"""
Massive synonym database — auto-generated from open sources.

Sources:
  - Moby Thesaurus (public domain, Grady Ward 1996)
  - Datamuse API (free, attribution requested)
  - RU Wiktionary (CC BY-SA 3.0)
  - UK Wiktionary (CC BY-SA 3.0)

Generated: 2026-03-02 20:22:05
EN: 30058 root words
RU: 115 root words
UK: 11 root words
"""

from __future__ import annotations

# ═══════════════════════════════════════════════════════════
#  ENGLISH SYNONYMS
# ═══════════════════════════════════════════════════════════

EN_SYNONYMS: dict[str, list[str]] = {
    'a cappella': ['abbandono', 'accrescendo', 'affettuoso', 'agilmente', 'agitato', 'amabile', 'amoroso', 'appassionatamente', 'appassionato', 'brillante', 'capriccioso', 'con affetto'],
    'a la mode': ['advanced', 'avant-garde', 'chic', 'contemporary', 'dashing', 'exclusive', 'far out', 'fashionable', 'fashionably', 'forward-looking', 'in', 'in the mode'],
    'a priori': ['a fortiori', 'a posteriori', 'analytic', 'back', 'backward', 'categorical', 'conditional', 'deducible', 'deductive', 'derivable', 'dialectic', 'discursive'],
    'a-bomb': ['h-bomb', 'atomic bomb', 'atomic warhead', 'clean bomb', 'cobalt bomb', 'dirty bomb', 'fusion bomb', 'hell bomb', 'hydrogen bomb', 'limited nuclear weapons', 'nuclear artillery', 'nuclear explosive'],
    'ab ovo': ['ab initio', 'aborigine', 'afresh', 'again', 'anew', 'as new', 'at first', 'at the start', 'basal', 'basic', 'before everything', 'chiefly'],
    'abaddon': ['aeshma', 'angra mainyu', 'apollyon', 'azazel', 'beelzebub', 'belial', 'eblis', 'gehenna', 'hades', 'lilith', 'mephisto', 'mephistopheles'],
    'abandon': ['abandonment', 'abjection', 'abjure', 'abort', 'abscond', 'acknowledge defeat', 'ardency', 'ardor', 'back out', 'beat a retreat', 'beg a truce', 'beg off'],
    'abandoned': ['a bit much', 'abjured', 'afire', 'amok', 'antiquated', 'antique', 'archaic', 'ardent', 'available', 'bellowing', 'berserk', 'boundless'],
    'abase': ['abash', 'bring down', 'bring low', 'bump', 'bust', 'cast down', 'cower', 'cringe', 'crush', 'debase', 'degrade', 'demean'],
    'abasement': ['bump', 'bust', 'casting down', 'comedown', 'debasement', 'deflation', 'degradation', 'degrading', 'demotion', 'depluming', 'descent', 'disgrace'],
    'abash': ['abase', 'appall', 'astound', 'bewilder', 'bother', 'bring down', 'bring low', 'cast down', 'chagrin', 'confound', 'confuse', 'crush'],
    'abashed': ['abroad', 'adrift', 'afflicted', 'agitated', 'ashamed', 'astray', 'at sea', 'beset', 'bewildered', 'blushing', 'bothered', 'cast down'],
    'abate': ['ablate', 'abolish', 'abrade', 'abrogate', 'abstract', 'adjust to', 'allay', 'alleviate', 'allow', 'alter', 'anesthetize', 'annihilate'],
    'abatement': ['abridgment', 'agio', 'allayment', 'alleviation', 'allowance', 'analgesia', 'anesthesia', 'anesthetizing', 'appeasement', 'assuagement', 'attenuation', 'attrition'],
    'abatis': ['advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'bastion', 'battlement', 'breastwork'],
    'abbe': ['dd', 'doctor of divinity', 'holy joe', 'chaplain', 'churchman', 'clergyman', 'cleric', 'clerical', 'clerk', 'curate', 'cure', 'divine'],
    'abbess': ['canoness', 'chatelaine', 'clergywoman', 'conventual', 'dame', 'dowager', 'first lady', 'goodwife', 'governess', 'great lady', 'homemaker', 'housewife'],
    'abbot': ['abbacomes', 'ascetic', 'beadsman', 'brother', 'caloyer', 'celibate', 'cenobite', 'conventual', 'conventual prior', 'friar', 'grand prior', 'hermit'],
    'abbreviate': ['abridge', 'abstract', 'attenuate', 'be telegraphic', 'blot out', 'blue-pencil', 'bob', 'boil down', 'bowdlerize', 'cancel', 'capsulize', 'censor'],
    'abbreviated': ['spartan', 'abridged', 'abstracted', 'aposiopestic', 'bobbed', 'brief', 'brusque', 'capsule', 'capsulized', 'clipped', 'close', 'compact'],
    'abbreviation': ['abbreviature', 'abrege', 'abridgment', 'abstract', 'apocope', 'aposiopesis', 'astriction', 'astringency', 'blue-penciling', 'bottleneck', 'bowdlerization', 'brief'],
    'abdicate': ['abandon', 'abjure', 'acknowledge defeat', 'be pensioned', 'be superannuated', 'cashier', 'cast', 'cease', 'cede', 'cry quits', 'demit', 'desist from'],
    'abdication': ['abjuration', 'abjurement', 'cession', 'demission', 'deposal', 'dropping out', 'emeritus status', 'forced resignation', 'forswearing', 'handing over', 'relinquishment', 'renouncement'],
    'abdomen': ['abomasum', 'anus', 'appendix', 'bay window', 'beerbelly', 'belly', 'blind gut', 'bowels', 'brain', 'breadbasket', 'cecum', 'colon'],
    'abdominal': ['anal', 'appendical', 'big-bellied', 'cardiac', 'cecal', 'celiac', 'colic', 'colonic', 'coronary', 'duodenal', 'enteric', 'gastric'],
    'abduction': ['apprehension', 'arrest', 'arrestation', 'capture', 'catch', 'catching', 'collaring', 'coup', 'crimping', 'dragnet', 'forcible seizure', 'grab'],
    'abecedarian': ['aboriginal', 'allographic', 'alphabetarian', 'alphabetic', 'antenatal', 'apprentice', 'articled clerk', 'autochthonous', 'beginner', 'beginning', 'boot', 'budding'],
    'abecedary': ['abecedarium', 'alphabet book', 'and arithmetic', 'battledore', 'casebook', 'elementary education', 'elements', 'exercise book', 'first steps', 'gradus', 'grammar', 'hornbook'],
    'aberrant': ['aberrative', 'abnormal', 'abominable', 'abroad', 'adrift', 'all abroad', 'all off', 'all wrong', 'amiss', 'amorphous', 'anomalistic', 'anomalous'],
    'aberration': ['aberrance', 'aberrancy', 'abet', 'abnormality', 'abnormity', 'alienation', 'amorphism', 'anomalism', 'anomalousness', 'anomaly', 'bend', 'bias'],
    'abet': ['advance', 'advocate', 'aid', 'aid and abet', 'approve of', 'ask for', 'assist', 'avail', 'bail out', 'bear a hand', 'befriend', 'benefit'],
    'abettor': ['maecenas', 'accessory', 'accomplice', 'accomplice in crime', 'actuator', 'admirer', 'advocate', 'aficionado', 'angel', 'animator', 'apologist', 'backer'],
    'abeyance': ['abandonment', 'abjuration', 'abjurement', 'apathy', 'break', 'caesura', 'catalepsy', 'catatonia', 'cease-fire', 'cessation', 'cold storage', 'day off'],
    'abhor': ['abominate', 'be hostile to', 'contemn', 'detest', 'disapprove of', 'disdain', 'disfavor', 'dislike', 'disrelish', 'execrate', 'hate', 'hold in abomination'],
    'abhorrent': ['abominable', 'antipathetic', 'averse to', 'base', 'beastly', 'below contempt', 'beneath contempt', 'contemptible', 'crude', 'despicable', 'detestable', 'disgusted'],
    'abide': ['abide in', 'abide with', 'accede', 'accept', 'adhere', 'await', 'be big', 'be coextensive with', 'be comprised in', 'be constituted by', 'be contained in', 'be content with'],
    'abide by': ['accede', 'accept', 'acclaim', 'acquiesce', 'acquiesce in', 'act up to', 'adhere to', 'agree', 'agree to', 'agree with', 'applaud', 'assent'],
    'abiding': ['age-long', 'aged', 'ancient', 'antique', 'changeless', 'chronic', 'commorant', 'constant', 'continuing', 'continuous', 'diuturnal', 'durable'],
    'ability': ['ableness', 'address', 'adeptness', 'adequacy', 'adroitness', 'airmanship', 'aptitude', 'aptness', 'artfulness', 'artisanship', 'artistry', 'bravura'],
    'abject': ['abominable', 'accepting', 'acquiescent', 'agreeable', 'apologetic', 'arrant', 'assenting', 'atrocious', 'backscratching', 'base', 'beggarly', 'bootlicking'],
    'abjection': ['abandon', 'abandonment', 'corruptedness', 'corruption', 'corruptness', 'debasement', 'decadence', 'decadency', 'degeneracy', 'degenerateness', 'degeneration', 'degradation'],
    'abjuration': ['abandonment', 'abdication', 'abeyance', 'abjurement', 'abrogation', 'absolute contradiction', 'annulment', 'cessation', 'cession', 'chucking', 'chucking out', 'cold storage'],
    'abjure': ['abandon', 'abdicate', 'acknowledge defeat', 'assert the contrary', 'back down', 'back out', 'backwater', 'belie', 'brush aside', 'cease', 'cede', 'chuck'],
    'ablate': ['abate', 'abrade', 'abrase', 'absorb', 'assimilate', 'atomize', 'bark', 'bate', 'be eaten away', 'bleed white', 'break up', 'burn up'],
    'ablation': ['abrasion', 'abrasive', 'absorption', 'abstraction', 'assimilation', 'atomization', 'attrition', 'breakup', 'buffing', 'burning up', 'burnishing', 'chafe'],
    'ablaze': ['afire', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'bathed with light', 'bespangled', 'blazing', 'boiling over', 'breathless', 'brightened'],
    'able': ['adapted', 'adequate', 'adjusted', 'alert', 'au fait', 'brainy', 'brilliant', 'capable', 'checked out', 'clever', 'competent', 'effective'],
    'ablution': ['cleaning out', 'douche', 'douching', 'elution', 'elutriation', 'enema', 'flush', 'flushing', 'flushing out', 'irrigation', 'lathering', 'lavabo'],
    'ably': ['adeptly', 'adequately', 'adroitly', 'agilely', 'aptly', 'artfully', 'artistically', 'brilliantly', 'capably', 'cleverly', 'competently', 'cunningly'],
    'abnegation': ['abstinence', 'calm', 'calmness', 'conservatism', 'constraint', 'continence', 'contradiction', 'control', 'cool', 'declension', 'declination', 'declinature'],
    'abnormal': ['aberrant', 'abominable', 'absurd', 'amorphous', 'anomalistic', 'anomalous', 'atrocious', 'atypical', 'bereft of reason', 'brainsick', 'crackbrained', 'cracked'],
    'abnormality': ['aberrance', 'aberrancy', 'aberration', 'acute disease', 'affection', 'affliction', 'ailment', 'alienation', 'allergic disease', 'allergy', 'anomaly', 'atrophy'],
    'aboard': ['afloat', 'all aboard', 'aloft', 'among us', 'athwart the hawse', 'athwarthawse', 'aye', 'before the mast', 'here', 'hereabout', 'hereabouts', 'hereat'],
    'abode': ['abiding', 'accommodation', 'area', 'bearings', 'bench mark', 'billet', 'cohabitation', 'commorancy', 'diggings', 'digs', 'district', 'domicile'],
    'abolish': ['abate', 'abrogate', 'annihilate', 'annul', 'blot out', 'bring to naught', 'cancel', 'countermand', 'counterorder', 'delete', 'demolish', 'deracinate'],
    'abolition': ['abolishment', 'abrogation', 'annihilation', 'annulment', 'cancel', 'canceling', 'cancellation', 'cassation', 'choking', 'choking off', 'countermand', 'counterorder'],
    'abominable': ['aberrant', 'abhorrent', 'abject', 'abnormal', 'accursed', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beggarly'],
    'abomination': ['anglophobia', 'russophobia', 'abhorrence', 'allergy', 'anathema', 'annoyance', 'antagonism', 'anti-semitism', 'antipathy', 'atrocity', 'aversion', 'bad'],
    'aboriginal': ['abecedarian', 'aborigine', 'ancestral', 'antenatal', 'antepatriarchal', 'atavistic', 'autochthon', 'autochthonous', 'barbarian', 'barbaric', 'barbarous', 'basal'],
    'aborigine': ['bronze age man', 'hominidae', 'iron age man', 'stone age man', 'aboriginal', 'ancient', 'antediluvian', 'anthropoid', 'ape-man', 'autochthon', 'bushman', 'cave dweller'],
    'abort': ['abandon', 'belay', 'cancel', 'cease', 'close', 'conclude', 'cut it out', 'desist', 'determine', 'discontinue', 'drop it', 'end'],
    'abortive': ['barren', 'bootless', 'failed', 'failing', 'fruitless', 'futile', 'gainless', 'immature', 'ineffective', 'ineffectual', 'inefficacious', 'lame'],
    'abound': ['abound with', 'be alive with', 'bristle with', 'burst with', 'clutter', 'crawl', 'crawl with', 'creep with', 'crowd', 'crowded', 'exuberate', 'filled'],
    'about': ['again', 'aimlessly', 'all but', 'all over', 'all round', 'almost', 'along toward', 'alongside', 'anent', 'any which way', 'anyhow', 'anywise'],
    'about face': ['about-turn', 'accommodation', 'adaptation', 'adjustment', 'afterthoughts', 'alchemy', 'alteration', 'amelioration', 'apostasy', 'assimilation', 'assumption', 'back track'],
    'about ship': ['back and fill', 'bear away', 'bear off', 'bear to starboard', 'beat', 'beat about', 'box off', 'break', 'bring about', 'bring round', 'cant', 'cant round'],
    'above': ['a cut above', 'above all', 'above and beyond', 'abovestairs', 'additionally', 'again', 'ahead', 'airward', 'all included', 'aloft', 'aloof', 'also'],
    'above all': ['a fortiori', 'all the more', 'chiefly', 'dominantly', 'especially', 'even', 'ever so', 'first of all', 'in chief', 'in the main', 'indeed', 'mainly'],
    'above water': ['all clear', 'all straight', 'at anchor', 'clear', 'free and clear', 'high and dry', 'in harbor', 'in safety', 'in the clear', 'on', 'out of danger', 'out of debt'],
    'above-board': ['artless', 'candid', 'candidly', 'direct', 'forthright', 'frank', 'frankly', 'freely', 'genuine', 'guileless', 'honest', 'honorable'],
    'aboveboard': ['artless', 'authentic', 'before one', 'bona fide', 'face to face', 'fair and square', 'forthright', 'foursquare', 'genuine', 'good-faith', 'in broad daylight', 'in open court'],
    'abrade': ['abate', 'ablate', 'abrase', 'abstract', 'atomize', 'bark', 'bate', 'beat', 'blemish', 'bloody', 'bother', 'bray'],
    'abrasion': ['ablation', 'abrasive', 'abstraction', 'atomization', 'attrition', 'beating', 'blemish', 'break', 'brecciation', 'buffing', 'burn', 'burnishing'],
    'abrasive': ['ablation', 'ablative', 'abradant', 'abrasion', 'aluminum oxide', 'attrition', 'attritive', 'auto polish', 'buffing', 'burnish', 'burnishing', 'chafe'],
    'abreast': ['abeam', 'acquainted', 'along by', 'alongside', 'au courant', 'au fait', 'beside', 'by', 'coextensively', 'collaterally', 'contemporary', 'conversant'],
    'abridge': ['abbreviate', 'abstract', 'bereave', 'bleed', 'blot out', 'blue-pencil', 'bob', 'boil down', 'bowdlerize', 'brief', 'cancel', 'capsule'],
    'abridged': ['spartan', 'abbreviated', 'abstracted', 'aposiopestic', 'bobbed', 'brief', 'brusque', 'capsule', 'capsulized', 'clipped', 'close', 'compact'],
    'abridgment': ['abatement', 'abbreviation', 'abstract', 'alleviation', 'aphorism', 'apocope', 'attenuation', 'bereavement', 'blue-penciling', 'bowdlerization', 'breviary', 'brief'],
    'abroad': ['abashed', 'aberrant', 'adrift', 'afield', 'alfresco', 'all abroad', 'all off', 'all wrong', 'amiss', 'askew', 'astray', 'at fault'],
    'abrogate': ['abate', 'abolish', 'annihilate', 'annul', 'blot out', 'bring to naught', 'cancel', 'countermand', 'counterorder', 'disannul', 'discharge', 'dissolve'],
    'abrogation': ['abjuration', 'abjurement', 'abolishment', 'abolition', 'absolute contradiction', 'annulment', 'cancel', 'canceling', 'cancellation', 'cassation', 'contradiction', 'contrary assertion'],
    'abrupt': ['aggressive', 'arduous', 'bearish', 'beastly', 'bluff', 'blunt', 'blunt-edged', 'blunt-ended', 'blunt-pointed', 'blunted', 'bluntish', 'bold'],
    'abruptly': ['a corps perdu', 'bang', 'bearishly', 'bluffly', 'bluntly', 'boorishly', 'brashly', 'brusquely', 'cavalierly', 'churlishly', 'crustily', 'curtly'],
    'abscess': ['ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'aposteme', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'bed sore'],
    'abscond': ['abandon', 'absquatulate', 'beat a retreat', 'bolt', 'bow out', 'break', 'bunk', 'clear out', 'cut and run', 'decamp', 'depart', 'desert'],
    'absconded': ['absent', 'away', 'deleted', 'departed', 'disappeared', 'gone', 'lacking', 'missing', 'no longer present', 'nonattendant', 'nonexistent', 'not found'],
    'absence': ['awol', 'french leave', 'abscondence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'beggary', 'cut', 'day off', 'dearth', 'default'],
    'absent': ['absconded', 'absentminded', 'absorbed', 'abstracted', 'away', 'bemused', 'castle-building', 'daydreaming', 'daydreamy', 'deficient', 'deleted', 'departed'],
    'absent-minded': ['lethean', 'absent', 'absorbed', 'abstracted', 'amnestic', 'bemused', 'blocked', 'castle-building', 'converted', 'daydreaming', 'daydreamy', 'distracted'],
    'absentmindedness': ['lethe', 'walter mitty', 'absence of mind', 'absorption', 'abstractedness', 'abstraction', 'bemusement', 'brown study', 'carelessness', 'castle-building', 'daydream', 'daydreamer'],
    'absolute': ['ok', 'absolutist', 'absolutistic', 'abstract', 'accurate', 'actual', 'adducible', 'admissible', 'admitting no exception', 'admitting no question', 'affirmative', 'affirmatory'],
    'absolute zero': ['algidity', 'bitterness', 'bleakness', 'boiling point', 'briskness', 'chill', 'chilliness', 'cold', 'coldness', 'cool', 'coolness', 'coolth'],
    'absolutely': ['ok', 'roger', 'a outrance', 'actually', 'affirmatively', 'all out', 'all right', 'alright', 'alrighty', 'altogether', 'amen', 'and no mistake'],
    'absolution': ['acquittal', 'acquittance', 'amnesty', 'clearance', 'clearing', 'compurgation', 'condonation', 'destigmatization', 'destigmatizing', 'discharge', 'disculpation', 'dismissal'],
    'absolutism': ['caesarism', 'stalinism', 'absolute monarchy', 'absolute power', 'autarchy', 'authoritarianism', 'authority', 'autocracy', 'benevolent despotism', 'bond service', 'bondage', 'captivity'],
    'absolve': ['acquit', 'administer absolution', 'administer extreme unction', 'amnesty', 'cancel', 'clear', 'confess', 'declare a moratorium', 'decontaminate', 'destigmatize', 'discharge', 'dismiss'],
    'absorb': ['ablate', 'absorb the attention', 'adsorb', 'appreciate', 'apprehend', 'appropriate', 'arrest', 'assimilate', 'be with one', 'bleed white', 'blot', 'blot up'],
    'absorbed': ['absent', 'absentminded', 'absorbed in', 'abstracted', 'bemused', 'buried', 'buried in', 'buried in thought', 'castle-building', 'caught up in', 'concentrating', 'contemplating'],
    'absorbent': ['absorbency', 'absorption', 'adsorbent', 'adsorption', 'assimilation', 'blotter', 'blotting', 'blotting paper', 'chemisorption', 'chemosorption', 'digestion', 'endosmosis'],
    'absorbing': ['acute', 'arresting', 'attractive', 'captivating', 'consuming', 'deep', 'deep-felt', 'deepgoing', 'enchanting', 'engaging', 'engrossing', 'enthralling'],
    'absorption': ['walter mitty', 'ablation', 'absence of mind', 'absentmindedness', 'absorbed attention', 'absorbency', 'absorbent', 'abstractedness', 'abstraction', 'adsorbent', 'adsorption', 'application'],
    'absquatulate': ['abscond', 'beat a retreat', 'bolt', 'clear out', 'cut and run', 'decamp', 'depart', 'desert', 'dog it', 'elope', 'flee', 'fly'],
    'abstain': ['abnegate', 'abstain from', 'avoid', 'constrain', 'cop out', 'curb', 'decline', 'dispense with', 'do without', 'duck the issue', 'eschew', 'evade'],
    'abstainer': ['albigensian', 'apostolici', 'catharist', 'encratite', 'franciscan', 'pythagorean', 'pythagorist', 'rechabite', 'sabbatarian', 'shaker', 'trappist', 'waldensian'],
    'abstemious': ['apostolic', 'encratic', 'lenten', 'pythagorean', 'rechabite', 'shaker', 'spartan', 'stoic', 'abstentious', 'abstinent', 'ascetic', 'austere'],
    'abstention': ['encratism', 'friday', 'lenten fare', 'pythagoreanism', 'pythagorism', 'rechabitism', 'shakerism', 'spartan fare', 'stoicism', 'abstainment', 'abstemiousness', 'abstinence'],
    'abstinence': ['albigensianism', 'catharism', 'encratism', 'franciscanism', 'friday', 'lenten fare', 'platonic love', 'pythagoreanism', 'pythagorism', 'rechabitism', 'sabbatarianism', 'shakerism'],
    'abstract': ['abate', 'abbreviate', 'abbreviation', 'abbreviature', 'abrade', 'abrege', 'abridge', 'abridgment', 'abstract idea', 'abstraction', 'abstruse', 'academic'],
    'abstracted': ['abbreviated', 'abridged', 'absent', 'absentminded', 'absorbed', 'bemused', 'bobbed', 'buried in thought', 'capsule', 'capsulized', 'castle-building', 'clipped'],
    'abstraction': ['walter mitty', 'ablation', 'abrasion', 'absence of mind', 'absentmindedness', 'absorption', 'abstract', 'abstract idea', 'abstractedness', 'abulia', 'alienation', 'altarpiece'],
    'abstruse': ['herculean', 'abstract', 'arcane', 'arduous', 'beclouded', 'blind', 'brutal', 'buried', 'civilized', 'close', 'clouded', 'complex'],
    'absurd': ['pickwickian', 'a bit thick', 'a bit thin', 'abnormal', 'amusing', 'anomalous', 'asinine', 'balmy', 'barred', 'beyond belief', 'bizarre', 'childish'],
    'absurdity': ['absurdness', 'act of folly', 'aimlessness', 'amphigory', 'anticness', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'bizarreness', 'bizarrerie', 'blabber'],
    'abulia': ['abstraction', 'alienation', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'arteriosclerotic psychosis', 'catatonic stupor', 'certifiability', 'compulsion', 'cowardice', 'dejection'],
    'abundance': ['accumulation', 'acres', 'adequacy', 'affluence', 'amassment', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'backlog', 'bags', 'barrels'],
    'abundant': ['abounding', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'blooming', 'bottomless', 'bounteous', 'bountiful', 'bursting', 'bursting out', 'common'],
    'abuse': ['abuse of office', 'addiction', 'afflict', 'aggrieve', 'assail', 'assailing', 'assault', 'atrocity', 'attack', 'bark at', 'batter', 'befoul'],
    'abusive': ['rabelaisian', 'atrocious', 'back-biting', 'backhand', 'backhanded', 'belittling', 'bitchy', 'blackening', 'blameful', 'blasphemous', 'bludgeoning', 'blustering'],
    'abut': ['abut on', 'adjoin', 'appose', 'be based on', 'be contiguous', 'be in contact', 'bear on', 'bestraddle', 'bestride', 'border', 'border on', 'bring near'],
    'abysmal': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abyssal', 'appalling', 'astronomic', 'awful', 'bottomless', 'cavernous'],
    'abyss': ['bassalia', 'gehenna', 'sheol', 'tophet', 'abysm', 'abyssal zone', 'arroyo', 'bathyal zone', 'benthos', 'bottom waters', 'bottomless depths', 'box canyon'],
    'ac': ['dc', 'absorption current', 'active current', 'alternating current', 'conduction current', 'convection current', 'cycle', 'delta current', 'direct current', 'displacement current', 'eddy current', 'electric current'],
    'academia': ['academe', 'alma mater', 'college', 'college of engineering', 'community college', 'degree-granting institution', 'four-year college', 'graduate school', 'institute of technology', 'ivied halls', 'journalism school', 'junior college'],
    'academic': ['abstract', 'armchair', 'book-learned', 'bookish', 'booky', 'chimerical', 'classroom', 'closet', 'collegiate', 'conjectural', 'cross-disciplinary', 'devoted to studies'],
    'academician': ['bookman', 'classicist', 'clerk', 'colossus of knowledge', 'genius', 'giant of learning', 'humanist', 'learned clerk', 'learned man', 'literary man', 'litterateur', 'lover of learning'],
    'academy': ['gymnasium', 'latin school', 'realgymnasium', 'realschule', 'schule', 'ecole', 'educational institution', 'escuela', 'grammar school', 'high', 'high school', 'institute'],
    'accede': ['ok', 'abide by', 'accede to', 'accept', 'acclaim', 'accord to', 'acquiesce', 'acquiesce in', 'agree', 'agree to', 'agree with', 'allow'],
    'accelerate': ['activate', 'aggravate', 'atomize', 'beef up', 'blow up', 'bombard', 'bundle', 'bustle', 'cleave', 'complicate', 'concentrate', 'condense'],
    'acceleration': ['accelerando', 'aggravation', 'beefing-up', 'blowing up', 'blowup', 'concentration', 'condensation', 'consolidation', 'deepening', 'double time', 'double-quick', 'double-quick time'],
    'accelerator': ['pcv valve', 'alternator', 'ammeter', 'atom smasher', 'atomic accelerator', 'atomic cannon', 'bearings', 'bonnet', 'boot', 'brake', 'bucket seat', 'bumper'],
    'accent': ['alexandrine', 'accent mark', 'accents', 'accentuate', 'accentuation', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antispast', 'arsis', 'articulation'],
    'accentuate': ['accent', 'belabor', 'dwell on', 'emphasize', 'give emphasis to', 'harp on', 'highlight', 'italicize', 'overaccentuate', 'overemphasize', 'overstress', 'place emphasis on'],
    'accept': ['ok', 'abide by', 'abide with', 'accede', 'accede to', 'accept for gospel', 'accept implicitly', 'acclaim', 'accord to', 'accredit', 'acknowledge', 'acquiesce'],
    'acceptable': ['ok', 'adequate', 'admissible', 'adorable', 'agreeable', 'all right', 'alright', 'appetizing', 'attractive', 'average', 'bearable', 'better than nothing'],
    'acceptance': ['cd', 'iou', 'john hancock', 'mo', 'ok', 'acceptance bill', 'acceptation', 'acception', 'accession', 'accord', 'acknowledgment', 'acquiescence'],
    'acceptation': ['acceptance', 'acception', 'acquiescence', 'assurance', 'assuredness', 'belief', 'certainty', 'confidence', 'credence', 'credit', 'credulity', 'dependence'],
    'accepted': ['christian', 'acclaimed', 'accustomed', 'acknowledged', 'admired', 'admitted', 'adopted', 'advocated', 'affirmed', 'allowed', 'applauded', 'appointed'],
    'accepting': ['spartan', 'abject', 'acquiescent', 'agreeable', 'armed with patience', 'assenting', 'at ease', 'clement', 'comfortable', 'compassionate', 'complaisant', 'compliable'],
    'access': ['jacksonian epilepsy', 'rasputin', 'rolandic epilepsy', 'svengali', 'vip', 'abdominal epilepsy', 'accessibility', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation'],
    'accessible': ['adaptable', 'affirmed', 'all-around', 'amenable', 'announced', 'approachable', 'at hand', 'attainable', 'attendant', 'available', 'broadcast', 'brought to notice'],
    'accession': ['accedence', 'acceptance', 'access', 'accessory', 'accompaniment', 'accretion', 'accrual', 'accruement', 'accumulation', 'acquiescence', 'acquirement', 'acquisition'],
    'accessory': ['a party to', 'abettor', 'accessary', 'accession', 'accessories', 'accident', 'accidental', 'accompaniment', 'accompanying', 'accomplice', 'accomplice in crime', 'accretion'],
    'accident': ['accessary', 'accessory', 'accidental', 'addendum', 'addition', 'adjunct', 'adventure', 'appendage', 'appurtenance', 'auxiliary', 'blow', 'blunder'],
    'accident prone': ['breakneck', 'careless', 'desperate', 'devil-may-care', 'furious', 'harum-scarum', 'hasty', 'headlong', 'hotheaded', 'hurried', 'impetuous', 'mad'],
    'accidental': ['accessory', 'accident', 'accidentally', 'accompanying', 'addendum', 'addition', 'additional', 'adjunct', 'ado', 'adscititious', 'adventitious', 'afloat'],
    'acclaim': ['abide by', 'accede', 'accept', 'acclamation', 'acquiesce', 'acquiesce in', 'agree', 'agree to', 'agree with', 'applaud', 'applause', 'assent'],
    'acclaimed': ['accepted', 'admired', 'admitted', 'advocated', 'applauded', 'approved', 'backed', 'celebrated', 'cried up', 'distinguished', 'fabled', 'famed'],
    'acclamation': ['acclaim', 'accord', 'accordance', 'agreement', 'agreement of all', 'applause', 'big hand', 'burst of applause', 'cheer', 'chorus', 'clap', 'clapping'],
    'acclimate': ['acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'break', 'break in', 'case harden', 'condition', 'confirm', 'domesticate', 'domesticize'],
    'accolade': ['adulation', 'apotheosis', 'award', 'badge', 'bays', 'bepraisement', 'citation', 'congratulation', 'decoration', 'deification', 'distinction', 'eloge'],
    'accommodate': ['acclimate', 'acclimatize', 'accommodate with', 'accord', 'accustom', 'adapt', 'adapt to', 'adjust', 'adjust to', 'advance', 'afford', 'agree with'],
    'accommodating': ['accessible', 'accommodative', 'acquiescent', 'adapting', 'adaptive', 'adjusting', 'affable', 'agreeable', 'amenable', 'amiable', 'attentive', 'benevolent'],
    'accommodation': ['wall street loan', 'abatement of differences', 'about-face', 'acclimation', 'acclimatization', 'accommodations', 'accord', 'accordance', 'accustoming', 'acquiescence', 'adaptation', 'adaption'],
    'accommodations': ['accommodation', 'bed', 'bed and board', 'berth', 'board', 'board and room', 'diggings', 'digs', 'facilities', 'housing', 'keep', 'living quarters'],
    'accompaniment': ['accession', 'accessory', 'accordance', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct', 'adjuvant'],
    'accompany': ['agree', 'associate', 'associate with', 'assort with', 'attend', 'band together', 'be in phase', 'be in time', 'chaperon', 'chaperone', 'chord', 'coexist'],
    'accompanying': ['accessory', 'accidental', 'accordant', 'ado', 'afloat', 'afoot', 'agreeing', 'associate', 'associated', 'at one with', 'attendant', 'attending'],
    'accomplice': ['a party to', 'abettor', 'accessary', 'accessory', 'accomplice in crime', 'ally', 'assistant', 'associate', 'coconspirator', 'cohort', 'collaborator', 'colleague'],
    'accomplish': ['achieve', 'act', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be productive', 'be received', 'blow in', 'bob up'],
    'accomplished fact': ['accomplished', 'accomplishment', 'achieved', 'achievement', 'act', 'acta', 'action', 'actuality', 'adventure', 'at concert pitch', 'attained', 'attainment'],
    'accomplishment': ['ability', 'accomplished fact', 'accomplishments', 'achievement', 'acquirement', 'acquisition of knowledge', 'acquisitions', 'act', 'acta', 'action', 'administration', 'advance'],
    'accord': ['ok', 'accede to', 'accept', 'acceptance', 'acclamation', 'accommodate', 'accommodate with', 'accommodation', 'accord to', 'accordance', 'acquiescence', 'adapt'],
    'accordance': ['acclamation', 'accommodation', 'accompaniment', 'accord', 'acquiescence', 'acquittal', 'acquittance', 'adaptation', 'adaption', 'adherence', 'adjustment', 'affinity'],
    'according to': ['accommodated to', 'adapted to', 'adjusted to', 'after', 'agreeable to', 'agreeably to', 'answerable to', 'by', 'conformable to', 'congruent with', 'consistent with', 'in accordance with'],
    'according to hoyle': ['according to regulations', 'according to rule', 'appropriate', 'by the book', 'by the numbers', 'condign', 'correct', 'decent', 'decorous', 'due', 'fit', 'fitting'],
    'accordingly': ['according to circumstances', 'and so', 'appropriately', 'as a consequence', 'as a result', 'as it is', 'as matters stand', 'at that rate', 'because of that', 'because of this', 'compliantly', 'conformably'],
    'accost': ['address', 'advance', 'apostrophize', 'appeal to', 'approach', 'appropinquate', 'approximate', 'bear down on', 'bear down upon', 'bear up', 'bespeak', 'bid good day'],
    'account': ['a reckoning of', 'account current', 'account for', 'account of', 'account rendered', 'account stated', 'accounting', 'accounts', 'acquaintance', 'acta', 'adjudge', 'adjudicate'],
    'account for': ['accredit with', 'accrete to', 'acknowledge', 'allegorize', 'apply to', 'ascribe to', 'assign to', 'attach to', 'attribute to', 'blame', 'blame for', 'blame on'],
    'accountable': ['englishable', 'alleged', 'amenable', 'answerable', 'ascribable', 'assignable', 'attributable', 'attributed', 'chargeable', 'charged', 'construable', 'credited'],
    'accountant': ['ca', 'cpa', 'abacist', 'accountant general', 'actuary', 'amanuensis', 'archivist', 'auditor', 'bank accountant', 'bank examiner', 'bookkeeper', 'bursar'],
    'accounting': ['account', 'account rendered', 'accountancy', 'acta', 'analysis', 'annual', 'audit', 'auditing', 'bookkeeping', 'braking', 'brief', 'bulletin'],
    'accouterment': ['armament', 'catering', 'chandlery', 'endowment', 'equipment', 'finding', 'fitting out', 'furnishing', 'furnishment', 'investment', 'logistics', 'outfitting'],
    'accredit': ['ok', 'accept', 'account for', 'accredit with', 'accrete to', 'acknowledge', 'affirm', 'amen', 'apply to', 'approve', 'ascribe to', 'assign'],
    'accroach': ['adopt', 'annex', 'appropriate', 'arrogate', 'assume', 'colonize', 'commandeer', 'confiscate', 'conquer', 'encroach', 'enslave', 'expropriate'],
    'accrue': ['accrue from', 'accrue to', 'accumulate', 'advance', 'appreciate', 'arise from', 'balloon', 'be contingent on', 'be due to', 'be received', 'bloat', 'boom'],
    'acculturation': ['americanization', 'admission', 'adoption', 'affiliation', 'assimilation', 'citizenship by naturalization', 'citizenship papers', 'civility', 'civilization', 'complex', 'cultivation', 'cultural drift'],
    'accumulate': ['accouple', 'accrue', 'advance', 'agglomerate', 'agglutinate', 'aggregate', 'aggroup', 'amass', 'appreciate', 'articulate', 'assemble', 'associate'],
    'accumulation': ['abundance', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'acervation', 'addition', 'advance', 'agglomerate', 'agglomeration', 'aggrandizement'],
    'accuracy': ['absoluteness', 'attention to detail', 'attention to fact', 'care for truth', 'circumstantiality', 'conscientiousness', 'correctness', 'criticality', 'criticalness', 'definiteness', 'delicacy', 'detail'],
    'accurate': ['ok', 'absolute', 'all right', 'appreciative', 'attentive', 'authentic', 'careful', 'close', 'conscientious', 'correct', 'critical', 'dead right'],
    'accurately': ['bang', 'conscientiously', 'correctly', 'exactingly', 'exactly', 'exquisitely', 'faultlessly', 'flawlessly', 'fussily', 'in detail', 'just right', 'just so'],
    'accuse': ['accuse of', 'allege', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'article', 'attribute', 'blame', 'book', 'bring accusation', 'bring charges'],
    'accused': ['arraigned', 'blamed', 'charged', 'cited', 'correspondent', 'defendant', 'denounced', 'impeached', 'implicated', 'impugned', 'in complicity', 'incriminated'],
    'accustomed': ['accepted', 'acclimated', 'acclimatized', 'accommodated', 'adapted', 'adjusted', 'average', 'case-hardened', 'chronic', 'common', 'commonplace', 'conditioned'],
    'ace': ['a per se', 'air force', 'amigo', 'associate', 'atom', 'beaut', 'bedfellow', 'bedmate', 'best bower', 'bit', 'bomber pilot', 'bosom buddy'],
    'acedia': ['accidia', 'aloofness', 'anger', 'apathy', 'ataraxia', 'ataraxy', 'avarice', 'avaritia', 'benumbedness', 'blah', 'blahs', 'boredom'],
    'aceldama': ['belsen', 'dmz', 'abattoir', 'battle line', 'battle site', 'battlefield', 'battleground', 'butchery', 'combat area', 'combat zone', 'concentration camp', 'enemy line'],
    'acerbic': ['acerb', 'acerbate', 'acescent', 'acetose', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'amaroidal', 'asperous'],
    'acerbity': ['acescency', 'acid', 'acidity', 'acidness', 'acidulousness', 'acridity', 'acridness', 'acrimony', 'animosity', 'asperity', 'astringence', 'astringency'],
    'ache': ['ache for', 'ache to', 'aching', 'agonize', 'ail', 'angina', 'anguish', 'backache', 'be dying for', 'be dying to', 'be hurting for', 'bellyache'],
    'achieve': ['accomplish', 'acquire', 'act', 'actualize', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be productive', 'be received'],
    'achievement': ['accomplished fact', 'accomplishment', 'acquirement', 'acquisition', 'act', 'acta', 'action', 'administration', 'advent', 'adventure', 'alerion', 'animal charge'],
    'aching': ['heimweh', 'ache', 'achy', 'afflictive', 'algetic', 'angina', 'backache', 'bellyache', 'blow', 'cephalalgia', 'chilblains', 'chill'],
    'achromasia': ['achroma', 'achromatosis', 'albescence', 'albinism', 'albino', 'albinoism', 'blondness', 'canescence', 'chalkiness', 'creaminess', 'fairness', 'frostiness'],
    'achromic': ['achromatic', 'anemic', 'ashen', 'ashy', 'bled white', 'bloodless', 'cadaverous', 'chloranemic', 'colorless', 'dead', 'deadly pale', 'deathly pale'],
    'acid': ['det', 'dmt', 'foamite', 'lsd', 'mary jane', 'stp', 'thc', 'acerb', 'acerbate', 'acerbic', 'acerbity', 'acetic'],
    'acid rock': ['avant-garde jazz', 'ballroom music', 'bebop', 'boogie-woogie', 'bop', 'country rock', 'dance music', 'dances', 'folk rock', 'hard rock', 'hot jazz', 'jazz'],
    'acid test': ['assay', 'blank determination', 'brouillon', 'criterion', 'crucial test', 'crucible', 'determination', 'docimasy', 'essay', 'feeling out', 'first draft', 'kiteflying'],
    'acidhead': ['lsd user', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser', 'drug addict'],
    'acidify': ['acetify', 'acidulate', 'alkalify', 'alkalize', 'borate', 'carbonate', 'catalyze', 'chemical', 'chlorinate', 'electrolyze', 'ferment', 'homopolymerize'],
    'acidity': ['acerbity', 'acescency', 'acid', 'acidness', 'acidulousness', 'acridity', 'acrimony', 'agent', 'alkali', 'alkalinity', 'alloisomer', 'animosity'],
    'acidulous': ['acerb', 'acerbate', 'acerbic', 'acetic', 'acetose', 'acetous', 'acid', 'acidic', 'acidulated', 'acidulent', 'acrid', 'acrimonious'],
    'acknowledge': ['accept', 'account for', 'accredit with', 'accrete to', 'admit', 'admit everything', 'affirm', 'agree', 'agree provisionally', 'allege', 'allow', 'announce'],
    'acknowledged': ['accepted', 'admitted', 'affirmed', 'allowed', 'approved', 'authenticated', 'avowed', 'being done', 'certified', 'comme il faut', 'conceded', 'confessed'],
    'acknowledgment': ['abject apology', 'acceptance', 'acknowledgments', 'acquittance', 'admission', 'allowance', 'answer', 'answering', 'antiphon', 'apology', 'appreciation', 'avowal'],
    'acme': ['olympian heights', 'acme of perfection', 'aerial heights', 'all', 'apex', 'apogee', 'apotheosis', 'authority', 'authorization', 'be-all and end-all', 'beau ideal', 'best type'],
    'acne': ['acne vulgaris', 'dermamycosis', 'dermatitis', 'dermatosis', 'eczema', 'elephantiasis', 'epithelioma', 'erysipelas', 'erythema', 'exanthem', 'heat rash', 'herpes'],
    'acolyte': ['bible clerk', 'bible reader', 'acolytus', 'adjutant', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider', 'almoner', 'anagnost', 'assistant'],
    'acoustic': ['audible', 'audile', 'audio', 'auditory', 'aural', 'auricular', 'hearing', 'hypersonic', 'otic', 'otological', 'otopathic', 'otoscopic'],
    'acoustical': ['acoustic', 'audible', 'audile', 'audio', 'auditory', 'aural', 'auricular', 'hearing', 'hypersonic', 'otic', 'otological', 'otopathic'],
    'acoustics': ['newtonian physics', 'acoustical engineer', 'acoustician', 'aerophysics', 'applied physics', 'astrophysics', 'basic conductor physics', 'biophysics', 'chemical physics', 'cryogenics', 'crystallography', 'cytophysics'],
    'acquaint': ['accustom', 'advertise', 'advertise of', 'advise', 'apprise', 'brief', 'bring word', 'clue', 'communicate', 'disclose', 'divulge', 'do the honors'],
    'acquaintance': ['account', 'acquaintedness', 'advocate', 'alter ego', 'amigo', 'announcement', 'appreciation', 'apprehension', 'associate', 'awareness', 'backer', 'best friend'],
    'acquiesce': ['abide by', 'accede', 'accept', 'acclaim', 'accommodate', 'acquiesce in', 'adapt', 'adjust', 'agree', 'agree to', 'agree with', 'applaud'],
    'acquiescence': ['ok', 'quakerism', 'acceptance', 'acceptation', 'acception', 'accession', 'accommodation', 'accord', 'accordance', 'adaptation', 'adaption', 'adjustment'],
    'acquiescent': ['abject', 'accepting', 'accommodating', 'accordant', 'acquiescing', 'adaptable', 'adapting', 'adaptive', 'adjustable', 'adjusting', 'affirmative', 'agreeable'],
    'acquire': ['accept', 'accumulate', 'achieve', 'add', 'admit', 'amass', 'annex', 'assume', 'bag', 'be responsible for', 'be seized of', 'bring down'],
    'acquisition': ['acceptance', 'accession', 'accomplishment', 'accomplishments', 'achievement', 'acquirement', 'acquiring', 'acquisition of knowledge', 'acquisitions', 'admission', 'admittance', 'assets'],
    'acquisitive': ['a hog for', 'acquiring', 'all-devouring', 'ambitious for self', 'autistic', 'avaricious', 'avid', 'bottomless', 'careerist', 'coveting', 'covetous', 'demanding'],
    'acquit': ['absolve', 'amnesty', 'bear', 'carry', 'clear', 'comport', 'conduct', 'convict', 'decontaminate', 'demean', 'deport', 'destigmatize'],
    'acquittal': ['accordance', 'acquitment', 'acquittance', 'adherence', 'amortization', 'amortizement', 'binder', 'care', 'carrying out', 'cash', 'cash payment', 'clearance'],
    'acquitted': ['absolved', 'blotted', 'canceled', 'condoned', 'discharged', 'disregarded', 'exculpated', 'excused', 'exonerated', 'expended', 'forgiven', 'forgotten'],
    'acreage': ['area', 'breadth', 'continuum', 'dimension', 'emptiness', 'empty space', 'expanse', 'expansion', 'extension', 'extent', 'field', 'galactic space'],
    'acres': ['abundance', 'alluvion', 'alluvium', 'arable land', 'bags', 'barrels', 'bushel', 'chattels real', 'clay', 'clod', 'copiousness', 'countlessness'],
    'acrid': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrimonious', 'acute', 'amaroidal', 'antagonistic', 'antipathetic'],
    'acridity': ['acerbity', 'acidity', 'acidness', 'acidulousness', 'acridness', 'acrimony', 'acuity', 'acumination', 'acuteness', 'asperity', 'astringence', 'astringency'],
    'acrimonious': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'astringent', 'belligerent', 'biting', 'bitter'],
    'acrimony': ['acerbity', 'acid', 'acidity', 'acidness', 'acidulousness', 'acridity', 'animosity', 'animus', 'antipathy', 'asperity', 'astringency', 'bad blood'],
    'acrobat': ['aerialist', 'bareback rider', 'circus artist', 'clown', 'contortionist', 'equestrian director', 'equilibrist', 'flier', 'funambulist', 'gymnast', 'high wire artist', 'high-wire artist'],
    'acrobatics': ['rugby', 'aerobatics', 'agonistics', 'association football', 'athletics', 'banking', 'bathing', 'chandelle', 'crabbing', 'dive', 'diving', 'fishtailing'],
    'acropolis': ['bastion', 'beachhead', 'blockhouse', 'bridgehead', 'bunker', 'castle', 'citadel', 'donjon', 'fasthold', 'fastness', 'fort', 'fortress'],
    'across': ['across the grain', 'against', 'astraddle', 'astride', 'athwart', 'athwartships', 'bendwise', 'beyond', 'bias', 'biased', 'biaswise', 'catercorner'],
    'across the board': ['across-the-board', 'all', 'all put together', 'all-comprehensive', 'all-inclusive', 'altogether', 'as a body', 'as a whole', 'at large', 'blanket', 'bodily', 'collectively'],
    'acrostic': ['abuse of terms', 'acronym', 'amphibologism', 'amphiboly', 'anagram', 'avyayibhava', 'back formation', 'calembour', 'clipped word', 'compound', 'conjugate', 'construction'],
    'acrylic': ['bakelite', 'buna', 'celluloid', 'formica', 'lucite', 'mylar', 'pvc', 'perspex', 'plexiglas', 'styrofoam', 'teflon', 'acetate'],
    'act': ['accomplish', 'accomplished fact', 'accomplishment', 'achieve', 'achievement', 'acquit', 'act a part', 'act as', 'act as foil', 'act out', 'acta', 'acting'],
    'act as': ['act', 'act a part', 'act out', 'ape', 'copy', 'do', 'do duty', 'enact', 'function', 'function as', 'impersonate', 'masquerade as'],
    'act for': ['advance', 'answer for', 'appear for', 'assist', 'back up', 'be instrumental', 'change places with', 'commission', 'crowd out', 'cut out', 'deputize', 'displace'],
    'act like': ['affect', 'assume', 'borrow', 'chorus', 'copy', 'counterfeit', 'crib', 'ditto', 'do', 'do like', 'echo', 'fake'],
    'act of god': ['certainty', 'fate', 'fatefulness', 'force majeure', 'indefeasibility', 'ineluctability', 'inescapableness', 'inevasibleness', 'inevitability', 'inevitable accident', 'inevitableness', 'inexorability'],
    'act on': ['act upon', 'affect', 'approach', 'bear a hand', 'bear upon', 'concentrate on', 'condemn', 'decree', 'do something', 'do something about', 'doom', 'draw'],
    'act out': ['act', 'act a part', 'act as', 'ape', 'copy', 'create a role', 'depict', 'do', 'enact', 'impersonate', 'masquerade as', 'mime'],
    'acta': ['accomplished fact', 'accomplishment', 'account', 'account rendered', 'accounting', 'achievement', 'act', 'action', 'adventure', 'annual', 'blow', 'brief'],
    'acting': ['act', 'action', 'active', 'activism', 'activity', 'ad interim', 'affectation', 'aping', 'appearance', 'at work', 'attitudinizing', 'behavior'],
    'action': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'actions', 'activeness', 'activism', 'activity', 'acts', 'ad hoc measure', 'address'],
    'actionable': ['against the law', 'anarchic', 'anarchistic', 'anomic', 'applicable', 'authorized', 'black-market', 'bootleg', 'causidical', 'chargeable', 'competent', 'constitutional'],
    'activate': ['accelerate', 'actuate', 'animate', 'arouse', 'atomize', 'awaken', 'bombard', 'charge', 'cleave', 'contaminate', 'cross-bombard', 'energize'],
    'active': ['acting', 'active voice', 'activist', 'activistic', 'acute', 'aggressive', 'agile', 'alert', 'alive', 'animated', 'assiduous', 'at work'],
    'activism': ['act', 'acting', 'action', 'activeness', 'activity', 'behavior', 'business', 'doing', 'doings', 'employment', 'exercise', 'function'],
    'activist': ['ball of fire', 'beaver', 'big-time operator', 'bustler', 'busy bee', 'doer', 'eager beaver', 'enthusiast', 'go-getter', 'human dynamo', 'hustler', 'live wire'],
    'activity': ['act', 'acting', 'action', 'actions', 'activism', 'activities', 'acts', 'actuation', 'address', 'affair', 'affairs', 'affectation'],
    'actor': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'roscius', 'actress', 'affecter', 'agent', 'antagonist', 'antihero'],
    'actress': ['roscius', 'actor', 'antagonist', 'bad guy', 'barnstormer', 'character', 'character actor', 'character man', 'character woman', 'child actor', 'diseur', 'diseuse'],
    'actual': ['absolute', 'admitting no question', 'as is', 'ascertained', 'attested', 'authentic', 'authenticated', 'being', 'bona fide', 'categorically true', 'certain', 'certified'],
    'actuality': ['accomplished fact', 'achievement', 'actualization', 'attainment', 'authenticity', 'basis', 'being', 'confirmability', 'demonstratability', 'doubtlessness', 'embodiment', 'essence'],
    'actually': ['absolutely', 'assuredly', 'certainly', 'clearly', 'de facto', 'decidedly', 'demonstrably', 'factually', 'for a certainty', 'for real', 'forsooth', 'genuinely'],
    'actuary': ['ca', 'cpa', 'abacist', 'accident insurance', 'accountant', 'accountant general', 'annuity', 'assurance', 'auditor', 'aviation insurance', 'bail bond', 'bank accountant'],
    'actuate': ['animate', 'arouse', 'circulate', 'compel', 'drive', 'drive on', 'energize', 'excite', 'force', 'forward', 'foster', 'galvanize'],
    'actuation': ['activity', 'animation', 'direction', 'dynamics', 'going', 'influence', 'inner-direction', 'kinematics', 'kinesipathy', 'kinesis', 'kinesitherapy', 'kinetics'],
    'acuity': ['acridity', 'acumen', 'acumination', 'acuteness', 'adroitness', 'agility', 'alertness', 'apperception', 'aptitude', 'aptness', 'astuteness', 'attention'],
    'acumen': ['acuity', 'acuteness', 'apperception', 'astuteness', 'cogency', 'critical discernment', 'discernment', 'discrimination', 'farseeingness', 'farsightedness', 'flair', 'foresight'],
    'acute': ['machiavellian', 'machiavellic', 'absorbing', 'acanthoid', 'acanthous', 'accurate', 'acicular', 'acrid', 'active', 'acuate', 'aculeate', 'aculeiform'],
    'acutely': ['abundantly', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'conspicuously', 'copiously', 'eminently', 'emphatically', 'exceptionally', 'exquisitely', 'extraordinarily'],
    'ad infinitum': ['again and again', 'all over', 'at a stretch', 'at all points', 'at full length', 'at length', 'boundlessly', 'ceaselessly', 'connectedly', 'constantly', 'continually', 'continuously'],
    'ad lib': ['a beneplacito', 'a discretion', 'ad arbitrium', 'ad libitum', 'ad-libbing', 'al piacere', 'arrangement', 'at choice', 'at pleasure', 'at short notice', 'at sight', 'at will'],
    'adage': ['ana', 'analects', 'aphorism', 'apothegm', 'axiom', 'byword', 'catchword', 'collected sayings', 'current saying', 'dictate', 'dictum', 'distich'],
    'adagio': ['a poco', 'adagietto', 'allargando', 'allegretto', 'allegro', 'andante', 'andantino', 'calando', 'crescendo', 'decrescendo', 'diminuendo', 'forte'],
    'adamant': ['adamantine', 'at a standstill', 'cast-iron', 'dour', 'firm', 'flintlike', 'flinty', 'frozen', 'granitelike', 'granitic', 'grim', 'hard'],
    'adapt': ['acclimate', 'acclimatize', 'accommodate', 'accommodate with', 'accord', 'accustom', 'adapt to', 'adjust', 'adjust to', 'agree with', 'alter', 'ameliorate'],
    'adaptable': ['able to adapt', 'accessible', 'accommodative', 'acquiescent', 'adaptive', 'adjustable', 'all-around', 'alterable', 'alterative', 'ambidextrous', 'amphibious', 'at hand'],
    'adaptation': ['nachtmusik', 'about-face', 'absolute music', 'accommodation', 'accord', 'accordance', 'acquiescence', 'adaption', 'adjusting', 'adjustment', 'agreement', 'air varie'],
    'adapted': ['a propos', 'able', 'acclimated', 'acclimatized', 'accommodated', 'accommodated to', 'according to', 'accustomed', 'ad rem', 'adapted to', 'adjusted', 'adjusted to'],
    'add': ['adjoin', 'affix', 'agglutinate', 'algebraize', 'amalgamate', 'annex', 'append', 'assimilate', 'attach', 'augment', 'blend', 'burden'],
    'add to': ['aggrandize', 'amplify', 'augment', 'bloat', 'blow up', 'boost', 'broaden', 'build', 'build up', 'bulk', 'bulk out', 'crescendo'],
    'add up': ['add up to', 'aggregate', 'aggregate to', 'amount to', 'be ok', 'be correct', 'be just right', 'be right', 'cast up', 'cipher up', 'come', 'come to'],
    'addendum': ['ps', 'parthian shot', 'accession', 'accessory', 'accident', 'accidental', 'accompaniment', 'addenda', 'additament', 'addition', 'additive', 'additory'],
    'addict': ['lsd user', 'acidhead', 'address', 'adherent', 'adjust', 'admirer', 'aficionado', 'alcoholic', 'apply', 'aspirant', 'aspirer', 'bias'],
    'addiction': ['a habit', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'alcoholism', 'barbiturate addiction', 'barbiturism', 'chain smoking', 'chronic alcoholism', 'cocainism', 'crash', 'craving'],
    'adding machine': ['comptometer', 'abacus', 'adding', 'analog computer', 'arithmograph', 'arithmometer', 'calculating machine', 'calculator', 'cash register', 'computation', 'counter', 'difference engine'],
    'addition': ['anschluss', 'access', 'accession', 'accessory', 'accident', 'accidental', 'accompaniment', 'accord', 'accretion', 'accrual', 'accruement', 'accumulation'],
    'additional': ['accessory', 'accidental', 'accumulative', 'added', 'additive', 'additory', 'adscititious', 'adventitious', 'ancillary', 'another', 'appurtenant', 'ascititious'],
    'additionally': ['to boot', 'in addition'],
    'additive': ['accession', 'accessory', 'accompaniment', 'accumulative', 'addenda', 'addendum', 'additament', 'addition', 'additional', 'additory', 'additum', 'adjunct'],
    'addle': ['addle the wits', 'amaze', 'astound', 'baffle', 'ball up', 'bamboozle', 'beat', 'becloud', 'bedazzle', 'befuddle', 'bemuse', 'besot'],
    'addled': ['addlebrained', 'addleheaded', 'addlepated', 'at a loss', 'baffled', 'bamboozled', 'beat', 'beclouded', 'beery', 'befuddled', 'bemused', 'besotted'],
    'addlepate': ['addlebrain', 'addlehead', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead', 'clodhead'],
    'addlepated': ['addlebrained', 'addled', 'addleheaded', 'beclouded', 'befuddled', 'blear-witted', 'cloudy', 'dizzy', 'fogged', 'foggy', 'fuddlebrained', 'fuddled'],
    'address': ['parthian shot', 'abiding place', 'ability', 'abode', 'accost', 'action', 'actions', 'activity', 'acts', 'adduce', 'adeptness', 'adroitness'],
    'address book': ['domesday book', 'account book', 'adversaria', 'album', 'annual', 'appointment calendar', 'appointment schedule', 'blankbook', 'blotter', 'calendar', 'cashbook', 'catalog'],
    'addressee': ['accepter', 'acquirer', 'artist-in-residence', 'audience', 'auditor', 'beholder', 'communicator', 'consignee', 'correspondent', 'denizen', 'dweller', 'getter'],
    'adduction': ['affinity', 'allurement', 'attractance', 'attraction', 'attractiveness', 'attractivity', 'capillarity', 'capillary attraction', 'centripetal force', 'drag', 'draw', 'gravitation'],
    'adept': ['admirable crichton', 'daedalian', 'able', 'accomplished', 'adept in', 'adroit', 'anthroposophist', 'apt', 'artisan', 'artist', 'artistic', 'at home in'],
    'adequate': ['ok', 'able', 'acceptable', 'admissible', 'all right', 'ample', 'average', 'barely sufficient', 'better than nothing', 'capable', 'comfortable', 'commensurate'],
    'adhere': ['agglomerate', 'bunch', 'clasp', 'cleave', 'clinch', 'cling', 'cling to', 'clot', 'cluster', 'coagulate', 'cohere', 'combine'],
    'adhere to': ['abide by', 'act up to', 'administer', 'attend to', 'be faithful to', 'bite', 'carry out', 'carry through', 'clasp', 'cleave to', 'clench', 'clinch'],
    'adherence': ['ok', 'acceptance', 'accordance', 'accretion', 'acquittal', 'acquittance', 'adhesion', 'admiration', 'agglomeration', 'agglutination', 'allegiance', 'approbation'],
    'adherent': ['averroist', 'berkeleian', 'cartesian', 'comtist', 'cynic', 'cyrenaic', 'eleatic', 'epicurean', 'eretrian', 'fichtean', 'hegelian', 'heideggerian'],
    'adhesive': ['adherent', 'affixation', 'amylaceous', 'annexation', 'attachment', 'barnacle', 'binding', 'birdlime', 'bond', 'bramble', 'brier', 'bulldog'],
    'adhesive tape': ['ace bandage', 'band-aid', 'mystik tape', 'scotch tape', 'application', 'band', 'bandage', 'bandaging', 'batten', 'belt', 'binder', 'brace'],
    'adieu': ['godspeed', 'aloha', 'by', 'bye-bye', 'conge', 'doch-an-dorrach', 'farewell', 'good-bye', 'leave', 'leave-taking', 'parting', 'parting words'],
    'adipose': ['beefy', 'big-bellied', 'bloated', 'blowzy', 'blubbery', 'bosomy', 'brawny', 'burly', 'buttery', 'butyraceous', 'buxom', 'chrismal'],
    'adit': ['access', 'admission', 'admittance', 'air lock', 'approach', 'channel', 'conduit', 'corridor', 'course', 'ditch', 'duct', 'egress'],
    'adjacent': ['abutting', 'adjoining', 'attached', 'bordering', 'close-by', 'closest', 'connected', 'connecting', 'consecutive', 'conterminous', 'contiguous', 'coterminous'],
    'adjective': ['adjectival', 'adverb', 'adverbial', 'adversative conjunction', 'attributive', 'conjunction', 'conjunctive adverb', 'coordinating conjunction', 'copulative', 'copulative conjunction', 'correlative conjunction', 'disjunctive'],
    'adjoin': ['abut', 'abut on', 'add', 'affix', 'agglutinate', 'annex', 'append', 'appose', 'attach', 'be contiguous', 'be in contact', 'befringe'],
    'adjoining': ['abutting', 'adjacent', 'bordering', 'connecting', 'conterminous', 'contiguous', 'coterminous', 'end to end', 'endways', 'endwise', 'face to face', 'immediate'],
    'adjourn': ['break up', 'close', 'continue', 'curb', 'defer', 'delay', 'disband', 'discontinue', 'disperse', 'dissolve', 'drag out', 'extend'],
    'adjudicate': ['account', 'adjudge', 'allow', 'arbitrate', 'be judicious', 'consider', 'count', 'deem', 'esteem', 'exercise judgment', 'express an opinion', 'form an opinion'],
    'adjunct': ['accession', 'accessory', 'accident', 'accidental', 'accord', 'accretion', 'addendum', 'addition', 'adjunction', 'adornment', 'affairs', 'affiliation'],
    'adjure': ['administer an oath', 'appeal', 'appeal to', 'beg', 'beseech', 'call for help', 'call on', 'call upon', 'clamor for', 'conjure', 'crave', 'cry for'],
    'adjust': ['abate', 'accept', 'acclimate', 'acclimatize', 'accommodate', 'accommodate with', 'accord', 'accustom', 'adapt', 'adapt to', 'addict', 'adjust to'],
    'adjustable': ['able to adapt', 'acquiescent', 'adaptable', 'adaptive', 'all-around', 'alterable', 'alterative', 'ambidextrous', 'amphibious', 'changeable', 'checkered', 'complaisant'],
    'adjusted': ['able', 'acclimated', 'acclimatized', 'accommodated', 'accustomed', 'adapted', 'capable', 'case-hardened', 'checked out', 'competent', 'conditioned', 'experienced'],
    'adjustment': ['abatement of differences', 'about-face', 'acclimation', 'acclimatization', 'accommodation', 'accord', 'accordance', 'accustoming', 'acquiescence', 'adaptation', 'adaption', 'adjusting'],
    'adjutant': ['acolyte', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider', 'assistant', 'attendant', 'auxiliary', 'best man', 'coadjutant', 'coadjutor'],
    'adjuvant': ['accession', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct', 'alterative'],
    'administer': ['abide by', 'accord', 'adhere to', 'administer justice', 'administrate', 'afford', 'allocate', 'allot', 'allow', 'apply', 'apportion', 'assign'],
    'administer to': ['attend', 'attend on', 'care for', 'chore', 'dance attendance upon', 'do for', 'do service to', 'drudge', 'help', 'lackey', 'look after', 'maid'],
    'administration': ['academic dean', 'accomplishment', 'achievement', 'administering', 'administrator', 'application', 'applying', 'archon', 'auspices', 'authority', 'bestowal', 'board'],
    'administrator': ['academic dean', 'administration', 'agent', 'chancellor', 'conductor', 'dean', 'dean of men', 'dean of women', 'deputy', 'directeur', 'director', 'exec'],
    'admirable': ['adorable', 'angelic', 'awe-inspiring', 'beyond all praise', 'caressable', 'charming', 'commendable', 'creditable', 'cuddlesome', 'deserving', 'estimable', 'excellent'],
    'admiration': ['amor', 'christian love', 'eros', 'ok', 'platonic love', 'acceptance', 'account', 'adherence', 'adoration', 'affection', 'agape', 'amaze'],
    'admire': ['ok', 'accept', 'accord respect to', 'adore', 'apotheosize', 'appreciate', 'approve', 'approve of', 'bless', 'cherish', 'consider', 'countenance'],
    'admired': ['accepted', 'acclaimed', 'admitted', 'adored', 'advocated', 'applauded', 'appreciated', 'approved', 'backed', 'beloved', 'cherished', 'cried up'],
    'admirer': ['maecenas', 'abettor', 'adherent', 'adorer', 'advocate', 'aficionado', 'amateur', 'amorist', 'angel', 'apologist', 'backer', 'beau'],
    'admissibility': ['acceptability', 'adequacy', 'adequateness', 'admissibleness', 'admission', 'agreeability', 'allowableness', 'applicability', 'appositeness', 'appropriateness', 'aptitude', 'aptness'],
    'admissible': ['ok', 'a propos', 'absolute', 'acceptable', 'ad rem', 'adducible', 'adequate', 'admissive', 'admissory', 'agreeable', 'all right', 'allowable'],
    'admission': ['americanization', 'ok', 'acceptance', 'access', 'acculturation', 'acknowledging', 'acknowledgment', 'acquisition', 'adit', 'admissibility', 'admission fee', 'admittance'],
    'admissive': ['admissible', 'admissory', 'allowing', 'confessional', 'consenting', 'hospitable', 'imbibitory', 'indulgent', 'ingestive', 'intromissive', 'intromittent', 'invitatory'],
    'admit': ['americanize', 'anglicize', 'ok', 'accept', 'accord', 'acculturate', 'acculturize', 'acknowledge', 'acquiesce', 'acquire', 'admit everything', 'admit exceptions'],
    'admitted': ['accepted', 'acclaimed', 'acknowledged', 'admired', 'advocated', 'affirmed', 'allowed', 'applauded', 'approved', 'authenticated', 'avowed', 'backed'],
    'admixture': ['accretion', 'addition', 'alloy', 'alloyage', 'amalgam', 'amalgamation', 'bit', 'blend', 'blending', 'coalescence', 'combination', 'combo'],
    'admonish': ['advise', 'alert', 'bring to book', 'call down', 'call to account', 'caution', 'charge', 'chastise', 'chide', 'correct', 'cry havoc', 'cry out against'],
    'admonition': ['admonishment', 'advice', 'advising', 'advocacy', 'alarm', 'briefing', 'castigation', 'caution', 'cautioning', 'caveat', 'chastisement', 'chiding'],
    'ado': ['agitation', 'annoyance', 'anxiety', 'besetment', 'bother', 'botheration', 'brawl', 'broil', 'brouhaha', 'burst', 'bustle', 'can of worms'],
    'adobe': ['ashlar', 'biscuit', 'bisque', 'bowl', 'brick', 'bricks and mortar', 'cement', 'ceramic ware', 'ceramics', 'china', 'clayey', 'clayish'],
    'adolescent': ['at half cock', 'baby', 'callow', 'fledgling', 'green', 'half-baked', 'half-cocked', 'half-grown', 'hopeful', 'ill-digested', 'immature', 'impubic'],
    'adopt': ['americanize', 'anglicize', 'accept', 'acculturate', 'acculturize', 'admit', 'affect', 'affiliate', 'appropriate', 'approve', 'arrogate', 'assimilate'],
    'adopted': ['americanized', 'anglicized', 'accepted', 'acculturated', 'acculturized', 'appointed', 'approved', 'assimilated', 'carried', 'chosen', 'designated', 'elect'],
    'adoption': ['americanization', 'acceptance', 'acculturation', 'admission', 'affiliation', 'appropriation', 'arrogation', 'assimilation', 'assumption', 'borrowed plumes', 'circumcision', 'citizenship by naturalization'],
    'adorable': ['acceptable', 'admirable', 'agreeable', 'ambrosial', 'angelic', 'appealing', 'appetizing', 'attractive', 'beloved', 'captivating', 'caressable', 'charming'],
    'adoration': ['amor', 'christian love', 'eros', 'platonic love', 'admiration', 'affection', 'agape', 'apotheosis', 'appreciation', 'approbation', 'approval', 'ardency'],
    'adore': ['accord respect to', 'admire', 'adulate', 'affection', 'apotheosize', 'appreciate', 'bask in', 'be pleased with', 'cherish', 'coddle', 'dearly love', 'defer to'],
    'adored': ['admired', 'appreciated', 'beloved', 'cherished', 'darling', 'dear', 'dearly beloved', 'esteemed', 'favorite', 'held dear', 'held in respect', 'highly considered'],
    'adoring': ['christian', 'christianlike', 'christianly', 'admiring', 'adorant', 'affectionate', 'apotheosizing', 'awed', 'awestricken', 'awestruck', 'believing', 'conjugal'],
    'adorn': ['array', 'beautify', 'become one', 'bedeck', 'bedizen', 'bestow honor upon', 'blazon', 'color', 'confer distinction on', 'convolute', 'dandify', 'deck'],
    'adorned': ['beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'colored', 'decked out', 'decorated', 'embellished', 'embroidered'],
    'adornment': ['adjunct', 'arrangement', 'beauties', 'beautification', 'beauty treatment', 'color', 'color patterns', 'colors', 'colors of rhetoric', 'decor', 'decoration', 'elaboration'],
    'adrift': ['abashed', 'aberrant', 'abroad', 'afloat', 'all abroad', 'all off', 'all wrong', 'alternating', 'amiss', 'amorphous', 'askew', 'astray'],
    'adroit': ['daedalian', 'adept', 'adroitness', 'apt', 'artful', 'artistic', 'astute', 'authoritative', 'brainy', 'bravura', 'bright', 'brilliant'],
    'adsorb': ['absorb', 'assimilate', 'blot', 'blot up', 'chemisorb', 'chemosorb', 'digest', 'drink', 'drink in', 'drink up', 'engross', 'filter in'],
    'adsorbent': ['absorbency', 'absorbent', 'absorption', 'adsorption', 'assimilation', 'assimilative', 'bibulous', 'blotter', 'blotting', 'blotting paper', 'chemisorption', 'chemisorptive'],
    'adsorption': ['absorbency', 'absorbent', 'absorption', 'adsorbent', 'assimilation', 'blotter', 'blotting', 'blotting paper', 'chemisorption', 'chemosorption', 'digestion', 'endosmosis'],
    'adulation': ['acclaim', 'accolade', 'apotheosis', 'applause', 'bepraisement', 'blandishment', 'blarney', 'bunkum', 'cajolement', 'cajolery', 'compliment', 'congratulation'],
    'adult': ['aged', 'big', 'full-blown', 'full-fledged', 'full-grown', 'grown', 'grown up', 'grown-up', 'marriable', 'marriageable', 'mature', 'matured'],
    'adulterate': ['alloy', 'attenuate', 'baptize', 'bastardize', 'canker', 'cheapen', 'coarsen', 'confound', 'contaminate', 'cook', 'corrupt', 'cut'],
    'adulterated': ['airy', 'attenuate', 'attenuated', 'blemished', 'cut', 'damaged', 'defective', 'deficient', 'dilute', 'diluted', 'erroneous', 'ethereal'],
    'adultery': ['act of love', 'adulterous affair', 'affair', 'amour', 'aphrodisia', 'ass', 'balling', 'carnal knowledge', 'climax', 'cohabitation', 'coition', 'coitus'],
    'adulthood': ['adultness', 'age of consent', 'driving age', 'flower of age', 'full age', 'full bloom', 'full growth', 'fullgrownness', 'grown-upness', 'legal age', 'legalis homo', 'majority'],
    'adumbrate': ['allude to', 'argue', 'augur', 'auspicate', 'becloud', 'bedim', 'bespeak', 'betoken', 'block out', 'bode', 'body forth', 'call'],
    'advance': ['brownian movement', 'great leap forward', 'wall street loan', 'abet', 'accelerate', 'access', 'accession', 'accommodate with', 'accommodation', 'accomplishment', 'accost', 'accretion'],
    'advance guard': ['airhead', 'armed guard', 'avant-garde', 'bank guard', 'battle line', 'beachhead', 'bridgehead', 'coast guard', 'cordon', 'cordon sanitaire', 'farthest outpost', 'first line'],
    'advanced': ['a bit previous', 'a la mode', 'advanced in life', 'advanced in years', 'adventurous', 'aged', 'along in years', 'ameliorated', 'ancient', 'avant-garde', 'beautified', 'bettered'],
    'advancement': ['great leap forward', 'accomplishment', 'advance', 'advancing', 'aggrandizement', 'amelioration', 'amendment', 'amplification', 'anabasis', 'ascent', 'bettering', 'betterment'],
    'advantage': ['accommodation', 'account', 'advance', 'advancement', 'advantageously', 'advantageousness', 'advisability', 'allowance', 'amenity', 'answer', 'appliance', 'applicability'],
    'advantageous': ['acceptable', 'advisable', 'agreeable', 'appropriate', 'auspicious', 'banausic', 'becoming', 'befitting', 'beneficial', 'benevolent', 'bon', 'bonny'],
    'advantageously': ['advisably', 'amelioratively', 'appropriately', 'at a profit', 'beneficially', 'congruously', 'conveniently', 'decently', 'desirably', 'effectively', 'effectually', 'efficiently'],
    'advent': ['allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas', 'corpus christi'],
    'adventitious': ['accessory', 'accidental', 'additional', 'adscititious', 'aleatory', 'appurtenant', 'ascititious', 'auxiliary', 'casual', 'causeless', 'chance', 'chancy'],
    'adventure': ['clio', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adventures', 'affair', 'annals', 'aristeia', 'autobiography'],
    'adventurer': ['adventuress', 'alpinist', 'astronaut', 'betting ring', 'bettor', 'big operator', 'boneshaker', 'bounder', 'bourgeois gentilhomme', 'brazenface', 'cad', 'camper'],
    'adventuresome': ['adventurous', 'aggressive', 'ambitious', 'audacious', 'daredevil', 'daring', 'driving', 'dynamic', 'enterprising', 'foolhardy', 'forceful', 'go-ahead'],
    'adventuress': ['aspasia', 'delilah', 'jezebel', 'messalina', 'phryne', 'thais', 'adventurer', 'brazenface', 'courtesan', 'daredevil', 'demimondaine', 'demimonde'],
    'adventurous': ['adventuresome', 'adversary', 'aggressive', 'aleatory', 'ambitious', 'antagonist', 'anti', 'assaulter', 'attacker', 'audacious', 'bold', 'brash'],
    'adverb': ['adjectival', 'adjective', 'adverbial', 'adversative conjunction', 'attributive', 'conjunction', 'conjunctive adverb', 'coordinating conjunction', 'copulative', 'copulative conjunction', 'correlative conjunction', 'disjunctive'],
    'adversary': ['adversative', 'adverse', 'alien', 'antagonist', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'archenemy', 'assailant', 'bitter enemy', 'clashing'],
    'adverse': ['adversary', 'adversative', 'adversive', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'antonymous', 'at cross-purposes', 'balancing', 'clashing'],
    'advertent': ['agog', 'alert', 'all ears', 'all eyes', 'assiduous', 'attentive', 'aware', 'careful', 'concentrated', 'conscious', 'diligent', 'earnest'],
    'advertise': ['acquaint', 'advertise of', 'advise', 'air', 'announce', 'annunciate', 'apprise', 'ballyhoo', 'bark', 'bill', 'blazon', 'blazon forth'],
    'advertisement': ['ad', 'advert', 'advertising', 'announcement', 'ballyhoo', 'bill', 'blurb', 'broadcast', 'broadside', 'brochure', 'circular', 'classified'],
    'advice': ['admonition', 'advisement', 'alerting', 'broadcast journalism', 'caution', 'cautioning', 'clue', 'communication', 'communique', 'counsel', 'cue', 'direction'],
    'advisable': ['advantageous', 'appropriate', 'becoming', 'befitting', 'commendable', 'congruous', 'convenient', 'decent', 'desirable', 'expedient', 'favorable', 'feasible'],
    'advise': ['acquaint', 'admonish', 'advertise', 'advertise of', 'advocate', 'alert', 'apprise', 'brief', 'bring word', 'caution', 'clue', 'coach'],
    'advised': ['aforethought', 'aimed', 'aimed at', 'calculated', 'conscious', 'considered', 'contemplated', 'deliberate', 'deliberated', 'designed', 'envisaged', 'envisioned'],
    'adviser': ['dutch uncle', 'polonius', 'admonisher', 'announcer', 'annunciator', 'authority', 'backseat driver', 'buttinsky', 'channel', 'cicerone', 'communicant', 'communicator'],
    'advisory': ['admonition', 'admonitory', 'bulletin', 'cautionary', 'communicative', 'consultative', 'consultatory', 'council', 'deliberative', 'didactic', 'directive', 'educational'],
    'advocacy': ['abetment', 'admonition', 'advice', 'advising', 'advocating', 'advocation', 'aegis', 'auspices', 'backing', 'briefing', 'bruiting', 'buildup'],
    'advocate': ['maecenas', 'abet', 'abettor', 'acquaintance', 'admirer', 'advance', 'advise', 'aficionado', 'agent', 'aid and abet', 'allege in support', 'alpenstock'],
    'aegis': ['abetment', 'advocacy', 'arm guard', 'armament', 'armor', 'auspices', 'backing', 'backstop', 'bard', 'beaver', 'brassard', 'breastplate'],
    'aeon': ['platonic year', 'age', 'ages', 'annus magnus', 'blue moon', 'century', 'cycle', 'cycle of indiction', 'date', 'day', 'eternity', 'florid'],
    'aerate': ['aerify', 'air', 'air out', 'air-condition', 'air-cool', 'airify', 'atomize', 'beat', 'carbonate', 'chlorinate', 'cream', 'cross-ventilate'],
    'aerial': ['olympian', 'aerials', 'aeriform', 'aerodynamic', 'aerophysical', 'aerospace', 'aerostatic', 'aerotechnical', 'aery', 'air-built', 'air-conscious', 'air-minded'],
    'aerialist': ['acrobat', 'bareback rider', 'circus artist', 'clown', 'contortionist', 'equestrian director', 'equilibrist', 'flier', 'funambulist', 'gymnast', 'high wire artist', 'high-wire artist'],
    'aerobatics': ['acrobatics', 'banking', 'chandelle', 'crabbing', 'dive', 'diving', 'fishtailing', 'glide', 'nose dive', 'power dive', 'pull-up', 'pullout'],
    'aerodynamic': ['aerial', 'aerographic', 'aerologic', 'aeromechanical', 'aerophysical', 'aerospace', 'aerostatic', 'aerotechnical', 'aery', 'air-conscious', 'air-minded', 'air-wise'],
    'aerodynamics': ['aerial photography', 'aeroballistics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics', 'aeroscopy'],
    'aerography': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics', 'aeroscopy'],
    'aerology': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics', 'aeroscopy'],
    'aeromechanics': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics', 'aeroscopy'],
    'aeromedicine': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics', 'aeroscopy'],
    'aeronaut': ['aeroplaner', 'aeroplanist', 'air pilot', 'airplanist', 'astronaut', 'aviator', 'barnstormer', 'birdman', 'captain', 'cloud seeder', 'commercial pilot', 'copilot'],
    'aeronautics': ['air service', 'airline', 'astronautics', 'aviation', 'ballooning', 'blind flying', 'cloud-seeding', 'commercial aviation', 'contact flying', 'cruising', 'flight', 'flying'],
    'aeroplane': ['adjustable propeller', 'afterburner', 'aileron', 'air controls', 'air scoop', 'aircraft', 'airlift', 'airplane', 'airscrew', 'astrodome', 'avion', 'balloon'],
    'aerosol': ['aspergil', 'aspergillum', 'atomizer', 'clyster', 'concentrate sprayer', 'douche', 'enema', 'evaporator', 'fountain syringe', 'mist concentrate sprayer', 'needle bath', 'nozzle'],
    'aerospace': ['cat', 'aerial', 'aerophysical', 'aerosphere', 'aerotechnical', 'air hole', 'air pocket', 'air-conscious', 'air-minded', 'air-wise', 'airsick', 'airspace'],
    'aerosphere': ['cat', 'aerospace', 'air hole', 'air pocket', 'airspace', 'atmosphere', 'biosphere', 'bump', 'ceiling', 'crosswind', 'ecosphere', 'empty space'],
    'aerostatics': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics'],
    'aery': ['aerial', 'aeriform', 'aerodynamic', 'aerostatic', 'airish', 'airlike', 'airy', 'alfresco', 'atmospheric', 'breezy', 'ethereal', 'exposed'],
    'aesthetic': ['attic', 'aesthetically appealing', 'art-conscious', 'artistic', 'arty', 'attractive', 'beauteous', 'beautiful', 'chaste', 'choice', 'classic', 'cultivated'],
    'aesthetics': ['artistic taste', 'axiology', 'casuistry', 'connoisseurship', 'cosmology', 'dilettantism', 'epicureanism', 'epicurism', 'epistemology', 'ethics', 'expertise', 'expertism'],
    'aestival': ['arctic', 'autumn', 'autumnal', 'beryl-green', 'berylline', 'blood-hot', 'blood-warm', 'blue-green', 'bluish-green', 'boreal', 'brumal', 'calid'],
    'affable': ['bohemian', 'accommodating', 'agreeable', 'amiable', 'amicable', 'attentive', 'benevolent', 'benign', 'benignant', 'blissful', 'bonhomous', 'casual'],
    'affair': ['activities', 'activity', 'adulterous affair', 'adultery', 'affairs', 'amor', 'amour', 'article', 'artifact', 'at home', 'attempt', 'bag'],
    'affairs': ['accord', 'activities', 'activity', 'addition', 'adjunct', 'affair', 'affiliation', 'affinity', 'alliance', 'approximation', 'assemblage', 'association'],
    'affect': ['act', 'act a part', 'act like', 'act on', 'act upon', 'actuate', 'adopt', 'affection', 'affectivity', 'agitate', 'alter', 'answer to'],
    'affectation': ['barnumism', 'gongorism', 'act', 'acting', 'action', 'actions', 'activity', 'acts', 'address', 'affectedness', 'air', 'airs'],
    'affected': ['gongoresque', 'gongoristic', 'johnsonian', 'marinistic', 'tartuffian', 'tartuffish', 'afflicted', 'agonized', 'apocryphal', 'artificial', 'assumed', 'attacked'],
    'affecting': ['afflictive', 'bitter', 'bleak', 'cheerless', 'comfortless', 'deplorable', 'depressing', 'depressive', 'discomforting', 'dismal', 'dismaying', 'distressful'],
    'affection': ['amor', 'christian love', 'eros', 'platonic love', 'abnormality', 'access', 'acute disease', 'admiration', 'adoration', 'adore', 'affect', 'affectionateness'],
    'affectionate': ['christian', 'christlike', 'christly', 'adoring', 'benign', 'benignant', 'brotherly', 'caring', 'compassionate', 'conjugal', 'dear', 'decent'],
    'affianced': ['assured', 'betrothed', 'bound', 'bride-to-be', 'committed', 'compromised', 'contracted', 'engaged', 'fiance', 'fiancee', 'future', 'guaranteed'],
    'affidavit': ['admission', 'affirmation', 'allegation', 'assertion', 'asseveration', 'attest', 'attestation', 'authority', 'authorization', 'averment', 'avouchment', 'avowal'],
    'affiliate': ['americanize', 'anglicize', 'greek', 'accept', 'acculturate', 'acculturize', 'act in concert', 'act together', 'admit', 'adopt', 'affiliate to', 'affiliate with'],
    'affiliated': ['affiliate', 'agnate', 'akin', 'allied', 'associate', 'associated', 'attached', 'avuncular', 'bound', 'bracketed', 'cabalistic', 'closely related'],
    'affiliation': ['americanization', 'anschluss', 'acceptance', 'accord', 'acculturation', 'addition', 'adjunct', 'admission', 'adoption', 'affairs', 'affinity', 'agglomeration'],
    'affinity': ['a thing for', 'accord', 'accordance', 'addition', 'adduction', 'adjunct', 'affairs', 'affiliation', 'agape', 'agreement', 'alikeness', 'alliance'],
    'affirm': ['ok', 'accept', 'accredit', 'acknowledge', 'allege', 'amen', 'announce', 'annunciate', 'approve', 'argue', 'assert', 'assever'],
    'affirmation': ['john hancock', 'ok', 'parthian shot', 'a priori principle', 'acceptance', 'accord', 'acquiescence', 'address', 'admission', 'affidavit', 'affirmance', 'affirmative'],
    'affirmative': ['ok', 'absolute', 'acceptance', 'accord', 'accordant', 'acquiescence', 'acquiescent', 'affirmation', 'affirmative attitude', 'affirmative voice', 'affirmativeness', 'affirmatory'],
    'affirmed': ['accepted', 'accessible', 'acknowledged', 'admitted', 'alleged', 'allowed', 'announced', 'approved', 'asserted', 'asseverated', 'attested', 'authenticated'],
    'affix': ['ic analysis', 'accidence', 'add', 'adjoin', 'affixation', 'agglutinate', 'allomorph', 'allonge', 'anchor', 'annex', 'append', 'appendix'],
    'affixation': ['ic analysis', 'accession', 'accidence', 'addition', 'adhesive', 'adjunct', 'adjunction', 'affix', 'agglutination', 'allomorph', 'annexation', 'attachment'],
    'afflatus': ['apollo', 'apollo musagetes', 'bragi', 'calliope', 'castilian spring', 'erato', 'euterpe', 'geist', 'helicon', 'hippocrene', 'muse', 'parnassus'],
    'afflict': ['abuse', 'affect', 'aggrieve', 'agitate', 'agonize', 'ail', 'anguish', 'annoy', 'befoul', 'bewitch', 'bite', 'blight'],
    'afflicted': ['abashed', 'agitated', 'agonized', 'bent', 'beset', 'boiled', 'bombed', 'boozy', 'bothered', 'canned', 'cast down', 'chagrined'],
    'affliction': ['abnormality', 'acute disease', 'adverse circumstances', 'adversity', 'affection', 'aggravation', 'ailment', 'allergic disease', 'allergy', 'anguish', 'annoyance', 'atrophy'],
    'afflictive': ['aching', 'algetic', 'calamitous', 'dire', 'distasteful', 'distressing', 'galling', 'grievous', 'heartbreaking', 'hurtful', 'hurting', 'lamentable'],
    'affluence': ['easy street', 'abundance', 'afflux', 'affluxion', 'ample sufficiency', 'ampleness', 'amplitude', 'assets', 'avalanche', 'bed of roses', 'bonanza', 'bottomless purse'],
    'affluent': ['abounding', 'abounding in riches', 'abundant', 'acquisitive', 'all-sufficing', 'ample', 'aplenty', 'big-rich', 'bottomless', 'bounteous', 'bountiful', 'comfortable'],
    'afflux': ['access', 'accession', 'advance', 'advent', 'affluence', 'affluxion', 'approach', 'approaching', 'appropinquation', 'approximation', 'appulse', 'coming'],
    'afford': ['accommodate', 'accommodate with', 'accord', 'administer', 'allot', 'allow', 'amount to', 'award', 'be loaded', 'bear', 'bear the expense', 'bestow'],
    'afforestation': ['christmas tree farming', 'arboretum', 'arboriculture', 'boondocks', 'bush', 'bushveld', 'chase', 'climax forest', 'cloud forest', 'dendrology', 'forest', 'forest land'],
    'affront': ['aggrieve', 'aspersion', 'atrocity', 'barb', 'beard', 'bell the cat', 'bid defiance', 'bite the bullet', 'brave', 'brazen', 'brazen out', 'breast'],
    'affusion': ['aspergation', 'aspersion', 'baptism', 'baptismal gown', 'baptismal regeneration', 'baptistery', 'baptizement', 'bath', 'bathing', 'bedewing', 'chrismal', 'christening'],
    'afghan': ['bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedsheet', 'bedspread', 'blanket', 'buffalo robe', 'case', 'clothes', 'comfort', 'comforter'],
    'aficionado': ['maecenas', 'abettor', 'admirer', 'advocate', 'amateur', 'angel', 'apologist', 'attender', 'audience', 'authority', 'backer', 'buff'],
    'afire': ['abandoned', 'ablaze', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'blazing', 'boiling over', 'breathless', 'burning', 'candent'],
    'afloat': ['aboard', 'accidental', 'accompanying', 'ado', 'adrift', 'afoot', 'all aboard', 'aloft', 'alternating', 'amorphous', 'astir', 'at flood'],
    'afoot': ['accidental', 'accompanying', 'ado', 'afloat', 'astir', 'by foot', 'circumstantial', 'current', 'doing', 'eventuating', 'footback', 'going on'],
    'aforethought': ['advised', 'calculatedness', 'calculation', 'considered', 'deliberateness', 'deliberation', 'designed', 'express intention', 'expressness', 'forethought', 'intentionality', 'preconsideration'],
    'afraid': ['abulic', 'afeared', 'aghast', 'anxious', 'apologetic', 'apprehensive', 'averse', 'backward', 'cautious', 'chary', 'chicken', 'chickenhearted'],
    'afresh': ['ab ovo', 'again', 'anew', 'another time', 'as new', 'bis', 'da capo', 'de novo', 'ditto', 'encore', 'freshly', 'from scratch'],
    'aft': ['abaft', 'after', 'aftermost', 'astern', 'back', 'backward', 'baft', 'fore and aft', 'hind', 'hinder', 'hindermost', 'hindhand'],
    'after': ['abaft', 'accommodated to', 'according to', 'adapted to', 'adjusted to', 'aft', 'after a time', 'after all', 'after that', 'aftermost', 'afterward', 'afterwards'],
    'after a fashion': ['appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst', 'by some means', 'comparatively', 'detectably'],
    'after all': ['after', 'after that', 'afterwards', 'again', 'albeit', 'all the same', 'all things considered', 'although', 'at all events', 'at any rate', 'before the bench', 'before the court'],
    'aftereffect': ['afterbirth', 'afterclap', 'aftercrop', 'afterglow', 'aftergrowth', 'afterimage', 'aftermath', 'afterpain', 'aftertaste', 'by-product', 'consequence', 'event'],
    'afterglow': ['afterbirth', 'afterclap', 'aftercrop', 'aftereffect', 'aftergrowth', 'afterimage', 'aftermath', 'afterpain', 'aftertaste', 'air glow', 'balance', 'butt'],
    'afterimage': ['afterbirth', 'afterclap', 'aftercrop', 'aftereffect', 'afterglow', 'aftergrowth', 'aftermath', 'afterpain', 'aftertaste', 'balance', 'butt', 'butt end'],
    'afterlife': ['heaven', 'paradise', 'a better place', 'afterworld', 'beyond', 'destiny', 'eternal home', 'everlastingness', 'fate', 'following', 'future state', 'future time'],
    'aftermath': ['afterbirth', 'afterclap', 'aftercrop', 'aftereffect', 'afterglow', 'aftergrowth', 'afterimage', 'afterpain', 'aftertaste', 'bearing', 'bumper crop', 'by-product'],
    'afterpart': ['afterpiece', 'back', 'back door', 'back seat', 'back side', 'behind', 'breech', 'heel', 'hind end', 'hind part', 'hindhead', 'occiput'],
    'aftertaste': ['afterbirth', 'afterclap', 'aftercrop', 'aftereffect', 'afterglow', 'aftergrowth', 'afterimage', 'aftermath', 'afterpain', 'bitter', 'by-product', 'flavor'],
    'afterthought': ['ps', 'parthian shot', 'about-face', 'addendum', 'afterthoughts', 'appendix', 'back matter', 'better thoughts', 'bind', 'block', 'blockage', 'bureaucratic delay'],
    'afterwards': ['after', 'after a time', 'after a while', 'after all', 'after that', 'afterward', 'anon', 'before long', 'by and by', 'by destiny', 'ex post facto', 'fatally'],
    'afterworld': ['heaven', 'paradise', 'a better place', 'afterlife', 'beyond', 'destiny', 'eternal home', 'fate', 'future state', 'home', 'life after death', 'life to come'],
    'again': ['ab ovo', 'above', 'additionally', 'afresh', 'after all', 'albeit', 'all included', 'all the same', 'also', 'although', 'altogether', 'among other things'],
    'again and again': ['ad infinitum', 'at a stretch', 'ceaselessly', 'commonly', 'connectedly', 'constantly', 'continually', 'continuously', 'cumulatively', 'cyclically', 'day after day', 'day by day'],
    'against': ['about', 'across', 'adverse to', 'as to', 'at cross-purposes with', 'athwart', 'con', 'concerning', 'confronting', 'contra', 'contrary to', 'counter to'],
    'against the grain': ['a rebours', 'a reculons', 'abhorrent', 'against the tide', 'against the wind', 'anticlockwise', 'arear', 'arsy-varsy', 'ass-backwards', 'astern', 'at cross-purposes', 'at daggers'],
    'against the law': ['actionable', 'anarchic', 'anarchistic', 'anomic', 'black-market', 'bootleg', 'chargeable', 'contraband', 'contrary to law', 'criminal', 'felonious', 'flawed'],
    'agape': ['amor', 'bomfog', 'benthamism', 'christian charity', 'christian love', 'eros', 'platonic love', 'accord', 'accordance', 'admiration', 'adoration', 'affection'],
    'age': ['bronze age', 'dark ages', 'depression era', 'golden age', 'ice age', 'iron age', 'jacksonian age', 'middle ages', 'new deal era', 'platonic year', 'prohibition era', 'silver age'],
    'age old': ['aged', 'ageless', 'ancient', 'antediluvian', 'antique', 'auld', 'dateless', 'elderly', 'hoary', 'immemorial', 'of old', 'of yore'],
    'aged': ['abiding', 'advanced', 'advanced in life', 'advanced in years', 'age-long', 'age-old', 'along in years', 'ancient', 'antediluvian', 'antique', 'chronic', 'constant'],
    'agee': ['agee-jawed', 'askance', 'askant', 'askew', 'askewgee', 'asquint', 'awry', 'catawampous', 'catawamptious', 'cockeyed', 'crooked', 'skew'],
    'ageless': ['age-old', 'ancient', 'antique', 'auld', 'ceaseless', 'coeternal', 'constant', 'continual', 'continuous', 'dateless', 'elderly', 'endless'],
    'agency': ['action', 'activity', 'agent', 'agentship', 'antecedent', 'assignment', 'atelier', 'authority', 'authorization', 'barbershop', 'barter', 'bartering'],
    'agenda': ['batting order', 'beadroll', 'bill', 'bill of fare', 'blueprint', 'budget', 'cadastre', 'calendar', 'card', 'carte du jour', 'census', 'census report'],
    'agent': ['charlie mccarthy', 'federal', 'acid', 'acidity', 'acolyte', 'activator', 'actor', 'adjutant', 'administrator', 'advocate', 'agency', 'aid'],
    'agent provocateur': ['agitator', 'agitprop', 'capper', 'catalyst', 'come-on man', 'decoy', 'demagogue', 'exciter', 'firebrand', 'fomenter', 'incendiary', 'inciter'],
    'agglomeration': ['anschluss', 'accretion', 'accumulation', 'acervation', 'addition', 'adherence', 'adhesion', 'affiliation', 'agglomerate', 'agglutination', 'aggregate', 'aggregation'],
    'agglutination': ['accession', 'accretion', 'addition', 'adherence', 'adhesion', 'adjunct', 'adjunction', 'affixation', 'agglomeration', 'aggregation', 'annexation', 'articulation'],
    'aggrandize': ['add to', 'advance', 'amplify', 'apotheose', 'apotheosize', 'augment', 'ballyhoo', 'beatify', 'beef up', 'bloat', 'blow up', 'boost'],
    'aggrandized': ['accelerated', 'amplified', 'apotheosized', 'augmented', 'awesome', 'ballyhooed', 'beatified', 'beefed-up', 'big', 'bloated', 'boosted', 'broadened'],
    'aggravate': ['accelerate', 'agent provocateur', 'aggrandize', 'alienate', 'amplify', 'anger', 'annoy', 'antagonize', 'arouse', 'augment', 'badger', 'bait'],
    'aggravated': ['amplified', 'angry', 'annoyed', 'augmented', 'bothered', 'broken', 'browned-off', 'bugged', 'burned', 'burnt-up', 'burst', 'busted'],
    'aggravating': ['aggravative', 'annoying', 'bothering', 'bothersome', 'contentious', 'disturbing', 'exasperating', 'exasperative', 'galling', 'harassing', 'importunate', 'importune'],
    'aggravation': ['accelerando', 'acceleration', 'adverse circumstances', 'adversity', 'affliction', 'agitation', 'animation', 'annoyance', 'annoyingness', 'arousal', 'arousing', 'bad news'],
    'aggregate': ['a to z', 'a to izzard', 'account', 'accumulate', 'accumulated', 'accumulation', 'acervation', 'add up', 'add up to', 'agglomerate', 'agglomeration', 'aggregate to'],
    'aggregation': ['anschluss', 'accumulation', 'acervation', 'addition', 'affiliation', 'agglomerate', 'agglomeration', 'agglutination', 'aggregate', 'agreement', 'alliance', 'amalgamation'],
    'aggression': ['adventuresomeness', 'adventurousness', 'aggravated assault', 'aggressiveness', 'ambitiousness', 'amphibious attack', 'antagonism', 'armed assault', 'assailing', 'assailment', 'assault', 'attack'],
    'aggressive': ['abrupt', 'active', 'acute', 'adventuresome', 'adventurous', 'ambitious', 'animated', 'antagonistic', 'assertive', 'battling', 'bearish', 'beastly'],
    'aggrieve': ['abuse', 'afflict', 'affront', 'anguish', 'annoy', 'barb the dart', 'befoul', 'bewitch', 'blight', 'break down', 'bring to tears', 'bruise'],
    'aghast': ['afraid', 'agape', 'agog', 'all agog', 'amazed', 'anxious', 'appalled', 'ashen', 'astonished', 'astounded', 'at gaze', 'awed'],
    'agile': ['active', 'acute', 'adroit', 'alacritous', 'alert', 'alive', 'attentive', 'awake', 'breakneck', 'bright', 'brisk', 'catty'],
    'agility': ['acuity', 'acuteness', 'alacrity', 'alertness', 'attention', 'attentiveness', 'brightness', 'briskness', 'dispatch', 'expedition', 'expeditiousness', 'featliness'],
    'agio': ['abatement', 'allowance', 'bank discount', 'breakage', 'cash discount', 'chain discount', 'charge-off', 'concession', 'cut', 'deduction', 'depreciation', 'discount'],
    'agitate': ['actuate', 'afflict', 'air', 'argue', 'arouse', 'assail', 'attack', 'beat', 'beat up', 'blow the coals', 'bother', 'bounce'],
    'agitated': ['abashed', 'afflicted', 'all shook up', 'all-overish', 'anxious', 'anxioused up', 'apprehensive', 'aroused', 'beset', 'bothered', 'bustling', 'cast down'],
    'agitation': ['ado', 'aggravation', 'all-overs', 'angst', 'animation', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat', 'anxiousness'],
    'agitator': ['activist', 'agent provocateur', 'agitprop', 'beater', 'blender', 'brawler', 'catalyst', 'cement mixer', 'churn', 'crucible', 'demagogue', 'eggbeater'],
    'agitprop': ['agent provocateur', 'agitator', 'catalyst', 'demagogue', 'exciter', 'firebrand', 'fomenter', 'incendiary', 'inciter', 'indoctrination', 'inflamer', 'instigator'],
    'aglow': ['ablaze', 'afire', 'aflame', 'aflicker', 'alight', 'ardent', 'bathed with light', 'beaming', 'beamy', 'bespangled', 'blazing', 'blushing'],
    'agnate': ['affiliated', 'affinal', 'affinitive', 'akin', 'alike', 'allied', 'analogous', 'avuncular', 'closely related', 'cognate', 'collateral', 'comparable'],
    'agnostic': ['humean', 'humist', 'pyrrhonic', 'pyrrhonist', 'ambiguous', 'capricious', 'chancy', 'changeable', 'dicey', 'distrustful', 'doubter', 'doubtful'],
    'agnosticism': ['humism', 'pyrrhonism', 'atheism', 'blankmindedness', 'callowness', 'denial', 'disbelief', 'discredit', 'doubt', 'empty-headedness', 'greenhornism', 'greenness'],
    'agnus dei': ['alleluia', 'anamnesis', 'benedicite', 'blessing', 'canon', 'collect', 'communion', 'consecration', 'credo', 'dismissal', 'epistle', 'fraction'],
    'ago': ['antiquated', 'antique', 'back', 'back when', 'backward', 'blown over', 'by', 'bygone', 'bypast', 'dated', 'dead', 'dead and buried'],
    'agog': ['advertent', 'agape', 'aghast', 'alacritous', 'alert', 'all agog', 'all ears', 'all eyes', 'amazed', 'animated', 'anticipant', 'anticipating'],
    'agonize': ['ache', 'afflict', 'agonize over', 'ail', 'anguish', 'battle', 'be at sea', 'be uncertain', 'bear', 'beat about', 'bite', 'blanch'],
    'agonized': ['affected', 'afflicted', 'clawed', 'convulsed', 'crucified', 'devoured by', 'distressed', 'harrowed', 'hurt', 'hurting', 'imbued with', 'impressed'],
    'agonizing': ['acute', 'afflictive', 'atrocious', 'biting', 'consuming', 'cramping', 'cruel', 'desolating', 'distressful', 'distressing', 'excruciating', 'exquisite'],
    'agonizingly': ['abominably', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly', 'damnably', 'deadly', 'deathly'],
    'agony': ['aching heart', 'affliction', 'agonizingness', 'agony of mind', 'anguish', 'atrocious pain', 'bale', 'bitterness', 'bleeding heart', 'broken heart', 'care', 'carking care'],
    'agrarian': ['arcadian', 'agrestic', 'agricultural', 'agronomic', 'arable', 'bucolic', 'country', 'farm', 'farming', 'geoponic', 'lowland', 'native'],
    'agree': ['abide by', 'accede', 'accede to', 'accept', 'acclaim', 'accompany', 'accord', 'acknowledge', 'acquiesce', 'acquiesce in', 'admit', 'agree in opinion'],
    'agree to': ['ok', 'abide by', 'accede', 'accede to', 'accept', 'accept obligation', 'acclaim', 'accord to', 'acquiesce', 'acquiesce in', 'agree', 'agree with'],
    'agree with': ['abide by', 'accede', 'accept', 'acclaim', 'accommodate', 'accommodate with', 'accord', 'acquiesce', 'acquiesce in', 'adapt', 'adapt to', 'adjust'],
    'agreeable': ['junoesque', 'ok', 'abject', 'acceptable', 'accepting', 'accommodating', 'accommodative', 'accordant', 'achingly sweet', 'acquiescent', 'admissible', 'adorable'],
    'agreed': ['ok', 'acquiescent', 'acquiescing', 'agreeing', 'all right', 'amen', 'arranged', 'assentatious', 'assenting', 'aye', 'be it so', 'compacted'],
    'agreeing': ['accompanying', 'accordant', 'acquiescent', 'acquiescing', 'affirmative', 'agreeable', 'agreed', 'akin', 'amicable', 'answerable', 'approving', 'assentatious'],
    'agreement': ['anschluss', 'ok', 'acceptance', 'accession', 'acclamation', 'accommodation', 'accompaniment', 'accord', 'accordance', 'acquiescence', 'adaptation', 'adaption'],
    'agriculture': ['ceres', 'cora', 'demeter', 'dionysos', 'dionysus', 'flora', 'frey', 'gaea', 'gaia', 'kore', 'persephassa', 'persephone'],
    'agriculturist': ['bauer', 'agriculturalist', 'agrologist', 'agronomist', 'coffee-planter', 'collective farm worker', 'crofter', 'cropper', 'cultivator', 'dirt farmer', 'dry farmer', 'farm laborer'],
    'agronomics': ['agrarianism', 'agricultural geology', 'agriculture', 'agrology', 'agronomy', 'contour farming', 'cultivation', 'culture', 'dirt farming', 'dry farming', 'dryland farming', 'farm economy'],
    'agronomist': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'coffee-planter', 'collective farm worker', 'crofter', 'cropper', 'cultivator', 'dirt farmer', 'dry farmer', 'farm laborer'],
    'aground': ['anchored', 'beached', 'castaway', 'caught', 'chained', 'fast', 'fastened', 'fixed', 'foundered', 'grounded', 'hard and fast', 'held'],
    'ague': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'abscess', 'acute articular rheumatism', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anemia', 'ankylosis'],
    'ahead': ['a cut above', 'above', 'ahead of time', 'alee', 'along', 'ante', 'ascendant', 'before', 'beforehand', 'beforetime', 'betimes', 'better'],
    'aid': ['samaritan', 'a leg up', 'abet', 'acolyte', 'adjutant', 'agent', 'aide', 'aide-de-camp', 'aider', 'alimony', 'alleviate', 'alleviation'],
    'aid and abet': ['abet', 'advocate', 'ask for', 'comfort', 'countenance', 'embolden', 'encourage', 'endorse', 'favor', 'feed', 'foster', 'give encouragement'],
    'aide': ['adc', 'co', 'od', 'acolyte', 'adjutant', 'agent', 'aid', 'aide-de-camp', 'aider', 'ally', 'assistant', 'attendant'],
    'ail': ['ache', 'afflict', 'agonize', 'anguish', 'be affected with', 'be the matter', 'beset', 'bite', 'blanch', 'blench', 'bother', 'burn'],
    'ailment': ['abnormality', 'acute disease', 'affection', 'affliction', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'cardiovascular disease', 'chronic disease'],
    'aim': ['address', 'affectation', 'aim at', 'ambition', 'angle', 'animus', 'aspiration', 'aspire', 'aspire after', 'aspire to', 'atmosphere', 'attempt'],
    'aim at': ['aim', 'aspire after', 'aspire to', 'barrage', 'be after', 'be desirous of', 'bend', 'blast', 'blitz', 'bombard', 'cannon', 'cannonade'],
    'aimless': ['amorphous', 'by the way', 'capricious', 'casual', 'causeless', 'chance', 'designless', 'desultory', 'deviative', 'digressive', 'disarticulated', 'discontinuous'],
    'aimlessly': ['anarchically', 'at haphazard', 'at hazard', 'at random', 'bootlessly', 'casually', 'chaotically', 'confusedly', 'dispersedly', 'dysteleologically', 'fecklessly', 'fruitlessly'],
    'air': ['cat', 'caelus', 'action', 'actions', 'activity', 'acts', 'address', 'advertise', 'aerate', 'aerodynamics', 'aerospace', 'aerosphere'],
    'air built': ['aerial', 'airy', 'chimeric', 'chimerical', 'cloud-born', 'cloud-built', 'cloud-woven', 'dreamlike', 'ethereal', 'fanciful', 'fatuitous', 'fatuous'],
    'air condition': ['aerate', 'air', 'air out', 'air-cool', 'airify', 'chill', 'cool', 'cross-ventilate', 'fan', 'freshen', 'ice', 'ice-cool'],
    'air conditioning': ['adiabatic absorption', 'adiabatic demagnetization', 'adiabatic expansion', 'aerage', 'aeration', 'air cooling', 'airing', 'blast freezing', 'chilling', 'congealment', 'congelation', 'cooling'],
    'air corps': ['adjutant general corps', 'air arm', 'air force', 'air service', 'armored corps', 'army corps', 'army nurse corps', 'bugle corps', 'chemical corps', 'corps', 'corps of cadets', 'corps of signals'],
    'air current': ['crosscurrent', 'current', 'current of air', 'downdraft', 'draft', 'fall wind', 'flow of air', 'following wind', 'head wind', 'indraft', 'inflow', 'inhalation'],
    'air express': ['airfreight', 'airlift', 'asportation', 'bearing', 'carriage', 'carry', 'carrying', 'cartage', 'conveyance', 'drayage', 'expressage', 'ferriage'],
    'air force': ['anac', 'arf', 'atc', 'ats', 'air command', 'air transport command', 'air transport service', 'airborne reconnaissance force', 'army-navy air corps', 'bomber command', 'casu', 'coastal command'],
    'air hole': ['cat', 'aerospace', 'aerosphere', 'air duct', 'air passage', 'air pocket', 'air shaft', 'air tube', 'airspace', 'airway', 'armhole', 'blowhole'],
    'air lane': ['air line', 'air route', 'airway', 'beat', 'circuit', 'corridor', 'course', 'flight path', 'itinerary', 'lane', 'line', 'orbit'],
    'air lock': ['aboideau', 'access', 'adit', 'approach', 'corridor', 'dock gate', 'entrance', 'entranceway', 'entry', 'entryway', 'flood-hatch', 'floodgate'],
    'air mass': ['anticyclone', 'cold front', 'cold sector', 'cyclone', 'front', 'high', 'high-pressure area', 'isobar', 'isometric', 'isometric line', 'isopiestic line', 'isotherm'],
    'air pocket': ['cat', 'aerospace', 'aerosphere', 'air hole', 'airspace', 'bump', 'ceiling', 'crosswind', 'empty space', 'favorable wind', 'fog', 'front'],
    'air pollution': ['air', 'attritus', 'badness', 'bran', 'contamination', 'cosmic dust', 'crumb', 'crumble', 'dust', 'dust ball', 'efflorescence', 'fallout'],
    'air raid': ['air attack', 'air cover', 'air strike', 'air support', 'blitz', 'blitzkrieg', 'boarding', 'bombardment', 'bombing', 'cannonade', 'cover', 'dry run'],
    'air shaft': ['air duct', 'air hole', 'air passage', 'air tube', 'airway', 'blowhole', 'breathing hole', 'louver', 'louverwork', 'naris', 'nostril', 'shaft'],
    'air space': ['cat', 'lebensraum', 'aerospace', 'aerosphere', 'air hole', 'air pocket', 'area', 'back country', 'belt', 'bump', 'ceiling', 'clear space'],
    'air speed': ['celerity', 'dispatch', 'expedition', 'fastness', 'flight', 'flit', 'flurry', 'ground speed', 'haste', 'hurry', 'instantaneousness', 'knots'],
    'airburst': ['altitude peak', 'automatic control', 'blast-off', 'burn', 'burnout', 'ceiling', 'descent', 'end of burning', 'flight', 'ignition', 'impact', 'launch'],
    'airfreight': ['air express', 'air transport', 'air travel', 'air-express', 'airlift', 'airmail', 'asportation', 'bearing', 'carriage', 'carry', 'carrying', 'cartage'],
    'airiness': ['prospero', 'airy nothing', 'airy texture', 'appearance', 'ascent', 'attenuation', 'bodilessness', 'bounce', 'breeziness', 'bubbliness', 'buoyancy', 'carefreeness'],
    'airing': ['sunday drive', 'aerage', 'aeration', 'air conditioning', 'air cooling', 'amble', 'analysis', 'bandying', 'book', 'broadcast', 'broadcasting', 'bruiting'],
    'airlift': ['aeroplane', 'air express', 'airfreight', 'airplane', 'asportation', 'balloon', 'be airborne', 'bearing', 'carriage', 'carry', 'carrying', 'cartage'],
    'airline': ['aeronautics', 'air lane', 'air route', 'air service', 'airway', 'astronautics', 'aviation', 'axis', 'ballooning', 'beeline', 'blind flying', 'chord'],
    'airmail': ['pp', 'rd', 'rfd', 'air-express', 'airfreight', 'book post', 'consign', 'correspondence', 'direct mail', 'direct-mail selling', 'dispatch', 'drop a letter'],
    'airman': ['aeronaut', 'aeroplaner', 'aeroplanist', 'air pilot', 'airplanist', 'astronaut', 'aviator', 'barnstormer', 'birdman', 'captain', 'cloud seeder', 'commercial pilot'],
    'airmanship': ['ability', 'address', 'adeptness', 'adroitness', 'artfulness', 'artisanship', 'artistry', 'bravura', 'brief', 'briefing', 'brilliance', 'capability'],
    'airplane': ['cub', 'vtol', 'adjustable propeller', 'aeroplane', 'afterburner', 'aileron', 'air ambulance', 'air controls', 'air scoop', 'air scout', 'aircraft', 'airfreighter'],
    'airs': ['affectation', 'affectedness', 'airs and graces', 'arrogance', 'artificiality', 'clannishness', 'cliquishness', 'contempt', 'contemptuousness', 'contumely', 'despite', 'disdain'],
    'airship': ['graf zeppelin', 'aerostat', 'ballonet', 'balloon', 'basket', 'blimp', 'car', 'catwalk', 'dirigible', 'dirigible balloon', 'envelope', 'gas chamber'],
    'airsick': ['aerial', 'aerophysical', 'aerospace', 'aerotechnical', 'air-conscious', 'air-minded', 'air-wise', 'airworthy', 'aviational', 'barfy', 'carsick', 'nauseated'],
    'airtight': ['ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'close', 'compact', 'corrosionproof', 'dampproof', 'dustproof', 'dusttight', 'fast', 'fire-resisting'],
    'airway': ['air duct', 'air hole', 'air lane', 'air line', 'air passage', 'air route', 'air shaft', 'air tube', 'blowhole', 'breathing hole', 'corridor', 'lane'],
    'airy': ['barmecidal', 'barmecide', 'olympian', 'adulterated', 'aeolian', 'aerial', 'aeriform', 'aerodynamic', 'aerostatic', 'aery', 'air-built', 'airish'],
    'aisle': ['access', 'alley', 'ambulatory', 'aperture', 'arcade', 'artery', 'avenue', 'channel', 'cloister', 'colonnade', 'communication', 'conduit'],
    'ajar': ['agape', 'clashing', 'conflicting', 'confused', 'dehiscent', 'gaping', 'grating', 'harsh', 'jangling', 'jangly', 'jarring', 'jostling'],
    'akimbo': ['v-shaped', 'y-shaped', 'angular', 'bent', 'cornered', 'crooked', 'crotched', 'forked', 'furcal', 'furcate', 'geniculate', 'geniculated'],
    'akin': ['accordant', 'according', 'affiliated', 'affinal', 'affinitive', 'agnate', 'agreeable', 'agreeing', 'alike', 'allied', 'amicable', 'analogous'],
    'alabaster': ['amphibole', 'antimony', 'apatite', 'aplite', 'arsenic', 'asbestos', 'asphalt', 'azurite', 'bauxite', 'billiard table', 'bitumen', 'boron'],
    'alacrity': ['abruptness', 'acquiescence', 'agility', 'agreeability', 'agreeableness', 'amenability', 'animation', 'anxiety', 'anxiousness', 'appetite', 'ardor', 'avidity'],
    'alarm': ['angelus', 'angelus bell', 'roman candle', 'abject fear', 'admonishment', 'admonition', 'affright', 'aid to navigation', 'alarum', 'alert', 'amaze', 'amber light'],
    'alarming': ['awing', 'bad', 'chilling', 'critical', 'dangerous', 'dangersome', 'daunting', 'deterrent', 'deterring', 'disconcerting', 'discouraging', 'disheartening'],
    'albeit': ['after all', 'again', 'all the same', 'although', 'at all events', 'at any rate', 'but', 'even', 'even so', 'for all that', 'howbeit', 'however'],
    'albinism': ['christmas disease', 'hartnup disease', 'werdnig-hoffmann disease', 'achroma', 'achromasia', 'achromatic vision', 'achromatosis', 'albescence', 'albino', 'albinoism', 'astigmatism', 'astigmia'],
    'albino': ['achroma', 'achromasia', 'achromatosis', 'albescence', 'albinal', 'albinic', 'albinism', 'albinistic', 'albinoism', 'blondness', 'canescence', 'chalkiness'],
    'album': ['domesday book', 'festschrift', 'account book', 'address book', 'adversaria', 'ana', 'analects', 'annual', 'anthology', 'appointment calendar', 'appointment schedule', 'beauties'],
    'albumen': ['batter', 'bonnyclabber', 'butter', 'caviar', 'clabber', 'cornstarch', 'cream', 'curd', 'dough', 'egg', 'egg white', 'eggshell'],
    'alchemy': ['about-face', 'assimilation', 'assumption', 'becoming', 'bewitchery', 'change', 'change-over', 'charm', 'conversion', 'divination', 'enchantment', 'fetishism'],
    'alcohol': ['amytal', 'amytal pill', 'argyrol', 'chile saltpeter', 'demerol', 'dial', 'dolophine', 'john barleycorn', 'luminal', 'luminal pill', 'mercurochrome', 'merthiolate'],
    'alcoholic': ['lsd user', 'acidhead', 'addict', 'alcoholic addict', 'alternating personality', 'antisocial personality', 'ardent', 'bacchanal', 'bacchanalian', 'barfly', 'bibber', 'big drunk'],
    'alcoholism': ['a habit', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'addiction', 'alcoholic addiction', 'alcoholic psychosis', 'barbiturate addiction', 'barbiturism', 'bottle nose', 'chain smoking', 'chronic alcoholism'],
    'alcove': ['arbor', 'bay', 'belvedere', 'bower', 'carrel', 'conservatory', 'corner', 'cove', 'cranny', 'cubby', 'cubbyhole', 'cubicle'],
    'alderman': ['mp', 'member of congress', 'member of parliament', 'archon', 'assemblyman', 'bailie', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor', 'chosen freeholder'],
    'aleatory': ['nachtmusik', 'absolute music', 'accidental', 'adaptation', 'adventitious', 'adventurous', 'air varie', 'aleatoric', 'aleatory music', 'amorphous', 'arrangement', 'blobby'],
    'alehouse': ['bar', 'barrel house', 'barroom', 'beer garden', 'beer hall', 'beer parlor', 'bistro', 'blind tiger', 'brasserie', 'cabaret', 'cafe', 'cocktail lounge'],
    'alert': ['klaxon', 'mayday', 'sos', 'active', 'admonish', 'advertent', 'advise', 'agile', 'agog', 'air-raid alarm', 'alarm', 'alarm bell'],
    'alfresco': ['abroad', 'aerial', 'aeriform', 'aery', 'airish', 'airlike', 'airy', 'atmospheric', 'breezy', 'en plein air', 'ethereal', 'exposed'],
    'algae': ['ectocarpales', 'iceland moss', 'irish moss', 'phaeophyceae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper'],
    'algid': ['siberian', 'aguey', 'aguish', 'arctic', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'blue with cold', 'boreal', 'brisk'],
    'algorithm': ['arabic numerals', 'mo', 'roman numerals', 'algorism', 'applied mathematics', 'approach', 'attack', 'binary system', 'course', 'decimal system', 'duodecimal system', 'fashion'],
    'alias': ['jane doe', 'john doe', 'richard roe', 'anonym', 'assumed name', 'contrarily', 'else', 'elsewise', 'false name', 'fictitious name', 'in other respects', 'in other ways'],
    'alibi': ['alibi out of', 'apologize for', 'apology', 'blind', 'cloak', 'color', 'cop-out', 'cover', 'cover story', 'cover with excuses', 'cover-up', 'device'],
    'alien': ['jim crow', 'martian', 'uitlander', 'abalienate', 'adversary', 'adversative', 'adverse', 'alienate', 'alter', 'antagonistic', 'anti', 'antipathetic'],
    'alienate': ['abalienate', 'abrupt', 'alter', 'amortize', 'antagonize', 'assign', 'barter', 'bequeath', 'brainwash', 'cast off', 'cast out', 'cede'],
    'alienated': ['alone', 'aloof', 'antiestablishment', 'apart', 'at odds with', 'at variance with', 'breakaway', 'companionless', 'counter-culture', 'detached', 'differing', 'disaffected'],
    'alienation': ['abalienation', 'aberration', 'abnormality', 'abstraction', 'abulia', 'agreement to disagree', 'aloneness', 'aloofness', 'amortization', 'amortizement', 'anxiety', 'anxiety equivalent'],
    'alienist': ['adler', 'freud', 'horney', 'pavlov', 'reich', 'skinner', 'watson', 'alienism', 'clinical psychologist', 'industrial psychologist', 'neuropsychiatrist', 'psychiatrist'],
    'alight': ['ablaze', 'afire', 'aflame', 'aflicker', 'aglow', 'ardent', 'bathed with light', 'bespangled', 'blazing', 'bright', 'brightened', 'burning'],
    'alight upon': ['blunder upon', 'bump into', 'chance upon', 'come across', 'come among', 'come down on', 'come on', 'come up against', 'come upon', 'confront', 'descend upon', 'discover serendipitously'],
    'align': ['act with', 'adjust', 'align with', 'allocate', 'allot', 'apportion', 'array', 'bank', 'collimate', 'collineate', 'collocate', 'compose'],
    'alignment': ['accommodation', 'adaptation', 'adjustment', 'affiliation', 'alliance', 'amalgamation', 'analogy', 'association', 'bearings', 'cahoots', 'coadunation', 'coalescence'],
    'alike': ['accordant', 'akin', 'all one', 'all the same', 'analogous', 'aped', 'as is', 'at par', 'au pair', 'automatic', 'balanced', 'coequally'],
    'alimentation': ['aliment', 'alimony', 'bread', 'bread and butter', 'food chain', 'keep', 'livelihood', 'maintenance', 'nourishment', 'nurture', 'nutriment', 'nutrition'],
    'alimony': ['aid', 'alimentation', 'allotment', 'allowance', 'annuity', 'assistance', 'bounty', 'bread', 'bread and butter', 'depletion allowance', 'dole', 'fellowship'],
    'aliquot': ['algorismic', 'algorithmic', 'cardinal', 'decimal', 'differential', 'digital', 'even', 'exponential', 'figural', 'figurate', 'figurative', 'finite'],
    'alive': ['abounding', 'aboveground', 'active', 'activist', 'activistic', 'agile', 'alert', 'alive and kicking', 'alive to', 'alive with', 'among the living', 'animate'],
    'alive and kicking': ['aboveground', 'alive', 'among the living', 'animate', 'animated', 'breathing', 'bright-eyed and bushy-tailed', 'capable of life', 'chipper', 'conscious', 'endowed with life', 'enjoying health'],
    'alive to': ['appreciative of', 'apprised of', 'awake to', 'aware', 'aware of', 'behind the curtain', 'behind the scenes', 'cognizant', 'cognizant of', 'conscious', 'conscious of', 'hep to'],
    'alkali': ['acid', 'acidity', 'agent', 'alkalinity', 'alloisomer', 'anion', 'antacid', 'atom', 'base', 'biochemical', 'cation', 'chemical'],
    'alkalize': ['acetify', 'acidify', 'acidulate', 'alkalify', 'borate', 'carbonate', 'catalyze', 'chemical', 'chlorinate', 'electrolyze', 'ferment', 'homopolymerize'],
    'all': ['a to z', 'a to izzard', 'copernican universe', 'einsteinian universe', 'newtonian universe', 'ptolemaic universe', 'acme', 'across the board', 'aggregate', 'all and some', 'all and sundry', 'all being'],
    'all around': ['accessible', 'adaptable', 'adjustable', 'all-inclusive', 'ambidextrous', 'amphibious', 'at hand', 'available', 'broad', 'complete', 'comprehensive', 'consummate'],
    'all at once': ['abruptly', 'all together', 'at a blow', 'at a stroke', 'at once', 'at one blow', 'at one jump', 'at one stroke', 'at one swoop', 'at one time', 'bang', 'collectively'],
    'all clear': ['klaxon', 'mayday', 'sos', 'above water', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert', 'all straight'],
    'all comprehensive': ['across-the-board', 'all-comprehending', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'allover', 'blanket', 'boundless'],
    'all creation': ['copernican universe', 'einsteinian universe', 'newtonian universe', 'ptolemaic universe', 'all', 'all being', 'allness', 'cosmos', 'created nature', 'created universe', 'creation', 'everything that is'],
    'all ears': ['argus-eyed', 'advertent', 'agog', 'alert', 'all eyes', 'assiduous', 'attentive', 'aux aguets', 'aware', 'careful', 'concentrated', 'conscious'],
    'all embracing': ['absolute', 'aggregate', 'all', 'all-comprehending', 'all-comprehensive', 'all-covering', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-out', 'all-pervading'],
    'all in': ['beat', 'beat up', 'beaten', 'bleary', 'bone-weary', 'bushed', 'dead', 'dead-and-alive', 'dead-tired', 'deadbeat', 'depleted', 'dog-tired'],
    'all in all': ['all things considered', 'almost entirely', 'altogether', 'approximately', 'as a rule', 'as a whole', 'as an approximation', 'at large', 'broadly', 'broadly speaking', 'by and large', 'chiefly'],
    'all inclusive': ['across-the-board', 'aggregate', 'all', 'all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-pervading', 'allover'],
    'all out': ['a outrance', 'a toute outrance', 'absolute', 'absolutely', 'actively', 'admitting no exception', 'all hollow', 'all the way', 'all-embracing', 'all-encompassing', 'all-pervading', 'allegretto'],
    'all over': ['ad infinitum', 'all over hell', 'all round', 'all through', 'always', 'and everywhere', 'at about', 'at all points', 'at full length', 'cosmically', 'every bit', 'every inch'],
    'all overs': ['agitation', 'angst', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat', 'anxiousness', 'apprehension', 'apprehensiveness', 'cankerworm of care'],
    'all pervading': ['absolute', 'all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-out', 'allover', 'born'],
    'all powerful': ['absolute', 'all-knowing', 'all-seeing', 'all-wise', 'almighty', 'boundless', 'changeless', 'creating', 'creative', 'eternal', 'eternally the same', 'everlasting'],
    'all right': ['ok', 'roger', 'absolute', 'absolutely', 'acceptable', 'accurate', 'adequate', 'admissible', 'agreeable', 'agreed', 'alright', 'alrighty'],
    'all round': ['all about', 'all over', 'all over hell', 'and everywhere', 'around', 'every which way', 'everywhence', 'everywhere', 'everywheres', 'everywhither', 'far and near', 'far and wide'],
    'all seeing': ['all-knowing', 'all-powerful', 'all-wise', 'almighty', 'boundless', 'changeless', 'creating', 'creative', 'eternal', 'eternally the same', 'everlasting', 'glorious'],
    'all set': ['all ready', 'armed', 'armed and ready', 'booted and spurred', 'briefed', 'coached', 'cocked', 'equipped', 'familiarized', 'good and ready', 'groomed', 'in arms'],
    'all the way': ['a outrance', 'a toute outrance', 'all hollow', 'all out', 'as far as', 'flat out', 'the last extremity', 'to', 'to a fare-you-well', 'to a finish', 'to the backbone', 'to the end'],
    'all things considered': ['after all', 'all in all', 'altogether', 'as a rule', 'as a whole', 'as an approximation', 'at large', 'before the bench', 'before the court', 'broadly', 'broadly speaking', 'by and large'],
    'all thumbs': ['awkward', 'blunderheaded', 'blundering', 'boorish', 'bumbling', 'bungling', 'butterfingered', 'careless', 'clownish', 'clumsy', 'clumsy-fisted', 'cumbersome'],
    'all together': ['all agreeing', 'all at once', 'as one', 'as one man', 'at a blow', 'at a clip', 'at a stroke', 'at once', 'at one blow', 'at one jump', 'at one stroke', 'at one swoop'],
    'allay': ['abate', 'alleviate', 'anesthetize', 'appease', 'assuage', 'attemper', 'balm', 'bank the fire', 'benumb', 'blunt', 'calm', 'chasten'],
    'allegation': ['parthian shot', 'accusal', 'accusation', 'accusing', 'address', 'admission', 'affidavit', 'affirmance', 'affirmation', 'allegement', 'announcement', 'annunciation'],
    'allege': ['accuse', 'acknowledge', 'adduce', 'advance', 'affirm', 'announce', 'annunciate', 'argue', 'arraign', 'array', 'article', 'assert'],
    'alleged': ['accountable', 'accounted as', 'affirmed', 'announced', 'ascribable', 'asserted', 'asseverated', 'assignable', 'assumed', 'assumptive', 'attested', 'attributable'],
    'allegiance': ['acquiescence', 'adherence', 'adhesion', 'assigned task', 'attachment', 'bona fides', 'bond', 'bonne foi', 'bounden duty', 'burden', 'business', 'call of duty'],
    'allegorical': ['allegoric', 'anagogic', 'associational', 'connotational', 'connotative', 'definable', 'denotational', 'denotative', 'expressive', 'extended', 'extensional', 'fabulous'],
    'allegorize': ['account for', 'allude to', 'assume', 'bring to mind', 'clarify', 'clear up', 'connote', 'crack', 'decipher', 'demonstrate', 'demythologize', 'elucidate'],
    'allegory': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allusion', 'analogy', 'apologue', 'arcane meaning', 'assumption', 'balancing', 'bedtime story'],
    'allegro': ['accelerando', 'actively', 'adagietto', 'adagio', 'affrettando', 'all out', 'allegretto', 'andante', 'andantino', 'animatedly', 'breezily', 'briskly'],
    'alleluia': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'nunc dimittis', 'te deum', 'trisagion', 'vedic hymn'],
    'allergen': ['rh factor', 'agglutinin', 'allergic disorder', 'allergy', 'anaphylactin', 'antiantibody', 'antibody', 'antigen', 'antiserum', 'antitoxic serum', 'antitoxin', 'antivenin'],
    'allergic': ['anaphylactic', 'anemic', 'apoplectic', 'arthritic', 'averse', 'bilious', 'cancerous', 'chlorotic', 'colicky', 'consumptive', 'delicate', 'disaffected'],
    'allergy': ['abhorrence', 'abnormality', 'abomination', 'acute disease', 'affection', 'affliction', 'ailment', 'allergen', 'allergic disease', 'allergic disorder', 'anaphylaxis', 'antagonism'],
    'alleviate': ['abate', 'allay', 'anesthetize', 'appease', 'assuage', 'attemper', 'attenuate', 'bank the fire', 'bate', 'be light', 'benumb', 'blunt'],
    'alleviation': ['abatement', 'abridgment', 'allayment', 'analgesia', 'anesthesia', 'anesthetizing', 'appeasement', 'assuagement', 'attenuation', 'blunting', 'calming', 'contraction'],
    'alleviative': ['alleviating', 'alleviator', 'analgesic', 'anesthetic', 'anodyne', 'assuager', 'assuasive', 'balm', 'balmy', 'balsamic', 'benumbing', 'calmant'],
    'alley': ['autobahn', 'us highway', 'access', 'aisle', 'alleyway', 'ambulatory', 'aperture', 'arcade', 'arterial', 'arterial highway', 'arterial street', 'artery'],
    'alliance': ['anschluss', 'bund', 'nato', 'rochdale cooperative', 'seato', 'a world-without-end bargain', 'accompaniment', 'accord', 'accordance', 'addition', 'adjunct', 'affairs'],
    'allied': ['affiliate', 'affiliated', 'affinitive', 'agnate', 'akin', 'assembled', 'associate', 'associated', 'avuncular', 'banded together', 'bound', 'bracketed'],
    'alliteration': ['assonance', 'blank verse', 'chime', 'clink', 'consonance', 'crambo', 'dingdong', 'double rhyme', 'drone', 'eye rhyme', 'harping', 'humdrum'],
    'alliterative': ['alliteral', 'alliterating', 'assonant', 'assonantal', 'belabored', 'chanting', 'chiming', 'cliche-ridden', 'dingdong', 'harping', 'humdrum', 'jingle-jangle'],
    'allocate': ['align', 'allot', 'allow', 'appoint', 'apportion', 'appropriate to', 'array', 'assign', 'assign to', 'collocate', 'compose', 'deal'],
    'allocation': ['allotment', 'appointment', 'apportionment', 'appropriation', 'arrangement', 'array', 'arraying', 'assignment', 'attribution', 'collation', 'collocation', 'constitution'],
    'allocution': ['address', 'after-dinner speech', 'chalk talk', 'debate', 'declamation', 'diatribe', 'eulogy', 'exhortation', 'filibuster', 'forensic', 'forensic address', 'formal speech'],
    'allot': ['accord', 'administer', 'afford', 'align', 'allocate', 'allow', 'appoint', 'apportion', 'appropriate to', 'array', 'assign', 'assign to'],
    'allotheism': ['acosmism', 'animatism', 'animism', 'anthropolatry', 'anthropomorphism', 'anthropotheism', 'autotheism', 'cosmotheism', 'deism', 'ditheism', 'dualism', 'dyotheism'],
    'allotment': ['c ration', 'k ration', 'aid', 'alimony', 'allocation', 'allowance', 'annuity', 'appointment', 'apportionment', 'appropriation', 'arrangement', 'array'],
    'allotropy': ['proteus', 'allotropism', 'diversification', 'diversity', 'her infinite variety', 'heterogeneity', 'heteromorphism', 'manifoldness', 'multifariousness', 'multiplicity', 'nonuniformity', 'omnifariousness'],
    'allover': ['all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'catholic', 'cosmopolitan', 'country-wide'],
    'allow': ['ok', 'abate', 'accede', 'accept', 'accord', 'account', 'acknowledge', 'acquiesce', 'add', 'adjudge', 'adjudicate', 'administer'],
    'allow for': ['admit', 'admit exceptions', 'allow', 'bear with', 'blink at', 'color', 'concede', 'condone', 'connive at', 'consider', 'consider the circumstances', 'consider the source'],
    'allowance': ['c ration', 'k ration', 'ok', 'abatement', 'acceptance', 'account', 'acknowledgment', 'adjustment', 'admission', 'agio', 'aid', 'alimony'],
    'allowed': ['god-given', 'accepted', 'accorded', 'acknowledged', 'admitted', 'affirmed', 'approved', 'authenticated', 'avowed', 'bestowed', 'certified', 'conceded'],
    'alloy': ['carboloy', 'duralumin', 'duriron', 'german silver', 'monel metal', 'muntz metal', 'stellite', 'swedish steel', 'admix', 'admixture', 'adulterate', 'aggregate'],
    'allude to': ['address to', 'adumbrate', 'advert to', 'allegorize', 'assume', 'be taken as', 'blurt', 'blurt out', 'bring to attention', 'bring to mind', 'bring to notice', 'call attention to'],
    'allure': ['appeal', 'bait', 'bewitch', 'captivate', 'charisma', 'charm', 'decoy', 'delude', 'draw', 'enchant', 'entice', 'entrap'],
    'allurement': ['adduction', 'adorability', 'affinity', 'agreeability', 'amiability', 'appeal', 'attractance', 'attraction', 'attractiveness', 'attractivity', 'bait', 'blandishment'],
    'alluring': ['adductive', 'appealing', 'appetizing', 'attracting', 'attractive', 'attrahent', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching'],
    'allusion': ['allegory', 'arcane meaning', 'assumption', 'coloration', 'connotation', 'hint', 'implication', 'implied meaning', 'import', 'inference', 'innuendo', 'intimation'],
    'allusive': ['allusory', 'figurative', 'figured', 'flowery', 'implicational', 'implicative', 'implicatory', 'indicative', 'inferential', 'insinuating', 'insinuative', 'insinuatory'],
    'alluvium': ['acres', 'alluvion', 'arable land', 'ash', 'cataclysm', 'cinder', 'clay', 'clinker', 'clod', 'crust', 'debris', 'deluge'],
    'ally': ['accessory', 'accomplice', 'act in concert', 'act together', 'adjunct', 'affiliate', 'alter ego', 'amalgamate', 'analogon', 'analogue', 'apply', 'archduchy'],
    'alma mater': ['academe', 'academia', 'college', 'college of engineering', 'community college', 'degree-granting institution', 'four-year college', 'graduate school', 'institute of technology', 'ivied halls', 'journalism school', 'junior college'],
    'almighty': ['absolute', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'awfully', 'boundless', 'changeless', 'creating', 'creative', 'eternal', 'eternally the same'],
    'almond': ['brazil nut', 'almond paste', 'amande', 'amande douce', 'amandes mondees', 'bitter almond', 'blanched almonds', 'burnt almond', 'goober', 'goober pea', 'ground-pea', 'groundnut'],
    'almost': ['about', 'all but', 'approximately', 'as good as', 'as much as', 'barely', 'bordering on', 'close', 'closely', 'essentially', 'hardly', 'in effect'],
    'almsgiver': ['maecenas', 'robin hood', 'santa claus', 'almoner', 'angel', 'assignor', 'awarder', 'backer', 'benevolist', 'bestower', 'cheerful giver', 'conferrer'],
    'almsman': ['allottee', 'almswoman', 'annuitant', 'assign', 'assignee', 'bankrupt', 'beggar', 'beneficiary', 'casual', 'charity case', 'devisee', 'donee'],
    'aloft': ['aboard', 'above', 'abovestairs', 'afloat', 'airward', 'all aboard', 'aloof', 'athwart the hawse', 'athwarthawse', 'aye', 'before the mast', 'high'],
    'alone': ['abandoned', 'absolute', 'alienated', 'all alone', 'aloof', 'apart', 'azygous', 'barely', 'but', 'by itself', 'celibate', 'companionless'],
    'along': ['abeam', 'abreast', 'additionally', 'ahead', 'along by', 'alongside', 'as well', 'at length', 'beside', 'by', 'en route to', 'endlong'],
    'along with': ['added to', 'as well as', 'attended by', 'coupled with', 'in addition to', 'in association with', 'in company with', 'in conjunction with', 'including', 'inclusive of', 'let alone', 'linked to'],
    'aloof': ['laodicean', 'olympian', 'above', 'above all that', 'abovestairs', 'airward', 'alienated', 'aloft', 'alone', 'antisocial', 'apart', 'apathetic'],
    'alpha': ['beginning', 'blast-off', 'breaking-in', 'commencement', 'creation', 'cutting edge', 'dawn', 'dawning', 'edge', 'establishment', 'first', 'first blush'],
    'alpha particle': ['kern', 'nmr', 'antibaryon', 'antilepton', 'antimeson', 'atomic nucleus', 'atomic particle', 'aurora particle', 'baryon', 'beta particle', 'electron', 'elementary particle'],
    'alphabet': ['ipa', 'ita', 'initial teaching alphabet', 'alphabetics', 'art', 'basics', 'beginning', 'blueprint', 'charactering', 'characterization', 'chart', 'choreography'],
    'alphabetarian': ['abecedarian', 'apprentice', 'articled clerk', 'beginner', 'boot', 'catechumen', 'debutant', 'entrant', 'fledgling', 'freshman', 'greenhorn', 'ignoramus'],
    'alphabetic': ['abecedarian', 'allographic', 'capital', 'graphemic', 'ideographic', 'lettered', 'lexigraphic', 'literal', 'logogrammatic', 'logographic', 'lower-case', 'majuscule'],
    'alphabetical': ['abecedarian', 'allographic', 'alphabetic', 'capital', 'graphemic', 'ideographic', 'lettered', 'lexigraphic', 'literal', 'logogrammatic', 'logographic', 'lower-case'],
    'alphabetize': ['alphabet', 'analyze', 'arrange', 'assort', 'break down', 'capitalize', 'catalog', 'categorize', 'character', 'class', 'classify', 'codify'],
    'already': ['as yet', 'before', 'before all', 'by this time', 'earlier', 'early', 'ere', 'ere then', 'erenow', 'erstwhile', 'even', 'formerly'],
    'alright': ['ok', 'roger', 'absolute', 'absolutely', 'acceptable', 'accurate', 'adequate', 'admissible', 'agreeable', 'all right', 'alrighty', 'amen'],
    'also': ['above', 'additionally', 'again', 'all included', 'along', 'altogether', 'among other things', 'and', 'and all', 'and also', 'and so', 'as well'],
    'also ran': ['aspirant', 'baby kisser', 'bankrupt', 'booby', 'candidate', 'dark horse', 'defeated candidate', 'defeatee', 'duck', 'dud', 'failure', 'fall guy'],
    'altar': ['communion table', 'altar carpet', 'altar desk', 'altar facing', 'altar of prothesis', 'altar rail', 'altar side', 'altar slab', 'altar stair', 'altar stone', 'altarpiece', 'ancona'],
    'altarpiece': ['communion table', 'abstract', 'abstraction', 'altar', 'altar carpet', 'altar desk', 'altar facing', 'altar of prothesis', 'altar rail', 'altar side', 'altar slab', 'altar stair'],
    'alter': ['abate', 'accommodate', 'adapt', 'adjust', 'adjust to', 'alter into', 'ameliorate', 'assuage', 'be changed', 'be converted into', 'be renewed', 'become'],
    'alter ego': ['i myself', 'acquaintance', 'advocate', 'ally', 'alter', 'alternate', 'alterum', 'amicus curiae', 'analogon', 'analogue', 'associate', 'attorney'],
    'alteration': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'amelioration', 'analysis', 'anatomization', 'apostasy', 'atomization', 'betterment', 'break', 'change'],
    'altercation': ['kilkenny cats', 'argument', 'bicker', 'bickering', 'blood feud', 'brawl', 'broil', 'cat-and-dog life', 'combat', 'conflict', 'contention', 'contentiousness'],
    'alternate': ['advocate', 'agent', 'alter ego', 'alternating', 'alternative', 'amicus curiae', 'analogy', 'attorney', 'back and fill', 'back-and-forth', 'backup', 'backup man'],
    'alternating current': ['ac', 'dc', 'absorption current', 'active current', 'conduction current', 'convection current', 'cycle', 'delta current', 'direct current', 'displacement current', 'eddy current', 'electric current'],
    'alternation': ['lissajous figure', 'back-and-forth', 'battledore and shuttlecock', 'beat', 'chain', 'coaction', 'coming and going', 'commutation', 'complementary distribution', 'concurrence', 'consecution', 'cooperation'],
    'alternative': ['additional', 'agent', 'alternate', 'alternate choice', 'analogy', 'another', 'attainable', 'backup', 'change', 'changeling', 'choice', 'comparison'],
    'althorn': ['alpenhorn', 'alphorn', 'alto horn', 'ballad horn', 'baritone', 'bass horn', 'brass choir', 'brass wind', 'brass-wind instrument', 'brasses', 'bugle', 'bugle horn'],
    'although': ['after all', 'again', 'albeit', 'all the same', 'at all events', 'at any rate', 'but', 'even', 'even so', 'for all that', 'howbeit', 'however'],
    'altimetry': ['altimeter', 'bathymetry', 'biometrics', 'biometry', 'cadastration', 'cartography', 'chorography', 'craniometry', 'geodesy', 'geodetics', 'goniometry', 'hypsography'],
    'altitude': ['cartesian coordinates', 'abscissa', 'apex', 'azimuth', 'ceiling', 'clearance', 'coordinates', 'cylindrical coordinates', 'declination', 'elevation', 'eminence', 'equator coordinates'],
    'alto': ['heldentenor', 'meistersinger', 'accompaniment', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso continuo', 'basso ostinato'],
    'altogether': ['above', 'absolutely', 'across the board', 'additionally', 'again', 'all', 'all in all', 'all included', 'all put together', 'all things considered', 'all told', 'also'],
    'altruism': ['bomfog', 'benthamism', 'christian charity', 'christian love', 'agape', 'beneficence', 'benevolence', 'benevolent disposition', 'benevolentness', 'bigheartedness', 'brotherly love', 'caritas'],
    'altruistic': ['almsgiving', 'beneficent', 'benevolent', 'bighearted', 'bounteous', 'bountiful', 'charitable', 'committed', 'consecrated', 'considerate', 'dedicated', 'devoted'],
    'alveolar': ['accented', 'alveolate', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'alveolus': ['alveolar ridge', 'alveolation', 'antrum', 'apex', 'armpit', 'arytenoid cartilages', 'back', 'basin', 'blade', 'bowl', 'cavity', 'concave'],
    'always': ['abidingly', 'again and again', 'all along', 'all over', 'all the time', 'all the while', 'at all times', 'at every turn', 'ceaselessly', 'changelessly', 'constantly', 'continually'],
    'am': ['ack emma', 'fm', 'pm', 'amplitude modulation', 'ante meridiem', 'double sideband', 'foreday', 'forenoon', 'grey-eyed morn', 'incense-breathing morn', 'matins', 'modulation'],
    'amah': ['abigail', 'au pair girl', 'ayah', 'betweenmaid', 'biddy', 'chambermaid', 'chaperon', 'companion', 'cook', 'dry nurse', 'duenna', 'femme de chambre'],
    'amalgam': ['admixture', 'alloy', 'alloyage', 'amalgamation', 'blend', 'combination', 'combo', 'commixture', 'composite', 'composition', 'compound', 'concoction'],
    'amalgamate': ['act in concert', 'act together', 'add', 'admix', 'affiliate', 'alloy', 'ally', 'assimilate', 'associate', 'band', 'band together', 'be in league'],
    'amalgamation': ['anschluss', 'addition', 'admixture', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alignment', 'alliance', 'alloy', 'alloyage', 'amalgam'],
    'amanuensis': ['federal', 'accountant', 'agent', 'archivist', 'baggage agent', 'bookkeeper', 'business agent', 'calligrapher', 'chirographer', 'claim agent', 'clerk', 'commercial agent'],
    'amass': ['accouple', 'accumulate', 'agglomerate', 'agglutinate', 'aggregate', 'aggroup', 'articulate', 'assemble', 'associate', 'backlog', 'band', 'batch'],
    'amassed': ['accumulated', 'agglomerate', 'aggregate', 'assembled', 'backlogged', 'bunched', 'bundled', 'clumped', 'clustered', 'collected', 'combined', 'conglomerate'],
    'amateur': ['sunday painter', 'abecedarian', 'admirer', 'aesthete', 'aficionado', 'amateurish', 'apprentice', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'authority', 'avocational'],
    'amateurish': ['amateur', 'clumsy', 'crude', 'dabbling', 'defective', 'deficient', 'dilettante', 'dilettantish', 'faulty', 'flawed', 'green', 'half-assed'],
    'amati': ['a string', 'cremona', 'd string', 'e string', 'g string', 'strad', 'stradivari', 'stradivarius', 'bass', 'bass viol', 'bow', 'bridge'],
    'amatory': ['admiring', 'amative', 'amorous', 'aphrodisiac', 'ardent', 'attracted', 'caressive', 'coquettish', 'coy', 'desirous', 'erotic', 'flirtatious'],
    'amaze': ['addle', 'admiration', 'affect', 'amazement', 'astonish', 'astound', 'awe', 'awestrike', 'baffle', 'bamboozle', 'beat', 'bedaze'],
    'amazed': ['agape', 'aghast', 'agog', 'all agog', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled', 'bewildered', 'bewitched'],
    'amazement': ['admiration', 'amaze', 'astonishing thing', 'astonishment', 'astoundment', 'awe', 'beguilement', 'bewilderment', 'breathless wonder', 'confoundment', 'curiosity', 'dumbfoundment'],
    'amazing': ['astonishing', 'astounding', 'awesome', 'breathtaking', 'confounding', 'dazzling', 'extraordinary', 'eye-opening', 'fabulous', 'mind-boggling', 'miraculous', 'overwhelming'],
    'amazon': ['xanthippe', 'androgyne', 'butch', 'colossus', 'dyke', 'fishwife', 'giant', 'harpy', 'hoyden', 'lesbian', 'ogress', 'romp'],
    'ambages': ['anfractuosity', 'bypass', 'circuit', 'circuitousness', 'circumambages', 'circumbendibus', 'circumlocution', 'circumvolution', 'convolution', 'crinkle', 'crinkling', 'detour'],
    'ambassador': ['agent', 'ambassadress', 'apostolic delegate', 'attache', 'career diplomat', 'chancellor', 'charge', 'commercial attache', 'consul', 'consul general', 'consular agent', 'delegate'],
    'ambergris': ['ambrosia', 'aromatic', 'aromatic gum', 'aromatic water', 'attar', 'attar of roses', 'balm', 'balm of gilead', 'balsam', 'bay oil', 'bergamot oil', 'champaca oil'],
    'ambidextrous': ['janus-like', 'machiavellian', 'adaptable', 'adjustable', 'all-around', 'ambidexter', 'ambidextral', 'amphibious', 'artful', 'bifacial', 'bifold', 'biform'],
    'ambience': ['alentours', 'ambient', 'ambit', 'atmosphere', 'borderlands', 'circle', 'circuit', 'circumambiencies', 'circumjacencies', 'circumstances', 'climate', 'compass'],
    'ambient': ['ambience', 'atmosphere', 'circling', 'circumambient', 'circumferential', 'circumflex', 'circumfluent', 'circumfluous', 'circumjacent', 'climate', 'embracing', 'encircling'],
    'ambiguity': ['janus', 'ambivalence', 'amphibologism', 'amphibology', 'amphiboly', 'antinomy', 'asymmetry', 'biformity', 'bifurcation', 'cavil', 'conjugation', 'counterword'],
    'ambiguous': ['greek to one', 'agnostic', 'amalgamated', 'ambivalent', 'amphibious', 'amphibolic', 'amphibological', 'amphibolous', 'antinomic', 'beyond understanding', 'blended', 'capricious'],
    'ambit': ['alentours', 'ambience', 'arena', 'bailiwick', 'beat', 'border', 'borderland', 'borderlands', 'circle', 'circuit', 'circumambiencies', 'circumjacencies'],
    'ambition': ['aim', 'ambitiousness', 'animus', 'anxiety', 'appetite', 'aspiration', 'avidity', 'basis', 'calling', 'careerism', 'catch', 'cause'],
    'ambitious': ['adventuresome', 'adventurous', 'aggressive', 'anxious', 'aspiring', 'audacious', 'avaricious', 'avid', 'bold', 'careerist', 'careeristic', 'chimerical'],
    'ambivalence': ['janus', 'ambiguity', 'ambitendency', 'ambivalence of impulse', 'antinomy', 'asymmetry', 'biformity', 'bifurcation', 'capriciousness', 'change of mind', 'changeableness', 'conflict'],
    'ambivalent': ['amalgamated', 'ambiguous', 'ambitendent', 'amphibious', 'antinomic', 'at loose ends', 'blended', 'capricious', 'changeable', 'combined', 'complex', 'composite'],
    'amble': ['airing', 'barge', 'bowl along', 'bundle', 'canter', 'caracole', 'claudicate', 'clump', 'constitutional', 'crawl', 'creep', 'curvet'],
    'ambling': ['ambulation', 'backpacking', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'deliberate', 'easy', 'faltering', 'flagging'],
    'ambrosia': ['caesar salad', 'jell-o salad', 'waldorf salad', 'ambergris', 'aromatic', 'aromatic gum', 'aromatic water', 'artificial sweetener', 'aspic', 'attar', 'attar of roses', 'balm'],
    'ambrosial': ['adorable', 'agreeable', 'aromatic', 'balmy', 'bittersweet', 'candied', 'dainty', 'darling', 'delectable', 'delicate', 'delicious', 'delightful'],
    'ambulatory': ['access', 'aisle', 'alley', 'ambulant', 'ambulative', 'aperture', 'arcade', 'artery', 'avenue', 'channel', 'circuit-riding', 'cloister'],
    'ambush': ['ambuscade', 'ambushment', 'assail', 'assault', 'astonish', 'attack', 'blind', 'blitz', 'booby trap', 'bushwhack', 'catch off-guard', 'catch unawares'],
    'amebic': ['euglena', 'adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'animalcule', 'bacillus', 'bacteria', 'bacterium', 'bug'],
    'ameliorate': ['accommodate', 'acculturate', 'adapt', 'adjust', 'advance', 'alleviate', 'alter', 'amend', 'be changed', 'be converted into', 'be renewed', 'better'],
    'amelioration': ['great leap forward', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'advance', 'advancement', 'alteration', 'amendment', 'apostasy', 'ascent', 'bettering'],
    'amen': ['ok', 'roger', 'absolutely', 'affirmative', 'affirmative attitude', 'affirmativeness', 'agreed', 'all right', 'alright', 'alrighty', 'as you say', 'assuredly'],
    'amenable': ['accessible', 'accommodating', 'accountable', 'acquiescent', 'adaptable', 'adapting', 'adaptive', 'adjusting', 'advance', 'agreeable', 'alacritous', 'ameliorate'],
    'amend': ['acculturate', 'advance', 'ameliorate', 'better', 'blue-pencil', 'boost', 'bring forward', 'civilize', 'come along', 'come on', 'compensate', 'correct'],
    'amendment': ['great leap forward', 'addendum', 'addition', 'advance', 'advancement', 'alteration', 'amelioration', 'ascent', 'attachment', 'bettering', 'betterment', 'bill'],
    'amends': ['atonement', 'balancing', 'blood money', 'commutation', 'compensate', 'compensation', 'composition', 'compromise', 'consideration', 'correction', 'counteraction', 'counterbalancing'],
    'amenities': ['cakes and ale', 'ceremonies', 'civilities', 'civility', 'comforts', 'comity', 'conveniences', 'convention', 'courtliness', 'creature comforts', 'decencies', 'decorum'],
    'amenity': ['accommodation', 'act of courtesy', 'advantage', 'affability', 'agreeability', 'agreeableness', 'amiability', 'amicability', 'appliance', 'appurtenance', 'attention', 'attractiveness'],
    'ament': ['born fool', 'capitulum', 'catkin', 'clot', 'cone', 'congenital idiot', 'corymb', 'cretin', 'cyme', 'defective', 'golem', 'half-wit'],
    'amentia': ['arrested development', 'backwardness', 'blithering idiocy', 'cretinism', 'half-wittedness', 'idiocy', 'idiotism', 'imbecility', 'infantilism', 'insanity', 'mental defectiveness', 'mental deficiency'],
    'america': ['africa', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'columbia', 'east', 'eastern hemisphere', 'eurasia', 'europe', 'far east'],
    'americanism': ['anglicism', 'briticism', 'frenchism', 'gallicism', 'hibernicism', 'irishism', 'latinism', 'scotticism', 'yankeeism', 'chauvinism', 'flag waving', 'jingoism'],
    'amethystine': ['lavender', 'lilac', 'livid', 'magenta', 'mauve', 'mulberry', 'orchid', 'pansy-purple', 'plum-colored', 'plum-purple', 'purple', 'purplescent'],
    'amex': ['american stock exchange', 'wall street', 'board', 'bourse', 'commodity exchange', 'corn pit', 'curb', 'curb exchange', 'curb market', 'exchange', 'exchange floor', 'outside market'],
    'amiable': ['accommodating', 'affable', 'affectionate', 'agreeable', 'amicable', 'approachable', 'benevolent', 'benign', 'benignant', 'blissful', 'bonhomous', 'brotherly'],
    'amicable': ['accordant', 'affable', 'agreeable', 'agreeing', 'akin', 'amiable', 'at one', 'attuned', 'beneficent', 'benevolent', 'benign', 'benignant'],
    'amicus curiae': ['ja', 'advocate', 'agent', 'alter ego', 'alternate', 'assessor', 'attorney', 'attorney-at-law', 'backup', 'backup man', 'barmaster', 'barrister'],
    'amidships': ['average', 'betwixt and between', 'central', 'core', 'equatorial', 'equidistant', 'half-and-half', 'halfway', 'in medias res', 'in the mean', 'in the middle', 'interior'],
    'amigo': ['ace', 'acquaintance', 'associate', 'bedfellow', 'bedmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty', 'camarade', 'chamberfellow'],
    'amino acid': ['alanine', 'albuminoid', 'arginine', 'chromoprotein', 'dipeptide', 'glycine', 'glycoprotein', 'leucine', 'lipoprotein', 'lysine', 'methionine', 'nucleoprotein'],
    'amiss': ['aberrant', 'abroad', 'adrift', 'afield', 'all abroad', 'all off', 'all wrong', 'askew', 'astray', 'at fault', 'awry', 'bad'],
    'amity': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'amiability', 'amiableness', 'amicability', 'amicableness', 'benevolence', 'bonds of harmony', 'brotherly love'],
    'ammonia': ['dry ice', 'freon', 'acetylene', 'argon', 'asphyxiating gas', 'butane', 'carbon dioxide', 'carbon monoxide', 'castor-bean meal', 'chlorine', 'coal gas', 'commercial fertilizer'],
    'amnesia': ['agnosia', 'blackout', 'catalepsy', 'cataplexy', 'catatonic stupor', 'daydreaming', 'daze', 'dream state', 'fugue', 'fugue state', 'hypnotic trance', 'loss of memory'],
    'amnesty': ['absolution', 'exculpation', 'excuse', 'exemption', 'exoneration', 'grace', 'immunity', 'impunity', 'indemnity', 'nolle prosequi', 'non prosequitur', 'nonprosecution'],
    'amnion': ['allantoic membrane', 'amniotic sac', 'arachnoid membrane', 'basement membrane', 'conjuctiva', 'eardrum', 'hymen', 'maidenhead', 'membrana serosa', 'membrana tympana', 'membrane', 'meninges'],
    'amoeba': ['euglena', 'adenovirus', 'aerobe', 'aerobic bacteria', 'anaerobe', 'anaerobic bacteria', 'animalcule', 'bacillus', 'bacteria', 'bacterium', 'bug', 'coccus'],
    'amok': ['dionysiac', 'abandoned', 'attack', 'bacchic', 'bellowing', 'berserk', 'carried away', 'convulsion', 'corybantic', 'delirious', 'demoniac', 'desperate'],
    'among': ['amid', 'amidst', 'amongst', 'at', 'between', 'betwixt', 'betwixt and between', 'by', 'from', 'in', 'mid', 'midst'],
    'amor': ['agdistis', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'astarte', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'amoral': ['conscienceless', 'corrupt', 'corrupted', 'criminal', 'crooked', 'dark', 'devious', 'dishonest', 'dishonorable', 'doubtful', 'dubious', 'evasive'],
    'amorality': ['amoralism', 'backsliding', 'carnality', 'criminality', 'delinquency', 'evil', 'evil nature', 'immorality', 'impurity', 'moral delinquency', 'peccability', 'prodigality'],
    'amorous': ['amative', 'amatory', 'aphrodisiac', 'ardent', 'carnal', 'desirous', 'enamored', 'erogenic', 'erogenous', 'erotic', 'erotogenic', 'fleshly'],
    'amorphous': ['aberrant', 'abnormal', 'adrift', 'afloat', 'aimless', 'aleatoric', 'aleatory', 'alternating', 'amorphic', 'anarchic', 'anomalistic', 'anomalous'],
    'amortization': ['abalienation', 'acquitment', 'acquittal', 'acquittance', 'alienation', 'amortizement', 'assignation', 'assignment', 'bargain and sale', 'barter', 'bequeathal', 'binder'],
    'amortize': ['abalienate', 'alien', 'alienate', 'assign', 'barter', 'bequeath', 'cede', 'clear', 'confer', 'consign', 'convey', 'deed'],
    'amount': ['account', 'add up', 'add up to', 'aggregate', 'amount to', 'amplitude', 'approach', 'batch', 'become', 'body', 'box score', 'budget'],
    'amount to': ['add up to', 'afford', 'aggregate', 'aggregate to', 'balance', 'break even', 'bring', 'bring in', 'come to', 'come up to', 'comprise', 'contain'],
    'amour': ['adulterous affair', 'adultery', 'affair', 'amorousness', 'cuckoldry', 'entanglement', 'eternal triangle', 'flirtation', 'forbidden love', 'hanky-panky', 'illicit love', 'infidelity'],
    'amphetamine': ['benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'methedrine', 'amphetamine sulfate', 'cocaine', 'coke', 'crystal', 'dextroamphetamine sulfate'],
    'amphibian': ['reptilia', 'surinam toad', 'aeroboat', 'air', 'airy nothing', 'angiosperm', 'anguine', 'annual', 'aquatic plant', 'batrachian', 'biennial', 'boat seaplane'],
    'amphibious': ['adaptable', 'adjustable', 'all-around', 'amalgamated', 'ambidextrous', 'ambiguous', 'ambivalent', 'blended', 'combined', 'complex', 'composite', 'compound'],
    'amphitheater': ['elizabethan theater', 'globe theatre', 'greek theater', 'agora', 'arena', 'arena theater', 'assembly hall', 'athletic field', 'auditorium', 'background', 'bear garden', 'bowl'],
    'ample': ['abounding', 'abundant', 'adequate', 'affluent', 'all-sufficing', 'amplify', 'amplitudinous', 'aplenty', 'augment', 'barely sufficient', 'bottomless', 'bounteous'],
    'amplification': ['access', 'accession', 'accomplishment', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'adjunct', 'advance', 'advancement', 'aggrandizement'],
    'amplified': ['accelerated', 'aggrandized', 'aggravated', 'ampliate', 'annoyed', 'augmented', 'ballyhooed', 'beefed-up', 'bloated', 'boosted', 'broadened', 'built-up'],
    'amplifier': ['attenuator', 'audio-frequency tube', 'ballast regulator', 'ballast tube', 'beam-switching tube', 'convertor', 'current regulator', 'damper', 'detector', 'discriminator', 'doubler', 'ear trumpet'],
    'amplify': ['add to', 'agent provocateur', 'aggrandize', 'aggravate', 'annoy', 'augment', 'ballyhoo', 'bloat', 'blow up', 'boost', 'broaden', 'build'],
    'amplitude': ['abundance', 'affluence', 'amount', 'ample sufficiency', 'ampleness', 'antinode', 'area', 'auditory effect', 'auditory phenomenon', 'avalanche', 'beam', 'bigness'],
    'amply': ['abundantly', 'acceptably', 'acutely', 'adequately', 'admissibly', 'agreeably', 'amazingly', 'appropriately', 'astonishingly', 'awesomely', 'becomingly', 'broadly'],
    'amputate': ['abscind', 'annihilate', 'ax', 'ban', 'bar', 'bisect', 'bob', 'butcher', 'carve', 'chop', 'cleave', 'clip'],
    'amputation': ['abscission', 'anastomotic operation', 'annihilation', 'bloodless operation', 'butchering', 'capital operation', 'chopping', 'cleavage', 'compensating operation', 'corneal transplant', 'crescent operation', 'cutting'],
    'amulet': ['charm', 'fetish', 'fylfot', 'gammadion', 'good-luck charm', 'hoodoo', 'juju', 'love charm', 'luck', 'lucky bean', 'lucky piece', 'madstone'],
    'amuse': ['absorb', 'animate', 'beguile', 'charm', 'cheer', 'convulse', 'delight', 'distract', 'divert', 'enchant', 'engross', 'enliven'],
    'amusement': ['animal pleasure', 'beguilement', 'bodily pleasure', 'carnal delight', 'comfort', 'content', 'contentment', 'coziness', 'creature comforts', 'dissipation', 'distraction', 'diversion'],
    'amusing': ['absurd', 'beguiling', 'bizarre', 'delightful', 'diverting', 'droll', 'eccentric', 'entertaining', 'fun', 'funny', 'hilarious', 'humorous'],
    'ana': ['festschrift', 'adage', 'album', 'analects', 'anthology', 'aphorism', 'apothegm', 'aquarium', 'archives', 'axiom', 'beauties', 'biographical material'],
    'anabolism': ['assimilation', 'avatar', 'basal metabolism', 'catabolism', 'catalysis', 'consubstantiation', 'displacement', 'heterotopia', 'metabolism', 'metagenesis', 'metamorphism', 'metamorphosis'],
    'anachronism': ['antedate', 'antedating', 'anticipation', 'defect', 'faux pas', 'flaw', 'gaffe', 'metachronism', 'misapplication', 'misdate', 'misdating', 'mistake'],
    'anachronistic': ['ahead of time', 'antedated', 'beforehand', 'behind time', 'behindhand', 'dated', 'early', 'foredated', 'late', 'metachronistic', 'misdated', 'mistimed'],
    'anaerobe': ['adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobic bacteria', 'bacillus', 'bacteria', 'bacterium', 'bug', 'coccus', 'echovirus', 'enterovirus'],
    'anagram': ['abuse of terms', 'acrostic', 'amphibologism', 'amphiboly', 'calembour', 'charade', 'conundrum', 'corruption', 'equivocality', 'equivoque', 'jeu de mots', 'logogram'],
    'anal': ['abdominal', 'accordant', 'appendical', 'bourgeois', 'cardiac', 'cecal', 'colic', 'colonic', 'compulsive', 'concordant', 'conformist', 'conventional'],
    'analects': ['festschrift', 'adage', 'album', 'ana', 'anthology', 'aphorism', 'apothegm', 'axiom', 'beauties', 'byword', 'canon', 'catchword'],
    'analeptic': ['adjuvant', 'alterative', 'bracing', 'corrective', 'corroborant', 'curative', 'healing', 'iatric', 'invigorating', 'medicative', 'medicinal', 'refreshing'],
    'analgesia': ['abatement', 'allayment', 'alleviation', 'anesthesia', 'anesthetizing', 'anxiety equivalent', 'appeasement', 'assuagement', 'callousness', 'deadening', 'deadness', 'depraved appetite'],
    'analgesic': ['amytal', 'amytal pill', 'darvon', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'pyramidon', 'seconal'],
    'analogous': ['akin', 'aligned', 'alike', 'analogical', 'answering', 'coequal', 'coextending', 'coextensive', 'collatable', 'collateral', 'commensurable', 'commensurate'],
    'analogue': ['ally', 'alter ego', 'analogon', 'associate', 'brother', 'close copy', 'close match', 'cognate', 'companion', 'complement', 'congenator', 'congener'],
    'analogy': ['accordance', 'affinity', 'agent', 'agreement', 'alignment', 'alikeness', 'allegory', 'alliance', 'alternate', 'alternative', 'ambiguity', 'aping'],
    'analysis': ['baconian method', 'boolean algebra', 'euclidean geometry', 'fourier analysis', 'lagrangian function', 'a fortiori reasoning', 'a posteriori reasoning', 'a priori reasoning', 'abstraction', 'accounting', 'airing', 'algebra'],
    'analyst': ['analyzer', 'assayer', 'behavior therapist', 'clinical psychologist', 'essayer', 'examiner', 'experimenter', 'headshrinker', 'hypnotherapist', 'narcotherapist', 'psychiatrist', 'psychoanalyst'],
    'analytic': ['a fortiori', 'a posteriori', 'a priori', 'acute', 'algebraic', 'analytical', 'categorical', 'classificatory', 'conditional', 'deductive', 'deep', 'dialectic'],
    'analytical': ['a fortiori', 'a posteriori', 'a priori', 'algebraic', 'analytic', 'categorical', 'classificatory', 'conditional', 'deductive', 'dialectic', 'discursive', 'enthymematic'],
    'analyze': ['air', 'alphabetize', 'anatomize', 'apply reason', 'arrange', 'assay', 'assort', 'atomize', 'bracket', 'break down', 'break up', 'canvass'],
    'analyzer': ['analyst', 'assayer', 'breaker', 'centrifuge', 'cutter', 'essayer', 'examiner', 'experimenter', 'gas analyzer', 'mass spectrograph', 'mass spectrometer', 'research worker'],
    'analyzing': ['edp', 'appraisal', 'appraisement', 'appraising', 'appreciation', 'assessing', 'assessment', 'classifying', 'collating', 'computer technology', 'computer typesetting', 'computing'],
    'anapest': ['alexandrine', 'accent', 'accentuation', 'amphibrach', 'amphimacer', 'anacrusis', 'antispast', 'arsis', 'bacchius', 'beat', 'cadence', 'caesura'],
    'anaphylactic': ['allergic', 'delicate', 'empathetic', 'empathic', 'goosy', 'hyperesthetic', 'hyperpathic', 'hypersensitive', 'irritable', 'itchy', 'nervous', 'overrefined'],
    'anaphylaxis': ['allergy', 'considerateness', 'delicacy', 'empathy', 'exquisiteness', 'fineness', 'hyperesthesia', 'hyperpathia', 'hypersensitivity', 'identification', 'irritability', 'nervousness'],
    'anarchic': ['bolshevik', 'bolshevist', 'carbonarist', 'castroist', 'castroite', 'communist', 'fenian', 'guevarist', 'jacobinic', 'leninist', 'maoist', 'marxist'],
    'anarchism': ['bolshevikism', 'bolshevism', 'carbonarism', 'castroism', 'jacobinism', 'maoism', 'marxism', 'new left', 'old left', 'sinn feinism', 'anarcho-syndicalism', 'anarchy'],
    'anarchist': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'cong', 'fenian', 'guevarist'],
    'anarchistic': ['actionable', 'against the law', 'anarchial', 'anarchic', 'anarcho-syndicalist', 'anomic', 'antinomian', 'black-market', 'bootleg', 'chaotic', 'chargeable', 'contraband'],
    'anarchy': ['aloofness', 'amorphia', 'amorphism', 'amorphousness', 'anarchism', 'anarcho-syndicalism', 'anomie', 'antinomianism', 'blurriness', 'chaos', 'confusion', 'criminal syndicalism'],
    'anathema': ['abhorrence', 'abomination', 'antipathy', 'arraignment', 'aversion', 'ban', 'bete noire', 'blame', 'blasphemy', 'bugbear', 'castigation', 'censure'],
    'anatomize': ['adduce', 'analyze', 'assay', 'atomize', 'break down', 'break up', 'change', 'chop logic', 'circumstantiate', 'cite', 'decompose', 'descend to particulars'],
    'anatomy': ['aerobiology', 'agrobiology', 'amnion', 'analysis', 'analyzation', 'anatomist', 'anatomizing', 'angiography', 'angiology', 'animal physiology', 'anthropography', 'anthropologist'],
    'ancestor': ['ancestress', 'announcer', 'antecedent', 'ascendant', 'avant-garde', 'begetter', 'bellwether', 'buccinator', 'bushwhacker', 'explorer', 'forebear', 'forefather'],
    'ancestors': ['antecedents', 'apprentice', 'architect', 'artificer', 'artist', 'ascendants', 'author', 'begetter', 'beginner', 'builder', 'conceiver', 'constructor'],
    'ancestral': ['aboriginal', 'ancestorial', 'antepatriarchal', 'atavistic', 'autochthonous', 'fatherlike', 'fatherly', 'grandfatherly', 'grandmotherly', 'grandparental', 'humanoid', 'maternal'],
    'ancestry': ['affiliation', 'agnate', 'agnation', 'alliance', 'aristocracy', 'aristocraticalness', 'birth', 'blood', 'blood relation', 'blood relationship', 'blood relative', 'blue blood'],
    'anchor': ['baldt anchor', 'navy anchor', 'northill anchor', 'affix', 'anchorage', 'annex', 'attach', 'batten', 'batten down', 'belay', 'berth', 'billet at'],
    'anchorage': ['admission', 'admission fee', 'anchor', 'anchorage ground', 'basin', 'berth', 'bourn', 'breakwater', 'brokerage', 'bulkhead', 'carfare', 'cellarage'],
    'anchored': ['aground', 'caught', 'chained', 'fast', 'fastened', 'fixed', 'grounded', 'held', 'high and dry', 'impacted', 'inextricable', 'jammed'],
    'anchorite': ['albigensian', 'catharist', 'diogenes', 'franciscan', 'hieronymian', 'hieronymite', 'sabbatarian', 'timon of athens', 'trappist', 'waldensian', 'abstainer', 'anchoress'],
    'ancient': ['bronze age man', 'hominidae', 'iron age man', 'stone age man', 'abiding', 'aboriginal', 'aborigine', 'advanced', 'advanced in life', 'advanced in years', 'age-long', 'age-old'],
    'ancillary': ['accessory', 'accompanying', 'additional', 'adjuvant', 'another', 'appurtenant', 'assistant', 'assisting', 'attendant', 'attending', 'auxiliary', 'coincident'],
    'andante': ['a poco', 'adagietto', 'adagio', 'allargando', 'allegretto', 'allegro', 'andante tempo', 'andantino', 'beat', 'calando', 'claudication', 'compound time'],
    'andiron': ['chain', 'coal tongs', 'crane', 'crook', 'damper', 'fire hook', 'fire tongs', 'firedog', 'grate', 'grating', 'grid', 'griddle'],
    'androgyny': ['androgynism', 'effeminacy', 'effeminateness', 'epicenism', 'epicenity', 'feminism', 'gynandrism', 'gynandry', 'hermaphroditism', 'intersexualism', 'intersexuality', 'muliebrity'],
    'anemia': ['christmas disease', 'letterer-siwe syndrome', 'lombardy leprosy', 'abscess', 'acute leukemia', 'adynamia', 'ague', 'angiohemophilia', 'ankylosis', 'anoxia', 'aplastic anemia', 'apnea'],
    'anemic': ['achromatic', 'achromic', 'allergic', 'apoplectic', 'arthritic', 'ashen', 'ashy', 'asthenic', 'bilious', 'bled white', 'bloodless', 'cadaverous'],
    'anemology': ['beaufort scale', 'aerography', 'aerology', 'anemometry', 'barometric wind rose', 'barometry', 'climatography', 'climatology', 'dynamic wind rose', 'forecasting', 'long-range forecasting', 'meteorology'],
    'anemometer': ['mach meter', 'accelerometer', 'anemograph', 'anemometrograph', 'anemoscope', 'cock', 'ground log', 'harpoon log', 'log', 'log line', 'patent log', 'speedometer'],
    'anesthesia': ['abatement', 'allayment', 'alleviation', 'analgesia', 'anesthetizing', 'anxiety equivalent', 'appeasement', 'assuagement', 'autism', 'callousness', 'catatonia', 'chill'],
    'anesthetic': ['mickey finn', 'pentothal', 'alleviating', 'alleviative', 'analgesic', 'anodyne', 'assuasive', 'balmy', 'balsamic', 'benumbing', 'cathartic', 'chloroform'],
    'anesthetize': ['ko', 'abate', 'allay', 'alleviate', 'appease', 'assuage', 'bedaze', 'benumb', 'besot', 'blunt', 'chloroform', 'coldcock'],
    'anesthetized': ['affectless', 'arctic', 'asleep', 'autistic', 'benumbed', 'blunt', 'cataleptic', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity'],
    'anew': ['ab ovo', 'afresh', 'again', 'another time', 'as new', 'bis', 'da capo', 'de novo', 'ditto', 'encore', 'freshly', 'from scratch'],
    'anfractuous': ['ambagious', 'circuitous', 'circumlocutory', 'cochlear', 'cochleate', 'convoluted', 'convolutional', 'corkscrew', 'corkscrewy', 'flexuose', 'flexuous', 'helical'],
    'angel': ['dionysus', 'maecenas', 'santa claus', 'abettor', 'admirer', 'advocate', 'aficionado', 'almoner', 'almsgiver', 'ancestral spirits', 'angelology', 'angels'],
    'angelic': ['christlike', 'christly', 'god-fearing', 'admirable', 'adorable', 'archangelic', 'beatified', 'blameless', 'canonized', 'caressable', 'celestial', 'charming'],
    'angelus': ['angelus bell', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'aid prayer', 'alarm', 'alarum', 'appeal', 'battle cry', 'beadroll'],
    'anger': ['a transient madness', 'acedia', 'affront', 'aggravate', 'angriness', 'annoy', 'annoyance', 'antagonism', 'ardency', 'ardor', 'arouse', 'asperity'],
    'angina': ['ache', 'aching', 'angina pectoris', 'aortic insufficiency', 'aortic stenosis', 'apoplectic stroke', 'apoplexy', 'arrhythmia', 'arteriosclerosis', 'atherosclerosis', 'atrial fibrillation', 'auricular fibrillation'],
    'angle': ['anschauung', 'action', 'aim', 'anagnorisis', 'angle for', 'angle of vision', 'angle off', 'apex', 'approach', 'architectonics', 'architecture', 'argument'],
    'angle for': ['address', 'ask for', 'beat about for', 'bid for', 'canvass', 'court', 'delve for', 'dig for', 'fish for', 'follow', 'go gunning for', 'gun for'],
    'anglicism': ['americanism', 'briticism', 'frenchism', 'gallicism', 'hibernicism', 'irishism', 'latinism', 'scotticism', 'yankeeism', 'chauvinism', 'flag waving', 'jingoism'],
    'angry': ['acid', 'acrimonious', 'aggravated', 'algetic', 'anarchic', 'angered', 'annoyed', 'blustering', 'blusterous', 'blustery', 'bothered', 'browned off'],
    'angst': ['agitation', 'all-overs', 'anguish', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat', 'anxiousness', 'apprehension', 'apprehensiveness'],
    'anguish': ['ache', 'aching heart', 'afflict', 'affliction', 'aggrieve', 'agonize', 'agony', 'agony of mind', 'ail', 'angst', 'anxiety', 'atrocious pain'],
    'anguished': ['aching', 'aggrieved', 'anxious', 'bleeding', 'bored', 'bruised', 'careworn', 'cheerless', 'cut', 'depressed', 'disgusted', 'doleful'],
    'angular': ['v-shaped', 'y-shaped', 'akimbo', 'bent', 'bony', 'cornered', 'crooked', 'crotched', 'crude', 'forked', 'furcal', 'furcate'],
    'anhydrous': ['saharan', 'arid', 'athirst', 'bone-dry', 'desert', 'droughty', 'dry', 'dry as dust', 'dusty', 'high and dry', 'juiceless', 'like parchment'],
    'anility': ['advanced age', 'advanced years', 'age of retirement', 'an incurable disease', 'caducity', 'childishness', 'debility', 'decline', 'decline of life', 'declining years', 'decrepitude', 'dotage'],
    'anima': ['anima humana', 'animating force', 'animus', 'atman', 'ba', 'bathmism', 'beating heart', 'biological clock', 'biorhythm', 'blood', 'breath', 'breath of life'],
    'animadversion': ['accusation', 'adverse criticism', 'aspersion', 'bad notices', 'bad press', 'captiousness', 'carping', 'cavil', 'caviling', 'censoriousness', 'censure', 'criticism'],
    'animal': ['adamic', 'angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'circean', 'draconian', 'goth', 'gothic', 'indian buffalo', 'kodiak bear', 'neanderthal'],
    'animal kingdom': ['animalia', 'and fish', 'animal life', 'animality', 'beasts', 'beasts of field', 'beasts of prey', 'big game', 'birds', 'blood', 'breed', 'brood'],
    'animal spirits': ['animate existence', 'animation', 'being alive', 'birth', 'capersomeness', 'coltishness', 'elan', 'esprit', 'existence', 'exuberance', 'friskiness', 'frolicsomeness'],
    'animal worship': ['druidism', 'parsiism', 'sabaism', 'zoroastrianism', 'demonism', 'demonolatry', 'devil worship', 'fetishism', 'fire worship', 'heathenism', 'hero worship', 'iconoduly'],
    'animalism': ['adam', 'marxism', 'animality', 'atomism', 'beastliness', 'behaviorism', 'bestiality', 'brutality', 'brutishness', 'carnal nature', 'carnal-mindedness', 'carnality'],
    'animalistic': ['adamic', 'circean', 'animal', 'animalian', 'animalic', 'beastlike', 'beastly', 'bestial', 'bodily', 'brutal', 'brute', 'brutelike'],
    'animality': ['adam', 'animalia', 'gothicism', 'neanderthalism', 'acuteness', 'and fish', 'animal kingdom', 'animal life', 'animalism', 'atrociousness', 'atrocity', 'barbarism'],
    'animate': ['aboveground', 'activate', 'activated', 'active', 'actuate', 'alert', 'alive', 'alive and kicking', 'among the living', 'animated', 'arouse', 'biological'],
    'animated': ['aboveground', 'activated', 'active', 'activist', 'activistic', 'actuated', 'acute', 'aggressive', 'alert', 'alive', 'alive and kicking', 'all agog'],
    'animated cartoon': ['cinemascope', 'cinerama', 'technicolor', 'western', 'black-and-white film', 'caricature', 'cartoon', 'chiller', 'cinema', 'color film', 'comic book', 'comic strip'],
    'animation': ['activity', 'actuation', 'afflatus', 'aggravation', 'agitation', 'alacrity', 'animal spirits', 'animate existence', 'animating spirit', 'animus', 'anxiety', 'anxiousness'],
    'animism': ['berkeleianism', 'hegelianism', 'kantianism', 'neoplatonism', 'platonic form', 'platonic idea', 'platonism', 'absolute idealism', 'allotheism', 'animatism', 'form', 'heathendom'],
    'animosity': ['acerbity', 'acid', 'acidity', 'acidulousness', 'acrimony', 'animus', 'antagonism', 'antipathy', 'asperity', 'bad blood', 'bad feeling', 'bile'],
    'animus': ['acrimony', 'afflatus', 'aim', 'ambition', 'anima', 'animating spirit', 'animation', 'animosity', 'antagonism', 'antipathy', 'appetence', 'appetency'],
    'anion': ['acid', 'acidity', 'agent', 'alkali', 'alkalinity', 'alloisomer', 'antacid', 'atom', 'base', 'biochemical', 'cation', 'chemical'],
    'ankh': ['calvary cross', 'christogram', 'greek cross', 'jerusalem cross', 'latin cross', 'maltese cross', 'russian cross', 'avellan cross', 'chi', 'chi-rho', 'christcross', 'crisscross'],
    'ankle': ['articulation', 'bayonet legs', 'boundary', 'bowlegs', 'butt', 'calf', 'cervix', 'clinch', 'closure', 'cnemis', 'connecting link', 'connecting rod'],
    'ankle deep': ['cursory', 'deep', 'deep-cut', 'deep-down', 'deep-engraven', 'deep-fixed', 'deep-laid', 'deep-lying', 'deep-reaching', 'deep-rooted', 'deep-seated', 'deep-set'],
    'annalist': ['boswell', 'advertising writer', 'art critic', 'author', 'authoress', 'autobiographer', 'autobiographist', 'belletrist', 'bibliographer', 'biographer', 'calendar maker', 'calendarist'],
    'annals': ['clio', 'muse of history', 'account', 'adventures', 'autobiography', 'biographical sketch', 'biography', 'case history', 'catalog', 'check sheet', 'chronicle', 'chronicles'],
    'annex': ['abstract', 'accession', 'accessory', 'accompaniment', 'accroach', 'acquire', 'add', 'addenda', 'addendum', 'additament', 'addition', 'additive'],
    'annexation': ['abstraction', 'accession', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adhesive'],
    'annihilate': ['abate', 'abolish', 'abrogate', 'abscind', 'amputate', 'annul', 'ban', 'bar', 'bereave of life', 'blot out', 'bob', 'bring to naught'],
    'annihilation': ['abolishment', 'abolition', 'abscission', 'amputation', 'annulment', 'bane', 'biological death', 'cessation of life', 'choking', 'choking off', 'clinical death', 'crossing the bar'],
    'anniversary': ['admission day', 'arbor day', 'armed forces day', 'armistice day', 'army day', 'bastille day', 'colorado day', 'constitution day', 'decoration day', 'dewali', 'discovery day', 'double ten'],
    'annotation': ['adversaria', 'aide-memoire', 'apparatus criticus', 'comment', 'commentary', 'commentation', 'docket', 'entry', 'exegesis', 'footnote', 'gloss', 'item'],
    'announce': ['advertise', 'affirm', 'allege', 'annunciate', 'antecede', 'antedate', 'anticipate', 'argue', 'assert', 'assever', 'asseverate', 'attest'],
    'announcement': ['account', 'acquaintance', 'ad', 'advert', 'advertisement', 'affirmance', 'affirmation', 'allegation', 'annunciation', 'assertion', 'asseveration', 'averment'],
    'announcer': ['aftra', 'dj', 'mc', 'adviser', 'ancestor', 'anchor', 'anchor man', 'anchorman', 'annunciator', 'antecedent', 'authority', 'avant-garde'],
    'annoy': ['abrade', 'agent provocateur', 'aggravate', 'agitate', 'amplify', 'arouse', 'augment', 'awake', 'awaken', 'badger', 'bait', 'be at'],
    'annoyance': ['ado', 'adverse circumstances', 'adversity', 'affliction', 'aggravation', 'amplification', 'anger', 'annoyingness', 'anxiety', 'augmentation', 'aversion', 'bad news'],
    'annoyed': ['aggravated', 'amplified', 'angry', 'anxious', 'augmented', 'beset', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'chafed', 'deliberately provoked'],
    'annoying': ['aggravating', 'aggravative', 'backbreaking', 'besetting', 'bothering', 'bothersome', 'burdensome', 'chafing', 'contentious', 'crushing', 'disquieting', 'distressful'],
    'annual': ['domesday book', 'account', 'account book', 'account rendered', 'accounting', 'acta', 'address book', 'adversaria', 'album', 'amphibian', 'angiosperm', 'appointment calendar'],
    'annuity': ['accident insurance', 'actuary', 'aid', 'alimony', 'allotment', 'allowance', 'assistance', 'assurance', 'aviation insurance', 'bail bond', 'bond', 'bounty'],
    'annul': ['abate', 'abolish', 'abrogate', 'abstract', 'annihilate', 'black out', 'blot out', 'bring to naught', 'bring to nothing', 'buffer', 'cancel', 'cancel out'],
    'annulet': ['achievement', 'alerion', 'animal charge', 'argent', 'armorial bearings', 'armory', 'arms', 'azure', 'bandeau', 'bar', 'bar sinister', 'baton'],
    'annulment': ['abjuration', 'abjurement', 'abolishment', 'abolition', 'abrogation', 'absolute contradiction', 'annihilation', 'broken home', 'broken marriage', 'cancel', 'canceling', 'cancellation'],
    'annum': ['abundant year', 'academic year', 'bissextile year', 'calendar month', 'calendar year', 'century', 'common year', 'day', 'decade', 'decennary', 'decennium', 'defective year'],
    'annunciation': ['affirmance', 'affirmation', 'allegation', 'announcement', 'assertion', 'asseveration', 'averment', 'avouchment', 'avowal', 'bulletin board', 'circular', 'communique'],
    'anodyne': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'anoint': ['administer the eucharist', 'beeswax', 'chair', 'chrism', 'confirm', 'crown', 'daub', 'do duty', 'dope', 'dose', 'dress', 'drug'],
    'anointment': ['accession', 'anointing', 'appointment', 'arrogation', 'assignment', 'assumption', 'authorization', 'chrismation', 'chrismatory', 'consecration', 'coronation', 'delegation'],
    'anomalous': ['aberrant', 'abnormal', 'absurd', 'amorphous', 'anomalistic', 'atypical', 'crank', 'crankish', 'cranky', 'crotchety', 'deviant', 'deviative'],
    'anomaly': ['aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'amorphism', 'anomalism', 'anomalousness', 'conceit', 'conversation piece', 'crackpotism', 'crank'],
    'anon': ['after a time', 'after a while', 'afterward', 'afterwards', 'again', 'at another time', 'at that moment', 'at that time', 'before long', 'betimes', 'by and by', 'by destiny'],
    'anonymous': ['closet', 'cryptonymic', 'cryptonymous', 'incognito', 'inmost', 'innermost', 'innominate', 'interior', 'intimate', 'inward', 'isolated', 'nameless'],
    'another': ['accessory', 'added', 'additional', 'ancillary', 'autre chose', 'auxiliary', 'collateral', 'contributory', 'different story', 'different thing', 'else', 'extra'],
    'anoxia': ['minamata disease', 'abscess', 'ague', 'altitude sickness', 'anemia', 'ankylosis', 'anoxemia', 'anoxic anoxia', 'anthrax', 'apnea', 'asphyxiation', 'asthma'],
    'answer': ['agnus dei', 'benedicite', 'esp', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'nunc dimittis', 'parthian shot', 'te deum'],
    'answer back': ['acknowledge', 'answer', 'come back', 'come back at', 'echo', 'flash back', 'give acknowledgment', 'give answer', 'lip', 'provoke', 'react', 'reecho'],
    'answer for': ['accept obligation', 'accept the responsibility', 'act for', 'agree to', 'appear for', 'back up', 'be accepted for', 'be answerable for', 'be regarded as', 'be responsible for', 'be security for', 'be sponsor for'],
    'antacid': ['acid', 'acidity', 'agent', 'alexipharmic', 'alkali', 'alkalinity', 'alkalizer', 'alloisomer', 'anion', 'annulling', 'anthelmintic', 'antibiotic'],
    'antagonism': ['abhorrence', 'abomination', 'aggression', 'aggressiveness', 'allergy', 'animosity', 'animus', 'annulling', 'antipathy', 'antithesis', 'argumentation', 'aversion'],
    'antagonist': ['roscius', 'actor', 'actress', 'adversary', 'anti', 'antihero', 'archenemy', 'assailant', 'bad guy', 'barnstormer', 'bit', 'bit part'],
    'antagonistic': ['acrid', 'adversary', 'adversative', 'adverse', 'adversive', 'aggressive', 'alien', 'anti', 'antipathetic', 'antithetic', 'antonymous', 'at cross-purposes'],
    'antagonize': ['aggravate', 'alienate', 'battle', 'be antipathetic', 'be inimical', 'beat against', 'beat up against', 'breast the wave', 'buck', 'buffet', 'buffet the waves', 'clash'],
    'ante': ['ahead', 'ante up', 'back', 'beforehand', 'bet', 'bet on', 'book', 'call', 'chunk', 'cover', 'ere', 'fade'],
    'ante bellum': ['antediluvian', 'antemundane', 'before the fall', 'before the flood', 'before the war', 'pre-aryan', 'pre-christian', 'pre-renaissance', 'pre-roman', 'preclassical', 'precultural', 'prehistoric'],
    'antecede': ['announce', 'antedate', 'anticipate', 'be before', 'be early', 'come before', 'come first', 'forerun', 'front', 'go ahead of', 'go before', 'go in advance'],
    'antecedent': ['agency', 'ancestor', 'ancestors', 'announcer', 'antecede', 'antecedents', 'antedate', 'anterior', 'anticipatory', 'ascendant', 'ascendants', 'avant-garde'],
    'antedate': ['announce', 'antecede', 'anticipate', 'backdate', 'be before', 'be dated', 'be early', 'bear date', 'come before', 'date', 'date at', 'date-stamp'],
    'antediluvian': ['bronze age man', 'gothic', 'hominidae', 'iron age man', 'methuselah', 'stone age man', 'victorian', 'aboriginal', 'aborigine', 'age-old', 'aged', 'ancient'],
    'antelope': ['angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'cape elk', 'indian buffalo', 'kodiak bear', 'virginia deer', 'aardvark', 'aardwolf', 'alpaca', 'anteater'],
    'antenna': ['aerials', 'barb', 'barbel', 'barbule', 'bedspring type', 'cat whisker', 'directional antenna', 'dish', 'doublet', 'feed-and-reflector unit', 'feeler', 'mast'],
    'antepast': ['antipasto', 'aperitif', 'appetizer', 'canape', 'course', 'cover', 'dessert', 'dish', 'entree', 'entremets', 'foretaste', 'help'],
    'anterior': ['album', 'ana', 'analects', 'antecedent', 'anticipatory', 'chief', 'ci-devant', 'collection', 'compilation', 'delectus', 'earlier', 'early'],
    'anthem': ['agnus dei', 'benedicite', 'brautlied', 'christmas carol', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'kunstlied', 'liebeslied', 'magnificat', 'miserere'],
    'anthill': ['bank', 'barrow', 'brae', 'butte', 'cock', 'down', 'drift', 'drumlin', 'dune', 'embankment', 'fell', 'foothills'],
    'anthology': ['festschrift', 'album', 'ana', 'analects', 'aquarium', 'beauties', 'body', 'book of verse', 'canon', 'chrestomathy', 'clippings', 'collectanea'],
    'anthrax': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'minamata disease', 'texas fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'altitude sickness', 'amebiasis'],
    'anthropoid': ['bronze age man', 'hominidae', 'iron age man', 'stone age man', 'aboriginal', 'aborigine', 'ancient', 'antediluvian', 'anthropomorphic', 'anthropopathic', 'ape-man', 'autochthon'],
    'anthropology': ['anatomy', 'animal physiology', 'anthropography', 'anthropologist', 'anthropometry', 'behavioral science', 'biology', 'comparative anatomy', 'conchology', 'craniology', 'craniometry', 'demography'],
    'anthropomorphism': ['acosmism', 'allotheism', 'anthropolatry', 'anthropopathism', 'anthropotheism', 'autotheism', 'cosmotheism', 'deism', 'ditheism', 'dualism', 'dyotheism', 'henotheism'],
    'anti': ['adversary', 'adversative', 'adverse', 'adversive', 'alien', 'antagonistic', 'antipathetic', 'antithetic', 'antonymous', 'at cross-purposes', 'balancing', 'clashing'],
    'anti semitism': ['anglophobia', 'jim crow', 'jim crow law', 'russophobia', 'abhorrence', 'abomination', 'antipathy', 'apartheid', 'aversion', 'bigotry', 'black power', 'black supremacy'],
    'antibiotic': ['chloromycetin', 'terramycin', 'acaricide', 'actinomycin', 'alexipharmic', 'amphotericin', 'antacid', 'anthelmintic', 'antidotal', 'antimicrobial', 'antipyretic', 'antiseptic'],
    'antibody': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'acquired immunity', 'active immunity', 'agglutinin', 'allergen', 'anaphylactin', 'antiantibody', 'antigen'],
    'antic': ['animated', 'artifice', 'bizarre', 'caper', 'capersome', 'caracole', 'carry on', 'casual', 'cavort', 'coltish', 'comic', 'comical'],
    'anticipate': ['announce', 'antecede', 'antedate', 'anticipation', 'apprehend', 'approach', 'avert', 'await', 'bar', 'be before', 'be destined', 'be early'],
    'anticipating': ['agape', 'agog', 'all agog', 'anticipant', 'anticipative', 'anticipatory', 'awaiting', 'big with child', 'big-laden', 'breeding', 'carrying', 'carrying a fetus'],
    'anticipation': ['tlc', 'a priori knowledge', 'anachronism', 'antecedence', 'antecedency', 'antedate', 'antedating', 'anteriority', 'apprehension', 'attention', 'beginnings', 'buddhi'],
    'anticipatory': ['agape', 'agog', 'all agog', 'antecedent', 'anterior', 'anticipant', 'anticipating', 'anticipative', 'atiptoe', 'awaiting', 'beforetime', 'bright and early'],
    'antidepressant': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'ataractic', 'diethyltryptamine', 'dimethyltryptamine', 'gage', 'ganja'],
    'antidote': ['alexipharmic', 'antacid', 'antiserum', 'antitoxin', 'antivenin', 'backfire', 'buffer', 'corrective', 'counteractant', 'counteractive', 'counteragent', 'counterirritant'],
    'antigen': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'acquired immunity', 'active immunity', 'agglutinin', 'allergen', 'anaphylactin', 'antiantibody', 'antibody'],
    'antihero': ['actor', 'antagonist', 'bit', 'bit part', 'cast', 'character', 'cue', 'fat part', 'feeder', 'heavy', 'hero', 'heroine'],
    'antinomy': ['ambiguity', 'ambivalence', 'asymmetry', 'disproportion', 'disproportionateness', 'equivocality', 'equivocation', 'heresy', 'heterodoxy', 'heterogeneity', 'incoherence', 'incommensurability'],
    'antipathetic': ['abhorrent', 'acrid', 'adversary', 'adversative', 'adverse', 'adversive', 'alien', 'antagonistic', 'anti', 'antipodal', 'antithetic', 'antithetical'],
    'antipathy': ['anglophobia', 'russophobia', 'abhorrence', 'abomination', 'allergy', 'anathema', 'animosity', 'animus', 'antagonism', 'anti-semitism', 'antithesis', 'averseness'],
    'antiphon': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'nunc dimittis', 'te deum', 'trisagion', 'vedic hymn'],
    'antipodal': ['antipodean', 'antithetic', 'antithetical', 'confronting', 'contradictory', 'contrapositive', 'contrary', 'converse', 'counter', 'diametric', 'diametrically opposite', 'eyeball-to-eyeball'],
    'antipodes': ['china', 'darkest africa', 'god knows where', 'greenland', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'siberia', 'south pole', 'thule', 'tierra del fuego'],
    'antipole': ['north pole', 'south pole', 'antipodal points', 'antipode', 'antipodes', 'antipoints', 'antipoles', 'antithesis', 'antonym', 'black and white', 'contra', 'contradictory'],
    'antiquarian': ['jonathan oldbuck', 'miniver cheevy', 'pre-raphaelite', 'antiquary', 'antique collector', 'antique dealer', 'antique-car collector', 'archaeological', 'archaeologist', 'archaist', 'classicist', 'dryasdust'],
    'antiquated': ['gothic', 'victorian', 'abandoned', 'abjured', 'ago', 'ancient', 'antediluvian', 'antique', 'archaic', 'blown over', 'by', 'bygone'],
    'antique': ['gothic', 'methuselah', 'victorian', 'abandoned', 'abiding', 'abjured', 'age-long', 'age-old', 'aged', 'ageless', 'ago', 'ancestral'],
    'antiquity': ['abidingness', 'aboriginality', 'age', 'ancien regime', 'ancient history', 'ancient manuscript', 'ancient times', 'ancientness', 'antique', 'archaism', 'artifact', 'atavism'],
    'antiseptic': ['argyrol', 'mercurochrome', 'merthiolate', 'salol', 'acaricide', 'alcohol', 'anthelmintic', 'antibiotic', 'aseptic', 'bactericide', 'boiled', 'boric acid'],
    'antisocial': ['timonistic', 'ascetic', 'austere', 'cold', 'cynical', 'eremitic', 'introverted', 'man-hating', 'misanthropic', 'misogynous', 'reclusive', 'remote'],
    'antithesis': ['antagonism', 'anteposition', 'antipathy', 'antipode', 'antipodes', 'antipole', 'antonym', 'clashing', 'collision', 'con', 'conflict', 'confrontation'],
    'antithetical': ['adversary', 'adversative', 'adverse', 'adversive', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antipodal', 'antipodean', 'antithetic', 'antonymous'],
    'antitoxin': ['rh factor', 'agglutinin', 'allergen', 'anaphylactin', 'antiantibody', 'antibody', 'antigen', 'antiserum', 'antitoxic serum', 'antivenin', 'bang', 'booster'],
    'antitype': ['antetype', 'archetype', 'biotype', 'classic example', 'criterion', 'epitome', 'fugleman', 'fugler', 'genotype', 'imitatee', 'lead', 'mirror'],
    'antonym': ['antipode', 'antipodes', 'antipole', 'antithesis', 'articulation', 'contra', 'converse', 'counter', 'counterbalance', 'countercheck', 'counterpoint', 'counterpoise'],
    'anus': ['abdomen', 'appendix', 'asshole', 'blind gut', 'bowels', 'brain', 'bung', 'bunghole', 'cecum', 'colon', 'duodenum', 'endocardium'],
    'anvil': ['eustachian tube', 'alembic', 'auditory apparatus', 'auditory canal', 'auditory meatus', 'auditory nerve', 'auditory ossicles', 'auditory tube', 'auricle', 'basilar membrane', 'bony labyrinth', 'caldron'],
    'anxiety': ['abstraction', 'abulia', 'ache', 'ado', 'alacrity', 'alienation', 'all-overs', 'angst', 'anguish', 'animation', 'annoyance', 'anxiety equivalent'],
    'anxious': ['aching', 'aghast', 'agitated', 'agog', 'alacritous', 'alarmed', 'all agog', 'all-overish', 'anguished', 'animated', 'annoyed', 'antsy'],
    'anxiously': ['animatedly', 'apprehensively', 'avidly', 'breathlessly', 'concernedly', 'eagerly', 'enthusiastically', 'fretfully', 'impatiently', 'intolerantly', 'keenly', 'misgivingly'],
    'any': ['a certain', 'all', 'all and some', 'all and sundry', 'an', 'any one', 'anybody', 'anyone', 'anything', 'atomic', 'aught', 'certain'],
    'any old way': ['airily', 'any which way', 'anyhow', 'bunglingly', 'carelessly', 'casually', 'clumsily', 'cursorily', 'disregardfully', 'forgetfully', 'haphazardly', 'heedlessly'],
    'anyhow': ['airily', 'any old way', 'any which way', 'anyway', 'anywise', 'at all', 'at any rate', 'at random', 'bunglingly', 'by any means', 'carelessly', 'casually'],
    'anytime': ['any day', 'any hour', 'any minute', 'any moment', 'any time', 'any time now', 'as may be', 'at all times', 'at any time', 'at whatever time', 'if ever', 'imminently'],
    'apace': ['pdq', 'amain', 'at flank speed', 'at once', 'by forced marches', 'cursorily', 'decisively', 'directly', 'double-quick', 'expeditiously', 'fast', 'feverishly'],
    'apart': ['a huis clos', 'adrift', 'alien', 'alienated', 'all to pieces', 'alone', 'aloof', 'apart from', 'aside', 'aside from', 'asunder', 'at a distance'],
    'apartheid': ['jim crow', 'jim crow law', 'alien', 'anti-semitism', 'apartness', 'black power', 'black supremacy', 'chauvinism', 'class consciousness', 'class distinction', 'class hatred', 'class prejudice'],
    'apathetic': ['laodicean', 'olympian', 'abeyant', 'affording no hope', 'aloof', 'anesthetic', 'ataractic', 'backward', 'balking', 'balky', 'benumbed', 'blah'],
    'apathy': ['laodiceanism', 'abeyance', 'abstraction', 'abulia', 'accidia', 'acedia', 'alienation', 'aloofness', 'anxiety', 'anxiety equivalent', 'anxiety state', 'ataraxia'],
    'ape': ['barbary ape', 'cape polecat', 'chiroptera', 'lagomorpha', 'primates', 'rodentia', 'act', 'act a part', 'act as', 'act out', 'angwantibo', 'anthropoid ape'],
    'apercu': ['a priori knowledge', 'abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'anticipation', 'article', 'brief', 'buddhi', 'capsule', 'causerie'],
    'aperitif': ['mickey', 'mickey finn', 'antepast', 'antipasto', 'appetizer', 'canape', 'chaser', 'cocktail', 'doch-an-dorrach', 'drink', 'eye-opener', 'foretaste'],
    'aperture': ['access', 'aisle', 'alley', 'ambulatory', 'arcade', 'artery', 'avenue', 'bore', 'breach', 'break', 'broaching', 'cavity'],
    'apex': ['olympian heights', 'achievement', 'acme', 'aerial heights', 'alveolar ridge', 'alveolus', 'angle', 'apogee', 'arytenoid cartilages', 'attainment', 'back', 'bend'],
    'aphasia': ['anaudia', 'aphonia', 'aphrasia', 'deaf-muteness', 'dumbness', 'dysarthria', 'dysphasia', 'echolalia', 'hysterical aphonia', 'imperfect speech', 'inarticulateness', 'incoherence'],
    'aphorism': ['abridgment', 'adage', 'ana', 'analects', 'apothegm', 'axiom', 'bon mot', 'boutade', 'bright idea', 'bright thought', 'brilliant idea', 'brocard'],
    'aphoristic': ['spartan', 'abbreviated', 'abridged', 'aposiopestic', 'axiomatic', 'brief', 'brusque', 'clipped', 'close', 'compact', 'compendious', 'compressed'],
    'aphrodite': ['adonis', 'agdistis', 'amor', 'apollo', 'apollo belvedere', 'apollon', 'ares', 'artemis', 'astarte', 'ate', 'athena', 'bacchus'],
    'apish': ['asinine', 'batty', 'befooled', 'beguiled', 'besotted', 'brainless', 'buffoonish', 'cockeyed', 'crazy', 'credulous', 'daffy', 'daft'],
    'aplenty': ['abounding', 'abundant', 'abundantly', 'affluent', 'affluently', 'all-sufficing', 'ample', 'bottomless', 'bottomlessly', 'bounteous', 'bounteously', 'bountiful'],
    'aplomb': ['assurance', 'balance', 'balanced personality', 'composure', 'confidence', 'constancy', 'constraint', 'control', 'cool', 'coolness', 'discipline', 'ease'],
    'apocalypse': ['actuarial prediction', 'afflatus', 'baring', 'direct communication', 'disclosing', 'disclosure', 'discovering', 'discovery', 'divine inspiration', 'divine revelation', 'envisioning', 'epiphany'],
    'apocalyptic': ['biblical', 'gospel', 'mosaic', 'new-testament', 'old-testament', 'apostolic', 'augural', 'auguring', 'bad', 'baleful', 'baneful', 'betraying'],
    'apocryphal': ['albigensian', 'arian', 'catharist', 'donatist', 'ebionitist', 'erastian', 'gnostic', 'jansenist', 'jansenistic', 'jovinianist', 'jovinianistic', 'lollard'],
    'apogee': ['earth insertion', 'lem', 'lm', 'acme', 'all', 'apex', 'aphelion', 'astronomical longitude', 'attitude-control rocket', 'autumnal equinox', 'ballistic capsule', 'brow'],
    'apollo': ['atda', 'ats', 'adonis', 'agdistis', 'alouette', 'amen-ra', 'amor', 'anna', 'aphrodite', 'apollo belvedere', 'apollo musagetes', 'apollon'],
    'apologetic': ['abject', 'apologia', 'ascetic', 'atoning', 'cleansing', 'compensational', 'compensatory', 'compunctious', 'conscience-stricken', 'contrite', 'defense', 'excusatory'],
    'apologetics': ['buddhology', 'mariolatry', 'mariology', 'mercersburg theology', 'apologia', 'apology', 'argument', 'argumentation', 'bicker', 'bickering', 'canonics', 'casuistry'],
    'apologia': ['apologetic', 'apologetics', 'apology', 'argument', 'argumentation', 'bicker', 'bickering', 'casuistry', 'clarification', 'contention', 'controversy', 'defense'],
    'apologist': ['maecenas', 'philadelphia lawyer', 'abettor', 'admirer', 'advocate', 'aficionado', 'angel', 'apologete', 'apologizer', 'arguer', 'argufier', 'backer'],
    'apologize': ['alibi', 'alibi out of', 'apologize for', 'ask forgiveness', 'beg indulgence', 'beg pardon', 'cover with excuses', 'defend', 'do penance', 'espouse', 'excuse', 'express regret'],
    'apology': ['abject apology', 'acknowledgment', 'admission', 'advocating', 'advocation', 'alibi', 'amends', 'apologetic', 'apologetics', 'apologia', 'apologies', 'argument'],
    'apoplexy': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'akinetic epilepsy', 'angina', 'angina pectoris', 'aortic insufficiency', 'aortic stenosis'],
    'apostasy': ['evangelicalism', 'protestantism', 'reform', 'zwinglianism', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'agreement to disagree', 'alienation', 'alteration', 'amelioration'],
    'apostate': ['sabbath-breaker', 'atheist', 'atheistic', 'backslider', 'backsliding', 'blasphemer', 'blasphemous', 'bolter', 'collaborationist', 'collaborative', 'collaborator', 'convert'],
    'apostatize': ['apostacize', 'betray', 'bolt', 'break away', 'change sides', 'defect', 'degenerate', 'desert', 'fall away', 'fall off', 'go over', 'let down'],
    'apostle': ['aaronic priesthood', 'ambrose of milan', 'athanasius', 'barnabas', 'basil', 'clement of alexandria', 'clement of rome', 'cyprian of carthage', 'cyril of jerusalem', 'gregory of nyssa', 'hermas', 'ignatius'],
    'apostolic': ['biblical', 'gospel', 'mosaic', 'new-testament', 'old-testament', 'apocalyptic', 'canonical', 'evangelic', 'evangelistic', 'gospel', 'inspired', 'papal'],
    'apothecary': ['antique store', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'chemist', 'cigar store', 'clothiers', 'clothing store', 'confectionery', 'dispenser', 'dress shop'],
    'apothegm': ['adage', 'ana', 'analects', 'aphorism', 'axiom', 'bon mot', 'boutade', 'bright idea', 'bright thought', 'brilliant idea', 'brocard', 'byword'],
    'apotheosis': ['accolade', 'acme', 'admiration', 'adoration', 'adulation', 'aggrandizement', 'appreciation', 'approbation', 'approval', 'ascension', 'ascent', 'assumption'],
    'appall': ['abash', 'astound', 'awe', 'confound', 'daunt', 'discomfit', 'disconcert', 'disgust', 'dismay', 'faze', 'freeze', 'give offense'],
    'appalling': ['astonishing', 'astounding', 'atrocious', 'awe-inspiring', 'awesome', 'awful', 'baneful', 'beastly', 'bewildering', 'confounding', 'conspicuous', 'daunting'],
    'appanage': ['accession', 'accessories', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct'],
    'apparatus': ['bunsen burner', 'erlenmeyer flask', 'kipp generator', 'accouterments', 'alembic', 'appliance', 'appliances', 'appointments', 'appurtenances', 'armament', 'aspirator', 'bag and baggage'],
    'apparel': ['appoint', 'array', 'attire', 'bedizenment', 'clad', 'clothes', 'clothing', 'costume', 'drapery', 'dress', 'dressing', 'duds'],
    'apparent': ['barmecidal', 'barmecide', 'airy', 'apparitional', 'appearing', 'autistic', 'beholdable', 'chimeric', 'clear', 'clear as crystal', 'colorable', 'colored'],
    'apparently': ['artificially', 'as it seems', 'at first sight', 'clearly', 'conspicuously', 'definitely', 'discernibly', 'distinctly', 'erroneously', 'evidently', 'explicitly', 'expressly'],
    'apparition': ['masan', 'appearance', 'appearing', 'arising', 'astral', 'astral spirit', 'avatar', 'banshee', 'bogey', 'brainchild', 'bubble', 'chimera'],
    'appeal': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'acceptability', 'adjuration', 'adjure', 'adorability', 'agacerie', 'agreeability'],
    'appeal to': ['accost', 'address', 'adjure', 'apostrophize', 'appeal', 'approach', 'ask', 'ask for', 'beg', 'beseech', 'bespeak', 'blackmail'],
    'appealing': ['achingly sweet', 'adjuratory', 'agreeable', 'agreeable-sounding', 'alluring', 'appetizing', 'ariose', 'arioso', 'attracting', 'attractive', 'begging', 'beguiling'],
    'appear': ['act', 'act as foil', 'appear like', 'approach', 'arise', 'arrive', 'assister', 'attend', 'barnstorm', 'be at', 'be evident', 'be noticeable'],
    'appearance': ['christophany', 'masan', 'prospero', 'satanophany', 'accomplishment', 'achievement', 'acting', 'advent', 'affectation', 'air', 'airiness', 'angelophany'],
    'appease': ['abate', 'allay', 'alleviate', 'anesthetize', 'assuage', 'benumb', 'calm', 'calm down', 'cater to', 'coddle', 'compose', 'conciliate'],
    'appeasement': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'united nations troops', 'abatement', 'allayment', 'alleviation', 'analgesia', 'anesthesia', 'anesthetizing', 'assuagement'],
    'appellation': ['appellative', 'baptism', 'binomen', 'binomial name', 'byword', 'calling', 'christening', 'cognomen', 'cryptonym', 'definition', 'denomination', 'designation'],
    'append': ['add', 'adjoin', 'affix', 'agglutinate', 'annex', 'attach', 'burden', 'complicate', 'conjoin', 'decorate', 'encumber', 'glue on'],
    'appendage': ['accession', 'accessories', 'accessory', 'accident', 'accidental', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory'],
    'appendectomy': ['adenoidectomy', 'arteriectomy', 'castration', 'cholecystectomy', 'craniectomy', 'cricoidectomy', 'cystectomy', 'enterectomy', 'gastrectomy', 'hemorrhoidectomy', 'hysterectomy', 'mammectomy'],
    'appendicitis': ['adenoiditis', 'adrenitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis', 'bunion'],
    'appendix': ['ps', 'parthian shot', 'abdomen', 'accessory', 'addendum', 'adjunct', 'affix', 'afterthought', 'allonge', 'anus', 'appurtenance', 'back matter'],
    'appertain to': ['affect', 'answer to', 'apply to', 'bear on', 'bear upon', 'belong to', 'concern', 'connect', 'correspond to', 'deal with', 'have connection with', 'interest'],
    'appertaining': ['a propos', 'ad rem', 'admissible', 'affinitive', 'applicable', 'applying', 'apposite', 'appropriate', 'apropos', 'associative', 'belonging', 'comparable'],
    'appetite': ['cyrenaic hedonism', 'cyrenaicism', 'alacrity', 'an universal wolf', 'animation', 'animus', 'anxiety', 'anxiousness', 'appetence', 'appetency', 'appetition', 'appetitiveness'],
    'appetizing': ['acceptable', 'adorable', 'agreeable', 'alluring', 'appealing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching'],
    'applaud': ['abide by', 'accede', 'accept', 'acclaim', 'acquiesce', 'acquiesce in', 'agree', 'agree to', 'agree with', 'approve', 'assent', 'boost'],
    'applause': ['acclaim', 'acclamation', 'alleluia', 'approbation', 'approval', 'big hand', 'burst of applause', 'cheer', 'cheering', 'cheers', 'chorus of cheers', 'clap'],
    'apple polisher': ['ass-licker', 'backscratcher', 'backslapper', 'bootlick', 'bootlicker', 'brown-nose', 'brownie', 'clawback', 'courtier', 'creature', 'cringer', 'dupe'],
    'apple polishing': ['ass-kissing', 'backscratching', 'bootlicking', 'brown-nosing', 'cringing', 'fawnery', 'fawning', 'flunkyism', 'footlicking', 'groveling', 'handshaking', 'ingratiation'],
    'appliance': ['charlie mccarthy', 'accommodation', 'accouterments', 'active use', 'advantage', 'agent', 'amenity', 'ancilla', 'apparatus', 'appliances', 'application', 'appointments'],
    'applicable': ['a propos', 'actionable', 'ad rem', 'adapted', 'admissible', 'appertaining', 'appliable', 'applying', 'apposite', 'appropriate', 'apropos', 'apt'],
    'application': ['ace bandage', 'band-aid', 'absorbed attention', 'absorption', 'accounting for', 'active use', 'address', 'adhesive tape', 'administration', 'answerability', 'appeal', 'appliance'],
    'applique': ['baste', 'bind', 'buttonhole', 'crochet', 'cross-stitch', 'embroider', 'fell', 'flap', 'fly', 'gather', 'imbrication', 'knit'],
    'apply': ['accouter', 'accredit', 'address', 'administer', 'affix', 'allot', 'ally', 'appeal', 'appertain', 'apply for', 'apply to', 'appoint'],
    'appoint': ['accouter', 'allocate', 'allot', 'appropriate to', 'arm', 'arrange', 'assign', 'assign to', 'authorize', 'choose', 'commission', 'decorate'],
    'appointment': ['accession', 'allocation', 'allotment', 'anointing', 'anointment', 'apostolic orders', 'appropriation', 'arrangement', 'arrogation', 'assignation', 'assignment', 'assumption'],
    'appointments': ['accessories', 'accouterments', 'appanages', 'apparatus', 'appendages', 'appliances', 'appurtenances', 'armament', 'belongings', 'choses', 'choses in action', 'choses in possession'],
    'apportion': ['accord', 'align', 'allocate', 'allot', 'array', 'assign', 'award', 'be partners in', 'bestow', 'carve', 'carve up', 'collocate'],
    'apposite': ['a propos', 'ad rem', 'adapted', 'admissible', 'appertaining', 'applicable', 'applying', 'appropriate', 'apropos', 'apt', 'becoming', 'befitting'],
    'appraisal': ['analyzing', 'appraisement', 'appraising', 'appreciation', 'apprizal', 'approximation', 'assessing', 'assessment', 'assize', 'assizement', 'calculation', 'categorization'],
    'appraise': ['adjudge', 'appreciate', 'assay', 'assess', 'audit', 'calculate', 'calibrate', 'caliper', 'call', 'catalog', 'categorize', 'check a parameter'],
    'appreciable': ['apparent', 'appraisable', 'apprehensible', 'ascertainable', 'assessable', 'calculable', 'clear', 'cognizable', 'comprehensible', 'computable', 'conceivable', 'concrete'],
    'appreciably': ['after a fashion', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst', 'comparatively', 'detectably', 'fairly'],
    'appreciate': ['absorb', 'accord respect to', 'accrue', 'accumulate', 'admire', 'adore', 'advance', 'apotheosize', 'appraise', 'apprehend', 'apprize', 'ascribe importance to'],
    'appreciation': ['acceptance', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'acknowledgment', 'addition', 'admiration', 'admission', 'adoration'],
    'appreciative': ['acclamatory', 'accurate', 'acknowledging', 'admiring', 'alive to', 'appreciative of', 'apprised of', 'approbatory', 'awake to', 'aware of', 'behind the curtain', 'behind the scenes'],
    'apprehend': ['absorb', 'accept', 'anticipate', 'appreciate', 'arrest', 'assimilate', 'be acquainted with', 'be afraid', 'be apprised of', 'be aware of', 'be cognizant of', 'be conscious of'],
    'apprehension': ['iq', 'pyrrhonism', 'abduction', 'agitation', 'alarm', 'all-overs', 'angst', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern'],
    'apprehensive': ['afraid', 'agitated', 'alive', 'all nerves', 'all-knowing', 'all-overish', 'anxious', 'anxioused up', 'apperceptive', 'appercipient', 'apprehending', 'awake'],
    'apprentice': ['abecedarian', 'alphabetarian', 'amateur', 'ancestors', 'apprenticed', 'architect', 'article', 'articled', 'articled clerk', 'artificer', 'artisan', 'artist'],
    'apprenticeship': ['basic training', 'binding over', 'breaking', 'breeding', 'conditioning', 'cultivation', 'development', 'discipline', 'drill', 'drilling', 'exercise', 'fetching-up'],
    'apprise': ['acquaint', 'advertise', 'advertise of', 'advise', 'announce', 'brief', 'bring word', 'clue', 'communicate', 'declare', 'disclose', 'discover'],
    'apprised of': ['alive to', 'appreciative of', 'awake to', 'aware of', 'behind the curtain', 'behind the scenes', 'cognizant of', 'conscious of', 'hep to', 'in the know', 'in the secret', 'informed of'],
    'approach': ['mo', 'access', 'accomplish', 'accomplishment', 'accordance', 'accost', 'achieve', 'achievement', 'act on', 'address', 'adit', 'advance'],
    'approachable': ['accessible', 'attainable', 'available', 'bribable', 'buyable', 'candid', 'come-at-able', 'communicative', 'conversable', 'corrupt', 'corruptible', 'demonstrative'],
    'approaching': ['about to be', 'advancing', 'already in sight', 'approximate', 'approximating', 'approximative', 'arm-in-arm', 'arriving', 'asymptotic', 'at hand', 'attracted to', 'brewing'],
    'approbation': ['john hancock', 'ok', 'acceptance', 'accord', 'account', 'acquiescence', 'adherence', 'admiration', 'adoration', 'affirmance', 'affirmation', 'affirmative'],
    'appropriate': ['a propos', 'absorb', 'abstract', 'acceptable', 'according to hoyle', 'accroach', 'ad rem', 'adapted', 'admissible', 'adopt', 'advantageous', 'advisable'],
    'appropriateness': ['account', 'advantage', 'aid', 'allotment', 'allowance', 'applicability', 'appositeness', 'appropriation', 'aptness', 'assistance', 'expediency', 'fitness'],
    'appropriation': ['abstraction', 'adoption', 'allocation', 'allotment', 'annexation', 'appointment', 'arrogation', 'assignment', 'assumption', 'autoplagiarism', 'boosting', 'borrowed plumes'],
    'approval': ['john hancock', 'ok', 'acceptance', 'accord', 'account', 'acquiescence', 'admiration', 'adoration', 'affirmance', 'affirmation', 'affirmative', 'affirmative voice'],
    'approve': ['ok', 'accede to', 'accept', 'accord to', 'accredit', 'admire', 'adopt', 'affiliate', 'affirm', 'agree to', 'allow', 'amen'],
    'approved': ['christian', 'accepted', 'acclaimed', 'acknowledged', 'admired', 'admitted', 'adopted', 'advocated', 'affirmed', 'allowed', 'applauded', 'appointed'],
    'approximate': ['accost', 'advance', 'advancing', 'ape', 'appear like', 'approach', 'approaching', 'appropinquate', 'approximating', 'approximative', 'arm-in-arm', 'assimilate'],
    'approximately': ['about', 'all but', 'all in all', 'almost', 'almost entirely', 'approaching', 'approximatively', 'around', 'by and large', 'chiefly', 'circa', 'close to'],
    'approximation': ['access', 'accession', 'accord', 'accordance', 'addition', 'adjunct', 'advance', 'advent', 'affairs', 'affiliation', 'affinity', 'afflux'],
    'appurtenance': ['accession', 'accessory', 'accident', 'accidental', 'accommodation', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory'],
    'appurtenances': ['accessories', 'accouterments', 'appanages', 'apparatus', 'appendages', 'appliances', 'appointments', 'armament', 'belongings', 'choses', 'choses in action', 'choses in possession'],
    'apron': ['acting area', 'airstrip', 'apron stage', 'backstage', 'band shell', 'bandstand', 'bib', 'board', 'bridge', 'clearway', 'coulisse', 'dock'],
    'apropos': ['a propos', 'about', 'ad rem', 'adapted', 'admissible', 'against', 'anent', 'appertaining', 'applicable', 'applying', 'apposite', 'appropriate'],
    'apse': ['easter sepulcher', 'ambry', 'arcade', 'arcature', 'arch', 'arched roof', 'archway', 'baptistery', 'blindstory', 'camber', 'ceilinged roof', 'chancel'],
    'apt': ['daedalian', 'a propos', 'ad rem', 'adapted', 'adept', 'adroit', 'alert', 'applicable', 'apposite', 'appropriate', 'apropos', 'artistic'],
    'apt to': ['answerable for', 'calculated to', 'capable of', 'dependent on', 'disposed to', 'exposed to', 'given to', 'in danger of', 'incident to', 'inclined to', 'liable to', 'likely to'],
    'aptitude': ['a thing for', 'ability', 'acuity', 'acuteness', 'admissibility', 'adroitness', 'affinity', 'an ear for', 'an eye for', 'animus', 'applicability', 'appositeness'],
    'aptitude test': ['binet-simon test', 'brown personality inventory', 'goldstein-sheerer test', 'iq', 'iq test', 'kent mental test', 'minnesota preschool scale', 'oseretsky test', 'rorschach test', 'stanford revision', 'stanford-binet test', 'szondi test'],
    'aptness': ['appositeness', 'appropriateness', 'bent', 'bump', 'expediency', 'faculty', 'fitness', 'flair', 'genius', 'head', 'helpfulness', 'knack'],
    'aqua lung': ['air cylinder', 'aquascope', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'bathyscaphe', 'bathysphere', 'benthoscope', 'breath', 'breath of air', 'breathing', 'broken wind'],
    'aquarium': ['festschrift', 'ana', 'anthology', 'body', 'chrestomathy', 'collectanea', 'collection', 'compilation', 'corpus', 'data', 'fishpond', 'florilegium'],
    'aquatic': ['aqueous', 'balneal', 'deep-sea', 'estuarine', 'grallatorial', 'hydrated', 'hydraulic', 'hydrous', 'liquid', 'littoral', 'natant', 'natatorial'],
    'aquatint': ['autolithograph', 'block', 'block print', 'cerography', 'chalcography', 'chromolithograph', 'color print', 'copperplate', 'copperplate print', 'crayon engraving', 'cribbling', 'cut'],
    'aqueduct': ['arroyo', 'bed', 'canal', 'canalization', 'channel', 'conduit', 'course', 'creek bed', 'crimp', 'culvert', 'cut', 'dike'],
    'aquiculture': ['algology', 'bathymetry', 'botany', 'bryology', 'dendrology', 'fungology', 'hydrography', 'hydroponics', 'marine biology', 'mycology', 'oceanography', 'paleobotany'],
    'aquiline': ['roman-nosed', 'altricial', 'anserine', 'anserous', 'aquiline-nosed', 'avian', 'avicular', 'beak-nosed', 'beak-shaped', 'beaked', 'bill-like', 'bill-shaped'],
    'arab': ['bedouin', 'bohemian', 'romany', 'zigeuner', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'dogie', 'gamin'],
    'arabesque': ['acciaccatura', 'appoggiatura', 'baroque', 'baroqueness', 'basketry', 'basketwork', 'cadence', 'cadenza', 'cancellation', 'chinoiserie', 'coloratura', 'cross-hatching'],
    'arbiter': ['jp', 'justice', 'amateur', 'arbiter elegantiarum', 'arbiter of taste', 'arbitrator', 'authority', 'bencher', 'bon vivant', 'cognoscente', 'collector', 'connaisseur'],
    'arbitrary': ['absolute', 'absolutist', 'absolutistic', 'aristocratic', 'arrogant', 'autarchic', 'authoritarian', 'authoritative', 'autocratic', 'autonomous', 'bossy', 'capricious'],
    'arbitrate': ['act between', 'adjudge', 'adjudicate', 'appease', 'bargain', 'go between', 'hear', 'hold court', 'hold the scales', 'intercede', 'intermediate', 'interpose'],
    'arbitrator': ['jp', 'justice', 'arbiter', 'bencher', 'broker', 'connection', 'contact', 'critic', 'go-between', 'his honor', 'his lordship', 'his worship'],
    'arbor': ['alcove', 'axis', 'axle', 'axle bar', 'axle shaft', 'axle spindle', 'axle-tree', 'belvedere', 'bower', 'casino', 'conservatory', 'distaff'],
    'arboreal': ['v-shaped', 'y-shaped', 'arborary', 'arboreous', 'arborescent', 'arboresque', 'arborical', 'arboriform', 'biforked', 'bifurcate', 'bifurcated', 'branched'],
    'arboretum': ['japanese garden', 'afforestation', 'alpine garden', 'bed', 'bog garden', 'boondocks', 'border', 'botanical garden', 'bush', 'bushveld', 'chase', 'climax forest'],
    'arc': ['ac arc', 'poulsen arc', 'aperiodic discharge', 'arc column', 'arc discharge', 'arc light', 'arch', 'bend', 'bow', 'brush discharge', 'catacaustic', 'catenary'],
    'arcade': ['access', 'aisle', 'alley', 'ambulatory', 'aperture', 'apse', 'arcature', 'arch', 'arched roof', 'archway', 'areaway', 'artery'],
    'arcadian': ['edenic', 'agrarian', 'agrestic', 'agricultural', 'bucolic', 'celestial', 'country', 'farm', 'genuine', 'heavenly', 'homespun', 'ideal'],
    'arcane': ['abstract', 'abstruse', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'cryptic', 'dark', 'deep', 'eerie'],
    'arch': ['machiavellian', 'machiavellic', 'acute', 'apse', 'arc', 'arcade', 'arcature', 'arch over', 'arched roof', 'archway', 'artful', 'astute'],
    'archaic': ['gothic', 'victorian', 'abandoned', 'abjured', 'antediluvian', 'antiquated', 'antique', 'behind the times', 'bygone', 'classical', 'dated', 'deserted'],
    'archaism': ['pre-raphaelitism', 'ancient manuscript', 'antiquarianism', 'antique', 'antiquity', 'archaeology', 'archaicism', 'artifact', 'cave painting', 'classicism', 'eolith', 'fossil'],
    'archangel': ['angel', 'angel of light', 'angel of love', 'angelology', 'angels', 'archangels', 'beatified soul', 'canonized mortal', 'celestial', 'cherub', 'cherubim', 'dominations'],
    'archbishop': ['grand penitentiary', 'holy father', 'abuna', 'antipope', 'archdeacon', 'archpriest', 'bishop', 'bishop coadjutor', 'canon', 'cardinal', 'cardinal bishop', 'cardinal deacon'],
    'archbishopric': ['kreis', 'abbacy', 'aedileship', 'archdeaconry', 'archdiocese', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'arrondissement', 'bailiwick', 'bishopdom', 'bishopric'],
    'arched': ['arciform', 'arclike', 'arcual', 'bandy', 'bent', 'bowed', 'bowlike', 'concave', 'convex', 'convexed', 'curvilinear', 'embowed'],
    'archer': ['nimrod', 'amateur athlete', 'artilleryman', 'athlete', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'blocking back', 'bowman', 'cannoneer'],
    'archery': ['artillery', 'ballistics', 'casting', 'chucking', 'firing', 'flinging', 'gunnery', 'heaving', 'hurling', 'jaculation', 'lobbing', 'missilery'],
    'archetype': ['geistesgeschichte', 'hegelian idea', 'kantian idea', 'platonic form', 'platonic idea', 'aesthetic form', 'antetype', 'antitype', 'archetypal pattern', 'art form', 'beau ideal', 'biotype'],
    'archetypical': ['antitypic', 'archetypal', 'archetypic', 'classic', 'consummate', 'developed', 'exemplary', 'expert', 'finished', 'fully developed', 'masterful', 'masterly'],
    'archipelago': ['ait', 'atoll', 'bar', 'cay', 'continental island', 'coral head', 'coral island', 'coral reef', 'holm', 'insularity', 'island', 'island group'],
    'architect': ['actor', 'agent', 'ancestors', 'apprentice', 'artificer', 'artist', 'author', 'begetter', 'beginner', 'builder', 'civil architect', 'conceiver'],
    'architectural': ['byzantine', 'corinthian', 'doric', 'gothic', 'greek', 'ionic', 'moorish', 'romanesque', 'tuscan', 'anatomic', 'architectonic', 'building'],
    'architecture': ['bauhaus', 'byzantine', 'egyptian', 'english', 'french', 'german', 'gothic', 'greco-roman', 'greek', 'greek revival', 'italian', 'persian'],
    'archives': ['indian reservation', 'ana', 'armory', 'arsenal', 'athenaeum', 'attic', 'bank', 'basement', 'bay', 'bin', 'biographical material', 'biographical records'],
    'archivist': ['accountant', 'amanuensis', 'bookkeeper', 'clerk', 'documentalist', 'engraver', 'filing clerk', 'librarian', 'marker', 'notary', 'notary public', 'prothonotary'],
    'archway': ['french door', 'apse', 'arcade', 'arcature', 'arch', 'arched roof', 'back door', 'barway', 'bulkhead', 'camber', 'carriage entrance', 'ceilinged roof'],
    'arctic': ['siberian', 'aestival', 'affectless', 'algid', 'anesthetized', 'antarctic', 'austral', 'autistic', 'autumn', 'autumnal', 'below zero', 'biting'],
    'ardent': ['abandoned', 'ablaze', 'acquiescent', 'afire', 'aflame', 'aflicker', 'aglow', 'agog', 'agreeable', 'alacritous', 'alcoholic', 'alight'],
    'ardor': ['amor', 'christian love', 'eros', 'platonic love', 'abandon', 'acquiescence', 'activity', 'admiration', 'adoration', 'affection', 'agape', 'agreeability'],
    'arduous': ['herculean', 'abrupt', 'abstruse', 'backbreaking', 'brutal', 'burdensome', 'complex', 'critical', 'crushing', 'delicate', 'demanding', 'difficile'],
    'area': ['abode', 'academic discipline', 'academic specialty', 'acreage', 'airspace', 'amplitude', 'applied science', 'arena', 'arrondissement', 'art', 'bag', 'bailiwick'],
    'arena': ['academic discipline', 'academic specialty', 'ambit', 'amphitheater', 'applied science', 'area', 'art', 'assembly hall', 'auditorium', 'back', 'backdrop', 'background'],
    'areola': ['annular muscle', 'annulus', 'aureole', 'chaplet', 'circle', 'circuit', 'circumference', 'circus', 'closed circle', 'corona', 'coronet', 'crown'],
    'ares': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'artemis', 'ate', 'athena', 'bacchus', 'bellona', 'ceres', 'cora'],
    'argosy': ['naval construction battalion', 'rn', 'royal navy', 'seabees', 'usn', 'united states navy', 'armada', 'bark', 'boat', 'bottom', 'bottoms', 'bucket'],
    'argot': ['aesopian language', 'babel', 'greek', 'babble', 'cant', 'cipher', 'code', 'cryptogram', 'double dutch', 'garble', 'gibberish', 'gift of tongues'],
    'arguable': ['at issue', 'confutable', 'conjectural', 'contestable', 'controversial', 'controvertible', 'debatable', 'deniable', 'disputable', 'doubtable', 'doubtful', 'dubious'],
    'argue': ['affirm', 'agitate', 'allege', 'altercate', 'analyze', 'announce', 'annunciate', 'approve', 'argufy', 'assert', 'assever', 'asseverate'],
    'argument': ['kilkenny cats', 'action', 'addend', 'affray', 'altercation', 'anagnorisis', 'angle', 'answer', 'antilogarithm', 'apologetics', 'apologia', 'apology'],
    'argumentative': ['argumental', 'belligerent', 'cat-and-dog', 'cat-and-doggish', 'combative', 'contentious', 'controversial', 'dialectic', 'disagreeable', 'disputatious', 'eristic', 'ill-humored'],
    'aria': ['air', 'aria buffa', 'aria cantabile', 'aria da capo', 'aria da chiesa', 'aria di bravura', 'aria di coloratura', 'aria fugata', 'aria parlante', 'arietta', 'arioso', 'bravura'],
    'arid': ['saharan', 'academic', 'acarpous', 'anhydrous', 'athirst', 'barren', 'blah', 'blank', 'bloodless', 'bone-dry', 'bookish', 'boring'],
    'ariel': ['befind', 'corrigan', 'finnbeara', 'mab', 'oberon', 'titania', 'banshee', 'brownie', 'cluricaune', 'dwarf', 'elf', 'fairy'],
    'arise': ['accrue from', 'appear', 'approach', 'arise from', 'ascend', 'aspire', 'awake', 'bail out', 'be born', 'be contingent on', 'be due to', 'become'],
    'aristocracy': ['ffvs', 'absolute monarchy', 'aedileship', 'ancestry', 'ancienne noblesse', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocraticalness', 'autarchy', 'autocracy', 'autonomy'],
    'aristocrat': ['brahman', 'archduke', 'armiger', 'baron', 'baronet', 'blue blood', 'count', 'daimio', 'duke', 'earl', 'esquire', 'gentleman'],
    'aristocratic': ['absolute', 'absolutist', 'absolutistic', 'arbitrary', 'arrogant', 'august', 'authoritarian', 'authoritative', 'autocratic', 'autonomous', 'bossy', 'bureaucratic'],
    'arithmetic': ['boolean algebra', 'euclidean geometry', 'fourier analysis', 'lagrangian function', 'algebra', 'algebraic geometry', 'analysis', 'analytic geometry', 'associative algebra', 'binary arithmetic', 'calculation', 'calculus'],
    'arithmetical': ['algebraic', 'algorismic', 'algorithmic', 'aliquot', 'analytic', 'cardinal', 'decimal', 'differential', 'digital', 'even', 'exponential', 'figural'],
    'ark': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'asperger', 'asperges', 'aspergillum', 'bambino', 'beadroll', 'beads'],
    'arm': ['accouter', 'advocate', 'affiliate', 'alpenstock', 'appendage', 'appoint', 'armlet', 'armor', 'armor-plate', 'athletic supporter', 'authorize', 'back'],
    'arm in arm': ['affably', 'agreeably', 'amiably', 'amicably', 'approaching', 'approximate', 'approximating', 'ardently', 'arm-in-arm', 'burning', 'cheek by jowl', 'cheek-by-jowl'],
    'armada': ['naval construction battalion', 'rn', 'royal navy', 'seabees', 'usn', 'united states navy', 'argosy', 'coast guard', 'division', 'escadrille', 'fleet', 'flotilla'],
    'armadillo': ['angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'indian buffalo', 'kodiak bear', 'virginia deer', 'aardvark', 'aardwolf', 'alpaca', 'anteater', 'antelope'],
    'armament': ['a-weapons', 'accouterment', 'accouterments', 'aegis', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armor', 'arms', 'biological weapons', 'catering'],
    'armed': ['accoutered', 'all ready', 'all set', 'armed and ready', 'arrayed', 'battled', 'booted and spurred', 'briefed', 'bristling with arms', 'carrying', 'catered', 'cloaked'],
    'armed force': ['armed service', 'army', 'array', 'career soldiers', 'fighting machine', 'forces', 'ground forces', 'ground troops', 'host', 'legions', 'military establishment', 'occupation force'],
    'armistice': ['pax dei', 'pax romana', 'peace of god', 'breathing spell', 'buffer zone', 'cease-fire', 'cooling-off period', 'demilitarized zone', 'hollow truce', 'modus vivendi', 'neutral territory', 'pacification'],
    'armor': ['philistinism', 'aegis', 'armament', 'armature', 'armor plate', 'bard', 'beaver', 'body armor', 'brassard', 'breastplate', 'buckler', 'bulletproof vest'],
    'armored': ['armed cap-a-pie', 'armor-plated', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'coped', 'covered', 'covert', 'cowled', 'curtained'],
    'armory': ['achievement', 'alerion', 'ammo dump', 'animal charge', 'annulet', 'archives', 'argent', 'armorial bearings', 'arms', 'arsenal', 'artillery park', 'assembly line'],
    'arms': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'art of war', 'azure', 'bandeau', 'bar', 'bar sinister'],
    'army': ['kp', 'a mass of', 'a world of', 'armed force', 'armed service', 'army group', 'array', 'battalion', 'battery', 'battle group', 'bevy', 'brigade'],
    'aroma': ['atmosphere', 'attribute', 'aura', 'badge', 'balm', 'balminess', 'bouquet', 'brand', 'breath', 'cachet', 'cast', 'character'],
    'aromatic': ['ambrosial', 'balmy', 'effluvious', 'essenced', 'flowery', 'fragrant', 'fruity', 'incense-breathing', 'malodorous', 'musky', 'odorant', 'odorate'],
    'around': ['about', 'again', 'alive', 'all about', 'all over', 'all round', 'all through', 'almost', 'along toward', 'anticlockwise', 'any which way', 'anyhow'],
    'arousal': ['a high', 'aggravation', 'agitation', 'animation', 'arousing', 'awakening', 'bringing out', 'calling forth', 'drawing out', 'eduction', 'electrification', 'emotion'],
    'arouse': ['aggravate', 'agitate', 'alarm', 'alert', 'anger', 'animate', 'annoy', 'awake', 'awaken', 'bestir', 'blow the coals', 'blow up'],
    'aroused': ['agog', 'alarmed', 'alerted', 'aquiver', 'atingle', 'atwitter', 'bursting', 'carried away', 'ebullient', 'effervescent', 'excited', 'exhilarated'],
    'arousing': ['aggravation', 'agitation', 'animation', 'aphrodisiac', 'aphroditous', 'arousal', 'educible', 'eductive', 'electrification', 'elicitory', 'eradicative', 'eroticizing'],
    'arraign': ['accuse', 'allege', 'anathematize', 'anathemize', 'animadvert on', 'article', 'blame', 'book', 'bring accusation', 'bring charges', 'bring to book', 'call to account'],
    'arraignment': ['accusal', 'accusation', 'accusing', 'allegation', 'allegement', 'anathema', 'bail', 'bill of particulars', 'blame', 'bringing of charges', 'bringing to book', 'castigation'],
    'arrange': ['accommodate', 'adapt', 'adjust', 'align', 'alphabetize', 'analyze', 'array', 'assort', 'blend', 'blueprint', 'break down', 'bring about'],
    'arranged': ['agreed', 'aligned', 'arrayed', 'assorted', 'blueprinted', 'businesslike', 'calculated', 'categorized', 'charted', 'classified', 'compacted', 'composed'],
    'arrangement': ['nachtmusik', 'abatement of differences', 'absolute music', 'accommodation', 'accord', 'adaptation', 'adjunct', 'adjustment', 'adornment', 'affair', 'agreement', 'air varie'],
    'arrant': ['abject', 'abominable', 'absolute', 'atrocious', 'awful', 'bad', 'barefaced', 'base', 'beastly', 'beggarly', 'beneath contempt', 'black'],
    'array': ['indian file', 'adduce', 'adorn', 'advance', 'align', 'allege', 'allocate', 'allocation', 'allot', 'allotment', 'apparel', 'apportion'],
    'arrayed': ['aligned', 'appareled', 'armed', 'arranged', 'assorted', 'attired', 'battled', 'bedecked', 'breeched', 'capped', 'categorized', 'chausse'],
    'arrearage': ['arrear', 'arrears', 'back debts', 'back payments', 'bouncing check', 'break', 'debt', 'decline', 'defalcation', 'default', 'defect', 'defectiveness'],
    'arrears': ['arrear', 'arrearage', 'back debts', 'back payments', 'bouncing check', 'decline', 'defalcation', 'default', 'defectiveness', 'deferred payments', 'deficit', 'deficit financing'],
    'arrest': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'abduction', 'absorb', 'absorb the attention', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'akinetic epilepsy', 'apoplexy'],
    'arrested': ['babbling', 'back', 'backward', 'behind', 'behindhand', 'belated', 'blithering', 'blocked', 'bridled', 'burbling', 'callow', 'caught'],
    'arrested development': ['freudian fixation', 'amentia', 'backwardness', 'blithering idiocy', 'cretinism', 'father fixation', 'fixation', 'half-wittedness', 'idiocy', 'idiotism', 'imbecility', 'infantile fixation'],
    'arresting': ['affective', 'appealing', 'apprehension', 'arrestation', 'arrestment', 'attractive', 'conspicuous', 'dazzling', 'detention', 'electrifying', 'enchanting', 'extraordinary'],
    'arrival': ['advent', 'appearance', 'approach', 'blind landing', 'comer', 'coming', 'coming in', 'do', 'emergence', 'entrance', 'entrant', 'go'],
    'arrive': ['accomplish', 'achieve', 'achieve success', 'advance', 'appear', 'approach', 'arrive at', 'arrive in', 'attain', 'attain to', 'be a success', 'be received'],
    'arrive at': ['accomplish', 'achieve', 'approach', 'arrive', 'arrive in', 'arrive upon', 'attain', 'attain to', 'be received', 'blow in', 'bob up', 'check in'],
    'arriviste': ['babbitt', 'philistine', 'young turk', 'boor', 'bounder', 'bourgeois', 'bright young man', 'cad', 'churl', 'clown', 'comer', 'emigrant'],
    'arrogance': ['airs', 'assurance', 'assuredness', 'audacity', 'belief', 'bluster', 'boastfulness', 'bold front', 'boldness', 'brash bearing', 'brashness', 'brassiness'],
    'arrogant': ['absolute', 'absolutist', 'absolutistic', 'affected', 'arbitrary', 'aristocratic', 'artificial', 'assuming', 'assured', 'audacious', 'authoritarian', 'authoritative'],
    'arrogate': ['accroach', 'adopt', 'annex', 'appropriate', 'assume', 'assume command', 'colonize', 'commandeer', 'confiscate', 'conquer', 'encroach', 'enslave'],
    'arrogation': ['accession', 'accounting for', 'adoption', 'anointing', 'anointment', 'answerability', 'application', 'appointment', 'appropriation', 'ascription', 'assignation', 'assignment'],
    'arrow': ['antelope', 'arrowhead', 'barb', 'blaze', 'blue darter', 'blue streak', 'bobtailed arrow', 'bolt', 'cannonball', 'chested arrow', 'cloth yard shaft', 'compass needle'],
    'arsenal': ['ammo dump', 'archives', 'armory', 'artillery park', 'assembly line', 'assembly plant', 'atomic arsenal', 'atomic energy plant', 'attic', 'bank', 'basement', 'bay'],
    'arsenic': ['ddd', 'ddt', 'paris green', 'antimony', 'arsenic trioxide', 'beryllium', 'bichloride of mercury', 'cadmium', 'carbolic acid', 'carbon monoxide', 'carbon tetrachloride', 'chlorine'],
    'arsonist': ['annihilator', 'biblioclast', 'bomber', 'burner', 'demolisher', 'destroyer', 'dynamitard', 'dynamiter', 'exterminator', 'fire worshiper', 'firebug', 'hun'],
    'arsy varsy': ['a rebours', 'against the grain', 'anarchic', 'ass over elbows', 'ass-backwards', 'back-to-front', 'backwards', 'balled up', 'bollixed up', 'by contraries', 'capsized', 'chaotic'],
    'art': ['american', 'art nouveau', 'ashcan school', 'barbizon', 'bauhaus', 'bolognese', 'british', 'cobra', 'dadaism', 'dutch', 'fauvism', 'flemish'],
    'art song': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'alba', 'anthem', 'aubade', 'ballad', 'ballade', 'ballata', 'barcarole'],
    'art work': ['art object', 'brainchild', 'bric-a-brac', 'classic', 'composition', 'creation', 'design', 'grotesque', 'kitsch', 'master', 'masterpiece', 'masterwork'],
    'arterial': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway', 'blind alley'],
    'arteriosclerosis': ['angina', 'angina pectoris', 'aortic insufficiency', 'aortic stenosis', 'apoplectic stroke', 'apoplexy', 'arrhythmia', 'atherosclerosis', 'atrial fibrillation', 'auricular fibrillation', 'beriberi heart', 'calcification'],
    'artery': ['autobahn', 'us highway', 'access', 'aisle', 'alley', 'alleyway', 'ambulatory', 'aorta', 'aperture', 'arcade', 'arterial', 'arterial highway'],
    'artful': ['byzantine', 'machiavellian', 'machiavellic', 'acute', 'adroit', 'ambidextrous', 'arch', 'astute', 'cagey', 'calculating', 'canny', 'chiseling'],
    'artful dodger': ['casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'philadelphia lawyer', 'yankee horse trader', 'actor', 'bamboozler', 'befuddler', 'beguiler', 'charmer'],
    'artfulness': ['gongorism', 'italian hand', 'ability', 'acuteness', 'address', 'adeptness', 'adroitness', 'affectation', 'affectedness', 'airmanship', 'animal cunning', 'art'],
    'arthritic': ['allergic', 'anemic', 'apoplectic', 'bilious', 'cancerous', 'case', 'chlorotic', 'colicky', 'consumptive', 'dropsical', 'dyspeptic', 'edematous'],
    'arthritis': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis'],
    'article': ['accuse', 'affair', 'allege', 'apprentice', 'arraign', 'article of commerce', 'article of merchandise', 'artifact', 'aspect', 'autograph', 'back matter', 'beat'],
    'articulate': ['ciceronian', 'demosthenian', 'demosthenic', 'tullian', 'accouple', 'accumulate', 'adjust', 'agglutinate', 'amass', 'apprehensible', 'assemble', 'associate'],
    'articulation': ['indian file', 'agglomeration', 'agglutination', 'aggregation', 'allophone', 'alveolar', 'ankle', 'antonym', 'apico-alveolar', 'apico-dental', 'array', 'aspiration'],
    'artifact': ['affair', 'ancient manuscript', 'antique', 'antiquity', 'archaism', 'article', 'brainchild', 'cave painting', 'child', 'coinage', 'composition', 'concoction'],
    'artifice': ['gongorism', 'italian hand', 'machiavellianism', 'action', 'acuteness', 'ad hoc measure', 'adeptness', 'adroitness', 'affectation', 'affectedness', 'ambidexterity', 'answer'],
    'artificial': ['gongoresque', 'gongoristic', 'marinistic', 'affected', 'apocryphal', 'assumed', 'bastard', 'bogus', 'brummagem', 'colorable', 'colored', 'concocted'],
    'artilleryman': ['nimrod', 'archer', 'artillerist', 'bomb thrower', 'bombardier', 'bomber', 'bowman', 'cannoneer', 'carabineer', 'crack shot', 'dead shot', 'deadeye'],
    'artisan': ['admirable crichton', 'adept', 'aeromechanic', 'apprentice', 'artificer', 'artist', 'artiste', 'attache', 'authority', 'connaisseur', 'connoisseur', 'consultant'],
    'artist': ['admirable crichton', 'ace', 'adept', 'ancestors', 'apprentice', 'architect', 'artificer', 'artisan', 'artiste', 'attache', 'author', 'authority'],
    'artistic': ['attic', 'daedalian', 'adept', 'adroit', 'aesthetic', 'apt', 'art-conscious', 'arty', 'authoritative', 'beautiful', 'bravura', 'brilliant'],
    'artistry': ['ability', 'address', 'adeptness', 'adroitness', 'airmanship', 'art', 'artfulness', 'artisanship', 'artistic skill', 'arty-craftiness', 'authorcraft', 'authorship'],
    'artless': ['aboveboard', 'arty', 'awkward', 'befoolable', 'big', 'bluff', 'blunt', 'born yesterday', 'broad', 'brusque', 'bungling', 'candid'],
    'artlessness': ['absolute realism', 'authenticity', 'bluffness', 'bluntness', 'bona fideness', 'broadness', 'brusqueness', 'candidness', 'candor', 'directness', 'forthrightness', 'frankness'],
    'as': ['ad eundem', 'after this fashion', 'along these lines', 'as an example', 'as an instance', 'as long as', 'as things go', 'as well', 'at what price', 'because', 'being', 'being as how'],
    'as a rule': ['all in all', 'all things considered', 'altogether', 'as a whole', 'as an approximation', 'as per usual', 'as things go', 'as usual', 'at large', 'broadly', 'broadly speaking', 'by and large'],
    'as is': ['actual', 'alike', 'as per usual', 'as things are', 'as usual', 'at a stand', 'at a standstill', 'being', 'coequally', 'coextensively', 'coincidentally', 'congruently'],
    'as it were': ['assumably', 'assumedly', 'assumptively', 'figuratively', 'figuratively speaking', 'in a manner', 'in a way', 'in seeming', 'kind of', 'metaphorically', 'presumably', 'presumedly'],
    'as long as': ['as', 'as far as', 'at which time', 'being', 'cause', 'considering', 'during which time', 'for', 'inasmuch as', 'just so', 'seeing', 'since'],
    'as one': ['all agreeing', 'all together', 'as one man', 'at a clip', 'at once', 'at one time', 'back to back', 'by acclamation', 'cheek by jowl', 'coactively', 'coefficiently', 'coinstantaneously'],
    'as usual': ['as a rule', 'as is', 'as per usual', 'as things are', 'as things go', 'at a stand', 'at a standstill', 'chiefly', 'commonly', 'consistently', 'customarily', 'generally'],
    'as well': ['above', 'ad eundem', 'additionally', 'again', 'all included', 'also', 'altogether', 'among other things', 'and all', 'and also', 'and so', 'as'],
    'asbestos': ['act drop', 'amianthus', 'asbestos board', 'asbestos curtain', 'backdrop', 'batten', 'border', 'cloth', 'coulisse', 'counterweight', 'curtain', 'curtain board'],
    'ascend': ['advance', 'arise', 'aspire', 'back', 'back up', 'bank', 'budge', 'buss the clouds', 'cant', 'careen', 'chandelle', 'change'],
    'ascendancy': ['cadmean victory', 'ko', 'pyrrhic victory', 'accomplishment', 'ascendance', 'authority', 'balance of power', 'championship', 'charisma', 'charm', 'clout', 'conquest'],
    'ascendant': ['a cut above', 'above', 'absolute', 'ahead', 'anabatic', 'antecedent', 'ascendancy', 'ascending', 'ascensional', 'ascensive', 'at the head', 'authoritarian'],
    'ascending': ['olympian', 'acclinate', 'acclivitous', 'aerial', 'airy', 'altitudinous', 'anabatic', 'ascendant', 'ascensional', 'ascensive', 'aspiring', 'axial'],
    'ascension': ['anabasis', 'apotheosis', 'ascent', 'assumption', 'clamber', 'climb', 'climbing', 'elevation', 'escalade', 'fountain', 'gathering', 'gush'],
    'ascent': ['brownian movement', 'great leap forward', 'abruptness', 'access', 'accession', 'acclivity', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance'],
    'ascertain': ['afford proof of', 'appraise', 'ask', 'assure', 'be informed', 'become acquainted with', 'bring home to', 'broaden the mind', 'catch on', 'certify', 'cinch', 'clear up'],
    'ascertained': ['actual', 'appreciated', 'apprehended', 'assured', 'attested', 'authenticated', 'borne out', 'categorically true', 'certain', 'certified', 'circumstantiated', 'comprehended'],
    'ascetic': ['albigensian', 'apostolic', 'apostolici', 'catharist', 'diogenes', 'encratic', 'encratite', 'franciscan', 'hieronymian', 'hieronymite', 'lenten', 'pythagorean'],
    'asceticism': ['day of atonement', 'encratism', 'friday', 'lenten fare', 'pythagoreanism', 'pythagorism', 'rechabitism', 'shakerism', 'spartan fare', 'stoicism', 'yom kippur', 'abstainment'],
    'ascorbic acid': ['adermin', 'aneurin', 'antiberi-beri factor', 'axerophthol', 'biotin', 'carotene', 'cholecalciferol', 'choline', 'cobalamin', 'cryptoxanthin', 'cyanocobalamin', 'ergocalciferol'],
    'ascribable': ['accountable', 'alleged', 'assignable', 'attributable', 'attributed', 'charged', 'credited', 'derivable from', 'derivational', 'derivative', 'deserving', 'due'],
    'ascribe': ['accredit', 'adduce', 'advance', 'affix', 'allege', 'apply', 'assign', 'attach', 'attach to', 'attribute', 'charge', 'cite'],
    'ash': ['alluvion', 'alluvium', 'ashes', 'brand', 'calx', 'carbon', 'charcoal', 'cinder', 'cinders', 'clinker', 'clinkers', 'coal'],
    'ash wednesday': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'candlemas', 'candlemas day', 'carnival', 'christmas', 'corpus christi'],
    'ashamed': ['abashed', 'abject', 'blushing', 'chagrined', 'chapfallen', 'conscience-smitten', 'conscience-stricken', 'contrite', 'crestfallen', 'crushed', 'discomfited', 'embarrassed'],
    'ashen': ['quaker-colored', 'achromatic', 'achromic', 'acier', 'adust', 'aghast', 'anemic', 'appalled', 'ashy', 'astounded', 'awed', 'awestricken'],
    'ashes': ['ash', 'body', 'bones', 'brand', 'cadaver', 'calx', 'carbon', 'carcass', 'carrion', 'charcoal', 'cinder', 'cinders'],
    'ashram': ['adytum', 'body', 'caste', 'cell', 'clan', 'class', 'cloister', 'colony', 'commonwealth', 'commune', 'community', 'den'],
    'aside': ['a huis clos', 'all', 'apart', 'askance', 'askant', 'askew', 'aslant', 'aslope', 'asquint', 'away', 'awry', 'back'],
    'aside from': ['adrift', 'apart', 'apart from', 'asunder', 'away from', 'bar', 'barring', 'beside', 'besides', 'ex', 'except', 'except for'],
    'asinine': ['boeotian', 'absurd', 'airy', 'apish', 'batty', 'beef-brained', 'beef-witted', 'befooled', 'beguiled', 'besotted', 'blockish', 'bovid'],
    'ask': ['apply for', 'argue', 'ask a question', 'ask about', 'ask for', 'ask questions', 'assess', 'be hurting for', 'be indicated', 'beg', 'beg leave', 'beseech'],
    'ask for': ['abet', 'aid and abet', 'angle for', 'apply for', 'ask', 'beat about for', 'beg leave', 'bespeak', 'blackmail', 'call for', 'challenge', 'claim'],
    'askance': ['aside', 'askant', 'askew', 'asquint', 'awry', 'broadside', 'broadside on', 'cam', 'captiously', 'censoriously', 'cock-a-hoop', 'cockeyed'],
    'askew': ['aberrant', 'abroad', 'adrift', 'agee', 'agee-jawed', 'all abroad', 'all off', 'all wrong', 'amiss', 'anamorphous', 'askance', 'askant'],
    'asking price': ['advance', 'approach', 'bargain price', 'bearish prices', 'bid', 'bid price', 'book value', 'bullish prices', 'call price', 'cash price', 'closing price', 'controlled price'],
    'asleep': ['a stranger to', 'anesthetized', 'asleep in jesus', 'at rest', 'benumbed', 'bereft of life', 'blind to', 'breathless', 'called home', 'callous', 'carrion', 'cataleptic'],
    'aspect': ['adjunct', 'air', 'angle', 'appurtenance', 'article', 'astrodiagnosis', 'astrology', 'astromancy', 'attitude', 'attribute', 'azimuth', 'bearing'],
    'aspen': ['chattering', 'palsied', 'quaking', 'quavering', 'quavery', 'quivering', 'quivery', 'shaking', 'shaky', 'shivering', 'shivery', 'shuddering'],
    'asperity': ['acerbity', 'acid', 'acidity', 'acidness', 'acidulousness', 'acridity', 'acrimony', 'anger', 'animosity', 'astringency', 'austerity', 'bad humor'],
    'asperse': ['affront', 'calumniate', 'christen', 'defame', 'denigrate', 'deride', 'immerse', 'insult', 'libel', 'mock', 'offend', 'scandal'],
    'aspersion': ['abuse', 'adverse criticism', 'affront', 'affusion', 'agape', 'allegation', 'animadversion', 'aspergation', 'asperges', 'atrocity', 'auricular confession', 'backbiting'],
    'asphalt': ['formica', 'masonite', 'tarmac', 'tarvia', 'alabaster', 'amphibole', 'antimony', 'apatite', 'aplite', 'arsenic', 'asbestos', 'azurite'],
    'asphyxiate': ['od', 'be killed', 'bottle up', 'burke', 'censor', 'choke', 'choke off', 'clamp down on', 'cork', 'cork up', 'crack down on', 'crush'],
    'asphyxiation': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxia', 'asthma', 'ataxia', 'atrophy', 'backache', 'bleeding'],
    'aspic': ['caesar salad', 'jell-o salad', 'waldorf salad', 'ambrosia', 'barbecue', 'boiled meat', 'bouilli', 'chef salad', 'civet', 'cole slaw', 'combination salad', 'crab louis'],
    'aspirant': ['leibnizian optimist', 'pollyanna', 'addict', 'also-ran', 'applicant', 'aspirer', 'baby kisser', 'bidder', 'candidate', 'chiliast', 'claimant', 'collector'],
    'aspirate': ['breathe', 'breathe in', 'coo', 'draw in', 'inhale', 'inspire', 'maffle', 'mumble', 'murmur', 'mussitate', 'mutter', 'sigh'],
    'aspiration': ['aqua-lung', 'aim', 'allophone', 'alveolar', 'ambition', 'ambitiousness', 'animus', 'apico-alveolar', 'apico-dental', 'articulation', 'artificial respiration', 'assimilation'],
    'aspire': ['aim', 'aim at', 'aim high', 'aspire after', 'aspire to', 'bank on', 'be after', 'be ambitious', 'become airborne', 'claw skyward', 'confide', 'count on'],
    'aspiring': ['olympian', 'aerial', 'airy', 'altitudinous', 'ambitious', 'ascending', 'assured', 'careerist', 'careeristic', 'colossal', 'confident', 'dominating'],
    'ass': ['rocky mountain canary', 'siberian husky', 'act of love', 'adultery', 'aphrodisia', 'arse', 'balling', 'beast of burden', 'bigot', 'bitter-ender', 'born fool', 'buffoon'],
    'ass backwards': ['a rebours', 'a reculons', 'against the grain', 'anarchic', 'anticlockwise', 'arear', 'arsy-varsy', 'astern', 'away', 'awkwardly', 'back', 'backward'],
    'assail': ['ambush', 'assault', 'attack', 'blister', 'blitz', 'bushwhack', 'castigate', 'censure', 'come at', 'come down on', 'crack down on', 'criminate'],
    'assailant': ['adversary', 'aggressor', 'antagonist', 'assailer', 'assaulter', 'attacker', 'combatant', 'enemy', 'foe', 'foeman', 'invader', 'mugger'],
    'assassin': ['cain', 'alarmist', 'apache', 'assassinator', 'bloodletter', 'bloodshedder', 'bomber', 'bravo', 'burker', 'butcher', 'button man', 'cannibal'],
    'assault': ['abuse', 'aggravated assault', 'aggression', 'ambush', 'amphibious attack', 'armed assault', 'assail', 'assailing', 'assailment', 'attack', 'banzai attack', 'barbarize'],
    'assay': ['acid test', 'analysis', 'analyzation', 'analyze', 'anatomize', 'anatomizing', 'anatomy', 'appraise', 'appreciate', 'approach', 'assaying', 'assess'],
    'assemblage': ['a to z', 'a to izzard', 'bund', 'rochdale cooperative', 'aggregate', 'all', 'all and sundry', 'all sorts', 'alliance', 'alpha and omega', 'assembly', 'assembly line'],
    'assemble': ['accouple', 'accumulate', 'agglomerate', 'agglutinate', 'aggregate', 'aggroup', 'amass', 'articulate', 'associate', 'band', 'batch', 'bond'],
    'assembled': ['accumulated', 'agglomerate', 'aggregate', 'allied', 'amassed', 'associated', 'banded together', 'bound', 'bracketed', 'built', 'bunched', 'bundled'],
    'assembly': ['british cabinet', 'sanhedrin', 'us cabinet', 'advisory body', 'architecture', 'assemblage', 'assemblee', 'assembly line', 'assembly-line production', 'assignation', 'association', 'at home'],
    'assembly line': ['armory', 'arsenal', 'assemblage', 'assembly', 'assembly plant', 'assembly-line production', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery', 'brewery'],
    'assemblyman': ['mp', 'member of congress', 'member of parliament', 'alderman', 'chosen freeholder', 'city father', 'congressman', 'congresswoman', 'councilman', 'floor leader', 'lawgiver', 'lawmaker'],
    'assent': ['ok', 'abide by', 'accede', 'accede to', 'accept', 'acceptance', 'acclaim', 'accord', 'accord to', 'accordance', 'acquiesce', 'acquiesce in'],
    'assenting': ['abject', 'accepting', 'accordant', 'acquiescent', 'acquiescing', 'affirmative', 'agreeable', 'agreed', 'agreeing', 'approving', 'assentatious', 'complaisant'],
    'assert': ['advance', 'advocate', 'affirm', 'allege', 'allege in support', 'announce', 'annunciate', 'answer', 'argue', 'argue for', 'assever', 'asseverate'],
    'assertion': ['parthian shot', 'a priori principle', 'address', 'admission', 'affidavit', 'affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'answer', 'apostrophe'],
    'assertive': ['absolute', 'affirmative', 'affirmatory', 'aggressive', 'assertative', 'assertional', 'bold', 'bossy', 'certain', 'confident', 'decided', 'declarative'],
    'assess': ['account', 'appraise', 'appreciate', 'ask', 'assay', 'calculate', 'calibrate', 'caliper', 'call', 'catalog', 'categorize', 'charge'],
    'assessed': ['ad valorem', 'admeasured', 'appraised', 'evaluated', 'gauged', 'good for', 'known by measurement', 'mapped', 'measured', 'metered', 'plotted', 'priced'],
    'assessment': ['irish dividend', 'account', 'allowance', 'analyzing', 'appraisal', 'appraisement', 'appraising', 'appreciation', 'apprizal', 'approximation', 'assessing', 'assize'],
    'assessor': ['internal revenue service', 'ja', 'amicus curiae', 'appraiser', 'assayer', 'barmaster', 'cartographer', 'chancellor', 'chorographer', 'circuit judge', 'customhouse', 'customs'],
    'asset': ['advantage', 'assets', 'bankroll', 'benefit', 'capital', 'distinction', 'effects', 'equity', 'glory', 'holdings', 'honor', 'means'],
    'assets': ['swiss bank account', 'accounts', 'accounts payable', 'accounts receivable', 'affluence', 'assessed valuation', 'assets and liabilities', 'available means', 'balance', 'bank account', 'bottom dollar', 'bottomless purse'],
    'asseverate': ['acknowledge', 'affirm', 'allege', 'announce', 'annunciate', 'argue', 'assert', 'assever', 'attest', 'aver', 'avouch', 'avow'],
    'asshole': ['anus', 'boob', 'booby', 'bung', 'bunghole', 'chump', 'ding-a-ling', 'dingbat', 'dingdong', 'galoot', 'goof', 'jerk'],
    'assiduity': ['advertence', 'advertency', 'alertness', 'application', 'ardor', 'assiduousness', 'attention', 'attention span', 'attentiveness', 'awareness', 'bulldog tenacity', 'care'],
    'assiduous': ['advertent', 'agog', 'alert', 'all ears', 'all eyes', 'ardent', 'attentive', 'aware', 'careful', 'concentrated', 'conscious', 'constant'],
    'assign': ['abalienate', 'accredit', 'alien', 'alienate', 'allocate', 'allot', 'allow', 'amortize', 'apply', 'appoint', 'apportion', 'appropriate'],
    'assignation': ['abalienation', 'accounting for', 'agreement', 'alienation', 'amortization', 'amortizement', 'answerability', 'application', 'appointment', 'arrangement', 'arrogation', 'ascription'],
    'assignee': ['agent', 'allottee', 'almsman', 'almswoman', 'annuitant', 'appointee', 'assign', 'attorney', 'beneficiary', 'candidate', 'deputy', 'devisee'],
    'assignment': ['abalienation', 'accession', 'accounting for', 'agency', 'agentship', 'alienation', 'allocation', 'allotment', 'amortization', 'amortizement', 'anointing', 'anointment'],
    'assimilate': ['americanize', 'anglicize', 'ablate', 'absorb', 'accommodate', 'accommodate with', 'accord', 'acculturate', 'acculturize', 'adapt', 'adapt to', 'add'],
    'assimilated': ['americanized', 'anglicized', 'accented', 'acculturated', 'acculturized', 'adopted', 'alveolar', 'amalgamated', 'apical', 'apico-alveolar', 'apico-dental', 'articulated'],
    'assimilation': ['americanization', 'anschluss', 'ablation', 'about-face', 'absorbency', 'absorbent', 'absorption', 'accommodation', 'accordance', 'acculturation', 'adaptation', 'addition'],
    'assist': ['abet', 'accompany', 'act for', 'advance', 'aid', 'assistance', 'attend', 'avail', 'bail out', 'be instrumental', 'bear a hand', 'befriend'],
    'assistance': ['advantage', 'aid', 'alimony', 'allotment', 'allowance', 'alterative', 'analeptic', 'annuity', 'appropriation', 'assist', 'avail', 'backing'],
    'assistant': ['acolyte', 'adjutant', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider', 'ancilla', 'assistant professor', 'associate', 'associate professor', 'attendant'],
    'assizes': ['appellate court', 'chancery', 'chancery court', 'circuit court', 'civil court', 'common-law court', 'conciliation court', 'county court', 'court of appeals', 'court of assize', 'court of chancery', 'court of claims'],
    'associate': ['greek', 'abettor', 'accessory', 'accompany', 'accomplice', 'accord', 'accouple', 'accumulate', 'ace', 'acquaintance', 'act in concert', 'act together'],
    'associated': ['accessory', 'accompanying', 'accordant', 'affiliate', 'affiliated', 'agreeing', 'allied', 'assembled', 'associate', 'at one with', 'attendant', 'attending'],
    'association': ['anschluss', 'british cabinet', 'sanhedrin', 'us cabinet', 'accompaniment', 'accord', 'accordance', 'addition', 'adjunct', 'advisory body', 'affairs', 'affiliation'],
    'assonance': ['alliteration', 'blank verse', 'chime', 'clink', 'consonance', 'crambo', 'dingdong', 'double rhyme', 'drone', 'eye rhyme', 'harping', 'humdrum'],
    'assonant': ['accordant', 'according', 'alliteral', 'alliterating', 'alliterative', 'assonantal', 'attuned', 'belabored', 'blended', 'blending', 'chanting', 'chiming'],
    'assort': ['alphabetize', 'analyze', 'arrange', 'bolt', 'break down', 'catalog', 'categorize', 'class', 'classify', 'codify', 'collate', 'digest'],
    'assorted': ['adapted', 'aligned', 'arranged', 'arrayed', 'associated', 'at odds', 'at variance', 'bracketed', 'cataloged', 'categorized', 'chosen', 'classified'],
    'assortment': ['agglomeration', 'all sorts', 'allay', 'alleviate', 'appease', 'array', 'assemblage', 'assuage', 'batch', 'broad spectrum', 'calm', 'categorization'],
    'assuage': ['abate', 'adjust to', 'allay', 'alleviate', 'alter', 'anesthetize', 'appease', 'attemper', 'bank the fire', 'benumb', 'blunt', 'box in'],
    'assuasive': ['alleviating', 'alleviative', 'altering', 'analgesic', 'anesthetic', 'anodyne', 'balmy', 'balsamic', 'benumbing', 'bounding', 'calmant', 'calmative'],
    'assume': ['accept', 'account as', 'accroach', 'acquire', 'act', 'act a part', 'act like', 'admit', 'adopt', 'affect', 'affirm', 'allegorize'],
    'assumed': ['accepted', 'accounted as', 'affected', 'alleged', 'apocryphal', 'artificial', 'assumptive', 'bastard', 'bogus', 'brummagem', 'chanced', 'colorable'],
    'assumption': ['a priori principle', 'about-face', 'acceptance', 'accession', 'acquisition', 'admission', 'admittance', 'adoption', 'affirmation', 'alchemy', 'allegory', 'allusion'],
    'assurance': ['bible oath', 'absolute certainty', 'absoluteness', 'acceptation', 'acception', 'accident insurance', 'acquiescence', 'actuary', 'agreement', 'aid and comfort', 'annuity', 'aplomb'],
    'assure': ['afford hope', 'and candle', 'ascertain', 'assert', 'assert under oath', 'asseverate', 'attest', 'augur well', 'avouch', 'back', 'be convincing', 'be sponsor for'],
    'assured': ['affianced', 'arrogant', 'ascertained', 'aspiring', 'assurance', 'assuredness', 'attested', 'balanced', 'believing', 'betrothed', 'bound', 'certain'],
    'assuredly': ['ok', 'roger', 'absolutely', 'actually', 'all right', 'alright', 'alrighty', 'amen', 'and no mistake', 'as you say', 'at all events', 'at any rate'],
    'astarte': ['adonis', 'amor', 'aphrodite', 'apollo', 'apollo belvedere', 'artemis', 'ashtoreth', 'baal', 'balder', 'ceres', 'cleopatra', 'cupid'],
    'astern': ['a rebours', 'a reculons', 'abaft', 'aft', 'after', 'against the grain', 'anticlockwise', 'arear', 'ass-backwards', 'away', 'back', 'backward'],
    'asteroid': ['earth', 'jupiter', 'mars', 'mercury', 'neptune', 'pluto', 'saturn', 'uranus', 'venus', 'asteroids', 'aurora particles', 'blackout'],
    'asthma': ['asiatic flu', 'hong kong flu', 'abscess', 'acute bronchitis', 'adenoiditis', 'ague', 'allergen', 'allergic disorder', 'allergy', 'aluminosis', 'amygdalitis', 'anemia'],
    'asthmatic': ['breathing', 'errhine', 'expiratory', 'heaving', 'huffing', 'inspiratory', 'nasal', 'panting', 'pneumonic', 'puffing', 'pulmonary', 'pulmonic'],
    'astonish': ['affright', 'alarm', 'amaze', 'ambush', 'astound', 'awe', 'awestrike', 'bedaze', 'bedazzle', 'bewilder', 'boggle', 'bowl down'],
    'astonishing': ['amazing', 'appalling', 'astounding', 'breathtaking', 'confounding', 'conspicuous', 'egregious', 'electrifying', 'exceptional', 'extraordinary', 'eye-opening', 'fabulous'],
    'astound': ['abash', 'amaze', 'appall', 'astonish', 'awe', 'awestrike', 'bedaze', 'bedazzle', 'bewilder', 'boggle', 'bowl down', 'bowl over'],
    'astounded': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'appalled', 'ashen', 'astonished', 'at gaze', 'awed', 'awestricken', 'awestruck'],
    'astounding': ['amazing', 'appalling', 'astonishing', 'awe-inspiring', 'awesome', 'awful', 'breathtaking', 'confounding', 'dire', 'direful', 'dread', 'dreaded'],
    'astral': ['buddhic body', 'cynthian', 'masan', 'airy', 'anagalactic', 'apparition', 'appearance', 'asomatous', 'asteroidal', 'astral body', 'astral spirit', 'astrologic'],
    'astray': ['abashed', 'aberrant', 'abroad', 'adrift', 'afield', 'all abroad', 'all off', 'all wrong', 'amiss', 'askew', 'at fault', 'at sea'],
    'astringency': ['spartanism', 'abbreviation', 'acerbity', 'acidity', 'acidulousness', 'acridity', 'acridness', 'acrimony', 'asperity', 'astriction', 'astringence', 'austerity'],
    'astringent': ['spartan', 'spartanic', 'acerb', 'acerbic', 'acid', 'acidulous', 'acrid', 'acrimonious', 'alum', 'amaroidal', 'ascetic', 'asperous'],
    'astrologer': ['cassandra', 'chaldean', 'druid', 'astroalchemist', 'astrologian', 'astromancer', 'augur', 'calamity howler', 'crystal gazer', 'divinator', 'diviner', 'divineress'],
    'astrology': ['friday', 'friday the thirteenth', 'appointed lot', 'aspect', 'astral influences', 'astrodiagnosis', 'astromancy', 'augury', 'book of fate', 'clairvoyance', 'constellation', 'crystal ball'],
    'astronaut': ['martian', 'adventurer', 'aeronaut', 'aeroplaner', 'aeroplanist', 'air pilot', 'airplanist', 'alien', 'alpinist', 'aviator', 'barnstormer', 'birdman'],
    'astronautics': ['aeronautics', 'aerospace medicine', 'aerospace research', 'aerospace science', 'aerospace technology', 'air service', 'airline', 'aviation', 'ballooning', 'bioastronautics', 'blind flying', 'cloud-seeding'],
    'astronomic': ['atlantean', 'brobdingnagian', 'cyclopean', 'cynthian', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'amplitudinous', 'anagalactic', 'asteroidal', 'astral'],
    'astronomical': ['atlantean', 'brobdingnagian', 'cyclopean', 'cynthian', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'amplitudinous', 'anagalactic', 'asteroidal', 'astral'],
    'astronomy': ['astrogeology', 'astrognosy', 'astrography', 'astrolithology', 'astrophotography', 'astrophysics', 'celestial mechanics', 'gravitational astronomy', 'meteoritics', 'radar astronomy', 'radio astronomy', 'solar physics'],
    'astrophysical': ['cynthian', 'aerophysical', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'celestial', 'circumplanetary', 'cislunar'],
    'astrophysics': ['newtonian physics', 'acoustics', 'aerophysics', 'applied physics', 'astrogeology', 'astrognosy', 'astrography', 'astrolithology', 'astronomy', 'astrophotography', 'basic conductor physics', 'biophysics'],
    'astute': ['machiavellian', 'machiavellic', 'acute', 'adroit', 'alert', 'apperceptive', 'appercipient', 'arch', 'argute', 'artful', 'cagey', 'calculating'],
    'asunder': ['adrift', 'all to pieces', 'apart', 'apart from', 'aside from', 'at a distance', 'away', 'away from', 'bipartite', 'by two', 'dichotomous', 'discontinuous'],
    'asylum': ['va hospital', 'almshouse', 'base hospital', 'bedlam', 'bird sanctuary', 'bolt-hole', 'bughouse', 'cache', 'clinic', 'community hospital', 'concealment', 'convalescent home'],
    'asymmetric': ['anamorphous', 'askew', 'bent', 'bowed', 'cockeyed', 'contorted', 'crazy', 'crooked', 'crumpled', 'crunched', 'deviative', 'disparate'],
    'asymmetrical': ['anamorphous', 'askew', 'asymmetric', 'bent', 'bowed', 'cockeyed', 'contorted', 'crazy', 'crooked', 'crumpled', 'crunched', 'deviative'],
    'asymmetry': ['ambiguity', 'ambivalence', 'anamorphism', 'anamorphosis', 'antinomy', 'buckle', 'contortion', 'contrariety', 'crookedness', 'detorsion', 'deviation', 'difference'],
    'asymptote': ['approach', 'bottleneck', 'collision course', 'concentralization', 'concentration', 'concourse', 'concurrence', 'confluence', 'conflux', 'congress', 'convergence', 'converging'],
    'at a loss': ['addled', 'at a nonplus', 'at a stand', 'at a standstill', 'at an impasse', 'baffled', 'bamboozled', 'beat', 'bewildered', 'buffaloed', 'confounded', 'dazed'],
    'at a standstill': ['adamant', 'adamantine', 'as is', 'as per usual', 'as things are', 'as usual', 'at a halt', 'at a loss', 'at a nonplus', 'at a stand', 'at an impasse', 'at anchor'],
    'at all': ['anyhow', 'anyway', 'anywise', 'at any cost', 'at any rate', 'by any chance', 'by any means', 'by merest chance', 'ever', 'however', 'if at all', 'in any case'],
    'at any cost': ['at all', 'at all costs', 'at all events', 'at all risks', 'at any price', 'by any chance', 'by any means', 'by merest chance', 'come what may', 'despite', 'even with', 'ever'],
    'at any rate': ['absolutely', 'after a fashion', 'after all', 'again', 'albeit', 'all the same', 'although', 'and no mistake', 'anyhow', 'anyway', 'anywise', 'appreciably'],
    'at cross purposes': ['adversative', 'adverse', 'adverse to', 'adversive', 'against', 'against the grain', 'against the tide', 'against the wind', 'antagonistic', 'anti', 'antipathetic', 'antithetic'],
    'at ease': ['abed', 'accepting', 'at home', 'at rest', 'comfortable', 'composed', 'content', 'contented', 'easy', 'easygoing', 'eupeptic', 'euphoric'],
    'at fault': ['aberrant', 'abroad', 'adrift', 'all abroad', 'all off', 'all wrong', 'amiss', 'arraignable', 'askew', 'astray', 'awry', 'beside the mark'],
    'at hand': ['about', 'about to be', 'accessible', 'adaptable', 'all-around', 'along toward', 'already in sight', 'approaching', 'around', 'at close quarters', 'attendant', 'available'],
    'at home': ['affair', 'assemblee', 'assembly', 'assignation', 'at ease', 'at rest', 'back home', 'ball', 'brawl', 'caucus', 'chez soi', 'colloquium'],
    'at issue': ['against the grain', 'against the tide', 'against the wind', 'arguable', 'at cross-purposes', 'at daggers', 'at daggers drawn', 'at odds', 'at variance', 'at war with', 'athwart', 'before the house'],
    'at large': ['across the board', 'afoot and lighthearted', 'all', 'all in all', 'all put together', 'all things considered', 'altogether', 'as a body', 'as a rule', 'as a whole', 'as an approximation', 'at length'],
    'at length': ['ad infinitum', 'along', 'at large', 'at last', 'at long last', 'at the end', 'at the last', 'completely', 'conclusively', 'endlong', 'endways', 'endwise'],
    'at liberty': ['afoot and lighthearted', 'at large', 'available', 'clear', 'detached', 'disengaged', 'easygoing', 'emancipated', 'fallow', 'footloose', 'footloose and fancy-free', 'free'],
    'at most': ['after a fashion', 'appreciably', 'at any rate', 'at best', 'at least', 'at the least', 'at the most', 'at the outside', 'at worst', 'comparatively', 'detectably', 'fairly'],
    'at odds': ['against the grain', 'against the tide', 'against the wind', 'alienated', 'antagonistic', 'antiestablishment', 'antipathetic', 'assorted', 'at cross-purposes', 'at daggers', 'at daggers drawn', 'at enmity'],
    'at once': ['pdq', 'all at once', 'all together', 'amain', 'apace', 'as one', 'at a blow', 'at a stroke', 'at one blow', 'at one jump', 'at one stroke', 'at one swoop'],
    'at one': ['accordant', 'affirmative', 'agreeable', 'agreeing', 'akin', 'amicable', 'answerable', 'at one with', 'attuned', 'carried by acclamation', 'coexistent', 'coexisting'],
    'at random': ['aimlessly', 'any which way', 'anyhow', 'anywise', 'around', 'at haphazard', 'at hazard', 'at intervals', 'at irregular intervals', 'brokenly', 'by catches', 'by chance'],
    'at rest': ['abed', 'asleep', 'asleep in jesus', 'at ease', 'at home', 'bereft of life', 'breathless', 'called home', 'calm', 'carrion', 'cloistered', 'cool'],
    'at sea': ['abashed', 'abroad', 'adrift', 'afloat', 'astray', 'bewildered', 'bothered', 'by sea', 'by water', 'clueless', 'confused', 'discomposed'],
    'at variance': ['against the grain', 'against the tide', 'against the wind', 'alienated', 'antagonistic', 'antiestablishment', 'antipathetic', 'assorted', 'at cross-purposes', 'at daggers', 'at daggers drawn', 'at enmity'],
    'at war': ['against the grain', 'against the tide', 'against the wind', 'antagonistic', 'antipathetic', 'at cross-purposes', 'at daggers', 'at daggers drawn', 'at feud', 'at issue', 'at loggerheads', 'at odds'],
    'ataraxy': ['accidia', 'acedia', 'aloofness', 'apathy', 'ataraxia', 'benumbedness', 'blah', 'blahs', 'bovinity', 'calmness', 'carelessness', 'casualness'],
    'atavism': ['mnemosyne', 'aboriginality', 'affect memory', 'age', 'ancien regime', 'ancientness', 'anterograde memory', 'antiquity', 'backset', 'backward deviation', 'cobwebs of antiquity', 'collective memory'],
    'atavistic': ['aboriginal', 'ancestral', 'antepatriarchal', 'autochthonous', 'bodily', 'born', 'coeval', 'congenital', 'connatal', 'connate', 'connatural', 'constitutional'],
    'atelier': ['agency', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'butcher shop', 'company', 'concern', 'corporation', 'desk', 'establishment', 'facility'],
    'atheism': ['agnosticism', 'apostasy', 'backsliding', 'denial', 'desertion', 'disbelief', 'discredit', 'faithlessness', 'fall from grace', 'gentilism', 'heresy', 'impiety'],
    'atheist': ['sabbath-breaker', 'apostate', 'backslider', 'blasphemer', 'deserter', 'disbeliever', 'gentile', 'heathen', 'infidel', 'minimifidian', 'nonbeliever', 'nullifidian'],
    'atheistic': ['apostate', 'atheist', 'backsliding', 'blasphemous', 'disbelieving', 'faithless', 'fallen', 'fallen from grace', 'gentile', 'goyish', 'heathen', 'impious'],
    'athena': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'bacchus', 'bellona', 'ceres', 'cora'],
    'atherosclerosis': ['angina', 'angina pectoris', 'aortic insufficiency', 'aortic stenosis', 'apoplectic stroke', 'apoplexy', 'arrhythmia', 'arteriosclerosis', 'atrial fibrillation', 'auricular fibrillation', 'beriberi heart', 'calcification'],
    'athlete': ['amateur athlete', 'archer', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'blocking back', 'bowman', 'catcher', 'center', 'coach'],
    'athletic': ['able-bodied', 'acrobatic', 'active', 'agonistic', 'brawny', 'broad-shouldered', 'burly', 'energetic', 'gymnastic', 'muscle-bound', 'muscular', 'palaestral'],
    'athletics': ['rugby', 'acrobatics', 'agonistics', 'amusement', 'association football', 'bathing', 'breather', 'calisthenics', 'diversion', 'drill', 'entertainment', 'exercise'],
    'athwart': ['across', 'across the grain', 'adverse to', 'against', 'against the grain', 'against the tide', 'against the wind', 'at cross-purposes', 'at cross-purposes with', 'at daggers', 'at daggers drawn', 'at issue'],
    'atlas': ['lambert conformal projection', 'mercator projection', 'miller projection', 'aeronautical chart', 'arcade', 'astronomical chart', 'azimuthal projection', 'calendar', 'cartographer', 'cartography', 'caryatid', 'casebook'],
    'atman': ['anima', 'anima humana', 'animating force', 'astral body', 'ba', 'bathmism', 'beating heart', 'biological clock', 'biorhythm', 'blood', 'breath', 'breath of life'],
    'atmosphere': ['action', 'aerial', 'aerodynamics', 'aerosphere', 'air', 'ambience', 'ambient', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'argument'],
    'atoll': ['ait', 'archipelago', 'bar', 'cay', 'continental island', 'coral head', 'coral island', 'coral reef', 'holm', 'insularity', 'island', 'island group'],
    'atom': ['bohr atom', 'dirac atom', 'lewis-langmuir atom', 'thomson atom', 'ace', 'acid', 'acidity', 'agent', 'air', 'alkali', 'alkalinity', 'alloisomer'],
    'atom smashing': ['alpha decay', 'atom-chipping', 'atomic disintegration', 'atomic reaction', 'atomization', 'beta decay', 'bombardment', 'breeding', 'bullet', 'chain reaction', 'cleavage', 'disintegration series'],
    'atomic': ['a certain', 'an', 'any', 'any one', 'atomatic', 'atomiferous', 'atomistic', 'corpuscular', 'cyclic', 'diatomic', 'dibasic', 'either'],
    'atomism': ['aristotelianism', 'berkeleianism', 'bohr theory', 'bradleianism', 'cynicism', 'cyrenaic hedonism', 'cyrenaicism', 'dirac theory', 'epicureanism', 'fichteanism', 'hegelianism', 'heideggerianism'],
    'atomization': ['ablation', 'abrasion', 'aeration', 'aerification', 'alpha decay', 'alteration', 'analysis', 'anatomization', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction'],
    'atomize': ['ablate', 'abrade', 'accelerate', 'activate', 'adduce', 'aerate', 'aerify', 'analyze', 'anatomize', 'beat', 'bombard', 'bray'],
    'atomizer': ['aerosol', 'aspergil', 'aspergillum', 'censer', 'clyster', 'concentrate sprayer', 'douche', 'enema', 'evaporator', 'fountain syringe', 'fumigator', 'incense burner'],
    'atonal': ['absonant', 'cacophonous', 'cracked', 'diaphonic', 'disconsonant', 'discordant', 'disharmonic', 'disharmonious', 'dissonant', 'flat', 'grating', 'harsh'],
    'atone': ['accord', 'answer', 'appease', 'assonate', 'atone for', 'attune', 'be harmonious', 'be in tune', 'blend', 'chime', 'chord', 'compensate'],
    'atonement': ['amends', 'appeasement', 'balancing', 'blood money', 'commutation', 'compensation', 'consideration', 'counteraction', 'counterbalancing', 'damages', 'expiation', 'guerdon'],
    'atony': ['adynamia', 'anemia', 'blah feeling', 'bloodlessness', 'cachexia', 'cachexy', 'cowardice', 'debilitation', 'debility', 'dullness', 'etiolation', 'faintness'],
    'atrocious': ['draconian', 'tartarean', 'aberrant', 'abject', 'abnormal', 'abominable', 'abusive', 'acute', 'afflictive', 'agonizing', 'animal', 'anthropophagous'],
    'atrociously': ['abjectly', 'abominably', 'arrantly', 'awfully', 'barbarously', 'basely', 'bec et ongles', 'bestially', 'brutally', 'brutishly', 'contemptibly', 'cruelly'],
    'atrocity': ['abomination', 'abuse', 'acuteness', 'affront', 'animality', 'aspersion', 'atrociousness', 'awfulness', 'bad', 'bane', 'banefulness', 'barbarity'],
    'atrophy': ['sanforizing', 'abnormality', 'abscess', 'acute disease', 'affection', 'affliction', 'ague', 'ailment', 'allergic disease', 'allergy', 'anemia', 'ankylosis'],
    'attach': ['add', 'adhere', 'adjoin', 'affiliate', 'affix', 'agglutinate', 'anchor', 'annex', 'append', 'apply', 'appropriate', 'ascribe'],
    'attache': ['admirable crichton', 'adept', 'ambassador', 'ambassadress', 'apostolic delegate', 'artisan', 'artist', 'authority', 'career diplomat', 'chancellor', 'charge', 'commercial attache'],
    'attached to': ['crazy about', 'devoted to', 'enamored of', 'far gone on', 'fond of', 'gone on', 'hipped on', 'in love with', 'mad about', 'nuts about', 'partial to', 'smitten with'],
    'attachment': ['amor', 'christian love', 'eros', 'platonic love', 'accession', 'accessory', 'accompaniment', 'accounting for', 'addenda', 'addendum', 'additament', 'addition'],
    'attack': ['jacksonian epilepsy', 'mo', 'rolandic epilepsy', 'abdominal epilepsy', 'abuse', 'accept', 'access', 'acquired epilepsy', 'action', 'activated epilepsy', 'activation', 'affect'],
    'attain': ['accede', 'accomplish', 'achieve', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain to', 'be instated', 'be received', 'blow in', 'bob up'],
    'attainable': ['accessible', 'achievable', 'actable', 'approachable', 'available', 'come-at-able', 'compassable', 'doable', 'feasible', 'findable', 'getatable', 'gettable'],
    'attainment': ['accession', 'accomplished fact', 'accomplishment', 'accomplishments', 'achievement', 'acquirement', 'acquisition', 'acquisition of knowledge', 'acquisitions', 'addition', 'advent', 'appearance'],
    'attar': ['ambergris', 'ambrosia', 'aromatic', 'aromatic gum', 'aromatic water', 'attar of roses', 'balm', 'balm of gilead', 'balsam', 'bay oil', 'bergamot oil', 'champaca oil'],
    'attempt': ['accept', 'affair', 'aim to', 'approach', 'assault', 'assay', 'assume', 'attack', 'attempt to', 'begin', 'beginning', 'bid'],
    'attend': ['accompany', 'administer to', 'aid', 'animadvert', 'appear', 'assist', 'assister', 'associate', 'associate with', 'assort with', 'attend on', 'attend to'],
    'attend to': ['abide by', 'act up to', 'adhere to', 'advert to', 'attend', 'auscultate', 'baby-sit', 'be all ears', 'be aware of', 'be engrossed in', 'be faithful to', 'bend an ear'],
    'attendance': ['appearance', 'assemblage', 'assembly', 'attendant', 'attending', 'audience', 'being', 'body of retainers', 'box office', 'cohort', 'cortege', 'court'],
    'attendant': ['ganymede', 'hebe', 'x-ray technician', 'accessible', 'accessory', 'accompanier', 'accompanist', 'accompanying', 'accompanyist', 'acolyte', 'adherent', 'adjunct'],
    'attending': ['accessory', 'accompanying', 'ancillary', 'associated', 'attendant', 'coincident', 'collateral', 'combined', 'concomitant', 'concurrent', 'conjoint', 'correlative'],
    'attention': ['nb', 'tlc', 'absorption', 'acclaim', 'act of courtesy', 'acuity', 'acuteness', 'agility', 'alertness', 'amenity', 'anticipation', 'application'],
    'attentive': ['accommodating', 'accommodative', 'accurate', 'advertent', 'affable', 'agile', 'agog', 'agreeable', 'alert', 'alive', 'all ears', 'all eyes'],
    'attenuate': ['sanforize', 'abate', 'adulterate', 'alleviate', 'attenuated', 'baptize', 'bate', 'blow off', 'blunt', 'cast forth', 'clear away', 'constrict'],
    'attenuated': ['sanforized', 'abated', 'ablated', 'adulterated', 'airy', 'attenuate', 'bated', 'belittled', 'boyish', 'cadaverous', 'consumed', 'contracted'],
    'attest': ['acknowledge', 'affirm', 'allege', 'and candle', 'announce', 'approve', 'argue', 'assert', 'assert under oath', 'asseverate', 'assure', 'authenticate'],
    'attestation': ['admission', 'affidavit', 'affirmation', 'allegation', 'assertion', 'asseveration', 'attest', 'authentication', 'authority', 'authorization', 'averment', 'avouchment'],
    'attested': ['actual', 'affirmed', 'alleged', 'announced', 'ascertained', 'asserted', 'asseverated', 'assured', 'authenticated', 'averred', 'avouched', 'avowed'],
    'attic': ['ciceronian', 'aesthetic', 'artistic', 'biting', 'brilliant', 'chaste', 'choice', 'classic', 'classical', 'clear', 'clever', 'common'],
    'attire': ['accouter', 'apparel', 'appoint', 'arm', 'array', 'bedeck', 'bedizenment', 'bedrape', 'bundle up', 'clad', 'clothe', 'clothes'],
    'attitude': ['air', 'approach', 'aspect', 'assumption', 'azimuth', 'bearing', 'bearings', 'bent', 'bias', 'carriage', 'celestial navigation', 'climate of opinion'],
    'attorney': ['mc', 'advocate', 'agent', 'alter ego', 'alternate', 'amicus curiae', 'assignee', 'attorney-at-law', 'backup', 'backup man', 'bailiff', 'barrister'],
    'attract': ['adduct', 'affect the interest', 'allure', 'appeal', 'appeal to', 'be attractive', 'be magnetic', 'becharm', 'beckon', 'beguile', 'bewitch', 'captivate'],
    'attracted': ['advancing', 'approaching', 'approximate', 'approximative', 'attracted to', 'cathectic', 'coming', 'concerned', 'curious', 'drawn to', 'enthusiastic', 'excited'],
    'attraction': ['circean', 'acceptability', 'accord', 'affinity', 'agacerie', 'agreeability', 'agreeable', 'allure', 'allurement', 'alluring', 'appeal', 'appealing'],
    'attractive': ['absorbing', 'acceptable', 'adductive', 'adorable', 'aesthetic', 'aesthetically appealing', 'agreeable', 'alluring', 'appealing', 'appetizing', 'arresting', 'attracting'],
    'attributable': ['accountable', 'alleged', 'arising from', 'ascribable', 'assignable', 'attributable to', 'attributed', 'caused by', 'charged', 'coming from', 'contingent on', 'credited'],
    'attribute': ['ic analysis', 'account for', 'accredit', 'accredit with', 'accrete to', 'acknowledge', 'affection', 'apply', 'apply to', 'appositive', 'aroma', 'ascribe'],
    'attrition': ['abatement', 'ablation', 'abrasion', 'abrasive', 'absorption', 'apologies', 'assimilation', 'atomization', 'attenuation', 'ayenbite of inwit', 'beating', 'bitterness'],
    'attune': ['accommodate', 'accord', 'adapt', 'adjust', 'adjust to', 'agree', 'assimilate', 'assonate', 'atone', 'balance', 'be harmonious', 'be in tune'],
    'attuned': ['accordant', 'according', 'agreeable', 'agreeing', 'akin', 'amicable', 'assonant', 'assonantal', 'at one', 'blended', 'blending', 'chiming'],
    'au fait': ['able', 'abreast', 'acquainted', 'au courant', 'au fond', 'basically', 'becoming', 'befitting', 'capable', 'comme il faut', 'competent', 'conforming'],
    'au pair girl': ['abigail', 'amah', 'ayah', 'betweenmaid', 'biddy', 'chambermaid', 'chaperon', 'companion', 'cook', 'duenna', 'femme de chambre', 'fille de chambre'],
    'auburn': ['titian', 'adust', 'bay', 'bay-colored', 'bayard', 'brazen', 'bronze', 'bronze-colored', 'bronzed', 'brownish-red', 'carroty', 'castaneous'],
    'audacious': ['adventuresome', 'adventurous', 'arrogant', 'bold', 'brash', 'brassy', 'brave', 'brazen', 'bumptious', 'careless', 'challenging', 'cheeky'],
    'audacity': ['adventuresomeness', 'adventurousness', 'arrogance', 'assurance', 'audaciousness', 'balls', 'bold front', 'boldness', 'brash bearing', 'brashness', 'brass', 'brassiness'],
    'audible': ['acoustic', 'articulate', 'audile', 'audio', 'auditory', 'aural', 'auricular', 'clear', 'contrastive', 'definite', 'distinct', 'distinctive'],
    'audience': ['accepter', 'acquirer', 'addressee', 'aficionado', 'attender', 'attention', 'audition', 'auditor', 'auditory', 'bargaining', 'bargaining session', 'beholder'],
    'audio frequency': ['af', 'cps', 'ehf', 'hf', 'hz', 'mf', 'rf', 'shf', 'uhf', 'vhf', 'vlf', 'carrier frequency'],
    'audit': ['accountancy', 'accounting', 'analysis', 'auditing', 'balance', 'balance the books', 'bookkeeping', 'check', 'check and doublecheck', 'check out', 'check over', 'checkup'],
    'audition': ['gedankenexperiment', 'attention', 'audibility', 'audience', 'aural examination', 'aural sense', 'auscultation', 'bench test', 'blue book', 'bugging', 'conference', 'dry run'],
    'auditor': ['big brother', 'ca', 'cpa', 'accepter', 'accountant', 'accountant general', 'acquirer', 'actuary', 'addressee', 'audience', 'audient', 'autodidact'],
    'auditorium': ['elizabethan theater', 'globe theatre', 'greek theater', 'agora', 'amphitheater', 'arena', 'arena theater', 'assembly hall', 'athletic field', 'background', 'balcony', 'bear garden'],
    'auger': ['aculeus', 'acumination', 'bit', 'bore', 'bore bit', 'borer', 'brace and bit', 'breast auger', 'breast drill', 'broach', 'burr', 'chamfer bit'],
    'aught': ['aggrandize', 'any', 'any one', 'anybody', 'anyone', 'anything', 'augment', 'beef up', 'boost', 'cipher', 'either', 'enlarge'],
    'augment': ['add to', 'agent provocateur', 'aggrandize', 'aggravate', 'amplify', 'annoy', 'bloat', 'blow up', 'boost', 'broaden', 'build', 'build up'],
    'augmentation': ['accession', 'accretion', 'adjunct', 'annex', 'attachment', 'bonus', 'boot', 'complement', 'enhancement', 'enrichment', 'extra', 'fixture'],
    'augur': ['cassandra', 'druid', 'adumbrate', 'argue', 'astrologer', 'bespeak', 'betoken', 'bid fair to', 'bode', 'calamity howler', 'crystal gazer', 'divinator'],
    'augur well': ['afford hope', 'assure', 'bid fair', 'cheer', 'give hope', 'have good prospects', 'hold out hope', 'hold out promise', 'inspire', 'inspire hope', 'inspirit', 'justify hope'],
    'augury': ['adumbration', 'anticipation', 'astrology', 'auspice', 'betokening', 'betokenment', 'boding', 'clairvoyance', 'crystal ball', 'crystal gazing', 'divination', 'divining'],
    'august': ['aristocratic', 'awe-inspiring', 'awesome', 'awful', 'baronial', 'courtly', 'dignified', 'distinguished', 'dreadful', 'elevated', 'eminent', 'estimable'],
    'aunt': ['auntie', 'blood brother', 'brethren', 'brother', 'bub', 'bubba', 'bud', 'buddy', 'country cousin', 'cousin', 'cousin once removed', 'cousin twice removed'],
    'aura': ['air', 'ambiance', 'ambience', 'anthelion', 'antisun', 'appearance', 'aroma', 'aspect', 'atmosphere', 'aureole', 'blaze of glory', 'brilliance'],
    'aureole': ['annular muscle', 'annulus', 'anthelion', 'antisun', 'areola', 'aura', 'chaplet', 'circle', 'circuit', 'circumference', 'circus', 'closed circle'],
    'auricular': ['acoustic', 'audible', 'audile', 'audio', 'auditory', 'aural', 'between us', 'confidential', 'esoteric', 'hearing', 'in petto', 'inside'],
    'aurora': ['alpenglow', 'arch aurora', 'aurora australis', 'aurora borealis', 'aurora glory', 'aurora polaris', 'break of day', 'brightening', 'chanticleer', 'cockcrow', 'cocklight', 'crack of dawn'],
    'ausgespielt': ['bankrupt', 'blasted', 'blighted', 'broken', 'burned-out', 'desolated', 'destroyed', 'devastated', 'devitalized', 'disabled', 'done', 'done for'],
    'auspices': ['abetment', 'accountability', 'administration', 'advocacy', 'aegis', 'approval', 'authority', 'backing', 'bossing', 'care', 'championship', 'charge'],
    'auspicious': ['advantageous', 'appropriate', 'befitting', 'beneficial', 'benevolent', 'benign', 'benignant', 'blessed', 'blessed with luck', 'bon', 'bonny', 'braw'],
    'austere': ['albigensian', 'catharist', 'franciscan', 'lenten', 'sabbatarian', 'spartan', 'spartanic', 'trappist', 'waldensian', 'abstemious', 'abstinent', 'amaroidal'],
    'austerity': ['albigensianism', 'catharism', 'franciscanism', 'lenten fare', 'sabbatarianism', 'spartan simplicity', 'spartanism', 'trappism', 'waldensianism', 'yoga', 'abstinence', 'anchoritic monasticism'],
    'autarchic': ['arbitrary', 'autarkic', 'autocratic', 'autonomous', 'commanding', 'despotic', 'dogmatic', 'imperious', 'independent', 'monocratic', 'nonconstitutional', 'self-dependent'],
    'autarchy': ['caesarism', 'declaration of independence', 'stalinism', 'absolute monarchy', 'absolutism', 'aristocracy', 'autarky', 'authoritarianism', 'autocracy', 'autonomy', 'benevolent despotism', 'coalition government'],
    'auteur': ['mc', 'ballyhoo man', 'barker', 'callboy', 'costume designer', 'costumer', 'costumier', 'director', 'emcee', 'equestrian director', 'exhibitor', 'impresario'],
    'authentic': ['christian', 'aboveboard', 'absolute', 'accepted', 'accurate', 'actual', 'adducible', 'admissible', 'approved', 'attestative', 'attestive', 'authoritative'],
    'authenticate': ['ok', 'accept', 'accredit', 'affirm', 'amen', 'approve', 'attest', 'authorize', 'autograph', 'avouch', 'back', 'back up'],
    'authenticated': ['accepted', 'acknowledged', 'actual', 'admitted', 'affirmed', 'allowed', 'approved', 'ascertained', 'attested', 'avowed', 'borne out', 'categorically true'],
    'authenticity': ['absolute realism', 'accomplished fact', 'actuality', 'artlessness', 'authoritativeness', 'bona fideness', 'calculability', 'canonicalness', 'canonicity', 'creativeness', 'creativity', 'dependability'],
    'author': ['actor', 'advertising writer', 'agent', 'ancestor', 'ancestors', 'annalist', 'apprentice', 'architect', 'art critic', 'artificer', 'artist', 'authoress'],
    'authoritarian': ['spartan', 'spartanic', 'absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'ascendant', 'astringent', 'austere', 'authoritative'],
    'authoritative': ['christian', 'daedalian', 'absolute', 'absolutist', 'absolutistic', 'accepted', 'accurate', 'acquainted with', 'adept', 'adroit', 'approved', 'apt'],
    'authorities': ['john bull', 'uncle sam', 'washington', 'whitehall', 'bureaucracy', 'directorate', 'hierarchy', 'higher echelons', 'higher-ups', 'management', 'ministry', 'officialdom'],
    'authority': ['admirable crichton', 'acme', 'adept', 'administration', 'adviser', 'affidavit', 'aficionado', 'agency', 'agentship', 'amateur', 'amperage', 'announcer'],
    'authorization': ['john hancock', 'ok', 'acceptance', 'accession', 'accredit', 'acme', 'advance', 'affidavit', 'affirmance', 'affirmation', 'agency', 'agentship'],
    'authorize': ['ok', 'accept', 'accredit', 'affirm', 'allow', 'amen', 'appoint', 'approve', 'arm', 'assign', 'authenticate', 'autograph'],
    'authorized': ['absolute', 'accredited', 'actionable', 'applicable', 'appointed', 'ascendant', 'authoritarian', 'authoritative', 'autocratic', 'chartered', 'clothed with authority', 'commanding'],
    'authorship': ['artistry', 'authorcraft', 'automatic writing', 'beginning', 'cacoethes scribendi', 'coinage', 'composition', 'conception', 'concoction', 'contrivance', 'contriving', 'creation'],
    'autism': ['acquisitiveness', 'airy nothing', 'alienation', 'anesthesia', 'autistic thinking', 'avoidance mechanism', 'bashfulness', 'blame-shifting', 'bubble', 'careerism', 'catatonia', 'chill'],
    'autistic': ['barmecidal', 'barmecide', 'acquisitive', 'affectless', 'airy', 'ambitious for self', 'anesthetized', 'apparent', 'apparitional', 'arctic', 'bashful', 'blunt'],
    'auto': ['pcv valve', 'accelerator', 'alternator', 'ammeter', 'autocar', 'automobile', 'bearings', 'boat', 'bonnet', 'boot', 'brake', 'bucket seat'],
    'autobiography': ['clio', 'muse of history', 'adventures', 'annals', 'biographical sketch', 'biography', 'case history', 'chronicle', 'chronicles', 'chronology', 'confessions', 'curriculum vitae'],
    'autochthonous': ['abecedarian', 'aboriginal', 'ancestral', 'antenatal', 'antepatriarchal', 'atavistic', 'beginning', 'budding', 'creative', 'elemental', 'elementary', 'embryonic'],
    'autocrat': ['simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'caesar', 'commissar', 'czar', 'despot', 'dictator', 'disciplinarian'],
    'autocratic': ['absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'ascendant', 'autarchic', 'authoritarian', 'authoritative', 'authorized', 'autonomous'],
    'autodidactic': ['bookish', 'coeducational', 'college-bred', 'collegiate', 'cultural', 'didactic', 'disciplinary', 'edifying', 'educated', 'educating', 'educational', 'educative'],
    'autoeroticism': ['active algolagnia', 'algolagnia', 'algolagny', 'amour-propre', 'amphierotism', 'anal intercourse', 'bestiality', 'bisexuality', 'buggery', 'complacency', 'consequentiality', 'coprophilia'],
    'autograph': ['john hancock', 'article', 'brainchild', 'christcross', 'cipher', 'composition', 'computer printout', 'copy', 'countermark', 'countersign', 'countersignature', 'counterstamp'],
    'automat': ['beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop', 'coffeehouse'],
    'automated': ['automatic', 'automatous', 'cybernated', 'self-acting', 'self-active', 'self-adjusting', 'self-closing', 'self-controlled', 'self-cooking', 'self-directed', 'self-directing', 'self-dumping'],
    'automatic': ['accordant', 'accustomed', 'alike', 'automated', 'automatic device', 'automaton', 'automatous', 'balanced', 'beaten', 'blind', 'blowgun', 'blowpipe'],
    'automatic writing': ['ouija', 'artistry', 'authorcraft', 'authorship', 'automatism', 'blind impulse', 'cacoethes scribendi', 'composition', 'compulsiveness', 'conditioning', 'creative writing', 'drama-writing'],
    'automatism': ['ouija', 'automatic control', 'automatic writing', 'automation', 'automatization', 'bad habit', 'blind impulse', 'characteristic', 'compulsiveness', 'conditioning', 'creature of habit', 'custom'],
    'automobile': ['pcv valve', 'accelerator', 'alternator', 'ambulance', 'ammeter', 'armored car', 'auto', 'autocar', 'beach buggy', 'bearings', 'berlin', 'boat'],
    'autonomous': ['absolute', 'arbitrary', 'aristocratic', 'autarchic', 'autarkic', 'authoritarian', 'autocratic', 'bureaucratic', 'civic', 'civil', 'constitutional', 'democratic'],
    'autonomy': ['declaration of independence', 'absolute monarchy', 'aristocracy', 'autarchy', 'autarky', 'autocracy', 'autonomousness', 'coalition government', 'colonialism', 'commonwealth', 'constitutional government', 'constitutional monarchy'],
    'autopsy': ['canvass', 'check', 'check out', 'check over', 'check up on', 'coroner', 'examine', 'give an examination', 'go over', 'inquest', 'inspect', 'look at'],
    'autosuggestion': ['animal magnetism', 'hypnology', 'hypnosis', 'hypnotherapy', 'hypnotic suggestion', 'hypnotism', 'mesmerism', 'mesmerization', 'od', 'odyl', 'odylic force', 'posthypnotic suggestion'],
    'autumn': ['aestival', 'arctic', 'autumnal', 'boreal', 'brumal', 'canicular', 'equinoctial', 'fall', 'harvest', 'harvest home', 'harvest time', 'hibernal'],
    'auxiliary': ['abetting', 'accessory', 'accident', 'accidental', 'acolyte', 'addendum', 'addition', 'additional', 'adjunct', 'adjutant', 'adjuvant', 'adscititious'],
    'avail': ['abet', 'account', 'advance', 'advantage', 'aid', 'answer', 'applicability', 'appositeness', 'appropriateness', 'assist', 'bail out', 'be equal to'],
    'availability': ['access', 'accessibility', 'actual presence', 'applicability', 'approachability', 'being here', 'being there', 'come-at-ableness', 'effectiveness', 'efficacy', 'efficiency', 'existence'],
    'available': ['abandoned', 'accessible', 'adaptable', 'all-around', 'approachable', 'at hand', 'at leisure', 'at liberty', 'at loose ends', 'attainable', 'attendant', 'close by'],
    'avalanche': ['abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'blizzard', 'bonanza', 'bountifulness', 'bountiousness', 'bumper crop', 'coast', 'copiousness'],
    'avant garde': ['a la mode', 'advance guard', 'advanced', 'airhead', 'ancestor', 'announcer', 'antecedent', 'authentic', 'battle line', 'beachhead', 'bellwether', 'bridgehead'],
    'avarice': ['acedia', 'acquisitiveness', 'anger', 'avariciousness', 'avaritia', 'avidity', 'avidness', 'cheapness', 'closefistedness', 'closeness', 'covetousness', 'craving'],
    'avaricious': ['a hog for', 'acquisitive', 'all-devouring', 'avid', 'bottomless', 'cheap', 'close', 'closefisted', 'coveting', 'covetous', 'devouring', 'esurient'],
    'avatar': ['buddha', 'christophany', 'jagannath', 'juggernaut', 'kurma', 'matsya', 'narsinh', 'parshuram', 'rama', 'satanophany', 'vaman', 'varah'],
    'ave maria': ['angelus', 'ave', 'hail mary', 'kyrie eleison', 'paternoster', 'aid prayer', 'appeal', 'beadroll', 'beads', 'beseechment', 'bidding prayer', 'breviary'],
    'avenge': ['avengement', 'avenging', 'chasten', 'chastise', 'compensate', 'correct', 'counterblow', 'even the score', 'get even with', 'launch a vendetta', 'pay back', 'pay out'],
    'avenue': ['autobahn', 'us highway', 'access', 'aisle', 'alley', 'alleyway', 'ambulatory', 'aperture', 'arcade', 'arterial', 'arterial highway', 'arterial street'],
    'aver': ['acknowledge', 'affirm', 'allege', 'announce', 'annunciate', 'argue', 'assert', 'assever', 'asseverate', 'attest', 'avouch', 'avow'],
    'average': ['everyman', 'public', 'accustomed', 'amidships', 'as a rule', 'average man', 'average out', 'avoid extremes', 'balance', 'banal', 'besetting', 'bisect'],
    'average man': ['cockney', 'everyman', 'john smith', 'public', 'average', 'bourgeois', 'common man', 'common run', 'commoner', 'everyman', 'everywoman', 'generality'],
    'averse': ['abhorrent', 'afraid', 'allergic', 'anti', 'antipathetic', 'at odds', 'averse to', 'backward', 'balky', 'contrary', 'cursory', 'differing'],
    'aversion': ['anglophobia', 'russophobia', 'abhorrence', 'abomination', 'allergy', 'anathema', 'animosity', 'antagonism', 'anti-semitism', 'antipathy', 'averseness', 'backwardness'],
    'avert': ['about-face', 'anticipate', 'balk', 'bar', 'bear off', 'check', 'debar', 'deflect', 'deter', 'discourage', 'dishearten', 'divert'],
    'avian': ['altricial', 'anserine', 'anserous', 'aquiline', 'avicular', 'birdlike', 'birdy', 'columbine', 'dovelike', 'goosy', 'hawklike', 'nesting'],
    'avid': ['a hog for', 'acquisitive', 'agog', 'alacritous', 'all agog', 'all-devouring', 'animated', 'anxious', 'ardent', 'athirst', 'avaricious', 'bottomless'],
    'avidity': ['acquisitiveness', 'alacrity', 'animation', 'anxiety', 'anxiousness', 'appetite', 'avarice', 'avariciousness', 'avidness', 'breathless impatience', 'cheerful readiness', 'covetousness'],
    'avidly': ['animatedly', 'anxiously', 'avariciously', 'breathlessly', 'covetously', 'devouringly', 'eagerly', 'enthusiastically', 'graspingly', 'greedily', 'hoggishly', 'impatiently'],
    'avoid': ['abstain', 'abstain from', 'avert', 'be stuck-up', 'bilk', 'blench', 'blink', 'circumvent', 'cringe', 'debar', 'deflect', 'divert'],
    'avoidance': ['encratism', 'friday', 'lenten fare', 'pythagoreanism', 'pythagorism', 'rechabitism', 'shakerism', 'spartan fare', 'stoicism', 'abstainment', 'abstemiousness', 'abstention'],
    'avoirdupois': ['beef', 'beefiness', 'deadweight', 'fatness', 'gravity', 'gross weight', 'heaviness', 'heft', 'heftiness', 'liveweight', 'neat weight', 'net'],
    'avouch': ['acknowledge', 'admit', 'affirm', 'allege', 'announce', 'annunciate', 'argue', 'assert', 'assever', 'asseverate', 'assure', 'attest'],
    'avow': ['accept', 'acknowledge', 'admit', 'admit everything', 'affirm', 'agree provisionally', 'allege', 'allow', 'announce', 'annunciate', 'argue', 'assent grudgingly'],
    'avowal': ['acceptance', 'acknowledgment', 'admission', 'affidavit', 'affirmance', 'affirmation', 'allegation', 'allowance', 'announcement', 'annunciation', 'appreciation', 'assertion'],
    'avowed': ['accepted', 'acknowledged', 'admitted', 'affirmed', 'alleged', 'allowed', 'announced', 'approved', 'asserted', 'asseverated', 'attested', 'authenticated'],
    'await': ['abide', 'anticipate', 'approach', 'be destined', 'be fated', 'be imminent', 'be in store', 'be to be', 'be to come', 'bide', 'bide the issue', 'brew'],
    'awake': ['activate', 'agile', 'alert', 'alive', 'animate', 'annoy', 'apprehensive', 'arouse', 'aroused', 'attentive', 'au courant', 'awake to'],
    'awake to': ['alive to', 'appreciative of', 'apprised of', 'aware of', 'behind the curtain', 'behind the scenes', 'cognizant of', 'conscious of', 'hep to', 'in the know', 'in the secret', 'informed of'],
    'awaken': ['alert', 'annoy', 'arouse', 'awake', 'awaken to', 'be begotten', 'be born', 'be incarnated', 'become alive to', 'become aware of', 'become conscious of', 'bestir'],
    'award': ['academy award', 'christmas present', 'nobel prize', 'oscar', 'accolade', 'accommodation', 'accord', 'accordance', 'action', 'administer', 'afford', 'allocate'],
    'aware': ['acquainted', 'advertent', 'agog', 'alert', 'alive', 'alive to', 'all ears', 'all eyes', 'all-knowing', 'apperceptive', 'appercipient', 'appreciative of'],
    'awareness': ['advertence', 'advertency', 'alertness', 'apperception', 'appreciation', 'appreciativeness', 'assiduity', 'assiduousness', 'attention', 'attention span', 'attentiveness', 'care'],
    'awash': ['afloat', 'at flood', 'bathed', 'deluged', 'dipped', 'drenched', 'dribbling', 'dripping', 'dripping wet', 'drowned', 'engulfed', 'floating'],
    'away': ['a rebours', 'a reculons', 'absconded', 'absent', 'afar', 'against the grain', 'aloof', 'anticlockwise', 'apart', 'arear', 'aside', 'ass-backwards'],
    'awe': ['abject fear', 'admiration', 'adoration', 'affright', 'alarm', 'amaze', 'amazement', 'apotheosis', 'appall', 'appreciation', 'approbation', 'approval'],
    'awe inspiring': ['babylonian', 'corinthian', 'appalling', 'astounding', 'august', 'awesome', 'awful', 'awing', 'barbaric', 'bizarre', 'deluxe', 'dire'],
    'awesome': ['gargantuan', 'affecting', 'aggrandized', 'alarming', 'amazing', 'amplitudinous', 'apotheosized', 'appalling', 'astonishing', 'astounding', 'astronomical', 'august'],
    'awestruck': ['admiring', 'adoring', 'agape', 'aghast', 'agog', 'all agog', 'amazed', 'apotheosizing', 'appalled', 'ashen', 'astonished', 'astounded'],
    'awful': ['babylonian', 'corinthian', 'abominable', 'appalling', 'arrant', 'astounding', 'atrocious', 'august', 'awe-inspiring', 'awesome', 'awfully', 'awing'],
    'awfully': ['abominably', 'agonizingly', 'alarmingly', 'almighty', 'appallingly', 'astoundingly', 'atrociously', 'awe-inspiringly', 'awesomely', 'awful', 'awingly', 'badly'],
    'awkward': ['latinate', 'all thumbs', 'blankminded', 'blunderheaded', 'blundering', 'bombastic', 'boorish', 'bulky', 'bumbling', 'bungling', 'butterfingered', 'callow'],
    'awol': ['french leave', 'abscondence', 'absence', 'absence without leave', 'absent without leave', 'absentation', 'absenteeism', 'absenting', 'absquatulation', 'bolt', 'cut', 'day off'],
    'awry': ['aberrant', 'abroad', 'adrift', 'afield', 'agee', 'agee-jawed', 'all abroad', 'all off', 'all wrong', 'amiss', 'aside', 'askance'],
    'ax': ['amputate', 'battle-ax', 'beheading', 'bisect', 'blade', 'block', 'boot out', 'bounce', 'burning', 'butcher', 'can', 'capital punishment'],
    'axial': ['ascending', 'back', 'back-flowing', 'backward', 'centermost', 'central', 'centralized', 'centric', 'centroidal', 'centrosymmetric', 'concentrated', 'descending'],
    'axiom': ['a belief', 'a priori principle', 'a priori truth', 'absolute fact', 'accepted fact', 'actual fact', 'adage', 'admitted fact', 'affirmation', 'ana', 'analects', 'aphorism'],
    'axiomatic': ['absolute', 'actual', 'admitting no question', 'aphoristic', 'apparent', 'clear', 'clear as crystal', 'confirmable', 'crisp', 'crystal-clear', 'demonstrable', 'demonstratable'],
    'axis': ['bund', 'rochdale cooperative', 'air line', 'alliance', 'anthrophore', 'arbor', 'assemblage', 'association', 'axle', 'axle bar', 'axle shaft', 'axle spindle'],
    'aye': ['australian ballot', 'hare system', 'ok', 'acceptance', 'accord', 'acquiescence', 'affirmation', 'affirmative', 'affirmative attitude', 'affirmative voice', 'affirmativeness', 'agreed'],
    'azimuth': ['cartesian coordinates', 'abscissa', 'aim', 'altitude', 'aspect', 'attitude', 'bearing', 'bearings', 'bent', 'celestial navigation', 'compass bearing', 'compass direction'],
    'azure': ['caelus', 'achievement', 'air', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'azure-blue', 'azure-colored'],
    'baal': ['adad', 'adapa', 'anu', 'anunaki', 'ashtoreth', 'ashur', 'astarte', 'beltu', 'ceres', 'dagon', 'damkina', 'demeter'],
    'babbitt': ['middle american', 'philistine', 'anal character', 'arriviste', 'boeotian', 'boob', 'boor', 'bounder', 'bourgeois', 'burgher', 'cad', 'churl'],
    'babble': ['aesopian language', 'babel', 'greek', 'absurdity', 'amphigory', 'argot', 'babblement', 'baffle', 'balderdash', 'bavardage', 'be greek to', 'be beyond one'],
    'babbling': ['arrested', 'backward', 'blithering', 'bubbling', 'burbling', 'crackbrained', 'cracked', 'crazy', 'cretinistic', 'cretinous', 'delirious', 'dithering'],
    'babe': ['angel', 'baby', 'baby bunting', 'baby-doll', 'bambino', 'bantling', 'broad', 'buttercup', 'cherub', 'chick', 'chickabiddy', 'child'],
    'babel': ['aesopian language', 'greek', 'argot', 'babble', 'bedlam', 'cacophony', 'cant', 'cipher', 'clamor', 'clash', 'code', 'confusion of tongues'],
    'baby': ['elzevir', 'milquetoast', 'adolescent', 'angel', 'apprentice', 'babe', 'babish', 'baby bunting', 'baby-doll', 'baby-sized', 'babyish', 'bambino'],
    'baby grand': ['klavier', 'steinway', 'cembalo', 'clarichord', 'clavicembalo', 'clavichord', 'clavicittern', 'clavicymbal', 'clavicytherium', 'clavier', 'concert grand', 'cottage piano'],
    'baby sit': ['attend to', 'care for', 'chaperon', 'cherish', 'conserve', 'foster', 'keep watch over', 'look after', 'look out for', 'look to', 'matronize', 'mind'],
    'babyish': ['babish', 'baby', 'childish', 'childlike', 'doll-like', 'dollish', 'immature', 'in arms', 'in diapers', 'in nappies', 'in swaddling clothes', 'in the cradle'],
    'babylonian': ['corinthian', 'awe-inspiring', 'awful', 'barbaric', 'deluxe', 'elaborate', 'elegant', 'extravagant', 'fancy', 'fine', 'glorious', 'grand'],
    'bacchanal': ['alcoholic', 'alcoholic addict', 'bacchanalia', 'bacchanalian', 'bat', 'bender', 'bibber', 'big drunk', 'binge', 'boozer', 'bout', 'bust'],
    'bacchic': ['dionysiac', 'amok', 'berserk', 'corybantic', 'desperate', 'frantic', 'frenetic', 'frenzied', 'furious', 'like one possessed', 'mad', 'madding'],
    'bacchus': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'ceres', 'cora', 'cronus'],
    'bachelor': ['bayard', 'don quixote', 'gawain', 'lancelot', 'ritter', 'sidney', 'sir galahad', 'baccalaureate', 'baccalaureus', 'bach', 'banneret', 'baronet'],
    'bachelorhood': ['bachelordom', 'bachelorism', 'bachelorship', 'celibacy', 'continence', 'maidenhead', 'maidenhood', 'misogamy', 'misogyny', 'monachism', 'monasticism', 'single blessedness'],
    'bacillus': ['adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'bacteria', 'bacterium', 'bug', 'coccus', 'echovirus', 'enterovirus'],
    'back': ['a priori', 'a rebours', 'a reculons', 'abandon', 'abet', 'accented', 'acknowledgments', 'advance', 'advocate', 'affirm', 'afford support', 'aft'],
    'back and fill': ['about ship', 'alternate', 'battledore and shuttlecock', 'bear away', 'bear off', 'bear to starboard', 'beat', 'beat about', 'box off', 'break', 'bring about', 'bring round'],
    'back and forth': ['alternate', 'alternately', 'back-and-forth', 'backward and forward', 'backwards and forwards', 'capriciously', 'changeably', 'desultorily', 'erratically', 'hitch and hike', 'in and out', 'inconstantly'],
    'back burner': ['dinky', 'dispensable', 'immaterial', 'inappreciable', 'inconsequential', 'inconsiderable', 'inessential', 'inferior', 'insignificant', 'irrelevant', 'little', 'minor'],
    'back country': ['lebensraum', 'air space', 'back', 'back of beyond', 'backwood', 'backwoods', 'backwoodsy', 'boondock', 'boondocks', 'borderland', 'brush', 'bush country'],
    'back door': ['french door', 'afterpart', 'afterpiece', 'archway', 'back', 'back road', 'back seat', 'back side', 'back stairs', 'back street', 'back way', 'backstairs'],
    'back down': ['abjure', 'back off', 'back out', 'backpedal', 'backtrack', 'backwater', 'balance', 'balk', 'beat a retreat', 'beg off', 'break off combat', 'cave in'],
    'back matter': ['ps', 'parthian shot', 'acknowledgments', 'addendum', 'afterthought', 'appendix', 'article', 'back', 'bastard title', 'bibliography', 'book', 'catch line'],
    'back number': ['methuselah', 'antediluvian', 'antique', 'banal', 'behind the times', 'bewhiskered', 'bromidic', 'collection', 'common', 'commonplace', 'conservative', 'copy'],
    'back of beyond': ['china', 'darkest africa', 'god knows where', 'greenland', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'siberia', 'south pole', 'thule', 'tierra del fuego'],
    'back out': ['abandon', 'abjure', 'back down', 'backpedal', 'backwater', 'beat a retreat', 'beg off', 'boggle', 'chicken', 'chicken out', 'climb down', 'crawfish out'],
    'back scratching': ['apple-polishing', 'ass-kissing', 'backscratching', 'barter', 'bootlicking', 'brown-nosing', 'cringing', 'even trade', 'fawnery', 'fawning', 'flunkyism', 'footlicking'],
    'back seat': ['afterpart', 'afterpiece', 'back', 'back door', 'back side', 'behind', 'breech', 'heel', 'hind end', 'hind part', 'hindhead', 'humbleness'],
    'back stairs': ['back door', 'back road', 'back street', 'back way', 'bolt-hole', 'by-lane', 'bypass', 'bypath', 'byroad', 'bystreet', 'byway', 'companion'],
    'back talk': ['acknowledgment', 'answer', 'answering', 'antiphon', 'back answer', 'backchat', 'cheek', 'comeback', 'echo', 'evasive reply', 'guff', 'impudence'],
    'back to back': ['as one', 'as one man', 'at opposite extremes', 'behind', 'behind the scenes', 'coactively', 'coefficiently', 'collectively', 'combinedly', 'communally', 'concertedly', 'concordantly'],
    'back up': ['act for', 'advance', 'affirm', 'afford support', 'answer for', 'appear for', 'ascend', 'attest', 'authenticate', 'back', 'back away', 'back off'],
    'back way': ['back door', 'back road', 'back stairs', 'back street', 'bolt-hole', 'by-lane', 'bypass', 'bypath', 'byroad', 'bystreet', 'byway', 'covert way'],
    'backbiting': ['abuse', 'animadversion', 'backstabbing', 'belittlement', 'calumnious', 'calumny', 'defamation', 'defamatory', 'depreciation', 'detracting', 'disparagement', 'invective'],
    'backbone': ['advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backing', 'bandeau', 'bearer', 'bottom', 'bra', 'brace', 'bracer'],
    'backbreaking': ['herculean', 'annoying', 'arduous', 'besetting', 'bothersome', 'burdensome', 'crushing', 'effortful', 'forced', 'grueling', 'hard-earned', 'hard-fought'],
    'backdrop': ['act drop', 'arena', 'asbestos', 'asbestos board', 'back', 'background', 'batten', 'border', 'cloth', 'coulisse', 'counterweight', 'curtain'],
    'backed': ['accepted', 'acclaimed', 'admired', 'admitted', 'advocated', 'applauded', 'approved', 'calcified', 'callous', 'calloused', 'case-hardened', 'cried up'],
    'backer': ['dionysus', 'maecenas', 'samaritan', 'santa claus', 'abettor', 'acquaintance', 'admirer', 'advocate', 'aficionado', 'aid', 'aider', 'ally'],
    'backfire': ['backlash', 'backlashing', 'balefire', 'bang', 'beacon', 'beacon fire', 'blast', 'blaze', 'blow out', 'blow up', 'blowout', 'blowup'],
    'backflow': ['charybdis', 'maelstrom', 'back stream', 'backwash', 'backwater', 'countercurrent', 'counterflow', 'counterflux', 'eddy', 'gulf', 'gurge', 'maelstrom'],
    'background': ['action', 'agora', 'amphitheater', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'arena', 'argument', 'athletic field', 'atmosphere', 'auditorium'],
    'backhanded': ['o-shaped', 'abusive', 'ambagious', 'atrocious', 'backhand', 'calumnious', 'circuitous', 'circular', 'contumelious', 'deflectional', 'degrading', 'deviant'],
    'backing': ['brownian movement', 'smyth sewing', 'abetment', 'about-face', 'about-turn', 'advance', 'advocacy', 'advocate', 'advocating', 'aegis', 'affirmation', 'aid'],
    'backlash': ['antagonism', 'antipathy', 'backfire', 'backlashing', 'backwash', 'boomerang', 'bounce', 'bounce back', 'bound', 'carom', 'clashing', 'clout'],
    'backlog': ['abundance', 'accumulation', 'amassment', 'bavin', 'brush', 'brushwood', 'budget', 'cache', 'collection', 'commissariat', 'commissary', 'cornucopia'],
    'backpedal': ['arrest', 'back', 'back away', 'back off', 'back out', 'back up', 'backtrack', 'backtrail', 'backwater', 'brake', 'check', 'clip the wings'],
    'backseat driver': ['dutch uncle', 'paul pry', 'polonius', 'sunday driver', 'admonisher', 'adviser', 'bus driver', 'busman', 'busybody', 'buttinsky', 'cabby', 'cabdriver'],
    'backslapper': ['adulator', 'apple-polisher', 'ass-licker', 'backscratcher', 'blarneyer', 'bootlick', 'bootlicker', 'brown-nose', 'brownie', 'cajoler', 'clawback', 'courtier'],
    'backslide': ['cock', 'defect', 'degenerate', 'desert', 'err', 'fall', 'fall again into', 'fall astern', 'fall away', 'fall back', 'fall behind', 'fall from grace'],
    'backsliding': ['adamic', 'about-face', 'amorality', 'apostasy', 'apostate', 'atheism', 'atheistic', 'backing', 'backset', 'backslide', 'backward motion', 'backward step'],
    'backstage': ['dr', 'acting area', 'apron', 'apron stage', 'band shell', 'bandstand', 'before an audience', 'before the footlights', 'behind the scenes', 'board', 'bridge', 'coulisse'],
    'backstairs': ['back-door', 'clandestine', 'covert', 'feline', 'furtive', 'hidlings', 'hole-and-corner', 'hugger-mugger', 'privy', 'quiet', 'shifty', 'skulking'],
    'backstop': ['advocate', 'aegis', 'arch dam', 'arm guard', 'back', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier', 'bear-trap dam', 'beaver dam'],
    'backstroke': ['australian crawl', 'long melford', 'aquaplaning', 'aquatics', 'backhand', 'backhander', 'balneation', 'bathe', 'bathing', 'bolo punch', 'breaststroke', 'butterfly'],
    'backup': ['about-face', 'about-turn', 'advocate', 'agent', 'alter ego', 'alternate', 'alternative', 'amicus curiae', 'analogy', 'attorney', 'back track', 'back trail'],
    'backward': ['micawberish', 'olympian', 'a priori', 'a rebours', 'a reculons', 'about', 'afraid', 'aft', 'after', 'after time', 'aftermost', 'again'],
    'backwash': ['charybdis', 'maelstrom', 'back stream', 'backcountry', 'backflow', 'backlash', 'backwater', 'backwoods', 'boondocks', 'bush', 'clout', 'condensation trail'],
    'backwater': ['charybdis', 'maelstrom', 'abjure', 'arrest', 'back', 'back away', 'back down', 'back off', 'back out', 'back stream', 'back up', 'backcountry'],
    'backwoods': ['back', 'back country', 'back of beyond', 'back-country', 'backcountry', 'backwash', 'backwater', 'backwood', 'backwoodsy', 'boondock', 'boondocks', 'borderland'],
    'backwoodsman': ['briar-hopper', 'brush ape', 'bumpkin', 'bushman', 'clam digger', 'cracker', 'desert rat', 'forester', 'frontiersman', 'hick', 'hillbilly', 'hinterlander'],
    'bacon': ['butt', 'chitterlings', 'cochon de lait', 'cracklings', 'fat back', 'flitch', 'gammon', 'ham', 'ham steak', 'haslet', 'headcheese', 'jambon'],
    'bacteria': ['euglena', 'adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'animalcule', 'bacillus', 'bacterium', 'bug', 'coccus'],
    'bacteriology': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology', 'biometrics', 'biometry'],
    'bad': ['ok', 'abhorrent', 'abominable', 'abomination', 'ace-high', 'ailing', 'alarming', 'amiss', 'apocalyptic', 'arrant', 'atrocious', 'atrocity'],
    'bad blood': ['acrimony', 'animosity', 'animus', 'antagonism', 'antipathy', 'bad temper', 'bad will', 'bitter feeling', 'bitterness', 'blighting glance', 'clashing', 'collision'],
    'bad boy': ['booger', 'buffoon', 'bugger', 'cutup', 'devil', 'elf', 'enfant terrible', 'funmaker', 'hood', 'hoodlum', 'hooligan', 'imp'],
    'bad breath': ['bo', 'bad smell', 'body odor', 'fetidity', 'fetidness', 'fetor', 'foul breath', 'foul odor', 'frowst', 'graveolence', 'halitosis', 'malodor'],
    'bad character': ['bad name', 'bad odor', 'bad report', 'bad reputation', 'bad repute', 'disapprobation', 'discredit', 'disesteem', 'disfavor', 'dishonor', 'evil repute', 'ill fame'],
    'bad debt': ['accounts payable', 'accounts receivable', 'amount due', 'bad debts', 'bill', 'bills', 'borrowing', 'charges', 'chits', 'debt', 'default', 'defection'],
    'bad faith': ['machiavellianism', 'punic faith', 'ambidexterity', 'artifice', 'barratry', 'breach', 'breach of contract', 'breach of faith', 'breach of privilege', 'breach of promise', 'breach of trust', 'breaking'],
    'bad guy': ['roscius', 'actor', 'actress', 'antagonist', 'barnstormer', 'character', 'character actor', 'character man', 'character woman', 'child actor', 'diseur', 'diseuse'],
    'bad habit': ['automatism', 'besetting sin', 'characteristic', 'creature of habit', 'custom', 'failing', 'failure', 'fault', 'flaw', 'foible', 'force of habit', 'frailty'],
    'bad influence': ['jonah', 'rasputin', 'svengali', 'vip', 'access', 'big wheel', 'court', 'curse', 'eminence grise', 'enchantment', 'evil eye', 'evil genius'],
    'bad job': ['bevue', 'blunder', 'bobble', 'boggle', 'bonehead play', 'boner', 'boo-boo', 'botch', 'bungle', 'bungling', 'clumsy performance', 'error'],
    'bad language': ['billingsgate', 'blue language', 'colorful language', 'cursing', 'cussing', 'dirty language', 'dirty talk', 'dysphemism', 'evil speaking', 'filth', 'filthy language', 'foul language'],
    'bad lot': ['backslider', 'bad egg', 'black sheep', 'blighter', 'degenerate', 'fallen angel', 'good-for-nothing', 'lecher', 'lost sheep', 'lost soul', 'lowlife', 'miscreant'],
    'bad name': ['bad character', 'bad odor', 'bad report', 'bad reputation', 'bad repute', 'disapprobation', 'discredit', 'disesteem', 'disfavor', 'dishonor', 'evil repute', 'ill fame'],
    'bad news': ['aggravation', 'annoyance', 'bad child', 'bad example', 'bad man', 'bad person', 'bad woman', 'bedevilment', 'bore', 'bother', 'botheration', 'bothersomeness'],
    'bad notices': ['adverse criticism', 'animadversion', 'aspersion', 'bad press', 'captiousness', 'carping', 'cavil', 'caviling', 'censoriousness', 'criticism', 'exception', 'faultfinding'],
    'bad person': ['criminal', 'crook', 'deceiver', 'delinquent', 'evildoer', 'felon', 'gangster', 'lawbreaker', 'malefactor', 'malevolent', 'malfeasant', 'malfeasor'],
    'bad press': ['adverse criticism', 'animadversion', 'aspersion', 'bad notices', 'captiousness', 'carping', 'cavil', 'caviling', 'censoriousness', 'criticism', 'exception', 'faultfinding'],
    'bad taste': ['babbittry', 'gothicism', 'barbarism', 'barbarousness', 'bombasticness', 'bourgeois taste', 'cacology', 'cacophony', 'camp', 'campiness', 'clumsiness', 'coarseness'],
    'bad temper': ['irish', 'anger', 'asperity', 'bad blood', 'bad humor', 'bad will', 'bile', 'biliousness', 'blighting glance', 'causticity', 'choler', 'corrosiveness'],
    'badge': ['hershey bar', 'id card', 'accolade', 'armory', 'aroma', 'attribute', 'aviation badge', 'award', 'badge of office', 'badges', 'banner', 'bar'],
    'badger': ['aggravate', 'annoy', 'bait', 'be at', 'bedevil', 'beset', 'blackmail', 'bother', 'bristle', 'brown off', 'bug', 'bullyrag'],
    'badgered': ['baited', 'bedeviled', 'beset', 'bugged', 'bullyragged', 'chivied', 'deviled', 'dogged', 'harassed', 'harried', 'heckled', 'hectored'],
    'badinage': ['backchat', 'banter', 'chaff', 'chaffing', 'exchange', 'fooling', 'fooling around', 'give-and-take', 'good-natured banter', 'harmless teasing', 'jape', 'jest'],
    'badly': ['afield', 'amiss', 'astray', 'atrociously', 'awfully', 'awry', 'carelessly', 'critically', 'cruelly', 'damagingly', 'dangerously', 'defectively'],
    'badly off': ['depressed', 'dire', 'distressed', 'donsie', 'doomful', 'down to bedrock', 'embarrassed', 'evil-starred', 'fatal', 'feeling the pinch', 'fortuneless', 'funest'],
    'baffle': ['addle', 'amaze', 'babble', 'bafflement', 'balk', 'ball up', 'bamboozle', 'be greek to', 'be beyond one', 'be too deep', 'beat', 'beat one'],
    'baffled': ['addled', 'at a loss', 'at a nonplus', 'at a stand', 'at a standstill', 'at an impasse', 'balked', 'bamboozled', 'beat', 'betrayed', 'bewildered', 'bilked'],
    'bafflement': ['baffle', 'balk', 'balking', 'betrayed hope', 'bewilderment', 'blasted expectation', 'blighted hope', 'blow', 'bother', 'buffet', 'check', 'checkmate'],
    'baffling': ['bewildering', 'bothering', 'confounding', 'confusing', 'defeating', 'discomposing', 'disconcerting', 'dismaying', 'distracting', 'disturbing', 'embarrassing', 'enigmatic'],
    'bag': ['iud', 'abstract', 'acquire', 'activities', 'activity', 'affair', 'affairs', 'affinity', 'and', 'annex', 'appropriate', 'area'],
    'bagatelle': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'bauble', 'bean', 'bibelot', 'bit', 'brass farthing', 'button', 'cent'],
    'bagel': ['danish', 'danish pastry', 'english muffin', 'parker house roll', 'yorkshire pudding', 'bialy', 'bialystoker', 'bun', 'clover-leaf roll', 'coffee cake', 'crescent roll', 'croissant'],
    'baggage': ['gladstone', 'jezebel', 'apparatus', 'attache case', 'backpack', 'bad woman', 'bag', 'bag and baggage', 'bandbox', 'bitch', 'briefcase', 'broad'],
    'baggy': ['amorphic', 'amorphous', 'anarchic', 'bagging', 'ballooning', 'bellying', 'billowing', 'billowy', 'bloated', 'blobby', 'blurred', 'blurry'],
    'bail': ['arraignment', 'bond', 'bucket', 'charge', 'cup', 'decant', 'dip', 'dish', 'dish out', 'dish up', 'earnest', 'earnest money'],
    'bail bond': ['accident insurance', 'actuary', 'annuity', 'assurance', 'aviation insurance', 'bond', 'business life insurance', 'casualty insurance', 'certificate of insurance', 'court bond', 'credit insurance', 'credit life insurance'],
    'bail out': ['abet', 'aid', 'arise', 'assist', 'avail', 'bear a hand', 'befriend', 'benefit', 'break away', 'break cover', 'break forth', 'break jail'],
    'bailiff': ['g-man', 'mc', 'mp', 'attorney', 'beadle', 'beagle', 'bound bailiff', 'butler', 'captain', 'catchpole', 'chief of police', 'commissioner'],
    'bailiwick': ['kreis', 'ambit', 'archbishopric', 'archdiocese', 'arena', 'arrondissement', 'beat', 'bishopric', 'border', 'borderland', 'borough', 'bureau'],
    'bairn': ['cherub', 'child', 'chit', 'darling', 'innocent', 'kid', 'kitten', 'lamb', 'lambkin', 'little bugger', 'little fellow', 'little guy'],
    'bait': ['aggravate', 'allure', 'allurement', 'annoy', 'badger', 'bait the hook', 'baited trap', 'be at', 'bedevil', 'beset', 'birdlime', 'bite'],
    'baited': ['badgered', 'bedeviled', 'beset', 'bugged', 'bullyragged', 'chivied', 'deviled', 'dogged', 'harassed', 'harried', 'heckled', 'hectored'],
    'bake': ['air-dry', 'anhydrate', 'barbecue', 'baste', 'be in heat', 'blanch', 'blaze', 'bloom', 'blot', 'boil', 'braise', 'brew'],
    'baked': ['adust', 'boiled', 'braised', 'broiled', 'browned', 'burnt', 'coddled', 'cooked', 'corky', 'curried', 'dehydrated', 'desiccated'],
    'baker': ['bookdealer', 'bookseller', 'butcher', 'chandler', 'chef', 'chef de cuisine', 'chief cook', 'clothing merchant', 'confectioner', 'cook', 'culinarian', 'culinary artist'],
    'bakery': ['appetizing store', 'bakehouse', 'bakeshop', 'bodega', 'butcher shop', 'caboose', 'camboose', 'cookery', 'cookhouse', 'cookroom', 'creamery', 'cuisine'],
    'baking': ['ardent', 'barbecuing', 'basting', 'blistering', 'boiling', 'braising', 'brewing', 'broil', 'broiling', 'burning', 'burning hot', 'canicular'],
    'balance': ['swiss bank account', 'accommodate', 'accord', 'account', 'account current', 'account rendered', 'account stated', 'adjust', 'afterglow', 'afterimage', 'agree', 'amount to'],
    'balance of power': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'appeasement', 'ascendance', 'ascendancy', 'brinkmanship', 'coexistence', 'colonialism', 'compromise', 'containment'],
    'balance of trade': ['big business', 'business', 'business dealings', 'commerce', 'commercial affairs', 'commercial relations', 'dealing', 'dealings', 'fair trade', 'free trade', 'industry', 'intercourse'],
    'balance sheet': ['account book', 'accounts payable ledger', 'accounts receivable ledger', 'bank ledger', 'bankbook', 'books', 'card ledger', 'cashbook', 'cost card', 'cost ledger', 'cost sheet', 'daybook'],
    'balanced': ['accordant', 'alike', 'all there', 'apoise', 'assured', 'automatic', 'clearheaded', 'clearminded', 'coequal', 'collected', 'commonsense', 'compos mentis'],
    'balancing': ['adversative', 'adverse', 'adversive', 'allegory', 'amendatory', 'amends', 'analogy', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'antonymous'],
    'balcony': ['auditorium', 'box', 'box seat', 'catafalque', 'dais', 'dress circle', 'emplacement', 'estrade', 'fauteuil', 'floor', 'gallery', 'heliport'],
    'bald': ['spartan', 'acomous', 'ascetic', 'austere', 'bald-headed', 'bare', 'bare-ass', 'beardless', 'blank', 'candid', 'clean-shaven', 'clear'],
    'balder': ['adonis', 'aesir', 'aphrodite', 'apollo', 'apollo belvedere', 'astarte', 'bor', 'bori', 'bragi', 'cleopatra', 'donar', 'forseti'],
    'balderdash': ['absurdity', 'amphigory', 'babble', 'babblement', 'bibble-babble', 'bilge', 'blabber', 'blather', 'bombast', 'bombastry', 'bosh', 'bushwa'],
    'bale': ['aching heart', 'agony', 'agony of mind', 'anguish', 'bind up', 'bindle', 'bitterness', 'bleeding heart', 'bolt', 'bouquet', 'broken heart', 'budget'],
    'balefire': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'backfire', 'beacon', 'beacon fire', 'bell', 'bell buoy', 'blaze', 'blinker', 'blue peter'],
    'baleful': ['apocalyptic', 'bad', 'baneful', 'bitchy', 'black', 'bodeful', 'boding', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'counterproductive'],
    'balk': ['baffle', 'bafflement', 'balk at', 'balking', 'be unwilling', 'beam', 'beat', 'begrudge', 'betrayed hope', 'bevue', 'bilk', 'blast'],
    'balked': ['baffled', 'betrayed', 'bilked', 'blasted', 'blighted', 'chapfallen', 'crestfallen', 'crossed', 'crushed', 'dashed', 'defeated', 'disappointed'],
    'ball': ['kaffeeklatsch', 'action', 'agate', 'assemblee', 'assembly', 'assignation', 'at home', 'bal', 'bal costume', 'bal masque', 'ball bearing', 'balloon'],
    'ball of fire': ['activist', 'beaver', 'big-time operator', 'bustler', 'busy bee', 'doer', 'eager beaver', 'enthusiast', 'go-getter', 'human dynamo', 'hustler', 'live wire'],
    'ball the jack': ['barrel', 'boom', 'bowl along', 'breeze', 'breeze along', 'brush', 'clip', 'cut along', 'fleet', 'flit', 'fly', 'fly low'],
    'ball up': ['addle', 'addle the wits', 'becloud', 'bedazzle', 'befuddle', 'bewilder', 'bollix', 'bollix up', 'bother', 'bug', 'bugger', 'bugger up'],
    'ballad': ['brautlied', 'christmas carol', 'english sonnet', 'horatian ode', 'italian sonnet', 'kunstlied', 'liebeslied', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'volkslied'],
    'balladeer': ['arranger', 'ballad maker', 'ballad singer', 'balladist', 'balladmonger', 'bard', 'composer', 'contrapuntist', 'ethnomusicologist', 'fili', 'folk singer', 'folk-rock singer'],
    'balladmonger': ['meistersinger', 'parnassian', 'arch-poet', 'arranger', 'ballad maker', 'balladeer', 'balladist', 'bard', 'beat poet', 'bucoliast', 'composer', 'contrapuntist'],
    'ballast': ['balance', 'break bulk', 'break out ballast', 'clear for action', 'clear the decks', 'consideration', 'counterbalance', 'counterpoise', 'counterweight', 'equipoise', 'equivalent', 'firm'],
    'balled up': ['byzantine', 'anarchic', 'arsy-varsy', 'ass-backwards', 'bollixed up', 'bothered', 'buggered', 'buggered up', 'chaotic', 'complex', 'complicated', 'confounded'],
    'ballerina': ['ballet dancer', 'ballet girl', 'ballroom dancer', 'choral dancer', 'chorus boy', 'chorus girl', 'clog dancer', 'coryphee', 'dancer', 'dancing girl', 'danseur', 'danseur noble'],
    'ballet': ['broadway musical', 'grand guignol', 'passion play', 'singspiel', 'tom show', 'antimasque', 'audience success', 'ballad opera', 'ballet divertissement', 'ballroom dancing', 'bomb', 'broadcast drama'],
    'balletic': ['actor-proof', 'all-star', 'ballet', 'cinematic', 'cinematographic', 'dance', 'dancing', 'dramatic', 'dramatical', 'dramaturgic', 'film', 'filmic'],
    'balloon': ['graf zeppelin', 'accrue', 'accumulate', 'advance', 'aeroplane', 'aerostat', 'air bubble', 'airlift', 'airplane', 'airship', 'appreciate', 'bag'],
    'ballooning': ['access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'aeronautics', 'aggrandizement', 'air service', 'airline'],
    'ballot': ['australian ballot', 'hare system', 'indiana ballot', 'massachusetts ballot', 'absentee ballot', 'aye', 'blanket ballot', 'canvass', 'canvassing', 'casting vote', 'counting heads', 'cumulative voting'],
    'ballplayer': ['amateur athlete', 'archer', 'athlete', 'baseballer', 'baseman', 'batter', 'battery', 'blocking back', 'bowman', 'catcher', 'center', 'coach'],
    'ballroom': ['amusement park', 'cabaret', 'cafe chantant', 'cafe dansant', 'casino', 'chamber', 'chambre', 'dance floor', 'dance hall', 'dancery', 'dancing pavilion', 'entertainment industry'],
    'balls': ['adventuresomeness', 'adventurousness', 'audaciousness', 'audacity', 'bag', 'ballocks', 'baloney', 'basket', 'beard', 'blague', 'bosh', 'bravado'],
    'ballyhoo': ['pr', 'advertise', 'aggrandize', 'aggrandizement', 'amplification', 'amplify', 'bark', 'big talk', 'bill', 'blowing up', 'blurb', 'boost'],
    'ballyhoo man': ['mc', 'auteur', 'ballyhooer', 'barker', 'callboy', 'canvasser', 'costume designer', 'costumer', 'costumier', 'director', 'emcee', 'equestrian director'],
    'balm': ['mentholatum', 'vaseline', 'aid', 'allay', 'alleviative', 'alleviator', 'alterative', 'ambergris', 'ambrosia', 'analeptic', 'anodyne', 'aroma'],
    'balmy': ['saturnian', 'absurd', 'agreeable', 'allaying', 'alleviating', 'alleviative', 'ambrosial', 'analgesic', 'anesthetic', 'anodyne', 'aromatic', 'assuaging'],
    'balneation': ['australian crawl', 'aquaplaning', 'aquatics', 'backstroke', 'bathe', 'bathing', 'breaststroke', 'butterfly', 'crawl', 'diving', 'dog paddle', 'fin'],
    'baloney': ['applesauce', 'balls', 'bilge', 'blague', 'blah', 'blah-blah', 'bop', 'bosh', 'bull', 'bullshit', 'bunk', 'bunkum'],
    'balsam': ['aid', 'alterative', 'ambergris', 'ambrosia', 'analeptic', 'aromatic', 'aromatic gum', 'aromatic water', 'assistance', 'attar', 'attar of roses', 'balm'],
    'balustrade': ['samson post', 'baluster', 'banister', 'barrier', 'base', 'boundary', 'caryatid', 'colonnade', 'column', 'dado', 'die', 'doorjamb'],
    'bamboo curtain': ['berlin wall', 'pillars of hercules', 'arch dam', 'backstop', 'bank', 'bar', 'barrage', 'barrier', 'barrier of secrecy', 'bear-trap dam', 'beaver dam', 'blackout'],
    'bamboozle': ['addle', 'amaze', 'baffle', 'beat', 'befool', 'beguile', 'betray', 'bilk', 'bluff', 'boggle', 'buffalo', 'cajole'],
    'bamboozled': ['addled', 'at a loss', 'baffled', 'beat', 'buffaloed', 'confounded', 'dazed', 'floored', 'fuddled', 'in a dilemma', 'in suspense', 'licked'],
    'ban': ['eighteenth amendment', 'prohibition party', 'volstead act', 'abscind', 'amputate', 'anathema', 'annihilate', 'banish', 'banishment', 'bar', 'bar out', 'barring'],
    'banal': ['asinine', 'average', 'back-number', 'bewhiskered', 'bland', 'bromidic', 'central', 'cliched', 'common', 'commonplace', 'corny', 'cut-and-dried'],
    'banality': ['banalness', 'bromide', 'chestnut', 'cliche', 'commonness', 'commonplace', 'commonplace expression', 'commonplaceness', 'corn', 'corniness', 'familiar tune', 'familiarness'],
    'banana': ['burlesquer', 'caricaturist', 'clown', 'comedian', 'comic', 'cutup', 'epigrammatist', 'funnyman', 'gag writer', 'gagman', 'gagster', 'humorist'],
    'bananas': ['balmy', 'barmy', 'bats', 'batty', 'beany', 'bonkers', 'buggy', 'bughouse', 'bugs', 'crackers', 'cuckoo', 'daffy'],
    'band': ['ace bandage', 'band-aid', 'bund', 'german band', 'mystik tape', 'philharmonic', 'rochdale cooperative', 'scotch tape', 'accouple', 'accumulate', 'act in concert', 'act together'],
    'band aid': ['ace bandage', 'adhesive tape', 'application', 'band', 'bandage', 'bandaging', 'binder', 'brace', 'cast', 'cataplasm', 'compress', 'cotton'],
    'band shell': ['acting area', 'apron', 'apron stage', 'backstage', 'bandstand', 'board', 'bridge', 'coulisse', 'dock', 'dressing room', 'flies', 'fly floor'],
    'band together': ['accompany', 'act in concert', 'act together', 'affiliate', 'ally', 'amalgamate', 'associate', 'associate with', 'assort with', 'attend', 'band', 'be in cahoots'],
    'bandage': ['ace bandage', 'band-aid', 'mystik tape', 'scotch tape', 'adhesive tape', 'application', 'band', 'bandaging', 'bathe', 'batten', 'bedazzle', 'belt'],
    'bandeau': ['achievement', 'advocate', 'alerion', 'alpenstock', 'animal charge', 'annulet', 'argent', 'arm', 'armorial bearings', 'armory', 'arms', 'athletic supporter'],
    'banded': ['barred', 'brinded', 'brindle', 'brindled', 'listed', 'marbled', 'marbleized', 'streaked', 'streaky', 'striatal', 'striate', 'striated'],
    'bandit': ['air armada', 'air force', 'badman', 'bogey', 'bravo', 'brigand', 'bummer', 'combat plane', 'cutthroat', 'dacoit', 'desperado', 'enemy aircraft'],
    'banditry': ['armed robbery', 'asportation', 'assault and robbery', 'bank robbery', 'brigandage', 'brigandism', 'cattle lifting', 'cattle stealing', 'depredation', 'despoiling', 'despoilment', 'despoliation'],
    'bandog': ['cerberus', 'seeing eye dog', 'bitch', 'bowwow', 'canine', 'dog', 'fancy dog', 'guard dog', 'guide dog', 'gyp', 'kennel', 'lap dog'],
    'bandstand': ['acting area', 'apron', 'apron stage', 'backstage', 'band shell', 'board', 'bridge', 'coulisse', 'dock', 'dressing room', 'flies', 'fly floor'],
    'bandy': ['alternate', 'answer', 'arched', 'arciform', 'arclike', 'arcual', 'bandy-legged', 'banter', 'be quits with', 'blemished', 'bloated', 'bowed'],
    'bandy words': ['argue', 'argufy', 'bicker', 'cavil', 'chew the fat', 'chew the rag', 'chin', 'choplogic', 'colloque', 'colloquize', 'commerce with', 'commune with'],
    'bane': ['abomination', 'annihilation', 'atrocity', 'bad', 'befoulment', 'biological death', 'blight', 'blood', 'bloodletting', 'bloodshed', 'braining', 'cessation of life'],
    'baneful': ['apocalyptic', 'appalling', 'atrocious', 'awful', 'bad', 'baleful', 'beastly', 'black', 'bodeful', 'boding', 'brutal', 'calamitous'],
    'bang': ['abruptly', 'accurately', 'aggressiveness', 'antitoxin', 'backfire', 'bag', 'bang into', 'bangs', 'bar', 'bark', 'barricade', 'bash'],
    'bang up': ['ok', 'ace-high', 'bad', 'bonzer', 'boss', 'bully', 'but good', 'cool', 'corking', 'crackerjack', 'dandy', 'delicious'],
    'bangers': ['vienna sausage', 'black pudding', 'blood pudding', 'bologna', 'braunschweiger', 'frank', 'frankfurter', 'gooseliver', 'headcheese', 'hot dog', 'knockwurst', 'liver sausage'],
    'banging': ['blasting', 'bumping', 'bursting', 'cracking', 'crashing', 'exploding', 'explosive', 'flapping', 'knocking', 'popping', 'rapping', 'slapping'],
    'bangle': ['anklet', 'armlet', 'beads', 'bijou', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet', 'charm', 'chatelaine', 'circle'],
    'banish': ['ban', 'blackball', 'blacklist', 'boycott', 'bump', 'can', 'cashier', 'cast out', 'cut', 'debar', 'deport', 'discharge'],
    'banishment': ['ban', 'blackball', 'blackballing', 'blacklist', 'boycott', 'boycottage', 'defrocking', 'degradation', 'demotion', 'depluming', 'deportation', 'deprivation'],
    'banister': ['samson post', 'baluster', 'balustrade', 'base', 'caryatid', 'colonnade', 'column', 'dado', 'die', 'doorjamb', 'doorpost', 'footstalk'],
    'banjo': ['dobro guitar', 'f-hole guitar', 'spanish guitar', 'archlute', 'balalaika', 'banjo-uke', 'banjo-ukulele', 'banjo-zither', 'banjorine', 'banjuke', 'bass guitar', 'centerhole guitar'],
    'banjo eyes': ['baby blues', 'bright eyes', 'clear eyes', 'cornea', 'eye', 'eyeball', 'eyelid', 'goggle eyes', 'iris', 'lens', 'lid', 'naked eye'],
    'bank': ['bank of england', 'bank of france', 'federal reserve bank', 'fort knox', 'indian file', 'indian reservation', 'international monetary fund', 'lombard street bank', 'swiss bank', 'world bank', 'abatis', 'abutment'],
    'bank on': ['aspire to', 'bargain for', 'bet on', 'calculate on', 'confide', 'count on', 'depend on', 'desire', 'expect', 'feel confident', 'figure on', 'gamble on'],
    'bankbook': ['account book', 'accounts payable ledger', 'accounts receivable ledger', 'balance sheet', 'bank ledger', 'books', 'card ledger', 'cashbook', 'cost card', 'cost ledger', 'cost sheet', 'daybook'],
    'banker': ['shylock', 'bank clerk', 'bank manager', 'bank officer', 'bank president', 'banking executive', 'baron', 'big boss', 'big businessman', 'bill broker', 'business leader', 'businessman'],
    'banking': ['acrobatics', 'aerobatics', 'chandelle', 'crabbing', 'dive', 'diving', 'fishtailing', 'glide', 'investment banking', 'money changing', 'money dealing', 'nose dive'],
    'bankroll': ['angel', 'back', 'capitalize', 'finance', 'fund', 'grubstake', 'patronize', 'pay for', 'provide for', 'refinance', 'roll', 'set up'],
    'bankrupt': ['almsman', 'almswoman', 'also-ran', 'ausgespielt', 'bankrupt in', 'bare', 'bare of', 'beggar', 'bereft of', 'blasted', 'blighted', 'break'],
    'bankruptcy': ['bouncing check', 'breakage', 'breakdown', 'bust', 'collapse', 'crack-up', 'crash', 'crippling', 'damage', 'defeat', 'destruction', 'detriment'],
    'banned': ['barred', 'contraband', 'debarred', 'deported', 'ejected', 'excluded', 'exiled', 'expelled', 'forbade', 'forbid', 'forbidden', 'illegal'],
    'banner': ['communist threat', 'dannebrog', 'jolly roger', 'old glory', 'star-spangled banner', 'stars and stripes', 'union flag', 'union jack', 'western imperialism', 'and blue', 'arch', 'atrocity story'],
    'banneret': ['bayard', 'dannebrog', 'don quixote', 'gawain', 'jolly roger', 'lancelot', 'old glory', 'ritter', 'sidney', 'sir galahad', 'star-spangled banner', 'stars and stripes'],
    'banns': ['gretna green wedding', 'affiance', 'banns of matrimony', 'betrothal', 'betrothment', 'bridal', 'bridal suite', 'bridechamber', 'chuppah', 'church wedding', 'civil ceremony', 'civil wedding'],
    'banquet': ['lucullan feast', 'mardi gras', 'saturnalia', 'bean-feast', 'beano', 'blow', 'blowout', 'carnival', 'carouse', 'celebration', 'do', 'do justice to'],
    'banshee': ['ariel', 'befind', 'corrigan', 'finnbeara', 'mab', 'masan', 'oberon', 'titania', 'apparition', 'appearance', 'astral', 'astral spirit'],
    'bantam': ['arch', 'baby', 'baby-sized', 'banty', 'button', 'chit', 'compact', 'diminutive', 'duodecimo', 'featherweight', 'fingerling', 'handy'],
    'bantamweight': ['chinese boxer', 'black belt', 'boxer', 'brown belt', 'bruiser', 'catchweight', 'featherweight', 'fighter', 'fisticuffer', 'flyweight', 'heavyweight', 'karate expert'],
    'banter': ['backchat', 'badinage', 'beard', 'blandish', 'blarney', 'booing', 'brave', 'buffoonery', 'cajole', 'catcalling', 'chaff', 'chaffing'],
    'bantering': ['booing', 'catcalling', 'chaffing', 'derisive', 'derisory', 'fleering', 'flippant', 'fooling', 'grinning', 'hazing', 'hissing', 'hooting'],
    'banty': ['bantam', 'baby', 'baby-sized', 'bantam', 'barn-door fowl', 'barnyard fowl', 'biddy', 'broiler', 'brooder', 'broody hen', 'button', 'capon'],
    'banzai': ['bugle call', 'call to arms', 'call-up', 'catchword', 'clarion', 'clarion call', 'conscription', 'exhortation', 'go for broke', 'gung ho', 'levy', 'mobilization'],
    'baptism': ['acceptance', 'admission', 'admittance', 'affusion', 'appellation', 'aspergation', 'aspersion', 'baptismal gown', 'baptismal regeneration', 'baptistery', 'baptizement', 'bath'],
    'baptismal': ['high-church', 'ceremonial', 'ceremonious', 'eucharistic', 'formal', 'formular', 'formulary', 'initiative', 'initiatory', 'introductive', 'introductory', 'liturgic'],
    'baptistery': ['easter sepulcher', 'affusion', 'ambry', 'apse', 'aspergation', 'aspersion', 'baptism', 'baptismal gown', 'baptismal regeneration', 'baptizement', 'blindstory', 'chancel'],
    'baptize': ['adulterate', 'asperge', 'asperse', 'attenuate', 'bath', 'bathe', 'bury', 'call', 'christen', 'cleanse', 'cut', 'define'],
    'bar': ['hershey bar', 'maypole', 'abscind', 'accent', 'accent mark', 'achievement', 'ait', 'alehouse', 'alerion', 'ambo', 'amputate', 'animal charge'],
    'bar mitzvah': ['agape', 'asperges', 'aspersion', 'auricular confession', 'bas mitzvah', 'celebration', 'circumcision', 'confession', 'confirmation', 'high celebration', 'incense', 'invocation'],
    'bar sinister': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'aspersion', 'attaint', 'azure', 'badge of infamy'],
    'barb': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'barbarian': ['goth', 'gothic', 'neanderthal', 'uitlander', 'alien', 'animal', 'anthropophagite', 'backward', 'barbaric', 'barbarous', 'beast', 'bestial'],
    'barbaric': ['doric', 'draconian', 'gothic', 'neanderthal', 'philistine', 'tartarean', 'aggressive', 'alien', 'animal', 'anthropophagous', 'atrocious', 'barbarian'],
    'barbarism': ['gothicism', 'irish bull', 'neanderthalism', 'age of ignorance', 'animality', 'antiphrasis', 'bad taste', 'barbarity', 'barbarousness', 'benightedness', 'benightment', 'bestiality'],
    'barbarity': ['gothicism', 'neanderthalism', 'acuteness', 'animality', 'atrociousness', 'atrocity', 'barbarism', 'barbarousness', 'beastliness', 'bestiality', 'bloodiness', 'bloodlust'],
    'barbarous': ['doric', 'draconian', 'gothic', 'neanderthal', 'philistine', 'tartarean', 'alien', 'animal', 'anthropophagous', 'atrocious', 'backward', 'barbarian'],
    'barbecue': ['tv dinner', 'alfresco meal', 'aspic', 'bake', 'baste', 'blanch', 'boil', 'boiled meat', 'bouilli', 'braise', 'breakfast', 'brew'],
    'barbecued': ['baked', 'boiled', 'braised', 'broiled', 'browned', 'coddled', 'cooked', 'curried', 'deviled', 'fired', 'fricasseed', 'fried'],
    'barbed': ['acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'cornuted', 'cusped', 'cuspidate', 'hispid'],
    'barbel': ['antenna', 'barb', 'barbule', 'bristle', 'cat whisker', 'feeler', 'palp', 'palpus', 'setula', 'setule', 'striga', 'stubble'],
    'barber': ['beautician', 'beautifier', 'bob', 'clipper', 'coif', 'coiffeur', 'coiffeuse', 'coiffure', 'conk', 'cropper', 'hairdresser', 'manicurist'],
    'barbershop': ['agency', 'atelier', 'beauty parlor', 'beauty salon', 'beauty shop', 'bench', 'butcher shop', 'company', 'concern', 'corporation', 'desk', 'establishment'],
    'barbican': ['abatis', 'advanced work', 'antenna tower', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barricade', 'barrier', 'bartizan', 'bastion', 'battlement'],
    'barbiturate': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'barbiturism': ['a habit', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'addiction', 'alcoholism', 'barbiturate addiction', 'chain smoking', 'chronic alcoholism', 'cocainism', 'crash', 'craving'],
    'barbule': ['antenna', 'barb', 'barbel', 'barrel', 'cat whisker', 'cilium', 'feeler', 'filament', 'filamentule', 'palp', 'palpus', 'quill'],
    'bard': ['meistersinger', 'parnassian', 'arch-poet', 'ballad maker', 'ballad singer', 'balladeer', 'balladmonger', 'beat poet', 'bucoliast', 'elegist', 'epic poet', 'fili'],
    'bare': ['spartan', 'absolute', 'and', 'ascetic', 'austere', 'bald', 'bankrupt', 'bare-ass', 'bared', 'barren', 'basic', 'bland'],
    'bare handed': ['bare-ankled', 'bare-armed', 'bare-backed', 'bare-breasted', 'bare-chested', 'bare-headed', 'bare-legged', 'bare-necked', 'beggarly', 'defenseless', 'empty-handed', 'famished'],
    'bare necessities': ['call for', 'demand', 'demand for', 'desideration', 'desideratum', 'essential', 'essentials', 'indispensable', 'must', 'must item', 'necessaries', 'necessities'],
    'bare of': ['bankrupt in', 'bereft of', 'denuded of', 'deprived of', 'destitute of', 'devoid of', 'empty of', 'for want of', 'forlorn of', 'in default of', 'in want of', 'lacking'],
    'bare possibility': ['chance', 'conceivability', 'conceivableness', 'contingency', 'dark horse', 'doubtfulness', 'dubiousness', 'even chance', 'eventuality', 'faint likelihood', 'fighting chance', 'gambling chance'],
    'barefaced': ['arrant', 'audacious', 'aweless', 'bare-ankled', 'bare-armed', 'bare-backed', 'bare-breasted', 'bare-chested', 'bare-handed', 'bare-headed', 'bare-legged', 'bare-necked'],
    'barely': ['a bit', 'a little', 'alone', 'baldly', 'by a hair', 'by an ace', 'closely', 'ever so little', 'exclusively', 'exiguously', 'faintly', 'feebly'],
    'barf': ['be nauseated', 'be seasick', 'be sick', 'bring up', 'cascade', 'cast', 'choke on', 'chuck up', 'disgorge', 'disgorgement', 'egest', 'egesta'],
    'barfly': ['alcoholic', 'alcoholic addict', 'bacchanal', 'bacchanalian', 'bibber', 'big drunk', 'boozer', 'carouser', 'chronic alcoholic', 'chronic drunk', 'devotee of bacchus', 'dipsomaniac'],
    'barfy': ['airsick', 'bad', 'brackish', 'bum', 'carsick', 'cheesy', 'cloying', 'crappy', 'creepy', 'crummy', 'dirty', 'disgusting'],
    'bargain': ['abatement of differences', 'accommodation', 'accord', 'act between', 'adjustment', 'advantageous purchase', 'advise with', 'agree', 'agree to', 'agreement', 'allow for', 'anticipate'],
    'bargain for': ['agree', 'agree to', 'bank on', 'bargain', 'be a bargain', 'be a deal', 'be a go', 'be on', 'calculate on', 'come to terms', 'compact', 'contract'],
    'bargaining': ['audience', 'bargaining session', 'chaffer', 'chaffering', 'collective bargaining', 'coming to terms', 'conclave', 'confab', 'confabulation', 'conference', 'confrontation', 'congress'],
    'barge': ['amble', 'boat', 'bowl along', 'bundle', 'bus', 'cart', 'clump', 'coach', 'drag', 'dray', 'ferry', 'float'],
    'barge in': ['admit', 'be admitted', 'break in', 'break in upon', 'breeze in', 'burst in', 'bust in', 'butt in', 'charge in', 'come barging in', 'come between', 'come breezing in'],
    'baring': ['apocalypse', 'denudation', 'desquamation', 'disclosing', 'disclosure', 'discovering', 'discovery', 'divestment', 'excoriation', 'exfoliation', 'exhibitionism', 'expose'],
    'baritone': ['heldentenor', 'meistersinger', 'accompaniment', 'alpenhorn', 'alphorn', 'althorn', 'alto', 'alto horn', 'aria singer', 'ballad horn', 'baritenor', 'bass'],
    'bark': ['ablate', 'abrade', 'abrase', 'advertise', 'animal noise', 'argosy', 'ballyhoo', 'bang', 'barking', 'battle cry', 'bawl', 'bay'],
    'barker': ['mc', 'auteur', 'ballyhoo man', 'ballyhooer', 'callboy', 'canvasser', 'costume designer', 'costumer', 'costumier', 'director', 'emcee', 'equestrian director'],
    'barley': ['bird seed', 'bran', 'cat food', 'chicken feed', 'chop', 'corn', 'dog food', 'eatage', 'ensilage', 'feed', 'fodder', 'forage'],
    'barmaid': ['barkeep', 'barkeeper', 'barman', 'bartender', 'bootlegger', 'brewer', 'brewmaster', 'busboy', 'carhop', 'counterman', 'distiller', 'headwaiter'],
    'barmaster': ['ja', 'amicus curiae', 'assessor', 'chancellor', 'circuit judge', 'judge advocate', 'judge ordinary', 'jurat', 'justice in eyre', 'justice of assize', 'lay judge', 'legal assessor'],
    'barmy': ['balmy', 'bananas', 'bats', 'batty', 'beany', 'bonkers', 'buggy', 'bughouse', 'bugs', 'crackers', 'cuckoo', 'daffy'],
    'barnacle': ['adherent', 'adhesive', 'beat', 'bloodsucker', 'bramble', 'brier', 'bulldog', 'burr', 'cement', 'deadbeat', 'decal', 'decalcomania'],
    'barnstorm': ['act', 'act as foil', 'appear', 'come out', 'control', 'copilot', 'drive', 'emote', 'emotionalize', 'fly', 'get top billing', 'manipulate'],
    'barnyard': ['arable land', 'barton', 'cattle ranch', 'chicken farm', 'collective farm', 'cotton plantation', 'croft', 'dairy farm', 'demesne', 'demesne farm', 'dry farm', 'dude ranch'],
    'barometer': ['aerological instrument', 'aneroid barometer', 'aneroidograph', 'barograph', 'barometrograph', 'canon', 'check', 'criterion', 'degree', 'feeler', 'gauge', 'glass'],
    'baron': ['brahman', 'establishment', 'vip', 'archduke', 'aristocracy', 'aristocrat', 'armiger', 'banker', 'baronet', 'barons', 'big boss', 'big businessman'],
    'baronet': ['bayard', 'brahman', 'don quixote', 'gawain', 'lancelot', 'ritter', 'sidney', 'sir galahad', 'archduke', 'aristocrat', 'armiger', 'bachelor'],
    'baroque': ['gothic', 'arabesque', 'bizarre', 'brain-born', 'busy', 'chichi', 'deformed', 'dream-built', 'elaborate', 'elegant', 'embellished', 'extravagant'],
    'barrage': ['aim at', 'antiaircraft barrage', 'arch dam', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrier', 'bear-trap dam', 'beat', 'beating', 'beaver dam'],
    'barred': ['absurd', 'banded', 'banned', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'brinded', 'brindle', 'brindled', 'cabined'],
    'barrel': ['abundance', 'acres', 'bag', 'bags', 'ball the jack', 'barb', 'barbule', 'barrels', 'basket', 'beeline', 'bole', 'boom'],
    'barren': ['abortive', 'acarpous', 'arid', 'bare', 'blah', 'bland', 'blank', 'bleached', 'bleak', 'bloodless', 'bootless', 'celibate'],
    'barrens': ['arabia deserta', 'death valley', 'sahara', 'barren', 'barren land', 'brush', 'bush', 'desert', 'desolation', 'dust bowl', 'heath', 'howling wilderness'],
    'barricade': ['abatis', 'advanced work', 'arm', 'armor', 'armor-plate', 'balistraria', 'bang', 'bank', 'banquette', 'bar', 'barbed-wire entanglement', 'barbican'],
    'barrier': ['abatis', 'advanced work', 'arch dam', 'backstop', 'balistraria', 'balustrade', 'bamboo curtain', 'bank', 'banquette', 'bar', 'barbed-wire entanglement', 'barbican'],
    'barring': ['aside from', 'ban', 'bar', 'beside', 'besides', 'blockade', 'boycott', 'but', 'circumscription', 'debarment', 'debarring', 'demarcation'],
    'barrio': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'black ghetto', 'blighted area', 'business district', 'central city'],
    'barrister': ['advocate', 'agent', 'amicus curiae', 'attorney', 'attorney-at-law', 'barrister-at-law', 'counsel', 'counselor', 'counselor-at-law', 'deputy', 'friend at court', 'intercessor'],
    'barroom': ['alehouse', 'bar', 'barrel house', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'cabaret', 'cafe', 'cocktail lounge', 'dive', 'dramshop'],
    'barrow': ['anthill', 'arch', 'beehive tomb', 'boar', 'bone house', 'boundary stone', 'box grave', 'brae', 'brass', 'burial', 'burial chamber', 'burial mound'],
    'bartender': ['barkeep', 'barkeeper', 'barmaid', 'barman', 'bootlegger', 'brewer', 'brewmaster', 'busboy', 'carhop', 'counterman', 'distiller', 'headwaiter'],
    'barter': ['abalienate', 'abalienation', 'agency', 'alien', 'alienate', 'alienation', 'amortization', 'amortize', 'amortizement', 'assign', 'assignation', 'assignment'],
    'bartizan': ['abatis', 'advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bastion', 'battlement', 'breastwork'],
    'bas relief': ['anaglyph', 'bellying', 'boldness', 'boss', 'bulging', 'cameo', 'cameo glass', 'cavo-rilievo', 'cut glass', 'embossment', 'eminence', 'excrescence'],
    'basal': ['ab ovo', 'aboriginal', 'basic', 'basilar', 'beginning', 'bottom', 'bottommost', 'central', 'constituent', 'constitutive', 'crucial', 'elemental'],
    'basalt': ['aa', 'abyssal rock', 'bedrock', 'block lava', 'brash', 'breccia', 'conglomerate', 'crag', 'druid stone', 'festooned pahoehoe', 'gneiss', 'granite'],
    'base': ['cp', 'ghq', 'hq', 'mickey mouse', 'abhorrent', 'abject', 'abominable', 'acid', 'acidity', 'agent', 'alkali', 'alkalinity'],
    'base pay': ['compensation', 'dismissal wage', 'earnings', 'escalator clause', 'escalator plan', 'financial remuneration', 'gross income', 'guaranteed annual wage', 'hire', 'income', 'living wage', 'minimum wage'],
    'baseborn': ['base', 'bastard', 'below the salt', 'cockney', 'common', 'commonplace', 'false', 'fatherless', 'homely', 'humble', 'illegitimate', 'low'],
    'based on': ['absolute', 'adducible', 'admissible', 'attestative', 'attestive', 'authentic', 'bolstered', 'borne', 'boxed in', 'braced', 'buttressed', 'certain'],
    'baseless': ['bottomless', 'built on sand', 'empty', 'false', 'gratuitous', 'groundless', 'idle', 'ill-founded', 'indefensible', 'needless', 'not well-founded', 'pointless'],
    'basement': ['wc', 'archives', 'armory', 'arsenal', 'attic', 'backhouse', 'bank', 'base', 'baseboard', 'basis', 'bathroom', 'bay'],
    'baseness': ['abjectness', 'abominability', 'abominableness', 'arrantness', 'atrociousness', 'awfulness', 'badness', 'beastliness', 'beggarliness', 'bestiality', 'brutality', 'chicanery'],
    'bash': ['bang', 'bat', 'batter', 'beat', 'beating', 'belt', 'biff', 'blow', 'blowout', 'bonk', 'bruise', 'buffet'],
    'bashful': ['olympian', 'abashed', 'aloof', 'autistic', 'awkward', 'backward', 'blank', 'blushful', 'boggling', 'chilled', 'chilly', 'close'],
    'basic': ['ab ovo', 'aboriginal', 'acid', 'alkali', 'austere', 'bare', 'basal', 'basilar', 'bedrock', 'biochemical', 'bottom', 'capital'],
    'basic training': ['apprenticeship', 'arrangement', 'breaking', 'breeding', 'briefing', 'clearing the decks', 'conditioning', 'cultivation', 'development', 'discipline', 'drill', 'drilling'],
    'basin': ['alkali flat', 'alluvial plain', 'alveolation', 'alveolus', 'anchorage', 'anchorage ground', 'antrum', 'aquamanile', 'armpit', 'automatic dishwasher', 'bath', 'bathtub'],
    'basis': ['anschauung', 'a priori principle', 'affirmation', 'ambition', 'angle', 'angle of vision', 'antecedents', 'apriorism', 'aspiration', 'assertion', 'assumed position', 'assumption'],
    'bask': ['adore', 'appreciate', 'bask in', 'be pleased with', 'delight in', 'derive pleasure from', 'devour', 'eat up', 'enjoy', 'feast on', 'freak out on', 'get high on'],
    'basket': ['bag', 'ballocks', 'balls', 'barrel', 'bassinet', 'beard', 'bottle', 'box', 'box up', 'breadbasket', 'breasts', 'bushel'],
    'basketwork': ['arabesque', 'basketry', 'cancellation', 'cross-hatching', 'crossing-out', 'filigree', 'fret', 'fretwork', 'grate', 'grating', 'grid', 'gridiron'],
    'bass': ['a string', 'amati', 'cremona', 'd string', 'e string', 'g string', 'heldentenor', 'meistersinger', 'strad', 'stradivari', 'stradivarius', 'accompaniment'],
    'basso': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso buffo', 'basso cantante', 'basso profundo', 'blues singer', 'canary'],
    'bassoon': ['english horn', 'pandean pipe', 'aulos', 'basset horn', 'basset oboe', 'block flute', 'bombard', 'bourdon', 'cello', 'claribel', 'clarinet', 'clarion'],
    'bastard': ['sob', 'affected', 'apocryphal', 'artificial', 'assumed', 'bantling', 'bar sinister', 'baseborn', 'bastard child', 'bastardy', 'bird', 'blackguard'],
    'bastardize': ['adulterate', 'brutalize', 'contaminate', 'corrupt', 'cut', 'debase', 'debauch', 'demoralize', 'denaturalize', 'denature', 'deprave', 'dilute'],
    'baste': ['bake', 'bang', 'barbecue', 'bastinado', 'batter', 'bawl out', 'beat', 'belabor', 'belt', 'berate', 'birch', 'blanch'],
    'bastille': ['pow camp', 'black hole', 'borstal', 'borstal institution', 'bridewell', 'brig', 'bucket', 'caboose', 'calaboose', 'can', 'cell', 'chokey'],
    'bastion': ['abatis', 'acropolis', 'advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'battlement'],
    'bat': ['angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'indian buffalo', 'kodiak bear', 'virginia deer', 'aardvark', 'aardwolf', 'agate', 'alpaca', 'anteater'],
    'bat out': ['botch', 'bungle', 'dash off', 'do anyhow', 'do by halves', 'do carelessly', 'do offhand', 'fake up', 'fudge up', 'jury-rig', 'knock off', 'knock out'],
    'bat the eyes': ['allure', 'bait', 'bait the hook', 'blandish', 'blink', 'cajole', 'coax', 'decoy', 'draw', 'draw in', 'draw on', 'ensnare'],
    'batch': ['amount', 'array', 'assortment', 'block', 'budget', 'bulk', 'bunch', 'bundle', 'chunk', 'clod', 'clump', 'cluster'],
    'bate': ['abate', 'ablate', 'abrade', 'abstract', 'alleviate', 'allow', 'attenuate', 'bar', 'be eaten away', 'blunt', 'charge off', 'close'],
    'bated': ['abated', 'ablated', 'attenuated', 'belittled', 'consumed', 'contracted', 'curtailed', 'damped', 'dampened', 'dead', 'deadened', 'decreased'],
    'bated breath': ['aspiration', 'breath', 'breathy voice', 'exhalation', 'little voice', 'low voice', 'mumble', 'mumbling', 'murmur', 'murmuration', 'murmuring', 'mutter'],
    'bath': ['finnish bath', 'japanese bath', 'russian bath', 'swedish bath', 'turkish bath', 'acid bath', 'affusion', 'aquamanile', 'aspergation', 'aspersion', 'automatic dishwasher', 'bagnio'],
    'bathe': ['australian crawl', 'finnish bath', 'japanese bath', 'russian bath', 'swedish bath', 'turkish bath', 'aquaplaning', 'aquatics', 'backstroke', 'balneation', 'bandage', 'baptize'],
    'bathhouse': ['bagnio', 'balneae', 'balneum', 'bath', 'bathroom', 'baths', 'caldarium', 'lavatory', 'mikvah', 'public baths', 'rest room', 'sauna'],
    'bathing': ['australian crawl', 'rugby', 'acrobatics', 'affusion', 'agonistics', 'aquaplaning', 'aquatics', 'aspergation', 'aspersion', 'association football', 'athletics', 'backstroke'],
    'bathing beauty': ['miss america', 'bather', 'bathing girl', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'beauty queen', 'belle', 'bunny', 'charmer', 'cover girl'],
    'bathos': ['anticlimax', 'bleeding heart', 'cloyingness', 'comedown', 'goo', 'hearts-and-flowers', 'heaviness', 'heaviness of heart', 'heavy heart', 'heavyheartedness', 'maudlinness', 'mawkishness'],
    'bathroom': ['wc', 'backhouse', 'bagnio', 'balneae', 'balneum', 'basement', 'bath', 'bathhouse', 'baths', 'caldarium', 'can', 'closet'],
    'baths': ['bagnio', 'balneae', 'balneum', 'bath', 'bathhouse', 'bathroom', 'caldarium', 'casino', 'club', 'clubhouse', 'gambling house', 'gathering place'],
    'bathtub': ['aquamanile', 'automatic dishwasher', 'basin', 'bath', 'bidet', 'dishpan', 'dishwasher', 'ewer', 'finger bowl', 'kitchen sink', 'lavabo', 'lavatory'],
    'bathymetry': ['altimetry', 'aquiculture', 'bathometry', 'biometrics', 'biometry', 'cadastration', 'cartography', 'chorography', 'craniometry', 'depth sounding', 'echo sounding', 'echolocation'],
    'bathysphere': ['aqua-lung', 'air cylinder', 'aquascope', 'bathyscaphe', 'benthoscope', 'diving bell', 'diving boat', 'diving chamber', 'diving goggles', 'diving helmet', 'diving hood', 'diving mask'],
    'batman': ['ganymede', 'hebe', 'airline hostess', 'airline stewardess', 'attendant', 'bellboy', 'bellhop', 'bellman', 'bootblack', 'boots', 'cabin boy', 'caddie'],
    'baton': ['malacca cane', 'achievement', 'alerion', 'alpenstock', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'aspersion', 'attaint'],
    'batrachian': ['amphibian', 'anguine', 'bullfrog', 'colubriform', 'crawling', 'creeping', 'croaker', 'crocodilian', 'frog', 'froggy', 'hoppytoad', 'hoptoad'],
    'bats': ['balmy', 'bananas', 'barmy', 'batty', 'beany', 'bonkers', 'buggy', 'bughouse', 'bugs', 'crackers', 'cuckoo', 'daffy'],
    'battalion': ['kp', 'age group', 'army', 'army group', 'band', 'battery', 'battle group', 'bevy', 'body', 'brigade', 'bunch', 'cabal'],
    'batten': ['mystik tape', 'scotch tape', 'act drop', 'adhesive tape', 'anchor', 'articulate', 'asbestos', 'asbestos board', 'backdrop', 'band', 'bandage', 'bang'],
    'batter': ['beau brummel', 'abuse', 'albumen', 'amateur athlete', 'archer', 'assault', 'athlete', 'attack', 'ballplayer', 'bang', 'barbarize', 'baseballer'],
    'battering': ['assault', 'attack', 'butchery', 'disorderliness', 'forcible seizure', 'killing', 'laying waste', 'looting', 'massacre', 'obstreperousness', 'onslaught', 'pillaging'],
    'battery': ['kp', 'leyden jar', 'accumulator', 'amateur athlete', 'archer', 'army', 'army group', 'array', 'artillery', 'athlete', 'atomic battery', 'ballplayer'],
    'battery powered': ['dynamoelectric', 'electric', 'electric-powered', 'electrified', 'electrifying', 'electrochemical', 'electrodynamic', 'electrokinetic', 'electromechanical', 'electrometric', 'electromotive', 'electropneumatic'],
    'battle': ['actium', 'adrianople', 'aegates isles', 'aegospotami', 'agincourt', 'antietam', 'anzio', 'arbela-gaugamela', 'ardennes', 'austerlitz', 'ayacucho', 'balaclava'],
    'battle cry': ['angelus', 'angelus bell', 'alarm', 'alarum', 'bark', 'bawl', 'bellow', 'bid to combat', 'birdcall', 'bugle call', 'call', 'call to arms'],
    'battle fatigue': ['accident neurosis', 'anaphylactic shock', 'anxiety hysteria', 'anxiety neurosis', 'association neurosis', 'blast neurosis', 'combat fatigue', 'compensation neurosis', 'compulsion neurosis', 'conversion hysteria', 'conversion neurosis', 'expectation neurosis'],
    'battle royal': ['action', 'aerial combat', 'affray', 'armored combat', 'battle', 'brush', 'bullfight', 'clash', 'clash of arms', 'cockfight', 'combat', 'conflict'],
    'battledore': ['lastex', 'abecedarium', 'abecedary', 'agate', 'alphabet book', 'baleen', 'ball', 'baseball bat', 'bat', 'bauble', 'blocks', 'casebook'],
    'battlefield': ['dmz', 'aceldama', 'battle line', 'battle site', 'battleground', 'combat area', 'combat zone', 'enemy line', 'field', 'field of battle', 'field of blood', 'firing line'],
    'battlement': ['abatis', 'advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'bastion', 'breastwork'],
    'batty': ['apish', 'asinine', 'balmy', 'bananas', 'barmy', 'bats', 'beany', 'bedlamite', 'befooled', 'beguiled', 'besotted', 'bonkers'],
    'bauble': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'agate', 'bagatelle', 'ball', 'baseball bat', 'bat', 'battledore', 'bean'],
    'bawd': ['fancy man', 'gigolo', 'harlot', 'hooker', 'madam', 'maquereau', 'meretrix', 'moll', 'nightwalker', 'pander', 'panderer', 'pimp'],
    'bawdy': ['fescennine', 'rabelaisian', 'animal', 'aphrodisiomaniacal', 'blue', 'broad', 'carnal', 'clitoromaniacal', 'coarse', 'concupiscent', 'crude', 'dirty'],
    'bawdyhouse': ['bagnio', 'bordello', 'brothel', 'cathouse', 'crib', 'den', 'den of vice', 'disorderly house', 'dive', 'house of assignation', 'house of joy', 'house of prostitution'],
    'bawl': ['bark', 'battle cry', 'bawl out', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'blubber', 'bluster'],
    'bawl out': ['berate', 'bless', 'carpet', 'chew', 'chew ass', 'chew out', 'condemn', 'cuss out', 'denounce', 'give a going-over', 'give hail columbia', 'give hell'],
    'bay': ['old mug', 'titian', 'accolade', 'adust', 'alcove', 'archives', 'arm', 'armlet', 'armory', 'arsenal', 'attic', 'auburn'],
    'bay window': ['abdomen', 'abomasum', 'bay', 'beerbelly', 'belly', 'bow window', 'breadbasket', 'casement', 'casement window', 'corporation', 'craw', 'crop'],
    'bayard': ['titian', 'adust', 'auburn', 'bay', 'bay-colored', 'brazen', 'bronze', 'bronze-colored', 'bronzed', 'brownish-red', 'buckskin', 'calico pony'],
    'bayonet': ['dagger', 'dirk', 'dudgeon', 'impale', 'knife', 'lance', 'pierce', 'plunge in', 'poniard', 'run through', 'saber', 'spear'],
    'bayou': ['affluent', 'arm', 'armlet', 'bay', 'belt', 'bight', 'billabong', 'boca', 'branch', 'confluent', 'confluent stream', 'cove'],
    'bazaar': ['auto show', 'boat show', 'closing-out sale', 'commercial complex', 'distress sale', 'emporium', 'exposition', 'fair', 'flea fair', 'flea market', 'garage sale', 'going-out-of-business sale'],
    'bazoo': ['bronx cheer', 'bird', 'boo', 'catcall', 'chaps', 'chops', 'embouchure', 'gab', 'gob', 'hiss', 'hoot', 'jaw'],
    'be': ['abide', 'be extant', 'be found', 'be in existence', 'be met with', 'be present', 'be the case', 'be there', 'breathe', 'come', 'continue', 'endure'],
    'be above': ['be contemptuous of', 'care nothing for', 'contemn', 'deride', 'despise', 'disdain', 'disparage', 'disprize', 'dump on', 'feel contempt for', 'feel superior to', 'hold beneath one'],
    'be born': ['arise', 'awake', 'awaken', 'be begotten', 'be illegitimate', 'be incarnated', 'become', 'break out', 'burst forth', 'come alive', 'come forth', 'come into being'],
    'be careful': ['be cautious', 'bend over backwards', 'exercise care', 'go on tiptoe', 'handle with gloves', 'have a care', 'make haste slowly', 'pussyfoot', 'take care', 'take good care', 'take heed', 'take it easy'],
    'be gone': ['be all over', 'be consumed', 'be past', 'cease', 'cease to be', 'cease to exist', 'dematerialize', 'depart', 'die', 'die away', 'die out', 'disappear'],
    'be in': ['be in force', 'be the rage', 'be the rule', 'be the thing', 'carry', 'deal in', 'dominate', 'handle', 'job', 'market', 'merchandise', 'obtain'],
    'be off': ['beat it', 'begone', 'clear out', 'flake off', 'get', 'get going', 'get lost', 'get off', 'get out', 'git', 'go forth', 'hit the road'],
    'be still': ['abide', 'be a sideliner', 'coast', 'delay', 'do nothing', 'drift', 'freeze', 'hang fire', 'hibernate', 'idle', 'keep quiet', 'lie dormant'],
    'beach': ['bank', 'berm', 'careen', 'cast away', 'coast', 'coastland', 'coastline', 'embankment', 'foreshore', 'ground', 'ironbound coast', 'lido'],
    'beachcomber': ['arab', 'bowery bum', 'beach bum', 'beggar', 'beggarly fellow', 'blighter', 'bo', 'budmash', 'bum', 'bummer', 'caitiff', 'derelict'],
    'beachhead': ['acropolis', 'advance guard', 'airhead', 'avant-garde', 'bastion', 'battle line', 'blockhouse', 'bridgehead', 'bunker', 'castle', 'citadel', 'donjon'],
    'beacon': ['am transmitter', 'fm transmitter', 'klaxon', 'mayday', 'rt transmitter', 'roman candle', 'sos', 'texas tower', 'very flare', 'aid to navigation', 'air-raid alarm', 'airport beacon'],
    'bead': ['anklet', 'armlet', 'ball', 'balloon', 'bangle', 'beads', 'bejewel', 'beribbon', 'bespangle', 'bijou', 'bracelet', 'breastpin'],
    'beaded': ['adorned', 'bead-like', 'bead-shaped', 'beady', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'decked out', 'decorated'],
    'beading': ['binding', 'bordering', 'bordure', 'edging', 'fimbria', 'fimbriation', 'flounce', 'frill', 'frilling', 'fringe', 'furbelow', 'galloon'],
    'beadle': ['bible clerk', 'bible reader', 'g-man', 'mp', 'acolyte', 'almoner', 'anagnost', 'bailiff', 'beagle', 'bedral', 'bound bailiff', 'capitular'],
    'beads': ['agnus dei', 'angelus', 'ave', 'ave maria', 'hail mary', 'holy grail', 'host', 'kyrie eleison', 'paternoster', 'pieta', 'sanctus bell', 'sangraal'],
    'beagle': ['g-man', 'mp', 'bailiff', 'beadle', 'bound bailiff', 'captain', 'catchpole', 'chief of police', 'commissioner', 'constable', 'deputy', 'deputy sheriff'],
    'beak': ['jp', 'justice', 'antlia', 'arbiter', 'arbitrator', 'beezer', 'bencher', 'bill', 'bow', 'bowsprit', 'bugle', 'cape'],
    'beaked': ['roman-nosed', 'aquiline', 'aquiline-nosed', 'beak-nosed', 'beak-shaped', 'bill-like', 'bill-shaped', 'billed', 'clawlike', 'crookbilled', 'crooked', 'crooknosed'],
    'beam': ['am signal', 'crt spot', 'dm display', 'doppler signal', 'fm signal', 'h beam', 'i beam', 'if signal', 'if video signal', 'im display', 'rf amplifier', 'rf echoes'],
    'beaming': ['aglow', 'beamy', 'beatific', 'beatified', 'blessed', 'blissful', 'blithe', 'blithesome', 'blooming', 'blushing', 'bright', 'bright and sunny'],
    'bean': ['irish potato', 'kraut', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'algae', 'aubergine', 'autophyte', 'bagatelle', 'bauble'],
    'bean pole': ['barebones', 'beanstalk', 'broomstick', 'clothes pole', 'corpse', 'giant', 'grenadier', 'lanky', 'longlegs', 'longshanks', 'rattlebones', 'seven-footer'],
    'beanery': ['automat', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop', 'coffeehouse'],
    'bear': ['cape polecat', 'tartar', 'abide', 'abide with', 'acquiesce', 'acquit', 'act', 'admit of', 'affect', 'afflict', 'afford', 'afford support'],
    'bear down': ['beat down', 'bring low', 'buckle down', 'couch', 'crush', 'debase', 'defeat', 'depress', 'detrude', 'do double duty', 'downbear', 'elucubrate'],
    'bear down on': ['accost', 'advance', 'advance against', 'advance upon', 'approach', 'approach anchorage', 'appropinquate', 'approximate', 'bear against', 'bear down upon', 'bear hard upon', 'bear up'],
    'bear fruit': ['advance', 'bear', 'bloom', 'blossom', 'blow', 'bring forth', 'bring to maturity', 'come to fruition', 'develop', 'evolute', 'evolve', 'flourish'],
    'bear hug': ['bite', 'clamp', 'clasp', 'clench', 'clinch', 'cling', 'clinging', 'clutch', 'death grip', 'embrace', 'enfoldment', 'firm hold'],
    'bear in mind': ['brood over', 'cherish', 'consider', 'contemplate', 'dwell on', 'dwell upon', 'entertain thoughts of', 'fan the embers', 'harbor an idea', 'have in mind', 'have regard for', 'have thoughts about'],
    'bear off': ['about ship', 'angle', 'angle off', 'avert', 'back and fill', 'bear away', 'bear to starboard', 'beat', 'beat about', 'bend', 'bias', 'box off'],
    'bear out': ['affirm', 'afford support', 'attest', 'authenticate', 'back', 'back up', 'bear', 'bear up', 'bolster', 'bolster up', 'buttress', 'certify'],
    'bear up': ['accost', 'advance', 'afford support', 'approach', 'appropinquate', 'approximate', 'assure', 'back', 'back up', 'be proof against', 'bear', 'bear down on'],
    'bear upon': ['abut on', 'act on', 'affect', 'answer to', 'appertain to', 'apply to', 'approach', 'assault', 'be based on', 'bear', 'bear on', 'belong to'],
    'bear with': ['abide', 'abide with', 'allow for', 'bear', 'bide', 'blink at', 'brave', 'brook', 'condone', 'connive at', 'countenance', 'disregard'],
    'bear witness': ['acknowledge', 'affirm', 'allege', 'asseverate', 'attest', 'aver', 'avouch', 'avow', 'certify', 'depone', 'depose', 'disclose'],
    'bear witness against': ['betray', 'blab', 'blow the whistle', 'fink', 'inform against', 'inform on', 'narc', 'peach', 'rat', 'sell out', 'snitch', 'snitch on'],
    'beard': ['vandyke', 'affront', 'ascender', 'back', 'bag', 'ballocks', 'balls', 'basket', 'bastard type', 'beaver', 'bell the cat', 'belly'],
    'beardless': ['acomous', 'bald', 'bald-headed', 'boyish', 'boylike', 'calflike', 'childish', 'childlike', 'clean-shaven', 'coltish', 'depilous', 'girlish'],
    'bearer': ['aquarius', 'ganymede', 'hebe', 'advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'bheesty'],
    'bearing': ['zeitgeist', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'affective meaning', 'aftermath', 'aim', 'air', 'air express'],
    'bearings': ['abode', 'accommodation', 'achievement', 'adaptation', 'adjustment', 'alerion', 'alignment', 'animal charge', 'annulet', 'area', 'argent', 'armorial bearings'],
    'bearish': ['abrupt', 'aggressive', 'beastly', 'bitchy', 'bluff', 'blunt', 'brash', 'brusque', 'cankered', 'cantankerous', 'cavalier', 'churlish'],
    'beast': ['mafioso', 'young turk', 'animal', 'anthropophagite', 'barbarian', 'being', 'beldam', 'berserk', 'berserker', 'bomber', 'brute', 'cannibal'],
    'beast of burden': ['siberian husky', 'ass', 'camel', 'draft animal', 'dromedary', 'drudge', 'elephant', 'fag', 'galley slave', 'greasy grind', 'grind', 'grub'],
    'beastly': ['adamic', 'circean', 'draconian', 'tartarean', 'abhorrent', 'abominable', 'abrupt', 'aggressive', 'animal', 'animalian', 'animalic', 'animalistic'],
    'beat': ['alexandrine', 'bohemian', 'about ship', 'abrade', 'abscond', 'accent', 'accentuation', 'addle', 'addled', 'aerate', 'agitate', 'air lane'],
    'beat about': ['about ship', 'agonize over', 'angle for', 'ask for', 'back and fill', 'be at sea', 'be hard put', 'be uncertain', 'bear away', 'bear off', 'bear to starboard', 'beat'],
    'beat back': ['brush off', 'chase', 'chase away', 'chase off', 'cut', 'dismiss', 'drive away', 'drive back', 'fend off', 'hold off', 'keep off', 'pack off'],
    'beat down': ['bargain', 'bear down', 'bend', 'bid', 'bid for', 'blow down', 'break', 'break down', 'bring down', 'bring low', 'bring to terms', 'browbeat'],
    'beat it': ['be off', 'begone', 'blow', 'clear out', 'dog it', 'duck and run', 'duck out', 'flake off', 'get', 'get going', 'get lost', 'get out'],
    'beat off': ['block', 'check', 'counter', 'drive back', 'fend', 'fend off', 'hinder', 'hold at bay', 'hold off', 'keep at bay', 'keep off', 'obstruct'],
    'beat the drum': ['advertise', 'ballyhoo', 'bark', 'beat', 'beat a tattoo', 'beat the drums', 'beat time', 'bill', 'blow the trumpet', 'boost', 'build up', 'bulletin'],
    'beat up': ['agitate', 'all in', 'batter', 'battered', 'beat', 'beat-up', 'beaten', 'beaten up', 'bedraggled', 'blowzy', 'bone-weary', 'broken-down'],
    'beaten': ['all in', 'all up with', 'automatic', 'beat', 'beat up', 'bested', 'blebby', 'blistered', 'blistering', 'blistery', 'bone-weary', 'bubbling'],
    'beaten path': ['alameda', 'beat', 'beaten track', 'berm', 'bicycle path', 'boardwalk', 'bridle path', 'broken record', 'bureaucracy', 'bureaucratism', 'catwalk', 'chinoiserie'],
    'beater': ['nimrod', 'agitator', 'big game hunter', 'blender', 'cement mixer', 'churn', 'courser', 'crucible', 'eggbeater', 'emulsifier', 'hunter', 'huntress'],
    'beatification': ['aggrandizement', 'apotheosis', 'ascent', 'assumption', 'beatitude', 'bewitchment', 'blessedness', 'blessing', 'bliss', 'blissfulness', 'canonization', 'cheer'],
    'beatified': ['elysian', 'olympian', 'aggrandized', 'angelic', 'apotheosized', 'archangelic', 'awesome', 'beaming', 'beatific', 'big', 'blessed', 'blissful'],
    'beatify': ['aggrandize', 'apotheose', 'apotheosize', 'bless', 'canonize', 'cheer', 'cleanse', 'consecrate', 'crown', 'dedicate', 'deify', 'devote'],
    'beating': ['waterloo', 'abrasion', 'alternate', 'arrhythmia', 'atomization', 'attrition', 'bang', 'barrage', 'bash', 'bastinado', 'basting', 'bat'],
    'beatitude': ['beatification', 'bewitchment', 'blessedness', 'blessing', 'bliss', 'blissfulness', 'canonization', 'cheer', 'cheerfulness', 'cloud nine', 'consecration', 'dedication'],
    'beatnik': ['bohemian', 'deviant', 'dissenter', 'dropout', 'flower child', 'freak', 'heretic', 'hippie', 'maverick', 'misfit', 'nonconformist', 'nonjuror'],
    'beau': ['beau brummel', 'casanova', 'don juan', 'lothario', 'romeo', 'amoroso', 'beloved', 'blade', 'blood', 'boulevardier', 'boyfriend', 'caballero'],
    'beau brummel': ['arbiter of fashion', 'beau', 'blade', 'blood', 'boulevardier', 'buck', 'clotheshorse', 'clubman', 'clubwoman', 'coxcomb', 'dandy', 'deb'],
    'beaucoup': ['a deal', 'a great deal', 'a lot', 'abundantly', 'as all creation', 'as all get-out', 'considerable', 'considerably', 'ever so', 'ever so much', 'galore', 'greatly'],
    'beaut': ['miss america', 'ace', 'bathing beauty', 'beau ideal', 'beauty', 'beauty contest winner', 'beauty queen', 'belle', 'bunny', 'charmer', 'corker', 'cover girl'],
    'beauteous': ['aesthetic', 'aesthetically appealing', 'attractive', 'beautiful', 'bonny', 'comely', 'elegant', 'endowed with beauty', 'exquisite', 'eye-filling', 'fair', 'fine'],
    'beautified': ['advanced', 'ameliorated', 'bettered', 'civilized', 'converted', 'cultivated', 'cultured', 'developed', 'educated', 'embellished', 'enhanced', 'enriched'],
    'beautiful': ['admirable', 'aesthetic', 'aesthetically appealing', 'alluring', 'appealing', 'art-conscious', 'artistic', 'arty', 'attractive', 'beauteous', 'bonny', 'charming'],
    'beautiful people': ['vanity fair', 'beau monde', 'best people', 'cafe society', 'carriage trade', 'cream of society', 'drawing room', 'elite', 'fashionable society', 'good society', 'haut monde', 'high life'],
    'beautify': ['adorn', 'array', 'become one', 'bedeck', 'bedizen', 'blazon', 'color', 'cultivate', 'dandify', 'deck', 'deck out', 'decorate'],
    'beauty': ['miss america', 'advantage', 'asset', 'attraction', 'attractiveness', 'balance', 'bathing beauty', 'beau ideal', 'beaut', 'beauty contest winner', 'beauty queen', 'belle'],
    'beauty parlor': ['agency', 'atelier', 'barbershop', 'beauty salon', 'beauty shop', 'bench', 'butcher shop', 'company', 'concern', 'corporation', 'desk', 'establishment'],
    'beauty queen': ['miss america', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'belle', 'bunny', 'charmer', 'cover girl', 'dazzler', 'dream'],
    'beaver': ['vandyke', 'activist', 'ball of fire', 'beard', 'big-time operator', 'bristles', 'bustler', 'busy bee', 'doer', 'down', 'eager beaver', 'enthusiast'],
    'bebop': ['acid rock', 'avant-garde jazz', 'ballroom music', 'boogie-woogie', 'bop', 'country rock', 'dance music', 'dances', 'folk rock', 'hard rock', 'hot jazz', 'jazz'],
    'because': ['as', 'as long as', 'as things go', 'being', 'being as how', 'cause', 'considering', 'for', 'forasmuch as', 'in that', 'inasmuch as', 'insofar as'],
    'becharm': ['allure', 'attract', 'beguile', 'bewitch', 'captivate', 'carry away', 'cast a spell', 'charm', 'delectate', 'delight', 'draw on', 'enamor'],
    'becharmed': ['bewitched', 'captivated', 'charm-bound', 'charmed', 'enamored', 'enchanted', 'enraptured', 'fascinated', 'heartsmitten', 'hypnotized', 'in a trance', 'infatuate'],
    'beck': ['adolescent stream', 'arroyo', 'bearing', 'beck and call', 'beckon', 'bidding', 'body language', 'bourn', 'braided stream', 'branch', 'brook', 'brooklet'],
    'beckon': ['appeal', 'attract', 'be attractive', 'bid', 'call', 'engage', 'fetch', 'gesticulate', 'gesture', 'interest', 'invite', 'mime'],
    'becloud': ['addle', 'addle the wits', 'ball up', 'bedarken', 'bedazzle', 'bedim', 'befog', 'befuddle', 'begloom', 'bemist', 'bewilder', 'black'],
    'beclouded': ['abstruse', 'addlebrained', 'addled', 'addleheaded', 'addlepated', 'befuddled', 'blind', 'buried', 'close', 'clouded', 'cloudy', 'concealed'],
    'become': ['adorn', 'agree with', 'alter into', 'arise', 'assimilate to', 'be born', 'be bound', 'be changed', 'be converted into', 'be obligated', 'be obliged', 'become of'],
    'become of': ['attend', 'come about', 'come of', 'come out', 'develop', 'end', 'ensue', 'eventuate', 'fall out', 'fare', 'follow', 'issue'],
    'becoming': ['junoesque', 'a propos', 'ad rem', 'adapted', 'advantageous', 'advisable', 'agreeable', 'amply endowed', 'applicable', 'apposite', 'appropriate', 'apropos'],
    'bed': ['colonial bed', 'hollywood bed', 'japanese garden', 'a world-without-end bargain', 'accommodation', 'accommodations', 'alliance', 'alpine garden', 'aqueduct', 'arboretum', 'arroyo', 'band'],
    'bed of roses': ['easy street', 'affluence', 'clover', 'comfort', 'contentment', 'ease', 'easy circumstances', 'felicity', 'fleshpots', 'gracious life', 'gracious living', 'happiness'],
    'bedaub': ['apply paint', 'attaint', 'bedizen', 'begild', 'besmear', 'besmirch', 'besmoke', 'besmutch', 'besoil', 'bestain', 'black', 'blacken'],
    'bedazzle': ['addle', 'addle the wits', 'amaze', 'astonish', 'astound', 'awe', 'awestrike', 'ball up', 'bandage', 'be bright', 'beacon', 'beam'],
    'bedazzled': ['blindfold', 'blindfolded', 'darkened', 'dazed', 'dazzled', 'dopey', 'excecate', 'groggy', 'hoodwinked', 'in a daze', 'knocked silly', 'mazed'],
    'bedclothes': ['afghan', 'bed linen', 'bedcover', 'bedding', 'bedsheet', 'bedspread', 'blanket', 'buffalo robe', 'case', 'clothes', 'comfort', 'comforter'],
    'bedding': ['afghan', 'air mattress', 'band', 'base', 'basement', 'basis', 'bearing wall', 'bed', 'bed linen', 'bedclothes', 'bedcover', 'bedrock'],
    'bedeck': ['adorn', 'apparel', 'array', 'attire', 'beautify', 'bedaub', 'bedizen', 'bedrape', 'blazon', 'bundle up', 'clothe', 'color'],
    'bedecked': ['adorned', 'appareled', 'arrayed', 'attired', 'beaded', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'breeched', 'capped'],
    'bedevil': ['aggravate', 'annoy', 'badger', 'bait', 'be at', 'beset', 'bewitch', 'bother', 'bristle', 'brown off', 'bug', 'bullyrag'],
    'bedeviled': ['badgered', 'baited', 'beset', 'bugged', 'bullyragged', 'chivied', 'demonized', 'devil-ridden', 'deviled', 'dogged', 'harassed', 'harried'],
    'bedfellow': ['ace', 'adjunct', 'ally', 'amigo', 'associate', 'bedmate', 'bosom buddy', 'brother', 'brother-in-arms', 'buddy', 'bunkie', 'bunkmate'],
    'bedizen': ['adorn', 'apply paint', 'array', 'beautify', 'bedaub', 'bedeck', 'begild', 'besmear', 'blazon', 'brush on paint', 'calcimine', 'coat'],
    'bedizened': ['gongoresque', 'johnsonian', 'adorned', 'affected', 'beaded', 'bedecked', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'big-sounding', 'convoluted'],
    'bedlam': ['babel', 'bedlam let loose', 'asylum', 'blast', 'bobbery', 'brawl', 'brouhaha', 'bughouse', 'cacophony', 'chaos', 'charivari', 'chirm'],
    'bedmate': ['ace', 'amigo', 'associate', 'bedfellow', 'birthmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty', 'camarade', 'chamberfellow'],
    'bedpan': ['can', 'chamber', 'chamber pot', 'chemical closet', 'chemical toilet', 'commode', 'crapper', 'jerry', 'john', 'johnny', 'jordan', 'latrine'],
    'bedraggled': ['beat-up', 'befouled', 'besmirched', 'blowzy', 'careless', 'chintzy', 'decrepit', 'defiled', 'dilapidated', 'dirtied', 'dirty', 'down-at-heel'],
    'bedrape': ['apparel', 'array', 'attire', 'bedeck', 'bundle up', 'clothe', 'deck', 'dight', 'drape', 'dress', 'dud', 'enclothe'],
    'bedrock': ['aa', 'abyssal rock', 'basalt', 'base', 'basement', 'basic', 'basis', 'bearing wall', 'bed', 'bedding', 'belly', 'block lava'],
    'bedspread': ['afghan', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedsheet', 'blanket', 'buffalo robe', 'case', 'clothes', 'comfort', 'comforter'],
    'bedtime': ['beauty sleep', 'beddy-bye', 'blanket drill', 'bye-bye', 'curfew', 'doze', 'dreamland', 'drowse', 'eleventh hour', 'fitful sleep', 'hibernation', 'land of nod'],
    'bee': ['boutade', 'bumblebee', 'conceit', 'cornhusking', 'crotchet', 'drone', 'fancy', 'freak', 'honeybee', 'hornet', 'humor', 'husking'],
    'beef': ['brahman', 'indian buffalo', 'air a grievance', 'altercation', 'amperage', 'arm', 'armipotence', 'aurochs', 'authority', 'avoirdupois', 'beef cattle', 'beef extract'],
    'beef up': ['accelerate', 'aggrandize', 'aggravate', 'augment', 'blow up', 'boost', 'brace', 'brace up', 'buttress', 'case harden', 'complicate', 'concentrate'],
    'beefcake': ['telephoto', 'wirephoto', 'aerial photograph', 'black-and-white photograph', 'candid photograph', 'cheesecake', 'chronophotograph', 'color photograph', 'color print', 'diapositive', 'heliochrome', 'heliograph'],
    'beefed up': ['accelerated', 'aggrandized', 'ampliate', 'amplified', 'augmented', 'bloated', 'boosted', 'broadened', 'built-up', 'crescendoed', 'deepened', 'elevated'],
    'beefhead': ['addlebrain', 'addlehead', 'addlepate', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead', 'clodhead'],
    'beefing': ['beef', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'complaining', 'complaint', 'complaintful', 'crabbing', 'crabby', 'cranky', 'croaking'],
    'beefsteak': ['london broil', 'salisbury steak', 't-bone steak', 'bifteck', 'chopped steak', 'club steak', 'cubed steak', 'fillet steak', 'flank steak', 'ground beef', 'ground chuck', 'ground round'],
    'beefy': ['adipose', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'bouncing', 'brawny', 'burly', 'buxom', 'chubby', 'chunky', 'corpulent'],
    'beeline': ['air line', 'axis', 'chord', 'cut', 'cutoff', 'diagonal', 'diameter', 'direct line', 'directrix', 'edge', 'great-circle course', 'normal'],
    'beelzebub': ['abaddon', 'aeshma', 'angra mainyu', 'apollyon', 'azazel', 'belial', 'eblis', 'lilith', 'lucifer', 'mephisto', 'mephistopheles', 'old nick'],
    'beep': ['bay', 'bell', 'blare', 'blast', 'blat', 'blow', 'blow the horn', 'bray', 'bugle', 'clarion', 'fanfare', 'flourish of trumpets'],
    'beer garden': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer hall', 'beer parlor', 'bistro', 'blind tiger', 'cabaret', 'cafe', 'cocktail lounge', 'dive'],
    'beerbelly': ['abdomen', 'abomasum', 'bay window', 'belly', 'breadbasket', 'craw', 'crop', 'diaphragm', 'embonpoint', 'first stomach', 'gizzard', 'gullet'],
    'beery': ['addled', 'bathetic', 'bemused', 'besotted', 'blind drunk', 'cloying', 'crapulent', 'crapulous', 'dizzy', 'drenched', 'drunk', 'drunken'],
    'beetle': ['arachnid', 'arthropod', 'beetle-browed', 'beetling', 'bug', 'caterpillar', 'centipede', 'chilopod', 'daddy longlegs', 'digester', 'diplopod', 'fly'],
    'beetle browed': ['beetle', 'beetling', 'black', 'black-browed', 'dark', 'dejected', 'dour', 'dumpish', 'frowning', 'glowering', 'glum', 'grim'],
    'befall': ['be found', 'be met with', 'be realized', 'bechance', 'betide', 'break', 'chance', 'come', 'come about', 'come along', 'come down', 'come off'],
    'befit': ['advance', 'advantage', 'agree with', 'answer', 'be bound', 'be obligated', 'be obliged', 'be right', 'become', 'befitting', 'behoove', 'benefit'],
    'befitting': ['a propos', 'ad rem', 'adapted', 'advantageous', 'advisable', 'applicable', 'apposite', 'appropriate', 'appropriate to', 'apropos', 'apt', 'auspicious'],
    'befog': ['becloud', 'bedim', 'bemist', 'bewilder', 'blanket', 'blind', 'blur', 'camouflage', 'cap', 'clabber up', 'cloak', 'cloud'],
    'before': ['above', 'aforetime', 'ahead', 'ahead of time', 'already', 'ante', 'before all', 'before now', 'beforehand', 'beforetime', 'betimes', 'by choice'],
    'before long': ['after a time', 'after a while', 'afterward', 'afterwards', 'anon', 'betimes', 'by and by', 'by destiny', 'directly', 'ere long', 'fatally', 'hopefully'],
    'beforehand': ['ahead', 'ahead of time', 'anachronistic', 'ante', 'antedated', 'before', 'beforetime', 'behind time', 'behindhand', 'betimes', 'dated', 'earlier'],
    'beforetime': ['aforetime', 'ahead', 'ahead of time', 'anticipative', 'anticipatory', 'before', 'before now', 'beforehand', 'betimes', 'bright and early', 'earlier', 'early'],
    'befoul': ['abuse', 'afflict', 'aggrieve', 'benasty', 'bespatter', 'bewitch', 'blacken', 'blight', 'condemn', 'contaminate', 'convert', 'corrupt'],
    'befriend': ['abet', 'aid', 'assist', 'avail', 'bail out', 'bear a hand', 'benefit', 'buddy up', 'comfort', 'do good', 'doctor', 'ease'],
    'befrilled': ['adorned', 'beaded', 'bedecked', 'bedizened', 'bejeweled', 'beribboned', 'bespangled', 'colored', 'decked out', 'decorated', 'embellished', 'embroidered'],
    'befuddle': ['addle', 'addle the wits', 'ball up', 'becloud', 'bedazzle', 'bemuse', 'besot', 'bewilder', 'bother', 'bug', 'cloud', 'confuse'],
    'befuddled': ['addlebrained', 'addled', 'addleheaded', 'addlepated', 'beclouded', 'cloudy', 'fogged', 'foggy', 'fuddlebrained', 'fuddled', 'hazy', 'in a fog'],
    'beg': ['adjure', 'appeal', 'appeal to', 'ask', 'bear', 'beget', 'beseech', 'besiege', 'brace', 'breed', 'bum', 'cadge'],
    'beg leave': ['apply for', 'ask', 'ask for', 'bespeak', 'call for', 'crave', 'demand', 'desire', 'file for', 'indent', 'make a request', 'make a requisition'],
    'beg off': ['abandon', 'back out', 'be unmoved', 'be unwilling', 'cry off', 'decline', 'decline to accept', 'depart from', 'disagree', 'disallow', 'discard', 'disclaim'],
    'beg the question': ['about the bush', 'around the bush', 'beat about', 'beat around', 'bicker', 'boggle', 'cavil', 'choplogic', 'dodge', 'duck', 'equivocate', 'evade'],
    'beg to differ': ['agree to differ', 'agree to disagree', 'be at variance', 'be in dissent', 'differ', 'disagree', 'disagree with', 'discord with', 'dissent', 'dissent from', 'divide on', 'drop out'],
    'beget': ['author', 'be fruitful', 'be productive', 'bear', 'birth', 'breed', 'breed true', 'bring about', 'bring forth', 'bring into being', 'bring to birth', 'bring to effect'],
    'beggar': ['arab', 'bowery bum', 'almsman', 'almswoman', 'asker', 'baffle', 'bankrupt', 'beach bum', 'beachcomber', 'beggarly fellow', 'blighter', 'bloke'],
    'beggared': ['beggarly', 'bereaved', 'bereft', 'broke', 'deprived', 'destitute', 'disadvantaged', 'flat', 'fleeced', 'fortuneless', 'ghettoized', 'impecunious'],
    'beggarly': ['abject', 'abominable', 'arrant', 'atrocious', 'backscratching', 'bare-handed', 'base', 'base-minded', 'beggared', 'beneath contempt', 'bereaved', 'bereft'],
    'beggary': ['absence', 'bare cupboard', 'bare subsistence', 'beggarliness', 'begging', 'bumming', 'cadging', 'defectiveness', 'deficiency', 'deficit', 'deprivation', 'destitution'],
    'begging': ['adjuratory', 'appealing', 'beggary', 'beseeching', 'bumming', 'cadging', 'entreating', 'imploring', 'mendicancy', 'mendicant', 'mendicity', 'mooching'],
    'begild': ['apply paint', 'aurify', 'bedaub', 'bedizen', 'besmear', 'brush on paint', 'calcimine', 'coat', 'color', 'complexion', 'cover', 'dab'],
    'begin': ['arise', 'attack', 'blast away', 'blast off', 'broach', 'commence', 'create', 'dig in', 'dive in', 'embark', 'enter', 'enter on'],
    'beginner': ['abecedarian', 'agent', 'alphabetarian', 'ancestors', 'apprentice', 'architect', 'articled clerk', 'artificer', 'artist', 'author', 'baby', 'begetter'],
    'beginning': ['abecedarian', 'aboriginal', 'alpha', 'anlage', 'antenatal', 'anticipation', 'appearance', 'authorship', 'autochthonous', 'babyhood', 'basal', 'beginnings'],
    'begrime': ['bemire', 'bemud', 'besmoke', 'besoil', 'dirt', 'dirty', 'dirty up', 'dust', 'foul', 'grime', 'mire', 'muck'],
    'begrudge': ['balk at', 'be unwilling', 'cast envious eyes', 'close the hand', 'covet', 'deny', 'envy', 'famish', 'grudge', 'hold back', 'live upon nothing', 'mind'],
    'beguile': ['allure', 'amuse', 'bamboozle', 'beat', 'becharm', 'beguile of', 'betray', 'bewitch', 'bilk', 'bluff', 'bunco', 'burn'],
    'beguiled': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'apish', 'asinine', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck'],
    'beguiling': ['alluring', 'amusing', 'appealing', 'appetizing', 'attractive', 'bewildering', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching', 'catchy'],
    'behalf': ['advantage', 'avail', 'behoof', 'benefit', 'benison', 'blessing', 'boon', 'convenience', 'for', 'gain', 'good', 'in place of'],
    'behave': ['acquit', 'act', 'act toward', 'act well', 'be good', 'be nice', 'bear', 'behave toward', 'carry', 'comport', 'conduct', 'control'],
    'behavior': ['pavlovian conditioning', 'act', 'acting', 'action', 'actions', 'activism', 'activity', 'bearing', 'comportment', 'conditioned response', 'conditioning', 'conduct'],
    'behaviorism': ['adlerian psychology', 'freudian psychology', 'freudianism', 'gestalt psychology', 'horneyan psychology', 'jungian psychology', 'marxism', 'pavlovian psychology', 'reichian psychology', 'skinnerian psychology', 'watsonian psychology', 'analytical psychology'],
    'behest': ['bidding', 'charge', 'command', 'commandment', 'demand', 'dictate', 'dictation', 'direct order', 'hest', 'imperative', 'injunction', 'mandate'],
    'behind': ['after', 'after time', 'afterpart', 'afterpiece', 'afterward', 'arrested', 'back', 'back door', 'back of', 'back seat', 'back side', 'back to back'],
    'behind the scenes': ['dr', 'alive to', 'appreciative of', 'apprised of', 'awake to', 'aware of', 'back to back', 'backstage', 'before an audience', 'before the footlights', 'behind', 'behind the curtain'],
    'behind time': ['after time', 'ahead of time', 'anachronistic', 'antedated', 'backward', 'beforehand', 'behind', 'behindhand', 'belatedly', 'dated', 'deep into', 'early'],
    'behindhand': ['after time', 'ahead of time', 'anachronistic', 'antedated', 'arrested', 'back', 'backward', 'beforehand', 'behind', 'behind time', 'belated', 'belatedly'],
    'behold': ['nb', 'catch sight of', 'clap eyes on', 'descry', 'discern', 'discover', 'distinguish', 'espy', 'glimpse', 'have in sight', 'ken', 'lay eyes on'],
    'beholden': ['acknowledging', 'appreciative', 'beholden to', 'bound', 'bounden', 'bounden to', 'cognizant of', 'committed', 'crediting', 'duty-bound', 'grateful', 'in debt'],
    'behoof': ['advantage', 'avail', 'behalf', 'benefit', 'benison', 'blessing', 'boon', 'convenience', 'gain', 'good', 'interest', 'percentage'],
    'beige': ['aureate', 'auric', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'buff', 'buff-yellow', 'canary', 'canary-yellow', 'chocolate', 'cinnamon'],
    'being': ['adamite', 'actual', 'actuality', 'aerobic organism', 'an existence', 'anaerobic organism', 'as', 'as is', 'as long as', 'autotrophic organism', 'body', 'bones'],
    'bejewel': ['bead', 'beribbon', 'beset', 'bespangle', 'diamond', 'encrust', 'engrave', 'feather', 'figure', 'filigree', 'flag', 'flounce'],
    'bejeweled': ['adorned', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'beribboned', 'bespangled', 'decked out', 'decorated', 'embellished', 'feathered', 'festooned'],
    'bel canto': ['bravura', 'choral singing', 'coloratura', 'croon', 'crooning', 'folk singing', 'hum', 'humming', 'intonation', 'lyricism', 'operatic singing', 'scat'],
    'belabor': ['accent', 'accentuate', 'always trot out', 'baste', 'bastinado', 'batter', 'beat', 'belt', 'birch', 'buffet', 'cane', 'club'],
    'belabored': ['alliterating', 'alliterative', 'assonant', 'chanting', 'chiming', 'cliche-ridden', 'dingdong', 'harping', 'humdrum', 'jingle-jangle', 'jog-trot', 'labored'],
    'belated': ['antique', 'archaic', 'arrested', 'back', 'backward', 'behind time', 'behindhand', 'blocked', 'dated', 'delayed', 'delayed-action', 'detained'],
    'belay': ['abandon', 'abort', 'affix', 'anchor', 'annex', 'attach', 'batten', 'batten down', 'cancel', 'cease', 'cement', 'chain'],
    'belch': ['blare', 'blat', 'blow open', 'blow out', 'bray', 'break out', 'burp', 'burr', 'burst', 'burst forth', 'burst out', 'buzz'],
    'beldam': ['jezebel', 'mafioso', 'young turk', 'bag', 'bat', 'battle-ax', 'beast', 'berserk', 'berserker', 'biddy', 'bitch', 'bitch-kitty'],
    'beleaguer': ['annoy', 'bedevil', 'beset', 'besiege', 'blockade', 'bound', 'box in', 'cage', 'chamber', 'close in', 'compass', 'contain'],
    'beleaguered': ['barred', 'beset', 'besieged', 'blockaded', 'bound', 'cabined', 'caged', 'cloistered', 'closed-in', 'confined', 'cooped', 'cordoned'],
    'belfry': ['antenna tower', 'barbican', 'bean', 'bell tower', 'campanile', 'carillon', 'colossus', 'column', 'conk', 'cupola', 'derrick', 'dome'],
    'belie': ['abjure', 'assert the contrary', 'be contrary to', 'blow sky-high', 'blow up', 'burlesque', 'call into question', 'camouflage', 'caricature', 'challenge', 'color', 'conceal'],
    'belied': ['confounded', 'confuted', 'deflated', 'denied', 'discarded', 'discredited', 'dismissed', 'disproved', 'disputed', 'exploded', 'exposed', 'impugned'],
    'belief': ['a belief', 'acceptance', 'acquiescence', 'arrogance', 'article of faith', 'assent', 'assurance', 'assuredness', 'axiom', 'canon', 'certainty', 'certitude'],
    'believable': ['colorable', 'conceivable', 'convincing', 'credible', 'creditable', 'fiduciary', 'impressive', 'likely', 'meaningful', 'persuasive', 'plausible', 'possible'],
    'believe': ['accept', 'accept for gospel', 'accept implicitly', 'accredit', 'admit', 'allow', 'assume', 'be afraid', 'be certain', 'be pious', 'be religious', 'believe in'],
    'believer': ['christian', 'god-fearing man', 'accepter', 'catechumen', 'churchgoer', 'churchite', 'churchman', 'communicant', 'convert', 'cultist', 'daily communicant', 'devotee'],
    'belittle': ['bedwarf', 'bring down', 'bring into discredit', 'bring low', 'criticize', 'cry down', 'de-emphasize', 'debase', 'decry', 'degrade', 'denigrate', 'deprecate'],
    'belittled': ['abated', 'ablated', 'attenuated', 'bated', 'consumed', 'contracted', 'curtailed', 'decreased', 'deflated', 'diminished', 'dissipated', 'dropped'],
    'belittling': ['abusive', 'back-biting', 'belittlement', 'bitchy', 'calumniatory', 'calumnious', 'catty', 'censorious', 'comedown', 'contempt', 'contemptuous', 'contumelious'],
    'bell': ['roman candle', 'aerophone', 'aid to navigation', 'alarm', 'amber light', 'arrest', 'balefire', 'battery', 'beacon', 'beacon fire', 'bell buoy', 'bells'],
    'bell the cat': ['affront', 'beard', 'bite the bullet', 'brave', 'brazen', 'brazen out', 'confront', 'court danger', 'defy danger', 'face', 'face the music', 'face up'],
    'belladonna': ['det', 'dmt', 'indian hemp', 'lsd', 'thc', 'bhang', 'cannabis', 'castor-oil plant', 'deadly nightshade', 'death camas', 'diethyltryptamine', 'dimethyltryptamine'],
    'bellboy': ['ganymede', 'hebe', 'airline hostess', 'airline stewardess', 'attendant', 'batman', 'bellhop', 'bellman', 'bootblack', 'boots', 'cabin boy', 'caddie'],
    'belle': ['miss america', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'beauty queen', 'bunny', 'charmer', 'cover girl', 'dazzler', 'dream'],
    'belles-lettres': ['french literature', 'renaissance literature', 'ancient literature', 'classics', 'contemporary literature', 'erotic literature', 'erotica', 'folk literature', 'humane letters', 'kitsch', 'letters', 'literature'],
    'bellhop': ['ganymede', 'hebe', 'airline hostess', 'airline stewardess', 'attendant', 'batman', 'bellboy', 'bellman', 'bootblack', 'boots', 'cabin boy', 'caddie'],
    'bellicose': ['aggressive', 'antagonistic', 'assertive', 'battling', 'belligerent', 'bickering', 'bloodthirsty', 'bloody', 'bloody-minded', 'chauvinist', 'chauvinistic', 'combative'],
    'bellied': ['bellylike', 'bug-eyed', 'bulged', 'bulging', 'convex', 'exophthalmic', 'goggle', 'goggled', 'popeyed', 'pouched', 'rotund', 'round'],
    'belligerence': ['aggression', 'aggressiveness', 'all-out war', 'antagonism', 'antipathy', 'appeal to arms', 'argumentativeness', 'armed combat', 'armed conflict', 'attack', 'battle', 'bellicism'],
    'belligerent': ['acrid', 'aggressive', 'antagonist', 'antagonistic', 'antipathetic', 'ardent', 'argumental', 'argumentative', 'attacking', 'battler', 'battling', 'bellicose'],
    'bellow': ['bark', 'battle cry', 'bawl', 'bay', 'be angry', 'be excitable', 'bell', 'bellow out', 'blare', 'blat', 'blate', 'bleat'],
    'bellowing': ['abandoned', 'amok', 'berserk', 'carried away', 'delirious', 'demoniac', 'distracted', 'ecstatic', 'enraptured', 'feral', 'ferocious', 'fierce'],
    'bellwether': ['mahdi', 'ancestor', 'announcer', 'antecedent', 'avant-garde', 'bell cow', 'bell mare', 'born leader', 'buccinator', 'bushwhacker', 'charismatic leader', 'choirmaster'],
    'belly': ['abdomen', 'abomasum', 'ascender', 'back', 'bag', 'balloon', 'bastard type', 'bay window', 'beard', 'bed', 'bedrock', 'beerbelly'],
    'belly dancer': ['artist', 'artiste', 'burlesque queen', 'chorine', 'chorus boy', 'chorus girl', 'conjurer', 'coryphee', 'dancer', 'dancing girl', 'ecdysiast', 'entertainer'],
    'belly flop': ['belly buster', 'belly whopper', 'cannonball', 'crash dive', 'dive', 'drop', 'fall', 'gainer', 'header', 'jackknife', 'nose dive', 'parachute jump'],
    'bellyache': ['ache', 'aching', 'air a grievance', 'angina', 'backache', 'beef', 'beefing', 'bellyaching', 'bitch', 'bitching', 'cephalalgia', 'clamor'],
    'bellyband': ['back band', 'backstrap', 'bearing rein', 'bit', 'blinders', 'blinds', 'breeching', 'bridle', 'caparison', 'cavesson', 'checkrein', 'cheekpiece'],
    'bellyful': ['bumper', 'capacity', 'charge', 'complement', 'cram', 'crush', 'engorgement', 'fill', 'full house', 'full measure', 'fullness', 'glut'],
    'belong': ['accord', 'affect', 'agree', 'answer to', 'appertain', 'appertain to', 'apply to', 'be a member', 'be inscribed', 'be there', 'bear on', 'bear upon'],
    'belongings': ['accessories', 'appanages', 'appendages', 'appointments', 'appurtenances', 'chattels', 'choses', 'choses in action', 'choses in possession', 'choses local', 'choses transitory', 'effects'],
    'beloved': ['admired', 'adored', 'beau', 'beloved object', 'cherished', 'crush', 'darling', 'dear', 'dear one', 'dearly beloved', 'esteemed', 'favorite'],
    'below': ['adown', 'at a disadvantage', 'at the nadir', 'behind', 'below deck', 'below par', 'below the mark', 'belowstairs', 'beneath', 'beneath the sky', 'down', 'down below'],
    'below par': ['ailing', 'at a discount', 'at a reduction', 'bad', 'below', 'below deck', 'below standard', 'below the mark', 'belowstairs', 'critically ill', 'down', 'down below'],
    'below the mark': ['amiss', 'astray', 'at a disadvantage', 'at the nadir', 'below', 'below deck', 'below par', 'below standard', 'belowstairs', 'beside the mark', 'beside the point', 'bootlessly'],
    'belt': ['appleton layer', 'f layer', 'heaviside-kennelly layer', 'mystik tape', 'scotch tape', 'van allen belt', 'adhesive tape', 'airspace', 'anklet', 'area', 'arm', 'armlet'],
    'belvedere': ['havana', 'texas tower', 'alcove', 'beacon', 'bleachers', 'box of cigars', 'bridge', 'cheroot', 'cigar', 'cigar box', 'cigar case', 'cigar cutter'],
    'bemire': ['begrime', 'bemud', 'besmoke', 'bog', 'bog down', 'dirt', 'dirty', 'dirty up', 'dust', 'grime', 'mire', 'muck'],
    'bemoan': ['be sorry for', 'bewail', 'complain', 'deplore', 'dirge', 'elegize', 'give sorrow words', 'grieve', 'grieve for', 'keen', 'knell', 'lament'],
    'bemused': ['absent', 'absentminded', 'absorbed', 'abstracted', 'addled', 'beery', 'besotted', 'blind drunk', 'castle-building', 'crapulent', 'crapulous', 'daydreaming'],
    'bench': ['british cabinet', 'sanhedrin', 'us cabinet', 'advisory body', 'agency', 'ambo', 'assembly', 'association', 'atelier', 'bar', 'barbershop', 'beauty parlor'],
    'bench mark': ['abode', 'area', 'bearings', 'bookmark', 'cairn', 'cardinal point', 'catstone', 'chief thing', 'climax', 'core', 'cornerstone', 'crisis'],
    'bend': ['s-curve', 'aberrancy', 'aberration', 'accommodate', 'accommodate with', 'accord', 'achievement', 'adapt', 'adapt to', 'adjust', 'adjust to', 'affect'],
    'bend over backwards': ['be careful', 'be cautious', 'be fair', 'be just', 'do justice to', 'exercise care', 'give and take', 'handle with gloves', 'have a care', 'lean over backwards', 'redress a wrong', 'remedy an injustice'],
    'bendable': ['adaptable', 'bending', 'compliant', 'ductile', 'elastic', 'extensible', 'extensile', 'fabricable', 'facile', 'fictile', 'flexible', 'flexile'],
    'bender': ['bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'binge', 'booze', 'bout', 'brannigan', 'bum', 'bust', 'carousal', 'carouse'],
    'bends': ['minamata disease', 'altitude sickness', 'anoxemia', 'anoxia', 'anoxic anoxia', 'anthrax', 'asteroids', 'aurora particles', 'black lung', 'blackout', 'caisson disease', 'chilblain'],
    'beneath contempt': ['abhorrent', 'abominable', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beggarly', 'below contempt', 'blameworthy', 'brutal', 'cheap'],
    'beneath one': ['cheap', 'debasing', 'degrading', 'demeaning', 'deplorable', 'disgraceful', 'gutter', 'humiliating', 'humiliative', 'infra dig', 'infra indignitatem', 'opprobrious'],
    'benedict arnold': ['brutus', 'judas', 'judas iscariot', 'quisling', 'archtraitor', 'betrayer', 'cockatrice', 'conniver', 'conspirator', 'conspirer', 'double agent', 'double-crosser'],
    'benedictine': ['augustinian', 'augustinian hermit', 'austin friar', 'bernardine', 'black friar', 'black monk', 'bonhomme', 'brigittine', 'capuchin', 'carmelite', 'carthusian', 'cistercian'],
    'benediction': ['ok', 'acknowledgment', 'advantage', 'approval', 'benedicite', 'benefit', 'benison', 'blessing', 'boon', 'cognizance', 'credit', 'crediting'],
    'benefaction': ['act of grace', 'act of kindness', 'alms', 'beneficence', 'benefit', 'benevolence', 'benignity', 'blessing', 'boon', 'charity', 'contribution', 'courtesy'],
    'beneficence': ['bomfog', 'benthamism', 'christian charity', 'christian love', 'agape', 'alms', 'altruism', 'auspiciousness', 'benefaction', 'benevolence', 'benevolent disposition', 'benevolentness'],
    'beneficent': ['almsgiving', 'altruistic', 'amicable', 'benevolent', 'benign', 'benignant', 'bighearted', 'charitable', 'cooperative', 'eleemosynary', 'favorable', 'freehearted'],
    'beneficial': ['advantageous', 'aidful', 'appropriate', 'auspicious', 'banausic', 'benevolent', 'benign', 'bon', 'bonny', 'bracing', 'braw', 'bueno'],
    'beneficiary': ['allottee', 'almsman', 'almswoman', 'annuitant', 'assign', 'assignee', 'benefice-holder', 'cestui', 'cestui que trust', 'cestui que use', 'deedholder', 'devisee'],
    'benefit': ['abet', 'absolute interest', 'account', 'act of grace', 'act of kindness', 'advance', 'advantage', 'aid', 'allowances', 'ameliorate', 'answer', 'assist'],
    'benevolence': ['bomfog', 'benthamism', 'christian charity', 'christian love', 'accommodatingness', 'act of grace', 'act of kindness', 'advantageousness', 'affability', 'agape', 'agreeableness', 'altruism'],
    'benevolent': ['accommodating', 'advantageous', 'affable', 'agreeable', 'almsgiving', 'altruistic', 'amiable', 'amicable', 'auspicious', 'beneficent', 'beneficial', 'benign'],
    'benighted': ['ableptical', 'amaurotic', 'backward', 'bereft of light', 'blind', 'color-blind', 'dark', 'dim-sighted', 'empty-headed', 'eyeless', 'hemeralopic', 'ignorant'],
    'benign': ['christian', 'christlike', 'christly', 'accommodating', 'affable', 'affectionate', 'agreeable', 'amiable', 'amicable', 'auspicious', 'beneficent', 'beneficial'],
    'benignity': ['accommodatingness', 'act of grace', 'act of kindness', 'advantageousness', 'affability', 'affectionateness', 'agreeableness', 'amiability', 'auspiciousness', 'benefaction', 'beneficence', 'beneficialness'],
    'bent': ['v-shaped', 'y-shaped', 'a thing for', 'ability', 'abnormal', 'affinity', 'afflicted', 'aim', 'akimbo', 'an ear for', 'an eye for', 'anamorphous'],
    'bent on': ['aching for', 'crazy to', 'dead set on', 'decided upon', 'desirous of', 'determined upon', 'dying for', 'dying to', 'fain of', 'fixed upon', 'fond of', 'hell-bent on'],
    'benthos': ['bassalia', 'loch ness monster', 'abyss', 'abyssal zone', 'alevin', 'bathyal zone', 'benthon', 'bottom waters', 'bottomless depths', 'cetacean', 'dolphin', 'fingerling'],
    'benumb': ['ko', 'abate', 'allay', 'alleviate', 'anesthetize', 'appease', 'assuage', 'bedaze', 'bemuse', 'besot', 'bite', 'blunt'],
    'benumbed': ['laodicean', 'olympian', 'aloof', 'anesthetized', 'apathetic', 'asleep', 'blah', 'blase', 'bored', 'callous', 'comatose', 'dead'],
    'benzedrine': ['benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'methedrine', 'amphetamine', 'amphetamine sulfate', 'cocaine', 'coke', 'crystal', 'dextroamphetamine sulfate'],
    'benzine': ['alcohol', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coal oil', 'coke', 'combustible', 'dope', 'electricity'],
    'bequeath': ['abalienate', 'add a codicil', 'alien', 'alienate', 'amortize', 'assign', 'barter', 'cede', 'confer', 'consign', 'convey', 'deed'],
    'bequeathal': ['abalienation', 'alienation', 'amortization', 'amortizement', 'assignation', 'assignment', 'attested copy', 'bargain and sale', 'barter', 'bequest', 'birthright', 'borough-english'],
    'bequest': ['attested copy', 'bequeathal', 'birthright', 'borough-english', 'codicil', 'coheirship', 'coparcenary', 'devise', 'entail', 'gavelkind', 'heirloom', 'heirship'],
    'berate': ['abuse', 'bark at', 'bawl out', 'betongue', 'blacken', 'castigate', 'chew out', 'chide', 'excoriate', 'execrate', 'fulminate against', 'harangue'],
    'berating': ['abuse', 'assailing', 'assault', 'attack', 'bitter words', 'blackening', 'contumely', 'diatribe', 'execration', 'hard words', 'invective', 'jawing'],
    'bereave': ['abridge', 'bleed', 'curtail', 'cut off', 'deprive', 'deprive of', 'disentitle', 'disinherit', 'dispossess', 'divest', 'drain', 'ease one of'],
    'bereaved': ['beggared', 'beggarly', 'bereaved of', 'bereft', 'cut off', 'denuded', 'deprived', 'deprived of', 'disadvantaged', 'distressed', 'divested', 'fatherless'],
    'bereavement': ['abridgment', 'cost', 'curtailment', 'damage', 'dead loss', 'debit', 'denial', 'denudation', 'deprivation', 'deprivement', 'despoilment', 'destruction'],
    'bereft': ['bankrupt in', 'bare of', 'beggared', 'beggarly', 'bereaved', 'bereaved of', 'bereft of', 'cut off', 'denuded', 'denuded of', 'deprived', 'deprived of'],
    'berg': ['dry ice', 'calf', 'cryosphere', 'firn', 'floe', 'frazil', 'frozen water', 'glaciation', 'glacier', 'glacieret', 'glaze', 'glazed frost'],
    'beribbon': ['bead', 'bejewel', 'bespangle', 'diamond', 'engrave', 'feather', 'figure', 'filigree', 'flag', 'flounce', 'flower', 'garland'],
    'beribboned': ['adorned', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'bespangled', 'decked out', 'decorated', 'embellished', 'feathered', 'festooned'],
    'beriberi': ['lombardy leprosy', 'anemia', 'ariboflavinosis', 'cachexia', 'chlorosis', 'deficiency anemia', 'dermatitis', 'goiter', 'greensickness', 'keratomalacia', 'kwashiorkor', 'maidism'],
    'berm': ['alameda', 'bank', 'beach', 'beaten path', 'beaten track', 'bicycle path', 'boardwalk', 'bridle path', 'catwalk', 'coast', 'coastland', 'coastline'],
    'berry': ['catawba', 'persian melon', 'valencia orange', 'acorn', 'akee', 'alligator pear', 'ananas', 'apple', 'apricot', 'avocado', 'banana', 'bearberry'],
    'berserk': ['dionysiac', 'abandoned', 'amok', 'bacchic', 'bellowing', 'carried away', 'corybantic', 'crazed', 'delirious', 'demoniac', 'desperate', 'distracted'],
    'berth': ['abide', 'accommodations', 'anchor', 'anchorage', 'anchorage ground', 'appointment', 'basin', 'bed', 'billet', 'breakwater', 'bulkhead', 'bunk'],
    'beseech': ['adjure', 'appeal', 'appeal to', 'beg', 'call for help', 'call on', 'call upon', 'clamor for', 'commune with god', 'conjure', 'crave', 'cry for'],
    'beseechment': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'adjuration', 'aid prayer', 'appeal', 'beadroll', 'beads', 'bid'],
    'beset': ['abashed', 'afflict', 'afflicted', 'aggravate', 'agitated', 'ail', 'annoy', 'annoyed', 'anxious', 'apply pressure', 'assail', 'assault'],
    'besetting': ['annoying', 'average', 'backbreaking', 'common', 'crushing', 'current', 'dominant', 'epidemic', 'grueling', 'heavy', 'hefty', 'irksome'],
    'beside': ['abeam', 'above', 'abreast', 'additionally', 'again', 'agitated', 'all included', 'along by', 'alongside', 'also', 'altogether', 'among other things'],
    'beside the point': ['adrift', 'amiss', 'astray', 'below the mark', 'beside the mark', 'beside the question', 'bootlessly', 'extraneous', 'extrinsic', 'far from it', 'fruitlessly', 'immaterial'],
    'besides': ['above and beyond', 'added', 'additionally', 'along', 'along with', 'also', 'apart from', 'as well', 'as well as', 'aside from', 'bar', 'barring'],
    'besiege': ['apply pressure', 'assail', 'assault', 'attack', 'beleaguer', 'beset', 'blandish', 'block', 'block off', 'block up', 'blockade', 'bound'],
    'besmear': ['apply paint', 'attaint', 'bedaub', 'bedizen', 'begild', 'besmirch', 'besmoke', 'besmutch', 'besoil', 'bestain', 'black', 'blacken'],
    'besmirch': ['attaint', 'bedarken', 'bedaub', 'besmear', 'besmoke', 'besmutch', 'besoil', 'bespatter', 'bestain', 'black', 'blacken', 'blackwash'],
    'besmirched': ['bedraggled', 'befouled', 'blackened', 'blotchy', 'darkened', 'defiled', 'dingy', 'dirtied', 'dirty', 'discolored', 'drabbled', 'draggled'],
    'besmoke': ['attaint', 'bedaub', 'begrime', 'bemire', 'bemud', 'besmear', 'besmirch', 'bestain', 'blacken', 'blur', 'brand', 'darken'],
    'besot': ['ko', 'addle', 'anesthetize', 'bedaze', 'befuddle', 'bemuse', 'benumb', 'blunt', 'chloroform', 'coldcock', 'deaden', 'desensitize'],
    'besotted': ['addled', 'apish', 'asinine', 'batty', 'beery', 'befooled', 'beguiled', 'bemused', 'blind drunk', 'brainless', 'buffoonish', 'cockeyed'],
    'bespangle': ['band', 'bar', 'bead', 'bejewel', 'beribbon', 'bespeckle', 'bespot', 'blotch', 'check', 'checker', 'dapple', 'diamond'],
    'bespangled': ['ablaze', 'adorned', 'aglow', 'alight', 'bathed with light', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'blotched'],
    'bespatter': ['asperge', 'asperse', 'attaint', 'bedabble', 'bedew', 'befoul', 'besmirch', 'bespot', 'besprinkle', 'blacken', 'blot', 'blow upon'],
    'bespeak': ['accost', 'address', 'announce', 'apostrophize', 'appeal to', 'apply for', 'apply to', 'approach', 'approve', 'argue', 'ask', 'ask for'],
    'bespeckle': ['band', 'bar', 'bespangle', 'bespot', 'blot', 'blotch', 'check', 'checker', 'dapple', 'dot', 'flake', 'fleck'],
    'best': ['aristocracy', 'barons', 'bear the palm', 'beat', 'beat all hollow', 'beat hollow', 'better', 'bottom', 'cap', 'champion', 'choice', 'chosen'],
    'best man': ['acolyte', 'adjutant', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider', 'assistant', 'attendant', 'auxiliary', 'bridemaiden', 'bridesmaid'],
    'best seller': ['big hit', 'book', 'bound book', 'brilliant success', 'classic', 'coloring book', 'definitive work', 'fad', 'folio', 'gas', 'gasser', 'great success'],
    'best wishes': ['best love', 'best regards', 'blessing', 'compliment', 'compliments', 'congratulation', 'devoirs', 'egards', 'felicitation', 'good wishes', 'gratulation', 'greetings'],
    'bested': ['all up with', 'beat', 'beaten', 'confounded', 'defeated', 'discomfited', 'done for', 'done in', 'down', 'fallen', 'fixed', 'floored'],
    'bestial': ['adamic', 'circean', 'draconian', 'gothic', 'neanderthal', 'tartarean', 'animal', 'animalian', 'animalic', 'animalistic', 'anthropophagous', 'atrocious'],
    'bestiality': ['adam', 'gothicism', 'neanderthalism', 'abominableness', 'anal intercourse', 'animalism', 'animality', 'atrociousness', 'autoeroticism', 'awfulness', 'barbarism', 'barbarity'],
    'bestow': ['accord', 'administer', 'afford', 'allot', 'allow', 'apply', 'award', 'bestow on', 'billet', 'board', 'bunk', 'communicate'],
    'bestowal': ['accommodation', 'accordance', 'administration', 'application', 'applying', 'award', 'awarding', 'bestowment', 'communication', 'concession', 'conferment', 'conferral'],
    'bestraddle': ['abut on', 'arch over', 'back', 'be based on', 'bear on', 'bestride', 'board', 'bridge', 'clear', 'climb on', 'command', 'dominate'],
    'bestride': ['abut on', 'arch over', 'back', 'be based on', 'bear on', 'bestraddle', 'board', 'bridge', 'bypass', 'clear', 'climb on', 'command'],
    'bet': ['ante', 'ante up', 'back', 'bet on', 'book', 'call', 'chunk', 'cover', 'fade', 'gamble', 'game', 'handbook'],
    'bet on': ['aller sans dire', 'ante', 'ante up', 'back', 'bank on', 'be axiomatic', 'be certain', 'be confident', 'bet', 'calculate on', 'call', 'count on'],
    'beta particle': ['kern', 'nmr', 'alpha particle', 'antibaryon', 'antilepton', 'antimeson', 'atomic nucleus', 'atomic particle', 'aurora particle', 'baryon', 'cathode particle', 'electron'],
    'beta ray': ['becquerel ray', 'grenz ray', 'roentgen ray', 'x radiation', 'x ray', 'actinic ray', 'alpha radiation', 'alpha ray', 'anode ray', 'beta radiation', 'canal ray', 'cathode ray'],
    'bete noire': ['dracula', 'frankenstein', 'mumbo jumbo', 'wolf-man', 'affliction', 'anathema', 'bane', 'bogey', 'bogeyman', 'boggart', 'bogle', 'booger'],
    'betide': ['be found', 'be met with', 'be realized', 'bechance', 'befall', 'break', 'chance', 'come', 'come about', 'come along', 'come down', 'come off'],
    'betimes': ['after a while', 'ahead', 'ahead of time', 'anon', 'at times', 'before', 'before long', 'beforehand', 'beforetime', 'by and by', 'directly', 'early'],
    'betoken': ['affect', 'announce', 'approve', 'argue', 'attest', 'augur', 'be construed as', 'be indicative of', 'be significant of', 'be symptomatic of', 'bespeak', 'bode'],
    'betray': ['abuse', 'apostatize', 'babble', 'bamboozle', 'be indiscreet', 'be unguarded', 'bear witness against', 'beguile', 'betoken', 'betray a confidence', 'blab', 'blabber'],
    'betrayal': ['judas kiss', 'abuse', 'apostasy', 'babbling', 'backsliding', 'bad faith', 'blabbering', 'blabbing', 'bolt', 'breach of faith', 'breakaway', 'communication leak'],
    'betrayed': ['baffled', 'balked', 'bilked', 'blasted', 'blighted', 'chapfallen', 'crestfallen', 'crossed', 'crushed', 'dashed', 'defeated', 'disappointed'],
    'betrayer': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'quisling', 'archtraitor', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'cockatrice', 'conniver'],
    'betrothed': ['affianced', 'assured', 'bound', 'bride-to-be', 'committed', 'compromised', 'contracted', 'engaged', 'fiance', 'fiancee', 'future', 'guaranteed'],
    'better': ['a cut above', 'above', 'accommodate', 'acculturate', 'adapt', 'adjust', 'advance', 'advantage', 'ahead', 'alter', 'altered', 'ameliorate'],
    'better half': ['common-law wife', 'concubine', 'consort', 'feme', 'feme covert', 'goodwife', 'goody', 'helpmate', 'helpmeet', 'lady', 'married woman', 'mate'],
    'better self': ['i myself', 'alter', 'alter ego', 'alterum', 'compunction', 'ego', 'ethical self', 'he', 'her', 'herself', 'him', 'himself'],
    'bettered': ['advanced', 'ameliorated', 'beautified', 'civilized', 'converted', 'cultivated', 'cultured', 'developed', 'educated', 'embellished', 'enhanced', 'enriched'],
    'betterment': ['great leap forward', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'advance', 'advancement', 'alteration', 'amelioration', 'amendment', 'apostasy', 'ascent'],
    'bettor': ['adventurer', 'betting ring', 'boneshaker', 'cardshark', 'cardsharp', 'cardsharper', 'compulsive gambler', 'crap shooter', 'gambler', 'gamester', 'hazarder', 'petty gambler'],
    'between the lines': ['covert', 'cryptic', 'delitescent', 'dormant', 'esoteric', 'hibernating', 'hidden', 'latent', 'lurking', 'muffled', 'mystic', 'obfuscated'],
    'betweentimes': ['ad interim', 'at infrequent intervals', 'at intervals', 'at odd times', 'at times', 'at various times', 'between acts', 'betweenwhiles', 'during the interval', 'en attendant', 'every so often', 'for a time'],
    'betwixt and between': ['amid', 'amidships', 'amidst', 'among', 'amongst', 'between', 'betwixt', 'dull', 'fair', 'fair to middling', 'fairish', 'half-and-half'],
    'bevel': ['ascender', 'astrolabe', 'azimuth circle', 'azimuth compass', 'back', 'bank', 'bastard type', 'beard', 'belly', 'bevel protractor', 'bevel square', 'beveled'],
    'beveled': ['aslant', 'aslope', 'atilt', 'bevel', 'bias', 'biased', 'canting', 'careening', 'inclinational', 'inclinatory', 'inclined', 'inclining'],
    'beverage': ['john barleycorn', 'ade', 'alcohol', 'alcoholic beverage', 'alcoholic drink', 'ambrosia', 'aqua vitae', 'ardent spirits', 'beef tea', 'birch beer', 'blood', 'booze'],
    'bevue': ['bad job', 'balk', 'blunder', 'bobble', 'boggle', 'bonehead play', 'boner', 'boo-boo', 'botch', 'bungle', 'clumsy performance', 'error'],
    'bevy': ['a mass of', 'a world of', 'age group', 'army', 'assembly', 'band', 'battalion', 'body', 'brigade', 'bunch', 'cabal', 'cast'],
    'bewail': ['be sorry for', 'bemoan', 'deplore', 'dirge', 'elegize', 'give sorrow words', 'grieve', 'keen', 'knell', 'lament', 'moan', 'mourn'],
    'bewhiskered': ['back-number', 'banal', 'bearded', 'bromidic', 'common', 'commonplace', 'corny', 'cut-and-dried', 'fade', 'familiar', 'fusty', 'hackney'],
    'bewilder': ['abash', 'addle', 'addle the wits', 'amaze', 'astonish', 'astound', 'awe', 'awestrike', 'baffle', 'ball up', 'becloud', 'bedaze'],
    'bewildered': ['abashed', 'abroad', 'adrift', 'agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'astray', 'at a loss'],
    'bewildering': ['baffling', 'beguiling', 'bothering', 'confounding', 'confusing', 'discomposing', 'disconcerting', 'dismaying', 'distracting', 'disturbing', 'embarrassing', 'enigmatic'],
    'bewitch': ['abuse', 'afflict', 'aggrieve', 'allure', 'attract', 'becharm', 'bedevil', 'befoul', 'beguile', 'blight', 'captivate', 'carry away'],
    'bewitched': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'becharmed', 'beguiled'],
    'bewitching': ['circean', 'alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'blandishing', 'cajoling', 'captivating', 'catching', 'charismatic', 'charming'],
    'bey': ['dalai lama', 'holy roman emperor', 'inca', 'kaiser', 'ardri', 'beg', 'beglerbeg', 'burgrave', 'cacique', 'caesar', 'cham', 'collector'],
    'beyond': ['heaven', 'paradise', 'a better place', 'above', 'above and beyond', 'across', 'added', 'additionally', 'after', 'afterlife', 'afterworld', 'again'],
    'beyond belief': ['a bit thick', 'a bit thin', 'absurd', 'bizarre', 'cockamamie', 'crazy', 'doubtable', 'doubtful', 'dubious', 'dubitable', 'extravagant', 'fantastic'],
    'beyond compare': ['a outrance', 'absolutely', 'all out', 'beyond all bounds', 'beyond comparison', 'beyond measure', 'completely', 'dead', 'downright', 'easily first', 'essentially', 'extremely'],
    'beyond control': ['breachy', 'contumacious', 'defiant', 'fractious', 'incorrigible', 'indocile', 'indomitable', 'insuppressible', 'intractable', 'irrepressible', 'obstreperous', 'out of hand'],
    'beyond measure': ['a outrance', 'absolutely', 'all out', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'completely', 'dead', 'downright', 'essentially', 'extravagantly', 'extremely'],
    'beyond one': ['complex', 'complicated', 'crabbed', 'cramp', 'difficult', 'garbled', 'hard', 'hard to understand', 'impracticable', 'impractical', 'inoperable', 'insuperable'],
    'beyond recall': ['beyond remedy', 'cureless', 'gone', 'immedicable', 'incorrigible', 'incurable', 'inoperable', 'irreclaimable', 'irrecoverable', 'irredeemable', 'irreformable', 'irremediable'],
    'biannual': ['annual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'decennial', 'diurnal', 'fortnightly', 'hebdomadal'],
    'bias': ['a thing for', 'aberrancy', 'aberration', 'across', 'affect', 'affinity', 'angle', 'angle off', 'animus', 'aptitude', 'aptness', 'aslant'],
    'biased': ['across', 'antiblack', 'aslant', 'aslope', 'athwart', 'atilt', 'bendwise', 'bent', 'bevel', 'beveled', 'bias', 'biaswise'],
    'bibelot': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'bagatelle', 'bauble', 'bean', 'bit', 'brass farthing', 'bric-a-brac', 'button'],
    'bible': ['douay bible', 'holy scripture', 'holy writ', 'king james version', 'revised standard version', 'revised version', 'scripture', 'septuagint', 'testament', 'vulgate', 'canon', 'canonical writings'],
    'biblical': ['gospel', 'mosaic', 'new-testament', 'old-testament', 'apocalyptic', 'apostolic', 'canonical', 'evangelic', 'evangelistic', 'gospel', 'inspired', 'prophetic'],
    'bibliographer': ['advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliognost', 'biblioklept', 'bibliolater', 'bibliomane', 'bibliomaniac', 'bibliopegist'],
    'bibliography': ['art index', 'baedeker', 'bibliography index', 'books in print', 'cumulative book index', 'education index', 'national union catalog', 'yellow pages', 'acknowledgments', 'annotated bibliography', 'annual bibliography', 'back'],
    'bibliolatry': ['sabbatarianism', 'bibliomania', 'bigotry', 'bluestockingism', 'book learning', 'book madness', 'bookiness', 'bookishness', 'booklore', 'charismatic gift', 'charismatic movement', 'charismatic renewal'],
    'bibliophile': ['bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliolatrist', 'bibliomane', 'bibliomaniac', 'bibliopegist', 'bibliophage', 'bibliophilist', 'bibliopole', 'bibliopolist'],
    'bibulous': ['absorbent', 'addicted to drink', 'adsorbent', 'assimilative', 'bibacious', 'blotting', 'chemisorptive', 'chemosorptive', 'crapulent', 'crapulous', 'digestive', 'drinking'],
    'bicameral': ['biaxial', 'bicuspid', 'bifid', 'biform', 'binocular', 'binomial', 'binominal', 'bipartite', 'biped', 'bipetalous', 'bipinnate', 'bisexual'],
    'bicentennial': ['anniversary', 'annual holiday', 'bicentenary', 'biennial', 'birthday', 'bissextile day', 'cental', 'centare', 'centenarian', 'centenary', 'centennial', 'centennium'],
    'biceps': ['adductor', 'arm', 'buccinator', 'elbow', 'forearm', 'gemellus', 'gluteus maximus', 'infraspinatus', 'intercostal', 'latissimus dorsi', 'levator', 'masseter'],
    'bicker': ['altercate', 'argue', 'argufy', 'around the bush', 'bandy words', 'battle', 'beat', 'beat about', 'beg the question', 'bicker over', 'boggle', 'brawl'],
    'bickerer': ['battler', 'belligerent', 'belted knight', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'combatant', 'competitor', 'contender', 'contestant'],
    'bickering': ['kilkenny cats', 'aflicker', 'aggressive', 'aggressiveness', 'altercation', 'apologetics', 'apologia', 'apology', 'argument', 'argumentation', 'bellicose', 'bellicosity'],
    'bicolored': ['bicolor', 'colorful', 'colory', 'crazy', 'daedal', 'dichromatic', 'divers-colored', 'harlequin', 'kaleidoscopic', 'many-colored', 'medley', 'motley'],
    'bicorn': ['cynthian', 's-shaped', 'corniform', 'crescent', 'crescent-shaped', 'crescentic', 'crescentiform', 'crescentlike', 'falcate', 'falciform', 'horn-shaped', 'horned'],
    'bicuspid': ['baby tooth', 'biaxial', 'bicameral', 'bifid', 'biform', 'binocular', 'binomial', 'binominal', 'bipartite', 'biped', 'bipetalous', 'bipinnate'],
    'bicycle': ['bike', 'bus', 'catch a train', 'chauffeur', 'chopper', 'cycle', 'drive', 'entrain', 'go by rail', 'iron', 'joyride', 'make a train'],
    'bid': ['adjuration', 'advance', 'appeal', 'approach', 'ask', 'asking price', 'assay', 'attempt', 'bargain', 'bargain price', 'beat down', 'beseechment'],
    'bid come': ['ask', 'call', 'call away', 'call back', 'call for', 'call forth', 'call in', 'call out', 'call together', 'call up', 'cite', 'conjure'],
    'bid price': ['asking price', 'bargain price', 'bearish prices', 'bid', 'book value', 'bullish prices', 'call price', 'cash price', 'closing price', 'controlled price', 'current price', 'current quotation'],
    'bidding': ['beck', 'beck and call', 'behest', 'bid', 'biddance', 'call', 'calling', 'calling forth', 'charge', 'command', 'commandment', 'convocation'],
    'biddy': ['bantam', 'jane', 'partlet', 'abigail', 'amah', 'au pair girl', 'ayah', 'bag', 'banty', 'barn-door fowl', 'barnyard fowl', 'bat'],
    'bide': ['abide', 'abide with', 'await', 'bear', 'bear with', 'bide the issue', 'brave', 'brook', 'carry on', 'cease not', 'continue', 'continue to be'],
    'bidet': ['aquamanile', 'automatic dishwasher', 'basin', 'bath', 'bathtub', 'carriage horse', 'cart horse', 'cavalry horse', 'dishpan', 'dishwasher', 'draft horse', 'dray horse'],
    'biennial': ['amphibian', 'angiosperm', 'anniversary', 'annual', 'annual holiday', 'aquatic plant', 'biannual', 'bicentenary', 'bicentennial', 'bimonthly', 'birthday', 'bissextile day'],
    'biff': ['bang', 'bash', 'bat', 'beating', 'belt', 'blow', 'bonk', 'bop', 'catch', 'chop', 'clap', 'clip'],
    'bifocals': ['polaroid glasses', 'blinkers', 'cheaters', 'colored glasses', 'contact lens', 'dark glasses', 'divided spectacles', 'eyeglass', 'eyeglasses', 'glasses', 'goggles', 'granny glasses'],
    'bifurcation': ['janus', 'ambiguity', 'ambivalence', 'angle', 'apex', 'arborescence', 'arborization', 'bend', 'bifidity', 'biforking', 'biformity', 'bight'],
    'big': ['adult', 'aggrandized', 'ample', 'apotheosized', 'arrogant', 'arty', 'awash', 'awesome', 'awful', 'awfully', 'beatified', 'benevolent'],
    'big brother': ['auditor', 'boatswain', 'boss', 'chief', 'comptroller', 'controller', 'floor manager', 'floorman', 'floorwalker', 'foreman', 'gaffer', 'ganger'],
    'big business': ['balance of trade', 'business', 'business dealings', 'commerce', 'commercial affairs', 'commercial relations', 'dealing', 'dealings', 'fair trade', 'free trade', 'industry', 'intercourse'],
    'big deal': ['emptiness', 'flimsiness', 'foolishness', 'frivolity', 'frivolousness', 'futility', 'idleness', 'inanity', 'levity', 'lightness', 'nugacity', 'shallowness'],
    'big dipper': ['antlia', 'antlia pneumatica', 'apus', 'aquarius', 'ara', 'caela sculptoris', 'caelum', 'camelopardus', 'cancer', 'columba noae', 'corona australis', 'corona borealis'],
    'big game': ['animalia', 'and fish', 'animal kingdom', 'animal life', 'animality', 'beasts', 'beasts of field', 'beasts of prey', 'beasts of venery', 'birds', 'brute creation', 'cattle'],
    'big gun': ['establishment', 'vip', 'baron', 'big boy', 'big cheese', 'big man', 'big name', 'big noise', 'big shot', 'big wheel', 'bigwig', 'brass'],
    'big hand': ['acclaim', 'acclamation', 'applause', 'burst of applause', 'cheer', 'clap', 'clapping', 'clapping of hands', 'eclat', 'encore', 'hand', 'handclap'],
    'big league': ['big', 'big-name', 'big-time', 'bigwig', 'bigwigged', 'consequential', 'considerable', 'double-barreled', 'earthshaking', 'grand', 'great', 'heavyweight'],
    'big mouth': ['captain bobadil', 'gascon', 'texan', 'blower', 'blowhard', 'blusterer', 'boaster', 'brag', 'braggadocio', 'braggart', 'candor', 'communicativeness'],
    'big name': ['establishment', 'vip', 'baron', 'big', 'big gun', 'big man', 'big-league', 'big-time', 'bigwig', 'bigwigged', 'brass', 'brass hat'],
    'big talk': ['barnumism', 'affectation', 'aggrandizement', 'amplification', 'ballyhoo', 'bedizenment', 'blowing up', 'bullshit', 'bunk', 'bunkum', 'burlesque', 'caricature'],
    'big talker': ['agreeable rattle', 'babbler', 'blab', 'blabberer', 'blatherer', 'chatterbox', 'chatterer', 'gabber', 'gabbler', 'gasbag', 'gibble-gabbler', 'great talker'],
    'big time': ['action', 'ball', 'big', 'big-league', 'big-name', 'bigwig', 'bigwigged', 'consequential', 'considerable', 'double-barreled', 'earthshaking', 'fun'],
    'big time operator': ['bmoc', 'activist', 'ball of fire', 'beaver', 'big cheese', 'big noise', 'big shot', 'big wheel', 'big-timer', 'bustler', 'busy bee', 'doer'],
    'big top': ['burlesque show', 'carnival', 'circus', 'coochie show', 'fantoccini', 'floor show', 'galanty show', 'girly show', 'hootchy-kootchy show', 'leg show', 'light show', 'magic show'],
    'big wheel': ['bmoc', 'rasputin', 'svengali', 'vip', 'access', 'bad influence', 'big boy', 'big cheese', 'big gun', 'big noise', 'big shot', 'big-time operator'],
    'bigamy': ['beena marriage', 'common-law marriage', 'companionate marriage', 'concubinage', 'deuterogamy', 'left-handed marriage', 'levirate', 'leviration', 'love match', 'marriage of convenience', 'monandry', 'monogamy'],
    'biggety': ['aggressively self-confident', 'bluff', 'bold', 'brash', 'bumptious', 'cheeky', 'chesty', 'chutzpadik', 'cocky', 'conceited', 'contemptuous', 'crusty'],
    'bighearted': ['almsgiving', 'altruistic', 'beneficent', 'benevolent', 'big', 'bounteous', 'bountiful', 'charitable', 'chivalrous', 'eleemosynary', 'elevated', 'exalted'],
    'bight': ['angle', 'apex', 'arm', 'armlet', 'bay', 'bayou', 'belt', 'bend', 'bifurcation', 'boca', 'cant', 'chevron'],
    'bigot': ['anglophobe', 'russophobe', 'approver', 'ass', 'bitter-ender', 'bug', 'bullethead', 'chauvinist', 'diehard', 'doctrinaire', 'dogmatist', 'dogmatizer'],
    'bigoted': ['sabbatarian', 'authoritarian', 'balking', 'balky', 'biased', 'bigot', 'borne', 'bulldogged', 'bulletheaded', 'bullheaded', 'case-hardened', 'closed'],
    'bigotry': ['anglophobia', 'russophobia', 'sabbatarianism', 'abhorrence', 'abomination', 'anti-semitism', 'antipathy', 'authoritarianism', 'aversion', 'balkiness', 'bias', 'bibliolatry'],
    'bigwig': ['establishment', 'vip', 'aristocracy', 'baron', 'barons', 'big boy', 'big cheese', 'big gun', 'big man', 'big name', 'big noise', 'big shot'],
    'bijou': ['anklet', 'armlet', 'bangle', 'beads', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet', 'charm', 'chatelaine', 'circle'],
    'bike': ['bicycle', 'bus', 'catch a train', 'chauffeur', 'chopper', 'cycle', 'drive', 'entrain', 'go by rail', 'iron', 'joyride', 'make a train'],
    'bilabial': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation', 'back'],
    'bilateral': ['janus-like', 'ambidextrous', 'bifacial', 'bifold', 'biform', 'bifurcated', 'binary', 'binate', 'biparous', 'bipartisan', 'bipartite', 'bivalent'],
    'bile': ['absorption', 'acerbity', 'acid', 'acidity', 'acidulousness', 'acrimony', 'anger', 'animosity', 'asperity', 'assimilation', 'autacoid', 'bad humor'],
    'bilge': ['balderdash', 'baloney', 'bilgewater', 'blah', 'blah-blah', 'blain', 'bleb', 'blister', 'blob', 'bop', 'bosh', 'boss'],
    'bilious': ['allergic', 'anemic', 'angry', 'apoplectic', 'arthritic', 'bad-tempered', 'bitter', 'cancerous', 'chlorotic', 'choleric', 'colicky', 'consumptive'],
    'bilk': ['avoid', 'baffle', 'balk', 'beat', 'beguile of', 'bunco', 'burn', 'cast down', 'cheat', 'chisel', 'chouse', 'chouse out of'],
    'bill': ['cd', 'federal reserve note', 'iou', 'mo', 'acceptance', 'acceptance bill', 'account', 'accounts payable', 'accounts receivable', 'act', 'advertise', 'affiche'],
    'bill collector': ['accumulator', 'collection agent', 'collector', 'connoisseur', 'credit man', 'creditor', 'creditress', 'debtee', 'douanier', 'dun', 'dunner', 'exciseman'],
    'bill of fare': ['account', 'agenda', 'batting order', 'bill', 'bill of lading', 'blueprint', 'books', 'budget', 'calendar', 'card', 'carte', 'carte du jour'],
    'bill of health': ['affidavit', 'attestation', 'authority', 'authorization', 'certificate', 'certificate of proficiency', 'certification', 'clearance', 'credential', 'deposition', 'diploma', 'full pratique'],
    'bill of particulars': ['accusal', 'accusation', 'accusing', 'allegation', 'allegement', 'arraignment', 'blame', 'bringing of charges', 'bringing to book', 'charge', 'complaint', 'count'],
    'bill of rights': ['declaration of right', 'magna carta', 'magna charta', 'petition of right', 'civil liberties', 'civil rights', 'constitution', 'constitutional amendment', 'constitutional guarantees', 'constitutional rights', 'human rights', 'legal rights'],
    'billed': ['roman-nosed', 'aquiline', 'aquiline-nosed', 'beak-nosed', 'beak-shaped', 'beaked', 'bill-like', 'bill-shaped', 'booked', 'clawlike', 'crookbilled', 'crooked'],
    'billet': ['achievement', 'acknowledgment', 'alerion', 'anchor', 'animal charge', 'annulet', 'answer', 'appointment', 'argent', 'armorial bearings', 'armory', 'arms'],
    'billet doux': ['pastoral epistle', 'aerogram', 'air letter', 'airgraph', 'bull', 'chain letter', 'dead letter', 'dimissorial', 'dimissory letter', 'drop letter', 'encyclical', 'fan letter'],
    'billion': ['a billion', 'a crore', 'a lakh', 'a million', 'a myriad', 'a nonillion', 'a quadrillion', 'a thousand', 'a zillion', 'astronomical number', 'googol', 'googolplex'],
    'billionaire': ['daddy warbucks', 'bloated plutocrat', 'capitalist', 'fat cat', 'man of means', 'man of substance', 'man of wealth', 'millionaire', 'moneybags', 'moneyed man', 'multimillionaire', 'nabob'],
    'billow': ['bag', 'balloon', 'be poised', 'belly', 'belly out', 'bilge', 'bore', 'bouge', 'break', 'breakers', 'bug', 'bulge'],
    'billowy': ['bagging', 'baggy', 'ballooning', 'bellying', 'bent', 'billowing', 'bloated', 'bosomy', 'bulbose', 'bulbous', 'bulging', 'bumped'],
    'billy goat': ['billy', 'boar', 'bubbly-jock', 'buck', 'bull', 'bullock', 'chanticleer', 'cock', 'cockerel', 'doe', 'doeling', 'dog'],
    'bin': ['archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bonded warehouse', 'bookcase', 'box', 'bunker', 'buttery'],
    'binary': ['janus-like', 'ambidextrous', 'bifacial', 'bifold', 'biform', 'bilateral', 'binate', 'biparous', 'bivalent', 'conduplicate', 'disomatous', 'double'],
    'bind': ['accept obligation', 'adjoin', 'afterthought', 'agglutinate', 'agree to', 'ally', 'anchor', 'annoyance', 'answer for', 'apply', 'apprentice', 'article'],
    'bind up': ['bale', 'band', 'bandage', 'belt', 'bend', 'bind', 'brace', 'bundle', 'bundle up', 'chain', 'cinch', 'do up'],
    'binder': ['ace bandage', 'band-aid', 'acquitment', 'acquittal', 'acquittance', 'adhesive tape', 'amortization', 'amortizement', 'application', 'band', 'bandage', 'bandaging'],
    'binding': ['smyth sewing', 'absolute', 'adhesive', 'affixation', 'annexation', 'attachment', 'authoritative', 'backing', 'bandage', 'bandaging', 'beading', 'bibliopegy'],
    'binge': ['bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'bender', 'blast', 'blowout', 'booze', 'bout', 'brannigan', 'bum', 'bust'],
    'bingo': ['monopoly', 'ping-pong', 'rugby', 'scrabble', 'archery', 'association football', 'backgammon', 'badminton', 'bagatelle', 'ball', 'bandy', 'baseball'],
    'binomial': ['linnaean', 'biaxial', 'bicameral', 'bicuspid', 'bifid', 'biform', 'binocular', 'binominal', 'bipartite', 'biped', 'bipetalous', 'bipinnate'],
    'biochemical': ['acid', 'acidity', 'agent', 'alkali', 'alkalinity', 'alloisomer', 'anion', 'antacid', 'atom', 'base', 'basic', 'cation'],
    'biochemistry': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'bacteriology', 'biochemics', 'biochemy', 'bioecology', 'biological science', 'biology', 'biometrics', 'biometry'],
    'biofeedback': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'assertiveness training', 'behavior modification', 'behavior therapy', 'bioenergetics', 'confrontation therapy', 'conjoint therapy'],
    'biography': ['clio', 'muse of history', 'adventures', 'annals', 'autobiography', 'biographical sketch', 'case history', 'chronicle', 'chronicles', 'chronology', 'confessions', 'curriculum vitae'],
    'biological clock': ['anima', 'animating force', 'atman', 'bathmism', 'beating heart', 'biorhythm', 'blood', 'breath', 'breath of life', 'divine breath', 'divine spark', 'elan vital'],
    'biological urge': ['andromania', 'aphrodisia', 'bodily appetite', 'carnal desire', 'concupiscence', 'desire', 'eromania', 'eroticism', 'eroticomaniac', 'erotism', 'erotomania', 'fleshly lust'],
    'biologist': ['anatomist', 'animal physiologist', 'anthropologist', 'bacteriologist', 'biochemist', 'biometrist', 'biophysicist', 'botanist', 'conchologist', 'cytologist', 'ecologist', 'entomologist'],
    'biology': ['aerobiology', 'agrobiology', 'anatomy', 'animal physiology', 'anthropology', 'astrobiology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science'],
    'bionics': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'automatic electronics', 'autonetics', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science'],
    'bionomics': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'autecology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology'],
    'biophysics': ['newtonian physics', 'acoustics', 'aerobiology', 'aerophysics', 'agrobiology', 'anatomy', 'applied physics', 'astrobiology', 'astrophysics', 'bacteriology', 'basic conductor physics', 'biochemics'],
    'biopsy': ['pap test', 'anatomic diagnosis', 'biological diagnosis', 'clinical diagnosis', 'cytodiagnosis', 'diagnosis', 'differential diagnosis', 'digital examination', 'electrocardiography', 'electroencephalography', 'electromyography', 'examination'],
    'biorhythm': ['anima', 'animating force', 'atman', 'bathmism', 'beating heart', 'biological clock', 'blood', 'breath', 'breath of life', 'divine breath', 'divine spark', 'elan vital'],
    'biosphere': ['earth', 'gaea', 'ge', 'tellus', 'terra', 'aerosphere', 'all that lives', 'atmosphere', 'biochore', 'biocycle', 'biota', 'biotope'],
    'bipartisan': ['biform', 'bifurcated', 'bilateral', 'bipartite', 'biparty', 'dichotomous', 'double', 'duadic', 'dual', 'dualistic', 'duplex', 'duplicated'],
    'bipartisanship': ['coaction', 'coadjuvancy', 'coadministration', 'coagency', 'cochairmanship', 'codirectorship', 'collaboration', 'collaborativeness', 'collectivism', 'collusion', 'commensalism', 'common effort'],
    'bipartite': ['apart', 'asunder', 'biaxial', 'bicameral', 'bicuspid', 'bifid', 'biform', 'bifurcated', 'bilateral', 'binocular', 'binomial', 'binominal'],
    'biped': ['amphibian', 'aquatic', 'biaxial', 'bicameral', 'bicuspid', 'bifid', 'biform', 'binocular', 'binomial', 'binominal', 'bipartite', 'bipetalous'],
    'bircher': ['bourbon', 'tory', 'conservatist', 'conservative', 'diehard', 'extreme right-winger', 'hard hat', 'imperialist', 'monarchist', 'radical right', 'reactionarist', 'reactionary'],
    'bird': ['bronx cheer', 'jane', 'atomic warhead', 'avifauna', 'baby bird', 'bastard', 'biddy', 'bird of jove', 'bird of juno', 'bird of minerva', 'bird of night', 'bird of passage'],
    'bird cage': ['aviary', 'birdhouse', 'bones', 'columbary', 'crap game', 'crap shooting', 'craps', 'crooked dice', 'cubes', 'dice', 'die', 'dovecote'],
    'bird sanctuary': ['indian reservation', 'archives', 'asylum', 'bank', 'forest preserve', 'game preserve', 'game reserve', 'game sanctuary', 'harbor', 'harbor of refuge', 'harborage', 'haven'],
    'birdcall': ['angelus', 'angelus bell', 'alarm', 'alarum', 'animal noise', 'bark', 'barking', 'battle cry', 'bugle call', 'call', 'clang', 'cry'],
    'birth': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory', 'abiogenesis'],
    'birth control': ['aridity', 'barrenness', 'contraception', 'dearth', 'dry womb', 'dryness', 'family planning', 'famine', 'impotence', 'ineffectualness', 'infecundity', 'infertility'],
    'birth defect': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'blight', 'cardiovascular disease', 'chronic disease'],
    'birthday': ['anniversary', 'annual holiday', 'bicentenary', 'bicentennial', 'biennial', 'bissextile day', 'centenary', 'centennial', 'commemoration', 'decennial', 'diamond jubilee', 'golden wedding anniversary'],
    'birthday suit': ['bareness', 'decollete', 'ecdysiast', 'gymnosophist', 'gymnosophy', 'nakedness', 'naturism', 'naturist', 'not a stitch', 'nudism', 'nudist', 'nudity'],
    'birthmark': ['blackhead', 'blaze', 'bleb', 'blemish', 'blister', 'blotch', 'brand', 'bulla', 'caste mark', 'character', 'check', 'checkmark'],
    'birthplace': ['vaterland', 'breeding place', 'brooder', 'cradle', 'fatherland', 'forcing bed', 'hatchery', 'home', 'homeground', 'homeland', 'hotbed', 'incubator'],
    'birthright': ['appanage', 'appurtenance', 'authority', 'bequeathal', 'bequest', 'borough-english', 'claim', 'coheirship', 'conjugal right', 'coparcenary', 'demand', 'divine right'],
    'biscuit': ['brussels biscuit', 'melba toast', 'adobe', 'bisque', 'bone', 'bowl', 'brick', 'brownie', 'cement', 'ceramic ware', 'ceramics', 'china'],
    'bisect': ['amputate', 'average', 'ax', 'bifurcate', 'branch', 'butcher', 'by two', 'carve', 'chop', 'cleave', 'cut', 'cut away'],
    'bisexual': ['ac-dc', 'amphierotic', 'androgyne', 'androgynous', 'auntie', 'autoerotic', 'bi-guy', 'biaxial', 'bicameral', 'bicuspid', 'bifid', 'biform'],
    'bishop': ['aaronic priesthood', 'grand penitentiary', 'holy father', 'melchizedek priesthood', 'seventy', 'abuna', 'antipope', 'apostle', 'archbishop', 'archdeacon', 'archpriest', 'bishop coadjutor'],
    'bishopric': ['kreis', 'abbacy', 'aedileship', 'archbishopric', 'archdeaconry', 'archdiocese', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'arrondissement', 'bailiwick', 'bishopdom'],
    'bison': ['brahman', 'indian buffalo', 'aurochs', 'beef', 'beef cattle', 'beeves', 'bossy', 'bovine', 'bovine animal', 'buffalo', 'bull', 'bullock'],
    'bisque': ['adobe', 'biscuit', 'borscht', 'bouillabaisse', 'bouillon', 'bowl', 'brick', 'broth', 'burgoo', 'cement', 'ceramic ware', 'ceramics'],
    'bistro': ['alehouse', 'automat', 'bar', 'barrel house', 'barroom', 'beanery', 'beer garden', 'beer parlor', 'blind tiger', 'buffet', 'buvette', 'cabaret'],
    'bit': ['algol', 'cobol', 'edp', 'fortran', 'a breath', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'ace', 'act'],
    'bit by bit': ['by degrees', 'by inches', 'by inchmeal', 'by slow degrees', 'by snatches', 'degreewise', 'drop by drop', 'foot by foot', 'gradatim', 'grade by grade', 'gradually', 'in detail'],
    'bitch': ['augean task', 'herculean task', 'jane', 'jezebel', 'partlet', 'seeing eye dog', 'air a grievance', 'backbreaker', 'bad woman', 'baggage', 'ballbuster', 'bandog'],
    'bitch box': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer', 'crystal pickup'],
    'bitchy': ['abusive', 'back-biting', 'baleful', 'bearish', 'belittling', 'calumniatory', 'calumnious', 'cankered', 'cantankerous', 'catty', 'censorious', 'churlish'],
    'bite': ['acerbity', 'acidity', 'acridity', 'acrimony', 'acuminate', 'acute pain', 'adhere to', 'afflict', 'agonize', 'ail', 'allotment', 'allowance'],
    'bite the bullet': ['affront', 'beard', 'bell the cat', 'brave', 'brazen', 'brazen out', 'confront', 'face', 'face the music', 'face up', 'face up to', 'front'],
    'bite the dust': ['bow', 'break up', 'crumble', 'crumble to dust', 'disintegrate', 'drop dead', 'fall', 'fall dead', 'fall down dead', 'fall to pieces', 'go down', 'go to pieces'],
    'biting': ['attic', 'siberian', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'acute'],
    'bitter': ['siberian', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'affecting', 'afflictive'],
    'bitter end': ['thule', 'ultima thule', 'bottom dollar', 'boundary', 'butt', 'butt end', 'catastrophe', 'climax', 'completion', 'conclusion', 'consummation', 'culmination'],
    'bitter pill': ['acerbity', 'acridity', 'acridness', 'affliction', 'astringence', 'astringency', 'bitter cup', 'bitter draft', 'bitter draught', 'bitterness', 'burden', 'burden of care'],
    'bitterly': ['abominably', 'acerbically', 'acerbly', 'acidly', 'acridly', 'acrimoniously', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitingly', 'blatantly'],
    'bitterness': ['absolute zero', 'acerbity', 'aching heart', 'acid', 'acidity', 'acidness', 'acidulousness', 'acridity', 'acridness', 'acrimony', 'agony', 'agony of mind'],
    'bivouac': ['konzentrationslager', 'lager', 'anchor', 'barrack', 'barracks', 'billet at', 'burrow', 'camp', 'camp out', 'campground', 'campsite', 'cantonment'],
    'biweekly': ['annual', 'biannual', 'biennial', 'bimonthly', 'catamenial', 'centenary', 'centennial', 'daily', 'daybook', 'decennial', 'diary', 'diurnal'],
    'bizarre': ['gothic', 'absurd', 'amusing', 'antic', 'awe-inspiring', 'awesome', 'awful', 'awing', 'baroque', 'beyond belief', 'brain-born', 'cockamamie'],
    'blab': ['agreeable rattle', 'babble', 'babblement', 'babbler', 'bavardage', 'be indiscreet', 'be unguarded', 'bear witness against', 'betray', 'betray a confidence', 'betrayer', 'bibble-babble'],
    'blabber': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bavardage', 'be indiscreet', 'be unguarded', 'betray', 'betray a confidence', 'betrayer', 'bibble-babble'],
    'blabbermouth': ['babbler', 'betrayer', 'blab', 'blabber', 'blabberer', 'chatterer', 'delator', 'fink', 'gabber', 'gossip', 'informer', 'jabberer'],
    'black': ['american indian', 'amerind', 'australian aborigine', 'brunswick black', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito'],
    'black and white': ['north pole', 'south pole', 'antipodal points', 'antipodes', 'antipoints', 'antipoles', 'arc lighting', 'brouillon', 'cartoon', 'charcoal', 'charcoal drawing', 'chiaroscuro'],
    'black belt': ['chinese boxer', 'agricultural region', 'arable land', 'bantamweight', 'boxer', 'brown belt', 'bruiser', 'citrus belt', 'corn belt', 'cotton belt', 'countryside', 'dust bowl'],
    'black death': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'ambulatory plague', 'amebiasis', 'amebic dysentery', 'anthrax'],
    'black eye': ['aspersion', 'attaint', 'badge of infamy', 'bar sinister', 'baton', 'bend sinister', 'black mark', 'black-and-blue mark', 'blot', 'blur', 'brand', 'broad arrow'],
    'black hole': ['beehive', 'cepheid variable', 'hertzsprung-russell diagram', 'hyades', 'messier catalog', 'ngc', 'pow camp', 'pleiades', 'seven sisters', 'absolute magnitude', 'bastille', 'binary star'],
    'black humor': ['atticism', 'agile wit', 'burlesque', 'caricature', 'comedy', 'dry wit', 'esprit', 'farce', 'humor', 'irony', 'lampoon', 'nimble wit'],
    'black lung': ['asiatic flu', 'hong kong flu', 'minamata disease', 'acute bronchitis', 'adenoiditis', 'altitude sickness', 'aluminosis', 'amygdalitis', 'anoxemia', 'anoxia', 'anoxic anoxia', 'anthracosilicosis'],
    'black magic': ['black mass', 'satanism', 'chthonian worship', 'demonism', 'demonography', 'demonolatry', 'demonology', 'demonomancy', 'demonomy', 'demonry', 'devil lore', 'devil worship'],
    'black man': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'black mark': ['aspersion', 'attaint', 'badge of infamy', 'bar sinister', 'baton', 'bend sinister', 'black eye', 'blot', 'blur', 'brand', 'broad arrow', 'censure'],
    'black market': ['cosa nostra', 'mafia', 'actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'black-marketeer', 'bootleg', 'bootlegging', 'chargeable', 'contraband'],
    'black mass': ['satanism', 'black magic', 'chthonian worship', 'demonism', 'demonography', 'demonolatry', 'demonology', 'demonomancy', 'demonomy', 'demonry', 'devil lore', 'devil worship'],
    'black out': ['annul', 'becloud', 'bedarken', 'bedim', 'begloom', 'black', 'blacken', 'block the light', 'blot out', 'brown', 'cancel', 'cast a shadow'],
    'black power': ['italian vote', 'jewish vote', 'jim crow', 'jim crow law', 'polish power', 'white power', 'amperage', 'anti-semitism', 'apartheid', 'armipotence', 'authority', 'beef'],
    'black sheep': ['backslider', 'bad egg', 'bad lot', 'blemish', 'degenerate', 'fallen angel', 'foreign body', 'foreign intruder', 'impurity', 'intruder', 'lecher', 'lost sheep'],
    'blackball': ['ban', 'banish', 'banishment', 'blackballing', 'blacklist', 'boycott', 'boycottage', 'cast out', 'categorically reject', 'complaint', 'cut', 'deport'],
    'blackdamp': ['afterdamp', 'breath', 'chokedamp', 'cloud', 'coal gas', 'damp', 'effluvium', 'exhalation', 'exhaust', 'exhaust gas', 'fetid air', 'firedamp'],
    'blacken': ['abuse', 'asperse', 'attaint', 'bark at', 'becloud', 'bedarken', 'bedaub', 'bedim', 'begloom', 'begrime', 'berate', 'besmear'],
    'blackhead': ['birthmark', 'bleb', 'blemish', 'blister', 'bulla', 'check', 'cicatrix', 'comedo', 'crack', 'crater', 'craze', 'defacement'],
    'blackjack': ['boston', 'earl of coventry', 'pit', 'polish bank', 'russian bank', 'all fours', 'baccarat', 'banker', 'bastinado', 'bat', 'battering ram', 'billy'],
    'blackleg': ['texas fever', 'anthrax', 'aphthous fever', 'bighead', 'black quarter', 'blackwater', 'blind staggers', 'bloody flux', 'broken wind', 'cattle plague', 'charbon', 'cheat'],
    'blacklist': ['anathematize', 'attaint', 'ban', 'banish', 'banishment', 'blackball', 'boycott', 'boycottage', 'bring home to', 'censure', 'condemn', 'convict'],
    'blackmail': ['account', 'allowance', 'ask', 'ask for', 'assessment', 'badger', 'badger game', 'bill', 'blood money', 'bloodsucking', 'boodle', 'booty'],
    'blackout': ['ko', 'agnosia', 'amnesia', 'anoxia', 'asteroids', 'aurora particles', 'bamboo curtain', 'barrier of secrecy', 'blocking', 'brownout', 'catalepsy', 'catatonia'],
    'blacktop': ['tarmac', 'tarvia', 'asphalt', 'bitumen', 'bituminous macadam', 'brick', 'carpet', 'causeway', 'cement', 'cobble', 'cobblestone', 'concrete'],
    'bladder': ['air bubble', 'bag', 'ball', 'balloon', 'bleb', 'blister', 'blob', 'blood blister', 'boll', 'bolus', 'bubble', 'bulb'],
    'blade': ['beau brummel', 'excalibur', 'skimobile', 'sno-cat', 'alveolar ridge', 'alveolus', 'apex', 'arytenoid cartilages', 'ax', 'back', 'battler', 'bayonet'],
    'blah': ['laodicean', 'olympian', 'acedia', 'aloof', 'aloofness', 'apathetic', 'apathy', 'arid', 'ataraxia', 'ataraxy', 'balderdash', 'baloney'],
    'blah feeling': ['adynamia', 'anemia', 'atony', 'bloodlessness', 'cachexia', 'cachexy', 'cowardice', 'debilitation', 'debility', 'dullness', 'etiolation', 'faintness'],
    'blahs': ['acedia', 'aloofness', 'angst', 'anguish', 'anxiety', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blue devils', 'blues'],
    'blame': ['account for', 'accountability', 'accounting for', 'accredit with', 'accrete to', 'accusal', 'accusation', 'accuse', 'accusing', 'acknowledge', 'allegation', 'allegement'],
    'blamed': ['absolute', 'accused', 'arraigned', 'blankety-blank', 'blasted', 'blessed', 'bloody', 'charged', 'cited', 'complete', 'confounded', 'consummate'],
    'blameless': ['christian', 'angelic', 'childlike', 'clean', 'clear', 'creditable', 'decent', 'dovelike', 'erect', 'estimable', 'ethical', 'exemplary'],
    'blameworthy': ['abominable', 'accusable', 'amiss', 'arraignable', 'arrant', 'at fault', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beneath contempt'],
    'blanch': ['ache', 'achromatize', 'agonize', 'ail', 'anguish', 'bake', 'barbecue', 'baste', 'besnow', 'bleach', 'bleach out', 'blench'],
    'blanched': ['aghast', 'appalled', 'ashen', 'ashy', 'astounded', 'awed', 'awestricken', 'awestruck', 'bleached', 'bleached white', 'colorless', 'cowed'],
    'bland': ['abstract', 'adulatory', 'balmy', 'banal', 'bare', 'barren', 'blah', 'blandishing', 'blank', 'blarneying', 'bleached', 'boring'],
    'blandish': ['adulate', 'advocate', 'allure', 'apply pressure', 'bait', 'bait the hook', 'banter', 'be hypocritical', 'beguile', 'beset', 'besiege', 'beslobber'],
    'blandishment': ['adulation', 'agacerie', 'allure', 'allurement', 'appeal', 'artful endearments', 'attraction', 'attractiveness', 'beguilement', 'beguiling', 'bewitchery', 'bewitchment'],
    'blank': ['olympian', 'absence', 'absolute', 'aloof', 'arid', 'awayness', 'backward', 'bald', 'bare', 'barren', 'bashful', 'bewildered'],
    'blank check': ['cd', 'iou', 'mo', 'acceptance', 'acceptance bill', 'ample scope', 'bank acceptance', 'bank check', 'bill', 'bill of draft', 'bill of exchange', 'carte blanche'],
    'blank wall': ['bar', 'barricade', 'barrier', 'blind alley', 'blind gut', 'block', 'blockade', 'blockage', 'bottleneck', 'cecum', 'choking', 'choking off'],
    'blanket': ['across-the-board', 'afghan', 'all-comprehensive', 'all-inclusive', 'apply to', 'becloud', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedsheet', 'bedspread'],
    'blankety blank': ['absolute', 'blamed', 'blasted', 'blessed', 'blooming', 'confounded', 'cursed', 'cussed', 'dadburned', 'danged', 'darned', 'dashed'],
    'blankminded': ['awkward', 'blank', 'callow', 'calm', 'dumb', 'empty', 'empty-headed', 'fatuous', 'gauche', 'green', 'groping', 'ignorant'],
    'blare': ['bark', 'bawl', 'bay', 'beep', 'belch', 'bell', 'bellow', 'blare forth', 'blast', 'blat', 'blate', 'blaze'],
    'blaring': ['atmospherics', 'blasting', 'blatant', 'blatting', 'blind spot', 'blustering', 'boisterous', 'brassy', 'brawling', 'brazen', 'clamant', 'clamorous'],
    'blarney': ['adulation', 'banter', 'blandish', 'blandishment', 'bunkum', 'cajole', 'cajolement', 'cajolery', 'compliment', 'con', 'eyewash', 'fair words'],
    'blase': ['laodicean', 'olympian', 'aloof', 'apathetic', 'ataractic', 'benumbed', 'blah', 'bored', 'carefree', 'careless', 'casual', 'comatose'],
    'blaspheme': ['abuse', 'accurse', 'anathematize', 'belittle', 'blast', 'calumniate', 'confound', 'curse', 'damn', 'darn', 'decry', 'defame'],
    'blasphemous': ['rabelaisian', 'abusive', 'apostate', 'atheistic', 'backsliding', 'calumniatory', 'calumnious', 'comminatory', 'contumelious', 'cursing', 'damnatory', 'denunciatory'],
    'blasphemy': ['abuse', 'affront', 'anathema', 'ban', 'befouling', 'billingsgate', 'blasphemousness', 'commination', 'curse', 'cursing', 'cussing', 'damnation'],
    'blast': ['bedlam let loose', 'accurse', 'aim at', 'anathematize', 'at full blast', 'attack', 'awake the dead', 'backfire', 'baffle', 'balk', 'bang', 'bark'],
    'blast off': ['alpha', 'altitude peak', 'automatic control', 'begin', 'beginning', 'blast away', 'burn', 'burnout', 'ceiling', 'commence', 'commencement', 'creation'],
    'blasted': ['ausgespielt', 'baffled', 'balked', 'bankrupt', 'betrayed', 'bilked', 'blamed', 'blankety-blank', 'blessed', 'blighted', 'blown', 'broken'],
    'blasting': ['atmospherics', 'banging', 'blaring', 'blind spot', 'bursting', 'cracking', 'crashing', 'crawling', 'creeping', 'drift', 'exploding', 'explosive'],
    'blasty': ['aeolian', 'airish', 'airy', 'blowy', 'blustering', 'blusterous', 'blustery', 'boreal', 'breezy', 'brisk', 'drafty', 'favonian'],
    'blat': ['bark', 'bawl', 'bay', 'beep', 'belch', 'bell', 'bellow', 'blare', 'blast', 'blate', 'bleat', 'blow'],
    'blatancy': ['arrantness', 'boldness', 'brazenness', 'clamorousness', 'colorfulness', 'conspicuousness', 'crudeness', 'dash', 'dazzle', 'dazzlingness', 'extravagance', 'extravaganza'],
    'blatant': ['arrant', 'barefaced', 'bawling', 'bellowing', 'blaring', 'blatting', 'blustering', 'boanergean', 'boisterous', 'bold', 'brassy', 'brawling'],
    'blatantly': ['abominably', 'agonizingly', 'arrantly', 'awfully', 'baldly', 'balefully', 'bitterly', 'boldly', 'brashly', 'brazenfacedly', 'brazenly', 'colorfully'],
    'blather': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bavardage', 'be stupid', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blatherskite'],
    'blaze': ['vandyke', 'arrow', 'backfire', 'bake', 'balefire', 'be bright', 'be in heat', 'beacon', 'beacon fire', 'beam', 'bedazzle', 'birthmark'],
    'blazer': ['eton jacket', 'mao jacket', 'blouse', 'body coat', 'bolero', 'bomber jacket', 'capuchin', 'car coat', 'chaqueta', 'chesterfield', 'claw hammer', 'claw-hammer coat'],
    'blazing': ['ablaze', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'blistering', 'branding', 'burning', 'calcination', 'candent'],
    'blazon': ['achievement', 'adorn', 'advertise', 'air', 'alerion', 'animal charge', 'announce', 'annulet', 'annunciate', 'argent', 'armorial bearings', 'armory'],
    'bleach': ['achromatization', 'achromatize', 'besnow', 'blanch', 'blanching', 'bleach out', 'bleacher', 'bleaching', 'bleaching agent', 'bleaching powder', 'blench', 'bowdlerize'],
    'bleached': ['bare', 'barren', 'blanched', 'bland', 'blank', 'bleached white', 'bright', 'characterless', 'clean', 'cleanly', 'clear', 'dainty'],
    'bleachers': ['texas tower', 'beacon', 'belvedere', 'bridge', 'conning tower', 'gallery', 'gazebo', 'grandstand', 'lighthouse', 'lookout', 'loophole', 'observation post'],
    'bleaching': ['achromatization', 'albification', 'blanching', 'bleach', 'decoloration', 'decolorization', 'decolorizing', 'discoloration', 'etiolation', 'fading', 'frosting', 'grizzling'],
    'bleak': ['siberian', 'affecting', 'afflictive', 'affording no hope', 'algid', 'apathetic', 'arctic', 'austere', 'bare', 'barren', 'below zero', 'biting'],
    'bleary': ['all in', 'blear', 'bleared', 'blurred', 'blurry', 'confused', 'dark', 'depleted', 'dim', 'drained', 'exhausted', 'faint'],
    'bleat': ['bark', 'bawl', 'bay', 'beef', 'bell', 'bellow', 'bellyache', 'bitch', 'blare', 'blat', 'blate', 'blow off'],
    'bleb': ['abscess', 'air bubble', 'aposteme', 'balloon', 'bed sore', 'bilge', 'birthmark', 'blackhead', 'bladder', 'blain', 'blemish', 'blister'],
    'blebby': ['beaten', 'blistered', 'blistering', 'blistery', 'bubbling', 'bubbly', 'burbling', 'burbly', 'carbonated', 'chiffon', 'ebullient', 'effervescent'],
    'bleed': ['abridge', 'abuse', 'ache', 'agonize', 'anguish', 'be sorry for', 'bereave', 'bleed for', 'bleed white', 'bloody', 'broach', 'brood over'],
    'bleed white': ['ablate', 'absorb', 'abuse', 'assimilate', 'bleed', 'burn up', 'clip', 'consume', 'denude', 'deplete', 'deplume', 'despoil'],
    'bleeding heart': ['aching heart', 'agony', 'agony of mind', 'anguish', 'bale', 'bathos', 'bitterness', 'bowels of compassion', 'broken heart', 'brokenheartedness', 'cloyingness', 'compassionateness'],
    'blemish': ['abrade', 'abrasion', 'baboon', 'bag', 'bark', 'besmirch', 'birthmark', 'black sheep', 'blaze', 'blaze a trail', 'blister', 'bloody'],
    'blemished': ['adulterated', 'bandy', 'bandy-legged', 'beautiless', 'bloated', 'blotted', 'bowlegged', 'cacophonic', 'cacophonous', 'checked', 'cicatrized', 'club-footed'],
    'blench': ['ache', 'agonize', 'ail', 'anguish', 'avoid', 'blanch', 'bleach', 'blink', 'boggle', 'cringe', 'decolor', 'decolorize'],
    'blend': ['anschluss', 'accord', 'add', 'addition', 'admix', 'admixture', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'alloy'],
    'blended': ['accordant', 'according', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'assimilated', 'assonant', 'assonantal', 'attuned', 'blending', 'chiming'],
    'bless': ['ok', 'accept', 'acknowledge', 'admire', 'adore', 'adulate', 'apotheosize', 'approve', 'approve of', 'arm', 'armor', 'beatify'],
    'blessed': ['elysian', 'olympian', 'absolute', 'auspicious', 'beaming', 'beatific', 'beatified', 'beatitude', 'blamed', 'blankety-blank', 'blasted', 'blessed with luck'],
    'blessed event': ['accouchement', 'birth', 'birth throes', 'birthing', 'childbearing', 'childbed', 'childbirth', 'confinement', 'delivery', 'genesis', 'giving birth', 'hatching'],
    'blessed with': ['enfeoffed', 'having', 'having and holding', 'holding', 'in possession of', 'landed', 'landholding', 'landowning', 'master of', 'occupying', 'owning', 'possessed of'],
    'blessing': ['godspeed', 'ok', 'acceptance', 'accord', 'acquiescence', 'act of grace', 'act of kindness', 'adherence', 'admiration', 'advantage', 'affirmation', 'affirmative'],
    'blight': ['abnormality', 'abomination', 'abuse', 'acute disease', 'adverse circumstances', 'adversity', 'affection', 'afflict', 'affliction', 'aggravation', 'aggrieve', 'ailment'],
    'blighted': ['absolute', 'ausgespielt', 'baffled', 'balked', 'bankrupt', 'betrayed', 'bilked', 'blasted', 'blessed', 'blown', 'botched', 'broken'],
    'blighter': ['bowery bum', 'beachcomber', 'beggar', 'beggarly fellow', 'budmash', 'bum', 'bummer', 'caitiff', 'derelict', 'devil', 'drifter', 'drunkard'],
    'blimp': ['bourbon', 'colonel blimp', 'graf zeppelin', 'aerostat', 'airship', 'ballonet', 'balloon', 'bloated aristocrat', 'captive balloon', 'diehard', 'dirigible', 'dirigible balloon'],
    'blind': ['ableptical', 'abstruse', 'alibi', 'amaurotic', 'ambuscade', 'ambush', 'ambushment', 'amorphous', 'apology', 'art', 'artful dodge', 'artifice'],
    'blind alley': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'bar'],
    'blind faith': ['credulity', 'credulousness', 'disposition to believe', 'dotage', 'ease of belief', 'fondness', 'gross credulity', 'infatuation', 'overcredulity', 'overcredulousness', 'overopenness to conviction', 'overtrustfulness'],
    'blind impulse': ['archetypal pattern', 'archetype', 'automatic response', 'automatic writing', 'automatism', 'brain wave', 'brainstorm', 'collective unconscious', 'compulsiveness', 'conditioning', 'drive', 'echolalia'],
    'blind spot': ['ablepsia', 'amaurosis', 'atmospheric attenuation', 'atmospherics', 'authoritarianism', 'benightedness', 'bigotry', 'blaring', 'blasting', 'blind side', 'blind spots', 'blinders'],
    'blind to': ['a stranger to', 'asleep', 'caught napping', 'dead to', 'deaf to', 'impercipient', 'in ignorance of', 'incognizant', 'insensible', 'insensible to', 'lost to', 'mindless'],
    'blinded': ['bedazzled', 'blind', 'blindfold', 'blindfolded', 'darkened', 'dazed', 'dazzled', 'dim-sighted', 'excecate', 'hoodwinked', 'imperceptive', 'impercipient'],
    'blinders': ['authoritarianism', 'back band', 'backstrap', 'bearing rein', 'bellyband', 'bigotry', 'bit', 'blind side', 'blind spot', 'blindfold', 'blinds', 'blinkers'],
    'blindfold': ['bandage', 'bedazzle', 'benight', 'blind', 'blind the eyes', 'blinders', 'blinds', 'blinkers', 'darken', 'daze', 'dazzle', 'deprive of sight'],
    'blindfolded': ['bedazzled', 'blind', 'blindfold', 'darkened', 'dazed', 'dazzled', 'dim-sighted', 'excecate', 'hoodwinked', 'imperceptive', 'impercipient', 'insensible'],
    'blinding': ['ablepsia', 'absolute', 'amaurosis', 'bedazzling', 'benightedness', 'bleeding', 'blessed', 'blind side', 'blind spot', 'blindfolding', 'blindness', 'blinking'],
    'blindness': ['albinism', 'astigmatism', 'astigmia', 'bad eyesight', 'blurred vision', 'deafness', 'defect of vision', 'dim-sightedness', 'dogmatism', 'double sight', 'double vision', 'faulty eyesight'],
    'blink': ['albedo', 'avoid', 'bat', 'bat the eyes', 'blench', 'blink at', 'blinking', 'broken', 'carefully ignore', 'cast', 'cold-shoulder', 'coruscate'],
    'blink at': ['abide with', 'accept', 'allow for', 'be big', 'be blind', 'be blind to', 'be caught out', 'be content with', 'be easy with', 'be inattentive', 'be unwary', 'bear'],
    'blinker': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'beacon', 'beacon fire', 'bell', 'bell buoy', 'blue peter', 'buoy', 'caution light'],
    'blinking': ['absolute', 'aflicker', 'asquint', 'astigmatic', 'bickering', 'blasted', 'bleeding', 'blink', 'blink-eyed', 'blinkard', 'blinky', 'blooming'],
    'blintz': ['danish pastry', 'french pastry', 'baklava', 'buckwheat cake', 'cheese blintz', 'chocolate eclair', 'cream puff', 'crepe', 'dowdy', 'eclair', 'flapcake', 'flapjack'],
    'blips': ['crt spot', 'dm display', 'doppler signal', 'if signal', 'im display', 'rf echoes', 'beam', 'beat signal', 'bounces', 'display', 'double-dot display', 'echo'],
    'bliss': ['canaan', 'new jerusalem', 'zion', 'affability', 'agreeability', 'agreeableness', 'amenity', 'amiability', 'amicability', 'beatification', 'beatitude', 'bewitchment'],
    'blissful': ['elysian', 'affable', 'agreeable', 'amiable', 'amicable', 'beaming', 'beatific', 'beatified', 'blessed', 'capering', 'cheerful', 'chirping'],
    'blister': ['abscess', 'air bubble', 'aposteme', 'assail', 'attack', 'balloon', 'bed sore', 'bilge', 'birthmark', 'blackhead', 'bladder', 'blain'],
    'blistered': ['adust', 'ashen', 'ashy', 'beaten', 'blebby', 'blistering', 'blistery', 'bubbling', 'bubbly', 'burbling', 'burbly', 'burned'],
    'blistering': ['afflict', 'annoy', 'ardent', 'baking', 'beaten', 'blasted', 'blazing', 'blebby', 'bleeding', 'blessed', 'blistered', 'blistery'],
    'blistery': ['beaten', 'blebby', 'blistered', 'blistering', 'bubbling', 'bubbly', 'burbling', 'burbly', 'carbonated', 'chiffon', 'ebullient', 'effervescent'],
    'blithe': ['beaming', 'blase', 'blissful', 'blithesome', 'boon', 'bright', 'bright and sunny', 'carefree', 'careless', 'casual', 'cheerful', 'cheery'],
    'blithering': ['absolute', 'arrested', 'babbling', 'backward', 'blasted', 'blessed', 'burbling', 'crackbrained', 'cracked', 'crazy', 'cretinistic', 'cretinous'],
    'blithesome': ['beaming', 'blithe', 'boon', 'bright', 'bright and sunny', 'cheerful', 'cheery', 'elated', 'eupeptic', 'euphoric', 'exalted', 'exhilarated'],
    'blitz': ['aggravated assault', 'aggression', 'aim at', 'air raid', 'ambush', 'amphibious attack', 'area bombing', 'armed assault', 'assail', 'assailing', 'assailment', 'assault'],
    'blitzkrieg': ['aggravated assault', 'aggression', 'air raid', 'amphibious attack', 'armed assault', 'assailing', 'assailment', 'assault', 'attack', 'banzai attack', 'blitz', 'bombardment'],
    'blizzard': ['avalanche', 'black squall', 'blow', 'crystal', 'driven snow', 'equinoctial', 'flake', 'flurry', 'gale', 'granular snow', 'half a gale', 'heavy blow'],
    'bloat': ['accrue', 'accumulate', 'add to', 'advance', 'aggrandize', 'amplify', 'appreciate', 'augment', 'balloon', 'bloatedness', 'bloating', 'blotter'],
    'bloated': ['accelerated', 'adipose', 'aggrandized', 'amplified', 'arrogant', 'augmented', 'bagging', 'baggy', 'ballooning', 'bandy', 'bandy-legged', 'beefed-up'],
    'blob': ['ball', 'balloon', 'bilge', 'bit', 'bladder', 'blain', 'bleb', 'blister', 'boll', 'bolus', 'boss', 'bow'],
    'blobby': ['aleatoric', 'aleatory', 'amorphic', 'amorphous', 'anarchic', 'baggy', 'blurred', 'blurry', 'broad', 'chance', 'chancy', 'chaotic'],
    'bloc': ['bund', 'rochdale cooperative', 'alliance', 'assemblage', 'association', 'axis', 'band', 'body', 'coalition', 'college', 'combination', 'combine'],
    'block': ['boeotian', 'dutch auction', 'afterthought', 'agate', 'agnosia', 'apply to', 'aquatint', 'arm', 'arrest', 'auction', 'auction block', 'auction sale'],
    'block out': ['adumbrate', 'block in', 'brief', 'carve', 'cast', 'chalk out', 'characterize', 'chisel', 'close', 'create', 'cut', 'delineate'],
    'blockade': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'afterthought', 'akinetic epilepsy', 'apoplexy', 'arm', 'armor'],
    'blockbuster': ['astonishment', 'blow', 'bomb', 'bombshell', 'catch', 'earthshaker', 'eye-opener', 'joker', 'kicker', 'peripeteia', 'revelation', 'shocker'],
    'blocked': ['lethean', 'absentminded', 'amnestic', 'arrested', 'back', 'backward', 'behindhand', 'belated', 'bound', 'choked', 'choked up', 'clogged'],
    'blockhead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blubberhead', 'blunderer', 'blunderhead', 'bonehead', 'boor', 'botcher', 'bufflehead', 'bumbler'],
    'blockheaded': ['beetleheaded', 'blockish', 'blunderheaded', 'boneheaded', 'cabbageheaded', 'chowderheaded', 'chuckleheaded', 'clodpated', 'dumbheaded', 'dunderheaded', 'fatheaded', 'jolterheaded'],
    'blockhouse': ['acropolis', 'bastion', 'beachhead', 'box', 'bridgehead', 'bungalow', 'bunker', 'cabin', 'castle', 'chalet', 'citadel', 'cot'],
    'blockish': ['boeotian', 'asinine', 'beef-brained', 'beef-witted', 'blockheaded', 'bovine', 'chuckleheaded', 'chumpish', 'cloddish', 'cowish', 'crass', 'dense'],
    'blocky': ['chubby', 'chunky', 'dumpy', 'fat', 'podgy', 'pudgy', 'pug', 'pugged', 'retrousse', 'snub-nosed', 'squat', 'squattish'],
    'bloke': ['adamite', 'bastard', 'being', 'bird', 'body', 'boy', 'buck', 'bugger', 'cat', 'chap', 'character', 'creature'],
    'blond': ['ash blond', 'ash-blond', 'bleached blond', 'bleached-blond', 'blond-haired', 'blond-headed', 'brunet', 'carrottop', 'champagne', 'flaxen', 'flaxen-haired', 'golden'],
    'blood': ['beau brummel', 'christmas disease', 'letterer-siwe syndrome', 'rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'acute leukemia', 'affiliation', 'agnate', 'agnation'],
    'blood and thunder': ['demonstrativeness', 'emotional appeal', 'emotionalism', 'emotionality', 'emotionalization', 'emotionalizing', 'emotiveness', 'emotivity', 'histrionics', 'human interest', 'love interest', 'making scenes'],
    'blood bank': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'x ray', 'antibody', 'antigen', 'arterial blood', 'arterial transfusion', 'blood', 'blood cell'],
    'blood brother': ['aunt', 'auntie', 'brethren', 'brother', 'bub', 'bubba', 'bud', 'buddy', 'country cousin', 'cousin', 'cousin once removed', 'cousin twice removed'],
    'blood money': ['account', 'allowance', 'amends', 'assessment', 'atonement', 'bill', 'blackmail', 'compensation', 'consideration', 'damages', 'emolument', 'fee'],
    'blood relative': ['agnate', 'ancestry', 'blood', 'blood relation', 'clansman', 'cognate', 'collateral', 'collateral relative', 'connections', 'consanguinean', 'distaff side', 'distant relation'],
    'bloodbath': ['bloodshed', 'blue ruin', 'breakup', 'butchery', 'carnage', 'consumption', 'damnation', 'decimation', 'depredation', 'desolation', 'despoilment', 'despoliation'],
    'bloodless': ['achromatic', 'achromic', 'anemic', 'anesthetic', 'arid', 'ashen', 'ashy', 'asthenic', 'at peace', 'barren', 'blah', 'blank'],
    'bloodletting': ['aspiration', 'bane', 'bleeding', 'blood', 'bloodshed', 'braining', 'broaching', 'cupping', 'dealing death', 'destruction', 'destruction of life', 'dispatch'],
    'bloodline': ['affiliation', 'apparentation', 'birth', 'blood', 'branch', 'breed', 'common ancestry', 'consanguinity', 'derivation', 'descent', 'direct line', 'distaff side'],
    'bloodlust': ['acuteness', 'animality', 'atrociousness', 'atrocity', 'barbarity', 'barbarousness', 'beastliness', 'bestiality', 'bloodiness', 'bloodthirst', 'bloodthirstiness', 'bloody-mindedness'],
    'bloodmobile': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'antibody', 'antigen', 'arterial blood', 'arterial transfusion', 'blood', 'blood bank', 'blood cell'],
    'bloodshed': ['all-out war', 'appeal to arms', 'armed combat', 'armed conflict', 'attack', 'bane', 'battle', 'belligerence', 'belligerency', 'blood', 'bloodbath', 'bloodletting'],
    'bloodstain': ['bloody', 'blot', 'blotch', 'blur', 'brand', 'dab', 'daub', 'ensanguine', 'eyesore', 'fleck', 'flick', 'flyspeck'],
    'bloodstream': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'antibody', 'antigen', 'arterial blood', 'blood', 'blood bank', 'blood cell', 'blood count'],
    'bloodsucker': ['barnacle', 'bedbug', 'blackmailer', 'extortioner', 'extortionist', 'freeloader', 'hanger-on', 'harpy', 'leech', 'lounge lizard', 'moocher', 'mosquito'],
    'bloodthirsty': ['draconian', 'tartarean', 'aggressive', 'animal', 'antagonistic', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'battling', 'beastly', 'bellicose'],
    'bloody': ['draconian', 'tartarean', 'abrade', 'accursed', 'aggressive', 'agonize', 'animal', 'antagonistic', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous'],
    'bloody minded': ['draconian', 'tartarean', 'aggressive', 'animal', 'antagonistic', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'battling', 'beastly', 'bellicose'],
    'bloom': ['hygeia', 'advance', 'anthesis', 'attain majority', 'attractiveness', 'bake', 'batten', 'be in bloom', 'be in flower', 'be in heat', 'beam', 'bear fruit'],
    'blooming': ['absolute', 'blamed', 'blankety-blank', 'blasted', 'bleeding', 'blinking', 'bloody', 'complete', 'consummate', 'cursed', 'damnable', 'execrable'],
    'blooper': ['bloomer', 'blunder', 'bobble', 'bonehead play', 'boner', 'boo-boo', 'boob stunt', 'boot', 'break', 'bull', 'bungle', 'dumb trick'],
    'blooping': ['birdies', 'black spot', 'bloom', 'blurping', 'definition', 'distortion', 'feedback', 'flare', 'flutter', 'fluttering', 'fringe area', 'ghost'],
    'blossom': ['advance', 'anthesis', 'batten', 'be in bloom', 'be in flower', 'bear fruit', 'bloom', 'blooming', 'blossoming', 'blow', 'blowing', 'blush'],
    'blot': ['absorb', 'adsorb', 'air-dry', 'anhydrate', 'annihilate', 'aspersion', 'assimilate', 'attaint', 'baboon', 'badge of infamy', 'bag', 'bake'],
    'blot out': ['abate', 'abbreviate', 'abolish', 'abridge', 'annul', 'becloud', 'bedarken', 'bedim', 'begloom', 'black', 'black out', 'blacken'],
    'blotch': ['band', 'bar', 'bedarken', 'besmirch', 'bespangle', 'bespeckle', 'bespot', 'birthmark', 'black', 'blacken', 'blackwash', 'blaze'],
    'blotchy': ['besmirched', 'bespangled', 'bespeckled', 'blotched', 'dingy', 'dirty', 'dotted', 'dotty', 'flea-bitten', 'flecked', 'fleckered', 'frecked'],
    'blotter': ['domesday book', 'absorbency', 'absorbent', 'absorption', 'account book', 'address book', 'adsorbent', 'adsorption', 'adversaria', 'album', 'annual', 'appointment calendar'],
    'blotto': ['blind', 'blind drunk', 'boozy', 'canned', 'disguised', 'drunk', 'helpless', 'inebriated', 'muddled', 'out', 'out cold', 'overcome'],
    'blow': ['barnumize', 'lucullan feast', 'accident', 'accomplished fact', 'accomplishment', 'ache', 'achievement', 'aching', 'act', 'acta', 'action', 'adventure'],
    'blow down': ['beat down', 'blow over', 'bowl down', 'bowl over', 'break down', 'bring down', 'bulldog', 'bulldoze', 'burn down', 'cast down', 'chop down', 'cut down'],
    'blow in': ['accomplish', 'achieve', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be received', 'bob up', 'check in', 'clock in'],
    'blow off': ['attenuate', 'beef', 'bellyache', 'bitch', 'bleat', 'blow', 'blowhard', 'cast forth', 'clear away', 'crab', 'dilute', 'dispel'],
    'blow out': ['backfire', 'belch', 'blast', 'blow', 'blow open', 'blow up', 'break out', 'burst', 'burst forth', 'burst out', 'bust', 'cast forth'],
    'blow over': ['be all over', 'be no more', 'become extinct', 'become void', 'blast', 'blow', 'blow a hurricane', 'blow down', 'blow great guns', 'blow up', 'bluster', 'bowl down'],
    'blow the whistle': ['arrest', 'bear witness against', 'betray', 'blab', 'block', 'brake', 'bring to', 'bring up short', 'call a halt', 'check', 'checkmate', 'cut short'],
    'blow up': ['accelerate', 'add to', 'adulate', 'aggrandize', 'aggravate', 'amplify', 'annoy', 'apotheosize', 'arouse', 'augment', 'awake', 'awaken'],
    'blower': ['captain bobadil', 'gascon', 'texan', 'aerator', 'air conditioner', 'air cooler', 'air filter', 'air passage', 'bellows', 'big mouth', 'blowgun', 'blowhard'],
    'blowgun': ['automatic', 'bellows', 'blower', 'blowpipe', 'blowtube', 'firearm', 'flamethrower', 'gat', 'gun', 'handgun', 'heater', 'musket'],
    'blowhard': ['captain bobadil', 'gascon', 'texan', 'big mouth', 'blower', 'blusterer', 'boaster', 'brag', 'braggadocio', 'braggart', 'fanfaron', 'gasbag'],
    'blowhole': ['air duct', 'air hole', 'air passage', 'air shaft', 'air tube', 'airway', 'armhole', 'avenue', 'breathing hole', 'bullet-hole', 'bunghole', 'channel'],
    'blown': ['blasted', 'bleak', 'blighted', 'despoiled', 'exposed', 'flyblown', 'frowsty', 'frowsy', 'frowy', 'frowzy', 'fusty', 'gamy'],
    'blowout': ['kaffeeklatsch', 'lucullan feast', 'mardi gras', 'saturnalia', 'backfire', 'ball', 'bang', 'banquet', 'bash', 'bean-feast', 'beano', 'blast'],
    'blowpipe': ['acetylene welder', 'automatic', 'bellows', 'blast lamp', 'blower', 'blowgun', 'blowtorch', 'blowtube', 'burner', 'firearm', 'flamethrower', 'gat'],
    'blowtorch': ['jet liner', 'acetylene welder', 'blast lamp', 'blowpipe', 'burner', 'business jet', 'jet', 'jet plane', 'multi-jet', 'pulse-jet', 'ramjet', 'single-jet'],
    'blowup': ['photostat', 'xerox', 'xerox copy', 'accelerando', 'acceleration', 'access', 'aggravation', 'backfire', 'bang', 'beefing-up', 'blast', 'blaze of temper'],
    'blowy': ['aeolian', 'airish', 'airy', 'blasty', 'blustering', 'blusterous', 'blustery', 'boreal', 'breezy', 'brisk', 'drafty', 'favonian'],
    'blowzy': ['adipose', 'beat-up', 'bedraggled', 'beefy', 'big-bellied', 'bloated', 'blooming', 'blowzed', 'bosomy', 'brawny', 'burly', 'burnt'],
    'blubber': ['bark', 'bawl', 'bellow', 'blare', 'blat', 'boil', 'boil over', 'boohoo', 'boom', 'bray', 'break down', 'breathe'],
    'blubbery': ['adipose', 'buttery', 'butyraceous', 'chrismal', 'chrismatory', 'fat', 'fatty', 'greasy', 'lardaceous', 'lardy', 'mucoid', 'oily'],
    'bludgeon': ['bat', 'baton', 'be imminent', 'billy', 'billy club', 'blackjack', 'bluster', 'bluster out of', 'bounce', 'browbeat', 'bulldoze', 'bully'],
    'blue': ['alice blue', 'amytal', 'amytal pill', 'brunswick blue', 'caelus', 'capri blue', 'chinese blue', 'copenhagen blue', 'demerol', 'dolophine', 'dresden blue', 'fescennine'],
    'blue blood': ['brahman', 'ancestry', 'archduke', 'aristocracy', 'aristocrat', 'aristocraticalness', 'armiger', 'baron', 'baronet', 'birth', 'blood', 'carnage'],
    'blue book': ['almanach de gotha', 'congressional record', 'hansard', 'red book', 'royal kalendar', 'social register', 'account', 'acquaintance', 'announcement', 'audition', 'briefing', 'bulletin'],
    'blue chip': ['assessable stock', 'authorized capital stock', 'blue chip stock', 'borrowed stock', 'capital stock', 'common stock', 'convertible preferred stock', 'corporate stock', 'cumulative preferred stock', 'cyclical stock', 'defensive stock', 'deferred stock'],
    'blue collar worker': ['breadwinner', 'casual', 'casual laborer', 'common laborer', 'day laborer', 'employee', 'factory worker', 'flunky', 'free lance', 'free-lancer', 'full-time worker', 'hand'],
    'blue devil': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'blue devils': ['blahs', 'blue johnnies', 'blues', 'dismals', 'dods', 'doldrums', 'dolefuls', 'dorts', 'dumps', 'frumps', 'grumps', 'megrims'],
    'blue language': ['bad language', 'billingsgate', 'colorful language', 'cursing', 'cussing', 'dirty language', 'dirty talk', 'dysphemism', 'evil speaking', 'filth', 'filthy language', 'foul language'],
    'blue movie': ['rabelaisianism', 'x-rated movie', 'bawdiness', 'bawdry', 'dirt', 'dirtiness', 'dirty movie', 'erotic art', 'erotic literature', 'erotographomania', 'fescenninity', 'filth'],
    'blue pencil': ['abbreviate', 'abridge', 'amend', 'blot out', 'bowdlerize', 'cancel', 'censor', 'correct', 'cross out', 'cut', 'delete', 'edit'],
    'blue ribbon': ['acme', 'authority', 'authorization', 'be-all and end-all', 'championship', 'command', 'control', 'cordon', 'cordon bleu', 'decoration', 'decoration of honor', 'directorship'],
    'blue streak': ['antelope', 'arrow', 'blue darter', 'cannonball', 'courser', 'dart', 'eagle', 'electricity', 'express train', 'flash', 'gazelle', 'greased lightning'],
    'blue velvet': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'bluejacket': ['ab', 'ancient mariner', 'argonaut', 'dylan', 'flying dutchman', 'naval reservist', 'neptune', 'od', 'poseidon', 'royal marine', 'seabee', 'varuna'],
    'blueprint': ['photostat', 'xerox', 'xerox copy', 'agenda', 'alphabet', 'approach', 'arrange', 'arrangement', 'art', 'attack', 'batting order', 'bill'],
    'blues': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'alba', 'anthem', 'art song', 'aubade', 'ballad', 'ballade', 'balladry'],
    'bluestocking': ['bibliophagic', 'book-fed', 'book-learned', 'book-loving', 'book-minded', 'book-read', 'book-wise', 'bookish', 'booky', 'donnish', 'formalist', 'inkhorn'],
    'bluff': ['herod', 'abrupt', 'act', 'act a part', 'acting', 'affable', 'affect', 'affectation', 'aggressive', 'appearance', 'approachable', 'artful dodge'],
    'blunder': ['absurdity', 'act of folly', 'bad job', 'be all thumbs', 'bevue', 'blooper', 'blow', 'blunder away', 'blunder into', 'blunder on', 'blunder upon', 'bobble'],
    'blunder upon': ['alight upon', 'be all thumbs', 'blunder', 'blunder away', 'blunder into', 'blunder on', 'boggle', 'botch', 'bumble', 'bump into', 'bungle', 'butcher'],
    'blunderhead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderer', 'bonehead', 'boor', 'botcher', 'bufflehead', 'bumbler'],
    'blunderheaded': ['all thumbs', 'awkward', 'beetleheaded', 'blockheaded', 'blundering', 'boneheaded', 'boorish', 'bumbling', 'bungling', 'butterfingered', 'cabbageheaded', 'careless'],
    'blunt': ['ko', 'abate', 'abrupt', 'affectless', 'aggressive', 'allay', 'alleviate', 'anesthetize', 'anesthetized', 'arctic', 'artless', 'assuage'],
    'blunted': ['abrupt', 'bluff', 'blunt', 'blunt-edged', 'blunt-ended', 'blunt-pointed', 'bluntish', 'dull', 'dull-edged', 'dull-pointed', 'dulled', 'dullish'],
    'blur': ['aspersion', 'attaint', 'badge of infamy', 'bar sinister', 'baton', 'becloud', 'bedaub', 'bedim', 'befog', 'bend sinister', 'besmear', 'besmirch'],
    'blurb': ['pr', 'acknowledgment', 'appreciation', 'ballyhoo', 'boost', 'bright light', 'buildup', 'celebrity', 'commendation', 'common knowledge', 'cry', 'currency'],
    'blurred': ['aleatoric', 'aleatory', 'amorphic', 'amorphous', 'anarchic', 'baggy', 'blear', 'bleared', 'bleary', 'blobby', 'blurry', 'breathy'],
    'blurt': ['allude to', 'babble', 'be indiscreet', 'be unguarded', 'betray', 'betray a confidence', 'blab', 'blabber', 'blurt out', 'burst out', 'call attention to', 'comment'],
    'blush': ['be guilty', 'blanch', 'bloom', 'blossom', 'blushing', 'change color', 'color', 'color up', 'coloring', 'crimson', 'crimsoning', 'darken'],
    'bluster': ['agitation', 'bawl', 'be livid', 'be pissed', 'bellow', 'blast', 'blow', 'blow a hurricane', 'blow great guns', 'blow over', 'blow up', 'bludgeon'],
    'blustering': ['abusive', 'aeolian', 'airish', 'airy', 'anarchic', 'angry', 'blaring', 'blasty', 'blatant', 'blatting', 'blowy', 'bludgeoning'],
    'bm': ['bloody flux', 'bowel movement', 'buffalo chips', 'ca-ca', 'catharsis', 'coprolite', 'coprolith', 'cow chips', 'cow flops', 'cow pats', 'crap', 'defecation'],
    'bo': ['bad breath', 'bad smell', 'beaded brow', 'beads of sweat', 'body odor', 'cold sweat', 'diaphoresis', 'exudate', 'exudation', 'fetidity', 'fetidness', 'fetor'],
    'boar': ['barrow', 'billy', 'billy goat', 'bubbly-jock', 'buck', 'bull', 'bullock', 'chanticleer', 'cock', 'cockerel', 'dog', 'drake'],
    'board': ['american stock exchange', 'amex', 'areopagus', 'british cabinet', 'c ration', 'k ration', 'sanhedrin', 'us cabinet', 'wall street', 'aboard', 'accommodate', 'accommodation'],
    'boarder': ['brillat-savarin', 'lucullus', 'board-and-roomer', 'bon vivant', 'cannibal', 'carnivore', 'connoisseur of food', 'consumer', 'diner', 'diner-out', 'eater', 'eater-out'],
    'boardinghouse': ['dorm', 'dormitory', 'doss house', 'fleabag', 'flophouse', 'guest house', 'hospice', 'hostel', 'hostelry', 'hotel', 'inn', 'lodging house'],
    'boards': ['broadway', 'acting area', 'apron', 'apron stage', 'backstage', 'band shell', 'bandstand', 'board', 'bridge', 'burlesque', 'carnival', 'circus'],
    'boardwalk': ['alameda', 'beaten path', 'beaten track', 'berm', 'bicycle path', 'bridle path', 'catwalk', 'esplanade', 'fastwalk', 'foot pavement', 'footpath', 'footway'],
    'boast': ['aggrandize', 'be enfeoffed of', 'be possessed of', 'be seized of', 'blow', 'bluster', 'boastfulness', 'boasting', 'bombast', 'bounce', 'brag', 'braggadocio'],
    'boast of': ['adulate', 'apotheosize', 'belaud', 'bepraise', 'bless', 'blow up', 'brag about', 'celebrate', 'cry up', 'deify', 'emblazon', 'eulogize'],
    'boastful': ['gascon', 'arrogant', 'boasting', 'braggart', 'bragging', 'cock-a-hoop', 'conceited', 'egotistical', 'exultant', 'fanfaron', 'fanfaronading', 'gasconading'],
    'boat': ['almadia', 'argosy', 'ark', 'auto', 'autocar', 'automobile', 'auxiliary', 'barge', 'bark', 'bottom', 'bucket', 'buggy'],
    'boating': ['canoeing', 'circumnavigation', 'coasting', 'cruising', 'gunkholing', 'motorboating', 'navigability', 'navigating', 'navigation', 'passage-making', 'periplus', 'rowing'],
    'boatman': ['bargee', 'bargeman', 'barger', 'boat-handler', 'boater', 'boatsman', 'ferrier', 'ferryman', 'galley slave', 'gondolier', 'lighterman', 'oar'],
    'boatswain': ['big brother', 'od', 'auditor', 'boss', 'captain', 'chief', 'chief engineer', 'chief mate', 'commander', 'comptroller', 'controller', 'deck officer'],
    'boatyard': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'boilery', 'bookbindery', 'brewery', 'brickyard', 'cannery', 'creamery'],
    'bob': ['carling float', 't square', 'abbreviate', 'abridge', 'abscind', 'abstract', 'accost', 'address', 'amputate', 'angle', 'annihilate', 'bait the hook'],
    'bob up': ['accomplish', 'achieve', 'appear unexpectedly', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be received', 'be unexpected', 'blow in'],
    'bobble': ['bad job', 'bevue', 'bitch', 'bitch up', 'bloomer', 'blooper', 'blow', 'blunder', 'bob', 'boggle', 'bollix', 'bonehead into it'],
    'bobby': ['dogberry', 'john law', 'bluebottle', 'bluecoat', 'bull', 'constable', 'cop', 'copper', 'dick', 'flatfoot', 'flattie', 'gendarme'],
    'bode': ['apprehend', 'augur', 'betoken', 'croak', 'forebode', 'foreshadow', 'foreshow', 'foretoken', 'forewarn', 'have a premonition', 'have a presentiment', 'look black'],
    'bodega': ['appetizing store', 'bakery', 'bakeshop', 'butcher shop', 'creamery', 'dairy', 'deli', 'delicatessen', 'food shop', 'food store', 'fruit stand', 'grocery'],
    'bodiless': ['airy', 'asomatous', 'astral', 'decarnate', 'decarnated', 'discarnate', 'disembodied', 'ethereal', 'extramundane', 'ghostly', 'immaterial', 'impalpable'],
    'bodily': ['adamic', 'circean', 'across the board', 'all', 'all put together', 'altogether', 'animal', 'animalistic', 'as a body', 'as a whole', 'at large', 'atavistic'],
    'body': ['adamite', 'bund', 'festschrift', 'rochdale cooperative', 'affiliation', 'age group', 'aggregate', 'alliance', 'amount', 'amplitude', 'an existence', 'ana'],
    'body build': ['anatomy', 'body', 'brand', 'build', 'cast', 'character', 'characteristic', 'characteristics', 'complexion', 'composition', 'constituents', 'constitution'],
    'body count': ['account', 'accounts', 'bill of mortality', 'capitulation', 'casualty list', 'census', 'count', 'death roll', 'head count', 'inventory', 'martyrology', 'mortuary roll'],
    'body language': ['bearing', 'beck', 'beckon', 'carriage', 'charade', 'chironomy', 'dactylology', 'deaf-and-dumb alphabet', 'dumb show', 'gesticulation', 'gesture', 'gesture language'],
    'body odor': ['bo', 'bad breath', 'bad smell', 'beaded brow', 'beads of sweat', 'cold sweat', 'diaphoresis', 'exudate', 'exudation', 'fetidity', 'fetidness', 'fetor'],
    'body politic': ['everyman', 'john doe', 'public', 'ally', 'archduchy', 'archdukedom', 'buffer state', 'captive nation', 'chieftaincy', 'chieftainry', 'citizenry', 'city-state'],
    'bodyguard': ['cavalier', 'chaperon', 'companion', 'conductor', 'convoy', 'duenna', 'escort', 'esquire', 'fellow traveler', 'gentleman-at-arms', 'guard', 'guards'],
    'bog': ['baygall', 'bemire', 'bog down', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'cesspool', 'cloaca', 'cloaca maxima', 'drain', 'dump'],
    'bogey': ['dracula', 'frankenstein', 'mumbo jumbo', 'wolf-man', 'air armada', 'air force', 'bandit', 'bogeyman', 'boggart', 'bogle', 'booger', 'boogerman'],
    'bogeyman': ['dracula', 'frankenstein', 'mumbo jumbo', 'wolf-man', 'bogey', 'boggart', 'bogle', 'booger', 'boogerman', 'boogeyman', 'bug', 'bugaboo'],
    'boggle': ['addle', 'amaze', 'around the bush', 'astonish', 'astound', 'awe', 'awestrike', 'back out', 'bad job', 'baffle', 'balk', 'bamboozle'],
    'boggy': ['boggish', 'damp', 'dampish', 'dank', 'dewy', 'fenny', 'humid', 'marish', 'marshy', 'mirish', 'miry', 'moist'],
    'bogus': ['affected', 'apocryphal', 'artificial', 'assumed', 'bastard', 'brummagem', 'colorable', 'colored', 'counterfeit', 'counterfeited', 'distorted', 'dressed up'],
    'bohemian': ['arab', 'bedouin', 'romany', 'zigeuner', 'affable', 'beat', 'beatnik', 'breakaway', 'casual', 'cordial', 'degage', 'deviant'],
    'boil': ['abscess', 'agitation', 'antisepticize', 'aposteme', 'autoclave', 'bake', 'barbecue', 'baste', 'be in heat', 'be livid', 'be pissed', 'bed sore'],
    'boil down': ['abbreviate', 'abridge', 'abstract', 'bob', 'capsulize', 'clip', 'compress', 'condense', 'contract', 'crop', 'curtail', 'cut'],
    'boiler room': ['klaxon', 'boiler factory', 'brokerage', 'brokerage house', 'brokerage office', 'bucket shop', 'bull-roarer', 'bunco game', 'catcall', 'cherry bomb', 'clack', 'clacker'],
    'boiling': ['agitation', 'ardent', 'baking', 'barbecuing', 'basting', 'blistering', 'bluster', 'bobbery', 'boil', 'boiling over', 'braising', 'brewing'],
    'boiling over': ['ablaze', 'afire', 'ardent', 'boiling', 'breathless', 'burning', 'burning with excitement', 'cordial', 'delirious', 'drunk', 'enthusiastic', 'excited'],
    'boisterous': ['blaring', 'blatant', 'blatting', 'blustering', 'blusterous', 'blustery', 'brassy', 'brawling', 'brazen', 'bullying', 'clamant', 'clamorous'],
    'bold': ['abrupt', 'adventurous', 'arrant', 'arrogant', 'audacious', 'aweless', 'barefaced', 'blatant', 'bluff', 'bold as brass', 'bold-spirited', 'boldfaced'],
    'bold faced': ['aweless', 'barefaced', 'blackface', 'bold', 'bold as brass', 'boldface', 'boldfaced', 'brassy', 'brazen', 'brazenfaced', 'cheeky', 'chromotypic'],
    'boldly': ['arrantly', 'audaciously', 'blatantly', 'boldfacedly', 'bravely', 'brazenfacedly', 'brazenly', 'bulldoggishly', 'chivalrously', 'conspicuously', 'courageously', 'daringly'],
    'bole': ['anthrophore', 'axis', 'barrel', 'cane', 'carpophore', 'cask', 'caudex', 'caulicle', 'caulis', 'column', 'culm', 'cylinder'],
    'boll': ['ball', 'balloon', 'bladder', 'blob', 'bolus', 'bubble', 'bulb', 'bulbil', 'bulblet', 'burr', 'capsule', 'cod'],
    'bollix up': ['ball up', 'bollix', 'bugger', 'bugger up', 'confound', 'confuse', 'cook', 'foul up', 'fumble', 'garble', 'gum up', 'hash up'],
    'bollixed up': ['anarchic', 'arsy-varsy', 'ass-backwards', 'balled up', 'buggered', 'buggered up', 'chaotic', 'confused', 'cooked', 'fouled up', 'galley-west', 'gummed up'],
    'bologna': ['vienna sausage', 'bangers', 'black pudding', 'blood pudding', 'braunschweiger', 'frank', 'frankfurter', 'gooseliver', 'headcheese', 'hot dog', 'knockwurst', 'liver sausage'],
    'bolshevik': ['bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'communist sympathizer', 'cong', 'fenian', 'guevarist'],
    'bolster': ['advance', 'affirm', 'afford support', 'aid', 'air mattress', 'assist', 'assure', 'attest', 'authenticate', 'back', 'back up', 'bear'],
    'bolt': ['awol', 'french leave', 'irish confetti', 'jupiter fulgur', 'thor', 'abscond', 'absence without leave', 'absquatulate', 'absquatulation', 'apostacize', 'apostasy', 'apostatize'],
    'bolt hole': ['asylum', 'back door', 'back stairs', 'back way', 'cache', 'concealment', 'corner', 'cover', 'covert', 'covert way', 'coverture', 'cranny'],
    'bolus': ['ball', 'balloon', 'bite', 'bladder', 'blob', 'boll', 'bubble', 'bulb', 'bulbil', 'bulblet', 'capsule', 'champ'],
    'bomb': ['a-bomb', 'grand guignol', 'h-bomb', 'passion play', 'tom show', 'aerial bomb', 'antimasque', 'antipersonnel bomb', 'astonishment', 'atom-bomb', 'atomic bomb', 'audience success'],
    'bombard': ['accelerate', 'activate', 'aim at', 'assail', 'assault', 'atomize', 'attack', 'barrage', 'batter', 'besiege', 'blast', 'blitz'],
    'bombardier': ['aerial photographer', 'aircrew', 'aircrewman', 'artillerist', 'artilleryman', 'avigator', 'belly gunner', 'bomb thrower', 'bomber', 'cannoneer', 'crew', 'crew chief'],
    'bombardment': ['air raid', 'alpha decay', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction', 'atomization', 'beta decay', 'blitz', 'blitzkrieg', 'breeding', 'broadside'],
    'bombast': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'blabber', 'blather', 'bluster', 'boast', 'boastfulness', 'boasting'],
    'bombastic': ['latinate', 'aureate', 'awkward', 'big', 'bloated', 'cramped', 'cumbrous', 'declamatory', 'elephantine', 'euphuistic', 'extravagant', 'flatulent'],
    'bomber': ['mafioso', 'young turk', 'alarmist', 'annihilator', 'arsonist', 'artillerist', 'artilleryman', 'assassin', 'beast', 'beldam', 'berserk', 'berserker'],
    'bombing': ['air cover', 'air raid', 'air support', 'area bombing', 'blitz', 'carpet bombing', 'cover', 'dive-bombing', 'dry run', 'high-altitude bombing', 'low-altitude bombing', 'milk run'],
    'bombshell': ['aerial bomb', 'antipersonnel bomb', 'astonishment', 'blockbuster', 'blow', 'bomb', 'carcass', 'catch', 'concussion grenade', 'depth bomb', 'depth charge', 'earthshaker'],
    'bon mot': ['aphorism', 'apothegm', 'boutade', 'bright idea', 'bright thought', 'brilliant idea', 'conceit', 'crack', 'epigram', 'facetiae', 'flash of wit', 'flight of wit'],
    'bon ton': ['conformity', 'consuetude', 'convention', 'currency', 'custom', 'established way', 'etiquette', 'fashion', 'fashionableness', 'folkway', 'haute couture', 'high fashion'],
    'bon vivant': ['brillat-savarin', 'cyrenaic', 'heliogabalus', 'lucullus', 'sardanapalus', 'amateur', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'authority', 'board-and-roomer', 'boarder'],
    'bona fide': ['aboveboard', 'attested', 'authentic', 'candid', 'card-carrying', 'consistently', 'constantly', 'devotedly', 'dinkum', 'fair and square', 'faithfully', 'firmly'],
    'bonanza': ['eldorado', 'golconda', 'abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bountifulness', 'bountiousness', 'bumper crop', 'copiousness'],
    'bond': ['fannie mae', 'federal agency bond', 'ginnie mae', 'oregon boat', 'series e bond', 'series h bond', 'accident insurance', 'accord', 'accouple', 'accumulate', 'actuary', 'addition'],
    'bondage': ['absolutism', 'bond service', 'captivity', 'control', 'debt slavery', 'deprivation of freedom', 'disenfranchisement', 'disfranchisement', 'domination', 'enslavement', 'enthrallment', 'feudalism'],
    'bondsman': ['bailsman', 'bondmaid', 'bondman', 'bondslave', 'bondswoman', 'captive', 'chattel', 'chattel slave', 'churl', 'concubine', 'debt slave', 'galley slave'],
    'bone': ['adamant', 'aitchbone', 'anklebone', 'anvil', 'backbone', 'bill', 'biscuit', 'bony', 'breastbone', 'brick', 'buck', 'calcaneus'],
    'bone of contention': ['apple of discord', 'bone to pick', 'casus belli', 'catechism', 'cross-interrogatory', 'cross-question', 'crow to pick', 'crow to pluck', 'debating point', 'demand', 'feeler', 'grounds for war'],
    'bonehead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead', 'clodhead'],
    'boner': ['bad job', 'bevue', 'bloomer', 'blooper', 'blunder', 'bobble', 'boggle', 'bonehead play', 'boo-boo', 'boob stunt', 'boot', 'botch'],
    'bones': ['anatomy', 'appendicular skeleton', 'ashes', 'axial skeleton', 'battery', 'being', 'bells', 'bird cage', 'body', 'bosom', 'breast', 'cadaver'],
    'bonhomie': ['affability', 'amiability', 'ardency', 'cordiality', 'friendliness', 'generosity', 'geniality', 'gentleness', 'good disposition', 'good humor', 'good nature', 'good temper'],
    'bonkers': ['balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bedlamite', 'brainsick', 'buggy', 'bughouse', 'bugs', 'crackbrained'],
    'bonny': ['junoesque', 'advantageous', 'agreeable', 'amply endowed', 'attractive', 'auspicious', 'beauteous', 'beautiful', 'becoming', 'beneficial', 'benevolent', 'bon'],
    'bonus': ['trinkgeld', 'balance', 'bonus system', 'bounty', 'bribe', 'buried treasure', 'compensation', 'consideration', 'decoration', 'discovery', 'dividend', 'donative'],
    'bony': ['angular', 'bone', 'cement', 'cemental', 'concrete', 'corneous', 'dense', 'diamondlike', 'dure', 'flat', 'flat-chested', 'fleshless'],
    'boo': ['bronx cheer', 'mary jane', 'bird', 'booing', 'cannabis', 'catcall', 'give the bird', 'give the raspberry', 'grass', 'hiss', 'hissing', 'hoot'],
    'boo boo': ['bad job', 'bevue', 'bloomer', 'blooper', 'blunder', 'bobble', 'boggle', 'bonehead play', 'boner', 'boob stunt', 'boot', 'botch'],
    'boob': ['babbitt', 'philistine', 'asshole', 'babe', 'bag', 'boeotian', 'boobs', 'booby', 'bosom', 'breast', 'breasts', 'brisket'],
    'booby': ['also-ran', 'asshole', 'bag', 'boob', 'boobs', 'bosom', 'breast', 'breasts', 'brisket', 'bust', 'chest', 'chump'],
    'booby trap': ['dionaea', 'ambuscade', 'ambush', 'ambushment', 'baited trap', 'blind', 'deadfall', 'deathtrap', 'decoy', 'firetrap', 'flytrap', 'gin'],
    'boodle': ['beat', 'bilk', 'blackmail', 'blunt', 'bomb', 'booty', 'brass', 'bread', 'bribe', 'bribe money', 'bucks', 'bundle'],
    'boogie woogie': ['acid rock', 'avant-garde jazz', 'ballroom music', 'bebop', 'bop', 'country rock', 'dance music', 'dances', 'folk rock', 'hard rock', 'hot jazz', 'jazz'],
    'book': ['holy writ', 'scripture', 'spenserian stanza', 'accuse', 'airing', 'allege', 'ante', 'antistrophe', 'arraign', 'article', 'back matter', 'balance'],
    'book collector': ['bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliomane', 'bibliomaniac', 'bibliopegist', 'bibliophage', 'bibliophile', 'bibliopole', 'bibliopolist', 'bibliotaph'],
    'book value': ['asking price', 'bearish prices', 'bid price', 'bullish prices', 'call price', 'closing price', 'decline', 'face value', 'fixed price', 'flash price', 'flurry', 'flutter'],
    'bookbinding': ['smyth sewing', 'backing', 'bibliopegy', 'binder board', 'binding', 'book cloth', 'book cover', 'book jacket', 'bookcase', 'case', 'casemaking', 'casing-in'],
    'bookcase': ['smyth sewing', 'archives', 'armory', 'arsenal', 'attic', 'backing', 'bank', 'basement', 'bay', 'bibliopegy', 'bin', 'binder board'],
    'bookdealer': ['baker', 'bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliomane', 'bibliomaniac', 'bibliopegist', 'bibliophage', 'bibliophile', 'bibliopole', 'bibliopolist'],
    'booked': ['billed', 'documented', 'down', 'enrolled', 'entered', 'filed', 'indexed', 'inscribed', 'legal', 'logged', 'minuted', 'of record'],
    'booking': ['appointment', 'bespeaking', 'borscht circuit', 'briefing', 'cataloging', 'chronicling', 'circuit', 'date', 'employment', 'engagement', 'enlistment', 'enrollment'],
    'bookish': ['academic', 'autodidactic', 'bibliophagic', 'bluestocking', 'book-fed', 'book-learned', 'book-loving', 'book-minded', 'book-read', 'book-wise', 'booky', 'college-bred'],
    'bookkeeper': ['ca', 'cpa', 'abacist', 'accountant', 'accountant general', 'actuary', 'amanuensis', 'archivist', 'auditor', 'bank accountant', 'bank examiner', 'bursar'],
    'booklover': ['bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliolatrist', 'bibliomane', 'bibliomaniac', 'bibliopegist', 'bibliophage', 'bibliophile', 'bibliophilist', 'bibliopole'],
    'bookmaker': ['bagman', 'bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliomane', 'bibliomaniac', 'bibliopegist', 'bibliophage', 'bibliophile', 'bibliopole', 'bibliopolist'],
    'books': ['account', 'account book', 'accounts payable ledger', 'accounts receivable ledger', 'balance sheet', 'bank ledger', 'bankbook', 'bill', 'bill of fare', 'bill of lading', 'card ledger', 'carte'],
    'bookseller': ['baker', 'bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliomane', 'bibliomaniac', 'bibliopegist', 'bibliophage', 'bibliophile', 'bibliopole', 'bibliopolist'],
    'bookstore': ['antique store', 'apothecary', 'automobile showroom', 'book club', 'bookshop', 'bookstall', 'bookstand', 'bootery', 'candy store', 'chemist', 'cigar store', 'clothiers'],
    'bookworm': ['bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliolatrist', 'bibliomane', 'bibliomaniac', 'bibliopegist', 'bibliophage', 'bibliophile', 'bibliophilist', 'bibliopole'],
    'boom': ['carling float', 'access', 'accession', 'accretion', 'accrual', 'accrue', 'accruement', 'accumulate', 'accumulation', 'addition', 'advance', 'aggrandizement'],
    'boomerang': ['irish confetti', 'backfire', 'backlash', 'backlashing', 'bola', 'bolt', 'bounce', 'bounce back', 'bound', 'bound back', 'brickbat', 'cannon'],
    'booming': ['balmy', 'birring', 'blooming', 'blossoming', 'bombilation', 'bombinating', 'bombination', 'boom', 'burring', 'buzzing', 'cannonade', 'cannonading'],
    'boon': ['advantage', 'avail', 'award', 'behalf', 'behoof', 'benediction', 'benefaction', 'benefit', 'benevolence', 'benison', 'blessing', 'blithe'],
    'boondocks': ['china', 'darkest africa', 'god knows where', 'greenland', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'siberia', 'south pole', 'thule', 'tierra del fuego'],
    'boor': ['babbitt', 'philistine', 'arriviste', 'backwoodsman', 'barbarian', 'blockhead', 'blunderer', 'blunderhead', 'boob', 'botcher', 'bounder', 'bourgeois'],
    'boorish': ['all thumbs', 'awkward', 'barbarian', 'barbaric', 'blunderheaded', 'blundering', 'bucolic', 'bumbling', 'bungling', 'butterfingered', 'caddish', 'careless'],
    'boost': ['great leap forward', 'a leg up', 'abstract', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'acculturate', 'accumulation', 'acknowledgment', 'add to'],
    'booster': ['comsat', 'intelsat', 'syncom', 'telstar', 'adherent', 'admirer', 'amateur', 'antitoxin', 'applauder', 'appreciator', 'bag', 'bang'],
    'boot': ['naval reservist', 'procrustean bed', 'royal marine', 'seabee', 'abecedarian', 'additionally', 'alphabetarian', 'also', 'apprentice', 'articled clerk', 'as well', 'avail'],
    'bootblack': ['ganymede', 'hebe', 'airline hostess', 'airline stewardess', 'attendant', 'batman', 'bellboy', 'bellhop', 'bellman', 'boots', 'cabin boy', 'caddie'],
    'booth': ['nissen hut', 'quonset hut', 'box', 'cavity', 'cell', 'cellule', 'chamber', 'compartment', 'crib', 'crypt', 'cubicle', 'enclosed space'],
    'bootleg': ['actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'bathtub gin', 'black-market', 'black-marketeer', 'blockade', 'brew', 'chargeable', 'contraband'],
    'bootlegger': ['mafioso', 'barkeep', 'barkeeper', 'barmaid', 'barman', 'bartender', 'black marketeer', 'brewer', 'brewmaster', 'dealer', 'distiller', 'drug pusher'],
    'bootless': ['abortive', 'barren', 'counterproductive', 'effete', 'empty', 'etiolated', 'failed', 'failing', 'fatuitous', 'fatuous', 'feckless', 'fruitless'],
    'bootlicker': ['apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bootlick', 'brown-nose', 'brownie', 'clawback', 'courtier', 'creature', 'cringer', 'dupe'],
    'booty': ['bag', 'blackmail', 'boodle', 'capture', 'catch', 'contraband', 'gain', 'graft', 'haul', 'hot goods', 'loot', 'perks'],
    'booze': ['john barleycorn', 'alcohol', 'alcoholic beverage', 'alcoholic drink', 'aqua vitae', 'ardent spirits', 'bat', 'bender', 'beverage', 'bib', 'brannigan', 'brew'],
    'bop': ['acid rock', 'avant-garde jazz', 'ballroom music', 'baloney', 'bash', 'bat', 'bebop', 'belt', 'biff', 'bilge', 'blah', 'blah-blah'],
    'bordello': ['bagnio', 'bawdy house', 'bawdyhouse', 'brothel', 'cathouse', 'clip joint', 'crib', 'den', 'den of thieves', 'den of vice', 'disorderly house', 'dive'],
    'border': ['berlin wall', 'japanese garden', 'pillars of hercules', 'abut', 'abut on', 'act drop', 'adjoin', 'alpine garden', 'ambit', 'approach', 'approximate', 'arboretum'],
    'bordering': ['adjacent', 'adjoining', 'beading', 'binding', 'borderline', 'bordure', 'boundary', 'bounding', 'coastal', 'connecting', 'conterminous', 'contiguous'],
    'borderland': ['berlin wall', 'pillars of hercules', 'alentours', 'ambience', 'ambit', 'arena', 'back country', 'backwoods', 'bailiwick', 'bamboo curtain', 'beat', 'boondock'],
    'borderline': ['ambiguous', 'bordering', 'boundary', 'bounding', 'coastal', 'determinant', 'determinative', 'determining', 'dubitable', 'equivocal', 'extreme', 'fringing'],
    'borderline case': ['aliene', 'bedlamite', 'blind bargain', 'chance', 'contingency', 'crackbrain', 'crackpot', 'dement', 'demoniac', 'double contingency', 'energumen', 'fanatic'],
    'bore': ['acupunctuation', 'acupuncture', 'aggravation', 'annoyance', 'auger', 'bad news', 'be tedious', 'bedevilment', 'billow', 'bite', 'bore stiff', 'bore to death'],
    'boreal': ['siberian', 'aeolian', 'aestival', 'airish', 'airy', 'algid', 'antarctic', 'arctic', 'austral', 'autumn', 'autumnal', 'below zero'],
    'bored': ['aloof', 'anguished', 'anxious', 'apathetic', 'benumbed', 'blase', 'bored stiff', 'bored to death', 'bored to tears', 'careless', 'cheerless', 'dead'],
    'boredom': ['acedia', 'aloofness', 'angst', 'anguish', 'anxiety', 'apathy', 'boredness', 'carelessness', 'cheerlessness', 'detachment', 'discomfort', 'discomposure'],
    'boring': ['acupunctuation', 'acupuncture', 'arid', 'bore', 'boresome', 'broach', 'dead', 'drab', 'dreary', 'drill hole', 'drudging', 'dry'],
    'born': ['absolute', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'atavistic', 'bearing', 'birth', 'bodily', 'bring forth', 'broad-based', 'calved'],
    'born yesterday': ['artless', 'bluff', 'blunt', 'candid', 'childlike', 'confiding', 'direct', 'frank', 'guileless', 'ingenu', 'ingenuous', 'innocent'],
    'borne': ['based on', 'bolstered', 'braced', 'buttressed', 'founded on', 'grounded on', 'guyed', 'held', 'ineffectual', 'limited', 'maintained', 'mean'],
    'borne out': ['ascertained', 'attested', 'authenticated', 'certified', 'circumstantiated', 'confirmed', 'corroborated', 'demonstrated', 'determined', 'established', 'fixed', 'proved'],
    'borough': ['kreis', 'stadt', 'archbishopric', 'archdiocese', 'arrondissement', 'bailiwick', 'banlieue', 'bishopric', 'boom town', 'bourg', 'burg', 'burgh'],
    'borrow': ['abstract', 'act like', 'adopt', 'affect', 'and', 'annex', 'appropriate', 'assume', 'bag', 'boost', 'bum', 'cadge'],
    'borrowing': ['accounts payable', 'accounts receivable', 'amount due', 'appropriation', 'autoplagiarism', 'bad debts', 'bill', 'bills', 'borrowed word', 'calque', 'charges', 'cheap money'],
    'borrowing power': ['bank credit', 'book credit', 'cash credit', 'commercial credit', 'consumer credit', 'credit', 'credit insurance', 'credit rating', 'credit union', 'hire purchase plan', 'installment credit', 'installment plan'],
    'borstal': ['pow camp', 'bastille', 'black hole', 'borstal institution', 'borstal school', 'bridewell', 'brig', 'cell', 'concentration camp', 'condemned cell', 'death cell', 'death house'],
    'boscage': ['bosket', 'brake', 'canebrake', 'ceja', 'chamisal', 'chaparral', 'coppice', 'copse', 'copsewood', 'covert', 'frith', 'motte'],
    'bosh': ['balderdash', 'balls', 'baloney', 'bilge', 'blague', 'blah', 'blah-blah', 'blatherskite', 'bop', 'bull', 'bullshit', 'bunk'],
    'bosom': ['bag', 'bear', 'being', 'beloved', 'blood', 'bones', 'boobs', 'boon', 'bottle up', 'bowels', 'breast', 'breasts'],
    'bosomy': ['adipose', 'bagging', 'baggy', 'ballooning', 'beefy', 'bellying', 'big-bellied', 'billowing', 'billowy', 'bloated', 'blowzy', 'brawny'],
    'boss': ['a per se', 'big brother', 'ok', 'ace', 'ace-high', 'administrator', 'anaglyph', 'ascendant', 'at the head', 'auditor', 'bad', 'bang-up'],
    'bossism': ['machtpolitik', 'realpolitik', 'tammany hall', 'arbitrariness', 'authoritarianism', 'authoritativeness', 'autocraticalness', 'career politics', 'confrontation politics', 'consensus politics', 'domineering', 'domineeringness'],
    'bossy': ['brahman', 'indian buffalo', 'partlet', 'absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'aurochs', 'authoritarian', 'authoritative'],
    'botanic': ['bulbous', 'cereal', 'farinaceous', 'fruitlike', 'fruity', 'herbaceous', 'herbal', 'herbose', 'herbous', 'herby', 'leguminose', 'leguminous'],
    'botanical': ['botanic', 'bulbous', 'cereal', 'farinaceous', 'fruitlike', 'fruity', 'herbaceous', 'herbal', 'herbose', 'herbous', 'herby', 'leguminose'],
    'botanist': ['anatomist', 'bacteriologist', 'biochemist', 'biologist', 'biometrist', 'biophysicist', 'bryologist', 'cytologist', 'dendrologist', 'ecologist', 'geneticist', 'herbalist'],
    'botany': ['aerobiology', 'agrobiology', 'amnion', 'anatomy', 'astrobiology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology'],
    'botch': ['anamorphosis', 'bad job', 'bad likeness', 'bat out', 'be all thumbs', 'bevue', 'bitch up', 'blight', 'blow', 'blunder', 'blunder away', 'blunder into'],
    'botched': ['blighted', 'bungled', 'bungling', 'butchered', 'clumsy', 'deficient', 'destroyed', 'fumbled', 'half-assed', 'haphazard', 'hit-and-miss', 'hit-or-miss'],
    'both': ['a deux', 'brace', 'couple', 'couplet', 'distich', 'double harness', 'doublet', 'duad', 'duet', 'duo', 'dyad', 'either'],
    'bother': ['abash', 'abrade', 'abuse a privilege', 'addle', 'addle the wits', 'ado', 'afflict', 'aggravate', 'aggravation', 'agitate', 'agitation', 'ail'],
    'bothered': ['abashed', 'abroad', 'adrift', 'afflicted', 'aggravated', 'agitated', 'all-overish', 'angry', 'annoyed', 'anxious', 'anxioused up', 'apprehensive'],
    'bothersome': ['aggravating', 'annoying', 'backbreaking', 'besetting', 'bothering', 'burdensome', 'chafing', 'crushing', 'disquieting', 'distressful', 'distressing', 'disturbing'],
    'bottle': ['dutch courage', 'alcohol', 'alcoholic drink', 'backbone', 'bag', 'barrel', 'basket', 'booze', 'bottle up', 'box', 'box in', 'box up'],
    'bottle up': ['arrest', 'asphyxiate', 'bosom', 'box in', 'box up', 'bury', 'cabin', 'cache', 'cage', 'casket', 'censor', 'check'],
    'bottleneck': ['abbreviation', 'approach', 'astriction', 'astringency', 'asymptote', 'bar', 'barrier', 'blank wall', 'blind alley', 'blind gut', 'block', 'blockade'],
    'bottom': ['argosy', 'arse', 'ass', 'at bottom', 'backbone', 'backside', 'bark', 'basal', 'base', 'basement', 'basic', 'basically'],
    'bottom dollar': ['swiss bank account', 'thule', 'ultima thule', 'assets', 'balance', 'bank account', 'bitter end', 'boundary', 'budget', 'butt', 'butt end', 'cash reserves'],
    'bottom out': ['alter', 'ameliorate', 'be changed', 'be converted into', 'be renewed', 'break', 'change', 'checker', 'chop', 'chop and change', 'come about', 'come around'],
    'bottomland': ['alkali flat', 'alluvial plain', 'basin', 'baygall', 'bog', 'bottom', 'bottoms', 'buffalo wallow', 'bushveld', 'campo', 'champaign', 'champaign country'],
    'bottomless': ['a hog for', 'abounding', 'abundant', 'abysmal', 'abyssal', 'acquisitive', 'affluent', 'all-devouring', 'all-sufficing', 'ample', 'aplenty', 'avaricious'],
    'bottomless pit': ['abaddon', 'gehenna', 'hades', 'naraka', 'pandemonium', 'sheol', 'tophet', 'avichi', 'bowels', 'deep space', 'deeps', 'depths'],
    'bough': ['appendage', 'arm', 'bine', 'branch', 'branchedness', 'branchiness', 'burgeon', 'deadwood', 'flagellum', 'fork', 'frond', 'hand'],
    'bouillabaisse': ['irish stew', 'bisque', 'borscht', 'bouillon', 'broth', 'burgoo', 'chicken soup', 'chowder', 'clam chowder', 'clear soup', 'consomme', 'curry'],
    'bouillon': ['beef', 'beef extract', 'beef tea', 'bisque', 'borscht', 'bouillabaisse', 'broth', 'bully', 'bully beef', 'burgoo', 'charqui', 'chicken soup'],
    'boulevard': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'bounce': ['am signal', 'crt spot', 'dm display', 'doppler signal', 'fm signal', 'highland fling', 'if signal', 'im display', 'rf amplifier', 'rf echoes', 'rf signal', 'rf stage'],
    'bounce back': ['backfire', 'backlash', 'be reflected', 'be sent back', 'boom', 'boomerang', 'bounce', 'bound', 'bound back', 'cannon', 'cannon off', 'carom'],
    'bouncing': ['active', 'activist', 'activistic', 'alive', 'animated', 'beefy', 'bouncy', 'bounding', 'breezy', 'brisk', 'bubbly', 'chipper'],
    'bound': ['highland fling', 'absolute', 'adjoin', 'affianced', 'affiliate', 'affiliated', 'allied', 'and jump', 'apodictic', 'apprenticed', 'articled', 'assembled'],
    'boundary': ['thule', 'ultima thule', 'ankle', 'articulation', 'balustrade', 'barrier', 'bisector', 'bitter end', 'border line', 'bordering', 'borderline', 'borders'],
    'bounder': ['babbitt', 'philistine', 'arriviste', 'boor', 'bourgeois', 'cad', 'churl', 'clown', 'cur', 'epicier', 'groundling', 'guttersnipe'],
    'boundless': ['gargantuan', 'a bit much', 'abandoned', 'all-comprehensive', 'all-inclusive', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'amplitudinous', 'astronomical'],
    'bountiful': ['abounding', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'beneficent', 'bighearted', 'blooming', 'bottomless', 'bounteous', 'bursting'],
    'bounty': ['trinkgeld', 'aid', 'alimony', 'allotment', 'allowance', 'annuity', 'assistance', 'award', 'beneficence', 'bigheartedness', 'bonus', 'bonus system'],
    'bouquet': ['tl', 'aroma', 'arrangement', 'bale', 'balm', 'balminess', 'bindle', 'bolt', 'boughpot', 'boutonniere', 'budget', 'bunch'],
    'bourgeois': ['babbitt', 'babbittish', 'cockney', 'everyman', 'john smith', 'middle american', 'philistine', 'accordant', 'anal', 'anal character', 'arriviste', 'average'],
    'bourn': ['adolescent stream', 'anchorage', 'arroyo', 'beck', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'braided stream', 'branch', 'break boundary'],
    'bourse': ['american stock exchange', 'amex', 'wall street', 'board', 'commodity exchange', 'corn pit', 'curb', 'curb exchange', 'curb market', 'exchange', 'exchange floor', 'outside market'],
    'bout': ['chinese boxing', 'olympic games', 'olympics', 'arsis', 'bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'beat', 'bender', 'binge', 'boxing'],
    'boutique': ['chain store', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dime store', 'discount house', 'discount store', 'emporium', 'establishment'],
    'bovine': ['boeotian', 'brahman', 'indian buffalo', 'asinine', 'aurochs', 'beef', 'beef cattle', 'beef-brained', 'beef-witted', 'beeves', 'bison', 'blockish'],
    'bow': ['a string', 'amati', 'cremona', 'd string', 'e string', 'g string', 's-curve', 'strad', 'stradivari', 'stradivarius', 'accost', 'address'],
    'bow out': ['abandon', 'abscond', 'beat a retreat', 'bundle', 'bundle off', 'depart', 'disappear', 'dismiss', 'duck out', 'egress', 'escape', 'evacuate'],
    'bowdlerize': ['abbreviate', 'abridge', 'bleach', 'blot out', 'blue-pencil', 'cancel', 'censor', 'clean', 'clean out', 'clean up', 'cleanse', 'clear out'],
    'bowel movement': ['bm', 'bloody flux', 'buffalo chips', 'ca-ca', 'catharsis', 'coprolite', 'coprolith', 'cow chips', 'cow flops', 'cow pats', 'crap', 'defecation'],
    'bowels': ['abdomen', 'anus', 'appendix', 'belly', 'blind gut', 'bottomless pit', 'brain', 'cecum', 'colon', 'core', 'deep space', 'deeps'],
    'bower': ['ace', 'alcove', 'arbor', 'best bower', 'cards', 'clubs', 'conservatory', 'deck', 'deuce', 'diamonds', 'dummy', 'face cards'],
    'bowl': ['adobe', 'advance', 'agora', 'alveolation', 'alveolus', 'amphitheater', 'antrum', 'arena', 'armpit', 'athletic field', 'auditorium', 'background'],
    'bowl over': ['amaze', 'astonish', 'astound', 'awe', 'awestrike', 'bedaze', 'bedazzle', 'bewilder', 'blow down', 'blow over', 'boggle', 'bowl down'],
    'bowlegged': ['bandy', 'bandy-legged', 'bent', 'blemished', 'bloated', 'bowed', 'club-footed', 'crooked', 'curved', 'defaced', 'deformed', 'disfigured'],
    'box': ['christmas present', 'archives', 'armory', 'arsenal', 'attic', 'auditorium', 'award', 'bag', 'balcony', 'bank', 'barrel', 'basement'],
    'box in': ['abate', 'adjust to', 'alter', 'assuage', 'beleaguer', 'beset', 'besiege', 'blockade', 'bottle up', 'bound', 'box', 'box up'],
    'box office': ['attendance', 'avails', 'booking office', 'branch', 'branch office', 'cabinet', 'chambers', 'chancellery', 'chancery', 'closet', 'commissions', 'consulate'],
    'boxcar': ['pullman', 'pullman car', 'baggage car', 'caboose', 'car', 'carriage', 'chair car', 'coach', 'coal car', 'covered waggon', 'day coach', 'diner'],
    'boxcars': ['sexagesima', 'boxcar', 'dozen', 'duodecimo', 'eighty', 'eleven', 'fifteen', 'fifty', 'five and twenty', 'fortnight', 'forty', 'four and twenty'],
    'boxer': ['chinese boxer', 'bantamweight', 'black belt', 'brown belt', 'bruiser', 'featherweight', 'fighter', 'fisticuffer', 'flyweight', 'heavyweight', 'karate expert', 'light heavyweight'],
    'boxing': ['chinese boxing', 'bottling', 'bout', 'boxing match', 'canning', 'close fighting', 'crating', 'encasement', 'fighting', 'fisticuffs', 'infighting', 'package'],
    'boy': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'boycott': ['avoid', 'ban', 'banish', 'banishment', 'bar', 'barring', 'beef', 'bitch', 'blackball', 'blacklist', 'blockade', 'boggle'],
    'boyfriend': ['casanova', 'don juan', 'lothario', 'romeo', 'admirer', 'amoroso', 'beau', 'beloved', 'caballero', 'cavalier', 'cavaliere servente', 'crush'],
    'boyhood': ['babyhood', 'childhood', 'childkind', 'children', 'girlhood', 'kids', 'little kids', 'maidenhead', 'maidenhood', 'new generation', 'pre-teens', 'rising generation'],
    'boyish': ['adolescent', 'airy', 'attenuate', 'attenuated', 'beardless', 'boylike', 'calflike', 'childish', 'childlike', 'coltish', 'delicate', 'diaphanous'],
    'bra': ['advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'bearer', 'brace', 'bracer', 'bracket'],
    'brace': ['ace bandage', 'band-aid', 'adhesive tape', 'advocate', 'afford support', 'alpenstock', 'animate', 'appeal', 'application', 'arm', 'athletic supporter', 'back'],
    'brace up': ['animate', 'assure', 'beef up', 'bolster', 'brace', 'brighten up', 'brisk', 'brisken', 'buck up', 'buttress', 'case harden', 'cheer'],
    'bracelet': ['anklet', 'armlet', 'band', 'bangle', 'beads', 'belt', 'bijou', 'breastpin', 'brooch', 'chain', 'chaplet', 'charm'],
    'bracer': ['advocate', 'alpenstock', 'analeptic', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'bearer', 'bra', 'brace'],
    'bracing': ['activating', 'analeptic', 'animating', 'animative', 'bearing', 'beneficial', 'benign', 'bolstering', 'brisk', 'burdened', 'buttressing', 'carrying'],
    'bracken': ['algae', 'autophyte', 'bean', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'diatom', 'fern', 'fruits and vegetables', 'fucus'],
    'bracket': ['accouple', 'accumulate', 'advocate', 'agglutinate', 'ally', 'alpenstock', 'amass', 'analyze', 'apply', 'arm', 'articulate', 'assemble'],
    'brackish': ['bad', 'barfy', 'briny', 'cloying', 'fetid', 'foul', 'fulsome', 'high', 'icky', 'maggoty', 'mawkish', 'nasty'],
    'bract': ['blade', 'bracteole', 'bractlet', 'cotyledon', 'flag', 'floral leaf', 'foliole', 'frond', 'glume', 'involucre', 'involucrum', 'lamina'],
    'brag': ['captain bobadil', 'gascon', 'texan', 'big mouth', 'blow', 'blower', 'blowhard', 'bluff', 'bluster', 'bluster and bluff', 'blusterer', 'boast'],
    'brag about': ['adulate', 'apotheosize', 'belaud', 'bepraise', 'bless', 'blow up', 'boast of', 'celebrate', 'cry up', 'deify', 'emblazon', 'eulogize'],
    'braggart': ['captain bobadil', 'gascon', 'herod', 'narcissus', 'scaramouch', 'texan', 'big mouth', 'blatherskite', 'blower', 'blowhard', 'bluff', 'bluffer'],
    'bragging': ['gascon', 'bluster', 'boast', 'boastful', 'boastfulness', 'boasting', 'bombast', 'brag', 'braggadocio', 'braggart', 'braggartism', 'bravado'],
    'bragi': ['aesir', 'apollo', 'apollo musagetes', 'balder', 'bor', 'bori', 'calliope', 'castilian spring', 'donar', 'erato', 'euterpe', 'forseti'],
    'brahma': ['agni', 'asvins', 'atman', 'avalokita', 'bhairava', 'bhairavi', 'chandi', 'daksha', 'devaki', 'devi', 'dharma', 'dharti mai'],
    'brahman': ['buddhist', 'christian', 'ramwat', 'anthroposophist', 'archduke', 'aristocrat', 'armiger', 'bairagi', 'baron', 'baronet', 'bashara', 'bhikhari'],
    'braid': ['band', 'brail', 'bun', 'cable', 'chignon', 'coil', 'cord', 'cue', 'embroidery', 'enlace', 'entwine', 'fillet'],
    'braille': ['boston type', 'new york point', 'optacon', 'pathsounder', 'seeing eye dog', 'visotoner', 'cane', 'embosser', 'guide dog', 'high-speed embosser', 'line letter', 'noctograph'],
    'brain': ['vernunft', 'abdomen', 'acumen', 'afferent neuron', 'anus', 'appendix', 'autonomic nervous system', 'axon', 'bean', 'blind gut', 'blow to pieces', 'blow up'],
    'brain damage': ['aberration', 'abnormality', 'alienation', 'brainsickness', 'clouded mind', 'craziness', 'daftness', 'dementedness', 'dementia', 'derangement', 'disorientation', 'distraction'],
    'brain trust': ['british cabinet', 'sanhedrin', 'us cabinet', 'advisory body', 'assembly', 'association', 'bench', 'board', 'body of advisers', 'borough council', 'cabinet', 'camarilla'],
    'brain wave': ['automatic response', 'blind impulse', 'brainstorm', 'drive', 'fancy', 'flash', 'fleeting impulse', 'gut response', 'impulse', 'inspiration', 'instinct', 'involuntary impulse'],
    'brainchild': ['apparition', 'art object', 'article', 'artifact', 'autograph', 'brainstorm', 'bric-a-brac', 'bright idea', 'bright thought', 'brilliant idea', 'bubble', 'child'],
    'brainless': ['apish', 'asinine', 'batty', 'befooled', 'beguiled', 'besotted', 'buffoonish', 'cockeyed', 'crazy', 'credulous', 'daffy', 'daft'],
    'brainstorm': ['absurd idea', 'afebrile delirium', 'automatic response', 'blind impulse', 'boutade', 'brain wave', 'brainchild', 'bright idea', 'bright thought', 'brilliant idea', 'capriccio', 'caprice'],
    'brainwash': ['alienate', 'beat into', 'catechize', 'condition', 'corrupt', 'counterindoctrinate', 'imbue', 'implant', 'impregnate', 'impress', 'inculcate', 'indoctrinate'],
    'brainwork': ['abstract thought', 'act of thought', 'application', 'boning', 'cerebration', 'cogitation', 'conceit', 'conception', 'conceptualization', 'conning', 'contemplation', 'cram'],
    'brainy': ['adroit', 'alert', 'apt', 'bright', 'brilliant', 'clever', 'dexterous', 'gifted', 'keen', 'keen-witted', 'knowing', 'nimble'],
    'braise': ['bake', 'barbecue', 'baste', 'blanch', 'boil', 'brew', 'broil', 'brown', 'coddle', 'cook', 'curry', 'devil'],
    'brake': ['arrest', 'backpedal', 'backwater', 'bar', 'bearing rein', 'bit', 'block', 'boscage', 'bosket', 'bring to', 'bring up short', 'canebrake'],
    'bramble': ['adherent', 'adhesive', 'barnacle', 'brier', 'brier bush', 'bristle', 'bulldog', 'burr', 'bush', 'cactus', 'catchweed', 'cement'],
    'bran': ['air pollution', 'attritus', 'bark', 'barley', 'bird seed', 'capsule', 'case', 'cat food', 'chaff', 'chicken feed', 'chop', 'corn'],
    'branch': ['adolescent stream', 'affiliate', 'affiliation', 'affluent', 'angle', 'angle off', 'apparentation', 'appendage', 'arm', 'arroyo', 'bayou', 'bear off'],
    'branch out': ['bestrew', 'bifurcate', 'branch', 'broadcast', 'circumfuse', 'deal out', 'deploy', 'diffract', 'diffuse', 'dispense', 'disperse', 'dispread'],
    'branching': ['v-shaped', 'y-shaped', 'arboreal', 'arborescence', 'arborescent', 'arboriform', 'arborization', 'bifidity', 'biforked', 'biforking', 'bifurcate', 'bifurcated'],
    'brand': ['acid', 'actual cautery', 'aroma', 'ash', 'ashes', 'aspersion', 'attaint', 'attribute', 'badge', 'badge of infamy', 'bar sinister', 'baton'],
    'brandish': ['advertise', 'affect', 'air', 'betoken', 'blazon forth', 'breathe', 'bring forth', 'bring forward', 'bring into view', 'bring out', 'bring to notice', 'dangle'],
    'brash': ['abrupt', 'aggressive', 'arrogant', 'audacious', 'bearish', 'beastly', 'biggety', 'bluff', 'blunt', 'bold', 'brassy', 'brazen'],
    'brass': ['adc', 'co', 'establishment', 'german band', 'od', 'philharmonic', 'vip', 'aide', 'aide-de-camp', 'alpenhorn', 'alphorn', 'althorn'],
    'brassiere': ['advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'bearer', 'bra', 'brace', 'bracer'],
    'brassy': ['titian', 'adust', 'affront', 'arrant', 'arrogant', 'auburn', 'audacious', 'aureate', 'aweless', 'barefaced', 'bay', 'bay-colored'],
    'bravado': ['adventuresomeness', 'adventurousness', 'arrogance', 'audaciousness', 'audacity', 'balls', 'bluff', 'bluster', 'bluster and bluff', 'blustering', 'boast', 'boastfulness'],
    'brave': ['achilles', 'amazon', 'david', 'hector', 'roland', 'samson', 'a man', 'abide', 'abide with', 'advantageous', 'affront', 'air serviceman'],
    'bravery': ['dutch courage', 'sunday best', 'boldness', 'braveness', 'chiffon', 'chivalrousness', 'chivalry', 'clinquant', 'conspicuous gallantry', 'courage', 'courageousness', 'daring'],
    'bravura': ['daedalian', 'ability', 'address', 'adept', 'adeptness', 'adroit', 'adroitness', 'adventuresomeness', 'adventurousness', 'airmanship', 'alto', 'apt'],
    'braw': ['junoesque', 'advantageous', 'agreeable', 'amply endowed', 'auspicious', 'becoming', 'beneficial', 'benevolent', 'bon', 'bonny', 'brave', 'bravura'],
    'brawl': ['bedlam let loose', 'ado', 'affray', 'agitation', 'altercate', 'altercation', 'argument', 'assemblee', 'assembly', 'assignation', 'at home', 'ball'],
    'brawler': ['agitator', 'battler', 'belligerent', 'belted knight', 'bickerer', 'bitter-ender', 'blade', 'bravo', 'bully', 'bullyboy', 'combatant', 'competitor'],
    'brawling': ['bawling', 'blaring', 'blatant', 'blatting', 'blustering', 'boanergean', 'boisterous', 'brassy', 'brazen', 'clamant', 'clamorous', 'clamoursome'],
    'brawn': ['all that lives', 'beef', 'beefiness', 'biosphere', 'biota', 'brawniness', 'ecosphere', 'elasticity', 'fiber', 'flesh', 'flora and fauna', 'heftiness'],
    'brawny': ['able-bodied', 'adipose', 'athletic', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'broad-shouldered', 'bulky', 'burly', 'buxom'],
    'bray': ['abrade', 'atomize', 'bark', 'bawl', 'bay', 'beat', 'beep', 'belch', 'bell', 'bellow', 'blare', 'blast'],
    'brazen': ['titian', 'adust', 'affront', 'arrant', 'arrogant', 'auburn', 'audacious', 'aureate', 'aweless', 'barefaced', 'bay', 'bay-colored'],
    'brazen out': ['affront', 'bear up', 'beard', 'bell the cat', 'bite the bullet', 'brave', 'brazen', 'come up fighting', 'confront', 'face', 'face down', 'face out'],
    'breach': ['abysm', 'abyss', 'alienation', 'arroyo', 'atrocity', 'bad faith', 'bore', 'box canyon', 'breach of contract', 'breach of faith', 'breach of friendship', 'breach of privilege'],
    'breach of promise': ['punic faith', 'bad faith', 'barratry', 'breach', 'breach of contract', 'breach of faith', 'breach of privilege', 'breach of trust', 'breaking', 'contravention', 'dereliction', 'disaffection'],
    'bread': ['communion', 'eucharist', 'french bread', 'holy communion', 'host', 'irish soda bread', 'italian bread', 'last supper', 'sacrament sunday', 'tlc', 'alimentation', 'alimony'],
    'breadth': ['acreage', 'amount', 'amplitude', 'area', 'beam', 'bigness', 'body', 'broad gauge', 'broad-mindedness', 'broadness', 'bulk', 'caliber'],
    'breadwinner': ['blue-collar worker', 'casual', 'casual laborer', 'common laborer', 'day laborer', 'employee', 'factory worker', 'flunky', 'free lance', 'free-lancer', 'full-time worker', 'hand'],
    'breadwinning': ['advantageous', 'banausic', 'businesslike', 'commercial', 'fat', 'gainful', 'lucrative', 'materialistic', 'moneymaking', 'paying', 'practical', 'productive'],
    'break': ['abeyance', 'about ship', 'about-face', 'abrade', 'abrasion', 'abscond', 'abysm', 'abyss', 'accidentality', 'acclimate', 'acclimatize', 'accommodate'],
    'break away': ['apostacize', 'apostatize', 'bail out', 'betray', 'bolt', 'break jail', 'break loose', 'change sides', 'cut loose', 'defect', 'desert', 'escape'],
    'break down': ['afflict', 'aggrieve', 'alphabetize', 'analyze', 'anatomize', 'anguish', 'arrange', 'assay', 'assort', 'bawl', 'beat down', 'bend'],
    'break even': ['amount to', 'balance', 'come to', 'come up to', 'correspond', 'ditto', 'draw', 'equal', 'even', 'even off', 'keep pace with', 'knot'],
    'break forth': ['appear', 'arise', 'bail out', 'be revealed', 'become known', 'bob up', 'break cover', 'burst forth', 'come', 'come forth', 'come out', 'come to light'],
    'break ground': ['break the ice', 'cast away', 'cast loose', 'cast off', 'cat the anchor', 'create', 'drop the mooring', 'head', 'head up', 'initiate', 'invent', 'lead'],
    'break in': ['acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'admit', 'apprentice', 'barge in', 'be admitted', 'breach', 'break'],
    'break loose': ['bail out', 'break away', 'break jail', 'break out', 'clear', 'cut loose', 'disembarrass', 'disembroil', 'disengage', 'disentangle', 'disinvolve', 'dislodge'],
    'break of day': ['aurora', 'brightening', 'chanticleer', 'cocklight', 'crack of dawn', 'dawn', 'dawning', 'day-peep', 'daybreak', 'daylight', 'dayspring', 'first brightening'],
    'break off': ['agree to disagree', 'be at cross-purposes', 'break', 'clash', 'collide', 'conflict', 'contradict', 'counter', 'cut off', 'differ', 'disaccord', 'disagree'],
    'break out': ['od', 'arise', 'be born', 'be brought down', 'be felled', 'be struck down', 'be traumatized', 'become', 'belch', 'blow open', 'blow out', 'break loose'],
    'break the ice': ['approach', 'blaze the trail', 'break ground', 'clear the way', 'court', 'create', 'cultivate', 'cultivate the soil', 'go in advance', 'head', 'head up', 'initiate'],
    'break the law': ['breach the law', 'care naught for', 'circumvent the law', 'commit a crime', 'contravene', 'defy', 'disobey', 'disobey the law', 'disregard', 'disregard the law', 'flout', 'go counter to'],
    'break the news': ['air', 'announce', 'break it to', 'breathe', 'bring word', 'come out with', 'confide', 'confide to', 'divulgate', 'divulge', 'evulgate', 'give a report'],
    'break through': ['achieve success', 'advance', 'arrive', 'be a success', 'breach', 'break in', 'break into', 'break open', 'break out', 'burst in', 'bust in', 'cave in'],
    'break up': ['ablate', 'accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'amuse', 'analyze', 'anatomize', 'assay', 'atomize', 'be in stitches'],
    'breakable': ['brittle', 'brittle as glass', 'cheap-jack', 'cobwebby', 'crackable', 'crisp', 'crispy', 'crumbly', 'crushable', 'dainty', 'delicate', 'delicately weak'],
    'breakage': ['abatement', 'agio', 'allowance', 'bank discount', 'bankruptcy', 'breach', 'break', 'breakdown', 'burst', 'cash discount', 'chain discount', 'charge-off'],
    'breakaway': ['bohemian', 'abjuratory', 'alienated', 'antagonistic', 'antiestablishment', 'antipathetic', 'apostasy', 'at odds with', 'at variance with', 'backsliding', 'beat', 'betrayal'],
    'breakdown': ['analysis', 'analyzation', 'anatomizing', 'anatomy', 'assay', 'assaying', 'bankruptcy', 'bloodless revolution', 'bouleversement', 'breakage', 'breaking down', 'breaking up'],
    'breaker': ['analyzer', 'billow', 'bore', 'breakers', 'breeder', 'broncobuster', 'buckaroo', 'cattleman', 'centrifuge', 'chop', 'choppiness', 'chopping sea'],
    'breakfast': ['tv dinner', 'alfresco meal', 'barbecue', 'brunch', 'buffet supper', 'clambake', 'coffee break', 'cookout', 'diner', 'dinner', 'elevenses', 'fish fry'],
    'breaking point': ['bloat', 'bloating', 'distension', 'extreme tension', 'inflation', 'overdistension', 'overdrawing', 'overexpansion', 'overextension', 'overstrain', 'overstraining', 'overstretching'],
    'breakneck': ['abrupt', 'accident-prone', 'agile', 'bluff', 'bold', 'breathless', 'careless', 'dangerous', 'daredevil', 'dashing', 'desperate', 'devil-may-care'],
    'breakout': ['break', 'deliverance', 'delivery', 'emergence', 'escape', 'escapism', 'evasion', 'extrication', 'flight', 'freeing', 'getaway', 'issuance'],
    'breaks': ['accidentality', 'actuarial calculation', 'adventitiousness', 'blessing', 'break', 'casualness', 'chance', 'destiny', 'fate', 'felicity', 'flukiness', 'fortuitousness'],
    'breakthrough': ['aggravated assault', 'aggression', 'amphibious attack', 'armed assault', 'assailing', 'assailment', 'assault', 'attack', 'avant-propos', 'banzai attack', 'blitz', 'blitzkrieg'],
    'breakup': ['ablation', 'analysis', 'analyzation', 'anatomizing', 'anatomy', 'apoplexy', 'assay', 'assaying', 'atomization', 'biodegradability', 'biodegradation', 'bloodbath'],
    'breakwater': ['abutment', 'anchorage', 'anchorage ground', 'arc-boutant', 'arch dam', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier', 'basin'],
    'breast': ['chateaubriand', 'affront', 'antagonize', 'bag', 'ballocks', 'balls', 'basket', 'battle', 'beard', 'beat against', 'beat up against', 'being'],
    'breastwork': ['abatis', 'advanced work', 'arch dam', 'backstop', 'balistraria', 'bamboo curtain', 'bank', 'banquette', 'bar', 'barbed-wire entanglement', 'barbican', 'barrage'],
    'breath': ['aqua-lung', 'a breath', 'afterdamp', 'amaze', 'anima', 'anima humana', 'animating force', 'aroma', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'astonish'],
    'breathe': ['he', 'affect', 'air', 'alert', 'approve', 'argue', 'articulate', 'aspirate', 'attest', 'bark', 'bawl', 'be'],
    'breather': ['athletics', 'blow', 'break', 'breath', 'breathing place', 'breathing space', 'breathing spell', 'breathing time', 'calisthenics', 'cigarette break', 'cocktail hour', 'coffee break'],
    'breathless': ['ablaze', 'abrupt', 'afire', 'agape', 'aghast', 'agog', 'airless', 'alacritous', 'all agog', 'amazed', 'anaudic', 'animated'],
    'breathtaking': ['agitating', 'amazing', 'astonishing', 'astounding', 'charged', 'cliff-hanging', 'confounding', 'disquieting', 'distracting', 'disturbing', 'electric', 'exciting'],
    'breathy': ['blurred', 'choked', 'choking', 'croaking', 'drawling', 'drawly', 'dysphonic', 'guttural', 'harsh', 'hawking', 'hoarse', 'inarticulate'],
    'breccia': ['aa', 'abyssal rock', 'agglomerate', 'agglomeration', 'basalt', 'bedrock', 'block lava', 'brash', 'bunch', 'clot', 'cluster', 'concrete'],
    'breech': ['afterpart', 'afterpiece', 'back', 'back door', 'back seat', 'back side', 'backside', 'bed', 'bedrock', 'behind', 'belly', 'bottom'],
    'breeching': ['back band', 'backstrap', 'bearing rein', 'bellyband', 'bit', 'blinders', 'blinds', 'bridle', 'caparison', 'cavesson', 'checkrein', 'cheekpiece'],
    'breed': ['accrue', 'accumulate', 'advance', 'affiliation', 'animal kingdom', 'apparentation', 'appear', 'appreciate', 'apprentice', 'arise', 'author', 'balloon'],
    'breeder': ['atomic pile', 'breaker', 'breeder reactor', 'bricks', 'broncobuster', 'buckaroo', 'cattleman', 'chain reactor', 'chain-reacting pile', 'cow keeper', 'cowman', 'dairy farmer'],
    'breeding': ['alpha decay', 'animal husbandry', 'animal rearing', 'apprenticeship', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction', 'atomization', 'basic training', 'bee culture', 'beekeeping'],
    'breeze': ['air', 'ball the jack', 'barrel', 'blast', 'blow', 'blow a hurricane', 'blow great guns', 'blow over', 'blow up', 'blubber', 'bluster', 'boom'],
    'breeze in': ['admit', 'barge in', 'be admitted', 'break in', 'burst in', 'bust in', 'come barging in', 'come breezing in', 'come busting in', 'come in', 'creep in', 'cross the threshold'],
    'breezy': ['active', 'activist', 'activistic', 'aeolian', 'aerial', 'aeriform', 'aery', 'airish', 'airlike', 'airy', 'alfresco', 'alive'],
    'brethren': ['assembly', 'aunt', 'auntie', 'blood brother', 'brother', 'bub', 'bubba', 'bud', 'buddy', 'churchgoers', 'class', 'congregation'],
    'brevet': ['agency', 'agentship', 'appointment', 'assignment', 'authority', 'authorization', 'bull', 'care', 'charge', 'charter', 'commission', 'commissioning'],
    'brevity': ['brachylogy', 'briefness', 'brusqueness', 'compactness', 'compendiousness', 'conciseness', 'concision', 'crispness', 'curtness', 'dumbness', 'economy', 'economy of words'],
    'brew': ['john barleycorn', 'pilsner', 'alcohol', 'alcoholic beverage', 'alcoholic drink', 'ale', 'angle', 'approach', 'aqua vitae', 'ardent spirits', 'await', 'bake'],
    'brewery': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery', 'bottling works', 'brickyard', 'cannery'],
    'brewing': ['about to be', 'already in sight', 'approaching', 'at hand', 'baking', 'barbecuing', 'basting', 'boiling', 'braising', 'broil', 'broiling', 'catering'],
    'briar': ['adherent', 'adhesive', 'barnacle', 'bramble', 'brier', 'brier bush', 'bristle', 'bulldog', 'burr', 'bush', 'cactus', 'catchweed'],
    'bribe': ['trinkgeld', 'approach', 'bait', 'bonus', 'boodle', 'bounty', 'bribe money', 'buy', 'buy off', 'carrot', 'consideration', 'corrupt'],
    'bric-a-brac': ['art object', 'bauble', 'bibelot', 'brainchild', 'chaff', 'chicken feed', 'chickenshit', 'classic', 'composition', 'creation', 'design', 'details'],
    'brick': ['tarmac', 'tarvia', 'adamant', 'adobe', 'ashlar', 'asphalt', 'biscuit', 'bisque', 'bitumen', 'bituminous macadam', 'blacktop', 'block'],
    'brickbat': ['irish confetti', 'affront', 'aspersion', 'atrocity', 'bola', 'bolt', 'boomerang', 'contempt', 'contumely', 'countermissile', 'cut', 'despite'],
    'bridge': ['a string', 'amati', 'bifrost', 'boston', 'cremona', 'd string', 'e string', 'earl of coventry', 'g string', 'pit', 'polish bank', 'russian bank'],
    'bridgehead': ['acropolis', 'advance guard', 'airhead', 'avant-garde', 'bastion', 'battle line', 'beachhead', 'blockhouse', 'bunker', 'castle', 'citadel', 'donjon'],
    'bridle': ['oregon boat', 'anchor', 'anger', 'arrest', 'back band', 'backstrap', 'bearing rein', 'bed', 'bed down', 'bellyband', 'bilbo', 'bind'],
    'brief': ['spartan', 'abbreviated', 'abbreviation', 'abbreviature', 'abrege', 'abridge', 'abridged', 'abridgment', 'abrupt', 'abstract', 'account', 'account rendered'],
    'briefed': ['abreast of', 'all ready', 'all set', 'armed', 'armed and ready', 'au courant', 'booted and spurred', 'coached', 'cocked', 'educated', 'enlightened', 'equipped'],
    'briefing': ['account', 'acquaintance', 'admonition', 'advice', 'advising', 'advocacy', 'airmanship', 'announcement', 'appointment', 'arrangement', 'basic training', 'bespeaking'],
    'briefly': ['accurately', 'aphoristically', 'bluntly', 'brusquely', 'compendiously', 'concisely', 'crisply', 'curtly', 'economically', 'exactly', 'fleetingly', 'flickeringly'],
    'brier': ['adherent', 'adhesive', 'barnacle', 'bramble', 'brier bush', 'bristle', 'bulldog', 'burr', 'bush', 'cactus', 'catchweed', 'cement'],
    'brig': ['pow camp', 'bastille', 'black hole', 'borstal', 'borstal institution', 'bridewell', 'calaboose', 'can', 'cell', 'clink', 'concentration camp', 'condemned cell'],
    'brigade': ['kp', 'age group', 'army', 'army group', 'band', 'battalion', 'battery', 'battle group', 'bevy', 'body', 'bunch', 'cabal'],
    'brigadier': ['adc', 'co', 'od', 'aide', 'aide-de-camp', 'brigadier general', 'captain', 'chicken colonel', 'chief of staff', 'colonel', 'commandant', 'commander'],
    'bright': ['leibnizian', 'saturnian', 'adroit', 'advanced', 'agile', 'aglow', 'alert', 'alight', 'alive', 'animate', 'animated', 'apt'],
    'brighten': ['animate', 'beacon', 'boost', 'break', 'brighten up', 'buoy up', 'burnish', 'cheer', 'cheer up', 'dawn', 'encourage', 'enlighten'],
    'brightness': ['munsell chroma', 'technicolor', 'acuity', 'acuteness', 'adroitness', 'agility', 'alertness', 'aptitude', 'aptness', 'attention', 'attentiveness', 'auspiciousness'],
    'brilliance': ['babylonian splendor', 'technicolor', 'ability', 'acuity', 'acuteness', 'address', 'adeptness', 'adroitness', 'airmanship', 'aptitude', 'aptness', 'artfulness'],
    'brilliant': ['attic', 'daedalian', 'able', 'accomplished', 'adept', 'adroit', 'apt', 'artistic', 'authoritative', 'beaming', 'beautiful', 'bedazzling'],
    'brim': ['bank', 'board', 'border', 'bordure', 'brink', 'brow', 'coast', 'edge', 'featheredge', 'flange', 'frame', 'fringe'],
    'brimming': ['sro', 'awash', 'brimful', 'bulging', 'bursting', 'capacity', 'chock-full', 'chuck-full', 'congested', 'cram-full', 'crammed', 'crowded'],
    'brindle': ['banded', 'barred', 'brinded', 'brindled', 'listed', 'marbled', 'marbleized', 'streaked', 'streaky', 'striatal', 'striate', 'striated'],
    'bring': ['accompany', 'accomplish', 'achieve', 'advance', 'affect', 'afford', 'allure', 'amount to', 'assume', 'attend', 'attract', 'be sold'],
    'bring about': ['about ship', 'accomplish', 'achieve', 'act', 'author', 'back and fill', 'be productive', 'bear', 'bear away', 'bear off', 'bear to starboard', 'beat'],
    'bring back': ['bring', 'bring to', 'bring to mind', 'call back', 'call for', 'call to mind', 'call up', 'chase after', 'conjure up', 'evoke', 'extradite', 'fetch'],
    'bring before': ['advance', 'affront', 'brave', 'breast', 'bring forward', 'bring up', 'broach', 'challenge', 'commend to attention', 'confront', 'confront with', 'dare'],
    'bring charges': ['accuse', 'allege', 'arraign', 'article', 'book', 'bring accusation', 'bring to book', 'charge', 'cite', 'complain', 'denounce', 'denunciate'],
    'bring down': ['abase', 'abash', 'acquire', 'be responsible for', 'beat down', 'belittle', 'blow down', 'blow over', 'blow to pieces', 'blow up', 'bowl down', 'bowl over'],
    'bring forth': ['affect', 'arouse', 'author', 'bear', 'bear fruit', 'beget', 'betoken', 'birth', 'born', 'brandish', 'breathe', 'breed'],
    'bring forward': ['acculturate', 'adduce', 'advance', 'affect', 'affront', 'allege', 'ameliorate', 'amend', 'array', 'betoken', 'better', 'boost'],
    'bring home to': ['account for', 'accredit with', 'accrete to', 'accuse of', 'acknowledge', 'afford proof of', 'anathematize', 'apply to', 'ascertain', 'ascribe to', 'assign to', 'assure'],
    'bring in': ['acquire', 'afford', 'amount to', 'bring', 'come to', 'come up to', 'cost', 'crop', 'crop herbs', 'cut', 'dig', 'drag down'],
    'bring off': ['accomplish', 'achieve', 'bring about', 'bring through', 'bring to effect', 'bring to pass', 'carry into effect', 'carry into execution', 'carry off', 'carry out', 'carry through', 'come through'],
    'bring on': ['acquire', 'adduce', 'advance', 'allege', 'array', 'be responsible for', 'bring', 'bring down', 'bring forward', 'bring to bear', 'bring upon', 'call forth'],
    'bring out': ['affect', 'arouse', 'betoken', 'brandish', 'breathe', 'bring forth', 'bring forward', 'bring into view', 'bring to light', 'bring to notice', 'call forth', 'call out'],
    'bring round': ['about ship', 'argue into', 'assure', 'back and fill', 'be convincing', 'bear away', 'bear off', 'bear to starboard', 'beat', 'beat about', 'box off', 'break'],
    'bring to': ['arrest', 'assimilate to', 'become', 'block', 'brake', 'bring back', 'bring up short', 'call back', 'change', 'change into', 'change over', 'check'],
    'bring to light': ['arouse', 'bare', 'break the seal', 'bring forth', 'bring out', 'call forth', 'call out', 'call up', 'deduce', 'derive', 'develop', 'dig up'],
    'bring to mind': ['allegorize', 'allude to', 'ape', 'appear like', 'approach', 'approximate', 'assume', 'be like', 'be redolent of', 'bear resemblance', 'bring back', 'call back'],
    'bring to pass': ['accomplish', 'achieve', 'author', 'bear', 'beget', 'breed', 'bring about', 'bring forth', 'bring off', 'bring to effect', 'carry into execution', 'carry off'],
    'bring up': ['advance', 'advert', 'affront', 'allude', 'apprentice', 'barf', 'be seasick', 'be sick', 'brave', 'break', 'break in', 'breast'],
    'brink': ['bank', 'board', 'border', 'bordure', 'brim', 'brow', 'coast', 'edge', 'featheredge', 'flange', 'frame', 'fringe'],
    'brinkmanship': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'adventurousness', 'appeasement', 'audaciousness', 'audacity', 'balance of power', 'boldness', 'coexistence', 'colonialism'],
    'brio': ['activity', 'animation', 'ardor', 'briskness', 'dash', 'elan', 'enthusiasm', 'esprit', 'glow', 'gusto', 'impetuosity', 'impetus'],
    'brisk': ['siberian', 'active', 'activist', 'activistic', 'acute', 'adroit', 'aeolian', 'aggressive', 'airish', 'airy', 'algid', 'alive'],
    'bristle': ['vandyke', 'acuminate', 'aggravate', 'anger', 'annoy', 'arise', 'arouse', 'badger', 'bait', 'barb', 'barbel', 'be alive'],
    'bristle with': ['abound', 'abound with', 'be alive with', 'burst with', 'clutter', 'crawl with', 'creep with', 'crowd', 'exuberate', 'flow', 'gush', 'jam'],
    'bristling': ['alive with', 'barbellate', 'bristled', 'bristly', 'bursting', 'close', 'compact', 'crammed', 'crawling', 'crowded', 'crowding', 'dense'],
    'bristly': ['acanaceous', 'aculeolate', 'barbellate', 'brambly', 'briery', 'bristled', 'bristling', 'bushy', 'cirrose', 'fleecy', 'flocculent', 'furry'],
    'brittle': ['atrophied', 'breakable', 'brittle as glass', 'capricious', 'changeable', 'cheap-jack', 'cobwebby', 'corruptible', 'crackable', 'crisp', 'crispy', 'crumbly'],
    'broach': ['advance', 'air', 'auger', 'bite', 'bleed', 'blue', 'bore', 'bring before', 'bring forward', 'bring in', 'bring up', 'chink'],
    'broad': ['jane', 'jezebel', 'abstract', 'accented', 'aleatoric', 'aleatory', 'alveolar', 'amorphous', 'ample', 'amplitudinous', 'apical', 'apico-alveolar'],
    'broad minded': ['advanced', 'broad', 'broad-gauged', 'catholic', 'cosmopolitan', 'deep', 'ecumenical', 'ecumenistic', 'freethinking', 'knowing', 'latitudinarian', 'learned'],
    'broad shouldered': ['able-bodied', 'athletic', 'brawny', 'burly', 'hairychested', 'he-mannish', 'macho', 'muscle-bound', 'muscular', 'potent', 'sinewy', 'thewy'],
    'broadcast': ['accessible', 'advertise', 'advertisement', 'affirmed', 'air', 'airing', 'announce', 'announced', 'announcement', 'annunciate', 'attenuation', 'bandying'],
    'broadcasting': ['fcc', 'fm broadcasting', 'airing', 'attenuation', 'bandying', 'book', 'broadcast', 'bruiting', 'bruiting about', 'circulation', 'circumfusion', 'diffraction'],
    'broaden': ['accrue', 'accumulate', 'add to', 'advance', 'aggrandize', 'amplify', 'appreciate', 'augment', 'balloon', 'bloat', 'blow up', 'boom'],
    'broadly': ['abroad', 'absurdly', 'all in all', 'all joking aside', 'all things considered', 'altogether', 'amusingly', 'as a rule', 'as a whole', 'as an approximation', 'at large', 'bizarrely'],
    'broadside': ['antiaircraft barrage', 'aside', 'askance', 'askant', 'asquint', 'bank', 'barrage', 'beam', 'bombardment', 'border', 'box barrage', 'breadthwise'],
    'broadway': ['burlesque', 'carnival', 'circus', 'drama', 'entertainment industry', 'legit', 'legitimate stage', 'off broadway', 'off-off-broadway', 'playland', 'repertory drama', 'show biz'],
    'broil': ['ado', 'affray', 'agitation', 'altercate', 'altercation', 'argument', 'bake', 'baking', 'barbecue', 'barbecuing', 'baste', 'basting'],
    'broiler': ['bantam', 'cornish hen', 'dutch oven', 'alcohol stove', 'baker', 'banty', 'barbecue', 'barn-door fowl', 'barnyard fowl', 'biddy', 'boiler', 'brooder'],
    'broke': ['bankrupt', 'beat', 'beggared', 'broken', 'busted', 'dead', 'destitute', 'down-and-out', 'failed', 'flat', 'flat broke', 'hard up'],
    'broken': ['aggravated', 'aloof', 'ausgespielt', 'bankrupt', 'beaten', 'blasted', 'blighted', 'broke', 'broken off', 'broken-down', 'brought low', 'bumpy'],
    'broken down': ['battered', 'beat-up', 'beaten up', 'brokenhearted', 'crushed', 'cut up', 'decrepit', 'derelict', 'desolated', 'dilapidated', 'dingy', 'heart-stricken'],
    'broken heart': ['aching heart', 'agony', 'agony of mind', 'anguish', 'bale', 'bitterness', 'bleeding heart', 'brokenheartedness', 'crushing', 'depression', 'depth of misery', 'desolation'],
    'broken off': ['broken', 'chopped-off', 'choppy', 'decousu', 'disconnected', 'discontinued', 'discontinuous', 'discrete', 'disjunctive', 'episodic', 'fitful', 'herky-jerky'],
    'broken-hearted': ['cheerless', 'crushed', 'dejected', 'depressed', 'devastated', 'disconsolate', 'doleful', 'dolorous', 'down', 'downcast', 'downhearted', 'forlorn'],
    'broker': ['realtor', 'wall streeter', 'agent', 'arbitrator', 'bill broker', 'bond crowd', 'cambist', 'connection', 'contact', 'cotton broker', 'curb broker', 'dealer'],
    'brokerage': ['admission', 'admission fee', 'agency', 'anchorage', 'barter', 'bartering', 'boiler room', 'brokerage house', 'brokerage office', 'bucket shop', 'buying and selling', 'carfare'],
    'bromide': ['abstraction', 'banality', 'chestnut', 'cliche', 'commonplace', 'commonplace expression', 'corn', 'familiar tune', 'general idea', 'generalization', 'generalized proposition', 'glittering generality'],
    'bronchitis': ['asiatic flu', 'hong kong flu', 'acute bronchitis', 'adenoiditis', 'adrenitis', 'aluminosis', 'amygdalitis', 'anthracosilicosis', 'anthracosis', 'appendicitis', 'arteritis', 'arthritis deformans'],
    'broncobuster': ['breaker', 'breeder', 'buckaroo', 'caballero', 'cattleman', 'cavalier', 'cavalryman', 'chevalier', 'circus rider', 'cow keeper', 'cowboy', 'cowgirl'],
    'bronze': ['titian', 'adust', 'auburn', 'aureate', 'bay', 'bay-colored', 'bayard', 'brass', 'brassy', 'brazen', 'bronze-colored', 'bronzed'],
    'brooch': ['anklet', 'armlet', 'bangle', 'beads', 'bijou', 'bracelet', 'breastpin', 'broach', 'chain', 'chaplet', 'charm', 'chatelaine'],
    'brood': ['agonize', 'animal kingdom', 'be abstracted', 'be gravid', 'be knocked up', 'be pregnant', 'be with child', 'blood', 'breed', 'carry', 'carry young', 'chew the cud'],
    'brood mare': ['houyhnhnm', 'partlet', 'biddy', 'bitch', 'bossy', 'charger', 'colt', 'courser', 'cow', 'critter', 'dobbin', 'doe'],
    'brood over': ['ache', 'agonize', 'bear in mind', 'bleed', 'breathe vengeance', 'cherish', 'chew over', 'con over', 'deliberate over', 'deliberate upon', 'digest', 'dwell on'],
    'brooder': ['bantam', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'birthplace', 'breeding place', 'broiler', 'broody hen', 'capon', 'chanticleer', 'chick'],
    'brook': ['abide', 'abide with', 'accept', 'adolescent stream', 'allow', 'arroyo', 'be big', 'be content with', 'be easy with', 'bear', 'bear with', 'beck'],
    'broom': ['autoclave', 'brush', 'carpet sweeper', 'comb', 'currycomb', 'dishcloth', 'dishwasher', 'doormat', 'duster', 'dustpan', 'facecloth', 'hackle'],
    'broth': ['bisque', 'borscht', 'bouillabaisse', 'bouillon', 'burgoo', 'chicken soup', 'chowder', 'clam chowder', 'clear soup', 'consomme', 'decoction', 'egg drop soup'],
    'brothel': ['babylon', 'gomorrah', 'sodom', 'bagnio', 'bawdy house', 'bawdyhouse', 'bordello', 'cathouse', 'clip joint', 'crib', 'den', 'den of iniquity'],
    'brother': ['greek', 'abbacomes', 'abbot', 'acquaintance', 'adjunct', 'advocate', 'affiliate', 'ally', 'alter ego', 'analogon', 'analogue', 'ascetic'],
    'brotherhood': ['affectionateness', 'affiliation', 'agnation', 'alliance', 'ancestry', 'association', 'benignancy', 'benignity', 'blood', 'blood relationship', 'boon companionship', 'brotherliness'],
    'brotherly': ['christian', 'christlike', 'christly', 'affectionate', 'agreeable', 'amiable', 'amicable', 'benign', 'benignant', 'compassionate', 'congenial', 'cordial'],
    'brotherly love': ['amor', 'bomfog', 'benthamism', 'christian charity', 'christian love', 'eros', 'platonic love', 'accord', 'accordance', 'admiration', 'adoration', 'affection'],
    'brouhaha': ['bedlam let loose', 'ado', 'agitation', 'babel', 'bedlam', 'blast', 'bluster', 'bobbery', 'boil', 'boiling', 'bother', 'brawl'],
    'brow': ['acme', 'air', 'apex', 'apogee', 'bank', 'bean', 'bearing', 'board', 'border', 'bordure', 'brim', 'brink'],
    'browbeat': ['badger', 'beat down', 'bludgeon', 'bluster', 'bluster out of', 'bounce', 'break', 'bulldoze', 'bully', 'bullyrag', 'castrate', 'clamp down on'],
    'brown': ['argos brown', 'bordeaux', 'cologne brown', 'mexican red', 'roman umber', 'saint benoit', 'turkey umber', 'acorn', 'alesan', 'alizarin brown', 'anthracene brown', 'anthragallol'],
    'brown nose': ['apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bootlick', 'bootlicker', 'brownie', 'clawback', 'courtier', 'creature', 'cringer', 'dupe'],
    'brown study': ['walter mitty', 'absence of mind', 'absentmindedness', 'absorption', 'abstractedness', 'abstraction', 'bad dream', 'bemusement', 'castle-building', 'close study', 'concentration', 'contemplativeness'],
    'browned off': ['aggravated', 'angered', 'angry', 'annoyed', 'bothered', 'bugged', 'burnt-up', 'chafed', 'cross', 'disturbed', 'exasperated', 'galled'],
    'brownie': ['ariel', 'befind', 'corrigan', 'finnbeara', 'lilliputian', 'mab', 'oberon', 'titania', 'tom thumb', 'apple-polisher', 'ass-licker', 'backscratcher'],
    'browse': ['batten upon', 'crop', 'dip into', 'fatten on', 'fatten upon', 'feast on', 'feast upon', 'feed on', 'flip through', 'glance at', 'glance over', 'glance through'],
    'bruise': ['abrasion', 'abuse', 'aggrieve', 'anguish', 'barb the dart', 'bash', 'batter', 'beat', 'beat up', 'black', 'black eye', 'black-and-blue mark'],
    'bruiser': ['chinese boxer', 'bantamweight', 'black belt', 'bodyguard', 'bouncer', 'boxer', 'brown belt', 'enforcer', 'featherweight', 'fighter', 'fisticuffer', 'flyweight'],
    'brumal': ['siberian', 'aestival', 'algid', 'arctic', 'autumn', 'autumnal', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'boreal'],
    'brunch': ['tv dinner', 'alfresco meal', 'barbecue', 'breakfast', 'buffet supper', 'clambake', 'coffee break', 'cookout', 'diner', 'dinner', 'elevenses', 'fish fry'],
    'brunet': ['ash blond', 'auburn-haired', 'beige', 'black-haired', 'black-locked', 'bleached blond', 'blond', 'brown', 'brown-haired', 'brownish', 'brownish-yellow', 'carrottop'],
    'brunt': ['appulse', 'bulldozing', 'bulling', 'bump', 'burden', 'cannon', 'carambole', 'carom', 'clash', 'collision', 'concussion', 'crack-up'],
    'brush': ['arabia deserta', 'death valley', 'sahara', 'action', 'aerial combat', 'affray', 'air brush', 'air-dry', 'anhydrate', 'armored combat', 'art paper', 'attouchement'],
    'brush aside': ['abandon', 'abjure', 'brush off', 'chuck', 'chuck out', 'contemn', 'contradict', 'decline', 'deny', 'despise', 'disapprove', 'discard'],
    'brush off': ['abandon', 'beat back', 'broom', 'brush', 'brush aside', 'chase', 'chase away', 'chase off', 'cold shoulder', 'cut', 'dismiss', 'dismissal'],
    'brush up': ['bone up', 'brighten up', 'cram', 'cram up', 'dress', 'fettle', 'fix', 'freshen', 'furbish', 'furbish up', 'get up', 'get up on'],
    'brusque': ['spartan', 'abbreviated', 'abridged', 'abrupt', 'aggressive', 'aposiopestic', 'artless', 'bearish', 'beastly', 'bluff', 'blunt', 'brash'],
    'brutal': ['adamic', 'circean', 'draconian', 'gothic', 'herculean', 'neanderthal', 'tartarean', 'abominable', 'abstruse', 'animal', 'animalian', 'animalic'],
    'brutality': ['adam', 'gothicism', 'neanderthalism', 'abominableness', 'acuteness', 'animalism', 'animality', 'atrociousness', 'atrocity', 'awfulness', 'barbarism', 'barbarity'],
    'brutalize': ['assault', 'attack', 'barbarize', 'bastardize', 'batter', 'burn', 'butcher', 'callous', 'carry on', 'case harden', 'corrupt', 'debauch'],
    'brute': ['adamic', 'circean', 'draconian', 'goth', 'mafioso', 'neanderthal', 'tartarean', 'young turk', 'animal', 'animalian', 'animalic', 'animalistic'],
    'brute force': ['amperage', 'armipotence', 'authority', 'beef', 'big battalions', 'black power', 'charge', 'charisma', 'clout', 'cogence', 'cogency', 'compulsion'],
    'bub': ['aunt', 'auntie', 'blood brother', 'boy', 'brethren', 'brother', 'bubba', 'buck', 'bud', 'buddy', 'colt', 'country cousin'],
    'bubble': ['air', 'air pocket', 'airy hope', 'airy nothing', 'apparition', 'autism', 'babble', 'ball', 'balloon', 'be enthusiastic', 'bilge', 'bladder'],
    'bubbly': ['active', 'activist', 'activistic', 'airy', 'alive', 'animated', 'beaten', 'blebby', 'blistered', 'blistering', 'blistery', 'bouncing'],
    'buccaneer': ['ab', 'ancient mariner', 'argonaut', 'blackbeard', 'captain hook', 'captain kidd', 'dylan', 'flying dutchman', 'henry morgan', 'jean lafitte', 'neptune', 'od'],
    'buck': ['beau brummel', 'belgian hare', 'cape elk', 'highland fling', 'virginia deer', 'and jump', 'antagonize', 'antelope', 'assault', 'battle', 'bear', 'bear upon'],
    'buck fever': ['agitation', 'apprehensiveness', 'attack of nerves', 'case of nerves', 'excessive irritability', 'fear', 'fidgetiness', 'fidgets', 'morbid excitability', 'nerves', 'nervosity', 'nervous stomach'],
    'buck up': ['animate', 'assure', 'bolster', 'brace', 'brace up', 'brighten up', 'brisk', 'brisken', 'cheer', 'cheer up', 'chirk up', 'console'],
    'buckaroo': ['breaker', 'breeder', 'broncobuster', 'caballero', 'cattleman', 'cavalier', 'cavalryman', 'chevalier', 'circus rider', 'cow keeper', 'cowboy', 'cowgirl'],
    'bucket': ['argosy', 'bail', 'bark', 'barrel', 'be caught short', 'be short', 'belong', 'boat', 'bottom', 'bucketshop', 'calaboose', 'can'],
    'bucket shop': ['barroom', 'boiler room', 'boozer', 'brokerage', 'brokerage house', 'brokerage office', 'bunco game', 'con game', 'confidence game', 'drinkery', 'fall to', 'goldbrick'],
    'buckle': ['anamorphism', 'anamorphosis', 'articulate', 'asymmetry', 'batten', 'batten down', 'bend', 'bolt', 'bulge', 'butt', 'button', 'catch'],
    'buckle down': ['be determined', 'be in earnest', 'be resolved', 'buckle to', 'cross the rubicon', 'die fighting', 'die hard', 'endeavor', 'go all out', 'go for broke', 'hump', 'hump it'],
    'buckshot': ['ball', 'bar shot', 'bird shot', 'bullet', 'cannon shot', 'cannonball', 'case shot', 'crossbar shot', 'duck shot', 'dumdum bullet', 'expanding bullet', 'grape'],
    'buckskin': ['australian seal', 'bay', 'bayard', 'bearskin', 'beaver', 'beaverette', 'black fox', 'black marten', 'black sable', 'brook mink', 'calf', 'calfskin'],
    'bucolic': ['alcaic', 'anacreontic', 'arcadian', 'castalian', 'english sonnet', 'homeric', 'horatian ode', 'hudibrastic', 'italian sonnet', 'petrarchan sonnet', 'pierian', 'pindaric'],
    'bud': ['anlage', 'acrospire', 'aunt', 'auntie', 'blood brother', 'boy', 'brethren', 'brother', 'bub', 'bubba', 'buck', 'buddy'],
    'buddha': ['confucius', 'gandhi', 'jagannath', 'juggernaut', 'kurma', 'mahavira', 'matsya', 'mentor', 'muhammad', 'narsinh', 'nestor', 'parshuram'],
    'budding': ['abecedarian', 'aboriginal', 'antenatal', 'autochthonous', 'beginning', 'blooming', 'blossoming', 'burgeoning', 'callow', 'creative', 'crescent', 'developed'],
    'buddy': ['ace', 'amigo', 'associate', 'aunt', 'auntie', 'bedfellow', 'bedmate', 'benchfellow', 'birthmate', 'blood brother', 'bosom buddy', 'boy'],
    'budge': ['advance', 'alcohol', 'aqua vitae', 'ascend', 'back', 'back up', 'booze', 'change', 'change place', 'circle', 'climb', 'descend'],
    'budget': ['swiss bank account', 'abundance', 'accounts', 'accounts payable', 'accounts receivable', 'accumulation', 'agenda', 'aggregate', 'allotment', 'allowance', 'amassment', 'amount'],
    'buff': ['leatherette', 'leatheroid', 'maecenas', 'abettor', 'adherent', 'admirer', 'advocate', 'aficionado', 'amateur', 'angel', 'apologist', 'appendage'],
    'buffalo': ['brahman', 'indian buffalo', 'addle', 'amaze', 'aurochs', 'baffle', 'balk', 'bamboozle', 'beat', 'beef', 'beef cattle', 'beeves'],
    'buffer': ['t square', 'aegis', 'annul', 'antacid', 'antidote', 'arch dam', 'arm guard', 'awl', 'backstop', 'bale breaker', 'bamboo curtain', 'bank'],
    'buffer state': ['ally', 'archduchy', 'archdukedom', 'barrier', 'body politic', 'brattice', 'buffer', 'bulkhead', 'bumper', 'captive nation', 'chieftaincy', 'chieftainry'],
    'buffet': ['abuse', 'agonize', 'ambo', 'antagonize', 'automat', 'bafflement', 'balk', 'bang', 'bar', 'bash', 'baste', 'bastinado'],
    'buffoon': ['columbine', 'hanswurst', 'harlequin', 'pantalone', 'pantaloon', 'polichinelle', 'pulcinella', 'punch', 'punchinello', 'scaramouch', 'ass', 'bad boy'],
    'buffoonery': ['acting', 'asininity', 'banter', 'battiness', 'brainlessness', 'business', 'characterization', 'clownishness', 'crackpottedness', 'crankiness', 'craziness', 'daffiness'],
    'bug': ['algol', 'cobol', 'fortran', 'mumbo jumbo', 'abrade', 'addict', 'addle', 'addle the wits', 'adenovirus', 'aerobe', 'aerobic bacteria', 'aficionado'],
    'bug eyed': ['bellied', 'bulged', 'cockeyed', 'cross-eyed', 'exophthalmic', 'glare-eyed', 'goggle', 'goggled', 'monocular', 'moon-eyed', 'one-eyed', 'popeyed'],
    'bugbear': ['dracula', 'frankenstein', 'mumbo jumbo', 'wolf-man', 'affliction', 'anathema', 'bane', 'bete noire', 'bogey', 'bogeyman', 'boggart', 'bogle'],
    'bugger': ['mumbo jumbo', 'sob', 'bad boy', 'ball up', 'bastard', 'beat it', 'bird', 'bitch', 'bitch up', 'bloke', 'bobble', 'bogey'],
    'buggy': ['auto', 'autocar', 'automobile', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bedlamite', 'boat', 'bonkers'],
    'bughouse': ['asylum', 'batty', 'bedlam', 'bedlamite', 'buggy', 'bugs', 'cracked', 'crazed', 'crazy', 'crazy house', 'daft', 'demented'],
    'bugle': ['alpenhorn', 'alphorn', 'althorn', 'alto horn', 'antlia', 'bagpipe', 'ballad horn', 'baritone', 'bass horn', 'bay', 'beak', 'beep'],
    'bugle call': ['angelus', 'angelus bell', 'alarm', 'alarum', 'battle cry', 'birdcall', 'call', 'call to arms', 'call-up', 'catchword', 'clarion', 'clarion call'],
    'bugs': ['ape about', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bedlamite', 'bonkers', 'buggy', 'bughouse', 'bugs on'],
    'build': ['platonic form', 'platonic idea', 'add to', 'aesthetic form', 'aggrandize', 'amplify', 'anatomy', 'archetype', 'architectonics', 'architecture', 'arrangement', 'art form'],
    'build up': ['add to', 'advertise', 'agent provocateur', 'aggrandize', 'aggravate', 'amplify', 'annoy', 'assemble', 'augment', 'ballyhoo', 'bark', 'bill'],
    'builder': ['ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'barber', 'beautician', 'begetter', 'beginner', 'brazier', 'bricklayer'],
    'building': ['dymaxion house', 'white house', 'adobe house', 'anatomy', 'architectonics', 'architecture', 'arrangement', 'assemblage', 'assembly', 'build', 'buildup', 'casa'],
    'building block': ['air', 'atom', 'atomic particles', 'atoms', 'brute matter', 'chemical element', 'component', 'constituent', 'core', 'distillate', 'distillation', 'earth'],
    'buildup': ['access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'acknowledgment', 'addition', 'advance', 'advertising', 'advocacy', 'advocating'],
    'built': ['junoesque', 'agreeable', 'amply endowed', 'assembled', 'becoming', 'bonny', 'braw', 'built for comfort', 'buxom', 'callipygian', 'callipygous', 'cast'],
    'bulb': ['ball', 'balloon', 'bilge', 'bladder', 'blain', 'bleb', 'blister', 'blob', 'boll', 'bolus', 'boss', 'bow'],
    'bulbous': ['bagging', 'baggy', 'ballooning', 'bellying', 'billowing', 'billowy', 'bloated', 'bosomy', 'botanic', 'bulblike', 'bulbose', 'bulging'],
    'bulge': ['advantage', 'allowance', 'bag', 'balloon', 'beetle', 'belly', 'belly out', 'bilge', 'billow', 'blain', 'bleb', 'blister'],
    'bulging': ['sro', 'bagging', 'baggy', 'ballooning', 'bellied', 'bellying', 'bellylike', 'billowing', 'billowy', 'bloated', 'bosomy', 'brimful'],
    'bulk': ['accumulate', 'add to', 'agglomerate', 'aggrandize', 'aggregate', 'aggroup', 'amass', 'amount', 'ampleness', 'amplify', 'amplitude', 'area'],
    'bulkhead': ['french door', 'anchorage', 'anchorage ground', 'arch dam', 'archway', 'back door', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier'],
    'bulky': ['gargantuan', 'adamantine', 'amplitudinous', 'astronomical', 'awesome', 'awkward', 'boundless', 'broad-bodied', 'bullnecked', 'chunky', 'clumsy', 'coarse'],
    'bull': ['brahman', 'dogberry', 'indian buffalo', 'irish bull', 'john law', 'pastoral epistle', 'aerogram', 'air letter', 'airgraph', 'anacoluthon', 'andric', 'appointment'],
    'bulldog': ['achilles', 'david', 'hector', 'roland', 'samson', 'a man', 'adherent', 'adhesive', 'barnacle', 'bramble', 'brave', 'brier'],
    'bulldogged': ['adherent', 'adhesive', 'balking', 'balky', 'bigoted', 'bulldoggish', 'bulldoggy', 'bulletheaded', 'bullheaded', 'case-hardened', 'clingy', 'dogged'],
    'bulldoze': ['assault', 'be imminent', 'bear', 'bear upon', 'beat down', 'blackjack', 'blank', 'blow down', 'bludgeon', 'bluster', 'bluster out of', 'boost'],
    'bullet': ['alpha decay', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction', 'atomization', 'ball', 'bar shot', 'barrel', 'beta decay', 'bird shot', 'bombardment'],
    'bulletin': ['account', 'account rendered', 'accounting', 'acquaintance', 'acta', 'announcement', 'annual', 'blue book', 'brief', 'briefing', 'census report', 'communication'],
    'bullfight': ['action', 'aerial combat', 'affray', 'armored combat', 'battle', 'battle royal', 'brush', 'clash', 'clash of arms', 'cockfight', 'combat', 'conflict'],
    'bullheaded': ['adherent', 'adhesive', 'balking', 'balky', 'bigoted', 'bulldogged', 'bulldoggish', 'bulldoggy', 'bulletheaded', 'case-hardened', 'clingy', 'closed-minded'],
    'bullion': ['bar', 'button', 'cast', 'casting', 'coin gold', 'coin silver', 'copper', 'earth metals', 'gate', 'gold', 'gold dust', 'gold nugget'],
    'bullshit': ['babble', 'balderdash', 'balls', 'baloney', 'big talk', 'bilge', 'blabber', 'blague', 'blah', 'blah-blah', 'blather', 'bop'],
    'bullwhack': ['belt', 'blacksnake', 'bullwhip', 'cat', 'cowhide', 'crop', 'flagellum', 'horsewhip', 'knout', 'kurbash', 'lash', 'quirt'],
    'bullwhacker': ['jehu', 'cabby', 'cabdriver', 'cabman', 'cameleer', 'carter', 'cartman', 'charioteer', 'coachman', 'coachy', 'cocher', 'cochero'],
    'bully': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'goliath', 'hercules', 'herod', 'ok', 'polyphemus', 'samson'],
    'bulwark': ['abatis', 'abutment', 'advanced work', 'aegis', 'arc-boutant', 'arch dam', 'arm guard', 'backstop', 'balistraria', 'bamboo curtain', 'bank', 'banquette'],
    'bum': ['arab', 'bowery bum', 'amiss', 'arse', 'ass', 'backside', 'bad', 'barfy', 'bat around', 'beach bum', 'beachcomber', 'beg'],
    'bum around': ['do nothing', 'goof off', 'hang around', 'idle', 'laze', 'lazy', 'lie around', 'loaf', 'loiter about', 'loll around', 'lollop around', 'lounge'],
    'bumble': ['be all thumbs', 'blow', 'blunder', 'blunder away', 'blunder into', 'blunder on', 'blunder upon', 'bobble', 'boggle', 'bollix', 'bombinate', 'botch'],
    'bumbling': ['all thumbs', 'awkward', 'blunderheaded', 'blundering', 'boorish', 'bungling', 'butterfingered', 'careless', 'clownish', 'clumsy', 'clumsy-fisted', 'cumbersome'],
    'bummer': ['arab', 'bowery bum', 'adverse circumstances', 'adversity', 'affliction', 'aggravation', 'annoyance', 'bandit', 'beach bum', 'beachcomber', 'beggar', 'beggarly fellow'],
    'bump': ['cat', 'abase', 'abasement', 'ability', 'aerospace', 'aerosphere', 'air hole', 'air pocket', 'airspace', 'appulse', 'aptness', 'assassinate'],
    'bump into': ['alight upon', 'bang', 'bang into', 'blunder upon', 'bump', 'cannon', 'carom', 'carom into', 'chance upon', 'clash', 'collide', 'come across'],
    'bump off': ['assassinate', 'blast', 'blot out', 'cool', 'croak', 'do in', 'dust off', 'erase', 'execute', 'finish', 'fix', 'get'],
    'bumper': ['aegis', 'arm guard', 'backstop', 'barrier', 'bellyful', 'beverage', 'big', 'brattice', 'buffer', 'buffer state', 'bulkhead', 'bulwark'],
    'bumpkin': ['boor', 'bucolic', 'clod', 'clodhopper', 'clown', 'country bumpkin', 'farmer', 'gawk', 'gawky', 'hayseed', 'hick', 'hillbilly'],
    'bumptious': ['aggressively self-confident', 'arrogant', 'audacious', 'biggety', 'brassy', 'brazen', 'challenging', 'cheeky', 'chesty', 'cocky', 'cold', 'conceited'],
    'bumpy': ['bagging', 'baggy', 'ballooning', 'bellying', 'billowing', 'billowy', 'bloated', 'bosomy', 'bouncy', 'broken', 'bulbose', 'bulbous'],
    'bun': ['danish', 'danish pastry', 'english muffin', 'parker house roll', 'yorkshire pudding', 'bagel', 'bialy', 'bialystoker', 'braid', 'chignon', 'clover-leaf roll', 'coffee cake'],
    'bunch': ['a mass of', 'a world of', 'accumulate', 'adhere', 'affiliate', 'age group', 'agglomerate', 'agglomeration', 'aggregate', 'aggroup', 'ally', 'amass'],
    'bunco': ['ballot-box stuffing', 'cardsharping', 'cheat', 'cheating', 'cozenage', 'diddle', 'diddling', 'dishonesty', 'dodge', 'fishy transaction', 'flam', 'flimflam'],
    'bunco artist': ['bunco steerer', 'cardsharp', 'cardsharper', 'carpetbagger', 'con artist', 'con man', 'confidence man', 'crimp', 'horse coper', 'horse trader', 'jackleg', 'land pirate'],
    'buncombe': ['washingtonese', 'adulation', 'balls', 'baloney', 'big talk', 'bilge', 'blague', 'blah', 'blah-blah', 'blandishment', 'blarney', 'bop'],
    'bundle': ['accelerate', 'amble', 'array', 'bale', 'band', 'bandage', 'barge', 'batch', 'belt', 'bend', 'bind', 'bind up'],
    'bundle off': ['bow out', 'bundle', 'dismiss', 'float', 'give a start', 'give the air', 'give the gate', 'hustle out', 'kick off', 'launch', 'pack off', 'put in motion'],
    'bundle up': ['apparel', 'array', 'attire', 'bale', 'bedeck', 'bedrape', 'bind up', 'bundle', 'clothe', 'deck', 'dight', 'do up'],
    'bungle': ['bad job', 'bat out', 'be all thumbs', 'bevue', 'blooper', 'blow', 'blunder', 'blunder away', 'blunder into', 'blunder on', 'blunder upon', 'bobble'],
    'bungler': ['blockhead', 'blunderbuss', 'blunderer', 'blunderhead', 'boor', 'botcher', 'bumbler', 'clod', 'clodhopper', 'clodknocker', 'clot', 'clown'],
    'bungling': ['all thumbs', 'awkward', 'bad job', 'blunderheaded', 'blunderheadedness', 'blundering', 'boggling', 'boorish', 'botch', 'botched', 'botchery', 'botching'],
    'bunion': ['abscess', 'adenoiditis', 'adrenitis', 'aposteme', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'bed sore'],
    'bunk': ['abide', 'abscond', 'applesauce', 'balderdash', 'balls', 'baloney', 'bed', 'bedstead', 'beguile', 'berth', 'bestow', 'betray'],
    'bunker': ['abri', 'acropolis', 'air-raid shelter', 'antre', 'approach trench', 'archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bastion'],
    'bunkum': ['grade a', 'washingtonese', 'adulation', 'applesauce', 'balderdash', 'balls', 'baloney', 'bang-up', 'big talk', 'bilge', 'blague', 'blah'],
    'bunny': ['belgian hare', 'miss america', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'beauty queen', 'belle', 'buck', 'charmer', 'cottontail'],
    'bunt': ['advance', 'assault', 'beak', 'bear', 'bear upon', 'bearing', 'boost', 'bowl', 'brush', 'buck', 'bull', 'bulldoze'],
    'bunting': ['dannebrog', 'jolly roger', 'old glory', 'star-spangled banner', 'stars and stripes', 'union flag', 'union jack', 'and blue', 'banderole', 'banner', 'banneret', 'black flag'],
    'buoy': ['carling float', 'mae west', 'roman candle', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'balsa', 'balsa raft', 'beacon', 'beacon fire', 'bear up'],
    'buoy up': ['afford support', 'animate', 'back', 'back up', 'bear', 'bear up', 'bolster', 'bolster up', 'boost', 'brace', 'brighten', 'buoy'],
    'buoyancy': ['adaptability', 'airiness', 'ascent', 'bounce', 'bounciness', 'breeziness', 'bubbliness', 'buoyance', 'carefreeness', 'chirpiness', 'daintiness', 'debonairness'],
    'buoyant': ['adaptable', 'adaptive', 'afloat', 'airy', 'animated', 'blithe', 'bouncy', 'breezy', 'bright', 'carefree', 'cheerful', 'convalescent'],
    'burble': ['babble', 'be stupid', 'blather', 'blither', 'blubber', 'boil', 'boil over', 'bubble', 'bubble over', 'bubble up', 'chatter', 'clack'],
    'burden': ['spenserian stanza', 'accommodation', 'add', 'adjoin', 'affix', 'afflict', 'affliction', 'agglutinate', 'agitate', 'albatross', 'allegiance', 'amount'],
    'burdened': ['bearing', 'bolstering', 'bracing', 'buttressing', 'carrying', 'charged', 'cumbered', 'encumbered', 'fraught', 'freighted', 'full-charged', 'full-fraught'],
    'burdensome': ['herculean', 'annoying', 'arduous', 'backbreaking', 'besetting', 'bothersome', 'crushing', 'cumbersome', 'cumbrous', 'demanding', 'distressing', 'effortful'],
    'bureau': ['agency', 'bailiwick', 'chest', 'chest of drawers', 'chiffonier', 'commissariat', 'constablery', 'constablewick', 'constabulary', 'department', 'desk', 'division'],
    'bureaucracy': ['administration', 'authorities', 'beadledom', 'beat', 'beaten path', 'bumbledom', 'bureaucratism', 'chinoiserie', 'daily grind', 'directorate', 'government', 'grind'],
    'bureaucratic': ['absolute', 'administrative', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'civic', 'civil', 'constitutional', 'democratic', 'despotic', 'dictatorial'],
    'burg': ['stadt', 'banlieue', 'boom town', 'borough', 'bourg', 'burgh', 'city', 'conurbation', 'crossroads', 'exurb', 'exurbia', 'faubourg'],
    'burgeon': ['acrospire', 'augment', 'bine', 'bloom', 'blossom', 'blow', 'bough', 'branch', 'branchedness', 'branchiness', 'brew', 'bud'],
    'burgher': ['babbitt', 'christian', 'middle american', 'philistine', 'anal character', 'big-city man', 'bourgeois', 'burgess', 'citizen', 'city dweller', 'city man', 'city slicker'],
    'burghermaster': ['alderman', 'archon', 'bailie', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor', 'city councilman', 'city father', 'city manager', 'commissar', 'commissioner'],
    'burglary': ['break-in', 'breaking and entering', 'burglarizing', 'caper', 'filch', 'grab', 'heist', 'housebreaking', 'job', 'lift', 'pinch', 'rip-off'],
    'burial': ['baptism', 'barrow', 'beehive tomb', 'bone house', 'box grave', 'burial at sea', 'burial chamber', 'burial customs', 'burial mound', 'burying', 'catacombs', 'cenotaph'],
    'buried': ['abstruse', 'beclouded', 'blind', 'close', 'clouded', 'concealed', 'covered', 'covert', 'deep-buried', 'drowned', 'eclipsed', 'engulfed'],
    'buried in': ['absorbed', 'absorbed in', 'caught up in', 'contemplating', 'contemplative', 'devoted', 'devoted to', 'engaged', 'engrossed', 'engrossed in', 'immersed in', 'intent'],
    'burl': ['bilge', 'blain', 'bleb', 'blister', 'blob', 'boss', 'bow', 'bubble', 'bulb', 'bulge', 'bulla', 'bump'],
    'burlesque': ['atticism', 'broadway', 'thalia', 'aggrandize', 'aggrandizement', 'agile wit', 'amplification', 'amplify', 'anamorphosis', 'ape', 'arlequinade', 'bad likeness'],
    'burly': ['able-bodied', 'adipose', 'athletic', 'beefy', 'big', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'broad-shouldered', 'buxom'],
    'burn': ['earth insertion', 'lem', 'lm', 'abrade', 'abrasion', 'adolescent stream', 'afflict', 'agonize', 'ail', 'air-dry', 'altitude peak', 'anhydrate'],
    'burn out': ['beat', 'blow', 'break down', 'collapse', 'crack up', 'debilitate', 'die', 'die away', 'die out', 'do in', 'do up', 'droop'],
    'burn up': ['ablate', 'absorb', 'aggravate', 'anger', 'annoy', 'assimilate', 'badger', 'bait', 'be at', 'bedevil', 'beset', 'bleed white'],
    'burner': ['argand burner', 'acetylene welder', 'annihilator', 'arsonist', 'biblioclast', 'blast lamp', 'blowpipe', 'blowtorch', 'bomber', 'burning ghat', 'caliduct', 'cinerator'],
    'burning': ['abandoned', 'ablaze', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrimonious', 'afire', 'aflame'],
    'burnish': ['buff', 'dress', 'finish', 'furbish', 'glance', 'glaze', 'gloss', 'luster', 'polish', 'rub', 'rub up', 'sand'],
    'burr': ['accent', 'adherent', 'adhesive', 'barnacle', 'belch', 'blare', 'blat', 'boll', 'bramble', 'bray', 'brier', 'bristle'],
    'burrow': ['abri', 'anchor', 'antre', 'be incognito', 'beat the bushes', 'billet at', 'bivouac', 'bore', 'bunker', 'camp', 'cave', 'cavern'],
    'bursar': ['accountant', 'auditor', 'bookkeeper', 'cashier', 'cashkeeper', 'chamberlain', 'compensator', 'comptroller', 'controller', 'curator', 'defrayer', 'depositary'],
    'burst': ['access', 'ado', 'aggravated', 'agitation', 'antiaircraft barrage', 'backfire', 'bang', 'bark', 'barrage', 'belch', 'blast', 'blaze'],
    'burst forth': ['arise', 'bail out', 'be born', 'become', 'belch', 'blow open', 'blow out', 'bob up', 'break cover', 'break forth', 'break out', 'bud'],
    'burst in': ['admit', 'barge in', 'be admitted', 'breach', 'break in', 'break in upon', 'break into', 'break open', 'break through', 'breeze in', 'bust in', 'butt in'],
    'burst out': ['be in stitches', 'belch', 'blow open', 'blow out', 'blurt', 'blurt out', 'break out', 'break up', 'burst forth', 'burst into laughter', 'burst out laughing', 'burst with laughter'],
    'bursting': ['sro', 'abundant', 'agog', 'alive with', 'aquiver', 'aroused', 'atingle', 'atwitter', 'banging', 'blasting', 'bloated', 'blooming'],
    'bury': ['abandon', 'baptize', 'bosom', 'bottle up', 'cache', 'coffin', 'conceal', 'conduct a funeral', 'consign to oblivion', 'cover up', 'deluge', 'deposit'],
    'bus': ['auto', 'autobus', 'autocar', 'automobile', 'barge', 'bicycle', 'bike', 'boat', 'buggy', 'cab', 'car', 'cart'],
    'busboy': ['aquarius', 'ganymede', 'hebe', 'barkeep', 'barkeeper', 'barmaid', 'barman', 'bartender', 'bearer', 'bheesty', 'caddie', 'cargo handler'],
    'bush': ['arabia deserta', 'death valley', 'sahara', 'afforestation', 'arboretum', 'back country', 'backcountry', 'backwash', 'backwater', 'backwoods', 'barren', 'barren land'],
    'bushed': ['all in', 'beat', 'beat up', 'beaten', 'bone-weary', 'dead', 'dead-and-alive', 'dead-tired', 'deadbeat', 'dog-tired', 'dog-weary', 'done'],
    'bushfighting': ['a-war', 'h-war', 'aerial warfare', 'amphibious warfare', 'atom war', 'atomic war', 'bacteriological warfare', 'biological warfare', 'chemical warfare', 'conventional war', 'defensive warfare', 'gas warfare'],
    'bushing': ['backing', 'ball bearing', 'bearing', 'bevel bearing', 'bush', 'chassis', 'doubling', 'doublure', 'facing', 'filler', 'filling', 'frame'],
    'bushman': ['bronze age man', 'hominidae', 'iron age man', 'stone age man', 'aboriginal', 'aborigine', 'ancient', 'antediluvian', 'anthropoid', 'ape-man', 'autochthon', 'backwoodsman'],
    'bushwa': ['balderdash', 'baloney', 'bilge', 'blah', 'blah-blah', 'bop', 'bosh', 'bull', 'bullshit', 'bunk', 'bunkum', 'crap'],
    'bushwhack': ['ambush', 'assail', 'assault', 'astonish', 'attack', 'blitz', 'catch off-guard', 'catch unawares', 'come at', 'come down on', 'come from behind', 'come upon unexpectedly'],
    'bushwhacker': ['charley', 'vc', 'vietcong', 'ancestor', 'announcer', 'antecedent', 'avant-garde', 'bellwether', 'buccinator', 'bushfighter', 'casual', 'explorer'],
    'bushy': ['afforestational', 'arborary', 'arboreal', 'arboreous', 'arborescent', 'arboresque', 'arborical', 'arboriform', 'bosky', 'braky', 'bristly', 'bushlike'],
    'business': ['aktiengesellschaft', 'acting', 'action', 'activeness', 'activism', 'activity', 'affair', 'aktiebolag', 'allegiance', 'area', 'art', 'assigned task'],
    'business cycle': ['boom', 'bottoming out', 'business fluctuations', 'bust', 'cooling off', 'crisis', 'depression', 'downturn', 'economic cycle', 'economic expansion', 'economic growth', 'expanding economy'],
    'businesslike': ['arranged', 'banausic', 'breadwinning', 'commercial', 'formal', 'habitual', 'harmonious', 'in hand', 'materialistic', 'methodical', 'moneymaking', 'normal'],
    'bust': ['abase', 'abasement', 'ado', 'apprehend', 'apprehension', 'arch', 'arrest', 'arrestation', 'arrestment', 'bacchanal', 'bacchanalia', 'bacchanalian'],
    'bust in': ['admit', 'barge in', 'be admitted', 'breach', 'break in', 'break into', 'break open', 'break through', 'breeze in', 'burst in', 'cave in', 'come barging in'],
    'busted': ['aggravated', 'bankrupt', 'beat', 'broke', 'broken', 'burned', 'burst', 'checked', 'chipped', 'cracked', 'crazed', 'cut'],
    'bustle': ['accelerate', 'ado', 'agitation', 'bake', 'beat', 'bilk', 'bite', 'bluff', 'bluster', 'bluster and bluff', 'blustering', 'boastfulness'],
    'bustling': ['active', 'agitated', 'brisk', 'busy', 'energetic', 'eventful', 'fidgety', 'fluttering', 'fluttery', 'fretful', 'full of incident', 'fussing'],
    'busy': ['absorb', 'active', 'arabesque', 'assiduous', 'at it', 'at work', 'attend to business', 'baroque', 'burden', 'bustling', 'busybody', 'chichi'],
    'busybody': ['paul pry', 'peeping tom', 'a tale-bearing animal', 'backseat driver', 'butt in', 'butt-in', 'buttinsky', 'eavesdropper', 'fool', 'gossip', 'gossip columnist', 'gossiper'],
    'busywork': ['assignment', 'chare', 'charge', 'chore', 'commission', 'duty', 'errand', 'exercise', 'fish to fry', 'homework', 'job', 'job of work'],
    'but': ['after all', 'again', 'albeit', 'all the same', 'alone', 'although', 'aside from', 'at all events', 'at any rate', 'bar', 'barring', 'besides'],
    'butch': ['ac-dc', 'amazon', 'amphierotic', 'androgyne', 'auntie', 'autoerotic', 'bi-guy', 'bisexed', 'bisexual', 'bull dyke', 'catamite', 'chicken'],
    'butcher': ['cain', 'amputate', 'annihilate', 'annihilator', 'apache', 'assassin', 'assassinator', 'assault', 'attack', 'ax', 'baggage man', 'bakehead'],
    'butchered': ['botched', 'bungled', 'castrated', 'cut short', 'docked', 'fumbled', 'garbled', 'hashed', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised'],
    'butler': ['mc', 'attorney', 'bailiff', 'boy', 'chamberlain', 'chauffeur', 'coachman', 'croupier', 'curator', 'custodian', 'driver', 'emcee'],
    'butt': ['thule', 'ultima thule', 'abut', 'abut on', 'adjoin', 'advance', 'afterglow', 'afterimage', 'aim', 'ankle', 'articulate', 'articulation'],
    'butt in': ['barge in', 'blow it', 'break in', 'break in upon', 'burst in', 'busybody', 'charge in', 'come between', 'crash', 'crash in', 'crash the gates', 'creep in'],
    'butte': ['anthill', 'barrow', 'brae', 'down', 'drumlin', 'dune', 'fell', 'foothills', 'hill', 'hillock', 'hummock', 'knob'],
    'butter': ['albumen', 'batter', 'bedaub', 'besmear', 'blandness', 'blarney', 'blubber', 'bonnyclabber', 'breeze', 'butter up', 'buttermilk', 'cataplasm'],
    'butterfingers': ['clumsy', 'dub', 'duffer', 'foozler', 'foul-up', 'fumble-fist', 'goof', 'goofball', 'goofer', 'hick', 'lummox', 'lump'],
    'buttinsky': ['dutch uncle', 'paul', 'polonius', 'admonisher', 'adviser', 'backseat driver', 'butt-in', 'confidant', 'consultant', 'counsel', 'counselor', 'crasher'],
    'buttocks': ['arse', 'ass', 'backside', 'beam', 'behind', 'bottom', 'breech', 'bum', 'butt', 'can', 'cheeks', 'croup'],
    'button': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'anchor', 'armory', 'articulate', 'badge', 'badge of office', 'badges', 'bagatelle'],
    'button up': ['bang', 'bar', 'barricade', 'batten', 'batten down', 'bolt', 'button', 'cap', 'carry to completion', 'choke', 'choke off', 'clam up'],
    'buttonhole': ['accost', 'address', 'apostrophize', 'appeal to', 'apply pressure', 'approach', 'beset', 'besiege', 'bespeak', 'blandish', 'bore', 'bore stiff'],
    'buttress': ['abutment', 'advocate', 'affirm', 'afford support', 'alpenstock', 'arc-boutant', 'arm', 'athletic supporter', 'attest', 'authenticate', 'back', 'back up'],
    'buxom': ['junoesque', 'adipose', 'agreeable', 'amply endowed', 'attractive', 'becoming', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bonny', 'bosomy'],
    'buy': ['abide by', 'accede', 'accept', 'accept for gospel', 'accept implicitly', 'acclaim', 'acquiesce', 'acquiesce in', 'acquire', 'advantageous purchase', 'agree', 'agree to'],
    'buy in': ['buy', 'buy back', 'buy into', 'buy off', 'buy on credit', 'buy up', 'complete a purchase', 'corner', 'engross', 'financier', 'invest', 'invest in'],
    'buy off': ['approach', 'bribe', 'buy', 'buy back', 'buy in', 'buy into', 'buy on credit', 'buy up', 'complete a purchase', 'corner', 'corrupt', 'engross'],
    'buzz': ['ddd', 'indian file', 'alert', 'array', 'articulation', 'assibilate', 'assibilation', 'bank', 'bark', 'bawl', 'belch', 'bellow'],
    'buzz off': ['be getting along', 'come away', 'depart', 'exit', 'gang along', 'get along', 'get away', 'get off', 'get on', 'get under way', 'go', 'go along'],
    'buzzer': ['klaxon', 'mayday', 'sos', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert', 'all clear', 'beacon'],
    'by': ['abeam', 'abreast', 'accommodated to', 'according to', 'adapted to', 'adieu', 'adjusted to', 'after', 'agreeable to', 'agreeably to', 'all through', 'along by'],
    'by all means': ['ok', 'roger', 'absolutely', 'all right', 'alright', 'alrighty', 'amen', 'and no mistake', 'as you say', 'assuredly', 'at all events', 'at any rate'],
    'by and by': ['after a time', 'after a while', 'afterward', 'afterwards', 'anon', 'before long', 'behind', 'betimes', 'by destiny', 'directly', 'ere long', 'fatally'],
    'by and large': ['all in all', 'all things considered', 'almost entirely', 'altogether', 'approximately', 'as a rule', 'as a whole', 'as an approximation', 'at large', 'broadly', 'broadly speaking', 'chiefly'],
    'by chance': ['accidentally', 'as it chanced', 'at haphazard', 'at intervals', 'at random', 'by a fluke', 'by accident', 'by fits', 'by good fortune', 'by hazard', 'by snatches', 'capriciously'],
    'by choice': ['before', 'by election', 'by vote', 'electively', 'first', 'freely', 'gratuitously', 'in preference', 'independently', 'optionally', 'preferably', 'rather'],
    'by degrees': ['bit by bit', 'by inches', 'by inchmeal', 'by slow degrees', 'by snatches', 'degreewise', 'drop by drop', 'foot by foot', 'gradatim', 'grade by grade', 'gradually', 'in detail'],
    'by design': ['advisedly', 'calculatedly', 'consciously', 'contemplatedly', 'deliberately', 'designedly', 'in cold blood', 'intentionally', 'knowingly', 'meditatedly', 'on purpose', 'pointedly'],
    'by means of': ['by', 'by dint of', 'by use of', 'by virtue of', 'by way of', 'helped by', 'hereby', 'herewith', 'in virtue of', 'on', 'per', 'thanks to'],
    'by no means': ['god forbid', 'i refuse', 'i will not', 'at no hand', 'au contraire', 'count me out', 'far from it', 'impossible', 'in no case', 'in no respect', 'in no wise', 'include me out'],
    'by product': ['afterbirth', 'afterclap', 'aftercrop', 'aftereffect', 'afterglow', 'aftergrowth', 'afterimage', 'aftermath', 'afterpain', 'aftertaste', 'consequence', 'consequent'],
    'by the way': ['a propos', 'accidental', 'aimless', 'apropos', 'apropos of', 'by the by', 'by-the-way', 'casual', 'desultory', 'deviative', 'digressive', 'discursive'],
    'by virtue of': ['after', 'because of', 'by', 'by authority of', 'by dint of', 'by means of', 'by reason of', 'by use of', 'by way of', 'considering', 'due to', 'hereby'],
    'by way of': ['all through', 'around', 'by', 'by dint of', 'by means of', 'by use of', 'by virtue of', 'hereby', 'herewith', 'in virtue of', 'on', 'over'],
    'bygone': ['ago', 'antiquated', 'antique', 'archaic', 'belated', 'blown over', 'by', 'bypast', 'dated', 'dead', 'dead and buried', 'deceased'],
    'bylaw': ['act', 'bill', 'canon', 'decree', 'dictate', 'dictation', 'edict', 'enactment', 'form', 'formality', 'formula', 'formulary'],
    'bypass': ['autobahn', 'us highway', 'alley', 'alleyway', 'ambages', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue'],
    'bystander': ['tv-viewer', 'abutter', 'adjoiner', 'attestant', 'attestator', 'attester', 'beholder', 'bird-watcher', 'borderer', 'cojuror', 'compurgator', 'deponent'],
    'byway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'back door'],
    'byword': ['adage', 'ana', 'analects', 'aphorism', 'apophthegm', 'apothegm', 'appellation', 'appellative', 'axiom', 'binomen', 'binomial name', 'burning shame'],
    'byzantine': ['machiavellian', 'artful', 'balled up', 'calculating', 'canny', 'collusive', 'complex', 'complicated', 'confounded', 'confused', 'connivent', 'conniving'],
    'c note': ['g-note', 'buck', 'cartwheel', 'cent', 'century', 'copper', 'dime', 'dollar', 'dollar bill', 'fifty cents', 'fin', 'fish'],
    'cabal': ['anschluss', 'addition', 'affiliation', 'age group', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'amalgamation', 'artifice', 'assimilation', 'association'],
    'cabala': ['anagoge', 'anagogics', 'anthroposophy', 'arcanum', 'cabalism', 'classified information', 'confidence', 'confidential communication', 'enigma', 'esoterica', 'esotericism', 'esoterics'],
    'caballero': ['bayard', 'casanova', 'don juan', 'don quixote', 'gawain', 'lancelot', 'lothario', 'ritter', 'romeo', 'sidney', 'sir galahad', 'amoroso'],
    'cabaret': ['elizabethan theater', 'globe theatre', 'greek theater', 'alehouse', 'amphitheater', 'amusement', 'amusement park', 'arena theater', 'auditorium', 'ballroom', 'bar', 'barrel house'],
    'cabbage': ['irish potato', 'kraut', 'aubergine', 'beans', 'blunt', 'boodle', 'brass', 'bread', 'bucks', 'chips', 'dinero', 'dough'],
    'cabdriver': ['jehu', 'sunday driver', 'backseat driver', 'bullwhacker', 'bus driver', 'busman', 'cabby', 'cabman', 'cameleer', 'carter', 'cartman', 'charioteer'],
    'cabin': ['berth', 'blockhouse', 'box', 'bungalow', 'chalet', 'compartment', 'cot', 'cote', 'cottage', 'cuddy', 'deckhouse', 'house'],
    'cabin boy': ['ganymede', 'hebe', 'airline hostess', 'airline stewardess', 'attendant', 'bakehead', 'batman', 'bellboy', 'bellhop', 'bellman', 'black gang', 'boilerman'],
    'cabinet': ['british cabinet', 'canterbury', 'sanhedrin', 'us cabinet', 'advisors', 'advisory body', 'advisory council', 'adytum', 'armoire', 'assembly', 'association', 'bench'],
    'cable': ['bx cable', 'teletype', 'wats', 'wats line', 'armored cable', 'battery cable', 'bell wire', 'braid', 'brail', 'cablegram', 'chain', 'co-ax'],
    'caboose': ['pullman', 'pullman car', 'baggage car', 'bakehouse', 'bakery', 'boxcar', 'camboose', 'car', 'carriage', 'chair car', 'coach', 'coal car'],
    'cache': ['asylum', 'backlog', 'bank', 'bolt-hole', 'bosom', 'bottle up', 'bundle away', 'bury', 'coffer', 'conceal', 'concealment', 'corner'],
    'cachet': ['aroma', 'attribute', 'badge', 'billhead', 'book stamp', 'bookplate', 'brand', 'broad arrow', 'cast', 'character', 'characteristic', 'check'],
    'cackle': ['homeric laughter', 'babble', 'babblement', 'bark', 'bavardage', 'bawl', 'be in stitches', 'belch', 'bellow', 'belly laugh', 'bibble-babble', 'blab'],
    'cacophony': ['babel', 'gothicism', 'agitation', 'atonalism', 'atonality', 'bad taste', 'barbarism', 'barbarousness', 'bedlam', 'bluster', 'bombasticness', 'brawl'],
    'cactus': ['bramble', 'brier', 'bristle', 'burr', 'catchweed', 'cleavers', 'goose grass', 'needle', 'nettle', 'pine needle', 'prickle', 'quill'],
    'cad': ['babbitt', 'philistine', 'arriviste', 'boor', 'bounder', 'bourgeois', 'churl', 'clown', 'epicier', 'groundling', 'guttersnipe', 'hooligan'],
    'cadaver': ['ashes', 'body', 'bones', 'carcass', 'carrion', 'clay', 'corpse', 'corpus delicti', 'crowbait', 'dead body', 'dead man', 'dead person'],
    'cadaverous': ['achromatic', 'achromic', 'anemic', 'ashen', 'ashy', 'attenuated', 'bled white', 'bloodless', 'blue', 'chloranemic', 'colorless', 'corpselike'],
    'caddie': ['aquarius', 'ganymede', 'hebe', 'airline hostess', 'airline stewardess', 'attendant', 'batman', 'bearer', 'bellboy', 'bellhop', 'bellman', 'bheesty'],
    'cadence': ['alexandrine', 'accent', 'accentuation', 'acciaccatura', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antispast', 'appoggiatura', 'arabesque', 'arsis'],
    'cadenza': ['acciaccatura', 'appoggiatura', 'arabesque', 'cadence', 'coloratura', 'division', 'embellishment', 'extempore', 'fioritura', 'flight', 'flourish', 'grace'],
    'cadet': ['naval reservist', 'royal marine', 'seabee', 'bluejacket', 'boot', 'freshman', 'frogman', 'gob', 'horse marine', 'jolly', 'junior', 'marine'],
    'cadger': ['beggar', 'bum', 'bummer', 'chapman', 'cheap-jack', 'cheap-john', 'colporteur', 'coster', 'costermonger', 'coupon clippers', 'drone', 'freeloader'],
    'cadre': ['kp', 'army', 'army group', 'battalion', 'battery', 'battle group', 'board', 'board of directors', 'board of regents', 'board of trustees', 'brigade', 'bunch'],
    'caducity': ['advanced age', 'advanced years', 'age of retirement', 'an incurable disease', 'anility', 'changeableness', 'childishness', 'corruptibility', 'death', 'debility', 'decline', 'decline of life'],
    'caesar': ['dalai lama', 'holy roman emperor', 'inca', 'kaiser', 'simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'ardri', 'arrogator', 'autarch', 'autocrat'],
    'caesura': ['alexandrine', 'abeyance', 'accent', 'accentuation', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antispast', 'arsis', 'bacchius', 'beat'],
    'cafe': ['alehouse', 'automat', 'bar', 'barrel house', 'barroom', 'beanery', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'buffet', 'buvette'],
    'cafeteria': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop', 'coffeehouse'],
    'cage': ['beleaguer', 'beset', 'besiege', 'blockade', 'bottle up', 'bound', 'box in', 'box up', 'chamber', 'check', 'cloister', 'close in'],
    'cagey': ['machiavellian', 'machiavellic', 'acute', 'arch', 'artful', 'astute', 'canny', 'chary', 'clever', 'crafty', 'cunning', 'cute'],
    'cahoots': ['accompaniment', 'accordance', 'affiliation', 'agreement', 'alignment', 'alliance', 'amalgamation', 'association', 'co-working', 'coaction', 'coadunation', 'coalescence'],
    'cairn': ['arch', 'barrow', 'bench mark', 'bookmark', 'boundary stone', 'brass', 'bust', 'catstone', 'cenotaph', 'column', 'cromlech', 'cross'],
    'cajole': ['adulate', 'advocate', 'allure', 'apply pressure', 'bait', 'bait the hook', 'bamboozle', 'beguile', 'beset', 'besiege', 'beslobber', 'beslubber'],
    'cake': ['boston cream pie', 'angel cake', 'angel food cake', 'baked alaska', 'bar', 'block', 'body', 'bun', 'candy', 'cheesecake', 'chocolate cake', 'chunk'],
    'calamitous': ['afflictive', 'awful', 'baneful', 'black', 'cataclysmal', 'cataclysmic', 'catastrophic', 'consuming', 'consumptive', 'deadly', 'demolishing', 'demolitionary'],
    'calamity': ['accident', 'adversity', 'affliction', 'bane', 'blow', 'bugbear', 'burden', 'casualty', 'cataclysm', 'catastrophe', 'collapse', 'collision'],
    'calcimine': ['apply paint', 'bedaub', 'bedizen', 'begild', 'besmear', 'brush on paint', 'chalk', 'coat', 'color', 'complexion', 'cover', 'dab'],
    'calcination': ['blazing', 'blistering', 'branding', 'burning', 'carbonization', 'cauterization', 'cautery', 'cineration', 'combustion', 'concremation', 'cracking', 'cremation'],
    'calculable': ['anticipatable', 'appraisable', 'appreciable', 'assessable', 'computable', 'countable', 'dependable', 'determinable', 'divinable', 'estimable', 'faithful', 'faithworthy'],
    'calculate': ['add', 'add up', 'algebraize', 'appraise', 'appreciate', 'arrange', 'ascertain', 'assay', 'assess', 'bank on', 'build on', 'calibrate'],
    'calculate on': ['bank on', 'bargain for', 'bet on', 'count on', 'depend on', 'figure on', 'forestall', 'gamble on', 'lean on', 'look for', 'look forward to', 'look out for'],
    'calculated': ['adapted', 'adjusted', 'advised', 'aimed', 'aimed at', 'arranged', 'blueprinted', 'charted', 'conscious', 'considered', 'contemplated', 'contrived'],
    'calculating': ['byzantine', 'machiavellian', 'artful', 'canny', 'careful', 'chary', 'chiseling', 'circumspect', 'collusive', 'computational', 'computative', 'computing'],
    'calculation': ['adding', 'aforethought', 'amount', 'answer', 'appraisal', 'appraisement', 'approach', 'approximation', 'arithmetic', 'arrangement', 'assessment', 'assize'],
    'calculator': ['ca', 'cpa', 'comptometer', 'abacist', 'abacus', 'accountant', 'accountant general', 'actuary', 'adding', 'adding machine', 'analog computer', 'arithmograph'],
    'calefaction': ['cooking', 'dielectric heating', 'electric heating', 'electronic heating', 'furnace heating', 'gas heating', 'heat exchange', 'heating', 'hot-air heating', 'increase of temperature', 'induction heating', 'insolation'],
    'calendar': ['chinese calendar', 'cotsworth calendar', 'domesday book', 'gregorian calendar', 'hindu calendar', 'jewish calendar', 'julian calendar', 'muslim calendar', 'revolutionary calendar', 'roman calendar', 'account book', 'address book'],
    'calf': ['brahman', 'dry ice', 'indian buffalo', 'ankle', 'aurochs', 'bayonet legs', 'beef', 'beef cattle', 'beeves', 'berg', 'birdling', 'bison'],
    'caliber': ['iq', 'ability', 'ableness', 'adequacy', 'amount', 'amplitude', 'apprehension', 'area', 'bigness', 'body', 'bore', 'breadth'],
    'calibrate': ['iq', 'ability', 'adjust', 'agenda', 'amplitude', 'appraise', 'appreciate', 'apprehension', 'area', 'assay', 'assess', 'batting order'],
    'calisthenics': ['athletics', 'breather', 'constitutional', 'daily dozen', 'drill', 'eurythmics', 'exercise', 'exercising', 'gymnastic exercises', 'gymnastics', 'isometrics', 'physical culture'],
    'call': ['angelus', 'angelus bell', 'ddd', 'accompany', 'address', 'adjuration', 'adumbrate', 'alarm', 'alarum', 'allurement', 'animal noise', 'ante'],
    'call attention to': ['address to', 'allude to', 'blurt', 'blurt out', 'bring to attention', 'bring to notice', 'cite', 'comment', 'direct attention to', 'direct to', 'exclaim', 'focus on'],
    'call for': ['affect', 'apply for', 'ask', 'ask for', 'assume', 'bare necessities', 'be hurting for', 'be indicated', 'beg leave', 'bespeak', 'bid come', 'blackmail'],
    'call forth': ['annoy', 'arouse', 'awake', 'awaken', 'bid come', 'blow the coals', 'blow up', 'bring', 'bring about', 'bring forth', 'bring on', 'bring out'],
    'call girl': ['b-girl', 'cyprian', 'paphian', 'bawd', 'daughter of joy', 'drab', 'erring sister', 'fallen woman', 'fille de joie', 'harlot', 'hooker', 'hustler'],
    'call in': ['advise with', 'ask', 'bargain', 'bid come', 'bill', 'call', 'call away', 'call back', 'call for', 'call forth', 'call out', 'call together'],
    'call off': ['ko', 'call over', 'call the roll', 'cancel', 'census', 'complete', 'count', 'delete', 'dispose of', 'drop', 'drop the curtain', 'end off'],
    'call on': ['adjure', 'advocate', 'appeal', 'appeal to', 'apply to', 'beg', 'beseech', 'bid', 'blandish', 'cajole', 'call for help', 'call the signals'],
    'call out': ['affront', 'arouse', 'beard', 'bellow out', 'bid come', 'bid defiance', 'brave', 'bring forth', 'bring out', 'bring to light', 'call', 'call away'],
    'call up': ['annoy', 'ape', 'appear like', 'approach', 'approximate', 'arouse', 'assemblage', 'assembly', 'awake', 'awaken', 'be like', 'be redolent of'],
    'caller': ['bellboy', 'bellhop', 'bellman', 'callboy', 'calling party', 'company', 'copyboy', 'errand boy', 'freeloader', 'frequenter', 'gate-crasher', 'guest'],
    'calligraphy': ['abstract art', 'art', 'art form', 'artist', 'arts and crafts', 'arts of design', 'autography', 'cave art', 'ceramics', 'chirography', 'copybook hand', 'decoration'],
    'calling': ['ambition', 'apostolic orders', 'appellation', 'appointment', 'area', 'art', 'aspiration', 'baptism', 'basis', 'beck', 'beck and call', 'bid'],
    'calling card': ['id card', 'badge', 'calligram', 'card', 'countermark', 'countersign', 'credentials', 'dog tag', 'identification', 'identification badge', 'identification tag', 'initials'],
    'calliope': ['hammond organ', 'mark', 'baroque organ', 'bazooka', 'calliophone', 'choralcelo', 'electric organ', 'electro-pneumatic organ', 'harmonium', 'hedgehog', 'hydraulic organ', 'launch pad'],
    'callous': ['philistine', 'anneal', 'apathetic', 'asleep', 'backed', 'benumbed', 'brazen', 'brutalize', 'calcified', 'calcify', 'calloused', 'case harden'],
    'callousness': ['philistinism', 'analgesia', 'anesthesia', 'armor', 'callosity', 'callus', 'coldbloodedness', 'coldheartedness', 'coldness', 'deadness', 'density', 'dullness'],
    'callow': ['a novice at', 'a stranger to', 'adolescent', 'arrested', 'at half cock', 'awkward', 'blankminded', 'budding', 'defective', 'deficient', 'dewy', 'dumb'],
    'callus': ['philistinism', 'armor', 'benign tumor', 'callosity', 'callousness', 'cancer', 'carcinoma', 'corn', 'cyst', 'excrescence', 'flintiness', 'formidable defenses'],
    'calm': ['abnegation', 'abstinence', 'accordance', 'allay', 'alleviate', 'anticyclone', 'appease', 'assuage', 'at peace', 'at rest', 'aweless', 'balm'],
    'calmative': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'calming': ['united nations troops', 'abatement', 'allayment', 'alleviation', 'appeasement', 'appeasing', 'assuagement', 'blunting', 'conciliation', 'cradling', 'damping', 'deadening'],
    'calmness': ['buddha-like composure', 'oriental calm', 'abnegation', 'abstinence', 'ataraxia', 'ataraxy', 'awelessness', 'calm', 'calm disposition', 'calm of mind', 'composure', 'conservatism'],
    'calorie': ['btu', 'british thermal unit', 'atomerg', 'dinamode', 'dyne', 'energid', 'erg', 'foot-pound', 'great calorie', 'horsepower-hour', 'horsepower-year', 'joule'],
    'calorie counter': ['acid-ash diet', 'allergy diet', 'bland diet', 'calorie chart', 'diabetic diet', 'diet', 'diet book', 'dietary', 'dietetics', 'dieting', 'high-protein diet', 'high-vitamin diet'],
    'calumny': ['abuse', 'animadversion', 'backbiting', 'backstabbing', 'belittlement', 'bitchiness', 'calumniation', 'cattiness', 'contumely', 'defamation', 'depreciation', 'disparagement'],
    'calx': ['ash', 'ashes', 'brand', 'carbon', 'charcoal', 'cinder', 'clinker', 'coal', 'coke', 'coom', 'dross', 'fume'],
    'calypso': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'alba', 'anthem', 'art song', 'aubade', 'ballad', 'ballade', 'ballata'],
    'camber': ['amplitude', 'apse', 'arcade', 'arcature', 'arch', 'arched roof', 'archway', 'bellying', 'bulging', 'ceilinged roof', 'concameration', 'concha'],
    'camel': ['cape elk', 'siberian husky', 'virginia deer', 'antelope', 'ass', 'beast of burden', 'buck', 'camelopard', 'caribou', 'deer', 'deerlet', 'doe'],
    'camelback': ['bowlegs', 'cleft palate', 'clubfoot', 'crookback', 'defacement', 'deformation', 'deformity', 'disfigurement', 'flatfoot', 'freakishness', 'harelip', 'humpback'],
    'cameo': ['anaglyph', 'bas-relief', 'boss', 'cameo glass', 'catalog', 'cataloging', 'cavo-rilievo', 'character', 'character sketch', 'characterization', 'cut glass', 'delineation'],
    'camera': ['iconoscope', 'kodak', 'photostat', 'slr', 'x-ray machine', 'achromatic lens', 'aerial reconnaissance camera', 'astigmatic lens', 'astrograph', 'box camera', 'burning glass', 'camera obscura'],
    'camouflage': ['bad copy', 'bad likeness', 'becloud', 'befog', 'belie', 'blanket', 'blind', 'burlesque', 'caricature', 'cloak', 'cloud', 'color'],
    'camouflaged': ['behind the curtain', 'behind the scenes', 'concealed', 'disguised', 'hidden', 'imperceptible', 'in disguise', 'incog', 'incognito', 'indiscernible', 'insensible', 'invisible'],
    'camp': ['american party', 'anti-monopoly party', 'babbittry', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party'],
    'campaign': ['action', 'activity', 'all-out campaign', 'campaign button', 'campaign commitments', 'campaign contribution', 'campaign fund', 'canvass', 'cause', 'circuit', 'commitment', 'compete'],
    'campanile': ['antenna tower', 'barbican', 'belfry', 'bell tower', 'carillon', 'colossus', 'column', 'cupola', 'derrick', 'dome', 'fire tower', 'lantern'],
    'camper': ['adventurer', 'alpinist', 'astronaut', 'camp trailer', 'caravan', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser', 'excursionist', 'explorer'],
    'campo': ['agora', 'alkali flat', 'alluvial plain', 'basin', 'bottomland', 'bushveld', 'champaign', 'champaign country', 'coastal plain', 'delta', 'desert', 'down'],
    'campus': ['agora', 'amphitheater', 'arena', 'athletic field', 'auditorium', 'background', 'bear garden', 'bowl', 'boxing ring', 'bull ring', 'canvas', 'circus'],
    'can': ['casanova', 'wc', 'arse', 'ass', 'ax', 'backhouse', 'backside', 'bag', 'barrel', 'basement', 'basket', 'bathroom'],
    'canal': ['eustachian tube', 'fallopian tube', 'aqueduct', 'arroyo', 'bed', 'bottleneck', 'canalization', 'canalize', 'carve', 'chamfer', 'channel', 'chisel'],
    'canape': ['blt', 'dagwood sandwich', 'sloppy joe', 'swiss cheese sandwich', 'antepast', 'antipasto', 'aperitif', 'appetizer', 'bacon-lettuce-tomato sandwich', 'cheeseburger', 'corned beef sandwich', 'double-decker sandwich'],
    'canard': ['cornish hen', 'artifice', 'bouncer', 'broiler', 'bruit', 'buzz', 'caille', 'caneton', 'capon', 'chapon', 'chicken', 'common talk'],
    'canary': ['heldentenor', 'meistersinger', 'philomel', 'alto', 'aria singer', 'aureate', 'auric', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo'],
    'cancel': ['ko', 'abandon', 'abbreviate', 'abolish', 'abolishment', 'abolition', 'abort', 'abridge', 'abrogate', 'abrogation', 'absolve', 'accent'],
    'cancellation': ['abandonment', 'abbreviation', 'abolishment', 'abolition', 'abridgment', 'abrogation', 'annulment', 'arabesque', 'basketry', 'basketwork', 'blot', 'blotting'],
    'cancer': ['benign tumor', 'blast', 'blight', 'callosity', 'callus', 'canker', 'carcinoma', 'corn', 'cyst', 'dry rot', 'excrescence', 'fungosity'],
    'candescent': ['ablaze', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'beaming', 'beamy', 'blazing', 'blushing', 'bright and sunny'],
    'candid': ['olympian', 'spartan', 'aboveboard', 'accessible', 'all jaw', 'approachable', 'artless', 'ascetic', 'austere', 'authentic', 'bald', 'bare'],
    'candidate': ['addict', 'agent', 'also-ran', 'applicant', 'appointee', 'aspirant', 'aspirer', 'assignee', 'baby kisser', 'bidder', 'campaigner', 'claimant'],
    'candle': ['asa scale', 'agnus dei', 'british candle', 'hefner candle', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'scheiner scale', 'ark', 'asperger'],
    'candor': ['accessibility', 'approachability', 'artlessness', 'austerity', 'baldness', 'bareness', 'big mouth', 'bluffness', 'bluntness', 'broadness', 'brusqueness', 'candidness'],
    'candy': ['jell-o', 'addictive drug', 'blancmange', 'cake', 'comfit', 'compote', 'concrete', 'condense', 'confection', 'confectionery', 'confiture', 'conserve'],
    'cane': ['boston type', 'braille', 'malacca cane', 'new york point', 'optacon', 'pathsounder', 'seeing eye dog', 'visotoner', 'advocate', 'aftergrass', 'alpenstock', 'anthrophore'],
    'canicular': ['aestival', 'arctic', 'ardent', 'autumn', 'autumnal', 'baking', 'blistering', 'boiling', 'boreal', 'broiling', 'brumal', 'burning'],
    'canine': ['seeing eye dog', 'amphibian', 'aquatic', 'baby tooth', 'bandog', 'bicuspid', 'biped', 'bitch', 'bowwow', 'bucktooth', 'cannibal', 'carnivore'],
    'canker': ['abscess', 'adulterate', 'alloy', 'aposteme', 'bed sore', 'blain', 'blast', 'bleb', 'blight', 'blister', 'boil', 'break up'],
    'cannibal': ['brillat-savarin', 'cain', 'lucullus', 'amphibian', 'animal', 'anthropophagite', 'apache', 'aquatic', 'assassin', 'assassinator', 'barbarian', 'beast'],
    'canniness': ['italian hand', 'acuteness', 'animal cunning', 'art', 'artfulness', 'artifice', 'astuteness', 'austerity', 'austerity program', 'cageyness', 'calculation', 'callidity'],
    'canning': ['anhydration', 'blast-freezing', 'bottling', 'boxing', 'brining', 'corning', 'crating', 'curing', 'dehydration', 'desiccation', 'dry-curing', 'drying'],
    'cannon': ['aim at', 'appulse', 'artillery', 'backfire', 'backlash', 'bang', 'bang into', 'barrage', 'battery', 'blast', 'blitz', 'bombard'],
    'cannonade': ['aim at', 'air raid', 'antiaircraft barrage', 'barrage', 'blast', 'blitz', 'blitzkrieg', 'bomb', 'bombard', 'bombardment', 'boom', 'booming'],
    'cannonball': ['antelope', 'arrow', 'ball', 'bar shot', 'belly buster', 'belly flop', 'belly whopper', 'bird shot', 'blue darter', 'blue streak', 'buckshot', 'bullet'],
    'canny': ['byzantine', 'machiavellian', 'machiavellic', 'scotch', 'acute', 'adroit', 'arch', 'artful', 'astute', 'cagey', 'calculating', 'careful'],
    'canoe': ['almadia', 'ark', 'auxiliary', 'barge', 'boat', 'buss', 'cargo boat', 'carry sail', 'cat', 'catamaran', 'circumnavigate', 'coast'],
    'canoeing': ['boating', 'circumnavigation', 'coasting', 'cruising', 'gunkholing', 'motorboating', 'navigability', 'navigating', 'navigation', 'passage-making', 'periplus', 'rowing'],
    'canon': ['bible', 'douay bible', 'festschrift', 'grand penitentiary', 'holy father', 'holy scripture', 'holy writ', 'king james version', 'procrustean law', 'revised standard version', 'revised version', 'scripture'],
    'canonical': ['biblical', 'christian', 'gospel', 'mariological', 'mosaic', 'new-testament', 'old-testament', 'abbatial', 'abbatical', 'accepted', 'apocalyptic', 'apostolic'],
    'canonicate': ['abbacy', 'archbishopric', 'archdeaconry', 'archiepiscopacy', 'archiepiscopate', 'bishopdom', 'bishopric', 'canonry', 'cardinalship', 'chaplaincy', 'chaplainship', 'curacy'],
    'canonize': ['aggrandize', 'apotheose', 'apotheosize', 'beatify', 'bless', 'cleanse', 'consecrate', 'crown', 'dedicate', 'deify', 'devote', 'elevate'],
    'canopy': ['caelus', 'air', 'altar carpet', 'altar cloth', 'antimacassar', 'apply to', 'awning', 'azure', 'baldacchino', 'baldachin', 'belvedere', 'blanket'],
    'cant': ['aesopian language', 'babel', 'greek', 'pecksniffery', 'tartuffery', 'tartuffism', 'about ship', 'affectation', 'affectedness', 'alert', 'angle', 'angularity'],
    'cantabile': ['achingly sweet', 'agreeable', 'agreeable-sounding', 'appealing', 'aria', 'aria buffa', 'aria cantabile', 'aria da capo', 'aria da chiesa', 'aria di bravura', 'aria di coloratura', 'aria fugata'],
    'cantankerous': ['bad-tempered', 'bearish', 'bilious', 'bitchy', 'cankered', 'choleric', 'churlish', 'contrary', 'crabbed', 'crabby', 'cranky', 'cross'],
    'cantata': ['negro spiritual', 'anthem', 'canticle', 'choral singing', 'chorale', 'chorus', 'church music', 'doxology', 'glee', 'gospel', 'gospel music', 'hymn'],
    'canteen': ['px', 'automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'calabash', 'cantina', 'carafe', 'carboy'],
    'canter': ['holy willie', 'joseph surface', 'mawworm', 'pecksniff', 'pharisee', 'tartuffe', 'affecter', 'amble', 'bound', 'bum', 'burst', 'burst of speed'],
    'canticle': ['agnus dei', 'benedicite', 'brautlied', 'christmas carol', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'kunstlied', 'liebeslied', 'magnificat', 'miserere'],
    'cantina': ['automat', 'bar', 'barroom', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'chophouse', 'chuck wagon'],
    'canting': ['pecksniffian', 'tartuffian', 'tartuffish', 'affected', 'aslant', 'aslope', 'atilt', 'bevel', 'beveled', 'bias', 'biased', 'careening'],
    'canto': ['spenserian stanza', 'accompaniment', 'air', 'alto', 'antistrophe', 'aria', 'baritone', 'bass', 'basso continuo', 'basso ostinato', 'bassus', 'book'],
    'canton': ['kreis', 'achievement', 'alerion', 'animal charge', 'annulet', 'archbishopric', 'archdiocese', 'argent', 'armorial bearings', 'armory', 'arms', 'arrondissement'],
    'cantor': ['heldentenor', 'levite', 'meistersinger', 'alto', 'aria singer', 'baal kore', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante'],
    'canvas': ['agora', 'air brush', 'amphitheater', 'aquarelle', 'arena', 'art paper', 'athletic field', 'auditorium', 'background', 'bear garden', 'big top', 'boltrope'],
    'canvass': ['australian ballot', 'hare system', 'address', 'addresses', 'agitate', 'air', 'all-out campaign', 'analyze', 'angle for', 'argue', 'assemblage', 'assembly'],
    'canyon': ['abysm', 'abyss', 'arroyo', 'box canyon', 'breach', 'break', 'cavity', 'chap', 'chasm', 'check', 'chimney', 'chink'],
    'cap': ['balmoral', 'dutch cap', 'panama', 'panama hat', 'salvation army bonnet', 'stetson', 'acme', 'apex', 'apogee', 'ascender', 'astrakhan', 'back'],
    'capability': ['ability', 'ableness', 'address', 'adeptness', 'adequacy', 'adroitness', 'airmanship', 'aptitude', 'artfulness', 'artisanship', 'artistry', 'bravura'],
    'capable': ['able', 'accomplished', 'adapted', 'adept', 'adequate', 'adjusted', 'apt', 'au fait', 'capable of', 'checked out', 'clever', 'competent'],
    'capable of': ['answerable for', 'apt to', 'dependent on', 'exposed to', 'in danger of', 'incident to', 'liable to', 'likely to', 'naked to', 'obliged to', 'open to', 'prone to'],
    'capacious': ['abundant', 'ample', 'amplitudinous', 'broad', 'commodious', 'comprehensive', 'copious', 'deep', 'expandable', 'expansive', 'extended', 'extending'],
    'capacity': ['iq', 'sro', 'ability', 'ableness', 'accommodation', 'acumen', 'address', 'adeptness', 'adequacy', 'adroitness', 'airmanship', 'amplitude'],
    'caparison': ['accouterments', 'back band', 'backstrap', 'bearing rein', 'bellyband', 'bit', 'blinders', 'blinds', 'breeching', 'bridle', 'cavesson', 'checkrein'],
    'cape': ['inverness cape', 'academic gown', 'afghan', 'beak', 'bill', 'blouse', 'breakwater', 'burnoose', 'capote', 'cardinal', 'cashmere', 'cassock'],
    'caper': ['antic', 'beam', 'bob', 'bounce', 'burglary', 'capriole', 'caracole', 'carol', 'carry on', 'cavort', 'chirp', 'chirrup'],
    'capillary': ['aorta', 'arterial', 'arteriole', 'artery', 'blood vessel', 'bristlelike', 'carotid', 'cirrose', 'cirrous', 'fibered', 'fibroid', 'fibrous'],
    'capital': ['grade a', 'abecedarian', 'ability', 'acmatic', 'advantageous', 'all-absorbing', 'allographic', 'alphabetic', 'apical', 'arch', 'art center', 'ascender'],
    'capital punishment': ['beheading', 'burning', 'crucifixion', 'decapitation', 'decollation', 'defenestration', 'electrocution', 'execution', 'fusillade', 'garrote', 'gassing', 'hanging'],
    'capitalism': ['capitalistic system', 'finance capitalism', 'free competition', 'free economy', 'free enterprise', 'free trade', 'free-enterprise economy', 'free-enterprise system', 'individualism', 'isolationism', 'laissez-aller', 'laissez-faire'],
    'capitalist': ['daddy warbucks', 'wall streeter', 'billionaire', 'bloated plutocrat', 'bourgeois', 'economist', 'fat cat', 'finance capitalist', 'financial expert', 'financier', 'free-enterprise', 'individualist'],
    'capitalization': ['assets', 'available means', 'backing', 'balance', 'capital', 'capital gains distribution', 'capital goods', 'capital structure', 'circulating capital', 'corpus', 'deficit financing', 'equity capital'],
    'capitalize': ['aid', 'alphabet', 'alphabetize', 'angel', 'assist', 'back', 'balance', 'balance the books', 'bankroll', 'book', 'carry', 'carry over'],
    'capitalize on': ['benefit from', 'carpe diem', 'cash in', 'cash in on', 'clean up', 'clear', 'coin money', 'commercialize', 'exploit', 'gain by', 'gross', 'improve'],
    'capitulate': ['abandon', 'acknowledge defeat', 'acquiesce', 'beg a truce', 'bow', 'cave', 'cede', 'come to terms', 'concede', 'cry pax', 'cry quits', 'defer'],
    'capitulation': ['nato', 'seato', 'abandonment', 'account', 'accounts', 'alliance', 'body count', 'cartel', 'census', 'cession', 'concord', 'concordat'],
    'capping': ['a cut above', 'above', 'ahead', 'ascendant', 'better', 'chosen', 'closing', 'concluding', 'consummating', 'consummative', 'consummatory', 'crowning'],
    'caprice': ['arbitrariness', 'bee', 'boutade', 'capriccio', 'capriciousness', 'carelessness', 'characteristic', 'conceit', 'contrariety', 'crank', 'crankiness', 'crotchet'],
    'capricious': ['adrift', 'afloat', 'agnostic', 'aimless', 'alternating', 'ambiguous', 'ambitendent', 'ambivalent', 'amorphous', 'arbitrary', 'at loose ends', 'brittle'],
    'capriole': ['highland fling', 'and jump', 'bob', 'bounce', 'bound', 'broad jump', 'buck', 'buckjump', 'caper', 'caracole', 'cavort', 'clear'],
    'capsize': ['be lost', 'careen', 'come a cropper', 'culbuter', 'fall', 'fall down', 'fall flat', 'fall headlong', 'fall over', 'fall prostrate', 'flounder', 'founder'],
    'capsule': ['earth insertion', 'lem', 'lm', 'abbreviated', 'abbreviation', 'abbreviature', 'abrege', 'abridge', 'abridged', 'abridgment', 'abstract', 'abstracted'],
    'captain': ['adc', 'co', 'g-man', 'mp', 'od', 'administer', 'administrate', 'admiral', 'aeronaut', 'aeroplaner', 'aeroplanist', 'aide'],
    'caption': ['banner', 'banner head', 'drop head', 'dropline', 'epigraph', 'hanger', 'head', 'head up', 'heading', 'headline', 'jump head', 'legend'],
    'captious': ['bickering', 'carping', 'caviling', 'censorious', 'choplogic', 'contrary', 'critic', 'critical', 'cynical', 'demanding', 'equivocatory', 'evasive'],
    'captivate': ['allure', 'argue into', 'attract', 'becharm', 'beguile', 'bewitch', 'bring over', 'bring round', 'bring to reason', 'carry away', 'cast a spell', 'charm'],
    'captivated': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'becharmed', 'beguiled'],
    'captivating': ['alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'catching', 'charismatic', 'charming', 'coaxing'],
    'captive': ['pow', 'bond', 'bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'caged', 'cageling', 'catch', 'chain gang', 'chattel'],
    'captivity': ['absolutism', 'bond service', 'bondage', 'close arrest', 'confinement', 'control', 'custody', 'debt slavery', 'deprivation of freedom', 'detention', 'disenfranchisement', 'disfranchisement'],
    'capture': ['abduction', 'acquire', 'apprehend', 'apprehension', 'arrest', 'arrestation', 'arrestment', 'bag', 'be seized of', 'bear the palm', 'booty', 'bust'],
    'car': ['pullman', 'pullman car', 'auto', 'autocar', 'automobile', 'baggage car', 'boat', 'boxcar', 'buggy', 'bus', 'caboose', 'carriage'],
    'carabineer': ['nimrod', 'zouave', 'archer', 'artilleryman', 'bersagliere', 'bowman', 'cannoneer', 'chasseur', 'crack shot', 'dead shot', 'deadeye', 'dogface'],
    'caracole': ['amble', 'antic', 'beam', 'bob', 'bounce', 'canter', 'caper', 'capriole', 'carol', 'carry on', 'cavort', 'chirp'],
    'carapace': ['armor', 'chitin', 'cortex', 'elytron', 'episperm', 'lorica', 'lorication', 'mail', 'pericarp', 'plate', 'protective covering', 'scute'],
    'caravan': ['conestoga wagon', 'camp trailer', 'camper', 'cavalcade', 'column', 'cortege', 'covered wagon', 'dray', 'dress parade', 'flyover', 'funeral', 'haywagon'],
    'carbohydrate': ['barley sugar', 'beet sugar', 'cellulose', 'clinical dextran', 'deoxyribose', 'dextran', 'dextrose', 'erythrose', 'fructose', 'galactose', 'glucose', 'glycogen'],
    'carbon': ['alcohol', 'apograph', 'ash', 'ashes', 'benzine', 'brand', 'briquette', 'burnable', 'butane', 'calx', 'carbon copy', 'charcoal'],
    'carbon copy': ['doppelganger', 'actual thing', 'apograph', 'carbon', 'copy', 'dead ringer', 'ditto', 'double', 'duplicate', 'equivalent', 'exact counterpart', 'facsimile'],
    'carbon dioxide': ['dry ice', 'freon', 'acetylene', 'ammonia', 'argon', 'asphyxiating gas', 'butane', 'carbon monoxide', 'chlorine', 'coal gas', 'coolant', 'ethane'],
    'carbon tetrachloride': ['foamite', 'acid', 'automatic sprinkler', 'carbon tet', 'carbon-dioxide foam', 'deck gun', 'deluge set', 'extinguisher', 'fire apparatus', 'fire engine', 'fire hose', 'fire hydrant'],
    'carbonate': ['acetify', 'acidify', 'acidulate', 'aerate', 'aerify', 'alkalify', 'alkalize', 'atomize', 'borate', 'catalyze', 'chemical', 'chlorinate'],
    'carbonation': ['acetification', 'acidification', 'acidulation', 'alkalization', 'boiling', 'bubbliness', 'bubbling', 'catalysis', 'chemicalization', 'ebullience', 'ebulliency', 'ebullition'],
    'carbuncle': ['abscess', 'aposteme', 'bed sore', 'blain', 'bleb', 'blister', 'boil', 'bubo', 'bulla', 'bump', 'bunion', 'canker'],
    'carcass': ['aerial bomb', 'anatomy', 'antipersonnel bomb', 'appendicular skeleton', 'ashes', 'axial skeleton', 'body', 'bomb', 'bombshell', 'bones', 'cadaver', 'carrion'],
    'carcinogenic': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'cancerous', 'chlorotic', 'colicky', 'consumptive', 'dropsical', 'dyspeptic', 'edematous'],
    'carcinoma': ['benign tumor', 'callosity', 'callus', 'cancer', 'corn', 'cyst', 'excrescence', 'fungosity', 'fungus', 'growth', 'intumescence', 'malignant growth'],
    'card': ['id card', 'ace', 'act', 'agenda', 'badge', 'batting order', 'behave', 'best bower', 'bill', 'bill of fare', 'binding twine', 'blueprint'],
    'card carrier': ['greek', 'affiliate', 'associate', 'belonger', 'brother', 'card-carrying member', 'cardholder', 'charter member', 'clubber', 'clubman', 'clubwoman', 'committeeman'],
    'card carrying': ['authentic', 'bona fide', 'candid', 'dinkum', 'following the letter', 'genuine', 'good', 'honest', 'honest-to-god', 'inartificial', 'lawful', 'legitimate'],
    'cardholder': ['greek', 'affiliate', 'associate', 'bargainer', 'belonger', 'brother', 'business agent', 'card-carrier', 'card-carrying member', 'charter member', 'clubber', 'clubman'],
    'cardiac': ['abdominal', 'anal', 'appendical', 'cecal', 'colic', 'colonic', 'coronary', 'duodenal', 'enteric', 'gastric', 'ileac', 'intestinal'],
    'cardiac arrest': ['angina', 'angina pectoris', 'aortic insufficiency', 'aortic stenosis', 'apoplectic stroke', 'apoplexy', 'arrhythmia', 'arteriosclerosis', 'atherosclerosis', 'atrial fibrillation', 'auricular fibrillation', 'beriberi heart'],
    'cardinal': ['gaussian integer', 'grand penitentiary', 'holy father', 'titian', 'titian-red', 'abuna', 'algebraic number', 'algorismic', 'algorithmic', 'aliquot', 'all-absorbing', 'antipope'],
    'cardiovascular disease': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'chronic disease'],
    'cardsharp': ['adventurer', 'betting ring', 'bettor', 'boneshaker', 'bunco artist', 'bunco steerer', 'cardshark', 'cardsharper', 'carpetbagger', 'compulsive gambler', 'con artist', 'con man'],
    'care': ['tlc', 'abetment', 'accordance', 'accountability', 'acquittal', 'acquittance', 'adherence', 'administration', 'adverse circumstances', 'adversity', 'advertence', 'advertency'],
    'care for': ['administer to', 'attend', 'attend on', 'attend to', 'baby-sit', 'bandage', 'bathe', 'be fond of', 'be partial to', 'burn with love', 'chaperon', 'cherish'],
    'care of souls': ['advowson', 'apostleship', 'benefice', 'call', 'charge', 'curacy', 'cure', 'glebe', 'holy orders', 'incumbency', 'living', 'pastorage'],
    'careen': ['ascend', 'bank', 'blunder', 'bob', 'bobble', 'cant', 'capsize', 'career', 'climb', 'coggle', 'come a cropper', 'culbuter'],
    'career': ['brownian movement', 'accomplished', 'advance', 'advancement', 'advancing', 'angular motion', 'art', 'ascending', 'ascent', 'at concert pitch', 'axial motion', 'backflowing'],
    'carefree': ['airy', 'blase', 'blithe', 'breezy', 'buoyant', 'careless', 'contented', 'corky', 'debonair', 'easy', 'easygoing', 'feckless'],
    'careful': ['scotch', 'accurate', 'advertent', 'agog', 'alert', 'all ears', 'all eyes', 'assiduous', 'attentive', 'aware', 'calculating', 'canny'],
    'carefully': ['assiduously', 'cannily', 'cautiously', 'charily', 'circumspectly', 'considerately', 'diligently', 'discreetly', 'easy', 'economically', 'frugally', 'gingerly'],
    'carefulness': ['austerity', 'austerity program', 'calculation', 'canniness', 'care', 'careful consideration', 'caution', 'cautiousness', 'chariness', 'circumspection', 'concern', 'consciousness'],
    'careless': ['absent-minded', 'accident-prone', 'airy', 'all thumbs', 'aloof', 'apathetic', 'arbitrary', 'artless', 'ataractic', 'awkward', 'barbarous', 'beat-up'],
    'carelessly': ['a corps perdu', 'airily', 'any old way', 'any which way', 'anyhow', 'apathetically', 'at haphazard', 'at intervals', 'at random', 'bunglingly', 'by chance', 'by fits'],
    'carelessness': ['abandon', 'absentmindedness', 'accidia', 'acedia', 'aloofness', 'apathy', 'ataraxia', 'ataraxy', 'blowziness', 'blunderheadedness', 'blundering', 'boggling'],
    'caress': ['artful endearments', 'attouchement', 'blandishment', 'blandishments', 'breath', 'brush', 'brush by', 'cocker', 'coddle', 'come in contact', 'contact', 'contingence'],
    'caressing': ['amorous dalliance', 'billing and cooing', 'bundling', 'cuddling', 'dalliance', 'feeling', 'fingering', 'fondling', 'friction', 'frottage', 'handling', 'hugging'],
    'caretaker': ['air warden', 'attendant', 'castellan', 'conservator', 'curator', 'custodian', 'forest ranger', 'game warden', 'gamekeeper', 'governor', 'guardian', 'guardian angel'],
    'careworn': ['aggrieved', 'anguished', 'distressed', 'doleful', 'dolorous', 'drawn', 'dumb with grief', 'exhausted', 'fagged', 'grief-stricken', 'griefful', 'grieved'],
    'carfare': ['admission', 'admission fee', 'anchorage', 'brokerage', 'cellarage', 'charge', 'charges', 'cover charge', 'demand', 'dockage', 'dues', 'entrance fee'],
    'cargo': ['baggage', 'bale', 'burden', 'burdening', 'burthen', 'carload', 'cartload', 'charge', 'charging', 'consignment', 'cross', 'cumber'],
    'caricature': ['atticism', 'aggrandize', 'aggrandizement', 'agile wit', 'amplification', 'amplify', 'anamorphosis', 'animated cartoon', 'bad likeness', 'ballyhoo', 'belie', 'big talk'],
    'caricaturist': ['architectural draftsman', 'banana', 'burlesquer', 'cartoonist', 'clown', 'comedian', 'comic', 'crayonist', 'cutup', 'delineator', 'draftsman', 'drawer'],
    'caries': ['carrion', 'decay', 'decomposition', 'dry gangrene', 'dry rot', 'foulness', 'gangrene', 'gas gangrene', 'moist gangrene', 'mortification', 'necrosis', 'necrotic tissue'],
    'carmine': ['titian', 'titian-red', 'bricky', 'cardinal', 'carnation', 'carnelian', 'cerise', 'cherry', 'cherry-colored', 'cherry-red', 'crimson', 'damask'],
    'carnage': ['bloodbath', 'bloodshed', 'blue ruin', 'breakup', 'butchery', 'consumption', 'damnation', 'decimation', 'depredation', 'desolation', 'despoilment', 'despoliation'],
    'carnal': ['adamic', 'circean', 'philistine', 'amorous', 'animal', 'animalistic', 'aphrodisiomaniacal', 'backsliding', 'bawdy', 'beastlike', 'beastly', 'bestial'],
    'carnal knowledge': ['act of love', 'adultery', 'aphrodisia', 'ass', 'balling', 'climax', 'cohabitation', 'coition', 'coitus', 'coitus interruptus', 'commerce', 'congress'],
    'carnality': ['adam', 'philistinism', 'amorality', 'animalism', 'animality', 'backsliding', 'bawdiness', 'beastliness', 'bestiality', 'brutality', 'brutishness', 'carnal nature'],
    'carnival': ['broadway', 'mardi gras', 'saturnalia', 'banquet', 'blowout', 'burlesque', 'burlesque show', 'circus', 'coochie show', 'do', 'drama', 'entertainment industry'],
    'carnivore': ['brillat-savarin', 'chiroptera', 'lagomorpha', 'lucullus', 'primates', 'rodentia', 'amphibian', 'aquatic', 'biped', 'board-and-roomer', 'boarder', 'bon vivant'],
    'carnivorous': ['cannibal', 'cannibalistic', 'commensal', 'dietetic', 'dining', 'eating', 'feeding', 'flesh-eating', 'fruitarian', 'gastronomic', 'gluttonous', 'grain-eating'],
    'carol': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'alba', 'anthem', 'art song', 'aubade', 'ballad', 'ballade', 'ballata'],
    'carom': ['appulse', 'backfire', 'backlash', 'backlashing', 'bang', 'bang into', 'boomerang', 'bounce', 'bounce back', 'bound', 'bound back', 'brunt'],
    'carousal': ['bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'bender', 'binge', 'booze', 'bout', 'brannigan', 'bust', 'carouse', 'celebration'],
    'carouse': ['bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'bender', 'binge', 'booze', 'boozer', 'bout', 'brannigan', 'bust', 'carousal'],
    'carousel': ['ferris wheel', 'highland games', 'olympiad', 'olympic games', 'chute-the-chutes', 'chutes', 'disk', 'field day', 'flying horses', 'games', 'gymkhana', 'meet'],
    'carp': ['bug', 'bully', 'bullyrag', 'carp at', 'catch at straws', 'cavil', 'complain', 'criticize', 'cut up', 'fault-find', 'find fault', 'fret at'],
    'carpe diem': ['capitalize on', 'cash in', 'conspicuous consumption', 'dissipation', 'extravagance', 'improve the occasion', 'incontinence', 'intemperance', 'lavishness', 'leaking purse', 'loose purse strings', 'make no provision'],
    'carpet': ['axminster', 'brussels carpet', 'caucasian rug', 'chinese rug', 'east indian rug', 'indian rug', 'oriental rug', 'persian rug', 'savonnerie', 'turkish rug', 'wilton', 'asphalt'],
    'carpetbagger': ['bunco artist', 'bunco steerer', 'cardsharp', 'cardsharper', 'con artist', 'con man', 'confidence man', 'crimp', 'horse coper', 'horse trader', 'jackleg', 'land pirate'],
    'carping': ['adverse criticism', 'animadversion', 'aspersion', 'bad notices', 'bad press', 'blameful', 'captious', 'captiousness', 'cavil', 'caviling', 'censorious', 'censoriousness'],
    'carriage': ['cape cart', 'concord buggy', 'pullman', 'pullman car', 'whitechapel cart', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'aid'],
    'carriage trade': ['vanity fair', 'beau monde', 'beautiful people', 'best people', 'blue blood', 'cafe society', 'clientage', 'clientele', 'cream of society', 'custom', 'drawing room', 'elite'],
    'carried away': ['abandoned', 'agog', 'amok', 'aquiver', 'aroused', 'atingle', 'atwitter', 'bellowing', 'berserk', 'bursting', 'bursting with happiness', 'delirious'],
    'carrier': ['aquarius', 'ganymede', 'hebe', 'hermes', 'iris', 'mercury', 'paul revere', 'pheidippides', 'advocate', 'aerial infection', 'airborne infection', 'aircraft'],
    'carrier pigeon': ['aquarius', 'ganymede', 'hebe', 'bearer', 'bheesty', 'busboy', 'caddie', 'cargo handler', 'carrier', 'carter', 'common carrier', 'conveyer'],
    'carrion': ['ashes', 'bilge', 'bilgewater', 'body', 'bones', 'cadaver', 'carcass', 'caries', 'clay', 'corpse', 'corpus delicti', 'corruption'],
    'carry': ['accept', 'accomplish', 'acquit', 'act', 'act up', 'adopt', 'affiliate', 'afford support', 'air express', 'airfreight', 'airlift', 'announce'],
    'carry away': ['abduce', 'abduct', 'allure', 'annihilate', 'attract', 'bear the palm', 'becharm', 'beguile', 'bereave of life', 'bewitch', 'captivate', 'capture'],
    'carry off': ['abduce', 'abduct', 'accomplish', 'achieve', 'annihilate', 'bear the palm', 'bereave of life', 'bring about', 'bring off', 'bring through', 'bring to effect', 'bring to pass'],
    'carry on': ['abide', 'act up', 'antic', 'assault', 'attack', 'barbarize', 'batter', 'be enthusiastic', 'be livid', 'be patient', 'be pissed', 'be responsible for'],
    'carry out': ['abide by', 'adhere to', 'administer', 'administrate', 'apply', 'be responsible for', 'bring about', 'bring off', 'bring to effect', 'bring to pass', 'carry into effect', 'carry into execution'],
    'carry over': ['assign', 'balance', 'balance the books', 'book', 'capitalize', 'carry', 'cast up accounts', 'charge off', 'close out', 'close the books', 'communicate', 'consign'],
    'carry through': ['abide', 'abide by', 'adhere to', 'administer', 'be patient', 'be responsible for', 'bear with composure', 'bring about', 'bring off', 'bring to effect', 'bring to pass', 'carry into effect'],
    'carry weight': ['amount to something', 'balance', 'be featured', 'be heavy', 'be influential', 'be persuasive', 'be prominent', 'be somebody', 'be something', 'count', 'counterbalance', 'cut ice'],
    'carrying': ['accoutered', 'aid', 'air express', 'airfreight', 'airlift', 'anticipating', 'armed', 'asportation', 'backing', 'bearing', 'big with child', 'big-laden'],
    'cart': ['barge', 'barrow', 'boat', 'bring', 'bus', 'carry', 'coach', 'convey', 'coup-cart', 'dogcart', 'drag', 'dray'],
    'carte blanche': ['ample scope', 'authority', 'blank check', 'clearance', 'copyright', 'discretion', 'dispensation', 'elbowroom', 'favor', 'field', 'franchise', 'free course'],
    'cartel': ['aktiengesellschaft', 'anschluss', 'nato', 'seato', 'accord', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'aktiebolag', 'alliance'],
    'carter': ['aquarius', 'ganymede', 'hebe', 'jehu', 'bearer', 'bheesty', 'bullwhacker', 'busboy', 'cabby', 'cabdriver', 'cabman', 'caddie'],
    'cartography': ['lambert conformal projection', 'mercator projection', 'miller projection', 'aeronautical chart', 'altimetry', 'astronomical chart', 'atlas', 'azimuthal projection', 'bathymetry', 'biometrics', 'biometry', 'cadastration'],
    'carton': ['ammunition box', 'ark', 'attache case', 'bag', 'bandolier', 'barrel', 'basket', 'billfold', 'bin', 'boot', 'bottle', 'box'],
    'cartoon': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'black and white', 'black-and-white film', 'blueprint', 'brouillon', 'caricature', 'charcoal', 'charcoal drawing'],
    'cartridge': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'backing', 'ball cartridge', 'bibliofilm', 'binaural system', 'bipack', 'bitch box'],
    'carve': ['allot', 'amputate', 'apportion', 'assemble', 'autolithograph', 'ax', 'be a printmaker', 'bisect', 'block out', 'book', 'butcher', 'calendar'],
    'carver': ['burinist', 'cerographer', 'chalcographer', 'chaser', 'clay modeler', 'earth artist', 'engraver', 'etcher', 'figurer', 'figuriste', 'gem carver', 'gem engraver'],
    'carving': ['bust', 'doll', 'dolly', 'dummy', 'fantoccini', 'figure', 'figurehead', 'figurine', 'gingerbread man', 'lay figure', 'man of straw', 'manikin'],
    'casanova': ['artful dodger', 'don juan', 'lothario', 'machiavel', 'machiavelli', 'machiavellian', 'romeo', 'actor', 'amoroso', 'bamboozler', 'beau', 'befuddler'],
    'cascade': ['niagara', 'bag', 'barf', 'belch', 'bring up', 'burst', 'cataract', 'chute', 'collapse', 'come down', 'comedown', 'crash'],
    'case': ['bible truth', 'smyth sewing', 'abessive', 'ablative', 'absolute fact', 'accepted fact', 'accusative', 'action', 'actual fact', 'adessive', 'admitted fact', 'afghan'],
    'case hardened': ['philistine', 'acclimated', 'acclimatized', 'accommodated', 'accustomed', 'adapted', 'adjusted', 'backed', 'balking', 'balky', 'bigoted', 'brazen'],
    'case history': ['clio', 'muse of history', 'adventures', 'anamnesis', 'annals', 'associative anamnesis', 'autobiography', 'biographical sketch', 'biography', 'case', 'catamnesis', 'chronicle'],
    'case in point': ['case', 'citation', 'cross reference', 'demonstration', 'emblem', 'example', 'exemplar', 'exemplification', 'explanation', 'exponent', 'illustration', 'instance'],
    'casebook': ['abecedarium', 'abecedary', 'alphabet book', 'atlas', 'battledore', 'calendar', 'catalog', 'catalogue raisonne', 'city directory', 'classified catalog', 'concordance', 'cyclopedia'],
    'casement': ['bay', 'bay window', 'bow window', 'cadre', 'case', 'casement window', 'casing', 'chassis', 'doorframe', 'fabric', 'fan window', 'fanlight'],
    'cash': ['cod', 'acquitment', 'acquittal', 'acquittance', 'amortization', 'amortizement', 'and pence', 'available funds', 'balance in hand', 'banknotes', 'bills', 'binder'],
    'cash in on': ['benefit from', 'capitalize on', 'carpe diem', 'cash in', 'clean up', 'clear', 'coin money', 'commercialize', 'exploit', 'gain by', 'gross', 'improve'],
    'cashbook': ['domesday book', 'account book', 'accounts payable ledger', 'accounts receivable ledger', 'address book', 'adversaria', 'album', 'annual', 'appointment calendar', 'appointment schedule', 'balance sheet', 'bank ledger'],
    'cashbox': ['fort knox', 'bank', 'bursary', 'cash register', 'chest', 'coffer', 'coin box', 'depository', 'exchequer', 'fisc', 'gold depository', 'locker'],
    'cashier': ['accountant', 'auditor', 'ax', 'bank clerk', 'bank manager', 'bank officer', 'bank president', 'banker', 'banking executive', 'bar', 'bill broker', 'bookkeeper'],
    'casino': ['amusement park', 'ballroom', 'baths', 'betting house', 'betting parlor', 'cabaret', 'cafe chantant', 'cafe dansant', 'club', 'clubhouse', 'crib', 'dance floor'],
    'cask': ['bag', 'barrel', 'basket', 'bole', 'bottle', 'box', 'box up', 'breaker', 'butt', 'can', 'capsule', 'carton'],
    'casket': ['bottle up', 'box', 'box in', 'box up', 'burial case', 'cabin', 'case', 'chest', 'cloister', 'closet', 'coffer', 'coffin'],
    'cassandra': ['druid', 'eeyore', 'jeremiah', 'admonisher', 'astrologer', 'augur', 'calamity howler', 'cautioner', 'crepehanger', 'crystal gazer', 'cynic', 'defeatist'],
    'cassock': ['churchman', 'cleric', 'clerical', 'clerk', 'confessor', 'cure', 'divine', 'ecclesiastic', 'father', 'father confessor', 'father in christ', 'gallach'],
    'cast': ['ace bandage', 'band-aid', 'platonic form', 'platonic idea', 'a thing for', 'abandon', 'abdicate', 'about ship', 'account', 'achromatism', 'acting company', 'actor'],
    'cast a spell': ['becharm', 'beguile', 'bewitch', 'captivate', 'carry away', 'charm', 'enchant', 'enrapture', 'enravish', 'enthrall', 'entrance', 'fascinate'],
    'cast away': ['abandon', 'beach', 'blow', 'break ground', 'cast', 'cast aside', 'cast loose', 'cast off', 'cat the anchor', 'chuck', 'consume', 'deep-six'],
    'cast down': ['abase', 'abash', 'abashed', 'afflicted', 'agitated', 'bad', 'baffle', 'balk', 'beat down', 'beset', 'bilk', 'blow down'],
    'cast forth': ['attenuate', 'blow off', 'blow out', 'clear away', 'debouch', 'decant', 'dilute', 'discharge', 'disembogue', 'disgorge', 'dispel', 'dissipate'],
    'cast off': ['abandon', 'abandoned', 'abrupt', 'abstract', 'adrift', 'afloat', 'alienate', 'aweigh', 'break ground', 'cast', 'cast aside', 'cast away'],
    'cast out': ['abrupt', 'abstract', 'alienate', 'ban', 'banish', 'bicker', 'blackball', 'boot out', 'bounce', 'cast', 'cast off', 'caterwaul'],
    'cast up': ['add up', 'boost', 'buoy up', 'cipher up', 'count up', 'detail', 'elevate', 'erect', 'escalate', 'figure up', 'foot up', 'heave'],
    'castanets': ['battery', 'bells', 'bones', 'celesta', 'chime', 'chimes', 'clappers', 'crash cymbal', 'cymbals', 'finger cymbals', 'gamelan', 'glockenspiel'],
    'castaway': ['dp', 'ishmael', 'abandoned', 'aground', 'cast-off', 'castoff', 'declasse', 'deep six', 'derelict', 'deserted', 'discard', 'discarded'],
    'caste': ['ashram', 'blood', 'body', 'bracket', 'branch', 'category', 'clan', 'class', 'colony', 'commonwealth', 'commune', 'community'],
    'castellan': ['air warden', 'attendant', 'captain', 'caretaker', 'chatelain', 'chatelaine', 'commandant', 'commander', 'conservator', 'curator', 'custodian', 'director'],
    'castellate': ['arm', 'armor', 'armor-plate', 'bank', 'barricade', 'battle', 'blockade', 'bulwark', 'crenellate', 'dig in', 'embattle', 'entrench'],
    'castigate': ['assail', 'attack', 'baste', 'beat', 'belabor', 'berate', 'blister', 'bring to account', 'bring to book', 'call to account', 'carpet', 'chasten'],
    'casting': ['cysp sculpture', 'adding', 'anaglyptics', 'anaglyptography', 'angling', 'archery', 'architectural sculpture', 'architecture', 'assembly', 'bone-carving', 'building', 'bullion'],
    'castle': ['acropolis', 'bastion', 'beachhead', 'bishop', 'blockhouse', 'bridgehead', 'bunker', 'chateau', 'chessman', 'citadel', 'court', 'donjon'],
    'castle building': ['walter mitty', 'absence of mind', 'absentmindedness', 'absorption', 'abstractedness', 'abstraction', 'bemusement', 'brown study', 'daydream', 'daydreamer', 'daydreaming', 'depth of thought'],
    'castoff': ['castaway', 'deep six', 'derelict', 'discard', 'discarding', 'disposal', 'dogie', 'dumping', 'elimination', 'flotsam', 'flotsam and jetsam', 'foundling'],
    'castrate': ['alter', 'beat down', 'bleed', 'break', 'browbeat', 'bulldoze', 'bully', 'change', 'clamp down on', 'coerce', 'compel', 'cow'],
    'castrated': ['asexual', 'bad', 'butchered', 'cold', 'crippled', 'cut short', 'debilitated', 'demasculinized', 'devitalized', 'disabled', 'docked', 'effeminized'],
    'casual': ['bohemian', 'charley', 'mickey mouse', 'vc', 'vietcong', 'accessory', 'accidental', 'accidentally', 'additional', 'adscititious', 'adventitious', 'affable'],
    'casualty': ['accident', 'adventure', 'blow', 'body count', 'calamity', 'casualties', 'cataclysm', 'catastrophe', 'chance hit', 'collision', 'contingency', 'contingent'],
    'casuistry': ['christian ethics', 'stoicism', 'aesthetics', 'altruistic ethics', 'apologetics', 'apologia', 'apology', 'apparent soundness', 'aretaics', 'argument', 'argumentation', 'axiology'],
    'cat': ['abyssinian cat', 'adamite', 'angora cat', 'argus', 'cheshire cat', 'chinchilla cat', 'himalayan cat', 'maltese cat', 'manx cat', 'persian cat', 'alley cat', 'barf'],
    'catabolism': ['assimilation', 'avatar', 'basal metabolism', 'catalysis', 'consubstantiation', 'displacement', 'heterotopia', 'metabolism', 'metagenesis', 'metamorphism', 'metamorphosis', 'metastasis'],
    'cataclysm': ['accident', 'alluvion', 'alluvium', 'apoplexy', 'bloodless revolution', 'blow', 'bouleversement', 'breakdown', 'breaking up', 'breakup', 'calamity', 'casualty'],
    'cataclysmic': ['baneful', 'black', 'calamitous', 'cataclysmal', 'catastrophic', 'consuming', 'consumptive', 'convulsive', 'deadly', 'demolishing', 'demolitionary', 'depredatory'],
    'catacombs': ['barrow', 'beehive tomb', 'bone house', 'box grave', 'burial', 'burial chamber', 'burial mound', 'cenotaph', 'charnel house', 'cist', 'cist grave', 'cromlech'],
    'catafalque': ['balcony', 'dais', 'emplacement', 'estrade', 'floor', 'funeral car', 'gallery', 'hearse', 'heliport', 'hustings', 'landing', 'landing pad'],
    'catalepsy': ['ko', 'abeyance', 'amnesia', 'apathy', 'apoplexy', 'blackout', 'cataplexy', 'catatonia', 'catatonic stupor', 'catatony', 'coma', 'daydreaming'],
    'catalog': ['baedeker', 'domesday book', 'yellow pages', 'account', 'account book', 'address book', 'admit', 'adversaria', 'album', 'alphabetize', 'analyze', 'annals'],
    'catalysis': ['acetification', 'acidification', 'acidulation', 'alkalization', 'avatar', 'carbonation', 'catabolism', 'catalyst', 'chemicalization', 'consubstantiation', 'decay', 'dialysis'],
    'catalyst': ['agent', 'agent provocateur', 'agitator', 'agitprop', 'alterant', 'alterative', 'alterer', 'author', 'begetter', 'beginner', 'catalysis', 'catalytic agent'],
    'catapult': ['arbalest', 'ballista', 'booster rocket', 'bowl', 'cast', 'chuck', 'chunk', 'dart', 'dash', 'fire', 'fling', 'flip'],
    'cataract': ['niagara', 'ablepsia', 'amaurosis', 'benightedness', 'blepharitis', 'blind side', 'blind spot', 'blindfolding', 'blinding', 'blindness', 'blurring the eyes', 'cascade'],
    'catastrophe': ['accident', 'action', 'anagnorisis', 'angle', 'apodosis', 'architectonics', 'architecture', 'argument', 'atmosphere', 'background', 'bad luck', 'bitter end'],
    'catastrophic': ['baneful', 'black', 'calamitous', 'cataclysmal', 'cataclysmic', 'consuming', 'consumptive', 'deadly', 'demolishing', 'demolitionary', 'depredatory', 'desolating'],
    'catatonic': ['abeyant', 'affectless', 'anesthetized', 'apathetic', 'arctic', 'asleep', 'autistic', 'blunt', 'brain-damaged', 'brain-injured', 'cataleptic', 'certifiable'],
    'catatonic stupor': ['abstraction', 'abulia', 'alienation', 'amnesia', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'catalepsy', 'cataplexy', 'compulsion', 'daydreaming'],
    'catawampous': ['agee', 'agee-jawed', 'askance', 'askant', 'askew', 'askewgee', 'asquint', 'awry', 'catawamptious', 'cockeyed', 'crooked', 'skew'],
    'catcall': ['bronx', 'bronx cheer', 'klaxon', 'bird', 'boiler factory', 'boiler room', 'boo', 'booing', 'bull-roarer', 'cherry bomb', 'clack', 'clacker'],
    'catch': ['od', 'abash', 'abduction', 'absorb', 'absorb the attention', 'accept', 'acquire', 'acquisition', 'allure', 'ambition', 'anchor', 'appreciate'],
    'catch at straws': ['ask for it', 'be hopeful', 'be rash', 'be reckless', 'carp', 'cavil', 'cut up', 'fault-find', 'find fault', 'go too far', 'keep hope alive', 'keep hoping'],
    'catch on': ['absorb', 'appreciate', 'apprehend', 'ascertain', 'assimilate', 'be blooded', 'be hep to', 'be on to', 'be successful', 'be wise to', 'be with one', 'become popular'],
    'catch up': ['abduct', 'carry off', 'catch up with', 'come up to', 'come up with', 'ensnare', 'entangle', 'entrap', 'fascinate', 'gain on', 'gain upon', 'grip'],
    'catcher': ['amateur athlete', 'archer', 'athlete', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'blocking back', 'bowman', 'captor', 'capturer'],
    'catching': ['alluring', 'annexational', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'charismatic', 'charming'],
    'catchword': ['acknowledgments', 'adage', 'ana', 'analects', 'aphorism', 'apothegm', 'axiom', 'back', 'back matter', 'bastard title', 'battle cry', 'bibliography'],
    'catchy': ['achingly sweet', 'agreeable', 'agreeable-sounding', 'appealing', 'ariose', 'arioso', 'beguiling', 'broken', 'canorous', 'cantabile', 'capricious', 'careening'],
    'catechism': ['weltanschauung', 'articles of religion', 'bone of contention', 'credenda', 'credo', 'creed', 'cross-interrogatory', 'cross-question', 'cult', 'debating point', 'demand', 'doctrinal statement'],
    'catechize': ['ask', 'beat into', 'brainwash', 'broaden the mind', 'civilize', 'condition', 'demonstrate', 'direct', 'edify', 'educate', 'enlighten', 'examine'],
    'catechumen': ['christian', 'god-fearing man', 'abecedarian', 'accepter', 'alphabetarian', 'apprentice', 'articled clerk', 'baby', 'beginner', 'believer', 'boot', 'brother'],
    'categorical': ['a fortiori', 'a posteriori', 'a priori', 'absolute', 'admitting no exception', 'all-out', 'analytic', 'apodeictic', 'apodictic', 'authoritative', 'certain', 'characteristic'],
    'categorize': ['alphabetize', 'analyze', 'appraise', 'arrange', 'assess', 'assort', 'bolt', 'break down', 'catalog', 'class', 'classify', 'codify'],
    'category': ['area', 'blood', 'bracket', 'branch', 'caste', 'clan', 'class', 'classification', 'department', 'division', 'estate', 'grade'],
    'catenary': ['arc', 'bow', 'cadence', 'catacaustic', 'caustic', 'circle', 'conchoid', 'crook', 'curl', 'curve', 'decline', 'decurrence'],
    'cater': ['baby', 'bunker', 'coal', 'coddle', 'cosset', 'dance attendance on', 'feed', 'fill up', 'forage', 'fuel', 'gas', 'gas up'],
    'cater to': ['attend', 'baby', 'cocker', 'coddle', 'cosset', 'cotton', 'do service', 'favor', 'fetch and carry', 'give way to', 'gratify', 'humor'],
    'catercorner': ['across', 'athwart', 'bendwise', 'bias', 'biased', 'biaswise', 'catercornered', 'catercornerways', 'cornerways', 'cornerwise', 'crossways', 'crosswise'],
    'caterer': ['chandler', 'commissariat', 'commissary', 'donor', 'furnisher', 'manciple', 'merchant', 'patron', 'provider', 'provisioner', 'purveyor', 'quartermaster'],
    'catering': ['accouterment', 'armament', 'baking', 'barbecuing', 'basting', 'boiling', 'braising', 'brewing', 'broil', 'broiling', 'chandlery', 'cookery'],
    'caterpillar': ['arachnid', 'arthropod', 'aurelia', 'beetle', 'bug', 'centipede', 'chilopod', 'chrysalis', 'cocoon', 'daddy longlegs', 'diplopod', 'fly'],
    'caterwaul': ['bark', 'battle cry', 'bawl', 'bay', 'bell', 'bellow', 'bicker', 'blare', 'blat', 'blate', 'bleat', 'bray'],
    'catharsis': ['bm', 'abreaction', 'abstersion', 'acting-out', 'bloody flux', 'bowdlerization', 'bowel movement', 'cleaning', 'cleansing', 'crap', 'defecation', 'dejection'],
    'cathartic': ['abstergent', 'alleviating', 'alleviative', 'analgesic', 'anesthetic', 'anodyne', 'aperient', 'assuasive', 'balmy', 'balsamic', 'benumbing', 'carminative'],
    'cathedral': ['accepted', 'approved', 'authentic', 'authoritative', 'basilica', 'bethel', 'cathedral church', 'church', 'church house', 'conventicle', 'duomo', 'ex cathedra'],
    'catheter': ['adjutage', 'drainpipe', 'efflux tube', 'fire hose', 'flue pipe', 'funnel', 'garden hose', 'gas pipe', 'hose', 'hosepipe', 'nipple', 'organ pipe'],
    'cathode ray': ['becquerel ray', 'grenz ray', 'roentgen ray', 'x radiation', 'x ray', 'actinic ray', 'alpha radiation', 'alpha ray', 'anode ray', 'beta radiation', 'beta ray', 'canal ray'],
    'catholic': ['all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'allover', 'broad', 'broad-gauged'],
    'cathouse': ['bagnio', 'bawdy house', 'bawdyhouse', 'bordello', 'brothel', 'clip joint', 'crib', 'den', 'den of thieves', 'den of vice', 'disorderly house', 'dive'],
    'cation': ['acid', 'acidity', 'agent', 'alkali', 'alkalinity', 'alloisomer', 'anion', 'antacid', 'atom', 'base', 'biochemical', 'chemical'],
    'cattle': ['alderney', 'animalia', 'ayrshire', 'brahman', 'chiroptera', 'dexter', 'durham', 'dutch belted', 'galloway', 'hereford', 'holstein', 'indian buffalo'],
    'cattleman': ['breaker', 'breeder', 'broncobuster', 'buckaroo', 'cow keeper', 'cowboy', 'cowgirl', 'cowhand', 'cowherd', 'cowman', 'cowpuncher', 'dairy farmer'],
    'catty': ['abusive', 'active', 'back-biting', 'belittling', 'bitchy', 'brisk', 'calumniatory', 'calumnious', 'catlike', 'cattish', 'censorious', 'contemptuous'],
    'cattycorner': ['across', 'athwart', 'bendwise', 'bias', 'biased', 'biaswise', 'catercorner', 'catercornered', 'catercornerways', 'cornerways', 'cornerwise', 'crossways'],
    'catwalk': ['bifrost', 'alameda', 'bascule bridge', 'bateau bridge', 'beaten path', 'beaten track', 'berm', 'bicycle path', 'boardwalk', 'bridge', 'bridle path', 'cantilever bridge'],
    'caucasian': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro', 'oriental'],
    'caucus': ['assemblee', 'assembly', 'assignation', 'at home', 'ball', 'brawl', 'breakaway group', 'by-election', 'camp', 'closed primary', 'colloquium', 'commission'],
    'caudal': ['boundary', 'caudate', 'caudated', 'caudiform', 'conclusive', 'definitive', 'determinative', 'endmost', 'eventual', 'extreme', 'farthest', 'final'],
    'caught': ['aground', 'anchored', 'arrested', 'chained', 'charmed', 'enchanted', 'enthralled', 'fascinated', 'fast', 'fastened', 'fixed', 'gripped'],
    'caught short': ['ad-lib', 'astonished', 'caught napping', 'caught off balance', 'extemporaneous', 'extemporized', 'haphazard', 'hasty', 'impromptu', 'improvised', 'makeshift', 'precipitate'],
    'caught up in': ['absorbed', 'absorbed in', 'buried in', 'contemplating', 'contemplative', 'devoted', 'devoted to', 'engaged', 'engrossed', 'engrossed in', 'enmeshed in', 'entangled in'],
    'caulk': ['bar', 'bind', 'block', 'block up', 'blockade', 'bung', 'chink', 'choke', 'choke off', 'choke up', 'clog', 'clog up'],
    'cause': ['accomplish', 'achieve', 'act', 'action', 'activity', 'agency', 'agent', 'ambition', 'antecedent', 'aspiration', 'author', 'basis'],
    'causeless': ['accidental', 'adventitious', 'aimless', 'aleatory', 'casual', 'chance', 'chancy', 'contingent', 'designless', 'destinal', 'dicey', 'driftless'],
    'causerie': ['article', 'chat', 'chin', 'coze', 'cozy chat', 'descant', 'discourse', 'discussion', 'disquisition', 'dissertation', 'essay', 'etude'],
    'causeway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'caustic': ['rabelaisian', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'actual cautery', 'acute'],
    'cauterant': ['acid', 'actual cautery', 'brand', 'brand iron', 'branding iron', 'burning', 'calefacient', 'calefactive', 'calefactory', 'caustic', 'cauter', 'cauterizer'],
    'cauterize': ['blaze', 'blister', 'brand', 'burn', 'burn in', 'burn off', 'cast', 'char', 'coal', 'crack', 'cupel', 'flame'],
    'caution': ['tlc', 'admonish', 'admonishment', 'admonition', 'advice', 'advise', 'advising', 'advocacy', 'alarm', 'alert', 'alerting', 'alertness'],
    'cautious': ['alert', 'ambling', 'attentive', 'cagey', 'calculating', 'canny', 'careful', 'chary', 'circumspect', 'claudicant', 'considerate', 'cozy'],
    'cavalcade': ['caravan', 'column', 'cortege', 'dress parade', 'flyover', 'funeral', 'line', 'march past', 'motorcade', 'mule train', 'pack train', 'parade'],
    'cavalier': ['bayard', 'casanova', 'don juan', 'don quixote', 'gawain', 'lancelot', 'lothario', 'ritter', 'romeo', 'sidney', 'sir galahad', 'abrupt'],
    'cave': ['abri', 'air-raid shelter', 'antre', 'bend', 'bomb shelter', 'bombproof', 'bow', 'bowl', 'break', 'break down', 'breakdown', 'breaking up'],
    'cave in': ['back down', 'bowl', 'breach', 'break', 'break down', 'break in', 'break into', 'break off combat', 'break open', 'break through', 'breakdown', 'breaking up'],
    'caveat': ['admonishment', 'admonition', 'advice', 'advising', 'advocacy', 'alarm', 'bench warrant', 'briefing', 'capias', 'caution', 'cautioning', 'consultation'],
    'caveman': ['bronze age man', 'hominidae', 'iron age man', 'stone age man', 'aboriginal', 'aborigine', 'ancient', 'antediluvian', 'anthropoid', 'ape-man', 'autochthon', 'bucko'],
    'cavern': ['abri', 'antre', 'bunker', 'burrow', 'cave', 'cove', 'dugout', 'foxhole', 'grot', 'grotto', 'hole', 'lair'],
    'cavernous': ['abysmal', 'abyssal', 'boat-shaped', 'boatlike', 'bottomless', 'bowl-shaped', 'bowllike', 'cavelike', 'commodious', 'concave', 'concaved', 'craterlike'],
    'caviar': ['albumen', 'anguille', 'eel', 'egg', 'egg white', 'eggshell', 'fish', 'fish eggs', 'glair', 'kipper', 'kippered salmon', 'ovule'],
    'cavil': ['adverse criticism', 'animadversion', 'argue', 'argufy', 'around the bush', 'aspersion', 'bad notices', 'bad press', 'bandy words', 'beat about', 'beg the question', 'bicker'],
    'caviling': ['captious', 'carping', 'censorious', 'contrary', 'critic', 'demanding', 'exacting', 'faultfinding', 'finicky', 'fussy', 'hairsplitting', 'hypercritical'],
    'cavity': ['abysm', 'abyss', 'alveolation', 'alveolus', 'antrum', 'aperture', 'armpit', 'arroyo', 'basin', 'booth', 'bowl', 'box'],
    'cavort': ['antic', 'bob', 'bounce', 'bound', 'caper', 'capriole', 'caracole', 'carry on', 'curvet', 'cut a dido', 'cut capers', 'cut up'],
    'caw': ['belch', 'blare', 'blat', 'bray', 'burr', 'buzz', 'cackle', 'call', 'carol', 'chatter', 'cheep', 'chirk'],
    'cay': ['ait', 'archipelago', 'atoll', 'bar', 'continental island', 'coral head', 'coral island', 'coral reef', 'holm', 'insularity', 'island', 'island group'],
    'cease': ['abandon', 'abdicate', 'abjure', 'abort', 'acknowledge defeat', 'ad infinitum', 'be consumed', 'be done for', 'be gone', 'be no more', 'belay', 'calm'],
    'cease fire': ['pax dei', 'pax romana', 'peace of god', 'abeyance', 'armistice', 'break', 'breathing spell', 'buffer zone', 'caesura', 'cooling-off period', 'day off', 'demilitarized zone'],
    'ceaseless': ['ageless', 'amaranthine', 'articulated', 'catenated', 'chattering', 'coeternal', 'concatenated', 'connected', 'constant', 'continual', 'continued', 'continuing'],
    'cecal': ['abdominal', 'anal', 'appendical', 'blank', 'blind', 'blind-alley', 'cardiac', 'choked', 'choked off', 'closed', 'colic', 'colonic'],
    'cede': ['abalienate', 'abandon', 'abdicate', 'abjure', 'accord', 'acknowledge defeat', 'alien', 'alienate', 'amortize', 'assign', 'barter', 'beg a truce'],
    'ceil': ['bonnet', 'cap', 'coif', 'cork', 'crown', 'dome', 'face', 'feather', 'fill', 'fur', 'hat', 'hood'],
    'ceiling': ['cat', 'acme', 'aerospace', 'aerosphere', 'air hole', 'air pocket', 'airspace', 'all', 'altitude', 'altitude peak', 'apogee', 'atmospheric visibility'],
    'celebrate': ['administer communion', 'adulate', 'advertise', 'apotheosize', 'attend communion', 'attend mass', 'beat the drum', 'belaud', 'bepraise', 'blare', 'blare forth', 'blaze'],
    'celebrated': ['acclaimed', 'conspicuous', 'distinguished', 'eminent', 'esteemed', 'estimable', 'exceptional', 'extraordinary', 'fabled', 'famed', 'famous', 'far-famed'],
    'celebration': ['sabbatarianism', 'agape', 'asperges', 'aspersion', 'auricular confession', 'baccalaureate service', 'bacchanal', 'bacchanalia', 'bacchanalian', 'banquet', 'bar mitzvah', 'bas mitzvah'],
    'celebrity': ['establishment', 'pr', 'vip', 'acclaim', 'ballyhoo', 'baron', 'big gun', 'big man', 'big name', 'bigwig', 'blurb', 'brass'],
    'celerity': ['air speed', 'alacrity', 'bat', 'briskness', 'dispatch', 'expedition', 'expeditiousness', 'fastness', 'flight', 'flit', 'flurry', 'gait'],
    'celesta': ['battery', 'bells', 'bones', 'castanets', 'chime', 'chimes', 'clappers', 'crash cymbal', 'cymbals', 'finger cymbals', 'gamelan', 'glockenspiel'],
    'celestial': ['elysian', 'olympian', 'astral', 'astronomical', 'beatific', 'blessed', 'divine', 'elysian', 'empyreal', 'empyrean', 'ethereal', 'godly'],
    'celestial navigation': ['var', 'aspect', 'astronavigation', 'attitude', 'azimuth', 'bearing', 'bearings', 'chronometer', 'coastwise navigation', 'consolan', 'dead reckoning', 'electronic navigation'],
    'celibacy': ['encratism', 'friday', 'lenten fare', 'platonic love', 'pythagoreanism', 'pythagorism', 'rechabitism', 'shakerism', 'spartan fare', 'stoicism', 'abstainment', 'abstemiousness'],
    'celibate': ['apostolic', 'encratic', 'lenten', 'platonic', 'pythagorean', 'rechabite', 'shaker', 'spartan', 'stoic', 'abbacomes', 'abbot', 'absolute'],
    'cell': ['pow camp', 'photronic cell', 'adytum', 'animal cell', 'apartment', 'ashram', 'bastille', 'bioplast', 'black hole', 'booth', 'borstal', 'borstal institution'],
    'cellar': ['archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box', 'bunker'],
    'cello': ['a string', 'amati', 'cremona', 'd string', 'e string', 'english horn', 'g string', 'strad', 'stradivari', 'stradivarius', 'bass', 'bass viol'],
    'cement': ['tarmac', 'tarvia', 'accouple', 'accumulate', 'adamant', 'adhere', 'adherent', 'adhesive', 'adobe', 'affix', 'agglutinate', 'amass'],
    'cenotaph': ['arch', 'barrow', 'beehive tomb', 'bone house', 'boundary stone', 'box grave', 'brass', 'burial', 'burial chamber', 'burial mound', 'bust', 'cairn'],
    'censer': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'ark', 'asperger', 'asperges', 'aspergillum', 'atomizer', 'bambino'],
    'censor': ['abbreviate', 'abridge', 'annotator', 'asphyxiate', 'belittler', 'black out', 'bleach', 'blip', 'blot out', 'blue-pencil', 'bottle up', 'bowdlerize'],
    'censored': ['arcane', 'cabalistic', 'classified', 'close', 'closed', 'concealed', 'cryptic', 'dark', 'enigmatic', 'esoteric', 'hermetic', 'hidden'],
    'censorious': ['quakerish', 'victorian', 'abusive', 'accusatory', 'back-biting', 'belittling', 'bitchy', 'blackening', 'blameful', 'calumniatory', 'calumnious', 'captious'],
    'censorship': ['abbreviation', 'abridgment', 'bamboo curtain', 'barrier of secrecy', 'blackout', 'block', 'blockage', 'blocking', 'blue-penciling', 'bowdlerization', 'cancellation', 'censoring'],
    'censurable': ['amiss', 'blamable', 'blameful', 'culpable', 'discreditable', 'doubtful', 'guilty', 'improper', 'inadmissible', 'incorrect', 'objectionable', 'questionable'],
    'censure': ['accuse', 'anathema', 'anathematize', 'anathematizing', 'anathemize', 'animadvert on', 'annotate', 'approval', 'arraign', 'arraignment', 'aspersion', 'assail'],
    'census': ['account', 'accounting', 'accounts', 'agenda', 'assemblage', 'assembly', 'beadroll', 'body count', 'cadastre', 'calendar', 'call-up', 'canvass'],
    'cent': ['c-note', 'deutschmark', 'g-note', 'mark', 'reichsmark', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'afghani', 'anna'],
    'centenarian': ['father time', 'methuselah', 'nestor', 'old paar', 'bicentenary', 'bicentennial', 'cental', 'centare', 'centenary', 'centennial', 'centennium', 'centigram'],
    'centennial': ['anniversary', 'annual', 'annual holiday', 'biannual', 'bicentenary', 'bicentennial', 'biennial', 'bimonthly', 'birthday', 'bissextile day', 'biweekly', 'catamenial'],
    'center': ['activator', 'adductor', 'amateur athlete', 'approach', 'archer', 'athlete', 'attractant', 'attrahent', 'average', 'axiom', 'axis', 'balance'],
    'centipede': ['chilopoda', 'chordata', 'echiuroidea', 'ectoprocta', 'entoprocta', 'monoplacophora', 'nemertinea', 'phoronidea', 'arachnid', 'arthropod', 'beetle', 'bicentenary'],
    'central': ['pbx operator', 'aboriginal', 'accented', 'all-absorbing', 'alveolar', 'amidships', 'apical', 'apico-alveolar', 'apico-dental', 'arch', 'articulated', 'assimilated'],
    'centralize': ['affiliate', 'ally', 'approach', 'associate', 'band together', 'be in cahoots', 'bunch', 'bunch up', 'cabal', 'cement a union', 'center', 'center on'],
    'centrifuge': ['analyzer', 'breaker', 'centrifugate', 'cutter', 'eddy', 'gurge', 'reel', 'separator', 'sieve', 'spin', 'stripper', 'surge'],
    'centripetal': ['approaching', 'asymptotic', 'centrolineal', 'concentrating', 'concurrent', 'confluent', 'confocal', 'connivent', 'consolidating', 'converging', 'focal', 'meeting'],
    'centripetal force': ['adduction', 'affinity', 'allurement', 'attractance', 'attraction', 'attractiveness', 'attractivity', 'capillarity', 'capillary attraction', 'centrifugal force', 'drag', 'draw'],
    'centrist': ['laodicean', 'apathetic', 'center', 'compromiser', 'conservative', 'even', 'fifty-fifty', 'half-and-half', 'impartial', 'independent', 'indifferent', 'middle-of-the-road'],
    'centurion': ['nco', 'acting corporal', 'acting sergeant', 'bicentenary', 'bicentennial', 'cental', 'centare', 'centenarian', 'centenary', 'centennial', 'centennium', 'centigram'],
    'century': ['c-note', 'g-note', 'abundant year', 'academic year', 'aeon', 'age', 'ages', 'annum', 'bicentenary', 'bicentennial', 'bissextile year', 'buck'],
    'ceramics': ['abstract art', 'adobe', 'art', 'art form', 'artist', 'arts and crafts', 'arts of design', 'biscuit', 'bisque', 'bowl', 'brick', 'calligraphy'],
    'cerberus': ['aides', 'aidoneus', 'charon', 'cora', 'despoina', 'dis', 'dis pater', 'erebus', 'hades', 'hel', 'kore', 'loki'],
    'cereal': ['aftergrass', 'bamboo', 'botanic', 'breakfast food', 'bulbous', 'cane', 'cereal plant', 'corn', 'cornflakes', 'dry cereal', 'farina', 'farinaceous'],
    'cerebellum': ['arachnoid', 'arbor vitae', 'archipallium', 'between brain', 'brain stem', 'cerebellar hemispheres', 'cerebral cortex', 'cerebrospinal fluid', 'cerebrum', 'convolution', 'corpus callosum', 'corpus striatum'],
    'cerebral': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'cerebral cortex': ['afferent neuron', 'arachnoid', 'arbor vitae', 'archipallium', 'autonomic nervous system', 'axon', 'between brain', 'brain', 'brain stem', 'central nervous system', 'cerebellar hemispheres', 'cerebellum'],
    'cerebral palsy': ['ms', 'amyotrophic lateral sclerosis', 'brain disease', 'cephalalgia', 'chorea', 'emotional disorder', 'epilepsy', 'falling sickness', 'glossopharyngeal neuralgia', 'headache', 'herpes zoster', 'ischialgia'],
    'cerebrum': ['arachnoid', 'arbor vitae', 'archipallium', 'between brain', 'brain stem', 'cerebellar hemispheres', 'cerebellum', 'cerebral cortex', 'cerebrospinal fluid', 'convolution', 'corpus callosum', 'corpus striatum'],
    'ceremonial': ['high-church', 'august', 'baccalaureate service', 'baptismal', 'buckram', 'celebration', 'celebratory', 'ceremonious', 'ceremoniousness', 'ceremony', 'commemorative', 'commencement'],
    'ceremonious': ['high-church', 'attentive', 'baptismal', 'cap in hand', 'careful', 'ceremonial', 'chivalric', 'chivalrous', 'civil', 'conventional', 'correct', 'courteous'],
    'ceremony': ['amenities', 'anniversaries', 'appearances', 'baccalaureate service', 'buckram', 'celebrating', 'celebration', 'ceremonial', 'ceremonies', 'ceremoniousness', 'civilities', 'commemoration'],
    'ceres': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ashtoreth', 'astarte', 'ate', 'athena', 'baal'],
    'cerise': ['titian', 'titian-red', 'bricky', 'cardinal', 'carmine', 'carnation', 'carnelian', 'cherry', 'cherry-colored', 'cherry-red', 'crimson', 'damask'],
    'certain': ['a certain', 'absolute', 'accurate', 'actual', 'adducible', 'admissible', 'agape', 'agog', 'all agog', 'an', 'anticipant', 'anticipating'],
    'certainly': ['ok', 'roger', 'absolutely', 'actually', 'all right', 'alright', 'alrighty', 'amen', 'and no mistake', 'as you say', 'assuredly', 'at all events'],
    'certainty': ['absolutely', 'absoluteness', 'acceptation', 'acception', 'acquiescence', 'act of god', 'actuality', 'anticipation', 'assurance', 'assuredly', 'assuredness', 'authoritativeness'],
    'certificate': ['cd', 'iou', 'mo', 'acceptance', 'acceptance bill', 'affidavit', 'attestation', 'authority', 'authorization', 'bank acceptance', 'bank check', 'bill'],
    'certificate of deposit': ['cd', 'iou', 'mo', 'acceptance', 'acceptance bill', 'bank acceptance', 'bank check', 'bill', 'bill of draft', 'bill of exchange', 'blank check', 'callable securities'],
    'certification': ['john hancock', 'ok', 'acceptance', 'affidavit', 'affirmance', 'affirmation', 'approbation', 'approval', 'ascertainment', 'assurance', 'attestation', 'authentication'],
    'certified': ['accepted', 'acknowledged', 'actual', 'admitted', 'affirmed', 'alleged', 'allowed', 'announced', 'approved', 'ascertained', 'asserted', 'asseverated'],
    'certify': ['ok', 'accept', 'accredit', 'acknowledge', 'affirm', 'allege', 'amen', 'and candle', 'approve', 'ascertain', 'assert', 'assert under oath'],
    'cerulean': ['caelus', 'air', 'azure', 'azure-blue', 'azure-colored', 'azurean', 'azured', 'azureous', 'beryl-blue', 'berylline', 'blue', 'blue sky'],
    'cervix': ['abbreviation', 'advocate', 'alpenstock', 'ankle', 'arm', 'articulation', 'astriction', 'astringency', 'athletic supporter', 'back', 'backbone', 'backing'],
    'cessation': ['abandonment', 'abeyance', 'abjuration', 'abjurement', 'absentation', 'apodosis', 'breach', 'break', 'caesura', 'casting away', 'catastrophe', 'cease'],
    'cession': ['abalienation', 'abandonment', 'abdication', 'abjuration', 'abjurement', 'alienation', 'allowance', 'amortization', 'amortizement', 'assignation', 'assignment', 'bargain and sale'],
    'cesspool': ['sodom', 'bog', 'cesspit', 'cloaca', 'cloaca maxima', 'den', 'drain', 'dump', 'garbage dump', 'marsh', 'mire', 'pandemonium'],
    'cetacean': ['loch ness monster', 'alevin', 'baleen whale', 'beluga', 'benthon', 'benthos', 'blackfish', 'blue whale', 'cachalot', 'dolphin', 'finback', 'fingerling'],
    'chafe': ['ablate', 'ablation', 'abrade', 'abrase', 'abrasion', 'abrasive', 'afflict', 'aggravate', 'agonize', 'ail', 'annoy', 'arouse'],
    'chaff': ['afterglow', 'afterimage', 'air', 'aluminum foil', 'badinage', 'balance', 'banter', 'bark', 'barrack', 'bones', 'bran', 'bric-a-brac'],
    'chagrin': ['abash', 'abashment', 'cast down', 'confound', 'confuse', 'confusion', 'discomfit', 'discomfiture', 'discompose', 'discomposure', 'disconcert', 'disconcertion'],
    'chagrined': ['abashed', 'afflicted', 'agitated', 'ashamed', 'beset', 'blushing', 'bothered', 'cast down', 'chapfallen', 'confused', 'crestfallen', 'crushed'],
    'chain': ['alps', 'andes', 'caucasus', 'himalayas', 'indian file', 'kekule formula', 'oregon boat', 'rockies', 'accouple', 'accumulate', 'accumulative', 'additive'],
    'chain gang': ['pow', 'cageling', 'captive', 'con', 'convict', 'detenu', 'ex-convict', 'gaolbird', 'internee', 'jailbird', 'lifer', 'parolee'],
    'chain reaction': ['indian file', 'alpha decay', 'array', 'articulation', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction', 'atomization', 'bank', 'beta decay', 'bombardment'],
    'chair': ['eames chair', 'hitchcock chair', 'tv chair', 'administer', 'administrate', 'anoint', 'armchair', 'armless chair', 'authority', 'ax', 'back seat', 'banquette'],
    'chalk': ['air brush', 'alabaster', 'art paper', 'ballpoint pen', 'besnow', 'blackboard', 'blanch', 'blaze', 'blaze a trail', 'bleach', 'blemish', 'blotch'],
    'chalk talk': ['address', 'after-dinner speech', 'allocution', 'assignment', 'debate', 'declamation', 'diatribe', 'discourse', 'disquisition', 'eulogy', 'exercise', 'exhortation'],
    'chalk up': ['acquire', 'annex', 'blaze', 'blaze a trail', 'blemish', 'blotch', 'book', 'brand', 'calendar', 'carve', 'catalog', 'chalk'],
    'chalky': ['argent', 'argentine', 'branny', 'canescent', 'chalklike', 'comminute', 'comminuted', 'cretaceous', 'crushed', 'detrital', 'detrited', 'disintegrated'],
    'challenge': ['socratic method', 'affront', 'arouse', 'ask', 'ask for', 'asking', 'attack', 'awake a doubt', 'awaken', 'baffle', 'balk', 'banter'],
    'challenging': ['alluring', 'arrogant', 'audacious', 'bold', 'brash', 'brassy', 'brazen', 'bumptious', 'cheeky', 'cocky', 'contemptuous', 'daring'],
    'chamber': ['british cabinet', 'geiger counter', 'sanhedrin', 'us cabinet', 'wilson chamber', 'advisory body', 'alpha pulse analyzer', 'apartment', 'assembly', 'association', 'atom counter', 'ballroom'],
    'chamber music': ['nachtmusik', 'absolute music', 'adaptation', 'air varie', 'aleatory', 'aleatory music', 'arrangement', 'chamber orchestra', 'composition', 'descant', 'electronic music', 'etude'],
    'chamber of commerce': ['aktiengesellschaft', 'aktiebolag', 'body corporate', 'business', 'business establishment', 'cartel', 'combine', 'commercial enterprise', 'compagnie', 'company', 'concern', 'conglomerate'],
    'chamber pot': ['bedpan', 'can', 'chamber', 'chemical closet', 'chemical toilet', 'commode', 'crapper', 'jerry', 'john', 'johnny', 'jordan', 'latrine'],
    'chamberlain': ['accountant', 'auditor', 'bookkeeper', 'bursar', 'butler', 'cashier', 'cashkeeper', 'comptroller', 'controller', 'curator', 'depositary', 'depository'],
    'chambermaid': ['abigail', 'amah', 'au pair girl', 'ayah', 'betweenmaid', 'biddy', 'chaperon', 'companion', 'cook', 'duenna', 'femme de chambre', 'fille de chambre'],
    'chambers': ['apartment', 'booking office', 'box office', 'branch', 'branch office', 'cabinet', 'chancellery', 'chancery', 'closet', 'cold-water flat', 'consulate', 'corporate headquarters'],
    'chameleon': ['april showers', 'dalmatian', 'gila monster', 'proteus', 'vicar of bray', 'agama', 'alligator', 'anole', 'antigorite', 'bearded lizard', 'blindworm', 'box turtle'],
    'champ': ['olympic medal winner', 'award winner', 'bite', 'bolus', 'champion', 'chaw', 'chew', 'chew the cud', 'chew up', 'chomp', 'conquering hero', 'conqueror'],
    'champaign': ['alkali flat', 'alluvial plain', 'bailiwick', 'basin', 'bottomland', 'bushveld', 'campo', 'champaign country', 'coastal plain', 'delta', 'demesne', 'desert'],
    'champion': ['a per se', 'maecenas', 'olympic medal winner', 'abettor', 'ace', 'admirer', 'advocate', 'aficionado', 'allege in support', 'alter ego', 'alternate', 'amicus curiae'],
    'championship': ['cadmean victory', 'ko', 'pyrrhic victory', 'abetment', 'acme', 'advocacy', 'aegis', 'ascendancy', 'auspices', 'authority', 'authorization', 'backing'],
    'chance': ['a leg up', 'accidental', 'accidentally', 'advantage', 'adventitious', 'adventure', 'aleatoric', 'aleatory', 'amorphous', 'appear', 'approach', 'aptitude'],
    'chance upon': ['alight upon', 'blunder upon', 'bump into', 'come across', 'come on', 'come up against', 'come upon', 'discover serendipitously', 'encounter', 'fall in with', 'happen upon', 'hit upon'],
    'chancel': ['easter sepulcher', 'ambry', 'apse', 'baptistery', 'blindstory', 'choir', 'cloisters', 'confessional', 'confessionary', 'crypt', 'diaconicon', 'diaconicum'],
    'chancellery': ['aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'bishopric', 'booking office', 'box office', 'branch', 'branch office', 'cabinet', 'chairmanship'],
    'chancellor': ['ja', 'academic dean', 'administration', 'administrator', 'alderman', 'ambassador', 'ambassadress', 'amicus curiae', 'apostolic delegate', 'archon', 'assessor', 'attache'],
    'chancery': ['appellate court', 'archives', 'assizes', 'booking office', 'box office', 'branch', 'branch office', 'cabinet', 'chambers', 'chancellery', 'chancery court', 'circuit court'],
    'chancre': ['french disease', 'spanish pox', 'vd', 'abscess', 'acquired syphilis', 'aposteme', 'balanitis gangrenosa', 'bed sore', 'blain', 'bleb', 'blister', 'boil'],
    'chancy': ['accidental', 'adventitious', 'adventurous', 'agnostic', 'aleatoric', 'aleatory', 'ambiguous', 'amorphous', 'blobby', 'blurred', 'blurry', 'broad'],
    'chandler': ['baker', 'bookdealer', 'bookseller', 'butcher', 'caterer', 'clothing merchant', 'commissariat', 'commissary', 'confectioner', 'dealer', 'distributor', 'donor'],
    'change': ['aberration', 'about-face', 'accommodate', 'adapt', 'adjust', 'advance', 'agency', 'agent', 'alchemy', 'alter', 'alteration', 'alternate'],
    'change course': ['about ship', 'back and fill', 'bear away', 'bear off', 'bear to starboard', 'beat', 'beat about', 'box off', 'break', 'bring about', 'bring round', 'cant'],
    'change of heart': ['abject apology', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'alteration', 'amelioration', 'amendment', 'apology', 'apostasy', 'betterment', 'break'],
    'change of mind': ['about-face', 'afterthoughts', 'ambitendency', 'ambivalence', 'amendment', 'better thoughts', 'capriciousness', 'change of allegiance', 'change of heart', 'changeableness', 'double-mindedness', 'dubiety'],
    'changeable': ['able to adapt', 'adaptable', 'adjustable', 'adrift', 'afloat', 'agnostic', 'alterable', 'alterative', 'altered', 'alternating', 'ambiguous', 'ambitendent'],
    'changed': ['altered', 'assimilated', 'better', 'changeable', 'converted', 'degenerate', 'deviant', 'divergent', 'improved', 'metamorphosed', 'metastasized', 'modified'],
    'changeless': ['abiding', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'boundless', 'constant', 'continuing', 'creating', 'creative', 'durable'],
    'changeling': ['agent', 'alternate', 'alternative', 'analogy', 'backup', 'change', 'comparison', 'copy', 'counterfeit', 'deputy', 'double', 'dummy'],
    'channel': ['edp', 'access', 'adolescent stream', 'adviser', 'aisle', 'alley', 'amateur band', 'ambulatory', 'announcer', 'annunciator', 'aperture', 'approach'],
    'chant': ['agnus dei', 'benedicite', 'brautlied', 'christmas carol', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'kunstlied', 'liebeslied', 'magnificat', 'miserere'],
    'chaos': ['agitation', 'aloofness', 'amorphia', 'amorphism', 'amorphousness', 'anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism', 'astronomical unit', 'bedlam', 'befuddlement'],
    'chaotic': ['aleatoric', 'aleatory', 'amorphic', 'amorphous', 'anarchial', 'anarchic', 'anarchistic', 'angry', 'antinomian', 'arsy-varsy', 'ass-backwards', 'baggy'],
    'chaotically': ['aimlessly', 'anarchically', 'capriciously', 'confusedly', 'dispersedly', 'erratically', 'every which way', 'helter-skelter', 'higgledy-piggledy', 'impulsively', 'inconsistently', 'inconstantly'],
    'chap': ['adamite', 'abysm', 'abyss', 'arroyo', 'bastard', 'being', 'bird', 'bloke', 'body', 'box canyon', 'boy', 'bozo'],
    'chapel': ['lady chapel', 'amphitheater', 'arena', 'assembly hall', 'auditorium', 'chantry', 'chapel of ease', 'chapel royal', 'concert hall', 'convention hall', 'dance hall', 'exhibition hall'],
    'chaperon': ['abigail', 'amah', 'attend', 'attend to', 'au pair girl', 'ayah', 'baby-sit', 'bear', 'betweenmaid', 'biddy', 'bodyguard', 'boss'],
    'chapfallen': ['abashed', 'afflicted', 'agitated', 'ashamed', 'baffled', 'balked', 'beset', 'betrayed', 'bilked', 'blasted', 'blighted', 'blue'],
    'chaplain': ['dd', 'doctor of divinity', 'grand penitentiary', 'holy father', 'holy joe', 'abbe', 'abuna', 'antipope', 'archbishop', 'archdeacon', 'archpriest', 'bishop'],
    'chaps': ['bazoo', 'chops', 'embouchure', 'gab', 'gob', 'jaw', 'jaws', 'jowls', 'kisser', 'lips', 'mandibles', 'maw'],
    'chapter': ['council of nicaea', 'council of trent', 'lateran council', 'vatican council', 'affiliate', 'arm', 'article', 'back matter', 'basis', 'book', 'branch', 'branch office'],
    'char': ['blaze', 'blister', 'brand', 'burn', 'burn in', 'burn off', 'cast', 'cauterize', 'chare', 'charwoman', 'chore', 'cleaner'],
    'character': ['adamite', 'altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'roscius', 'vip', 'verworn theory', 'weismann theory'],
    'character assassination': ['attack', 'backbiting', 'backstabbing', 'belittlement', 'blackening', 'calumny', 'defamation', 'defamation of character', 'defilement', 'denigration', 'depreciation', 'dirt'],
    'characteristic': ['affection', 'affective', 'appropriate', 'aroma', 'attribute', 'automatism', 'bad habit', 'badge', 'banner', 'birthmark', 'body-build', 'brand'],
    'characterization': ['acting', 'action', 'alphabet', 'anagnorisis', 'angle', 'aping', 'architectonics', 'architecture', 'argument', 'art', 'atmosphere', 'background'],
    'characterize': ['adumbrate', 'argue', 'be characteristic', 'be indicative of', 'be significant of', 'be symptomatic of', 'bespeak', 'betoken', 'block out', 'brand', 'bring to life', 'catch a likeness'],
    'characterless': ['amorphic', 'amorphous', 'anarchic', 'arid', 'baggy', 'bare', 'barren', 'blah', 'bland', 'blank', 'bleached', 'blobby'],
    'charade': ['grand guignol', 'passion play', 'tom show', 'absurdity', 'anagram', 'antimasque', 'audience success', 'ballet', 'bearing', 'beck', 'beckon', 'body language'],
    'charcoal': ['air brush', 'alcohol', 'art paper', 'ash', 'ashes', 'benzine', 'black and white', 'blackening', 'blacking', 'blackwash', 'brand', 'briquette'],
    'charge': ['accountability', 'accounting for', 'accounts payable', 'accounts receivable', 'accredit', 'accusal', 'accusation', 'accuse', 'accusing', 'achievement', 'action', 'activate'],
    'charge in': ['barge in', 'break in', 'break in upon', 'burst in', 'butt in', 'come between', 'crash', 'crash in', 'crash the gates', 'creep in', 'crowd in', 'cut in'],
    'charge off': ['abate', 'allow', 'balance', 'balance the books', 'bate', 'book', 'bury the hatchet', 'capitalize', 'carry', 'carry over', 'cast up accounts', 'charge to experience'],
    'charged': ['accountable', 'accused', 'activated', 'agitating', 'alleged', 'arraigned', 'ascribable', 'assignable', 'attributable', 'attributed', 'autoluminescent', 'blamed'],
    'charger': ['houyhnhnm', 'brood mare', 'colt', 'courser', 'critter', 'dobbin', 'entire', 'entire horse', 'equine', 'filly', 'foal', 'gelding'],
    'charisma': ['agacerie', 'allure', 'allurement', 'amperage', 'appeal', 'armipotence', 'ascendancy', 'attraction', 'attractiveness', 'aura', 'authority', 'beef'],
    'charismatic': ['alluring', 'appealing', 'appetizing', 'attractive', 'authoritative', 'beguiling', 'bewitching', 'blandishing', 'bright', 'brilliant', 'cajoling', 'captivating'],
    'charismatic movement': ['bibliolatry', 'charismatic gift', 'charismatic renewal', 'fanaticism', 'gift of tongues', 'glossolalia', 'overdevoutness', 'overpiousness', 'overreligiousness', 'overrighteousness', 'overzealousness', 'pentecostalism'],
    'charitable': ['accommodating', 'almsgiving', 'altruistic', 'beneficent', 'benevolent', 'benign', 'bighearted', 'bleeding', 'bountiful', 'clement', 'commiserative', 'compassionate'],
    'charity': ['amor', 'bomfog', 'benthamism', 'christian charity', 'christian love', 'eros', 'platonic love', 'abetment', 'accord', 'accordance', 'admiration', 'adoration'],
    'charivari': ['bedlam let loose', 'bedlam', 'blast', 'bobbery', 'brawl', 'brouhaha', 'chirm', 'clamor', 'clangor', 'clap', 'clatter', 'commotion'],
    'charlatan': ['blagueur', 'bluff', 'bluffer', 'charlatanic', 'charlatanish', 'fake', 'faker', 'fourflusher', 'fraud', 'horse doctor', 'humbug', 'impersonator'],
    'charley': ['argus', 'bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'communist', 'cong', 'fenian', 'guevarist'],
    'charley horse': ['acute pain', 'bite', 'boring pain', 'cramp', 'cramps', 'crick', 'darting pain', 'fulgurant pain', 'girdle pain', 'gnawing', 'griping', 'hitch'],
    'charm': ['absorb', 'absorb the attention', 'adorability', 'agacerie', 'agreeability', 'agreeableness', 'alchemy', 'allay', 'allure', 'allurement', 'amiability', 'amulet'],
    'charmed': ['arrested', 'becharmed', 'bewitched', 'captivated', 'castle-building', 'caught', 'charm-bound', 'comfortable', 'content', 'contented', 'cozy', 'daydreaming'],
    'charmed circle': ['bunch', 'cabal', 'cadre', 'camarilla', 'cell', 'circle', 'clan', 'clique', 'closed circle', 'coterie', 'crew', 'crowd'],
    'charmer': ['artful dodger', 'casanova', 'circe', 'cleopatra', 'don juan', 'euryale', 'gorgon', 'lorelei', 'lothario', 'machiavel', 'machiavelli', 'machiavellian'],
    'charming': ['circean', 'admirable', 'adorable', 'alluring', 'angelic', 'appealing', 'appetizing', 'attracting', 'attractive', 'authoritative', 'beguiling', 'bewitching'],
    'charnel house': ['barrow', 'beehive tomb', 'bone house', 'box grave', 'burial', 'burial chamber', 'burial mound', 'burning ghat', 'catacombs', 'cenotaph', 'cist', 'cist grave'],
    'charon': ['aides', 'aidoneus', 'cerberus', 'cora', 'despoina', 'dis', 'dis pater', 'erebus', 'hades', 'hel', 'kore', 'loki'],
    'chart': ['lambert conformal projection', 'mercator projection', 'miller projection', 'adjust', 'aeronautical chart', 'alphabet', 'arrange', 'art', 'astronomical chart', 'atlas', 'azimuthal projection', 'blueprint'],
    'charter': ['ok', 'accredit', 'admission', 'agreement', 'allowance', 'approve', 'assign', 'authority', 'authorize', 'bareboat charter', 'brevet', 'certificate'],
    'chartreuse': ['aestival', 'beryl-green', 'berylline', 'blue-green', 'bluish-green', 'chloranemic', 'chlorine', 'chlorotic', 'citrine', 'citrinous', 'emerald', 'foliaged'],
    'chary': ['scotch', 'cagey', 'calculating', 'canny', 'careful', 'cheeseparing', 'circumspect', 'conserving', 'considerate', 'constrained', 'discreet', 'disinclined'],
    'chase': ['derby', 'kentucky derby', 'preakness stakes', 'address', 'afforestation', 'arboretum', 'assemble', 'beat', 'beat back', 'beau', 'bedog', 'bezel'],
    'chase after': ['bring', 'bring back', 'call for', 'fetch', 'fetch and carry', 'get', 'go after', 'go and get', 'go fetch', 'go for', 'go get', 'go to get'],
    'chaser': ['casanova', 'don juan', 'mickey', 'mickey finn', 'act', 'afterpiece', 'aperitif', 'bit', 'carver', 'clay modeler', 'cocktail', 'curtain'],
    'chasm': ['abysm', 'abyss', 'aperture', 'arroyo', 'blank', 'box canyon', 'breach', 'break', 'broaching', 'canyon', 'cavity', 'chap'],
    'chassis': ['backing', 'base', 'baseboard', 'basement', 'bearing', 'bushing', 'cabinet', 'cadre', 'case', 'casement', 'casing', 'console'],
    'chaste': ['apostolic', 'attic', 'ciceronian', 'encratic', 'lenten', 'pythagorean', 'rechabite', 'shaker', 'spartan', 'stoic', 'abase', 'absolute'],
    'chasten': ['abate', 'allay', 'alleviate', 'assuage', 'attemper', 'bank the fire', 'blunt', 'bring to account', 'bring to book', 'call to account', 'castigate', 'chastise'],
    'chastened': ['broken', 'constrained', 'controlled', 'domesticated', 'dovelike', 'gentle', 'housebroken', 'humble', 'hushed', 'in control', 'in hand', 'lamblike'],
    'chastise': ['admonish', 'baste', 'beat', 'belabor', 'berate', 'birch', 'bring to account', 'bring to book', 'call to account', 'cane', 'castigate', 'censure'],
    'chastity': ['atticism', 'encratism', 'friday', 'lenten fare', 'pythagoreanism', 'pythagorism', 'rechabitism', 'shakerism', 'spartan fare', 'stoicism', 'absoluteness', 'abstainment'],
    'chat': ['babble', 'babblement', 'bavardage', 'be closeted with', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather', 'blether', 'blethers', 'bull session'],
    'chatelaine': ['abbess', 'anklet', 'armlet', 'bangle', 'beads', 'bijou', 'bracelet', 'breastpin', 'brooch', 'captain', 'castellan', 'chain'],
    'chattel': ['acquest', 'belongings', 'bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'captive', 'chattel slave', 'chattels', 'churl', 'concubine'],
    'chatter': ['accents', 'babble', 'babblement', 'bavardage', 'be cold', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather', 'blether', 'blethers'],
    'chatterbox': ['agreeable rattle', 'babbler', 'big talker', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'blatherer', 'busybody', 'chatterer', 'conversationalist', 'gabber'],
    'chatty': ['all jaw', 'candid', 'chitchatty', 'colloquial', 'communicative', 'confabulatory', 'conversational', 'cozy', 'effusive', 'expansive', 'familiar', 'flip'],
    'chauffeur': ['sunday driver', 'backseat driver', 'bicycle', 'bike', 'boy', 'bus', 'bus driver', 'busman', 'butler', 'cabby', 'cabdriver', 'catch a train'],
    'chauvinism': ['americanism', 'anglicism', 'briticism', 'jim crow', 'jim crow law', 'aggression', 'aggressiveness', 'antagonism', 'anti-semitism', 'apartheid', 'bellicism', 'bellicosity'],
    'chauvinist': ['bigot', 'chauvin', 'doctrinaire', 'dogmatist', 'fanatic', 'flag waver', 'hard hat', 'hawk', 'hundred-percent american', 'hundred-percenter', 'illiberal', 'intolerant'],
    'chauvinistic': ['antiblack', 'biased', 'chauvinist', 'civic', 'colored', 'doctrinaire', 'dogmatic', 'flag-waving', 'influenced', 'interested', 'jaundiced', 'jingoist'],
    'cheap': ['mickey mouse', 'ng', 'at cost', 'avaricious', 'bad', 'base', 'beggarly', 'beneath contempt', 'beneath one', 'brummagem', 'budget', 'cheapjack'],
    'cheapen': ['adulterate', 'alloy', 'bargain', 'beat down', 'bid', 'bid for', 'break', 'canker', 'chaffer', 'coarsen', 'confound', 'contaminate'],
    'cheat': ['ballot-box stuffing', 'bamboozle', 'bamboozlement', 'beat', 'befool', 'beguile', 'beguile of', 'bilk', 'blackleg', 'boodle', 'bunco', 'burn'],
    'check': ['cd', 'iou', 'mo', 'a reckoning of', 'abrade', 'abrasion', 'abysm', 'abyss', 'acceptance', 'acceptance bill', 'accord', 'account'],
    'check in': ['accomplish', 'achieve', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be received', 'blow in', 'bob up', 'book'],
    'check out': ['audit', 'autopsy', 'balance', 'balance the books', 'buy it', 'canvass', 'cash in', 'check', 'check and doublecheck', 'check in', 'check over', 'check up on'],
    'checkbook': ['cd', 'iou', 'mo', 'acceptance', 'acceptance bill', 'bank acceptance', 'bank check', 'bill', 'bill of draft', 'bill of exchange', 'blank check', 'certificate'],
    'checker': ['alter', 'ameliorate', 'band', 'bar', 'be changed', 'be converted into', 'be renewed', 'bespangle', 'bespeckle', 'bespot', 'blotch', 'bottom out'],
    'checkerboard': ['agate', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble', 'blocks', 'check', 'checker', 'checkerwork', 'chessboard', 'club'],
    'checkered': ['able to adapt', 'adaptable', 'adjustable', 'alterable', 'alterative', 'changeable', 'check', 'checked', 'ever-changing', 'flexible', 'fluid', 'impermanent'],
    'checkers': ['monopoly', 'ping-pong', 'rugby', 'scrabble', 'archery', 'association football', 'backgammon', 'badminton', 'bagatelle', 'ball', 'bandy', 'baseball'],
    'checking account': ['swiss bank account', 'account', 'assets', 'balance', 'bank account', 'bank balance', 'bottom dollar', 'budget', 'cash reserves', 'charge account', 'command of money', 'credit account'],
    'checklist': ['baedeker', 'yellow pages', 'active list', 'agenda', 'beadroll', 'bibliography', 'blacklist', 'business directory', 'cadastre', 'calendar', 'catalog', 'census'],
    'checkmate': ['arrest', 'baffle', 'bafflement', 'balk', 'balking', 'bell', 'blast', 'block', 'brake', 'brave', 'bring to', 'bring up short'],
    'cheek': ['arse', 'ass', 'backside', 'bank', 'beam', 'behind', 'border', 'bottom', 'brashness', 'brass', 'brazen boldness', 'breech'],
    'cheeky': ['arrogant', 'audacious', 'biggety', 'bluff', 'bold', 'brash', 'brassy', 'brazen', 'bumptious', 'challenging', 'chutzpadik', 'cocky'],
    'cheep': ['cackle', 'call', 'carol', 'caw', 'chatter', 'chip', 'chipper', 'chirk', 'chirm', 'chirp', 'chirr', 'chirrup'],
    'cheer': ['abide by', 'accede', 'accept', 'acclaim', 'acclamation', 'acquiesce', 'acquiesce in', 'afford hope', 'agree', 'agree to', 'agree with', 'alleluia'],
    'cheerful': ['leibnizian', 'affable', 'agreeable', 'airy', 'amiable', 'amicable', 'animated', 'animating', 'beaming', 'beatific', 'beatified', 'blessed'],
    'cheerfully': ['affably', 'agreeably', 'airily', 'amiably', 'amicably', 'blissfully', 'blithely', 'cheerily', 'confidently', 'cordially', 'enjoyably', 'expectantly'],
    'cheerfulness': ['leibnizian optimism', 'pollyannaism', 'auspiciousness', 'beatification', 'beatitude', 'beneficence', 'benevolence', 'benignancy', 'benignity', 'bewitchment', 'blessedness', 'bliss'],
    'cheering': ['animating', 'assuring', 'auspicious', 'bracing', 'bright with promise', 'brisk', 'cheerful', 'cheery', 'comforting', 'condolatory', 'condolent', 'condoling'],
    'cheerless': ['affecting', 'afflictive', 'affording no hope', 'anguished', 'anxious', 'apathetic', 'bitter', 'bleak', 'bored', 'comfortless', 'deplorable', 'depressed'],
    'cheery': ['leibnizian', 'affable', 'agreeable', 'amiable', 'amicable', 'animating', 'beaming', 'beatific', 'beatified', 'blessed', 'blissful', 'blithe'],
    'cheese': ['alentejo', 'alise sainte reine', 'american cheese', 'amou', 'arrigny', 'asco', 'asio', 'augelot', 'aurore', 'autun', 'backstein', 'battelmatt'],
    'cheeseparing': ['scotch', 'canny', 'careful', 'chary', 'cheap', 'chinchy', 'chintzy', 'close', 'closefisted', 'conserving', 'cooling', 'cooling down'],
    'cheesy': ['mickey mouse', 'abject', 'abominable', 'arrant', 'atrocious', 'barfy', 'base', 'beggarly', 'beneath contempt', 'bum', 'cheap', 'coarse'],
    'cheetah': ['leo', 'siberian tiger', 'bobcat', 'cat-a-mountain', 'catamount', 'cougar', 'jaguar', 'leopard', 'lion', 'lynx', 'mountain lion', 'ocelot'],
    'chef': ['baker', 'boss', 'bwana', 'chef de cuisine', 'chief', 'chief cook', 'church dignitary', 'cook', 'culinarian', 'culinary artist', 'ecclesiarch', 'elder'],
    'chemical': ['chile saltpeter', 'absolute alcohol', 'acetate', 'acetone', 'acid', 'acidity', 'agent', 'alcohol', 'aldehyde', 'alkali', 'alkalinity', 'alloisomer'],
    'chemical apparatus': ['bunsen burner', 'erlenmeyer flask', 'kipp generator', 'alembic', 'aspirator', 'beaker', 'blowpipe', 'burette', 'capillary tube', 'condenser', 'crucible', 'deflagrating spoon'],
    'chemical element': ['acid', 'acidity', 'agent', 'air', 'alkali', 'alkalinity', 'alloisomer', 'anion', 'antacid', 'atom', 'atomic particles', 'base'],
    'chemist': ['antique store', 'apothecary', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'cigar store', 'clothiers', 'clothing store', 'confectionery', 'dispensary', 'dispensatory'],
    'chemistry': ['alchemy', 'applied chemistry', 'astrochemistry', 'biochemistry', 'biogeochemistry', 'chemicobiology', 'chemicoengineering', 'chemurgy', 'colloid chemistry', 'crystallochemistry', 'cytochemistry', 'electrochemistry'],
    'cherish': ['admire', 'adore', 'appreciate', 'apprize', 'attend to', 'baby-sit', 'bear', 'bear in mind', 'bosom', 'brood over', 'care for', 'chaperon'],
    'cherry bomb': ['klaxon', 'boiler factory', 'boiler room', 'bull-roarer', 'catcall', 'clack', 'clacker', 'clapper', 'cracker', 'cricket', 'firecracker', 'horn'],
    'cherub': ['angel', 'angel of light', 'angel of love', 'archangel', 'babe', 'baby', 'baby-doll', 'bairn', 'beatified soul', 'buttercup', 'canonized mortal', 'celestial'],
    'chess': ['monopoly', 'ping-pong', 'rugby', 'scrabble', 'archery', 'association football', 'backgammon', 'badminton', 'bagatelle', 'ball', 'bandy', 'baseball'],
    'chest': ['fort knox', 'archives', 'armory', 'arsenal', 'attic', 'bag', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'boobs'],
    'chestnut': ['joe miller', 'titian', 'adust', 'auburn', 'banality', 'bay', 'bay-colored', 'bayard', 'brazen', 'bromide', 'bronze', 'bronze-colored'],
    'chevalier': ['bayard', 'don quixote', 'gawain', 'lancelot', 'ritter', 'sidney', 'sir galahad', 'bachelor', 'banneret', 'baronet', 'broncobuster', 'buckaroo'],
    'chevron': ['hershey bar', 'achievement', 'alerion', 'angle', 'animal charge', 'annulet', 'apex', 'argent', 'armorial bearings', 'armory', 'arms', 'aviation badge'],
    'chew': ['bawl out', 'bite', 'bolus', 'bullshit', 'carpet', 'cavendish', 'chain-smoke', 'champ', 'chat', 'chaw', 'chew ass', 'chew out'],
    'chew out': ['bawl out', 'carpet', 'chew', 'chew ass', 'cuss out', 'give a going-over', 'give hail columbia', 'give hell', 'give the deuce', 'give what-for', 'jack up', 'jaw'],
    'chew the fat': ['bandy words', 'chew the rag', 'chin', 'colloque', 'colloquize', 'commerce with', 'commune with', 'communicate', 'communicate with', 'confab', 'confabulate', 'converse'],
    'chewing': ['appetite', 'ass-reaming', 'bawling-out', 'cannibalism', 'carnivorism', 'carnivority', 'carnivorousness', 'chain-smoke', 'consumption', 'cropping', 'cud-chewing', 'cussing-out'],
    'chewing gum': ['lastex', 'baleen', 'battledore', 'bubble gum', 'chicle', 'chicle gum', 'elastic', 'elastomer', 'gum', 'gum elastic', 'handball', 'jumping jack'],
    'chewy': ['cartilaginous', 'cohesive', 'coriaceous', 'durable', 'fibrous', 'gristly', 'hard', 'hardy', 'lasting', 'leatherlike', 'leathery', 'resistant'],
    'chi': ['calvary cross', 'christogram', 'greek cross', 'jerusalem cross', 'latin cross', 'maltese cross', 'russian cross', 'ankh', 'avellan cross', 'chi-rho', 'christcross', 'crisscross'],
    'chic': ['braw', 'classy', 'clothes-conscious', 'clothes-consciousness', 'cosmopolitan', 'coxcombry', 'craze', 'cry', 'dandyism', 'dapper', 'dashing', 'dressed to advantage'],
    'chicane': ['artifice', 'bamboozle', 'befool', 'cavil', 'chicanery', 'dishonesty', 'double-dealing', 'feint', 'flimflam', 'fool', 'fraud', 'furtiveness'],
    'chicanery': ['art', 'artful dodge', 'artifice', 'bag of tricks', 'baseness', 'bickering', 'blind', 'bluff', 'boggling', 'bosey', 'captiousness', 'catch'],
    'chichi': ['affected', 'arabesque', 'baroque', 'brave', 'bravura', 'braw', 'busy', 'dandiacal', 'dandified', 'dandyish', 'daring', 'dashing'],
    'chick': ['bantam', 'jane', 'angel', 'avifauna', 'babe', 'baby', 'baby bird', 'baby-doll', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy'],
    'chicken': ['ancona', 'andalusian', 'australorp', 'bantam', 'brahma', 'campine', 'cochin', 'cornish', 'cornish hen', 'hamburg', 'hershey bar', 'leghorn'],
    'chicken feed': ['barley', 'bird seed', 'bran', 'bric-a-brac', 'cat food', 'chaff', 'chickenshit', 'chop', 'corn', 'details', 'dog food', 'eatage'],
    'chide': ['admonish', 'berate', 'bring to book', 'call down', 'call to account', 'chastise', 'correct', 'have words with', 'lecture', 'lesson', 'objurgate', 'rate'],
    'chief': ['a per se', 'big brother', 'ace', 'achievement', 'acmatic', 'alerion', 'all-absorbing', 'animal charge', 'annulet', 'anointed king', 'antecedent', 'anterior'],
    'chiefly': ['a fortiori', 'ab initio', 'ab ovo', 'aborigine', 'above all', 'all in all', 'all the more', 'all things considered', 'almost entirely', 'altogether', 'approximately', 'as a rule'],
    'chieftain': ['anointed king', 'boss', 'chief', 'cock', 'crowned head', 'dynast', 'emperor', 'grand duke', 'head', 'headman', 'hierarch', 'high chief'],
    'chieftaincy': ['aedileship', 'ally', 'archbishopric', 'archduchy', 'archdukedom', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'bishopric', 'body politic', 'buffer state', 'captive nation'],
    'chilblain': ['minamata disease', 'abscess', 'ache', 'aching', 'altitude sickness', 'anoxemia', 'anoxia', 'anoxic anoxia', 'anthrax', 'aposteme', 'bed sore', 'black lung'],
    'child': ['adolescent', 'angel', 'artifact', 'babe', 'baby', 'bairn', 'boy', 'brainchild', 'brat', 'brood', 'bud', 'cherub'],
    'childbearing': ['accouchement', 'bearing', 'birth', 'birth throes', 'birthing', 'blessed event', 'childbed', 'childbirth', 'confinement', 'delivery', 'genesis', 'giving birth'],
    'childhood': ['adolescence', 'babyhood', 'beginnings', 'birth', 'boyhood', 'cradle', 'freshman year', 'genesis', 'girlhood', 'inception', 'inchoation', 'incipience'],
    'childish': ['arrested', 'asinine', 'babish', 'babyish', 'backward', 'beardless', 'boyish', 'boylike', 'calflike', 'childlike', 'coltish', 'decrepit'],
    'childishness': ['anility', 'babyishness', 'boylikeness', 'caducity', 'callowness', 'childlikeness', 'decline', 'dotage', 'dotardism', 'girlishness', 'immaturity', 'imprudence'],
    'childless': ['acarpous', 'arid', 'barren', 'celibate', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'exhausted', 'fallow', 'fruitless'],
    'childlike': ['angelic', 'artless', 'babish', 'babyish', 'beardless', 'blameless', 'bluff', 'blunt', 'born yesterday', 'boyish', 'boylike', 'calflike'],
    'children': ['babyhood', 'boyhood', 'breed', 'brood', 'childkind', 'descendants', 'descent', 'family', 'folks', 'fruit', 'get', 'girlhood'],
    'chill': ['laodiceanism', 'abscess', 'absolute zero', 'abstracted', 'ache', 'aching', 'affectless', 'ague', 'air-condition', 'air-cool', 'algidity', 'aloof'],
    'chiller': ['cinemascope', 'cinerama', 'technicolor', 'western', 'air cooler', 'animated cartoon', 'black-and-white film', 'cartoon', 'cinema', 'cold pack', 'color film', 'cooler'],
    'chilling': ['ache', 'aching', 'adiabatic absorption', 'adiabatic demagnetization', 'adiabatic expansion', 'air conditioning', 'air cooling', 'alarming', 'algific', 'awing', 'blast freezing', 'blast-freezing'],
    'chilly': ['olympian', 'above all that', 'affectless', 'aguey', 'aguish', 'algid', 'aloof', 'anesthetized', 'arctic', 'autistic', 'backward', 'bashful'],
    'chime': ['accord', 'accordance', 'agree', 'agreement', 'alliterate', 'alliteration', 'announce', 'answer to', 'articulate', 'assent', 'assonance', 'assonate'],
    'chimera': ['airy hope', 'airy nothing', 'apparition', 'autism', 'brainchild', 'bubble', 'daydream', 'deception', 'delirium', 'deluded belief', 'delusion', 'dereism'],
    'chimerical': ['barmecidal', 'barmecide', 'absurd', 'aerial', 'air-built', 'airy', 'ambitious', 'apparent', 'apparitional', 'autistic', 'chimeric', 'cloud-born'],
    'chiming': ['accord', 'accordance', 'accordant', 'according', 'alliteral', 'alliterating', 'alliterative', 'assonant', 'assonantal', 'attune', 'attuned', 'attunement'],
    'chimney': ['abysm', 'abyss', 'arroyo', 'box canyon', 'breach', 'break', 'canyon', 'cavity', 'chap', 'chasm', 'check', 'chimney corner'],
    'chimpanzee': ['cape polecat', 'ape', 'bar', 'bear', 'cavy', 'chimp', 'coon', 'ferret', 'foumart', 'glutton', 'groundhog', 'guinea pig'],
    'chin': ['bandy words', 'bat the breeze', 'beat the gums', 'button', 'causerie', 'chat', 'chew the fat', 'chew the rag', 'colloque', 'colloquize', 'commerce with', 'commune with'],
    'china': ['adobe', 'biscuit', 'bisque', 'bowl', 'brick', 'bubble', 'cement', 'ceramic ware', 'ceramics', 'clay', 'crock', 'crockery'],
    'chine': ['bilge', 'blain', 'bleb', 'blister', 'blob', 'boss', 'bow', 'bubble', 'bulb', 'bulge', 'bulla', 'bump'],
    'chink': ['abysm', 'abyss', 'aperture', 'arroyo', 'assailability', 'bar', 'bezel', 'bind', 'block', 'block up', 'blockade', 'box canyon'],
    'chinoiserie': ['arabesque', 'baroque', 'baroqueness', 'elaborateness', 'elegance', 'fanciness', 'fineness', 'flamboyance', 'floridity', 'floridness', 'floweriness', 'luxuriance'],
    'chintzy': ['beat-up', 'bedraggled', 'blowzy', 'careless', 'cheeseparing', 'chinchy', 'dilapidated', 'drabbletailed', 'draggled', 'draggletailed', 'exiguous', 'frowzy'],
    'chip': ['abrade', 'abrasion', 'air', 'bark', 'bit', 'blemish', 'bloody', 'breach', 'break', 'break in', 'breakage', 'bubble'],
    'chip in': ['acknowledge', 'be enfranchised', 'be implicated in', 'bear a hand', 'bear the expense', 'break in', 'chime in', 'come through', 'contribute', 'contribute to', 'cut in', 'defray'],
    'chipper': ['active', 'activist', 'activistic', 'alert', 'alive', 'alive and kicking', 'animate', 'animated', 'bouncing', 'bouncy', 'breezy', 'bright'],
    'chippy': ['jezebel', 'bad woman', 'baggage', 'bitch', 'broad', 'clitoromaniac', 'cocotte', 'drab', 'easy lay', 'easy woman', 'floozy', 'frail sister'],
    'chips': ['bakehead', 'black gang', 'blunt', 'boilerman', 'boodle', 'brass', 'bread', 'bucks', 'bungs', 'cabbage', 'cabin boy', 'cash'],
    'chirm': ['babel', 'brouhaha', 'cheep', 'chip', 'chipper', 'chirrup', 'chitter', 'clamor', 'din', 'hubbub', 'hullabaloo', 'jangle'],
    'chiropodist': ['anesthesiologist', 'cardiologist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'immunologist', 'internist', 'neurologist', 'obstetrician', 'oculist'],
    'chiropractic': ['galenic medicine', 'allopathic', 'allopathy', 'ayurveda', 'chiropodic', 'chiropraxis', 'clinical', 'dental', 'eclecticism', 'exodontic', 'homeopathic', 'homeopathy'],
    'chirp': ['anthem', 'ballad', 'bark', 'bawl', 'beam', 'bellow', 'blare', 'blat', 'blubber', 'boom', 'bray', 'breathe'],
    'chisel': ['assemble', 'autolithograph', 'bamboozle', 'be a printmaker', 'beat', 'beguile of', 'bilk', 'block out', 'bunco', 'burn', 'canal', 'canalize'],
    'chiseling': ['artful', 'burr', 'calculating', 'collusive', 'covinous', 'crafty', 'cross-hatching', 'cunning', 'deceitful', 'demitint', 'engravement', 'engraving'],
    'chit': ['accounts payable', 'accounts receivable', 'acknowledgment', 'amount due', 'answer', 'bad debts', 'bairn', 'bantam', 'banty', 'bill', 'billet', 'bills'],
    'chitchat': ['babble', 'back-fence gossip', 'backchat', 'beauty-parlor chitchat', 'cackle', 'chat', 'chatter', 'chitter', 'chitter-chatter', 'clack', 'cocktail-party chitchat', 'gabble'],
    'chivalrous': ['aristocratic', 'benevolent', 'big', 'bighearted', 'bold', 'bold-spirited', 'brave', 'ceremonious', 'charitable', 'chivalric', 'considerate', 'courageous'],
    'chivalry': ['dutch courage', 'ffvs', 'ancienne noblesse', 'aristocracy', 'arms', 'art of war', 'baronage', 'baronetage', 'bigheartedness', 'bigness', 'boldness', 'braveness'],
    'chivy': ['aggravate', 'annoy', 'badger', 'bait', 'be at', 'bedevil', 'beset', 'bother', 'bristle', 'brown off', 'bug', 'bullyrag'],
    'chlorinate': ['acetify', 'acidify', 'acidulate', 'aerate', 'aerify', 'alkalify', 'alkalize', 'antisepticize', 'atomize', 'autoclave', 'boil', 'borate'],
    'chloroform': ['ko', 'pentothal', 'anesthetize', 'annihilate', 'bedaze', 'benumb', 'bereave of life', 'besot', 'blunt', 'carry away', 'carry off', 'cocaine'],
    'chock': ['arrest', 'bar', 'barricade', 'bearing rein', 'bit', 'block', 'block up', 'blockade', 'bolt', 'brake', 'brim', 'chain'],
    'chock full': ['sro', 'awash', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chuck-full', 'congested', 'cram-full', 'crammed', 'crowded'],
    'chocolate': ['life saver', 'scotch kisses', 'beige', 'bonbon', 'brittle', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'bubble gum', 'butterscotch', 'candied apple'],
    'choice': ['attic', 'acceptance', 'adjudgment', 'adjudication', 'aesthetic', 'alternative', 'animus', 'appetence', 'appetency', 'appetite', 'appraisal', 'appropriate'],
    'choir': ['easter sepulcher', 'liederkranz', 'liedertafel', 'a cappella', 'ambry', 'apse', 'baptistery', 'blindstory', 'chamber chorus', 'chancel', 'choral group', 'choral society'],
    'choirmaster': ['mahdi', 'bell cow', 'bell mare', 'bellwether', 'born leader', 'cantor', 'charismatic leader', 'choir chaplain', 'choragus', 'choral director', 'chorister', 'conductor'],
    'choke': ['od', 'asphyxia', 'asphyxiate', 'asphyxiation', 'bake', 'bang', 'bar', 'barricade', 'batten', 'batten down', 'be in heat', 'be killed'],
    'chokedamp': ['afterdamp', 'blackdamp', 'breath', 'cloud', 'coal gas', 'damp', 'effluvium', 'exhalation', 'exhaust', 'exhaust gas', 'fetid air', 'firedamp'],
    'choking': ['abolishment', 'abolition', 'annihilation', 'annulment', 'asphyxia', 'asphyxiation', 'bar', 'barrier', 'blank wall', 'blind alley', 'blind gut', 'block'],
    'choler': ['acerbity', 'acid', 'acidity', 'acidulousness', 'acrimony', 'anger', 'animosity', 'asperity', 'bad humor', 'bad temper', 'bile', 'biliousness'],
    'cholera': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'choleric': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrimonious', 'ambivert', 'angry', 'bilious', 'bitter'],
    'chomp': ['bite', 'bolus', 'champ', 'chaw', 'chew', 'chew the cud', 'chew up', 'chump', 'crunch', 'cud', 'gnash', 'gnaw'],
    'choo choo': ['amtrak', 'baggage train', 'cable railroad', 'cog railroad', 'cog railway', 'el', 'electric', 'electric train', 'elevated', 'express', 'express train', 'flier'],
    'choose': ['adopt', 'aim at', 'be desirous of', 'choose to', 'choosy', 'co-opt', 'command', 'covet', 'crave', 'cull', 'decide', 'decree'],
    'choosing': ['adoptive', 'alternativity', 'appointive', 'choice', 'choosy', 'co-optation', 'co-option', 'constituent', 'decision', 'discriminating', 'eclectic', 'election'],
    'choosy': ['adoptive', 'appointive', 'censorious', 'choicy', 'choosing', 'conscientious', 'constituent', 'critical', 'demanding', 'difficult', 'discerning', 'discriminating'],
    'chop': ['saratoga chop', 'vandyke', 'alter', 'ameliorate', 'amputate', 'ax', 'bang', 'bank', 'barley', 'bash', 'bat', 'be changed'],
    'chop down': ['beat down', 'blow down', 'blow over', 'bowl down', 'bowl over', 'break down', 'bring down', 'bulldog', 'bulldoze', 'burn down', 'cast down', 'cut down'],
    'chop logic': ['analyze', 'anatomize', 'argue', 'argufy', 'around the bush', 'atomize', 'bandy words', 'beat about', 'beg the question', 'bicker', 'boggle', 'cavil'],
    'chopper': ['bicycle', 'bike', 'copter', 'cycle', 'eggbeater', 'helicopter', 'iron', 'minibike', 'motocycle', 'motorbike', 'motorcycle', 'pedicab'],
    'choppy': ['bouncy', 'broken', 'broken off', 'bumpy', 'capricious', 'careening', 'catchy', 'changeable', 'changing', 'chopped-off', 'coarse', 'coarse-grained'],
    'chops': ['bazoo', 'chaps', 'embouchure', 'gab', 'gob', 'jaw', 'jaws', 'jowls', 'kisser', 'lips', 'mandibles', 'maw'],
    'choral': ['alto', 'baritone', 'bass', 'bravura', 'choric', 'coloratura', 'dramatic', 'falsetto', 'heroic', 'hymnal', 'liturgical', 'lyric'],
    'chorale': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'liederkranz', 'liedertafel', 'magnificat', 'miserere', 'negro spiritual', 'nunc dimittis'],
    'chord': ['accompany', 'accord', 'air line', 'arpeggio', 'assonate', 'atone', 'attune', 'axis', 'be harmonious', 'be in tune', 'beeline', 'blend'],
    'chore': ['augean task', 'herculean task', 'administer to', 'assignment', 'attend', 'attend on', 'backbreaker', 'ballbuster', 'bitch', 'busywork', 'care for', 'char'],
    'chorea': ['ms', 'ague', 'amyotrophic lateral sclerosis', 'brain disease', 'bumpiness', 'cephalalgia', 'cerebral palsy', 'chattering', 'cold shivers', 'emotional disorder', 'epilepsy', 'falling sickness'],
    'choreographer': ['comedian', 'dramatist', 'dramatizer', 'dramaturge', 'farcer', 'farceur', 'farceuse', 'farcist', 'gagman', 'joke writer', 'jokesmith', 'librettist'],
    'choreography': ['alphabet', 'art', 'ballet', 'ballroom dancing', 'blueprint', 'charactering', 'characterization', 'chart', 'choreodrama', 'classical ballet', 'comedy ballet', 'conventional representation'],
    'chorography': ['lambert conformal projection', 'mercator projection', 'miller projection', 'aeronautical chart', 'altimetry', 'astronomical chart', 'atlas', 'azimuthal projection', 'bathymetry', 'biometrics', 'biometry', 'cadastration'],
    'chortle': ['homeric laughter', 'be in stitches', 'belly laugh', 'boff', 'boffola', 'break up', 'burst into laughter', 'burst of laughter', 'burst out', 'burst out laughing', 'burst with laughter', 'bust a gut'],
    'chorus': ['liederkranz', 'liedertafel', 'ps', 'parthian shot', 'spenserian stanza', 'a cappella', 'acclamation', 'accord', 'accordance', 'act like', 'acting company', 'addendum'],
    'chorus girl': ['artist', 'artiste', 'ballerina', 'ballet dancer', 'ballet girl', 'ballroom dancer', 'belly dancer', 'burlesque queen', 'choir member', 'choirboy', 'choirman', 'choral dancer'],
    'chosen': ['a cut above', 'above', 'accepted', 'adopted', 'ahead', 'appointed', 'approved', 'ascendant', 'better', 'capping', 'carried', 'champion'],
    'chouse': ['artifice', 'beat', 'bilk', 'cheat', 'cozen', 'defraud', 'diddle', 'do', 'feint', 'flimflam', 'gambit', 'gimmick'],
    'chowder': ['irish stew', 'bisque', 'borscht', 'bouillabaisse', 'bouillon', 'broth', 'burgoo', 'chicken soup', 'clam chowder', 'clear soup', 'consomme', 'curry'],
    'chrismal': ['affusion', 'altar cloth', 'aspergation', 'aspersion', 'baldacchino', 'baldachin', 'baptism', 'baptismal font', 'baptismal gown', 'baptismal regeneration', 'baptistery', 'baptizement'],
    'christ': ['christ jesus', 'emmanuel', 'god the son', 'god-man', 'immanuel', 'jesu', 'jesus', 'jesus christ', 'jesus of nazareth', 'king of glory', 'king of heaven', 'king of kings'],
    'christen': ['anoint', 'asperge', 'asperse', 'baptize', 'bring up', 'broach', 'call', 'define', 'denominate', 'designate', 'dip', 'dub'],
    'christening': ['affusion', 'appellation', 'aspergation', 'aspersion', 'baptism', 'baptismal gown', 'baptismal regeneration', 'baptistery', 'baptizement', 'calling', 'chrismal', 'definition'],
    'christian': ['christianlike', 'christianly', 'christlike', 'christly', 'god-fearing man', 'nazarene', 'nazarite', 'accepted', 'accepter', 'adoring', 'affectionate', 'approved'],
    'christian sectarians': ['confucianist', 'gheber', 'gnostic', 'hindu', 'jew', 'magian', 'magus', 'muhammadan', 'sabaean', 'shintoist', 'sikh', 'taoist'],
    'christianity': ['christendom', 'christianism', 'christlikeness', 'christliness', 'judeo-christian religion', 'orthodox christianity', 'protestant christianity', 'angelicalness', 'beauty of holiness', 'fear of god', 'godlikeness', 'godliness'],
    'christlike': ['christian', 'christly', 'god-fearing', 'affectionate', 'angelic', 'benign', 'benignant', 'brotherly', 'celestial', 'compassionate', 'decent', 'divine'],
    'christmas': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'corpus christi'],
    'christmas carol': ['brautlied', 'kunstlied', 'liebeslied', 'volkslied', 'alba', 'anthem', 'art song', 'aubade', 'ballad', 'ballade', 'ballata', 'barcarole'],
    'chromatic': ['cold', 'colorific', 'coloring', 'cool', 'dichromatic', 'enharmonic', 'glowing', 'harmonious', 'many-colored', 'matching', 'medley', 'monochromatic'],
    'chromosome': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'w chromosome', 'weismann theory', 'weismannism', 'wiesner theory'],
    'chronic': ['abiding', 'accepted', 'accustomed', 'age-long', 'aged', 'ancient', 'antique', 'confirmed', 'constant', 'continuing', 'customary', 'deep-dyed'],
    'chronicle': ['clio', 'muse of history', 'account', 'adventures', 'anecdotage', 'anecdote', 'annals', 'archive', 'autobiography', 'biograph', 'biographical sketch', 'biographize'],
    'chronicler': ['boswell', 'annalist', 'autobiographer', 'autobiographist', 'biographer', 'calendar maker', 'calendarist', 'chronographer', 'chronologer', 'chronologist', 'clockmaker', 'diarist'],
    'chronological': ['annalistic', 'autobiographical', 'biographical', 'calendarial', 'calendric', 'chronogrammatic', 'chronographic', 'chronologic', 'chronoscopic', 'continuous', 'dated', 'diaristic'],
    'chronology': ['clio', 'muse of history', 'account', 'adventures', 'almanac', 'annals', 'autobiography', 'biographical sketch', 'biography', 'calendar', 'case history', 'check sheet'],
    'chronometer': ['big ben', 'astronavigation', 'celestial navigation', 'clock', 'clock movement', 'clockworks', 'coastwise navigation', 'consolan', 'dead reckoning', 'fix', 'horologe', 'horologium'],
    'chthonian': ['acherontic', 'druid', 'hadean', 'lethean', 'parsi', 'plutonian', 'plutonic', 'sabaist', 'satan worshiper', 'satanist', 'stygian', 'tartarean'],
    'chubby': ['adipose', 'ample', 'beefy', 'big-bellied', 'bloated', 'blocky', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chunky'],
    'chuck': ['chateaubriand', 'abandon', 'abjure', 'abstract', 'anchorage', 'barf', 'be seasick', 'be sick', 'beak', 'blade roast', 'boot out', 'bounce'],
    'chuckle': ['homeric laughter', 'be in stitches', 'belly laugh', 'boff', 'boffola', 'break up', 'burst into laughter', 'burst of laughter', 'burst out', 'burst out laughing', 'burst with laughter', 'bust a gut'],
    'chum': ['ace', 'amigo', 'associate', 'associate with', 'assort with', 'bedfellow', 'bedmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty'],
    'chump': ['asshole', 'babe', 'bean', 'boob', 'booby', 'butt', 'champ', 'chaw', 'chew', 'chomp', 'cinch', 'conk'],
    'chunk': ['accumulation', 'acervation', 'agglomerate', 'agglomeration', 'aggregate', 'aggregation', 'allotment', 'allowance', 'amassment', 'amount', 'ante', 'batch'],
    'chunky': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blocky', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'corpulent'],
    'church': ['mass', 'adherents', 'affiliation', 'apostleship', 'bedtime prayer', 'body', 'branch', 'call', 'camp meeting', 'care of souls', 'church service', 'churchly'],
    'church house': ['basilica', 'bethel', 'cathedral', 'cathedral church', 'church', 'clergy house', 'conventicle', 'deanery', 'duomo', 'glebe', 'house of god', 'house of prayer'],
    'church music': ['negro spiritual', 'anthem', 'cantata', 'canticle', 'chorale', 'doxology', 'gospel', 'gospel music', 'hymn', 'hymn-tune', 'hymnody', 'hymnology'],
    'churchgoer': ['christian', 'god-fearing man', 'accepter', 'adorer', 'assembly', 'beadsman', 'believer', 'brethren', 'catechumen', 'celebrant', 'chapelgoer', 'churchgoers'],
    'churchly': ['abbatial', 'abbatical', 'archiepiscopal', 'canonical', 'capitular', 'capitulary', 'cathedral-like', 'cathedralesque', 'church', 'churchish', 'churchlike', 'clerical'],
    'churchman': ['christian', 'dd', 'doctor of divinity', 'god-fearing man', 'holy joe', 'abbe', 'accepter', 'believer', 'brother', 'catechumen', 'chaplain', 'church member'],
    'churl': ['babbitt', 'philistine', 'silas marner', 'arriviste', 'bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'boor', 'bounder', 'bourgeois'],
    'churlish': ['abrupt', 'aggressive', 'bearish', 'beastly', 'bitchy', 'bluff', 'blunt', 'boorish', 'brash', 'brusque', 'cankered', 'cantankerous'],
    'churn': ['agitate', 'agitation', 'agitator', 'beat', 'beat up', 'beater', 'blender', 'bluster', 'bobbery', 'boil', 'boiling', 'brouhaha'],
    'chute': ['ferris wheel', 'avenue', 'bank', 'bevel', 'bezel', 'blowhole', 'brolly', 'carousel', 'cascade', 'cataract', 'channel', 'chimney'],
    'chutzpah': ['backbone', 'bottom', 'brashness', 'brass', 'brazen boldness', 'cheek', 'crust', 'face', 'gall', 'grit', 'guts', 'gutsiness'],
    'cicatrix': ['birthmark', 'blackhead', 'blaze', 'bleb', 'blemish', 'blister', 'blotch', 'brand', 'bulla', 'caste mark', 'check', 'checkmark'],
    'cigar store': ['antique store', 'apothecary', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'chemist', 'clothiers', 'clothing store', 'confectionery', 'dress shop', 'drugstore'],
    'cilia': ['golgi apparatus', 'aster', 'basal body', 'cell membrane', 'central apparatus', 'central body', 'centriole', 'centroplasm', 'centrosome', 'centrosphere', 'chloroplast', 'chromoplast'],
    'ciliate': ['bristly', 'bushy', 'cirrose', 'fleecy', 'flocculent', 'furry', 'fuzzy', 'hairy', 'hirsute', 'hispid', 'lanate', 'matted'],
    'cinch': ['affix', 'afford proof of', 'anchor', 'annex', 'ascertain', 'assure', 'attach', 'babe', 'back band', 'backstrap', 'band', 'bandage'],
    'cincture': ['anklet', 'arena', 'armlet', 'band', 'begird', 'belt', 'bracelet', 'cingulum', 'circling', 'circumambience', 'circumambiency', 'circumcincture'],
    'cinder': ['alluvion', 'alluvium', 'ash', 'ashes', 'brand', 'burning ember', 'calx', 'carbon', 'charcoal', 'clinker', 'coal', 'coke'],
    'cinema': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'art film', 'black-and-white film', 'cartoon', 'chiller', 'cine', 'cinema verite', 'cinematograph'],
    'cineration': ['blazing', 'blistering', 'branding', 'burning', 'calcination', 'carbonization', 'cauterization', 'cautery', 'combustion', 'concremation', 'cracking', 'cremation'],
    'cipher': ['aesopian language', 'babel', 'greek', 'john hancock', 'a nobody', 'a nothing', 'add', 'algebraize', 'allegory', 'alphabetic character', 'argot', 'aught'],
    'circe': ['don juan', 'euryale', 'gorgon', 'lorelei', 'medea', 'medusa', 'parthenope', 'siren', 'stheno', 'bewitcher', 'charmer', 'coquette'],
    'circle': ['acquaintance', 'advance', 'alentours', 'alternate', 'ambience', 'ambit', 'anklet', 'annular muscle', 'annulus', 'anthelion', 'antisun', 'aphelion'],
    'circling': ['alternate', 'ambient', 'beating', 'cincture', 'circuition', 'circuitousness', 'circuitry', 'circularity', 'circulation', 'circumambience', 'circumambiency', 'circumambient'],
    'circuit': ['air lane', 'alentours', 'ambages', 'ambience', 'ambit', 'amplifier circuit', 'annular muscle', 'annulus', 'arena', 'areola', 'arsis', 'association'],
    'circuitous': ['o-shaped', 'aberrant', 'aberrative', 'ambagious', 'anfractuous', 'backhand', 'backhanded', 'circular', 'circumlocutional', 'circumlocutory', 'collateral', 'convolutional'],
    'circuitry': ['amplifier circuit', 'astable circuit', 'circling', 'circuition', 'circuitousness', 'circularity', 'circulation', 'circumambience', 'circumambiency', 'circumambulation', 'circumflexion', 'circumlocution'],
    'circular': ['o-shaped', 'actuate', 'ambagious', 'anfractuous', 'announcement', 'annular', 'annulate', 'annulose', 'annunciation', 'backhanded', 'booklet', 'brochure'],
    'circularity': ['aduncity', 'apparent soundness', 'aquilinity', 'arching', 'arcuation', 'casuistry', 'circling', 'circuition', 'circuitousness', 'circuitry', 'circulation', 'circumambience'],
    'circulate': ['advertise', 'air', 'announce', 'become public', 'break', 'bring out', 'broadcast', 'bruit about', 'buzz about', 'circle', 'circuit', 'circuiteer'],
    'circulation': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'advertisement', 'airing', 'angular momentum', 'angular motion', 'angular velocity', 'announcement', 'antibody'],
    'circumcision': ['adoption', 'agape', 'asperges', 'aspersion', 'auricular confession', 'bar mitzvah', 'bas mitzvah', 'celebration', 'confession', 'confirmation', 'conversion', 'high celebration'],
    'circumference': ['ambit', 'annular muscle', 'annulus', 'areola', 'aureole', 'border', 'boundaries', 'boundary', 'bounds', 'bourns', 'chaplet', 'circle'],
    'circumferential': ['ambient', 'circling', 'circumambient', 'circumflex', 'circumfluent', 'circumfluous', 'circumjacent', 'delineatory', 'embracing', 'encircling', 'enclosing', 'encompassing'],
    'circumlocution': ['ambages', 'anfractuosity', 'circling', 'circuition', 'circuitousness', 'circuitry', 'circularity', 'circulation', 'circumambages', 'circumambience', 'circumambiency', 'circumambulation'],
    'circumnavigate': ['boat', 'bypass', 'canoe', 'carry sail', 'circle', 'circuit', 'circuiteer', 'circulate', 'circumambulate', 'circummigrate', 'circumvent', 'close the circle'],
    'circumscribe': ['abate', 'abbreviate', 'adjust to', 'alter', 'assuage', 'bar', 'bound', 'box', 'box in', 'box up', 'circle in', 'coarct'],
    'circumscription': ['abbreviation', 'allowance', 'astriction', 'astringency', 'ban', 'bar', 'barring', 'beleaguerment', 'besetment', 'blockade', 'blockading', 'border line'],
    'circumspect': ['ambling', 'attentive', 'calculating', 'canny', 'careful', 'cautious', 'chary', 'claudicant', 'considerate', 'crawling', 'creeping', 'creeping like snail'],
    'circumstance': ['absolute fact', 'accepted fact', 'actual fact', 'adjunct', 'admitted fact', 'adventure', 'affair', 'appurtenance', 'aspect', 'axiom', 'bald fact', 'bare fact'],
    'circumstances': ['affairs', 'alentours', 'ambience', 'ambit', 'assessed valuation', 'assets', 'assets and liabilities', 'borderlands', 'circle', 'circuit', 'circumambiencies', 'circumjacencies'],
    'circumstantial': ['absolute', 'accessory', 'accidental', 'accompanying', 'accurate', 'additional', 'adducible', 'admissible', 'ado', 'adscititious', 'adventitious', 'afloat'],
    'circumstantiality': ['accuracy', 'attention to detail', 'conscientiousness', 'correctness', 'criticality', 'criticalness', 'delicacy', 'detail', 'exactingness', 'exactitude', 'exactness', 'exquisiteness'],
    'circumstantiate': ['adduce', 'affirm', 'anatomize', 'atomize', 'attest', 'authenticate', 'back', 'back up', 'bear out', 'bolster', 'buttress', 'certify'],
    'circumvent': ['avoid', 'baffle', 'balk', 'bamboozle', 'beat', 'befool', 'beg', 'beguile', 'betray', 'bilk', 'blast', 'bluff'],
    'circumvention': ['avoidance', 'avoiding reaction', 'bamboozlement', 'befooling', 'bluffing', 'buck-passing', 'calculated deception', 'conning', 'deceiving', 'deception', 'deceptiveness', 'defense mechanism'],
    'circus': ['broadway', 'agora', 'amphitheater', 'annular muscle', 'annulus', 'arena', 'areola', 'athletic field', 'auditorium', 'aureole', 'background', 'bear garden'],
    'cirrhosis': ['alcoholic addiction', 'alcoholic psychosis', 'alcoholism', 'bottle nose', 'cholangitis', 'cholecystitis', 'delirium tremens', 'dipsomania', 'ebriosity', 'grog blossom', 'habitual drunkenness', 'heavy drinking'],
    'cirrose': ['bristly', 'bushy', 'capillary', 'castellatus', 'cirrous', 'cloud-flecked', 'clouded', 'cloudy', 'cumuliform', 'cumulous', 'dark', 'dirty'],
    'cirrus': ['cloudcuckooland', 'alto-cumulus', 'alto-stratus', 'animal fiber', 'anvil cloud', 'artificial fiber', 'banner cloud', 'billowy cloud', 'cap cloud', 'capillament', 'cilium', 'cirro-cumulus'],
    'cist': ['barrow', 'beehive tomb', 'bone house', 'box grave', 'burial', 'burial chamber', 'burial mound', 'catacombs', 'cenotaph', 'charnel house', 'cist grave', 'cromlech'],
    'cistern': ['artificial lake', 'bayou lake', 'dam', 'dead water', 'dike', 'etang', 'farm pond', 'fishpond', 'freshwater lake', 'glacial lake', 'inland sea', 'lagoon'],
    'citadel': ['acropolis', 'bastion', 'beachhead', 'blockhouse', 'bridgehead', 'bunker', 'castle', 'donjon', 'fasthold', 'fastness', 'fort', 'fortress'],
    'citation': ['accolade', 'acknowledgment', 'assault', 'attack', 'award', 'by-line', 'case', 'censure', 'certiorari', 'confession', 'credit line', 'cross reference'],
    'cite': ['accuse', 'address to', 'adduce', 'advance', 'allege', 'allude to', 'anatomize', 'arraign', 'article', 'atomize', 'bid come', 'book'],
    'citizen': ['burgess', 'burgher', 'citizen by adoption', 'civilian', 'cosmopolitan', 'cosmopolite', 'deditician', 'denizen', 'dweller', 'franklin', 'free citizen', 'freedman'],
    'citizenry': ['everyman', 'john doe', 'public', 'body politic', 'common man', 'commonwealth', 'community', 'community at large', 'constituency', 'cultural community', 'demos', 'dwellers'],
    'city': ['bowery', 'chinatown', 'east end', 'east side', 'kreis', 'little hungary', 'little italy', 'stadt', 'west end', 'west side', 'archbishopric', 'archdiocese'],
    'city dweller': ['big-city man', 'bourgeois', 'burgess', 'burgher', 'city man', 'city slicker', 'exurbanite', 'oppidan', 'suburbanite', 'townee', 'towner', 'townfolk'],
    'city father': ['mp', 'member of congress', 'member of parliament', 'alderman', 'archon', 'assemblyman', 'bailie', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor'],
    'city hall': ['american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party', 'greenback party'],
    'city manager': ['alderman', 'archon', 'bailie', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor', 'city councilman', 'city father', 'commissar', 'commissioner'],
    'city slicker': ['big-city man', 'bourgeois', 'burgess', 'burgher', 'city dweller', 'city man', 'cosmopolitan', 'cosmopolite', 'exurbanite', 'man of experience', 'man-about-town', 'oppidan'],
    'city state': ['ally', 'archduchy', 'archdukedom', 'body politic', 'buffer state', 'captive nation', 'chieftaincy', 'chieftainry', 'colony', 'commonweal', 'commonwealth', 'country'],
    'civic': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'burghal', 'chauvinist', 'citified', 'city', 'civil', 'common'],
    'civil': ['absolute', 'accommodating', 'affable', 'agreeable', 'amiable', 'appropriate', 'aristocratic', 'attentive', 'authoritarian', 'autocratic', 'autonomous', 'becoming'],
    'civil ceremony': ['gretna green wedding', 'banns', 'bridal', 'bridal suite', 'bridechamber', 'chuppah', 'church wedding', 'civil wedding', 'elopement', 'epithalamium', 'espousals', 'espousement'],
    'civilian': ['ag', 'da', 'kc', 'qc', 'ssc', 'us attorney', 'attorney general', 'citizen', 'corporation lawyer', 'court-appointed lawyer', 'criminal lawyer', 'defense counsel'],
    'civility': ['acculturation', 'act of courtesy', 'affability', 'agreeableness', 'amenities', 'amenity', 'amiability', 'appropriateness', 'attention', 'becomingness', 'bienseance', 'ceremonies'],
    'civilization': ['acculturation', 'civility', 'complex', 'cultivation', 'cultural drift', 'culture', 'culture area', 'culture center', 'culture complex', 'culture conflict', 'culture contact', 'culture pattern'],
    'civilize': ['acculturate', 'advance', 'ameliorate', 'amend', 'anthropomorphize', 'better', 'boost', 'bring forward', 'broaden', 'broaden the mind', 'catechize', 'demonstrate'],
    'civilized': ['christian', 'abstruse', 'advanced', 'ameliorated', 'beautified', 'becoming', 'befitting', 'bettered', 'bland', 'comme il faut', 'conforming', 'converted'],
    'clabber': ['devonshire cream', 'albumen', 'batter', 'beat up', 'blood clot', 'bonnyclabber', 'butter', 'cake', 'casein', 'churn', 'clot', 'clotted cream'],
    'clack': ['klaxon', 'babble', 'babblement', 'bavardage', 'bibble-babble', 'bicker', 'blab', 'blabber', 'blah-blah', 'blather', 'blether', 'blethers'],
    'clacker': ['klaxon', 'boiler factory', 'boiler room', 'bull-roarer', 'catcall', 'cherry bomb', 'clack', 'clapper', 'cracker', 'cricket', 'firecracker', 'horn'],
    'clad': ['apparel', 'appareled', 'array', 'arrayed', 'attire', 'attired', 'bedecked', 'breeched', 'capped', 'chausse', 'cloaked', 'clothed'],
    'claim': ['absolute interest', 'acquire', 'adduce', 'advance', 'adverse possession', 'affidavit', 'affirm', 'affirmation', 'allegation', 'allege', 'alodium', 'application'],
    'claimant': ['accusant', 'accuser', 'allegator', 'appellant', 'applicant', 'aspirant', 'bidder', 'candidate', 'complainant', 'delator', 'impeacher', 'impugner'],
    'clairvoyance': ['esp', 'a priori knowledge', 'anticipation', 'apprehension', 'astrology', 'augury', 'buddhi', 'clairsentience', 'command', 'comprehension', 'conception', 'conceptualization'],
    'clairvoyant': ['anticipant', 'anticipatory', 'automatist', 'clairaudient', 'clairsentient', 'divinatory', 'extrasensory', 'farseeing', 'farsighted', 'feeling', 'forehanded', 'foreknowing'],
    'clam': ['chilopoda', 'chordata', 'dungeness crab', 'echiuroidea', 'ectoprocta', 'entoprocta', 'japanese crab', 'laconian', 'monoplacophora', 'nemertinea', 'phoronidea', 'spartan'],
    'clambake': ['tv dinner', 'alfresco meal', 'barbecue', 'breakfast', 'brunch', 'buffet supper', 'campaign dinner', 'campaigning', 'coffee break', 'cookout', 'diner', 'dinner'],
    'clammy': ['adhesive', 'amylaceous', 'bathed in sweat', 'beaded with sweat', 'clabbered', 'close', 'clotted', 'coagulated', 'curdled', 'damp', 'diaphoretic', 'doughy'],
    'clamor': ['babel', 'bedlam let loose', 'adjuration', 'agitate', 'air a grievance', 'appeal', 'babel', 'bawl', 'be noisy', 'bedlam', 'beef', 'bellow'],
    'clamor for': ['ache for', 'adjure', 'appeal', 'appeal to', 'ask', 'ask for', 'be dying for', 'be hurting for', 'be indicated', 'beg', 'beseech', 'blackmail'],
    'clamorous': ['acute', 'articulate', 'bawling', 'begging', 'blaring', 'blatant', 'blatting', 'blustering', 'boanergean', 'boisterous', 'brassy', 'brawling'],
    'clamp': ['affix', 'alum', 'anchor', 'annex', 'astringent', 'attach', 'bear hug', 'belay', 'bite', 'brace', 'bracket', 'cement'],
    'clamp down on': ['asphyxiate', 'beat down', 'bottle up', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'censor', 'choke off', 'coerce', 'compel'],
    'clan': ['animal kingdom', 'ashram', 'band', 'blood', 'body', 'bracket', 'branch', 'brand', 'breed', 'brood', 'brotherhood', 'bunch'],
    'clandestine': ['back-door', 'backstairs', 'covert', 'feline', 'furtive', 'hidlings', 'hole-and-corner', 'hugger-mugger', 'privy', 'quiet', 'shifty', 'skulking'],
    'clang': ['animal noise', 'bark', 'barking', 'belch', 'birdcall', 'blare', 'blat', 'bray', 'burr', 'buzz', 'cackle', 'call'],
    'clank': ['belch', 'blare', 'blat', 'bray', 'burr', 'buzz', 'cackle', 'caw', 'change ringing', 'chime', 'chiming', 'chink'],
    'clannish': ['arrogant', 'cliquey', 'cliquish', 'contemptuous', 'contumelious', 'disdainful', 'elect', 'ethnic', 'ethnocentric', 'exclusive', 'family', 'genetic'],
    'clansman': ['agnate', 'ancestry', 'blood', 'blood relation', 'blood relative', 'cognate', 'collateral', 'collateral relative', 'connections', 'consanguinean', 'distaff side', 'distant relation'],
    'clap': ['bedlam let loose', 'french disease', 'spanish pox', 'vd', 'acclaim', 'acclamation', 'acquired syphilis', 'applaud', 'applause', 'apply', 'balanitis gangrenosa', 'bang'],
    'clapboard': ['formica', 'masonite', 'asphalt', 'beam', 'billet', 'blacktop', 'board', 'boarding', 'brick', 'canvas', 'carpeting', 'cobblestone'],
    'clapper': ['klaxon', 'bell', 'boiler factory', 'boiler room', 'bull-roarer', 'catcall', 'cherry bomb', 'chimes', 'church bell', 'clack', 'clacker', 'cowbell'],
    'clappers': ['battery', 'bells', 'bones', 'castanets', 'celesta', 'chime', 'chimes', 'crash cymbal', 'cymbals', 'finger cymbals', 'gamelan', 'glockenspiel'],
    'clapping': ['acclaim', 'acclamation', 'applause', 'big hand', 'burst of applause', 'cheer', 'clap', 'clapping of hands', 'eclat', 'encore', 'hand', 'handclap'],
    'claptrap': ['absurdity', 'amphigory', 'argument', 'argument by analogy', 'argumentum ad baculum', 'argumentum ad captandum', 'argumentum ad hominem', 'babble', 'babblement', 'bad case', 'balderdash', 'balls'],
    'claqueur': ['adherent', 'applauder', 'appreciator', 'attender', 'audience', 'booster', 'buff', 'commender', 'deadhead', 'encomiast', 'eulogist', 'eulogizer'],
    'clarification': ['allegorization', 'bolting', 'colature', 'cracking', 'decipherment', 'decoding', 'demonstration', 'demythologization', 'destructive distillation', 'distillation', 'easing', 'editing'],
    'clarify': ['account for', 'allegorize', 'analyze', 'bolt', 'break down', 'clean', 'cleanse', 'clear', 'clear up', 'crack', 'decipher', 'decrassify'],
    'clarinet': ['english horn', 'pandean pipe', 'aulos', 'basset horn', 'basset oboe', 'bassoon', 'block flute', 'bombard', 'bourdon', 'cello', 'claribel', 'clarion'],
    'clarion': ['english horn', 'alpenhorn', 'alphorn', 'althorn', 'alto horn', 'bagpipe', 'ballad horn', 'baritone', 'bass horn', 'bassoon', 'bay', 'beep'],
    'clarity': ['atticism', 'accuracy', 'admission of light', 'appropriateness', 'articulateness', 'articulation', 'atmospheric visibility', 'care', 'ceiling', 'ceiling unlimited', 'chasteness', 'chastity'],
    'clash': ['babel', 'discordia', 'eris', 'action', 'aerial combat', 'affray', 'agree to disagree', 'altercation', 'antagonism', 'antagonize', 'antipathy', 'appulse'],
    'clashing': ['acrid', 'adversary', 'adversative', 'adverse', 'adversive', 'ajar', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'antonymous'],
    'clasp': ['abduct', 'adhere', 'adhere to', 'agglomerate', 'around', 'articulate', 'batten', 'batten down', 'bear hug', 'bite', 'bolt', 'bosom'],
    'class': ['account', 'adherents', 'advantageousness', 'agreeableness', 'allot', 'alphabetize', 'analyze', 'animal kingdom', 'antonomasia', 'appraise', 'appreciate', 'arrange'],
    'classic': ['french literature', 'renaissance literature', 'ageless', 'ancient literature', 'archetypal', 'archetype', 'art object', 'belles lettres', 'best seller', 'book', 'bound book', 'brainchild'],
    'classical': ['attic', 'ciceronian', 'gothic', 'greek', 'latin', 'roman', 'victorian', 'absolute', 'aesthetic', 'antediluvian', 'antiquated', 'antique'],
    'classicist': ['jonathan oldbuck', 'miniver cheevy', 'pre-raphaelite', 'academician', 'antiquarian', 'antiquary', 'antique collector', 'antique dealer', 'antique-car collector', 'archaeologist', 'archaist', 'bookman'],
    'classification': ['antonomasia', 'appraisal', 'assessment', 'binomial nomenclature', 'biosystematics', 'biosystematy', 'categorization', 'class', 'evaluation', 'factoring', 'family', 'gauging'],
    'classified': ['aligned', 'arcane', 'arranged', 'arrayed', 'assorted', 'cabalistic', 'cataloged', 'categorized', 'censored', 'close', 'closed', 'composed'],
    'classify': ['alphabetize', 'analyze', 'appraise', 'arrange', 'assess', 'assort', 'bolt', 'bosom', 'break down', 'catalog', 'categorize', 'class'],
    'classmate': ['ace', 'amigo', 'associate', 'bedfellow', 'bedmate', 'birthmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty', 'camarade'],
    'classy': ['ambitious', 'braw', 'chic', 'clothes-conscious', 'cosmopolitan', 'dapper', 'dashing', 'dressed to advantage', 'dressed to kill', 'elegant', 'exquisite', 'fancy'],
    'clatter': ['bedlam let loose', 'babble', 'babblement', 'bavardage', 'bedlam', 'bibble-babble', 'bicker', 'blab', 'blabber', 'blah-blah', 'blast', 'blather'],
    'clause': ['adjectival phrase', 'article', 'back matter', 'bill', 'book', 'boundary condition', 'calendar', 'catch', 'chapter', 'column', 'companion bills amendment', 'condition'],
    'clavichord': ['klavier', 'steinway', 'baby grand', 'cembalo', 'clarichord', 'clavicembalo', 'clavicittern', 'clavicymbal', 'clavicytherium', 'clavier', 'concert grand', 'cottage piano'],
    'claw': ['abduct', 'abrade', 'agonize', 'bark', 'blemish', 'bloody', 'break', 'burn', 'carry off', 'catch', 'chafe', 'check'],
    'clawed': ['agonized', 'convulsed', 'crucified', 'dentate', 'digital', 'digitate', 'digitated', 'fanged', 'fingered', 'footed', 'harrowed', 'hoofed'],
    'claws': ['administration', 'authority', 'clutches', 'command', 'control', 'digits', 'disposition', 'domination', 'dominion', 'empery', 'empire', 'fangs'],
    'clay': ['adam', 'hominidae', 'homo sapiens', 'missouri meerschaum', 'acres', 'alluvion', 'alluvium', 'anatomy', 'arable land', 'ashes', 'blubber', 'body'],
    'clean': ['christian', 'daedalian', 'absolute', 'absolutely', 'acknowledge', 'adept', 'admit', 'adroit', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading'],
    'clean cut': ['clean', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'coherent', 'comely', 'connected', 'consistent', 'conspicuous', 'crisp', 'crystal-clear'],
    'clean out': ['bleach', 'blow', 'blow out', 'bowdlerize', 'clean', 'clean up', 'cleanse', 'clear', 'clear away', 'clear off', 'clear out', 'clear the decks'],
    'clean slate': ['blamelessness', 'blank', 'bloodless revolution', 'bouleversement', 'breakdown', 'breakup', 'cataclysm', 'catastrophe', 'clean sweep', 'cleanliness', 'cleanness', 'clear conscience'],
    'clean sweep': ['bloodless revolution', 'bouleversement', 'breakdown', 'breakup', 'cataclysm', 'catastrophe', 'clean slate', 'computer revolution', 'convulsion', 'counterrevolution', 'debacle', 'overthrow'],
    'clean up': ['bleach', 'bowdlerize', 'button up', 'cap', 'capitalize on', 'carry to completion', 'cash in on', 'clean', 'clean out', 'cleanse', 'clear', 'clear out'],
    'cleaner': ['abstergent', 'cathartic', 'char', 'charwoman', 'cleaner-off', 'cleaner-up', 'cleaning agent', 'cleaning lady', 'cleaning man', 'cleaning solvent', 'cleaning woman', 'cleanser'],
    'cleaning': ['abstergent', 'abstersion', 'autoclave', 'bowdlerization', 'broom', 'brush', 'carpet sweeper', 'catharsis', 'cathartic', 'cleansing', 'comb', 'currycomb'],
    'cleanliness': ['asepsis', 'blamelessness', 'blotlessness', 'chastity', 'clean slate', 'cleanly habits', 'cleanness', 'clear conscience', 'daintiness', 'fastidiousness', 'faultlessness', 'freshness'],
    'cleanse': ['beatify', 'bleach', 'bless', 'bowdlerize', 'canonize', 'clarify', 'clean', 'clean out', 'clean up', 'cleanse away', 'clear out', 'consecrate'],
    'cleanser': ['carbona', 'abstergent', 'benzine', 'bleach', 'borax', 'carbon tet', 'carbon tetrachloride', 'cathartic', 'cleaner', 'cleaning agent', 'cleaning solvent', 'cleansing cream'],
    'cleansing': ['abstergent', 'abstersion', 'alleviating', 'alleviative', 'analgesic', 'anesthetic', 'anodyne', 'apologetic', 'ascetic', 'assuasive', 'atoning', 'balmy'],
    'clear': ['attic', 'ciceronian', 'mickey mouse', 'above water', 'abroad', 'absolute', 'absolve', 'absolved', 'abstract', 'account for', 'accumulate', 'acquire'],
    'clear away': ['abstract', 'attenuate', 'blow', 'blow off', 'blow out', 'cast forth', 'cast off', 'cast out', 'chuck', 'clean out', 'clear', 'clear off'],
    'clear out': ['abscond', 'absquatulate', 'abstract', 'be off', 'beat a retreat', 'beat it', 'begone', 'bleach', 'blow', 'blow out', 'bolt', 'bowdlerize'],
    'clear sighted': ['argus-eyed', 'alert', 'alive', 'awake', 'cat-eyed', 'clear-eyed', 'clear-witted', 'clearheaded', 'eagle-eyed', 'eye-minded', 'farseeing', 'farsighted'],
    'clear the decks': ['abstract', 'arrange', 'ballast', 'blow', 'blow out', 'break bulk', 'break out ballast', 'cast off', 'cast out', 'chuck', 'clean out', 'clean up'],
    'clear the way': ['aid', 'blaze the trail', 'break the ice', 'cultivate the soil', 'ease', 'expedite', 'explain', 'facilitate', 'go in advance', 'grease', 'grease the ways', 'grease the wheels'],
    'clear up': ['account for', 'allegorize', 'answer', 'ascertain', 'assure', 'bottom', 'certify', 'cinch', 'cipher', 'clarify', 'clean up', 'clear'],
    'clear-cut': ['assured', 'biting', 'categorical', 'chiseled', 'clean-cut', 'clear', 'clear as crystal', 'clear as day', 'coherent', 'connected', 'consistent', 'conspicuous'],
    'clearance': ['lebensraum', 'absolution', 'acquitment', 'acquittal', 'acquittance', 'aesthetic distance', 'air space', 'allowance', 'amortization', 'amortizement', 'ample scope', 'approval'],
    'clearing': ['lebensraum', 'absolution', 'acquittal', 'acquittance', 'air space', 'aperture', 'back country', 'breaking out', 'broaching', 'cavity', 'chasm', 'check'],
    'clearing house': ['bank of england', 'bank of france', 'federal reserve bank', 'international monetary fund', 'lombard street bank', 'swiss bank', 'world bank', 'bank', 'branch bank', 'central bank', 'commercial bank', 'farm loan bank'],
    'clearly': ['absolutely', 'actually', 'aloud', 'and no mistake', 'apparently', 'apprehensibly', 'articulately', 'assuredly', 'at all events', 'at any rate', 'audibly', 'by all means'],
    'cleavage': ['abscission', 'alienation', 'alpha decay', 'amputation', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction', 'atomization', 'beta decay', 'bombardment', 'breach'],
    'cleave': ['accelerate', 'activate', 'adhere', 'adhere to', 'agglomerate', 'amputate', 'associate', 'atomize', 'ax', 'bifurcate', 'bisect', 'bite'],
    'cleft': ['abysm', 'abyss', 'alienation', 'aperture', 'arroyo', 'bifurcated', 'bisected', 'blaze', 'box canyon', 'branched', 'branching', 'breach'],
    'cleft palate': ['bowlegs', 'camelback', 'clubfoot', 'crookback', 'defacement', 'deformation', 'deformity', 'disfigurement', 'flatfoot', 'freakishness', 'harelip', 'humpback'],
    'clemency': ['acceptance', 'benevolence', 'caritas', 'charity', 'clementness', 'commiseration', 'compassion', 'condolence', 'easiness', 'easygoingness', 'endurance', 'equitableness'],
    'clement': ['accepting', 'benevolent', 'benign', 'benignant', 'bleeding', 'charitable', 'commiserative', 'compassionate', 'condolent', 'easy', 'easygoing', 'forbearant'],
    'clench': ['abduct', 'adhere to', 'bear hug', 'bite', 'carry off', 'clamp', 'clasp', 'cleave to', 'clinch', 'cling', 'clinging', 'clip'],
    'clerestory': ['entresol', 'first floor', 'flat', 'floor', 'ground floor', 'level', 'mezzanine', 'mezzanine floor', 'rez-de-chaussee', 'ridgepole', 'roof', 'roofpole'],
    'clergyman': ['dd', 'doctor of divinity', 'holy joe', 'abbe', 'ayatollah', 'brother', 'canon', 'cassock', 'chaplain', 'churchman', 'cleric', 'clerical'],
    'cleric': ['dd', 'doctor of divinity', 'holy joe', 'abbe', 'chaplain', 'churchman', 'clergyman', 'clerical', 'clerk', 'curate', 'cure', 'divine'],
    'clerical': ['abbatial', 'abbatical', 'accounting', 'apostolic', 'archiepiscopal', 'bookkeeping', 'canonical', 'capitular', 'capitulary', 'churchly', 'churchman', 'cleric'],
    'clerk': ['bible clerk', 'bible reader', 'ca', 'cpa', 'dd', 'doctor of divinity', 'federal', 'holy joe', 'abbe', 'academician', 'accountant', 'accountant general'],
    'clever': ['attic', 'daedalian', 'machiavellian', 'machiavellic', 'able', 'acute', 'adept', 'adroit', 'agile', 'alert', 'all-around', 'amusing'],
    'cleverness': ['italian hand', 'ability', 'acuity', 'acuteness', 'address', 'adeptness', 'adroitness', 'airmanship', 'aptitude', 'aptness', 'art', 'artfulness'],
    'cliche': ['abstraction', 'banality', 'banalness', 'bathetic', 'bromide', 'byword', 'catch phrase', 'catchword', 'chestnut', 'cliched', 'commonness', 'commonplace'],
    'click': ['be blooded', 'be successful', 'bump', 'catch on', 'chink', 'clack', 'clink', 'clop', 'clump', 'clunk', 'come off', 'connect'],
    'cliff dwelling': ['dymaxion house', 'white house', 'adobe house', 'building', 'casa', 'consulate', 'country house', 'country seat', 'dacha', 'deanery', 'dwelling house', 'edifice'],
    'cliff hanger': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'closet drama', 'comedy drama'],
    'cliff hanging': ['agitating', 'anxiety', 'apprehension', 'breathtaking', 'charged', 'disquieting', 'distracting', 'disturbing', 'dread', 'electric', 'exciting', 'exhilarating'],
    'climacteric': ['change of life', 'charged', 'clutch', 'convergence of events', 'crisis', 'critical', 'critical juncture', 'critical point', 'crossroads', 'crucial', 'crucial period', 'crunch'],
    'climactic': ['acmatic', 'apical', 'capital', 'chief', 'consummate', 'head', 'headmost', 'highest', 'maximal', 'maximum', 'meridian', 'meridional'],
    'climate': ['antarctic zone', 'arctic circle', 'arctic zone', 'frigid zones', 'torrid zone', 'tropic of cancer', 'tropic of capricorn', 'variable zones', 'weltanschauung', 'air', 'ambiance', 'ambience'],
    'climatology': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics'],
    'climax': ['achieve satisfaction', 'acme', 'acme of perfection', 'act of love', 'adultery', 'all', 'apex', 'aphrodisia', 'apogee', 'apoplexy', 'ass', 'balling'],
    'climb': ['abandon', 'abruptness', 'acclivity', 'advance', 'anabasis', 'arise', 'ascend', 'ascension', 'ascent', 'back', 'back up', 'bank'],
    'climb down': ['abjure', 'alight', 'back down', 'back out', 'backwater', 'crawfish out', 'deny', 'disavow', 'disclaim', 'dismount', 'disown', 'eat crow'],
    'climber': ['adventurer', 'algae', 'alpinist', 'ascender', 'astronaut', 'autophyte', 'bean', 'bracken', 'brown algae', 'camper', 'comers and goers', 'commuter'],
    'climbing': ['brownian movement', 'acclinate', 'acclivitous', 'advance', 'ambition', 'ambitiousness', 'anabasis', 'anabatic', 'angular motion', 'ascendant', 'ascending', 'ascension'],
    'clime': ['antarctic zone', 'arctic circle', 'arctic zone', 'frigid zones', 'torrid zone', 'tropic of cancer', 'tropic of capricorn', 'variable zones', 'calm weather', 'climate', 'cold weather', 'equator'],
    'clinch': ['abduct', 'adhere', 'adhere to', 'affix', 'afford proof of', 'agglomerate', 'anchor', 'ankle', 'annex', 'articulation', 'ascertain', 'assure'],
    'clincher': ['ko', 'conclusive argument', 'coup de grace', 'crusher', 'death stroke', 'deathblow', 'end-all', 'ender', 'final stroke', 'finisher', 'finishing stroke', 'floorer'],
    'cling': ['accretion', 'adhere', 'adhere to', 'adherence', 'adhesion', 'agglomerate', 'agglomeration', 'agglutination', 'attach', 'bear hug', 'bite', 'bond'],
    'cling to': ['adhere', 'adhere to', 'agglomerate', 'around', 'bear', 'bite', 'bosom', 'bunch', 'cherish', 'clasp', 'cleave', 'cleave to'],
    'clinging': ['adhering', 'adhesion', 'agglutinate', 'bond', 'cleaving', 'cling', 'coherence', 'coherent', 'cohering', 'cohesion', 'cohesive', 'grasping'],
    'clinic': ['va hospital', 'x ray', 'asylum', 'base hospital', 'blood bank', 'charity ward', 'community hospital', 'consultation room', 'convalescent home', 'convalescent hospital', 'delivery room', 'dispensary'],
    'clinical': ['allopathic', 'chiropodic', 'chiropractic', 'dental', 'exodontic', 'homeopathic', 'hydropathic', 'iatric', 'medical', 'naturopathic', 'neurological', 'obstetric'],
    'clink': ['alliteration', 'assonance', 'blank verse', 'bump', 'calaboose', 'can', 'change ringing', 'chime', 'chiming', 'chink', 'chokey', 'clang'],
    'clinker': ['adobe', 'alluvion', 'alluvium', 'ash', 'ashes', 'ashlar', 'atonalism', 'atonality', 'brand', 'brick', 'bricks and mortar', 'cacophony'],
    'clio': ['calliope', 'erato', 'euterpe', 'melpomene', 'muse of history', 'polyhymnia', 'terpsichore', 'thalia', 'adventures', 'annals', 'artistic imagination', 'autobiography'],
    'clip': ['abbreviate', 'abridge', 'abscind', 'abstract', 'adhere to', 'amputate', 'annihilate', 'articulate', 'attach', 'ball the jack', 'ban', 'bang'],
    'clipped': ['spartan', 'abbreviated', 'abridged', 'abstracted', 'aposiopestic', 'bobbed', 'brief', 'brusque', 'capsule', 'capsulized', 'close', 'compact'],
    'clipping': ['abbreviation', 'ana', 'analects', 'anthology', 'apocope', 'aposiopesis', 'bit', 'butt', 'chip', 'chunk', 'clip', 'clippings'],
    'clique': ['age group', 'associate with', 'assort with', 'band', 'battalion', 'bevy', 'body', 'brigade', 'bunch', 'cabal', 'cadre', 'camarilla'],
    'cliquish': ['arrogant', 'clannish', 'cliquey', 'contemptuous', 'contumelious', 'disdainful', 'elect', 'ethnocentric', 'exclusive', 'haughty', 'scornful', 'select'],
    'clitoris': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'cod', 'cods', 'cullions', 'family jewels', 'female organs'],
    'cloak': ['alibi', 'apology', 'apply to', 'arm', 'armor', 'becloud', 'befog', 'blanket', 'bless', 'blind', 'block', 'bonnet'],
    'clobber': ['bang', 'bash', 'bat', 'bear the palm', 'beat', 'beat all hollow', 'belt', 'best', 'biff', 'blank', 'blast', 'bonk'],
    'clock': ['big ben', 'beat time', 'brood', 'chronometer', 'clock movement', 'clockworks', 'cover', 'fix the time', 'horologe', 'horologium', 'keep time', 'mark time'],
    'clock in': ['accomplish', 'achieve', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be received', 'blow in', 'bob up', 'check in'],
    'clock watcher': ['dallier', 'dawdle', 'dawdler', 'diddler', 'dillydallier', 'do-nothing', 'dolittle', 'doodler', 'eye-servant', 'faineant', 'gentleman of leisure', 'goldbrick'],
    'clockwise': ['anticlockwise', 'around', 'conservative', 'counterclockwise', 'dexter', 'dextral', 'dextrocardial', 'dextrocerebral', 'dextrocular', 'dextrogyrate', 'dextrogyratory', 'dextropedal'],
    'clod': ['boeotian', 'chateaubriand', 'neanderthal', 'acres', 'alluvion', 'alluvium', 'anatomy', 'arable land', 'ass', 'batch', 'blade roast', 'block'],
    'cloddish': ['boeotian', 'asinine', 'beef-brained', 'beef-witted', 'blockish', 'boorish', 'bovine', 'carlish', 'chumpish', 'churlish', 'clodhopping', 'clownish'],
    'clog': ['arrest', 'bar', 'barrier', 'bearing rein', 'bind', 'bit', 'blank wall', 'blind alley', 'blind gut', 'block', 'block up', 'blockade'],
    'cloister': ['easter sepulcher', 'abbey', 'access', 'adytum', 'aisle', 'alley', 'ambry', 'ambulatory', 'aperture', 'apse', 'arcade', 'areaway'],
    'cloistered': ['anchoritic', 'at rest', 'barred', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'cabined', 'caged', 'calm', 'claustral'],
    'clone': ['photostat', 'xerox', 'copy', 'counterpart', 'ditto', 'double', 'dupe', 'duplicate', 'duplication', 'facsimile', 'hectograph', 'manifold'],
    'clop': ['bump', 'chink', 'click', 'clink', 'clump', 'clunk', 'crump', 'drub', 'dull thud', 'flick', 'flump', 'footfall'],
    'close': ['autobahn', 'spartan', 'us highway', 'abandonment', 'abbreviated', 'abort', 'about', 'about to be', 'abridged', 'abstruse', 'accented', 'accommodate'],
    'close in': ['accost', 'advance', 'approach', 'appropinquate', 'approximate', 'bear down on', 'bear down upon', 'bear up', 'beleaguer', 'beset', 'besiege', 'blockade'],
    'close out': ['balance', 'balance the books', 'bar', 'book', 'button up', 'cap', 'capitalize', 'carry', 'carry over', 'carry to completion', 'cast up accounts', 'charge off'],
    'close up': ['approach', 'bang', 'bar', 'barricade', 'batten', 'batten down', 'block', 'block up', 'blockade', 'bolt', 'boom shot', 'button'],
    'closed': ['arcane', 'authoritarian', 'beyond reach', 'bigot', 'bigoted', 'blank', 'blind', 'blind-alley', 'borne', 'cabalistic', 'cecal', 'censored'],
    'closed minded': ['authoritarian', 'bigot', 'bigoted', 'borne', 'closed', 'constricted', 'cramped', 'creedbound', 'deaf', 'deaf to reason', 'fanatical', 'hidebound'],
    'closefisted': ['avaricious', 'cheap', 'clinging', 'close', 'grasping', 'hardfisted', 'illiberal', 'keeping', 'miserly', 'narrow', 'near', 'niggardly'],
    'closely': ['all but', 'almost', 'as good as', 'barely', 'carefully', 'close', 'compactly', 'densely', 'firmly', 'hardly', 'heavily', 'heedfully'],
    'closemouthed': ['brief', 'brusque', 'close', 'close-lipped', 'close-tongued', 'concise', 'curt', 'dark', 'discreet', 'dumb', 'economical of words', 'evasive'],
    'closeness': ['thi', 'accord', 'accordance', 'addition', 'adjunct', 'affairs', 'affiliation', 'affinity', 'agreement', 'airlessness', 'airtight secrecy', 'alikeness'],
    'closet': ['wc', 'academic', 'adytum', 'anonymous', 'archives', 'armory', 'arsenal', 'attic', 'backhouse', 'bank', 'basement', 'bathroom'],
    'closing': ['abandonment', 'accommodation', 'adjustment', 'arrangement', 'blockade', 'breakoff', 'capping', 'cease', 'ceasing', 'cessation', 'close', 'closure'],
    'closure': ['accomplishment', 'ankle', 'arrest', 'arrestation', 'arrestment', 'articulation', 'blockage', 'blocking', 'boundary', 'butt', 'cease', 'cervix'],
    'clot': ['devonshire cream', 'adhere', 'agglomerate', 'agglomeration', 'ament', 'array', 'assemble', 'batch', 'battery', 'beat up', 'blockhead', 'blood clot'],
    'cloth': ['act drop', 'asbestos', 'asbestos board', 'backdrop', 'batten', 'boltrope', 'border', 'canonicals', 'canvas', 'ceremonial attire', 'clericals', 'clew'],
    'clothe': ['accommodate', 'accouter', 'afford', 'apparel', 'apply to', 'arm', 'array', 'attire', 'authorize', 'bedeck', 'bedrape', 'blanket'],
    'clothes': ['afghan', 'apparel', 'array', 'attire', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedizenment', 'bedsheet', 'bedspread', 'blanket'],
    'clothes conscious': ['braw', 'chic', 'classy', 'cosmopolitan', 'dapper', 'dashing', 'dressed to advantage', 'dressed to kill', 'elegant', 'exquisite', 'genteel', 'jaunty'],
    'clotheshorse': ['beau brummel', 'arbiter of fashion', 'beau', 'blade', 'blood', 'boulevardier', 'buck', 'clubman', 'clubwoman', 'coxcomb', 'dandy', 'deb'],
    'clothier': ['antique store', 'apothecary', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'chemist', 'cigar store', 'clothiers', 'clothing store', 'confectionery', 'costumer'],
    'clotted': ['adhesive', 'amylaceous', 'caked', 'cakey', 'clabbered', 'clammy', 'coagulated', 'congealed', 'curded', 'curdled', 'doughy', 'gaumy'],
    'cloture': ['cloture by compartment', 'committee consideration', 'debate', 'deliberation', 'division', 'filibuster', 'filibustering', 'filing', 'first reading', 'guillotine', 'introduction', 'kangaroo cloture'],
    'cloud': ['a mass of', 'a world of', 'addle', 'addle the wits', 'adumbrate', 'afterdamp', 'apply to', 'army', 'ball up', 'becloud', 'bedarken', 'bedazzle'],
    'cloud nine': ['acme', 'apex', 'apogee', 'beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'brow', 'cap', 'cheer'],
    'cloud seeder': ['dry ice', 'aeronaut', 'aeroplaner', 'aeroplanist', 'air pilot', 'airplanist', 'artificial nucleation', 'astronaut', 'aviator', 'barnstormer', 'birdman', 'captain'],
    'cloudburst': ['brash', 'burst of rain', 'deluge', 'downfall', 'downflow', 'downpour', 'drencher', 'flood', 'gushing rain', 'heavy rain', 'plash', 'pour'],
    'clouded': ['acheronian', 'acherontic', 'cimmerian', 'stygian', 'abstruse', 'ambiguous', 'armored', 'beclouded', 'blind', 'buried', 'calico', 'cased'],
    'cloudland': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley'],
    'cloudy': ['acheronian', 'acherontic', 'cimmerian', 'stygian', 'addlebrained', 'addled', 'addleheaded', 'addlepated', 'adiaphanous', 'amorphous', 'angry', 'beclouded'],
    'clout': ['amperage', 'armipotence', 'ascendancy', 'authoritativeness', 'authority', 'backlash', 'backwash', 'bang', 'bash', 'bat', 'beating', 'beef'],
    'cloven': ['bifurcated', 'bisected', 'branched', 'branching', 'chinky', 'cleft', 'cracked', 'cut', 'dehiscent', 'dichotomous', 'dimidiate', 'divided'],
    'clover': ['easy street', 'affluence', 'bed of roses', 'comfort', 'contentment', 'deuce-ace', 'ease', 'easy circumstances', 'felicity', 'fleshpots', 'gracious life', 'gracious living'],
    'clown': ['babbitt', 'columbine', 'hanswurst', 'harlequin', 'pantalone', 'pantaloon', 'philistine', 'polichinelle', 'pulcinella', 'punch', 'punchinello', 'scaramouch'],
    'cloy': ['allay', 'cram', 'engorge', 'fill', 'fill up', 'glut', 'gorge', 'jade', 'overdose', 'overfeed', 'overfill', 'overgorge'],
    'cloying': ['bad', 'barfy', 'bathetic', 'beery', 'brackish', 'cloysome', 'fetid', 'filling', 'foul', 'fulsome', 'gooey', 'gushing'],
    'club': ['elizabethan theater', 'globe theatre', 'greek theater', 'affiliate', 'agate', 'alliance', 'ally', 'amphitheater', 'arena theater', 'associate', 'association', 'auditorium'],
    'clubby': ['affable', 'amiable', 'civil', 'clubbable', 'clubbish', 'communicative', 'companionable', 'companionate', 'compatible', 'congenial', 'courteous', 'fit for society'],
    'clubfoot': ['arch', 'bowlegs', 'camelback', 'cleft palate', 'crookback', 'defacement', 'deformation', 'deformity', 'digit', 'disfigurement', 'dog', 'extremity'],
    'clubwoman': ['beau brummel', 'greek', 'affiliate', 'arbiter of fashion', 'associate', 'belonger', 'bon vivant', 'brother', 'card-carrier', 'card-carrying member', 'cardholder', 'charter member'],
    'cluck': ['cackle', 'call', 'carol', 'caw', 'chatter', 'cheep', 'chirk', 'chirp', 'chirr', 'chirrup', 'chitter', 'chuck'],
    'clue': ['acquaint', 'advice', 'advise', 'alerting', 'answer', 'apprise', 'basis for belief', 'body of evidence', 'broad hint', 'catchword', 'caution', 'chain of evidence'],
    'clump': ['accumulate', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'amble', 'array', 'assemble', 'bang', 'barge', 'bash', 'bat'],
    'clumsily': ['airily', 'any old way', 'any which way', 'anyhow', 'ass-backwards', 'awkwardly', 'blunderingly', 'bunglingly', 'carelessly', 'casually', 'cumbersomely', 'cursorily'],
    'clumsy': ['doric', 'all thumbs', 'awkward', 'barbaric', 'barbarous', 'blunderheaded', 'blundering', 'boorish', 'botched', 'bovine', 'bulky', 'bumbling'],
    'clunk': ['bump', 'chink', 'click', 'clink', 'clop', 'clump', 'crump', 'dull thud', 'flick', 'flump', 'pad', 'pat'],
    'cluster': ['accumulate', 'adhere', 'agglomerate', 'agglomeration', 'aggregate', 'aggroup', 'amass', 'army', 'array', 'assemblage', 'assemble', 'assembly'],
    'clutch': ['abduct', 'adhere to', 'amount', 'array', 'batch', 'bear hug', 'bind', 'bite', 'body', 'brood', 'budget', 'bunch'],
    'clutches': ['administration', 'authority', 'claws', 'command', 'control', 'digits', 'disposition', 'domination', 'dominion', 'empery', 'empire', 'fangs'],
    'clutter': ['a mass of', 'a world of', 'abound with', 'army', 'arsy-varsiness', 'ataxia', 'atmospheric attenuation', 'be alive with', 'bevy', 'blind spots', 'bristle with', 'bunch'],
    'co op': ['boutique', 'chain store', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dime store', 'discount house', 'discount store', 'emporium', 'establishment'],
    'coach': ['privatdocent', 'privatdozent', 'pullman', 'pullman car', 'advise', 'advocate', 'amateur athlete', 'archer', 'athlete', 'athletic coach', 'baggage car', 'ballplayer'],
    'coached': ['accomplished', 'all ready', 'all set', 'armed', 'armed and ready', 'at concert pitch', 'booted and spurred', 'briefed', 'career', 'cocked', 'conversant', 'equipped'],
    'coachman': ['jehu', 'boy', 'bullwhacker', 'butler', 'cabby', 'cabdriver', 'cabman', 'cameleer', 'carter', 'cartman', 'charioteer', 'chauffeur'],
    'coact': ['accord', 'act in concert', 'act together', 'affiliate', 'agree', 'ally', 'amalgamate', 'associate', 'band', 'band together', 'be in cahoots', 'be in league'],
    'coadjutant': ['aid', 'aide', 'aide-de-camp', 'coacting', 'coactive', 'coadjutor', 'coadjuvant', 'coefficient', 'collaborative', 'collective', 'collectivist', 'collectivistic'],
    'coadjutor': ['grand penitentiary', 'holy father', 'abuna', 'acolyte', 'adjunct', 'adjutant', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider', 'ally'],
    'coagulate': ['devonshire cream', 'adhere', 'agglomerate', 'beat up', 'blood clot', 'bonnyclabber', 'bunch', 'cake', 'casein', 'churn', 'clabber', 'clasp'],
    'coal': ['alcohol', 'anthracite', 'ash', 'ashes', 'benzine', 'blaze', 'blister', 'brand', 'briquette', 'brown coal', 'bunker', 'burn'],
    'coalesce': ['act in concert', 'act together', 'add', 'adhere', 'admix', 'affiliate', 'alloy', 'ally', 'amalgamate', 'assimilate', 'associate', 'band'],
    'coalition': ['anschluss', 'bund', 'rochdale cooperative', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alignment', 'alliance', 'amalgamation', 'anschluss'],
    'coarse': ['adamic', 'circean', 'doric', 'mickey mouse', 'acerb', 'acerbic', 'acrid', 'amaroidal', 'animal', 'animalistic', 'arrested', 'astringent'],
    'coarsen': ['adulterate', 'alloy', 'boss', 'brutify', 'canker', 'carnalize', 'cheapen', 'confound', 'contaminate', 'corrupt', 'debase', 'debauch'],
    'coarseness': ['adam', 'gothicism', 'animalism', 'animality', 'bad manners', 'bad taste', 'barbarism', 'barbarousness', 'baseness', 'beastliness', 'bestiality', 'bodily size'],
    'coast': ['abide', 'avalanche', 'bank', 'be a sideliner', 'be effortless', 'be painless', 'be still', 'beach', 'beam', 'berm', 'board', 'boat'],
    'coast guard': ['naval construction battalion', 'rn', 'royal navy', 'seabees', 'usn', 'united states navy', 'advance guard', 'air-sea rescue', 'argosy', 'armada', 'armed guard', 'bank guard'],
    'coastal': ['bordering', 'borderline', 'boundary', 'bounding', 'determinant', 'determinative', 'determining', 'extreme', 'fringing', 'frontier', 'limbic', 'liminal'],
    'coat': ['eton jacket', 'leatherette', 'leatheroid', 'mao jacket', 'anorak', 'apply paint', 'bedaub', 'bedizen', 'begild', 'besmear', 'blanket', 'blazer'],
    'coat of arms': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'azure', 'bandeau', 'bar', 'bar sinister'],
    'coating': ['blanketing', 'blocking', 'blotting out', 'calcimining', 'cementwork', 'chromogen', 'cloaking', 'clouding', 'coat', 'coat of paint', 'collop', 'color'],
    'coauthor': ['advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'collaborate', 'collaborationist', 'collaborator', 'columnist', 'compiler'],
    'coax': ['advocate', 'allure', 'apply pressure', 'bait', 'bait the hook', 'banter', 'barter', 'beguile', 'beset', 'besiege', 'blandish', 'blarney'],
    'cob': ['ambler', 'auricle', 'bang', 'cap', 'corncob', 'ding', 'ear', 'ear of corn', 'exceed', 'excel', 'gaited horse', 'galloper'],
    'cobbler': ['booter', 'bootmaker', 'doctor', 'fixer', 'little miss fixit', 'maintenance man', 'mechanic', 'mechanician', 'mender', 'renovator', 'repairer', 'repairman'],
    'cobblestone': ['tarmac', 'tarvia', 'asphalt', 'bitumen', 'bituminous macadam', 'blacktop', 'brick', 'carpet', 'causeway', 'cement', 'cobble', 'concrete'],
    'cobweb': ['air', 'animal fiber', 'artificial fiber', 'bait', 'birdlime', 'bola', 'bubble', 'cambric tea', 'capillament', 'chaff', 'chip', 'cilium'],
    'cocaine': ['benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'methedrine', 'amphetamine', 'amphetamine sulfate', 'coke', 'crystal', 'dextroamphetamine sulfate'],
    'coccus': ['adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'bacillus', 'bacteria', 'bacterium', 'bug', 'echovirus', 'enterovirus'],
    'cock': ['bantam', 'anemograph', 'anemometer', 'anemometrograph', 'anemoscope', 'anthill', 'backslide', 'ball cock', 'ball valve', 'baloney', 'bank', 'banty'],
    'cockamamie': ['absurd', 'beyond belief', 'bizarre', 'crazy', 'extravagant', 'fantastic', 'foolish', 'grotesque', 'high-flown', 'incredible', 'laughable', 'ludicrous'],
    'cockatrice': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'quisling', 'achievement', 'alerion', 'animal charge', 'annulet', 'archtraitor', 'argent', 'armorial bearings'],
    'cockeyed': ['afflicted', 'agee', 'agee-jawed', 'amiss', 'anamorphous', 'apish', 'asinine', 'askance', 'askant', 'askew', 'askewgee', 'asquint'],
    'cockle': ['cocker', 'corrugate', 'crease', 'crimp', 'crimple', 'crinkle', 'crumple', 'dimple', 'fret', 'furrow', 'knit', 'knot'],
    'cockney': ['baseborn', 'below the salt', 'common', 'commonplace', 'homely', 'humble', 'low', 'lowborn', 'lowbred', 'lowly', 'mean', 'nonclerical'],
    'cockpit': ['agora', 'amphitheater', 'arena', 'athletic field', 'auditorium', 'background', 'bear garden', 'bowl', 'boxing ring', 'bull ring', 'campus', 'canvas'],
    'cocksure': ['arrogant', 'assured', 'certain', 'confident', 'convinced', 'decided', 'determined', 'hubristic', 'overconfident', 'oversure', 'overweening', 'persuaded'],
    'cocktail': ['cloudcuckooland', 'mickey', 'mickey finn', 'alto-cumulus', 'alto-stratus', 'anvil cloud', 'aperitif', 'banner cloud', 'billowy cloud', 'cap cloud', 'chaser', 'cirro-cumulus'],
    'cocktail lounge': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'cabaret', 'cafe', 'dive', 'dramshop'],
    'cocky': ['aggressively self-confident', 'arrogant', 'audacious', 'biggety', 'bluff', 'bold', 'brash', 'brassy', 'brazen', 'bumptious', 'challenging', 'cheeky'],
    'coconspirator': ['machiavellian', 'abettor', 'accessory', 'accomplice', 'accomplice in crime', 'cohort', 'confederate', 'conniver', 'conspirator', 'conspirer', 'counterplotter', 'exploiter'],
    'coda': ['ps', 'parthian shot', 'accession', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum'],
    'coddle': ['baby', 'bake', 'barbecue', 'baste', 'bay', 'blanch', 'boil', 'braise', 'brew', 'broil', 'brown', 'care for'],
    'coddled': ['baked', 'boiled', 'braised', 'broiled', 'browned', 'cooked', 'curried', 'deviled', 'fired', 'fricasseed', 'fried', 'grilled'],
    'code': ['aesopian language', 'babel', 'code napoleon', 'greek', 'napoleonic code', 'procrustean law', 'telautography', 'teletype', 'teletype network', 'teletyping', 'ten commandments', 'zeitgeist'],
    'codeine': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'codicil': ['ps', 'parthian shot', 'addendum', 'affix', 'afterthought', 'allonge', 'appendix', 'attested copy', 'back matter', 'bequeathal', 'bequest', 'chorus'],
    'codify': ['adjust', 'alphabetize', 'analyze', 'arrange', 'assort', 'break down', 'catalog', 'categorize', 'chart', 'class', 'classify', 'coordinate'],
    'coeducational': ['autodidactic', 'cultural', 'didactic', 'disciplinary', 'edifying', 'educating', 'educational', 'educative', 'enlightening', 'exhortatory', 'homiletic', 'hortatory'],
    'coefficient': ['coacting', 'coactive', 'coadjutant', 'coadjuvant', 'collaborative', 'collective', 'collectivist', 'collectivistic', 'collusive', 'combined', 'commensal', 'common'],
    'coequal': ['all one', 'all the same', 'analogous', 'answering', 'balanced', 'coextensive', 'coincident', 'coincidental', 'coinciding', 'compeer', 'complemental', 'complementary'],
    'coerce': ['beat down', 'beset', 'blackjack', 'bludgeon', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'clamp down on', 'compel', 'concuss'],
    'coercion': ['argumentum baculinum', 'compulsion', 'constraint', 'duress', 'high pressure', 'intimidation', 'menace', 'menacing', 'pressure', 'strong-arm tactics', 'the big stick', 'the bludgeon'],
    'coeternal': ['accompanying', 'ageless', 'agreeing', 'ceaseless', 'coetaneous', 'coeval', 'coexistent', 'coexisting', 'coinstantaneous', 'collateral', 'concomitant', 'concurrent'],
    'coeval': ['accompanying', 'agreeing', 'atavistic', 'bodily', 'born', 'coetaneous', 'coeternal', 'coexistent', 'coexisting', 'coinstantaneous', 'collateral', 'concomitant'],
    'coexistence': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'accompaniment', 'agreement', 'appeasement', 'balance of power', 'brinkmanship', 'coetaneity', 'coetaneousness', 'coevalneity'],
    'coexistent': ['accompanying', 'accordant', 'affirmative', 'agreeable', 'agreeing', 'answerable', 'at one', 'coetaneous', 'coeternal', 'coeval', 'coexisting', 'coherent'],
    'coextend': ['accompany', 'agree', 'be in phase', 'be in time', 'be parallel', 'coexist', 'coincide', 'concur', 'contemporize', 'equal', 'go alongside', 'go beside'],
    'coextensive': ['aligned', 'analogous', 'coequal', 'coextending', 'coincident', 'coincidental', 'coinciding', 'collateral', 'concurrent', 'congruent', 'correspondent', 'corresponding'],
    'coffee break': ['tv dinner', 'alfresco meal', 'barbecue', 'break', 'breakfast', 'breath', 'breather', 'breathing place', 'breathing space', 'breathing spell', 'breathing time', 'brunch'],
    'coffee klatch': ['kaffeeklatsch', 'ball', 'blowout', 'cocktail party', 'costume party', 'dinner', 'dinner party', 'donation party', 'entertainment', 'festivity', 'garden party', 'hen party'],
    'coffee shop': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffeehouse'],
    'coffer': ['fort knox', 'bank', 'bundle away', 'bursary', 'cache', 'cash register', 'cashbox', 'chest', 'coin box', 'deposit', 'depository', 'exchequer'],
    'cog': ['comb', 'commonality', 'commonalty', 'crag', 'creature', 'fang', 'flunky', 'follower', 'harrow', 'hoi polloi', 'inferior', 'jag'],
    'cogency': ['acuity', 'acumen', 'acuteness', 'advantageousness', 'agreeableness', 'amperage', 'apperception', 'armipotence', 'astuteness', 'auspiciousness', 'authoritativeness', 'authority'],
    'cogent': ['acute', 'admissible', 'advantageous', 'apperceptive', 'appercipient', 'argute', 'armipotent', 'astute', 'auspicious', 'authoritative', 'beneficial', 'benevolent'],
    'coggle': ['bob', 'bobble', 'careen', 'dangle', 'fluctuate', 'flutter', 'librate', 'lurch', 'nutate', 'oscillate', 'pendulate', 'pitch'],
    'cogitable': ['cerebrate', 'cogitate', 'collogue', 'collude', 'conceive', 'connive', 'conspire', 'contrive', 'deliberate', 'devise', 'envisage', 'envision'],
    'cogitate': ['cerebrate', 'conceive', 'conceptualize', 'entertain ideas', 'excogitate', 'exercise the mind', 'form ideas', 'give thought to', 'ideate', 'intellectualize', 'puzzle out', 'reason'],
    'cognate': ['affiliated', 'affinal', 'affinitive', 'agnate', 'akin', 'allied', 'ally', 'alter ego', 'analogon', 'analogue', 'ancestry', 'associate'],
    'cognitive': ['cogitative', 'concentrating', 'concentrative', 'conceptive', 'conceptual', 'conceptualized', 'contemplating', 'contemplative', 'deliberating', 'deliberative', 'excogitating', 'ideative'],
    'cognizance': ['acknowledgment', 'apperception', 'appreciation', 'appreciativeness', 'attention', 'awareness', 'benediction', 'cognition', 'consciousness', 'credit', 'crediting', 'due'],
    'cognizant': ['acknowledging', 'alive', 'alive to', 'all-knowing', 'apperceptive', 'appercipient', 'appreciative', 'appreciative of', 'apprehending', 'apprehensive', 'apprised of', 'au courant'],
    'cognomen': ['affectionate name', 'agnomen', 'appellation', 'appellative', 'binomen', 'binomial name', 'byname', 'byword', 'cryptonym', 'denomination', 'designation', 'diminutive'],
    'cognoscente': ['aesthete', 'amateur', 'annotator', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'authority', 'bon vivant', 'captious critic', 'carper', 'caviler', 'censor'],
    'cogwheel': ['hydromatic', 'automatic transmission', 'differential', 'differential gear', 'freewheel', 'gear', 'gear train', 'gearbox', 'gearing', 'gearshift', 'gearwheel', 'high'],
    'cohabit': ['abide', 'ball', 'be intimate', 'berth', 'bunk', 'come together', 'commit adultery', 'copulate', 'couple', 'cover', 'diddle', 'domicile'],
    'cohabitation': ['a world-without-end bargain', 'abiding', 'abode', 'act of love', 'adultery', 'alliance', 'aphrodisia', 'ass', 'balling', 'bed', 'bond of matrimony', 'bridebed'],
    'cohere': ['accord', 'adhere', 'agglomerate', 'agree', 'answer to', 'assent', 'associate', 'assort with', 'be consistent', 'be of one', 'be uniform with', 'blend'],
    'coherence': ['accord', 'accordance', 'accretion', 'adherence', 'adhesion', 'affinity', 'agglomeration', 'agglutination', 'agreement', 'assent', 'bond', 'chorus'],
    'coherent': ['accordant', 'adhering', 'affirmative', 'agglutinate', 'agreeable', 'agreeing', 'answerable', 'articulate', 'at one', 'clean-cut', 'clear', 'clear as crystal'],
    'cohesive': ['adhering', 'agglutinate', 'cartilaginous', 'chewy', 'cleaving', 'clinging', 'coherent', 'cohering', 'coriaceous', 'durable', 'fibrous', 'gristly'],
    'cohort': ['kp', 'abettor', 'accessory', 'accomplice', 'accomplice in crime', 'adherent', 'adjunct', 'age group', 'ally', 'army', 'army group', 'associate'],
    'coif': ['afro', 'barber', 'bob', 'bonnet', 'boot', 'breech', 'cap', 'ceil', 'cloak', 'coat', 'coiffure', 'cold wave'],
    'coil': ['bolt', 'braid', 'brouhaha', 'bun', 'chignon', 'circles', 'cirrus', 'corkscrew', 'crimp', 'crisp', 'cue', 'curl'],
    'coin': ['angle', 'apex', 'beget', 'bend', 'bifurcation', 'bight', 'bread', 'breed', 'bring forth', 'bring into being', 'call into being', 'cant'],
    'coinage': ['and pence', 'artifact', 'authorship', 'beginning', 'brainchild', 'breakthrough', 'cash', 'child', 'circulating medium', 'coined liberty', 'coining', 'cold cash'],
    'coincide': ['accompany', 'accord', 'agree', 'agree in opinion', 'agree with', 'answer to', 'assent', 'associate', 'assort with', 'be consistent', 'be in cahoots', 'be in phase'],
    'coincidence': ['accident', 'accompaniment', 'accord', 'accordance', 'affinity', 'agreement', 'alliance', 'assent', 'association', 'cahoots', 'chance', 'chorus'],
    'coincident': ['accessory', 'accompanying', 'accordant', 'affirmative', 'agreeable', 'agreeing', 'answerable', 'associate', 'associated', 'at one', 'at one with', 'attendant'],
    'coinciding': ['accordant', 'affirmative', 'agreeable', 'agreeing', 'answerable', 'at one', 'coequal', 'coexistent', 'coexisting', 'coextensive', 'coherent', 'coincident'],
    'coitus': ['act of love', 'adultery', 'aphrodisia', 'ass', 'balling', 'carnal knowledge', 'climax', 'cohabitation', 'coition', 'coitus interruptus', 'commerce', 'congress'],
    'coke': ['benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'methedrine', 'alcohol', 'amphetamine', 'amphetamine sulfate', 'ash', 'ashes'],
    'col': ['abysm', 'abyss', 'arroyo', 'box canyon', 'breach', 'break', 'canyon', 'cavity', 'chap', 'chasm', 'check', 'chimney'],
    'colander': ['bolter', 'clarifier', 'cradle', 'cribble', 'cribriformity', 'cribrosity', 'filter', 'grate', 'grating', 'honeycomb', 'lixiviator', 'net'],
    'cold': ['asiatic flu', 'hong kong flu', 'laodicean', 'olympian', 'siberian', 'abruptly', 'absolutely', 'acute bronchitis', 'adenoiditis', 'affectless', 'ague', 'aguey'],
    'cold blooded': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'callous', 'calloused', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity'],
    'cold comfort': ['faustianism', 'disappointment', 'discontent', 'discontentedness', 'discontentment', 'disgruntlement', 'dissatisfaction', 'dissatisfiedness', 'divine discontent', 'envy', 'ill humor', 'peevishness'],
    'cold cream': ['abstergent', 'balm', 'balsam', 'base', 'brilliantine', 'cathartic', 'chrism', 'cleaner', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing cream'],
    'cold cuts': ['chateaubriand', 'blade roast', 'breast', 'brisket', 'chuck', 'chuck roast', 'clod', 'filet mignon', 'flank', 'knuckle', 'loin', 'plate'],
    'cold front': ['air mass', 'anticyclone', 'cold sector', 'cyclone', 'front', 'high', 'high-pressure area', 'isobar', 'isometric', 'isometric line', 'isopiestic line', 'isotherm'],
    'cold shoulder': ['blink', 'brush-off', 'carefully ignore', 'cut', 'cut a corner', 'cut corners', 'cut direct', 'dismissal', 'disregard', 'dodge', 'fudge', 'high-hat'],
    'cold storage': ['abandonment', 'abeyance', 'abjuration', 'abjurement', 'cessation', 'conservation', 'coolerman', 'coolhouse', 'custody', 'dead storage', 'desistance', 'discontinuance'],
    'cold sweat': ['bo', 'abhorrence', 'abomination', 'agitation', 'all-overs', 'allergy', 'antagonism', 'antipathy', 'aversion', 'beaded brow', 'beads of sweat', 'body odor'],
    'cold type': ['intertype', 'linotype', 'monotype', 'cold-type typesetting', 'composing', 'composing stick', 'composition', 'computerized typesetting', 'dummy', 'furniture', 'galley chase', 'hot-metal typesetting'],
    'cold wave': ['afro', 'bitter weather', 'bleak weather', 'coif', 'coiffure', 'cold snap', 'cold weather', 'conk', 'depth of winter', 'freeze', 'freezing weather', 'frost'],
    'cold-blooded': ['apathetic', 'barbaric', 'barbarous', 'brutal', 'callous', 'cool', 'cruel', 'dispassionate', 'heartless', 'imperturbable', 'indifferent', 'inhuman'],
    'cold-hearted': ['apathetic', 'callous', 'cold', 'cool', 'cruel', 'frigid', 'heartless', 'indifferent', 'insensitive', 'mean', 'merciless', 'pitiless'],
    'coldhearted': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'callous', 'calloused', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity'],
    'coldly': ['antagonistically', 'apathetically', 'chillily', 'cold-bloodedly', 'coldheartedly', 'coolly', 'deadpan', 'dispassionately', 'dormantly', 'dully', 'frostily', 'halfheartedly'],
    'coldness': ['laodiceanism', 'absolute zero', 'algidity', 'aloofness', 'anesthesia', 'autism', 'backwardness', 'bashfulness', 'bitterness', 'blankness', 'bleakness', 'briskness'],
    'colic': ['abscess', 'ache', 'aching', 'ague', 'anemia', 'angina', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia'],
    'colicky': ['aching', 'achy', 'allergic', 'anemic', 'apoplectic', 'arthritic', 'backachy', 'bilious', 'cancerous', 'chlorotic', 'consumptive', 'dropsical'],
    'coliseum': ['agora', 'amphitheater', 'arena', 'athletic field', 'auditorium', 'background', 'bear garden', 'bowl', 'boxing ring', 'bull ring', 'campus', 'canvas'],
    'colitis': ['abdominal hernia', 'adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever'],
    'collaborate': ['accord', 'acquiesce', 'act in concert', 'act the traitor', 'act together', 'affiliate', 'agree', 'ally', 'amalgamate', 'associate', 'author', 'band'],
    'collaboration': ['accompaniment', 'accordance', 'agreement', 'alliance', 'association', 'bipartisanship', 'cahoots', 'co-working', 'coaction', 'coadjuvancy', 'coadministration', 'coagency'],
    'collaborator': ['trojan horse', 'advertising writer', 'annalist', 'apostate', 'art critic', 'author', 'authoress', 'backslider', 'belletrist', 'bibliographer', 'bolter', 'coauthor'],
    'collage': ['abstract', 'abstraction', 'altarpiece', 'block print', 'color print', 'copy', 'cyclorama', 'daub', 'diptych', 'engraving', 'fresco', 'icon'],
    'collapse': ['od', 'waterloo', 'amiable weakness', 'bankruptcy', 'be brought down', 'be felled', 'be found wanting', 'be ruined', 'be struck down', 'be traumatized', 'beating', 'become insolvent'],
    'collar': ['oregon boat', 'roman collar', 'anklet', 'apprehend', 'appropriate', 'armlet', 'armory', 'arrest', 'back band', 'backstrap', 'badge', 'badge of office'],
    'collate': ['assort', 'audit', 'bolt', 'bracket', 'categorize', 'check', 'check and doublecheck', 'check out', 'check over', 'classify', 'confirm', 'contrast'],
    'collateral': ['accessory', 'accident', 'accidental', 'accompanying', 'addendum', 'addition', 'additional', 'adjunct', 'adscititious', 'adventitious', 'affiliate', 'affiliated'],
    'collation': ['allocation', 'allotment', 'apportionment', 'arrangement', 'array', 'arraying', 'ascertainment', 'assurance', 'bite', 'certification', 'check', 'checking'],
    'colleague': ['ace', 'adjunct', 'aide', 'ally', 'amigo', 'assistant', 'associate', 'bedfellow', 'bedmate', 'bosom buddy', 'brother', 'brother-in-arms'],
    'collect': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'accouple', 'accumulate', 'agglomerate', 'agglutinate', 'aggregate', 'aggroup'],
    'collectanea': ['festschrift', 'album', 'ana', 'analects', 'anthology', 'aquarium', 'assortment', 'beauties', 'body', 'canon', 'chrestomathy', 'clippings'],
    'collected': ['accumulated', 'agglomerate', 'aggregate', 'allied', 'amassed', 'assembled', 'associated', 'assured', 'at ease', 'backlogged', 'balanced', 'banded together'],
    'collection': ['festschrift', 'abundance', 'accumulation', 'agglomeration', 'aggregation', 'album', 'alms', 'alms fee', 'amassment', 'ana', 'analects', 'anthology'],
    'collection agent': ['accumulator', 'bill collector', 'collector', 'connoisseur', 'credit man', 'creditor', 'creditress', 'debtee', 'douanier', 'dun', 'dunner', 'exciseman'],
    'collective': ['abstract', 'accompanying', 'accordant', 'agreeing', 'associate', 'associated', 'at one with', 'bland', 'broad', 'coacting', 'coactive', 'coadjutant'],
    'collective bargaining': ['bargaining', 'chaffer', 'chaffering', 'coming to terms', 'company union', 'craft union', 'dickering', 'haggle', 'haggling', 'higgling', 'horizontal union', 'industrial union'],
    'collective farm': ['arable land', 'barnyard', 'barton', 'cattle ranch', 'chicken farm', 'collectivism', 'collectivity', 'collegiality', 'common ownership', 'communal effort', 'communion', 'communism'],
    'collectively': ['across the board', 'all', 'all at once', 'all put together', 'altogether', 'as a body', 'as a whole', 'as one', 'as one man', 'at large', 'back to back', 'bodily'],
    'collectivism': ['fabian socialism', 'fabianism', 'marxian socialism', 'marxism', 'nazism', 'saint-simonism', 'bipartisanship', 'centralism', 'coaction', 'coadjuvancy', 'coadministration', 'coagency'],
    'collectivize': ['annex', 'attach', 'commandeer', 'communalize', 'communize', 'confiscate', 'distrain', 'expropriate', 'garnish', 'impound', 'impress', 'levy'],
    'collector': ['accumulator', 'addict', 'admirer', 'amateur', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'aspirant', 'aspirer', 'authority', 'base', 'beg'],
    'colleen': ['babe', 'baby', 'broad', 'chick', 'cutie', 'dame', 'damoiselle', 'damsel', 'demoiselle', 'doll', 'filly', 'frail'],
    'college': ['bund', 'rochdale cooperative', 'academe', 'academia', 'alliance', 'alma mater', 'assemblage', 'association', 'axis', 'band', 'bloc', 'body'],
    'collegiate': ['academic', 'autodidactic', 'bookish', 'classroom', 'college-bred', 'extramural', 'graduate', 'interscholastic', 'intramural', 'learned', 'postgraduate', 'preschool'],
    'collide': ['agree to disagree', 'antagonize', 'atomize', 'bang', 'bang into', 'battle', 'be antipathetic', 'be at cross-purposes', 'be at variance', 'be inimical', 'beat against', 'box'],
    'collision': ['accident', 'antagonism', 'antipathy', 'antithesis', 'appulse', 'backlash', 'bad blood', 'belligerence', 'blow', 'brunt', 'bulldozing', 'bulling'],
    'collop': ['bit', 'butt', 'chip', 'chunk', 'clip', 'clipping', 'coat', 'coating', 'covering', 'crumb', 'cut', 'cutting'],
    'colloquial': ['chatty', 'chitchatty', 'common', 'communicative', 'confabulatory', 'conversational', 'cozy', 'everyday', 'familiar', 'informal', 'interlocutory', 'nonstandard'],
    'colloquium': ['airing', 'analysis', 'assemblee', 'assembly', 'assignation', 'at home', 'ball', 'brawl', 'buzz session', 'canvassing', 'caucus', 'colloquy'],
    'colloquy': ['chat', 'colloquial discourse', 'colloquium', 'communication', 'communion', 'confabulation', 'conversation', 'converse', 'conversing', 'dialogue', 'discourse', 'exchange'],
    'collusion': ['accompaniment', 'accordance', 'agreement', 'alliance', 'artifice', 'association', 'bipartisanship', 'cabal', 'cahoots', 'chicane', 'chicanery', 'co-working'],
    'colon': ['alexandrine', 'deutschmark', 'mark', 'reichsmark', 'abdomen', 'accent', 'accentuation', 'afghani', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest'],
    'colonel': ['adc', 'co', 'od', 'aide', 'aide-de-camp', 'brigadier', 'brigadier general', 'captain', 'chicken colonel', 'chief of staff', 'commandant', 'commander'],
    'colonialism': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'absolute monarchy', 'appeasement', 'aristocracy', 'autarchy', 'autocracy', 'autonomy', 'balance of power', 'brinkmanship'],
    'colonization': ['hare system', 'pr', 'absentee voting', 'adoption', 'anchorage', 'appropriation', 'arrogation', 'assumption', 'ballot-box stuffing', 'card voting', 'conquest', 'cumulative system'],
    'colonize': ['adopt', 'anchor', 'appropriate', 'arrogate', 'assume', 'billet at', 'bivouac', 'burrow', 'camp', 'come to anchor', 'conquer', 'denizen'],
    'colonnade': ['access', 'aisle', 'alley', 'ambulatory', 'aperture', 'arcade', 'areaway', 'artery', 'atlas', 'avenue', 'baluster', 'balustrade'],
    'colony': ['adverse possession', 'ally', 'alodium', 'archduchy', 'archdukedom', 'army', 'ashram', 'body', 'body politic', 'buffer state', 'bunch', 'burgage'],
    'colophon': ['ps', 'parthian shot', 'acknowledgments', 'addendum', 'afterthought', 'appendix', 'back', 'back matter', 'bastard title', 'bibliography', 'billhead', 'book stamp'],
    'color': ['adrianople red', 'alice blue', 'arabian red', 'argos brown', 'bordeaux', 'brunswick black', 'brunswick blue', 'burgundy', 'capri blue', 'cassel yellow', 'chinese blue', 'chinese white'],
    'color blind': ['ableptical', 'amaurotic', 'benighted', 'bereft of light', 'blind', 'dark', 'dim-sighted', 'eyeless', 'hemeralopic', 'in darkness', 'mind-blind', 'nyctalopic'],
    'color blindness': ['christmas disease', 'daltonism', 'hartnup disease', 'werdnig-hoffmann disease', 'achromatic vision', 'achromatopsia', 'albinism', 'cystic fibrosis', 'deuteranopia', 'dichromatic vision', 'dichromatism', 'dysautonomia'],
    'coloration': ['achromatism', 'allegory', 'allusion', 'arcane meaning', 'assumption', 'cast', 'chromatism', 'chromism', 'color', 'color balance', 'color harmony', 'color printing'],
    'coloratura': ['acciaccatura', 'alto', 'appoggiatura', 'arabesque', 'aria', 'aria buffa', 'aria cantabile', 'aria da capo', 'aria da chiesa', 'aria di bravura', 'aria di coloratura', 'aria fugata'],
    'coloratura soprano': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso profundo', 'blues singer'],
    'colored': ['adorned', 'affected', 'antiblack', 'apocryphal', 'apparent', 'artificial', 'assumed', 'bastard', 'befrilled', 'biased', 'black', 'black-skinned'],
    'colored person': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'colorful': ['bicolor', 'bicolored', 'blatant', 'brave', 'brazen', 'brazenfaced', 'bright', 'bright-hued', 'brilliant', 'burning', 'colory', 'crazy'],
    'coloring': ['klangfarbe', 'abstractionism', 'achromatism', 'acrylic painting', 'acting', 'affectation', 'affective meaning', 'appearance', 'attitudinizing', 'bearing', 'bloom', 'bluff'],
    'colorless': ['abstract', 'achromatic', 'achromic', 'aloof', 'anemic', 'arid', 'ashen', 'ashy', 'barren', 'blah', 'blanched', 'bland'],
    'colors': ['communist threat', 'dannebrog', 'jolly roger', 'old glory', 'star-spangled banner', 'stars and stripes', 'union flag', 'union jack', 'western imperialism', 'adornment', 'and blue', 'atrocity story'],
    'colossal': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'olympian', 'abysmal', 'aerial', 'airy', 'altitudinous', 'amplitudinous'],
    'colosseum': ['agora', 'amphitheater', 'arena', 'athletic field', 'auditorium', 'background', 'bear garden', 'bowl', 'boxing ring', 'bull ring', 'campus', 'canvas'],
    'colossus': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'goliath', 'hercules', 'polyphemus', 'samson', 'superman', 'tarzan'],
    'colt': ['houyhnhnm', 'beginner', 'birdling', 'boot', 'boy', 'brood mare', 'bub', 'bubba', 'buck', 'bud', 'buddy', 'calf'],
    'coltish': ['animated', 'antic', 'beardless', 'boyish', 'boylike', 'calflike', 'capersome', 'childish', 'childlike', 'elvish', 'exuberant', 'frisky'],
    'column': ['kp', 'antenna tower', 'arcade', 'arch', 'army', 'army group', 'article', 'atlas', 'baluster', 'balustrade', 'banister', 'barbican'],
    'columnist': ['advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'city editor', 'coauthor', 'collaborator', 'compiler', 'composer'],
    'coma': ['ko', 'blackout', 'catalepsy', 'catatonia', 'catatony', 'dullness', 'encephalitis lethargica', 'faint', 'grayout', 'hebetude', 'high', 'kayo'],
    'comatose': ['laodicean', 'olympian', 'aloof', 'anesthetic', 'anesthetized', 'apathetic', 'asleep', 'benumbed', 'blah', 'blase', 'cataleptic', 'catatonic'],
    'comb': ['be poised', 'beat', 'billow', 'break', 'card', 'crash', 'curry', 'dash', 'ebb and flow', 'examine', 'forage', 'grub'],
    'combat': ['kilkenny cats', 'action', 'aerial combat', 'affray', 'all-out war', 'altercation', 'antagonize', 'appeal to arms', 'argument', 'armed combat', 'armed conflict', 'armored combat'],
    'combat fatigue': ['accident neurosis', 'anaphylactic shock', 'anxiety hysteria', 'anxiety neurosis', 'association neurosis', 'battle fatigue', 'blast neurosis', 'compensation neurosis', 'compulsion neurosis', 'conversion hysteria', 'conversion neurosis', 'expectation neurosis'],
    'combative': ['aggressive', 'antagonistic', 'argumental', 'argumentative', 'battling', 'bellicose', 'belligerent', 'bickering', 'bloodthirsty', 'bloody', 'bloody-minded', 'chauvinist'],
    'combination': ['bund', 'rochdale cooperative', 'accompaniment', 'accord', 'accordance', 'addition', 'adjunct', 'admixture', 'affairs', 'affiliation', 'affinity', 'agglomeration'],
    'combine': ['aktiengesellschaft', 'anschluss', 'bund', 'rochdale cooperative', 'accompany', 'accord', 'accouple', 'accumulate', 'act in concert', 'act together', 'add', 'addition'],
    'combined': ['accessory', 'accompanying', 'accordant', 'accumulated', 'agglomerate', 'aggregate', 'agreeing', 'amalgamated', 'amassed', 'ambiguous', 'ambivalent', 'amphibious'],
    'combining': ['accompanying', 'accordant', 'agreeing', 'associate', 'associated', 'associative', 'at one with', 'blending', 'coacting', 'coactive', 'coadunate', 'coalescent'],
    'combo': ['anschluss', 'german band', 'philharmonic', 'addition', 'admixture', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'alloy', 'amalgam'],
    'combustible': ['accendible', 'alcohol', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coke', 'dope', 'ethane'],
    'combustion': ['backfire', 'balefire', 'beacon', 'beacon fire', 'blaze', 'blazing', 'blistering', 'bonfire', 'branding', 'burning', 'burning ghat', 'calcination'],
    'come': ['accomplish', 'accost', 'achieve', 'achieve satisfaction', 'acquire', 'add up', 'add up to', 'advance', 'affect', 'aggregate', 'amount to', 'anticipate'],
    'come about': ['about ship', 'alter', 'ameliorate', 'attain fulfillment', 'attend', 'back and fill', 'be changed', 'be converted into', 'be found', 'be met with', 'be realized', 'be renewed'],
    'come across': ['alight upon', 'aller sans dire', 'be manifest', 'be no secret', 'blunder upon', 'bump into', 'chance upon', 'circulate', 'come across with', 'come among', 'come down with', 'come on'],
    'come again': ['alternate', 'be here again', 'circle', 'come and go', 'come around', 'come round', 'come round again', 'come up again', 'copy', 'cycle', 'ditto', 'do a repeat'],
    'come alive': ['awake', 'awaken', 'be begotten', 'be born', 'be incarnated', 'come into being', 'come into existence', 'come to', 'come to life', 'descry', 'discern', 'get up'],
    'come along': ['advance', 'ameliorate', 'amend', 'appear', 'approach', 'arise', 'be found', 'be so', 'be such', 'bechance', 'befall', 'betide'],
    'come and go': ['alternate', 'back and fill', 'battledore and shuttlecock', 'be here again', 'circle', 'come again', 'come around', 'come round', 'come round again', 'come up again', 'cycle', 'ebb and flow'],
    'come apart': ['ablate', 'atomize', 'be angry', 'be excitable', 'bellow', 'blow a gasket', 'blow up', 'break', 'break open', 'break up', 'burst', 'carry away'],
    'come around': ['acquiesce', 'agree', 'agree on', 'agree with', 'alter', 'alternate', 'ameliorate', 'be changed', 'be converted into', 'be here again', 'be persuaded', 'be renewed'],
    'come at': ['ambush', 'arrive at', 'arrive upon', 'assail', 'assault', 'attack', 'blitz', 'bushwhack', 'come down on', 'come upon', 'crack down on', 'descend on'],
    'come back': ['acknowledge', 'answer', 'answer back', 'bounce back', 'come around', 'come back at', 'come home', 'come round', 'come to', 'come up smiling', 'double', 'double back'],
    'come back at': ['acknowledge', 'answer', 'answer back', 'come back', 'counter', 'echo', 'flash back', 'get back at', 'give acknowledgment', 'give and take', 'give answer', 'give in exchange'],
    'come between': ['aggravate', 'alienate', 'barge in', 'break in', 'break in upon', 'burst in', 'butt in', 'charge in', 'crash', 'crash in', 'crash the gates', 'creep in'],
    'come by': ['accept', 'acquire', 'admit', 'assume', 'bag', 'be seized of', 'call', 'capture', 'catch', 'come in for', 'come into', 'come over'],
    'come clean': ['acknowledge', 'admit', 'admit everything', 'allow', 'avow', 'concede', 'confess', 'cop a plea', 'grant', 'let on', 'open up', 'out with it'],
    'come down': ['alight', 'be found', 'be met with', 'be realized', 'befall', 'betide', 'cascade', 'cataract', 'collapse', 'come', 'come about', 'come in'],
    'come down on': ['alight upon', 'ambush', 'assail', 'assault', 'attack', 'attend to', 'blitz', 'bushwhack', 'call down', 'come at', 'crack down on', 'descend on'],
    'come forth': ['appear', 'approach', 'arise', 'bail out', 'be born', 'be illegitimate', 'become', 'become manifest', 'become public', 'become visible', 'break', 'break cover'],
    'come forward': ['accost', 'advance', 'appear', 'approach', 'appropinquate', 'approximate', 'arise', 'attract attention', 'bear down on', 'bear down upon', 'bear up', 'become manifest'],
    'come hither': ['alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching', 'charismatic', 'charming'],
    'come hither look': ['amorous looks', 'bedroom eyes', 'coquetry', 'coquettish glances', 'coquettishness', 'coyness', 'dalliance', 'evil eye', 'flirtation', 'flirtatiousness', 'gape', 'gaze'],
    'come in': ['accomplish', 'accrue', 'accrue to', 'achieve', 'admit', 'alight', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to'],
    'come into': ['acquire', 'affiliate', 'affiliate with', 'associate', 'bag', 'be seized of', 'capture', 'catch', 'combine', 'come by', 'come in for', 'contract'],
    'come of': ['attend', 'become of', 'come about', 'come out', 'develop', 'end', 'ensue', 'eventuate', 'fall out', 'fare', 'follow', 'issue'],
    'come of age': ['attain majority', 'bloom', 'come to maturity', 'develop', 'fledge', 'flower', 'grow', 'grow up', 'leave the nest', 'mature', 'mellow', 'reach manhood'],
    'come off': ['abjure', 'be blooded', 'be found', 'be met with', 'be realized', 'be successful', 'befall', 'betide', 'break', 'carry away', 'catch on', 'chance'],
    'come on': ['accost', 'achieve success', 'advance', 'alight upon', 'allurement', 'ameliorate', 'amend', 'anticipate', 'appear', 'approach', 'appropinquate', 'approximate'],
    'come out': ['act', 'act as foil', 'appear', 'appear in print', 'arise', 'attend', 'bail out', 'barnstorm', 'be born', 'be found', 'be revealed', 'be so'],
    'come round': ['acquiesce', 'alter', 'alternate', 'ameliorate', 'be changed', 'be converted into', 'be here again', 'be persuaded', 'be renewed', 'bottom out', 'bounce back', 'break'],
    'come through': ['achieve success', 'advance', 'arrive', 'be a success', 'be glimpsed', 'be safe', 'be so', 'be such', 'beat the game', 'beat the system', 'break through', 'bring about'],
    'come to': ['accomplish', 'achieve', 'acquiesce', 'add up to', 'afford', 'aggregate', 'aggregate to', 'amount to', 'appear', 'approach', 'arrive', 'arrive at'],
    'come to light': ['appear', 'arise', 'be found', 'be revealed', 'become known', 'become manifest', 'become visible', 'betray itself', 'break forth', 'come', 'come along', 'come forth'],
    'come to nothing': ['annul', 'be done for', 'be no more', 'be unproductive', 'blow up', 'break down', 'bring to nothing', 'buffer', 'cancel', 'cancel out', 'cease', 'collapse'],
    'come to pass': ['attain fulfillment', 'be found', 'be met with', 'be realized', 'befall', 'betide', 'come', 'come about', 'come down', 'come off', 'come true', 'eventuate'],
    'come to terms': ['abandon', 'acknowledge defeat', 'agree', 'agree on', 'agree to', 'agree with', 'bargain for', 'be a bargain', 'be a deal', 'be a go', 'be on', 'beg a truce'],
    'come together': ['add', 'adhere', 'affiliate', 'ally', 'amalgamate', 'approach', 'assemble', 'assimilate', 'associate', 'ball', 'band together', 'be in cahoots'],
    'come true': ['attain fulfillment', 'be found', 'be met with', 'be realized', 'befall', 'betide', 'come', 'come about', 'come down', 'come off', 'come to pass', 'eventuate'],
    'come up against': ['alight upon', 'blunder upon', 'bring to bay', 'bump into', 'chance upon', 'close with', 'come across', 'come among', 'come on', 'come upon', 'confront', 'discover serendipitously'],
    'come upon': ['alight upon', 'appear unexpectedly', 'arrive at', 'arrive upon', 'be unexpected', 'blunder upon', 'bob up', 'bump into', 'chance upon', 'come across', 'come among', 'come at'],
    'come what may': ['at all events', 'at all risks', 'at any cost', 'at any price', 'compulsorily', 'from necessity', 'live or die', 'necessarily', 'need', 'needfully', 'needs', 'nolens volens'],
    'comeback': ['parthian shot', 'acknowledgment', 'answer', 'answering', 'antiphon', 'back answer', 'back talk', 'backchat', 'backfire', 'boomerang', 'caustic remark', 'convalescence'],
    'comedian': ['banana', 'buffoon', 'burlesquer', 'card', 'caricaturist', 'choreographer', 'clown', 'comedienne', 'comic', 'cutup', 'dramatist', 'dramatizer'],
    'comedown': ['abasement', 'anticlimax', 'backset', 'bafflement', 'balk', 'bathos', 'belittling', 'betrayed hope', 'blasted expectation', 'blighted hope', 'blow', 'breakdown'],
    'comedy': ['atticism', 'thalia', 'agile wit', 'arlequinade', 'black comedy', 'black humor', 'bladder', 'broad comedy', 'burlesque', 'burletta', 'camp', 'cap and bells'],
    'comeliness': ['atticism', 'agreeability', 'agreeableness', 'appropriateness', 'becomingness', 'bonniness', 'chasteness', 'chastity', 'clarity', 'classicalism', 'classicism', 'clearness'],
    'comely': ['junoesque', 'agreeable', 'amply endowed', 'appealing', 'appropriate', 'apt', 'attractive', 'beauteous', 'beautiful', 'becoming', 'befitting', 'bonny'],
    'comer': ['young turk', 'arrival', 'arriviste', 'bright young man', 'entrant', 'fledgling', 'immigrant', 'in-migrant', 'incomer', 'intruder', 'modern', 'modern generation'],
    'comestibles': ['board', 'bread', 'bread and butter', 'cheer', 'chow', 'creature comfort', 'cuisine', 'daily bread', 'eatables', 'eats', 'edibles', 'fare'],
    'comet': ['aldebaran', 'canicula', 'dog star', 'hesper', 'hesperus', 'lucifer', 'north star', 'phosphor', 'phosphorus', 'polaris', 'sirius', 'venus'],
    'comeuppance': ['compensation', 'desert', 'deserts', 'deserving', 'due', 'due reward', 'dues', 'just deserts', 'merit', 'merits', 'punishment', 'quittance'],
    'comfit': ['jell-o', 'blancmange', 'candy', 'compote', 'confection', 'confectionery', 'confiture', 'conserve', 'frosting', 'gelatin', 'glaze', 'honey'],
    'comfort': ['easy street', 'abet', 'abundance', 'acceptance', 'advocate', 'affluence', 'afghan', 'aid', 'aid and abet', 'aid and comfort', 'allay', 'alleviate'],
    'comfort station': ['wc', 'backhouse', 'basement', 'bathroom', 'can', 'closet', 'convenience', 'crapper', 'earth closet', 'head', 'john', 'johnny'],
    'comfortable': ['abounding in riches', 'acceptable', 'accepting', 'adequate', 'affluent', 'agreeable', 'amiable', 'at ease', 'big-rich', 'carefree', 'charmed', 'cheerful'],
    'comforter': ['afghan', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedsheet', 'bedspread', 'blanket', 'buffalo robe', 'case', 'clothes', 'comfort'],
    'comic': ['amusing', 'animated cartoon', 'antic', 'banana', 'broad', 'burlesque', 'burlesquer', 'camp', 'campy', 'caricature', 'caricaturist', 'cartoon'],
    'comical': ['absurd', 'broad', 'burlesque', 'comic', 'droll', 'farcical', 'foolish', 'funny', 'impish', 'ludicrous', 'mock-heroic', 'ridiculous'],
    'coming': ['about to be', 'access', 'accession', 'accomplishment', 'achievement', 'advance', 'advancing', 'advent', 'afflux', 'affluxion', 'already in sight', 'apparition'],
    'coming and going': ['lissajous figure', 'alternation', 'back-and-forth', 'ebb and flow', 'flux and reflux', 'reciprocation', 'rhythmic play', 'seesaw', 'seesawing', 'sine wave', 'teeter', 'teeter-totter'],
    'coming out': ['coming-out party', 'curtain raiser', 'debut', 'embarkation', 'embarkment', 'first appearance', 'floating', 'flotation', 'inaugural address', 'inauguration', 'induction', 'initiation'],
    'comma': ['ampersand', 'angle brackets', 'apostrophe', 'boundary', 'braces', 'caesura', 'colon', 'dash', 'decimal point', 'diagonal', 'dot', 'ellipsis'],
    'command': ['algol', 'cobol', 'fortran', 'ability', 'acme', 'address', 'adeptness', 'administer', 'administrate', 'administration', 'adroitness', 'airmanship'],
    'command of language': ['affectation', 'articulateness', 'command of words', 'effective style', 'eloquence', 'eloquent tongue', 'exaggeration', 'expression', 'expression of ideas', 'expressiveness', 'facundity', 'fashion'],
    'commandant': ['adc', 'co', 'od', 'aide', 'aide-de-camp', 'brigadier', 'brigadier general', 'bull', 'captain', 'castellan', 'chatelain', 'chatelaine'],
    'commandeer': ['accroach', 'annex', 'appropriate', 'arrogate', 'assume', 'attach', 'call up', 'collectivize', 'communalize', 'communize', 'confiscate', 'conscript'],
    'commander': ['a per se', 'adc', 'co', 'od', 'ace', 'admiral', 'aide', 'aide-de-camp', 'boatswain', 'boss', 'brigadier', 'brigadier general'],
    'commanding': ['absolute', 'ascendant', 'at the head', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'boss', 'chief', 'clothed with authority', 'compelling', 'competent'],
    'commandment': ['behest', 'bidding', 'canon', 'code', 'command', 'convention', 'dictate', 'dictation', 'dictum', 'direct order', 'form', 'formula'],
    'commemorate': ['beat the drum', 'blow the trumpet', 'celebrate', 'consecrate', 'dedicate', 'dress ship', 'fire a salute', 'hallow', 'hold jubilee', 'honor', 'immortalize', 'jubilate'],
    'commemoration': ['anniversaries', 'anniversary', 'annual holiday', 'bicentenary', 'bicentennial', 'biennial', 'birthday', 'bissextile day', 'celebrating', 'celebration', 'centenary', 'centennial'],
    'commence': ['arise', 'begin', 'blast away', 'blast off', 'come into being', 'dive in', 'embark', 'embark on', 'embark upon', 'enter', 'enter upon', 'establish'],
    'commencement': ['alpha', 'baccalaureate service', 'beginning', 'birth', 'blast-off', 'celebration', 'ceremonial', 'ceremony', 'conception', 'convocation', 'creation', 'cutting edge'],
    'commend': ['acclaim', 'advocate', 'applaud', 'approve', 'assign', 'back', 'boost', 'commit', 'compliment', 'confide', 'consign', 'countenance'],
    'commendable': ['admirable', 'advantageous', 'auspicious', 'beneficial', 'benevolent', 'beyond all praise', 'bon', 'bonny', 'braw', 'bueno', 'capital', 'cogent'],
    'commendation': ['acknowledgment', 'appreciation', 'assignment', 'blurb', 'boost', 'buildup', 'commitment', 'consignment', 'delegation', 'enfeoffment', 'entrustment', 'good word'],
    'commensal': ['cannibal', 'cannibalistic', 'carnivorous', 'coacting', 'coactive', 'coadjutant', 'coadjuvant', 'coefficient', 'collaborative', 'collective', 'collectivist', 'collectivistic'],
    'commensurate': ['accordant', 'adequate', 'affirmative', 'agreeable', 'agreeing', 'alike', 'ample', 'analogical', 'analogous', 'answerable', 'at one', 'at par'],
    'comment': ['parthian shot', 'accents', 'address', 'affirmation', 'allegation', 'allude to', 'analysis', 'animadversion', 'animadvert', 'annotate', 'annotation', 'answer'],
    'comment upon': ['air', 'analyze', 'annotate', 'canvass', 'censure', 'commentate', 'consider', 'controvert', 'criticize', 'critique', 'deal with', 'debate'],
    'commentary': ['affix', 'allonge', 'analysis', 'annotation', 'apparatus criticus', 'appendix', 'coda', 'codicil', 'comment', 'commentation', 'critical review', 'criticism'],
    'commentator': ['aftra', 'dj', 'mc', 'allegorist', 'anchor man', 'annotator', 'announcer', 'book reviewer', 'broadcaster', 'captious critic', 'carper', 'caviler'],
    'commerce': ['esp', 'act of love', 'activities', 'activity', 'adultery', 'affair', 'affairs', 'answer', 'aphrodisia', 'ass', 'bag', 'balling'],
    'commercial': ['banausic', 'breadwinning', 'broadcast', 'business', 'businesslike', 'canned show', 'commercial announcement', 'commercial program', 'electrical transcription', 'industrial', 'materialistic', 'mercantile'],
    'commingle': ['admix', 'alloy', 'amalgamate', 'bemingle', 'blend', 'coalesce', 'combine', 'commix', 'compose', 'compound', 'concoct', 'conglomerate'],
    'commiserate': ['ache', 'be sorry for', 'bleed', 'bleed for', 'comfort', 'compassionate', 'condole with', 'console', 'express sympathy for', 'feel for', 'feel sorrow for', 'feel sorry for'],
    'commissar': ['simon legree', 'absolute monarch', 'absolute ruler', 'alderman', 'all-powerful ruler', 'archon', 'arrogator', 'autarch', 'autocrat', 'bailie', 'burghermaster', 'burgomaster'],
    'commissary': ['px', 'abundance', 'accumulation', 'amassment', 'backlog', 'budget', 'canned foods', 'canteen', 'caterer', 'chandler', 'collection', 'commissar'],
    'commission': ['accomplishment', 'accredit', 'achievement', 'administration', 'allotment', 'allowance', 'appoint', 'assemblee', 'assembly', 'assign', 'assignation', 'assignment'],
    'commissioner': ['g-man', 'mp', 'alderman', 'archon', 'bailie', 'bailiff', 'beadle', 'beagle', 'bound bailiff', 'burghermaster', 'burgomaster', 'cabinet member'],
    'commit': ['accept obligation', 'accomplish', 'accredit', 'achieve', 'agree', 'agree to', 'allocate', 'allot', 'answer for', 'assign', 'assure', 'authorize'],
    'commitment': ['abandon', 'activity', 'affair', 'agency', 'agentship', 'agreement', 'allegiance', 'altruism', 'ardency', 'ardor', 'assigned task', 'assignment'],
    'committed': ['abandoned', 'affianced', 'afire', 'altruistic', 'ardent', 'assured', 'beholden', 'beholden to', 'betrothed', 'bound', 'bound and determined', 'bounden'],
    'committee': ['ad hoc committee', 'assemblee', 'assembly', 'assignation', 'at home', 'ball', 'board', 'body', 'brawl', 'cabinet', 'caucus', 'colloquium'],
    'committeeman': ['greek', 'affiliate', 'associate', 'belonger', 'brother', 'card-carrier', 'card-carrying member', 'cardholder', 'charter member', 'clubber', 'clubman', 'clubwoman'],
    'commodious': ['advantageous', 'ample', 'amplitudinous', 'appropriate', 'banausic', 'beneficial', 'broad', 'capacious', 'comfortable', 'comfy', 'contented', 'convenient'],
    'common': ['astroturf', 'attic', 'babbittish', 'mickey mouse', 'philistine', 'spartan', 'absolute interest', 'accustomed', 'adequate', 'all right', 'artificial turf', 'ascetic'],
    'common knowledge': ['pr', 'accessible', 'affirmed', 'announced', 'ballyhoo', 'blurb', 'bright light', 'broadcast', 'brought to notice', 'celebrity', 'circulated', 'common property'],
    'common law': ['corpus juris canonici', 'mishnah', 'roman law', 'spiritus mundi', 'sunna', 'talmud', 'admiralty law', 'ancient wisdom', 'archetypal myth', 'archetypal pattern', 'blue law', 'canon law'],
    'common man': ['cockney', 'everyman', 'john doe', 'john smith', 'public', 'a nobody', 'a nothing', 'average', 'average man', 'body politic', 'bourgeois', 'cipher'],
    'common people': ['bourgeoisie', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty', 'commoners', 'commons', 'laborers', 'linendrapers', 'lower classes', 'lower middle class'],
    'common sense': ['admissibility', 'balance', 'cool head', 'coolheadedness', 'coolness', 'due sense of', 'good sense', 'gumption', 'horse sense', 'judgment', 'justifiability', 'justness'],
    'commoner': ['cockney', 'everyman', 'john smith', 'average man', 'bourgeois', 'bourgeoisie', 'common man', 'common people', 'common run', 'common sort', 'commonage', 'commonality'],
    'commonly': ['again and again', 'all in all', 'all things considered', 'altogether', 'as a rule', 'as a whole', 'as an approximation', 'as per usual', 'as things go', 'as usual', 'at large', 'banally'],
    'commonness': ['attic simplicity', 'accustomedness', 'averageness', 'banality', 'banalness', 'baseness', 'chasteness', 'classical purity', 'cliche', 'coarseness', 'common occurrence', 'commonality'],
    'commonplace': ['attic', 'babbittish', 'philistine', 'spartan', 'abstraction', 'accustomed', 'ascetic', 'austere', 'average', 'back-number', 'bald', 'banal'],
    'commons': ['c ration', 'k ration', 'allotment', 'allowance', 'board', 'bourgeoisie', 'cafeteria', 'common', 'common people', 'common run', 'common sort', 'commonage'],
    'commonweal': ['ally', 'archduchy', 'archdukedom', 'body politic', 'buffer state', 'captive nation', 'chieftaincy', 'chieftainry', 'child welfare', 'city-state', 'colony', 'commonwealth'],
    'commonwealth': ['everyman', 'john doe', 'public', 'absolute monarchy', 'ally', 'archduchy', 'archdukedom', 'aristocracy', 'ashram', 'autarchy', 'autocracy', 'autonomy'],
    'commotion': ['bedlam let loose', 'ado', 'agitation', 'annoyance', 'bedlam', 'blast', 'bluster', 'bobbery', 'boil', 'boiling', 'bother', 'botheration'],
    'communal': ['associated', 'associational', 'civic', 'civil', 'coacting', 'coactive', 'coadjutant', 'coadjuvant', 'coalitional', 'coefficient', 'collaborative', 'collective'],
    'commune': ['kreis', 'archbishopric', 'archdiocese', 'arrondissement', 'ashram', 'bailiwick', 'bishopric', 'body', 'borough', 'canton', 'caste', 'city'],
    'commune with': ['bandy words', 'be in connection', 'be in contact', 'chew the fat', 'chew the rag', 'chin', 'colloque', 'colloquize', 'commerce with', 'communicate', 'communicate with', 'confab'],
    'communicable': ['allowable', 'assignable', 'bequeathable', 'bestowable', 'catching', 'conductive', 'consignable', 'contagious', 'conveyable', 'deadly', 'destructive', 'devisable'],
    'communicant': ['christian', 'god-fearing man', 'accepter', 'adorer', 'adviser', 'announcer', 'annunciator', 'authority', 'beadsman', 'believer', 'brother', 'catechumen'],
    'communicate': ['abut', 'accord', 'acquaint', 'adhere', 'administer', 'administer communion', 'advertise', 'advertise of', 'advice', 'advise', 'afford', 'allot'],
    'communicate with': ['answer', 'approach', 'bandy words', 'chew the fat', 'chew the rag', 'chin', 'colloque', 'colloquize', 'commerce with', 'commune with', 'communicate', 'confab'],
    'communication': ['access', 'accommodation', 'accordance', 'account', 'acknowledgment', 'acquaintance', 'advice', 'agglomeration', 'agglutination', 'aggregation', 'aisle', 'alley'],
    'communications': ['ap', 'associated press', 'fleet street', 'reuters', 'upi', 'united press international', 'book publishing', 'communication theory', 'communications industry', 'communications medium', 'communications network', 'electronic communications'],
    'communicative': ['accessible', 'advisory', 'affable', 'all jaw', 'amiable', 'approachable', 'candid', 'chatty', 'chitchatty', 'civil', 'clubbable', 'clubbish'],
    'communion': ['angelus', 'ave', 'ave maria', 'bolshevik', 'bolshie', 'communist', 'esp', 'hail mary', 'kyrie eleison', 'leninist', 'marxist', 'paternoster'],
    'communique': ['account', 'acquaintance', 'advice', 'announcement', 'annunciation', 'blue book', 'briefing', 'bulletin', 'bulletin board', 'circular', 'communication', 'data'],
    'communism': ['bolshevism', 'castroism', 'communist information bureau', 'communist party', 'maoism', 'marxian socialism', 'marxism', 'marxism-leninism', 'nazism', 'stalinism', 'titoism', 'trotskyism'],
    'communist': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist sympathizer', 'cong', 'fenian', 'guevarist'],
    'communist party': ['american party', 'anti-monopoly party', 'bolshevism', 'bull moose party', 'castroism', 'communist information bureau', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party'],
    'communistic': ['associated', 'coacting', 'coactive', 'coadjutant', 'coadjuvant', 'coefficient', 'collaborative', 'collective', 'collectivist', 'collectivistic', 'collusive', 'combined'],
    'community': ['everyman', 'john doe', 'public', 'accord', 'accordance', 'affiliation', 'affinity', 'agape', 'agreement', 'alikeness', 'alliance', 'amity'],
    'communize': ['annex', 'attach', 'collectivize', 'commandeer', 'communalize', 'confiscate', 'democratize', 'distrain', 'expropriate', 'garnish', 'impound', 'impress'],
    'commutation': ['agency', 'alternation', 'amends', 'atonement', 'balancing', 'battledore and shuttlecock', 'change', 'compensation', 'cooperation', 'counteraction', 'counterbalancing', 'counterchange'],
    'commute': ['alternate', 'bandy', 'be quits with', 'change', 'change for', 'compensate', 'compound for', 'convert', 'cooperate', 'counterchange', 'course', 'cover ground'],
    'commuter': ['adventurer', 'alpinist', 'astronaut', 'camper', 'climber', 'comers and goers', 'cosmopolite', 'cruiser', 'excursionist', 'explorer', 'fare', 'globe-girdler'],
    'compact': ['spartan', 'abbreviate', 'abbreviated', 'abridged', 'agree', 'agree to', 'agreement', 'airtight', 'ammunition box', 'aphoristic', 'aposiopestic', 'ark'],
    'companion': ['bayard', 'don quixote', 'gawain', 'lancelot', 'ritter', 'sidney', 'sir galahad', 'abigail', 'accompanier', 'accompanist', 'accompanyist', 'ace'],
    'companionable': ['affable', 'amiable', 'civil', 'clubbable', 'clubbish', 'clubby', 'communicative', 'companionate', 'compatible', 'congenial', 'courteous', 'fit for society'],
    'companionship': ['affiliation', 'amity', 'association', 'boon companionship', 'brotherhood', 'brotherliness', 'camaraderie', 'chumship', 'colleagueship', 'community', 'community of interest', 'company'],
    'company': ['aktiengesellschaft', 'kp', 'ace', 'acting company', 'actors', 'affiliation', 'age group', 'agency', 'aggregation', 'aktiebolag', 'amigo', 'army'],
    'comparable': ['affinitive', 'agnate', 'akin', 'alike', 'analogical', 'analogous', 'appertaining', 'approximate', 'approximating', 'approximative', 'associative', 'close'],
    'comparative': ['affinitive', 'analogical', 'analogous', 'appertaining', 'approximate', 'associative', 'collatable', 'commensurable', 'commensurate', 'comparable', 'congenial', 'connective'],
    'comparatively': ['after a fashion', 'appositely', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst', 'comparably'],
    'compare': ['admit of comparison', 'analogize', 'ape', 'appear like', 'approach', 'approximate', 'assimilate', 'associate', 'balance', 'be commensurable', 'be comparable', 'be like'],
    'comparison': ['accordance', 'affinity', 'agent', 'agreement', 'alikeness', 'alliance', 'alternate', 'alternative', 'analogy', 'aping', 'approach', 'approximation'],
    'compartment': ['alcove', 'bay', 'below', 'between-decks', 'boiler room', 'booth', 'box', 'brig', 'bunker', 'cabin', 'caboose', 'camboose'],
    'compass': ['gyrosin compass', 'johansson block', 'rdf', 't square', 'accept', 'accomplish', 'achieve', 'acquire', 'aesthetic distance', 'alentours', 'ambience', 'ambit'],
    'compassion': ['acceptance', 'affectionateness', 'benevolence', 'benignancy', 'benignity', 'brotherhood', 'charity', 'clemency', 'clementness', 'commiseration', 'condolence', 'easiness'],
    'compassionate': ['christian', 'christlike', 'christly', 'accepting', 'ache', 'affectionate', 'benign', 'benignant', 'bleeding', 'brotherly', 'charitable', 'clement'],
    'compatibility': ['accord', 'accordance', 'affability', 'affinity', 'agape', 'agreeability', 'agreeableness', 'agreement', 'amenity', 'amiability', 'amicability', 'amity'],
    'compatible': ['accordant', 'affable', 'affirmative', 'agreeable', 'agreeing', 'akin', 'amiable', 'amicable', 'answerable', 'appropriate', 'at one', 'attuned'],
    'compatriot': ['adjunct', 'ally', 'associate', 'bedfellow', 'brother', 'brother-in-arms', 'coadjutor', 'cohort', 'colleague', 'companion', 'compeer', 'comrade'],
    'compel': ['actuate', 'animate', 'beat down', 'beset', 'bind', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'cause', 'cause to'],
    'compelling': ['actuating', 'acute', 'animating', 'causal', 'causative', 'clamorous', 'coactive', 'compulsive', 'compulsory', 'constraining', 'critical', 'crucial'],
    'compendious': ['spartan', 'abbreviated', 'abridged', 'across-the-board', 'all-comprehensive', 'all-inclusive', 'aposiopestic', 'blanket', 'brief', 'brusque', 'clipped', 'close'],
    'compendium': ['baedeker', 'abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'brief', 'capsule', 'compend', 'condensation', 'condensed version', 'conspectus'],
    'compensate': ['abrogate', 'accommodate', 'adjust', 'alternate', 'amend', 'annul', 'atone', 'atone for', 'balance', 'bandy', 'be quits with', 'better'],
    'compensating': ['adversative', 'adverse', 'adversive', 'amendatory', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'antonymous', 'at cross-purposes', 'balancing', 'clashing'],
    'compensation': ['alienation', 'amends', 'atonement', 'autism', 'autistic thinking', 'avoidance mechanism', 'base pay', 'blame-shifting', 'blood money', 'comeuppance', 'composition', 'compromise'],
    'compensatory': ['amendatory', 'apologetic', 'ascetic', 'atoning', 'balancing', 'cleansing', 'compensating', 'compensational', 'compensative', 'counteracting', 'counteractive', 'counterbalancing'],
    'compete': ['antagonize', 'approach', 'attempt', 'battle', 'beat against', 'beat up against', 'breast the wave', 'buck', 'buffet', 'buffet the waves', 'challenge', 'clash'],
    'competence': ['ability', 'ableness', 'absolute power', 'absolutism', 'address', 'adeptness', 'adequacy', 'adequate supply', 'adequateness', 'adroitness', 'airmanship', 'appropriateness'],
    'competent': ['ok', 'able', 'absolute', 'acceptable', 'actionable', 'adapted', 'adept', 'adequate', 'adjusted', 'all right', 'ample', 'applicable'],
    'competently': ['ably', 'adeptly', 'adequately', 'adroitly', 'agilely', 'amply', 'aptly', 'artfully', 'artistically', 'brilliantly', 'capably', 'cleverly'],
    'competition': ['antagonism', 'antipathy', 'bad blood', 'championship', 'clashing', 'collision', 'competitor', 'concours', 'conflict', 'contention', 'contest', 'contrariety'],
    'competitive': ['adversary', 'adversative', 'adverse', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'clashing', 'competing', 'con', 'conflicting'],
    'competitor': ['adversary', 'amateur athlete', 'antagonist', 'archer', 'athlete', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'battler', 'belligerent'],
    'compilation': ['festschrift', 'album', 'ana', 'analects', 'anthology', 'aquarium', 'beauties', 'body', 'canon', 'chrestomathy', 'collectanea', 'collected works'],
    'compile': ['accumulate', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'assemble', 'batch', 'bring together', 'bulk', 'bunch', 'bunch together', 'bunch up'],
    'complacent': ['bovine', 'consequential', 'narcissan', 'narcissine', 'narcissistic', 'narcistic', 'overproud', 'overweening', 'self-admiring', 'self-approving', 'self-assuming', 'self-complacent'],
    'complain': ['accuse', 'ail', 'air a grievance', 'allege', 'arraign', 'article', 'be affected with', 'beef', 'bellyache', 'bemoan', 'bitch', 'boggle'],
    'complainant': ['accusant', 'accuser', 'allegator', 'appellant', 'bellyacher', 'claimant', 'complainer', 'crab', 'crank', 'croaker', 'delator', 'faultfinder'],
    'complainer': ['bellyacher', 'complainant', 'crab', 'crank', 'croaker', 'faultfinder', 'frondeur', 'griever', 'griper', 'grouch', 'grouser', 'growler'],
    'complaining': ['jeremianic', 'beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'complaint', 'complaintful', 'crabbing', 'crabby', 'cranky'],
    'complaint': ['abnormality', 'accusal', 'accusation', 'accusing', 'acute disease', 'affection', 'affidavit', 'affliction', 'ailment', 'allegation', 'allegement', 'allergic disease'],
    'complaisant': ['abject', 'accepting', 'accommodating', 'accommodative', 'acquiescent', 'adaptable', 'adaptive', 'adjustable', 'affable', 'agreeable', 'amiable', 'amicable'],
    'complement': ['a to z', 'a to izzard', 'ic analysis', 'accession', 'accessory', 'accompaniment', 'add to', 'addenda', 'addendum', 'additament', 'addition', 'additive'],
    'complementary': ['analogous', 'answering', 'coequal', 'complemental', 'completing', 'completive', 'completory', 'consummative', 'consummatory', 'correspondent', 'corresponding', 'culminative'],
    'complete': ['ko', 'sol', 'abide by', 'absolute', 'accomplish', 'accomplished', 'achieve', 'across-the-board', 'adhere to', 'administer', 'admit', 'admitting no exception'],
    'complete works': ['festschrift', 'album', 'ana', 'analects', 'anthology', 'beauties', 'canon', 'chrestomathy', 'collectanea', 'collected works', 'collection', 'compilation'],
    'completely': ['a outrance', 'absolutely', 'all out', 'altogether', 'and sinker', 'at length', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure', 'categorically', 'clearly'],
    'completion': ['accomplishment', 'achievement', 'administration', 'bitter end', 'carrying out', 'catastrophe', 'climax', 'close', 'closure', 'commission', 'completing', 'conclusion'],
    'complex': ['byzantine', 'chinese puzzle', 'diana complex', 'electra complex', 'gordian knot', 'herculean', 'oedipus complex', 'rube goldberg contraption', 'abstruse', 'acculturation', 'amalgamated', 'ambiguous'],
    'complexion': ['achromatism', 'air', 'ambiversion', 'bearing', 'body-build', 'brand', 'brow', 'carriage', 'cast', 'cast of countenance', 'character', 'characteristic'],
    'complexity': ['abstruseness', 'arduousness', 'bothersomeness', 'burdensomeness', 'complication', 'convolution', 'crabbedness', 'crampedness', 'deepness', 'difficultness', 'difficulty', 'esoterica'],
    'compliance': ['ok', 'quakerism', 'acceptance', 'accession', 'accommodatingness', 'accommodation', 'accord', 'accordance', 'acquiescence', 'acquittal', 'acquittance', 'adaptation'],
    'compliant': ['abject', 'accepting', 'accommodating', 'accordant', 'acquiescent', 'acquiescing', 'active', 'adaptable', 'adapting', 'adaptive', 'adjustable', 'adjusting'],
    'complicate': ['accelerate', 'add', 'adjoin', 'affix', 'agglutinate', 'aggravate', 'annex', 'append', 'attach', 'ball up', 'beef up', 'blow up'],
    'complicated': ['byzantine', 'daedalian', 'abstruse', 'arduous', 'balled up', 'beyond one', 'complex', 'compound', 'confounded', 'confused', 'convoluted', 'crabbed'],
    'complication': ['abnormality', 'abstruseness', 'action', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'anagnorisis', 'angle', 'architectonics'],
    'complicity': ['arraignability', 'arraignableness', 'artifice', 'association', 'bipartisanship', 'blameworthiness', 'bloody hands', 'burden', 'cabal', 'censurability', 'censurableness', 'chargeability'],
    'compliment': ['tl', 'acclaim', 'accolade', 'adulate', 'adulation', 'applaud', 'benevolence', 'beslobber', 'beslubber', 'best wishes', 'blandish', 'blandishment'],
    'complimentary': ['acclamatory', 'admiring', 'adulatory', 'appreciative', 'approbatory', 'bland', 'blandishing', 'blarneying', 'buttery', 'cajoling', 'charitable', 'commendatory'],
    'comply': ['abide by', 'accede', 'accept', 'acclaim', 'accommodate', 'accommodate with', 'accord', 'acquiesce', 'acquiesce in', 'act up to', 'adapt', 'adapt to'],
    'component': ['actuator', 'adjunct', 'air', 'amplifier', 'anode', 'appurtenance', 'aspect', 'atom', 'atomic particles', 'base', 'brute matter', 'building block'],
    'components': ['census', 'composition', 'constituents', 'content', 'contents', 'divisions', 'elements', 'guts', 'index', 'ingredients', 'innards', 'insides'],
    'comport': ['accord', 'acquit', 'act', 'bear', 'carry', 'check', 'conduct', 'correspond', 'demean', 'deport', 'dovetail', 'fit in'],
    'comportment': ['action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'bearing', 'behavior', 'behavior pattern', 'behavioral norm', 'behavioral science'],
    'compose': ['accommodate', 'accommodate with', 'accord', 'adapt', 'adapt to', 'adjust', 'adjust to', 'admix', 'agree with', 'align', 'allay', 'allocate'],
    'composed': ['accepting', 'aligned', 'amalgam', 'amalgamation', 'arranged', 'arrayed', 'assorted', 'assured', 'at ease', 'aweless', 'balanced', 'calm'],
    'composer': ['advertising writer', 'annalist', 'arranger', 'art critic', 'author', 'authoress', 'ballad maker', 'balladeer', 'balladist', 'balladmonger', 'belletrist', 'bibliographer'],
    'composite': ['admixture', 'alloy', 'amalgam', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'blend', 'blended', 'certain', 'combination', 'combined'],
    'composition': ['anschluss', 'intertype', 'linotype', 'monotype', 'nachtmusik', 'portland cement', 'spackle', 'abatement of differences', 'absolute music', 'accommodation', 'adaptation', 'addition'],
    'compost': ['admixture', 'ammonia', 'castor-bean meal', 'commercial fertilizer', 'commixture', 'composite', 'compound', 'dressing', 'dung', 'enrichener', 'fertilizer', 'fusion'],
    'composure': ['buddha-like composure', 'oriental calm', 'acceptance', 'aplomb', 'ataraxia', 'ataraxy', 'awelessness', 'calm disposition', 'calm of mind', 'calmness', 'comfort', 'constraint'],
    'compound': ['accommodate', 'acid', 'acidity', 'acronym', 'acrostic', 'add', 'add to', 'adjust', 'admix', 'admixture', 'agent', 'aggrandize'],
    'comprehend': ['absorb', 'accept', 'admit', 'appreciate', 'apprehend', 'assimilate', 'be acquainted with', 'be apprised of', 'be aware of', 'be cognizant of', 'be conscious of', 'be conversant with'],
    'comprehended': ['appreciated', 'apprehended', 'ascertained', 'bound up with', 'comprised', 'conceived', 'covered', 'discerned', 'down pat', 'embraced', 'encompassed', 'envisaged'],
    'comprehensible': ['appreciable', 'apprehensible', 'articulate', 'ascertainable', 'cognizable', 'conceivable', 'discernible', 'discoverable', 'distinguishable', 'easily understood', 'easy to understand', 'exoteric'],
    'comprehensibly': ['apprehensibly', 'articulately', 'clearly', 'coherently', 'definitely', 'distinctly', 'explicitly', 'expressly', 'in plain english', 'in plain terms', 'in plain words', 'intelligibly'],
    'comprehension': ['iq', 'admissibility', 'admission', 'apprehension', 'assimilation', 'caliber', 'capacity', 'clairvoyance', 'command', 'completeness', 'comprehensiveness', 'comprisal'],
    'comprehensive': ['absolute', 'across-the-board', 'aggregate', 'all', 'all-comprehensive', 'all-embracing', 'all-encompassing', 'all-inclusive', 'all-out', 'all-pervading', 'ample', 'blanket'],
    'compress': ['ace bandage', 'band-aid', 'abbreviate', 'abridge', 'abstract', 'adhesive tape', 'application', 'band', 'bandage', 'bandaging', 'bear', 'binder'],
    'compressed': ['spartan', 'abbreviated', 'abridged', 'abstracted', 'aposiopestic', 'bobbed', 'brief', 'brusque', 'capsule', 'capsulized', 'clamped', 'clipped'],
    'compression': ['abbreviation', 'abridgment', 'abstract', 'agglutination', 'apocope', 'astriction', 'astringency', 'bottleneck', 'cervix', 'circumscription', 'clamping', 'clamping down'],
    'comprise': ['accouple', 'accumulate', 'add', 'add up to', 'admit', 'affect', 'agglutinate', 'aggregate', 'aggregate to', 'amalgamate', 'amass', 'amount to'],
    'compromise': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'accommodate', 'accommodation', 'adjust', 'adjustment', 'agreement', 'amends', 'appeasement', 'arrange matters'],
    'comptroller': ['big brother', 'ca', 'cpa', 'accountant', 'accountant general', 'actuary', 'auditor', 'bank accountant', 'bank examiner', 'boatswain', 'bookkeeper', 'boss'],
    'compulsion': ['abstraction', 'abulia', 'alienation', 'amperage', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'armipotence', 'authority', 'beef', 'black power'],
    'compulsive': ['accordant', 'anal', 'automatic', 'blind', 'bourgeois', 'coactive', 'coercive', 'compelling', 'compulsatory', 'compulsory', 'concordant', 'conditioned'],
    'compulsively': ['anally', 'automatically', 'blindly', 'by reflex', 'compellingly', 'complaisantly', 'compliantly', 'compulsorily', 'conformably', 'conformingly', 'conventionally', 'flexibly'],
    'compulsory': ['absolute', 'binding', 'choiceless', 'coactive', 'compelling', 'compulsatory', 'compulsive', 'conclusive', 'constraining', 'decisive', 'decretory', 'dictated'],
    'compunction': ['attrition', 'bashfulness', 'beef', 'better self', 'bitch', 'boggle', 'boggling', 'boycott', 'challenge', 'complaint', 'conscience', 'conscientiousness'],
    'computation': ['accounting', 'adding', 'adding machine', 'analysis', 'appraisal', 'appraisement', 'approximation', 'arithmetic', 'assessment', 'assize', 'assizement', 'braking'],
    'compute': ['add', 'add up', 'algebraize', 'appraise', 'appreciate', 'ascertain', 'assay', 'assess', 'calculate', 'calibrate', 'caliper', 'cast'],
    'computer': ['ibm machine', 'ida', 'teleplotter', 'telereader', 'abacist', 'accountant', 'actuary', 'adder', 'analog computer', 'analytical control unit', 'analyzer', 'bookkeeper'],
    'computer program': ['algol', 'cobol', 'fortran', 'alphabetic data', 'alphanumeric code', 'angular data', 'assembler', 'binary digit', 'binary scale', 'binary system', 'bit', 'bug'],
    'computing': ['edp', 'analyzing', 'calculating', 'classifying', 'collating', 'computational', 'computative', 'computer technology', 'computer typesetting', 'data processing', 'data retrieval', 'electronic data processing'],
    'comrade': ['bolshevik', 'bolshie', 'greek', 'red', 'ace', 'adjunct', 'affiliate', 'ally', 'amigo', 'associate', 'auxiliary', 'bedfellow'],
    'comradeship': ['affiliation', 'alignment', 'alliance', 'amalgamation', 'association', 'boon companionship', 'brotherhood', 'brotherliness', 'cahoots', 'camaraderie', 'chumship', 'coadunation'],
    'con': ['pow', 'adversary', 'adversative', 'adverse', 'against', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'argue into', 'argument'],
    'con artist': ['bunco artist', 'bunco steerer', 'cardsharp', 'cardsharper', 'carpetbagger', 'con man', 'confidence man', 'crimp', 'horse coper', 'horse trader', 'jackleg', 'land pirate'],
    'con man': ['body snatcher', 'booster', 'bunco artist', 'bunco steerer', 'cardsharp', 'cardsharper', 'carpetbagger', 'chicken thief', 'con artist', 'confidence man', 'crimp', 'crook'],
    'concatenate': ['accouple', 'accumulate', 'agglutinate', 'amass', 'articulate', 'assemble', 'associate', 'band', 'be continuous', 'bond', 'bracket', 'bridge'],
    'concave': ['arched', 'arciform', 'arclike', 'arcual', 'bandy', 'boat-shaped', 'boatlike', 'bowed', 'bowl-shaped', 'bowlike', 'bowllike', 'cavelike'],
    'concavity': ['aduncity', 'alveolation', 'alveolus', 'antrum', 'aquilinity', 'arching', 'arcuation', 'armpit', 'basin', 'boss', 'bowl', 'bump'],
    'conceal': ['becloud', 'befog', 'blanket', 'blind', 'bosom', 'bury', 'cache', 'camouflage', 'classify', 'cloak', 'cloud', 'cover'],
    'concealed': ['abstruse', 'arcane', 'beclouded', 'behind the curtain', 'behind the scenes', 'blind', 'buried', 'cabalistic', 'camouflaged', 'censored', 'classified', 'close'],
    'concealment': ['abri', 'air-raid shelter', 'airtight secrecy', 'asylum', 'bolt-hole', 'bomb shelter', 'bombproof', 'bunker', 'cache', 'cave', 'close secrecy', 'closeness'],
    'concede': ['abandon', 'accept', 'accord', 'acknowledge', 'admit', 'admit everything', 'admit exceptions', 'agree provisionally', 'allow', 'allow for', 'assent grudgingly', 'avow'],
    'conceit': ['abstract thought', 'act of thought', 'affectation', 'aggressive self-confidence', 'amour propre', 'aphorism', 'apothegm', 'apprehension', 'arrogance', 'assume', 'assumption', 'assurance'],
    'conceited': ['gascon', 'aggressively self-confident', 'arrogant', 'biggety', 'boastful', 'boasting', 'braggart', 'bragging', 'bumptious', 'chesty', 'cocky', 'complacent'],
    'conceivable': ['apparent', 'appreciable', 'apprehensible', 'ascertainable', 'believable', 'cogitable', 'cognizable', 'colorable', 'comprehensible', 'conceivably possible', 'contingent', 'credible'],
    'conceive': ['absorb', 'accept', 'account as', 'animate', 'appreciate', 'apprehend', 'assimilate', 'assume', 'author', 'be acquainted with', 'be afraid', 'be apprised of'],
    'conceived': ['appreciated', 'apprehended', 'ascertained', 'coined', 'comprehended', 'discerned', 'discovered', 'down pat', 'fabricated', 'grasped', 'invented', 'known'],
    'concentrate': ['abbreviate', 'accelerate', 'aggravate', 'approach', 'assemble', 'attend closely to', 'attend to business', 'be alert', 'be obsessed with', 'beef up', 'blow up', 'bring into focus'],
    'concentrated': ['advertent', 'agog', 'alert', 'all ears', 'all eyes', 'assiduous', 'attentive', 'aware', 'axial', 'careful', 'centermost', 'central'],
    'concentration': ['abbreviation', 'absorbed attention', 'absorption', 'abstraction', 'accelerando', 'acceleration', 'advertence', 'advertency', 'agglutination', 'aggravation', 'alertness', 'application'],
    'concentration camp': ['belsen', 'konzentrationslager', 'lager', 'pow camp', 'abattoir', 'aceldama', 'barrack', 'barracks', 'bastille', 'bivouac', 'black hole', 'borstal'],
    'concept': ['vorstellung', 'apprehension', 'assumption', 'attitude', 'climate of opinion', 'common belief', 'community sentiment', 'conceit', 'conception', 'conceptualization', 'conclusion', 'consensus gentium'],
    'conception': ['calliope', 'clio', 'erato', 'euterpe', 'iq', 'melpomene', 'polyhymnia', 'terpsichore', 'thalia', 'vernunft', 'vorstellung', 'abstract thought'],
    'conceptual': ['bright', 'cerebral', 'cogitative', 'cognitive', 'concentrating', 'concentrative', 'conceptive', 'conceptualized', 'contemplating', 'contemplative', 'creative', 'deliberating'],
    'conceptualize': ['appreciate', 'apprehend', 'be acquainted with', 'be apprised of', 'be aware of', 'be cognizant of', 'be conscious of', 'be conversant with', 'be informed', 'cerebrate', 'cogitate', 'cognize'],
    'concern': ['aktiengesellschaft', 'tlc', 'absorb', 'academic discipline', 'academic specialty', 'accent', 'accommodatingness', 'activities', 'activity', 'affair', 'affairs', 'affect'],
    'concerned': ['a party to', 'active', 'affected', 'agitated', 'all-overish', 'anxious', 'anxioused up', 'apprehensive', 'attracted', 'bothered', 'caring', 'cathectic'],
    'concerning': ['about', 'against', 'anent', 'apropos of', 'as for', 'as regards', 'as respects', 'as to', 'in connection with', 'in point of', 'in re', 'in reference to'],
    'concert': ['philharmonic concert', 'acclamation', 'accompaniment', 'accord', 'accordance', 'act in concert', 'act together', 'affiliate', 'affinity', 'agreement', 'agreement of all', 'alliance'],
    'concert hall': ['elizabethan theater', 'globe theatre', 'greek theater', 'amphitheater', 'arena', 'arena theater', 'assembly hall', 'auditorium', 'cabaret', 'chapel', 'circle theater', 'club'],
    'concerted': ['accompanying', 'accordant', 'agreeing', 'associate', 'associated', 'at one with', 'coacting', 'coactive', 'coadjutant', 'coadjuvant', 'coadunate', 'coefficient'],
    'concession': ['abatement', 'abatement of differences', 'acceptance', 'accommodation', 'accordance', 'acknowledgment', 'adjustment', 'admission', 'agio', 'allowance', 'appease', 'appreciation'],
    'conciliate': ['allay', 'appease', 'calm', 'cool', 'defuse', 'dulcify', 'lay', 'lay the dust', 'mollify', 'pacify', 'placate', 'pour balm on'],
    'conciliatory': ['appeasing', 'benevolent', 'civilian', 'dovish', 'forbearing', 'forgiving', 'generous', 'irenic', 'kind', 'long-suffering', 'longanimous', 'magnanimous'],
    'concise': ['spartan', 'abbreviated', 'abridged', 'aposiopestic', 'brief', 'brusque', 'clipped', 'close', 'close-tongued', 'closemouthed', 'cogent', 'compact'],
    'conclave': ['council of nicaea', 'council of trent', 'lateran council', 'vatican council', 'assemblee', 'assembly', 'assignation', 'at home', 'audience', 'ball', 'bargaining', 'bargaining session'],
    'conclude': ['abort', 'accommodate', 'adjust', 'arrange', 'assume', 'be afraid', 'believe', 'button up', 'cap', 'carry to completion', 'cease', 'clean up'],
    'conclusion': ['ps', 'parthian shot', 'accommodation', 'addendum', 'adjustment', 'affirmance', 'affirmation', 'aftermath', 'afterthought', 'allegation', 'announcement', 'annunciation'],
    'conclusive': ['absolute', 'adducible', 'admissible', 'admitting no exception', 'all-out', 'apodictic', 'assuring', 'attestative', 'attestive', 'authentic', 'authoritative', 'based on'],
    'concoct': ['accessory', 'accompanying', 'adjuvant', 'admix', 'alloy', 'amalgamate', 'ancillary', 'angle', 'assemble', 'attendant', 'attending', 'beget'],
    'concoction': ['admixture', 'alloy', 'amalgam', 'artifact', 'authorship', 'beginning', 'blend', 'brainchild', 'brew', 'canard', 'child', 'coinage'],
    'concomitant': ['accession', 'accessory', 'accompaniment', 'accompanying', 'accordant', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum'],
    'concord': ['nato', 'seato', 'acclamation', 'accord', 'accordance', 'affinity', 'agape', 'agreement', 'agreement of all', 'alliance', 'amity', 'arpeggio'],
    'concordance': ['acclamation', 'accompaniment', 'accord', 'accordance', 'affinity', 'agape', 'agreement', 'agreement of all', 'alliance', 'amity', 'assent', 'association'],
    'concordant': ['accompanying', 'accordant', 'according', 'affirmative', 'agreeable', 'agreeing', 'akin', 'amicable', 'anal', 'answerable', 'associate', 'associated'],
    'concourse': ['accompaniment', 'accordance', 'affluence', 'afflux', 'affluxion', 'agglomeration', 'agglutination', 'aggregation', 'agreement', 'alliance', 'approach', 'articulation'],
    'concrete': ['formica', 'masonite', 'tarmac', 'tarvia', 'absolute', 'actual', 'adamant', 'adobe', 'agglomerate', 'agglomeration', 'appreciable', 'ashlar'],
    'concubine': ['better half', 'bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'captive', 'chattel', 'chattel slave', 'churl', 'common-law wife', 'debt slave'],
    'concupiscence': ['andromania', 'animality', 'aphrodisia', 'ardor', 'bawdiness', 'biological urge', 'bodily appetite', 'carnal desire', 'carnality', 'clitoromania', 'curiosity', 'desideration'],
    'concur': ['accede', 'accompany', 'accord', 'acquiesce', 'act in concert', 'act together', 'affiliate', 'agree', 'agree in opinion', 'agree with', 'ally', 'amalgamate'],
    'concurrence': ['acceptance', 'accession', 'acclamation', 'accompaniment', 'accord', 'accordance', 'acquiescence', 'agglomeration', 'agglutination', 'aggregation', 'agreement', 'agreement in principle'],
    'concurrent': ['accessory', 'accompanying', 'accordant', 'agreeing', 'aligned', 'analogous', 'approaching', 'associate', 'associated', 'asymptotic', 'at one', 'at one with'],
    'concurrently': ['all agreeing', 'all together', 'as one', 'as one man', 'at a clip', 'at once', 'at one time', 'back to back', 'by acclamation', 'cheek by jowl', 'coactively', 'coefficiently'],
    'concussion': ['abrasion', 'appulse', 'beating', 'blemish', 'blow', 'break', 'brunt', 'buffeting', 'bulldozing', 'bulling', 'bump', 'burn'],
    'condemn': ['accuse', 'act on', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'attaint', 'belittle', 'blacklist', 'blame', 'bring home to', 'bring to ruin'],
    'condemnation': ['acquittal', 'action', 'anathema', 'arraignment', 'award', 'blame', 'castigation', 'censure', 'consideration', 'damnation', 'decision', 'decree'],
    'condemnatory': ['abusive', 'accusative', 'accusatory', 'accusing', 'blackening', 'blameful', 'censorious', 'contemptuous', 'damnatory', 'denunciatory', 'deprecative', 'deprecatory'],
    'condensation': ['abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'accelerando', 'acceleration', 'accretion', 'adherence', 'adhesion', 'agglomeration', 'agglutination'],
    'condense': ['abbreviate', 'abridge', 'abstract', 'accelerate', 'aggravate', 'be telegraphic', 'beef up', 'blow up', 'bob', 'boil down', 'brief', 'cake'],
    'condensed': ['spartan', 'abbreviated', 'abridged', 'abstracted', 'aposiopestic', 'bobbed', 'bobtail', 'bobtailed', 'brief', 'brusque', 'canned', 'capsule'],
    'condescend': ['ok', 'accede to', 'accept', 'accord to', 'agree to', 'approve', 'approve of', 'assent', 'be willing', 'bridle', 'connive at', 'consent'],
    'condescending': ['arrogant', 'belittling', 'big', 'contemptuous', 'disdainful', 'domineering', 'haughty', 'high-faluting', 'high-flown', 'high-handed', 'high-hat', 'high-headed'],
    'condescension': ['olympian detachment', 'olympian loftiness', 'arrogance', 'arrogantness', 'assumption of superiority', 'condescendence', 'deigning', 'domineering', 'domineeringness', 'haughtiness', 'haughty airs', 'hauteur'],
    'condign': ['according to hoyle', 'appropriate', 'atrocious', 'awful', 'becoming', 'correct', 'decent', 'decorous', 'deserved', 'dreadful', 'due', 'fair'],
    'condiment': ['tabasco', 'worcestershire sauce', 'allspice', 'anchovies', 'angelica', 'applesauce', 'basil', 'bell pepper', 'black pepper', 'borage', 'burnet', 'caper'],
    'condition': ['abate', 'ability', 'abnormality', 'acclimate', 'acclimatize', 'accommodate', 'accustom', 'acute disease', 'adapt', 'adjust', 'adjust to', 'affairs'],
    'conditional': ['a fortiori', 'a posteriori', 'a priori', 'acceptable', 'accidental', 'adventitious', 'aleatory', 'analytic', 'at issue', 'casual', 'categorical', 'circumstantial'],
    'conditioned': ['acclimated', 'acclimatized', 'accommodated', 'accustomed', 'adapted', 'adjusted', 'at issue', 'automatic', 'blind', 'bound', 'bounded', 'case-hardened'],
    'conditioning': ['pavlovian conditioning', 'absorption and regurgitation', 'acclimation', 'acclimatization', 'accommodation', 'accustoming', 'adaptation', 'adaption', 'addictive', 'adjustment', 'apprenticeship', 'automatic writing'],
    'condolence': ['aid and comfort', 'assurance', 'benevolence', 'clemency', 'comfort', 'commiseration', 'compassion', 'consolation', 'easement', 'encouragement', 'favor', 'feeling'],
    'condominium': ['apartment house', 'association', 'cochairmanship', 'complicity', 'contribution', 'cooperative apartment house', 'copartnership', 'copartnery', 'cotenancy', 'duplex', 'duplex house', 'engagement'],
    'condone': ['abide with', 'accept', 'allow for', 'be big', 'be content with', 'be easy with', 'bear', 'bear with', 'blink at', 'brook', 'connive at', 'countenance'],
    'condoned': ['absolved', 'acquitted', 'blotted', 'canceled', 'disregarded', 'exculpated', 'excused', 'exonerated', 'forgiven', 'forgotten', 'indulged', 'overlooked'],
    'conducive': ['agential', 'agentival', 'agentive', 'aidful', 'assisting', 'beneficial', 'conducive to', 'constructive', 'contributory', 'employable', 'facilitating', 'favoring'],
    'conduct': ['accomplish', 'accomplishment', 'achievement', 'acquit', 'act', 'action', 'actions', 'activity', 'acts', 'address', 'administer', 'administration'],
    'conductance': ['conduction', 'conductivity', 'conductor', 'dielectric', 'electric conduction', 'electrode conductance', 'gas conduction', 'grid conductance', 'input conductance', 'insulator', 'ionic conduction', 'liquid conduction'],
    'conduction': ['communication', 'conductance', 'conductivity', 'conductor', 'contagion', 'convection', 'delivery', 'deportation', 'diapedesis', 'dielectric', 'diffusion', 'dissemination'],
    'conductor': ['kapellmeister', 'mahdi', 'administrator', 'agent', 'baggage man', 'bakehead', 'band leader', 'band major', 'bandmaster', 'bell cow', 'bell mare', 'bellwether'],
    'conduit': ['access', 'adit', 'aisle', 'alley', 'ambulatory', 'aperture', 'aqueduct', 'arcade', 'artery', 'avenue', 'canal', 'channel'],
    'condyle': ['bilge', 'blain', 'bleb', 'blister', 'blob', 'boss', 'bow', 'bubble', 'bulb', 'bulge', 'bulla', 'bump'],
    'cone': ['acoustical network', 'ament', 'capacitor speaker', 'capitulum', 'catkin', 'coaxial speaker', 'complex cone', 'conelet', 'conoid', 'cop', 'cornet', 'corymb'],
    'confab': ['advise', 'audience', 'bargaining', 'bargaining session', 'bull session', 'chinfest', 'collogue', 'conclave', 'confabulate', 'confabulation', 'conference', 'confrontation'],
    'confection': ['jell-o', 'admixture', 'alloy', 'amalgam', 'blancmange', 'blend', 'brew', 'candy', 'combination', 'combo', 'comfit', 'commixture'],
    'confectionery': ['jell-o', 'antique store', 'apothecary', 'automobile showroom', 'blancmange', 'bookstore', 'bootery', 'candy', 'candy store', 'chemist', 'cigar store', 'clothiers'],
    'confederacy': ['anschluss', 'bund', 'rochdale cooperative', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alignment', 'alliance', 'amalgamation', 'anschluss'],
    'confederate': ['abettor', 'accessory', 'accompany', 'accomplice', 'accomplice in crime', 'act in concert', 'act together', 'adjunct', 'affiliate', 'affiliated', 'allied', 'ally'],
    'confederation': ['anschluss', 'bund', 'rochdale cooperative', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alignment', 'alliance', 'amalgamation', 'anschluss'],
    'confer': ['abalienate', 'accord', 'administer', 'advise', 'advise with', 'advocate', 'afford', 'alien', 'alienate', 'allot', 'allow', 'amortize'],
    'conference': ['british cabinet', 'council of nicaea', 'council of trent', 'lateran council', 'sanhedrin', 'us cabinet', 'vatican council', 'advisory body', 'airing', 'analysis', 'archbishopric', 'archdiocese'],
    'confess': ['absolve', 'accept', 'account for', 'accredit with', 'accrete to', 'acknowledge', 'administer absolution', 'administer extreme unction', 'admit', 'admit everything', 'affirm', 'agree provisionally'],
    'confessed': ['accepted', 'acknowledged', 'admitted', 'affirmed', 'allowed', 'approved', 'authenticated', 'avowed', 'certified', 'conceded', 'confirmed', 'countersigned'],
    'confession': ['abject apology', 'acceptance', 'acknowledgment', 'adherents', 'admission', 'agape', 'allowance', 'apology', 'appreciation', 'asperges', 'aspersion', 'auricular confession'],
    'confessional': ['easter sepulcher', 'admissive', 'ambry', 'apse', 'baptistery', 'blindstory', 'canonical', 'chancel', 'choir', 'cloisters', 'confessionary', 'creedal'],
    'confessions': ['clio', 'muse of history', 'adventures', 'annals', 'autobiography', 'biographical sketch', 'biography', 'case history', 'chronicle', 'chronicles', 'chronology', 'curriculum vitae'],
    'confetti': ['dalmatian', 'antigorite', 'butterfly', 'candy cane', 'chameleon', 'cheetah', 'chrysotile', 'crazy quilt', 'firedog', 'harlequin', 'iris', 'jaguar'],
    'confidant': ['dutch uncle', 'polonius', 'acquaintance', 'admonisher', 'adviser', 'advocate', 'alter ego', 'amigo', 'backer', 'backseat driver', 'best friend', 'bosom friend'],
    'confide': ['air', 'alert', 'aspire to', 'assign', 'bank on', 'bestow', 'break it to', 'break the news', 'breathe', 'buzz', 'come out with', 'commend'],
    'confide in': ['believe in', 'deem trustworthy', 'depend on', 'have confidence in', 'have faith in', 'hope in', 'place confidence in', 'place reliance in', 'put trust in', 'rely on', 'repose', 'repose confidence in'],
    'confidence': ['acceptation', 'acception', 'acquiescence', 'anticipation', 'aplomb', 'arcanum', 'arrogance', 'aspiration', 'assumption', 'assurance', 'assured faith', 'assuredness'],
    'confidence man': ['bunco artist', 'bunco steerer', 'cardsharp', 'cardsharper', 'carpetbagger', 'con artist', 'con man', 'crimp', 'defrauder', 'diddler', 'gyp', 'horse coper'],
    'confident': ['agape', 'agog', 'all agog', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'arrogant', 'aspiring', 'assured', 'awaiting', 'aweless'],
    'confidential': ['auricular', 'between us', 'chummy', 'classified', 'close', 'closet', 'esoteric', 'hush-hush', 'hushed', 'in petto', 'inside', 'intimate'],
    'confiding': ['artless', 'bluff', 'blunt', 'born yesterday', 'candid', 'childlike', 'credulous', 'dependent', 'depending', 'direct', 'frank', 'guileless'],
    'configuration': ['platonic form', 'platonic idea', 'aesthetic form', 'angle', 'archetype', 'aroma', 'art form', 'aspect', 'attribute', 'badge', 'brand', 'build'],
    'confine': ['arena', 'arrest', 'bar', 'bastille', 'be into', 'be strong in', 'block', 'border line', 'bottle up', 'bound', 'boundary', 'boundary condition'],
    'confined': ['angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'authoritative', 'barred', 'bedfast', 'bedridden', 'beleaguered', 'beset', 'besieged', 'blockaded'],
    'confinement': ['accouchement', 'beleaguerment', 'besetment', 'birth', 'birth throes', 'birthing', 'blessed event', 'blockade', 'blockading', 'boundary', 'bounds', 'childbearing'],
    'confines': ['airspace', 'approach', 'approximation', 'area', 'belt', 'boundaries', 'bounds', 'bourns', 'circumference', 'circumscription', 'closeness', 'compass'],
    'confirm': ['ok', 'accede', 'accept', 'acclimate', 'acclimatize', 'accommodate', 'accredit', 'accustom', 'acquiesce', 'adapt', 'addict', 'adjust'],
    'confirmation': ['john hancock', 'ok', 'acceptance', 'affirmance', 'affirmation', 'agape', 'approbation', 'approval', 'ascertainment', 'asperges', 'aspersion', 'assurance'],
    'confirmed': ['accepted', 'accustomed', 'acknowledged', 'actual', 'admitted', 'affirmed', 'allowed', 'approved', 'ascertained', 'attested', 'authenticated', 'avowed'],
    'confiscate': ['accroach', 'annex', 'appropriate', 'arrogate', 'attach', 'collectivize', 'commandeer', 'communalize', 'communize', 'distrain', 'expropriate', 'garnish'],
    'conflagrate': ['bank', 'burn', 'enkindle', 'fan the flame', 'feed', 'feed the fire', 'fire', 'ignite', 'inflame', 'kindle', 'light', 'light up'],
    'conflagration': ['backfire', 'balefire', 'beacon', 'beacon fire', 'blaze', 'bonfire', 'burning ghat', 'campfire', 'cheerful fire', 'combustion', 'corposant', 'cozy fire'],
    'conflict': ['discordia', 'eris', 'kilkenny cats', 'action', 'aerial combat', 'affray', 'agree to disagree', 'altercation', 'ambivalence', 'ambivalence of impulse', 'antagonism', 'antagonize'],
    'conflicting': ['acrid', 'adversary', 'adversative', 'adverse', 'adversive', 'ajar', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'antonymous'],
    'confluence': ['accompaniment', 'accordance', 'affluence', 'afflux', 'affluxion', 'agglomeration', 'agglutination', 'aggregation', 'agreement', 'alliance', 'approach', 'articulation'],
    'conform': ['abide by', 'accommodate', 'accommodate with', 'accord', 'act up to', 'adapt', 'adapt to', 'adhere to', 'adjust', 'adjust to', 'agree', 'agree in opinion'],
    'conformation': ['platonic form', 'platonic idea', 'accommodation', 'accord', 'accordance', 'acquiescence', 'adaptation', 'adaption', 'adjustment', 'aesthetic form', 'affinity', 'agreement'],
    'conformist': ['babbitt', 'grundy', 'middle american', 'philistine', 'anal character', 'ape', 'bourgeois', 'burgher', 'compulsive character', 'conformer', 'conventionalist', 'copier'],
    'conformity': ['accord', 'accordance', 'acquiescence', 'acquittal', 'acquittance', 'adherence', 'adoration', 'affinity', 'agreement', 'alikeness', 'allegiance', 'alliance'],
    'confound': ['abash', 'accurse', 'addle', 'adulterate', 'alloy', 'amaze', 'anathematize', 'answer', 'answer conclusively', 'appall', 'argue down', 'astonish'],
    'confounded': ['byzantine', 'absolute', 'addled', 'agape', 'aghast', 'agog', 'all agog', 'all up with', 'amazed', 'astonished', 'astounded', 'at a loss'],
    'confront': ['accost', 'advance', 'affront', 'alight upon', 'analogize', 'approach', 'appropinquate', 'approximate', 'assimilate', 'await', 'baffle', 'balance'],
    'confrontation': ['allegory', 'analogy', 'antagonism', 'anteposition', 'antipathy', 'antithesis', 'audience', 'balancing', 'bargaining', 'bargaining session', 'clashing', 'collision'],
    'confronting': ['adversative', 'adverse', 'adversive', 'antagonistic', 'anti', 'antipathetic', 'antipodal', 'antithetic', 'antonymous', 'at cross-purposes', 'balancing', 'clashing'],
    'confuse': ['abash', 'addle', 'addle the wits', 'agitate', 'baffle', 'ball up', 'becloud', 'bedazzle', 'befog', 'befuddle', 'bemuse', 'bewilder'],
    'confused': ['byzantine', 'abashed', 'abroad', 'adrift', 'afflicted', 'agitated', 'ajar', 'aleatoric', 'aleatory', 'ambiguous', 'amorphic', 'amorphous'],
    'confusion': ['abashment', 'agitation', 'aloofness', 'ambiguity', 'ambiguousness', 'amorphia', 'amorphism', 'amorphousness', 'anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism'],
    'confute': ['answer', 'answer conclusively', 'antagonize', 'argue down', 'be antipathetic', 'be inimical', 'beat against', 'break', 'clash', 'collide', 'conflict', 'conflict with'],
    'congeal': ['adhere', 'agglomerate', 'blast', 'blast-freeze', 'blight', 'bunch', 'cake', 'chill', 'clabber', 'clasp', 'cleave', 'clinch'],
    'congealed': ['blast-frozen', 'caked', 'cakey', 'clabbered', 'clotted', 'coagulated', 'curded', 'curdled', 'frostbitten', 'frostnipped', 'frozen', 'frozen solid'],
    'congenial': ['accordant', 'affable', 'affinitive', 'affirmative', 'agnate', 'agreeable', 'agreeing', 'akin', 'allied', 'amiable', 'amicable', 'answerable'],
    'congeniality': ['accord', 'accordance', 'affability', 'affinity', 'agape', 'agreeability', 'agreeableness', 'agreement', 'amenity', 'amiability', 'amiableness', 'amicability'],
    'congenital': ['absolute', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'atavistic', 'bodily', 'born', 'broad-based', 'clean', 'clear', 'coeval'],
    'congeries': ['anschluss', 'accumulation', 'acervation', 'addition', 'affiliation', 'agglomerate', 'agglomeration', 'agglutination', 'aggregate', 'aggregation', 'agreement', 'alliance'],
    'congest': ['bar', 'bind', 'block', 'block up', 'blockade', 'brim', 'bung', 'caulk', 'charge', 'chink', 'chock', 'choke'],
    'congested': ['sro', 'bloated', 'blocked', 'bound', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full', 'choked', 'choked up'],
    'congestion': ['amplitude', 'bar', 'barrier', 'blank wall', 'blind alley', 'blind gut', 'block', 'blockade', 'blockage', 'bottleneck', 'cecum', 'choking'],
    'conglomerate': ['aktiengesellschaft', 'aa', 'abyssal rock', 'accumulate', 'accumulated', 'accumulation', 'acervation', 'adhere', 'admix', 'agglomerate', 'agglomeration', 'aggregate'],
    'conglomeration': ['anschluss', 'accretion', 'accumulation', 'acervation', 'addition', 'adherence', 'adhesion', 'affiliation', 'agglomerate', 'agglomeration', 'agglutination', 'aggregate'],
    'congratulation': ['accolade', 'adulation', 'apotheosis', 'bepraisement', 'deification', 'eloge', 'encomium', 'eulogium', 'eulogy', 'exaltation', 'excessive praise', 'flattery'],
    'congregate': ['assemble', 'bunch', 'bunch up', 'clot', 'cluster', 'collect', 'come together', 'congress', 'converge', 'copulate', 'couple', 'crowd'],
    'congress': ['british cabinet', 'esp', 'sanhedrin', 'us cabinet', 'act of love', 'adultery', 'advisory body', 'answer', 'aphrodisia', 'approach', 'ass', 'assemble'],
    'congressional district': ['kreis', 'archbishopric', 'archdiocese', 'arrondissement', 'bailiwick', 'bishopric', 'borough', 'canton', 'city', 'close borough', 'commune', 'constablewick'],
    'congressman': ['mp', 'member of congress', 'member of parliament', 'alderman', 'assemblyman', 'chosen freeholder', 'city father', 'congresswoman', 'councilman', 'floor leader', 'lawgiver', 'lawmaker'],
    'congruence': ['accord', 'accordance', 'affinity', 'agreement', 'assent', 'chorus', 'coequality', 'coherence', 'coincidence', 'compatibility', 'concert', 'concord'],
    'congruent': ['accordant', 'affirmative', 'agreeable', 'agreeing', 'answerable', 'at one', 'coequal', 'coexistent', 'coexisting', 'coextensive', 'coherent', 'coincident'],
    'congruity': ['accommodation', 'accord', 'accordance', 'acquiescence', 'adaptation', 'adaption', 'adjustment', 'affinity', 'agreement', 'assent', 'balance', 'bilateral symmetry'],
    'congruous': ['accordant', 'advantageous', 'advisable', 'affirmative', 'agreeable', 'agreeing', 'answerable', 'appropriate', 'at one', 'becoming', 'befitting', 'coexistent'],
    'conjectural': ['abstract', 'academic', 'arguable', 'armchair', 'at issue', 'confutable', 'contestable', 'controversial', 'controvertible', 'debatable', 'deniable', 'disputable'],
    'conjecture': ['assume', 'assumption', 'axiom', 'believe', 'blind guess', 'bold conjecture', 'conceive', 'conclude', 'deem', 'estimate', 'expect', 'fancy'],
    'conjoint': ['accessory', 'accompanying', 'accordant', 'agreeing', 'amalgamated', 'assimilated', 'associate', 'associated', 'at one with', 'attendant', 'attending', 'blended'],
    'conjugal': ['adoring', 'affectionate', 'bridal', 'connubial', 'demonstrative', 'devoted', 'epithalamic', 'faithful', 'filial', 'fond', 'husbandly', 'hymeneal'],
    'conjugate': ['accouple', 'accumulate', 'affiliate', 'affiliated', 'agglutinate', 'allied', 'amalgamated', 'amass', 'analyze', 'articulate', 'assemble', 'assimilated'],
    'conjugation': ['anschluss', 'ic analysis', 'janus', 'abutment', 'abuttal', 'accidence', 'addition', 'adjacency', 'adjoiningness', 'affiliation', 'affix', 'affixation'],
    'conjunction': ['anschluss', 'abutment', 'abuttal', 'accompaniment', 'accordance', 'addition', 'adjacency', 'adjectival', 'adjective', 'adjoiningness', 'adverb', 'adverbial'],
    'conjuration': ['abracadabra', 'charm', 'conjurement', 'escamotage', 'evocation', 'exorcisation', 'exorcism', 'exsufflation', 'hanky-panky', 'hocus-pocus', 'hokey-pokey', 'incantation'],
    'conjure': ['adjure', 'appeal', 'appeal to', 'bamboozle', 'beg', 'beguile', 'beseech', 'betray', 'bid come', 'bluff', 'brace', 'cajole'],
    'conjure up': ['bid come', 'bring back', 'bring to mind', 'call', 'call away', 'call back', 'call for', 'call forth', 'call in', 'call out', 'call to mind', 'call together'],
    'conjurer': ['comus', 'faust', 'artist', 'artiste', 'belly dancer', 'burlesque queen', 'chorine', 'chorus boy', 'chorus girl', 'coryphee', 'dancer', 'dancing girl'],
    'conk': ['beak', 'beezer', 'belfry', 'cash in', 'check out', 'chump', 'croak', 'decease', 'defrauder', 'diddler', 'die', 'dome'],
    'conk out': ['be done for', 'be no more', 'break', 'break down', 'cave in', 'cease', 'collapse', 'come apart', 'come to naught', 'come to nothing', 'come unstuck', 'crumble'],
    'connate': ['affiliated', 'affinal', 'affinitive', 'agnate', 'akin', 'allied', 'atavistic', 'bodily', 'born', 'coeval', 'cognate', 'congeneric'],
    'connect': ['abut', 'abut on', 'account for', 'accouple', 'accredit with', 'accrete to', 'accumulate', 'acknowledge', 'add', 'adhere', 'adjoin', 'affect'],
    'connected': ['affiliate', 'affiliated', 'affinitive', 'agnate', 'akin', 'allied', 'articulated', 'assembled', 'associate', 'associated', 'banded together', 'bound'],
    'connecting': ['adjacent', 'adjoining', 'binding', 'bordering', 'coalescent', 'coalescing', 'combinative', 'combinatory', 'combining', 'communicating', 'conjunctival', 'conjunctive'],
    'connection': ['esp', 'indian file', 'abutment', 'abuttal', 'access', 'accord', 'accounting for', 'acquaintance', 'act of love', 'addition', 'adjacency', 'adjoiningness'],
    'connections': ['byzantine intrigues', 'agnate', 'ancestry', 'backstairs influence', 'blood', 'blood relation', 'blood relative', 'clansman', 'cognate', 'collateral', 'collateral relative', 'consanguinean'],
    'connivance': ['ok', 'acceptance', 'accord', 'acquiescence', 'affirmation', 'affirmative', 'affirmative voice', 'agreement', 'approbation', 'approval', 'artifice', 'assent'],
    'connive': ['accord', 'agree', 'angle', 'associate', 'be in cahoots', 'blink at', 'brew', 'cabal', 'coact', 'coadunate', 'cogitate', 'coincide'],
    'connive at': ['ok', 'accede to', 'accept', 'accord to', 'agree to', 'allow for', 'approve', 'approve of', 'assent', 'be blind to', 'be caught out', 'be inattentive'],
    'conniver': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'machiavellian', 'quisling', 'archtraitor', 'betrayer', 'cockatrice', 'coconspirator', 'conspirator', 'conspirer'],
    'conniving': ['byzantine', 'machiavellian', 'calculating', 'coacting', 'coactive', 'coadjutant', 'coadjuvant', 'coefficient', 'collaborative', 'collective', 'collectivist', 'collectivistic'],
    'connoisseur': ['admirable crichton', 'accumulator', 'adept', 'aesthete', 'aficionado', 'amateur', 'annotator', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'artisan', 'artist'],
    'connotation': ['affective meaning', 'allegory', 'allusion', 'arcane meaning', 'assumption', 'bearing', 'coloration', 'coloring', 'consequence', 'denotation', 'drift', 'effect'],
    'connotative': ['allegorical', 'associational', 'connotational', 'definable', 'demonstrative', 'denominative', 'denotational', 'denotative', 'designative', 'diagnostic', 'emblematic', 'evidential'],
    'connote': ['add up to', 'allegorize', 'allude to', 'approve', 'argue', 'assume', 'attest', 'be construed as', 'be indicative of', 'be significant of', 'be symptomatic of', 'bespeak'],
    'conquer': ['acquire', 'adopt', 'annex', 'appropriate', 'arrogate', 'assume', 'baffle', 'balk', 'bear down', 'beat', 'beat down', 'bend'],
    'conqueror': ['champ', 'champion', 'conquering hero', 'conquistador', 'defeater', 'easy winner', 'hero', 'master', 'pancratiast', 'runner-up', 'shoo-in', 'subduer'],
    'conquest': ['cadmean victory', 'ko', 'pyrrhic victory', 'waterloo', 'adoption', 'appropriation', 'arrogation', 'ascendancy', 'assumption', 'beating', 'captive', 'catch'],
    'consanguinity': ['affiliation', 'affinity', 'agnation', 'alliance', 'ancestry', 'apparentation', 'birth', 'blood', 'blood relationship', 'bloodline', 'branch', 'breed'],
    'conscience': ['anima', 'censor', 'coconscious', 'collective unconscious', 'compunction', 'conscientiousness', 'conscious self', 'death instinct', 'demur', 'ego', 'ego ideal', 'ego-id conflict'],
    'conscience stricken': ['ashamed', 'conscience-smitten', 'full of remorse', 'regretful', 'remorseful', 'repining', 'rueful', 'self-accusing', 'self-condemning', 'self-convicting', 'self-debasing', 'self-flagellating'],
    'conscientious': ['accurate', 'active', 'attentive', 'careful', 'cautious', 'censorious', 'choicy', 'choosy', 'circumspect', 'close', 'compliant', 'conforming'],
    'conscious': ['aboveground', 'advertent', 'advised', 'agog', 'aimed', 'aimed at', 'alert', 'alive', 'alive and kicking', 'alive to', 'all ears', 'all eyes'],
    'consciously': ['advisedly', 'by design', 'calculatedly', 'contemplatedly', 'deliberately', 'designedly', 'eruditely', 'in cold blood', 'intelligently', 'intentionally', 'knowingly', 'learnedly'],
    'consciousness': ['advertence', 'advertency', 'alertness', 'all-night vigil', 'apperception', 'appreciation', 'appreciativeness', 'assiduity', 'assiduousness', 'attention', 'attention span', 'attentiveness'],
    'conscript': ['beat the drums', 'boot', 'call to arms', 'call up', 'commandeer', 'conscribe', 'detach', 'detach for service', 'draft', 'drafted man', 'draftee', 'enlist'],
    'conscription': ['bugle call', 'call', 'call to arms', 'call-up', 'catchword', 'clarion', 'clarion call', 'compulsory military service', 'draft', 'draft call', 'drafting', 'enlistment'],
    'consecration': ['agnus dei', 'alleluia', 'anamnesis', 'blessing', 'canon', 'collect', 'communion', 'credo', 'dismissal', 'epistle', 'fraction', 'gloria'],
    'consecutive': ['after', 'attendant', 'cadet', 'catenary', 'connected', 'consistent', 'continuous', 'enlarging', 'ensuing', 'following', 'increasing', 'joined'],
    'consensus': ['acclamation', 'accord', 'accordance', 'agreement', 'agreement of all', 'chorus', 'common assent', 'common consent', 'concert', 'concord', 'concordance', 'concurrence'],
    'consent': ['ok', 'abide by', 'accede', 'accede to', 'accept', 'acceptance', 'accession', 'acclaim', 'acclamation', 'accord', 'accord to', 'accordance'],
    'consenting': ['abject', 'accepting', 'accordant', 'acquiescent', 'acquiescing', 'admissive', 'affirmative', 'agreeable', 'agreed', 'agreeing', 'alacritous', 'allowing'],
    'consequence': ['ps', 'parthian shot', 'accent', 'addendum', 'affective meaning', 'aftereffect', 'aftermath', 'afterthought', 'amour propre', 'appendix', 'ascendancy', 'authority'],
    'consequent': ['appendant', 'consequential', 'derivational', 'derivative', 'ensuing', 'final', 'following', 'intelligent', 'logical', 'next', 'posterior', 'postpositional'],
    'consequential': ['absolute', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'big', 'big-league', 'big-name', 'big-time', 'bigwig', 'bigwigged'],
    'consequently': ['according to circumstances', 'accordingly', 'and so', 'as a consequence', 'as a result', 'as it is', 'as matters stand', 'at that rate', 'because of that', 'because of this', 'equally', 'ergo'],
    'conservation': ['attention', 'care', 'cold storage', 'conservancy', 'conservationism', 'control', 'custody', 'dead storage', 'directing', 'dry storage', 'economy', 'environmental conservation'],
    'conservationist': ['audubon society', 'national wildlife service', 'sierra club', 'arboriculturist', 'conservatist', 'conservative', 'conservator', 'deliverer', 'diehard', 'fogy', 'forest ranger', 'forester'],
    'conservatism': ['abnegation', 'abstinence', 'backwardness', 'calm', 'calmness', 'conservativeness', 'constraint', 'continence', 'control', 'cool', 'dispassion', 'evenness'],
    'conservative': ['democrat', 'labourite', 'republican', 'tory', 'whig', 'heeler', 'loyalist', 'partisan', 'party faithful', 'party hack', 'party man', 'party member'],
    'conservatory': ['academy of music', 'acting school', 'alcove', 'arbor', 'archives', 'armory', 'arsenal', 'art school', 'attic', 'bank', 'basement', 'bay'],
    'conserve': ['jell-o', 'attend to', 'baby-sit', 'blancmange', 'candy', 'care for', 'chaperon', 'cherish', 'comfit', 'compote', 'confection', 'confectionery'],
    'consider': ['account', 'account as', 'adjudge', 'adjudicate', 'admit', 'admit exceptions', 'air', 'allow', 'allow for', 'analyze', 'assume', 'be abstracted'],
    'considerable': ['able', 'absolute', 'active', 'appreciable', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'big', 'big-league', 'big-name'],
    'considerably': ['a deal', 'a great deal', 'a lot', 'abundantly', 'as all creation', 'as all get-out', 'beaucoup', 'considerable', 'ever so', 'ever so much', 'far', 'galore'],
    'considerate': ['accommodating', 'accommodative', 'affable', 'agreeable', 'amiable', 'attentive', 'benevolent', 'big', 'calculating', 'careful', 'cautious', 'charitable'],
    'consideration': ['tlc', 'trinkgeld', 'accent', 'accommodatingness', 'account', 'action', 'admiration', 'adoration', 'advertence', 'advertency', 'advisement', 'agreeableness'],
    'considered': ['advised', 'aforethought', 'aimed', 'aimed at', 'calculated', 'conscious', 'contemplated', 'deliberate', 'deliberated', 'designed', 'envisaged', 'envisioned'],
    'considering': ['after', 'all in all', 'as', 'as long as', 'because of', 'being', 'by reason of', 'by virtue of', 'cause', 'due to', 'for', 'in consideration of'],
    'consign': ['abalienate', 'accredit', 'address', 'air-express', 'airfreight', 'airmail', 'alien', 'alienate', 'amortize', 'assign', 'authorize', 'barter'],
    'consignee': ['federal', 'accepter', 'acquirer', 'addressee', 'agent', 'amanuensis', 'audience', 'auditor', 'baggage agent', 'beholder', 'business agent', 'claim agent'],
    'consignment': ['abalienation', 'agency', 'agentship', 'alienation', 'amortization', 'amortizement', 'assignation', 'assignment', 'authority', 'authorization', 'baggage', 'bargain and sale'],
    'consist': ['abide', 'accord', 'be', 'comport', 'conform', 'consort', 'correspond', 'dovetail', 'dwell', 'exist', 'fit in', 'gee'],
    'consist of': ['assemble', 'build', 'build up', 'combine', 'compose', 'constitute', 'construct', 'embody', 'enter into', 'fabricate', 'form', 'go into'],
    'consistency': ['accommodation', 'accord', 'accordance', 'acquiescence', 'adaptation', 'adaption', 'adhesiveness', 'adjustment', 'affinity', 'agreement', 'apposition', 'aptness'],
    'consistent': ['accordant', 'affirmative', 'agreeable', 'agreeing', 'alike', 'answerable', 'at one', 'authoritative', 'automatic', 'balanced', 'binding', 'clean-cut'],
    'consistent with': ['accommodated to', 'according to', 'adapted to', 'adjusted to', 'after', 'agreeable to', 'agreeably to', 'answerable to', 'by', 'conformable to', 'congruent with', 'in accordance with'],
    'consolation': ['aid and comfort', 'assurance', 'balm', 'comfort', 'commiseration', 'condolement', 'condolence', 'easement', 'encouragement', 'reassurance', 'relief', 'sharing of grief'],
    'console': ['animate', 'assuage', 'assure', 'bear up', 'buck up', 'cabinet', 'calm', 'chassis', 'cheer', 'cheer up', 'choir', 'claviature'],
    'consolidate': ['abbreviate', 'accelerate', 'act in concert', 'act together', 'add', 'affiliate', 'aggravate', 'ally', 'amalgamate', 'assimilate', 'associate', 'band'],
    'consolidated': ['amalgamated', 'assimilated', 'blended', 'clamped', 'close', 'close-knit', 'close-textured', 'close-woven', 'combinative', 'combinatory', 'combined', 'compact'],
    'consolidation': ['anschluss', 'abbreviation', 'accelerando', 'acceleration', 'accretion', 'addition', 'adherence', 'adhesion', 'affiliation', 'agglomeration', 'agglutination', 'aggravation'],
    'consomme': ['bisque', 'borscht', 'bouillabaisse', 'bouillon', 'broth', 'burgoo', 'chicken soup', 'chowder', 'clam chowder', 'clear soup', 'egg drop soup', 'fish soup'],
    'consonance': ['accord', 'accordance', 'affinity', 'agreement', 'alliteration', 'assent', 'assonance', 'attune', 'attunement', 'blank verse', 'calm', 'chime'],
    'consonant': ['accented', 'accordant', 'according', 'affirmative', 'agreeable', 'agreeing', 'alike', 'allophone', 'alveolar', 'answerable', 'apical', 'apico-alveolar'],
    'consort': ['accompanier', 'accompanist', 'accompanyist', 'accord', 'accordance', 'ace', 'adjunct', 'affinity', 'agreement', 'ally', 'amigo', 'assent'],
    'consort with': ['accompany', 'associate', 'associate with', 'assort with', 'attend', 'band together', 'bear', 'bring', 'carry', 'chaperon', 'chum', 'chum together'],
    'consortium': ['aktiengesellschaft', 'accord', 'agreement', 'aktiebolag', 'arrangement', 'bargain', 'binding agreement', 'body corporate', 'bond', 'business', 'business establishment', 'cartel'],
    'conspectus': ['abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'apocope', 'breviary', 'brief', 'capsule', 'compend', 'compression', 'condensation'],
    'conspicuous': ['appalling', 'apparent', 'arrant', 'arresting', 'astonishing', 'awe-inspiring', 'awesome', 'blatant', 'bold', 'celebrated', 'clean-cut', 'clear'],
    'conspicuous consumption': ['carpe diem', 'dissipation', 'extravagance', 'incontinence', 'intemperance', 'lavishness', 'leaking purse', 'loose purse strings', 'overgenerosity', 'overgenerousness', 'overliberality', 'pound-foolishness'],
    'conspicuously': ['abundantly', 'acutely', 'amazingly', 'amply', 'apparently', 'arrantly', 'astonishingly', 'awesomely', 'blatantly', 'boldly', 'celebratedly', 'clearly'],
    'conspiracy': ['anschluss', 'accompaniment', 'accordance', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'amalgamation', 'art', 'artful dodge'],
    'conspirator': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'machiavellian', 'quisling', 'abettor', 'accessory', 'accomplice', 'archtraitor', 'betrayer', 'cockatrice'],
    'conspire': ['accord', 'act in concert', 'act together', 'affiliate', 'agree', 'ally', 'amalgamate', 'angle', 'associate', 'band', 'band together', 'be in cahoots'],
    'constable': ['g-man', 'john law', 'mp', 'bailiff', 'beadle', 'beagle', 'bobby', 'bound bailiff', 'bull', 'captain', 'catchpole', 'chief of police'],
    'constabulary': ['cheka', 'fbi', 'gestapo', 'interpol', 'mp', 'mvd', 'mounties', 'nkvd', 'ogpu', 'rcmp', 'sp', 'scotland yard'],
    'constancy': ['abidingness', 'accordance', 'adherence', 'adhesion', 'age', 'allegiance', 'antiquity', 'aplomb', 'application', 'assiduity', 'assiduousness', 'attachment'],
    'constant': ['abiding', 'accordant', 'active', 'age-long', 'aged', 'ageless', 'alike', 'ancient', 'antique', 'ardent', 'articulated', 'assiduous'],
    'constantly': ['ad infinitum', 'again and again', 'always', 'at a stretch', 'at all times', 'at every turn', 'at regular intervals', 'at stated times', 'bona fide', 'ceaselessly', 'connectedly', 'consistently'],
    'constellation': ['antlia', 'antlia pneumatica', 'apus', 'aquarius', 'ara', 'big dipper', 'caela sculptoris', 'caelum', 'camelopardus', 'cancer', 'columba noae', 'corona australis'],
    'consternation': ['abject fear', 'affright', 'alarm', 'awe', 'bewilderment', 'blue funk', 'confusion', 'cowardice', 'dismay', 'distraction', 'dread', 'fear'],
    'constipated': ['blocked', 'bound', 'choked', 'choked up', 'clogged', 'clogged up', 'congested', 'costive', 'foul', 'fouled', 'full', 'infarcted'],
    'constipation': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'bar'],
    'constituency': ['affiliates', 'ambit', 'associates', 'bailiwick', 'body of affiliates', 'citizenry', 'commonwealth', 'community', 'constituents', 'cultural community', 'dwellers', 'electoral college'],
    'constituent': ['ab ovo', 'adjunct', 'adoptive', 'air', 'appointive', 'appurtenance', 'aspect', 'atom', 'atomic particles', 'basal', 'basic', 'brute matter'],
    'constitute': ['assemble', 'authorize', 'build', 'build up', 'combine', 'complement', 'complete', 'compose', 'comprise', 'consist of', 'construct', 'create'],
    'constitution': ['bill of rights', 'act', 'allocation', 'allotment', 'anatomy', 'animus', 'apportionment', 'aptitude', 'architectonics', 'architecture', 'arrangement', 'array'],
    'constitutional': ['absolute', 'actionable', 'affective', 'airing', 'amble', 'ambulation', 'applicable', 'aristocratic', 'atavistic', 'athletics', 'authoritarian', 'authorized'],
    'constrain': ['abate', 'abridge', 'abstain', 'aggrieve', 'allay', 'alleviate', 'arrest', 'assuage', 'attemper', 'ban', 'bank the fire', 'bar'],
    'constrained': ['olympian', 'aloof', 'arrested', 'backward', 'bashful', 'blank', 'bridled', 'chastened', 'chilled', 'chilly', 'cold', 'controlled'],
    'constraint': ['abnegation', 'abstinence', 'aloofness', 'aplomb', 'arrest', 'arrestation', 'backwardness', 'bashfulness', 'blankness', 'caging', 'calm', 'calmness'],
    'constrict': ['abbreviate', 'bang', 'bar', 'barricade', 'batten', 'batten down', 'block', 'block up', 'blockade', 'bolt', 'button', 'button up'],
    'constricted': ['angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'authoritarian', 'bigot', 'bigoted', 'blank', 'blind', 'blind-alley', 'borne', 'cecal'],
    'constriction': ['abbreviation', 'arrest', 'arrestation', 'arrestment', 'astriction', 'astringency', 'blockage', 'blocking', 'bottleneck', 'cervix', 'check', 'circumscription'],
    'construct': ['architecture', 'assemble', 'build', 'build up', 'building', 'cast', 'combine', 'compose', 'compound', 'concoct', 'consist of', 'constitute'],
    'construction': ['acronym', 'acrostic', 'adjectival phrase', 'anatomy', 'architectonics', 'architecture', 'arrangement', 'assemblage', 'assembly', 'avyayibhava', 'back formation', 'build'],
    'constructive': ['advantageous', 'aidful', 'beneficial', 'causative', 'conducive', 'construable', 'constructional', 'contributory', 'creative', 'deduced', 'definitional', 'demiurgic'],
    'construe': ['english', 'define', 'describe', 'diagnose', 'explicate', 'expound', 'interpret', 'read', 'read into', 'render', 'spell out', 'take'],
    'consul': ['ambassador', 'ambassadress', 'apostolic delegate', 'attache', 'career diplomat', 'chancellor', 'charge', 'commercial attache', 'consul general', 'consular agent', 'diplomat', 'diplomatic'],
    'consulate': ['dymaxion house', 'white house', 'adobe house', 'aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'bishopric', 'booking office', 'box office', 'branch'],
    'consult': ['go', 'advise', 'advise with', 'bargain', 'blow', 'call in', 'cast away', 'cogitate', 'collogue', 'compare notes', 'confab', 'confabulate'],
    'consultant': ['admirable crichton', 'dutch uncle', 'polonius', 'adept', 'admonisher', 'adviser', 'advisor', 'artisan', 'artist', 'attache', 'authority', 'backseat driver'],
    'consultation': ['admonition', 'advice', 'advising', 'advocacy', 'audience', 'bargaining', 'bargaining session', 'briefing', 'caution', 'caveat', 'conclave', 'confab'],
    'consume': ['sanforize', 'abate', 'ablate', 'absorb', 'annihilate', 'assimilate', 'atomize', 'atrophy', 'attenuate', 'bate', 'be eaten away', 'bestow'],
    'consumed': ['sanforized', 'abated', 'ablated', 'adust', 'ashen', 'ashy', 'attenuated', 'bated', 'belittled', 'blistered', 'burned', 'burnt'],
    'consumer': ['brillat-savarin', 'lucullus', 'board-and-roomer', 'boarder', 'bon vivant', 'browser', 'buyer', 'cannibal', 'carnivore', 'connoisseur of food', 'customer agent', 'diner'],
    'consumerism': ['buy', 'buying', 'buying power', 'buying up', 'catalog buying', 'coemption', 'consumer power', 'consumer sovereignty', 'cornering', 'emption', 'hire purchase', 'impulse buying'],
    'consuming': ['absorbing', 'agonizing', 'arresting', 'attractive', 'baneful', 'calamitous', 'cataclysmal', 'cataclysmic', 'catastrophic', 'consumptive', 'deadly', 'demolishing'],
    'consummate': ['able', 'absolute', 'accomplish', 'accomplished', 'achieve', 'acmatic', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'apical', 'archetypical'],
    'consummation': ['accomplished fact', 'accomplishing', 'accomplishment', 'achievement', 'achieving', 'acme', 'acme of perfection', 'apodosis', 'attaining', 'attainment', 'bitter end', 'carrying out'],
    'consumption': ['sanforizing', 'tb', 'ablation', 'active use', 'aerogenic tuberculosis', 'appetite', 'appliance', 'application', 'atrophy', 'attenuation', 'attrition', 'bloodbath'],
    'consumptive': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'astringent', 'baneful', 'bilious', 'calamitous', 'cancerous', 'case', 'cataclysmal', 'cataclysmic'],
    'contact': ['esp', 'accord', 'acquaintance', 'answer', 'approach', 'arbitrator', 'assail the ear', 'association', 'attouchement', 'be heard', 'breath', 'broker'],
    'contact lens': ['polaroid glasses', 'bifocals', 'blinkers', 'cheaters', 'colored glasses', 'dark glasses', 'divided spectacles', 'eyeglass', 'eyeglasses', 'glasses', 'goggles', 'granny glasses'],
    'contagious': ['assignable', 'catching', 'communicable', 'conductive', 'consignable', 'conveyable', 'deadly', 'destructive', 'endemic', 'envenomed', 'epidemial', 'epidemic'],
    'contain': ['accommodate', 'add up to', 'admit', 'affect', 'aggregate', 'aggregate to', 'amount to', 'arrest', 'assimilate', 'assume', 'bang', 'bar'],
    'container': ['arena', 'cincture', 'close', 'confine', 'coop', 'court', 'courtyard', 'curtilage', 'delimited field', 'enclave', 'enclosure', 'field'],
    'containment': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'appeasement', 'balance of power', 'brinkmanship', 'cincture', 'circling', 'circumambience', 'circumambiency', 'circumcincture'],
    'contaminate': ['activate', 'adulterate', 'alloy', 'bastardize', 'befoul', 'benasty', 'canker', 'charge', 'cheapen', 'coarsen', 'confound', 'corrupt'],
    'contaminated': ['abandoned', 'activated', 'autoluminescent', 'bad', 'bad for', 'cankered', 'charged', 'corrupt', 'corrupted', 'debased', 'debauched', 'decadent'],
    'contemn': ['abhor', 'abjure', 'be above', 'be contemptuous of', 'brush aside', 'care nothing for', 'chuck', 'chuck out', 'contradict', 'decline', 'deny', 'deride'],
    'contemplate': ['aim', 'anticipate', 'be abstracted', 'bear in mind', 'behold', 'bone', 'brood', 'brood over', 'chew over', 'chew the cud', 'con', 'consider'],
    'contemplation': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'a wise passiveness', 'absorbed attention', 'absorption', 'advisement', 'aid prayer', 'anticipation'],
    'contemporaneous': ['accompanying', 'actual', 'agreeing', 'as is', 'being', 'coetaneous', 'coeternal', 'coeval', 'coexistent', 'coexisting', 'coinstantaneous', 'collateral'],
    'contemporary': ['a la mode', 'abreast', 'accompanying', 'actual', 'advanced', 'agreeing', 'as is', 'associated', 'attendant', 'attending', 'au courant', 'avant-garde'],
    'contempt': ['abhorrence', 'abjuration', 'abjurement', 'affront', 'antipathy', 'arrogance', 'aspersion', 'atrocity', 'audacity', 'aversion', 'bold front', 'boldness'],
    'contemptible': ['abhorrent', 'abject', 'abominable', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beggarly', 'below contempt', 'beneath contempt'],
    'contemptuous': ['abjuratory', 'abusive', 'arrogant', 'audacious', 'back-biting', 'belittling', 'biggety', 'bitchy', 'blackening', 'blameful', 'bluff', 'bold'],
    'contend': ['affirm', 'agonize', 'allege', 'announce', 'annunciate', 'antagonize', 'argue', 'argufy', 'assert', 'assever', 'asseverate', 'aver'],
    'contend for': ['advocate', 'allege in support', 'answer', 'argue for', 'assert', 'bid for', 'champion', 'counter', 'defend', 'espouse', 'fight for', 'maintain'],
    'contend with': ['a outrance', 'bandy with', 'battle', 'battle it out', 'bump heads', 'care for', 'challenge', 'complain', 'complain loudly', 'confront', 'cope with', 'cross swords with'],
    'contender': ['battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'combatant', 'competitor', 'contestant'],
    'content': ['acceptance', 'accepting', 'accommodation', 'accordant', 'achieve inner harmony', 'acquiescent', 'acquiescing', 'affirmative', 'agreeable', 'agreed', 'agreeing', 'alacritous'],
    'contention': ['discordia', 'eris', 'altercation', 'antagonism', 'anteposition', 'antipathy', 'antithesis', 'apologetics', 'apologia', 'apology', 'argument', 'argumentation'],
    'contentious': ['aggravating', 'aggravative', 'aggressive', 'annoying', 'antagonistic', 'argumental', 'argumentative', 'battling', 'bellicose', 'belligerent', 'bloodthirsty', 'bloody'],
    'contents': ['acknowledgments', 'adjunct', 'appurtenance', 'aspect', 'back', 'back matter', 'bastard title', 'bibliography', 'card index', 'catch line', 'catchword', 'chart'],
    'conterminous': ['accompanying', 'adjacent', 'adjoining', 'agreeing', 'bordering', 'buck', 'coetaneous', 'coeternal', 'coeval', 'coexistent', 'coexisting', 'coinstantaneous'],
    'contest': ['kilkenny cats', 'olympic games', 'olympics', 'abjure', 'action', 'altercation', 'antagonize', 'argue', 'argufy', 'argument', 'assert the contrary', 'awake a doubt'],
    'contestant': ['adversary', 'battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'carouser', 'combatant'],
    'context': ['alentours', 'ambiance', 'ambience', 'ambit', 'background', 'borderlands', 'circle', 'circuit', 'circumambiencies', 'circumjacencies', 'circumstances', 'compass'],
    'contiguity': ['abutment', 'abuttal', 'accord', 'addition', 'adjacency', 'adjoiningness', 'adjunct', 'affairs', 'affiliation', 'affinity', 'alliance', 'apposition'],
    'contiguous': ['abutting', 'adjacent', 'adjoining', 'bordering', 'close', 'close-by', 'connecting', 'conterminous', 'coterminous', 'end to end', 'endways', 'endwise'],
    'continence': ['encratism', 'friday', 'lenten fare', 'platonic love', 'pythagoreanism', 'pythagorism', 'rechabitism', 'shakerism', 'spartan fare', 'stoicism', 'abnegation', 'abstainment'],
    'continent': ['africa', 'america', 'antipodes', 'apostolic', 'asia', 'asia major', 'asia minor', 'australasia', 'east', 'eastern hemisphere', 'encratic', 'eurasia'],
    'contingency': ['accessory', 'accident', 'accidental', 'addendum', 'addition', 'adjunct', 'adventure', 'appendage', 'appurtenance', 'aptitude', 'aptness', 'auxiliary'],
    'contingent': ['accessory', 'accident', 'accidental', 'addendum', 'addition', 'additional', 'adjunct', 'adscititious', 'adventitious', 'adventure', 'age group', 'aleatory'],
    'contingent on': ['arising from', 'attributable to', 'based on', 'boxed in', 'caused by', 'circumscribed by', 'coming from', 'contingent', 'dependent', 'dependent on', 'depending', 'depending on'],
    'continual': ['ageless', 'articulated', 'catenated', 'ceaseless', 'chattering', 'coeternal', 'concatenated', 'connected', 'constant', 'continued', 'continuing', 'continuous'],
    'continually': ['ad infinitum', 'again and again', 'always', 'at a stretch', 'at all times', 'at every turn', 'ceaselessly', 'connectedly', 'consecutively', 'constantly', 'continuously', 'cumulatively'],
    'continuance': ['ps', 'parthian shot', 'abidingness', 'addendum', 'afterthought', 'age', 'antiquity', 'appendix', 'back matter', 'ceaselessness', 'chorus', 'coda'],
    'continuation': ['ps', 'parthian shot', 'accession', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum'],
    'continue': ['abide', 'adjourn', 'advance', 'be continuous', 'be prolonged', 'bide', 'carry on', 'carry over', 'carry through', 'catenate', 'cease not', 'chain'],
    'continuing': ['abiding', 'age-long', 'aged', 'ancient', 'antique', 'articulated', 'assiduous', 'catenated', 'ceaseless', 'changeless', 'chronic', 'concatenated'],
    'continuity': ['accordance', 'action', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'argument', 'atmosphere', 'background', 'book', 'calm', 'catastrophe'],
    'continuous': ['abiding', 'accordant', 'ageless', 'alike', 'articulated', 'automatic', 'balanced', 'catenated', 'ceaseless', 'chronological', 'coeternal', 'concatenated'],
    'continuum': ['indian file', 'acreage', 'area', 'array', 'articulation', 'bank', 'breadth', 'buzz', 'catena', 'catenation', 'chain', 'chain reaction'],
    'contort': ['bend', 'buckle', 'corkscrew', 'crinkle', 'crook', 'crumple', 'curve', 'distort', 'garble', 'get one wrong', 'get wrong', 'gloss'],
    'contortion': ['anamorphism', 'anamorphosis', 'asymmetry', 'buckle', 'crookedness', 'detorsion', 'deviation', 'disproportion', 'distortion', 'gnarl', 'imbalance', 'irregularity'],
    'contour': ['broad lines', 'configuration', 'delineate', 'delineation', 'features', 'figuration', 'figure', 'framework', 'galbe', 'gestalt', 'limn', 'line'],
    'contra': ['a rebours', 'adverse to', 'against', 'against the grain', 'against the tide', 'against the wind', 'antipode', 'antipodes', 'antipole', 'antithesis', 'antonym', 'arsy-varsy'],
    'contraband': ['eighteenth amendment', 'prohibition party', 'volstead act', 'actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'ban', 'banned', 'barred', 'black-market'],
    'contraception': ['aridity', 'barrenness', 'birth control', 'dearth', 'dry womb', 'dryness', 'family planning', 'famine', 'impotence', 'ineffectualness', 'infecundity', 'infertility'],
    'contraceptive': ['iud', 'aegis', 'arm guard', 'backstop', 'bag', 'birth control device', 'buffer', 'bulwark', 'bumper', 'condom', 'contraceptive foam', 'copyright'],
    'contract': ['od', 'abbreviate', 'abridge', 'abstract', 'accept obligation', 'accord', 'acquire', 'affair', 'affiance', 'afflict', 'agree', 'agree to'],
    'contracted': ['spartan', 'abated', 'abbreviated', 'ablated', 'abridged', 'affianced', 'agreed', 'aposiopestic', 'arranged', 'assured', 'attenuated', 'bated'],
    'contraction': ['speedwriting', 'abatement', 'abbreviation', 'abridgment', 'alleviation', 'apocope', 'aposiopesis', 'attenuation', 'brachygraphy', 'clipping', 'coarctation', 'constriction'],
    'contradict': ['abjure', 'abrogate', 'agree to disagree', 'annul', 'answer', 'answer conclusively', 'antagonize', 'argue down', 'assert the contrary', 'be antipathetic', 'be at cross-purposes', 'be contrary to'],
    'contradiction': ['abjuration', 'abjurement', 'abrogation', 'absolute contradiction', 'annulment', 'answer', 'antagonism', 'antipathy', 'antithesis', 'argumentation', 'backlash', 'bucking'],
    'contradictory': ['abjuratory', 'abnegative', 'absonant', 'adversary', 'adversative', 'adverse', 'adversive', 'alien', 'ambiguous', 'ambivalent', 'antagonistic', 'anti'],
    'contradistinction': ['antagonism', 'antipathy', 'antithesis', 'clashing', 'collision', 'con', 'conflict', 'confrontation', 'contradiction', 'contraindication', 'contraposition', 'contrariety'],
    'contraindication': ['antagonism', 'antipathy', 'antithesis', 'clashing', 'collision', 'conflict', 'confrontation', 'contradiction', 'contradistinction', 'contraposition', 'contrariety', 'contrast'],
    'contralto': ['heldentenor', 'meistersinger', 'accompaniment', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso continuo'],
    'contraposition': ['antagonism', 'antipathy', 'antithesis', 'backlash', 'bucking', 'challenge', 'clashing', 'collision', 'con', 'conflict', 'confrontation', 'confutation'],
    'contraption': ['apparatus', 'contrivance', 'device', 'gadget', 'gimcrack', 'gimmick', 'gizmo', 'hand tool', 'implement', 'instrument', 'means', 'mechanical device'],
    'contrariety': ['abominability', 'accord', 'addition', 'adjunct', 'affairs', 'affiliation', 'affinity', 'alliance', 'antagonism', 'anteposition', 'antipathy', 'antithesis'],
    'contrary': ['abjuratory', 'abnegative', 'adversary', 'adversative', 'adverse', 'adversive', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antipodal', 'antipode'],
    'contrast': ['allegory', 'analogize', 'analogy', 'antagonism', 'anteposition', 'antipathy', 'antithesis', 'arc lighting', 'assimilate', 'bad copy', 'bad likeness', 'balance'],
    'contrast with': ['be at cross-purposes', 'be distinct', 'be distinguished', 'be opposed to', 'clash', 'clash with', 'conflict', 'conflict with', 'contradict', 'contrapose', 'contravene', 'controvert'],
    'contravallation': ['abatis', 'advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'bastion', 'battlement'],
    'contravene': ['abjure', 'breach', 'break', 'combat', 'contradict', 'cross', 'disaffirm', 'disclaim', 'disown', 'encroach', 'exclude', 'fight'],
    'contribute': ['accommodate', 'add to', 'advance', 'afford', 'aid', 'assist', 'augment', 'be enfranchised', 'be implicated in', 'bear a hand', 'bend to', 'bestow'],
    'contribute to': ['advance', 'advantage', 'boost', 'chip in', 'conduce to', 'contribute', 'decide', 'determine', 'donate to', 'encourage', 'expedite', 'facilitate'],
    'contribution': ['accommodation', 'accordance', 'alms', 'alms fee', 'assessment', 'association', 'award', 'awarding', 'benefaction', 'beneficence', 'bestowal', 'bestowment'],
    'contributor': ['maecenas', 'santa claus', 'almoner', 'almsgiver', 'angel', 'assignor', 'awarder', 'backer', 'bestower', 'cheerful giver', 'conferrer', 'consignor'],
    'contributory': ['accessory', 'additional', 'adjuvant', 'aidful', 'ancillary', 'another', 'appurtenant', 'auxiliary', 'beneficial', 'collateral', 'concessive', 'conducive'],
    'contrition': ['abject apology', 'acknowledgment', 'apologies', 'apology', 'attrition', 'ayenbite of inwit', 'bitterness', 'breast-beating', 'compunction', 'confession', 'contriteness', 'excuse'],
    'contrivance': ['charlie mccarthy', 'action', 'ad hoc measure', 'agent', 'anagnorisis', 'ancilla', 'angle', 'answer', 'apparatus', 'appliance', 'approach', 'architectonics'],
    'contrive': ['angle', 'arrange', 'be so', 'be such', 'beget', 'breed', 'bring', 'bring forth', 'bring into being', 'bring on', 'calculate', 'call forth'],
    'control': ['masan', 'r and d', 'abate', 'ability', 'abnegation', 'absolutism', 'abstinence', 'acme', 'action', 'address', 'adeptness', 'administration'],
    'controller': ['big brother', 'ca', 'cpa', 'accountant', 'accountant general', 'actuary', 'auditor', 'bank accountant', 'bank examiner', 'boatswain', 'bookkeeper', 'boss'],
    'controlling': ['absolute', 'all-absorbing', 'ascendant', 'at the head', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'boss', 'capital', 'cardinal', 'chief'],
    'controversial': ['arguable', 'argumental', 'argumentative', 'at issue', 'belligerent', 'cat-and-dog', 'cat-and-doggish', 'combative', 'confutable', 'conjectural', 'contentious', 'contestable'],
    'controversy': ['kilkenny cats', 'altercation', 'antagonism', 'apologetics', 'apologia', 'apology', 'argument', 'argumentation', 'bicker', 'bickering', 'blood feud', 'brawl'],
    'controvert': ['abjure', 'air', 'analyze', 'answer', 'answer conclusively', 'argue down', 'assert the contrary', 'be at cross-purposes', 'be contrary to', 'be opposed to', 'belie', 'break'],
    'contumacious': ['alienated', 'beyond control', 'breachy', 'contrary', 'defiant', 'disaffected', 'estranged', 'factious', 'fractious', 'froward', 'impatient of control', 'incorrigible'],
    'contumelious': ['rabelaisian', 'abusive', 'arrogant', 'atrocious', 'audacious', 'back-biting', 'backhand', 'backhanded', 'belittling', 'bitchy', 'blasphemous', 'bold'],
    'contumely': ['abuse', 'affront', 'airs', 'animadversion', 'arrogance', 'aspersion', 'assailing', 'assault', 'assurance', 'atrocity', 'attack', 'audacity'],
    'convalescent home': ['va hospital', 'asylum', 'base hospital', 'clinic', 'community hospital', 'convalescent hospital', 'evacuation hospital', 'field hospital', 'general hospital', 'home', 'hospital', 'infirmary'],
    'convection': ['communication', 'conduction', 'contagion', 'delivery', 'deportation', 'diapedesis', 'diffusion', 'dissemination', 'export', 'exportation', 'expulsion', 'extradition'],
    'convene': ['assemble', 'bid come', 'call', 'call away', 'call back', 'call for', 'call forth', 'call in', 'call out', 'call together', 'call up', 'cite'],
    'convenience': ['wc', 'accommodate', 'accommodation', 'adaptability', 'advantage', 'advantageousness', 'advisability', 'amenity', 'appliance', 'appropriateness', 'appurtenance', 'auspiciousness'],
    'conveniences': ['accouterments', 'amenities', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'cakes and ale', 'comforts', 'creature comforts', 'duffel', 'equipage'],
    'convenient': ['accessible', 'adaptable', 'adjacent', 'advantageous', 'advisable', 'all-around', 'appropriate', 'at hand', 'auspicious', 'available', 'becoming', 'befitting'],
    'convention': ['council of nicaea', 'council of trent', 'lateran council', 'nato', 'seato', 'vatican council', 'accord', 'agreement', 'alliance', 'amenities', 'arrangement', 'assemblee'],
    'conventional': ['christian', 'accepted', 'accordant', 'accustomed', 'acknowledged', 'admitted', 'agreed', 'anal', 'approved', 'authentic', 'authoritative', 'average'],
    'converge': ['adhere', 'approach', 'assemble', 'blend', 'bring into focus', 'bunch', 'bunch up', 'center', 'centralize', 'clinch', 'close', 'close in'],
    'conversant': ['abreast', 'accomplished', 'acquainted', 'acquainted with', 'alive', 'apprehending', 'apprehensive', 'at concert pitch', 'at home in', 'at home with', 'au courant', 'au fait'],
    'conversation': ['esp', 'accents', 'answer', 'chat', 'chatter', 'collegiality', 'colloquy', 'comment', 'commerce', 'communication', 'communion', 'community'],
    'conversational': ['all jaw', 'answering', 'candid', 'chatty', 'chitchatty', 'colloquial', 'common', 'communicating', 'communicational', 'communicative', 'communional', 'confabulatory'],
    'conversationalist': ['chatterbox', 'collocutor', 'colloquialist', 'conversational partner', 'converser', 'dialogist', 'discourser', 'interlocutor', 'interlocutress', 'interlocutrice', 'interlocutrix', 'palaverer'],
    'converse': ['esp', 'adversative', 'adverse', 'adversive', 'answer', 'antagonistic', 'anti', 'antipathetic', 'antipodal', 'antipode', 'antipodean', 'antipodes'],
    'conversion': ['fabianism', 'about-face', 'abstraction', 'abuse', 'abuse of office', 'accommodation', 'adaptation', 'adjustment', 'adoption', 'alteration', 'amelioration', 'annexation'],
    'convert': ['christian', 'god-fearing man', 'abuse', 'accepter', 'accommodate', 'actuate', 'adapt', 'adjust', 'alter', 'ameliorate', 'apostate', 'apostle'],
    'converted': ['lethean', 'absentminded', 'advanced', 'altered', 'ameliorated', 'amnestic', 'assimilated', 'beautified', 'better', 'bettered', 'blocked', 'born again'],
    'convertible': ['all one', 'all the same', 'changeable', 'coequal', 'commutable', 'commutative', 'coordinate', 'correspondent', 'corresponding', 'equal', 'equalizing', 'equiparant'],
    'convex': ['arched', 'arciform', 'arclike', 'arcual', 'bandy', 'bellied', 'bellylike', 'bowed', 'bowlike', 'bulging', 'concave', 'convexed'],
    'convexity': ['aduncity', 'aquilinity', 'arching', 'arcuation', 'belly', 'boss', 'bump', 'circularity', 'colophon', 'concameration', 'concavity', 'convolution'],
    'convey': ['abalienate', 'alien', 'alienate', 'amortize', 'articulate', 'assign', 'barter', 'bear', 'bequeath', 'break', 'breathe', 'broadcast'],
    'conveyance': ['abalienation', 'abstraction', 'air express', 'aircraft', 'airfreight', 'airlift', 'alienation', 'amortization', 'amortizement', 'annexation', 'announcement', 'appropriation'],
    'conveyer': ['aquarius', 'ganymede', 'hebe', 'bearer', 'bheesty', 'busboy', 'caddie', 'cargo handler', 'carrier', 'carrier pigeon', 'carter', 'common carrier'],
    'convict': ['judas', 'pow', 'acquit', 'anathematize', 'assure', 'attaint', 'be convincing', 'betrayer', 'blacklist', 'bring home to', 'bring over', 'bring round'],
    'conviction': ['anathematizing', 'arrogance', 'aspiration', 'assumption', 'assurance', 'assured faith', 'assuredness', 'belief', 'censure', 'certainty', 'certitude', 'cheerful expectation'],
    'convince': ['argue into', 'assure', 'be convincing', 'bring around', 'bring home to', 'bring over', 'bring round', 'bring to reason', 'captivate', 'carry conviction', 'charm', 'con'],
    'convinced': ['arrogant', 'assured', 'believing', 'certain', 'cocksure', 'confident', 'decided', 'determined', 'devout', 'dogmatic', 'doubtless', 'faithful'],
    'convincing': ['absolute', 'adducible', 'admissible', 'assuring', 'attestative', 'attestive', 'authentic', 'authoritative', 'based on', 'certain', 'circumstantial', 'cogent'],
    'convivial': ['boon', 'companionable', 'festal', 'festive', 'free and easy', 'gala', 'gay', 'gladsome', 'hail-fellow-well-met', 'hearty', 'hilarious', 'jocund'],
    'convocation': ['council of nicaea', 'council of trent', 'lateran council', 'vatican council', 'assemblee', 'assembly', 'assignation', 'at home', 'baccalaureate service', 'ball', 'beck', 'beck and call'],
    'convolution': ['barnumism', 'aduncity', 'affectation', 'aquilinity', 'arachnoid', 'arbor vitae', 'arching', 'archipallium', 'arcuation', 'bedizenment', 'between brain', 'big talk'],
    'convoy': ['attend', 'bear', 'bodyguard', 'bring', 'carry', 'cavalier', 'chaperon', 'companion', 'company', 'conduct', 'conductor', 'consort with'],
    'convulse': ['afflict', 'agitate', 'agonize', 'ail', 'amuse', 'beat', 'beat up', 'beguile', 'bite', 'bloody', 'bug', 'burn'],
    'convulsion': ['homeric laughter', 'jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'abscess', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'ague', 'akinetic epilepsy', 'amok'],
    'coo': ['aspirate', 'bark', 'bawl', 'bellow', 'blare', 'blat', 'blubber', 'boom', 'bray', 'breathe', 'buzz', 'cackle'],
    'cook': ['ko', 'abigail', 'adulterate', 'amah', 'au pair girl', 'ayah', 'bake', 'baker', 'ball up', 'barbecue', 'baste', 'be in heat'],
    'cook up': ['ad-lib', 'angle', 'beget', 'breed', 'brew', 'bring forth', 'bring into being', 'cabal', 'call into being', 'coin', 'collude', 'complot'],
    'cooker': ['dutch oven', 'alcohol stove', 'baker', 'barbecue', 'boiler', 'broiler', 'burner', 'caliduct', 'camp stove', 'chafer', 'chafing dish', 'cook stove'],
    'cookery': ['bakehouse', 'bakery', 'baking', 'barbecuing', 'basting', 'boiling', 'braising', 'brewing', 'broil', 'broiling', 'burner', 'caboose'],
    'cooking': ['a la mode', 'calefaction', 'dielectric heating', 'electric heating', 'electronic heating', 'furnace heating', 'gas heating', 'heat exchange', 'heating', 'hot-air heating', 'increase of temperature', 'induction heating'],
    'cookout': ['tv dinner', 'alfresco meal', 'barbecue', 'breakfast', 'brunch', 'buffet supper', 'clambake', 'coffee break', 'diner', 'dinner', 'elevenses', 'fish fry'],
    'cool': ['buddha-like composure', 'laodicean', 'ok', 'olympian', 'oriental calm', 'abate', 'abnegation', 'above all that', 'absolute zero', 'abstinence', 'ace-high', 'affectless'],
    'cool off': ['arrange', 'array', 'arrest', 'bridle', 'calm down', 'check', 'collect oneself', 'compose oneself', 'constrain', 'contain', 'control', 'cool'],
    'cooler': ['air cooler', 'calaboose', 'can', 'chiller', 'chokey', 'clink', 'cold pack', 'coop', 'fan', 'hoosegow', 'ice bag', 'ice bucket'],
    'coolie': ['aquarius', 'ganymede', 'hebe', 'bearer', 'bheesty', 'busboy', 'caddie', 'cargo handler', 'carrier', 'carrier pigeon', 'carter', 'common carrier'],
    'coop': ['arena', 'bar', 'beleaguer', 'beset', 'besiege', 'block', 'blockade', 'bottle up', 'bound', 'box in', 'box up', 'brooder'],
    'cooperate': ['accord', 'acquiesce', 'act in concert', 'act together', 'affiliate', 'agree', 'ally', 'alternate', 'amalgamate', 'answer to', 'apportion', 'assent'],
    'cooperation': ['accompaniment', 'accord', 'accordance', 'advocacy', 'affiliation', 'affinity', 'agreement', 'aid', 'alliance', 'alternation', 'assent', 'assistance'],
    'cooperative': ['bund', 'rochdale cooperative', 'accompanying', 'accordant', 'acquiescent', 'affirmative', 'agreeable', 'agreeing', 'alacritous', 'alliance', 'amenable', 'amicable'],
    'coordinate': ['accommodate', 'accompanying', 'accord', 'accordant', 'adapt', 'adjust', 'adjust to', 'agreeing', 'all one', 'all the same', 'ally', 'alter ego'],
    'coordinated': ['daedalian', 'adept', 'adroit', 'apt', 'artistic', 'authoritative', 'bravura', 'brilliant', 'clean', 'clever', 'crack', 'crackerjack'],
    'coordinates': ['cartesian coordinates', 'abscissa', 'altitude', 'azimuth', 'boundaries', 'bounds', 'bourns', 'circumference', 'circumscription', 'compass', 'confines', 'cylindrical coordinates'],
    'coordination': ['ability', 'accommodation', 'accounting', 'adaptation', 'address', 'adeptness', 'adjustment', 'adroitness', 'airmanship', 'analysis', 'artfulness', 'artisanship'],
    'cop': ['dogberry', 'john law', 'abstract', 'and', 'annex', 'appropriate', 'bag', 'bluecoat', 'bobby', 'boost', 'borrow', 'bull'],
    'cop a plea': ['acknowledge', 'admit', 'admit everything', 'allow', 'avow', 'come clean', 'concede', 'confess', 'cop out', 'escape without penalty', 'get away with', 'get by'],
    'cop out': ['abatement of differences', 'abstain', 'abstention', 'accommodate', 'accommodation', 'adjust', 'adjustment', 'alibi', 'anythingarianism', 'arrangement', 'bargain', 'cash in'],
    'cope': ['apply to', 'blanket', 'block', 'canopy', 'challenge', 'cloak', 'clothe', 'cloud', 'come through', 'compete', 'compete with', 'contend against'],
    'cope with': ['a outrance', 'accomplish', 'act toward', 'bandy with', 'battle', 'battle it out', 'behave toward', 'bump heads', 'care for', 'complete', 'conduct', 'contend with'],
    'copious': ['abounding', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'blooming', 'bottomless', 'bounteous', 'bountiful', 'broad', 'bursting'],
    'copper': ['c-note', 'dogberry', 'g-note', 'john law', 'titian', 'adust', 'auburn', 'aureate', 'bar', 'bay', 'bay-colored', 'bayard'],
    'copse': ['batch', 'bocage', 'boscage', 'bosk', 'bosket', 'brake', 'bunch', 'canebrake', 'ceja', 'chamisal', 'chaparral', 'clump'],
    'copulate': ['accouple', 'accumulate', 'agglutinate', 'amass', 'articulate', 'assemble', 'associate', 'ball', 'band', 'be intimate', 'beget', 'bill and coo'],
    'copy': ['doppelganger', 'photostat', 'xerox', 'abstract', 'abstraction', 'act', 'act a part', 'act as', 'act like', 'act out', 'actual thing', 'adopt'],
    'copyboy': ['ganymede', 'hebe', 'airline hostess', 'airline stewardess', 'attendant', 'batman', 'bellboy', 'bellhop', 'bellman', 'bootblack', 'boots', 'cabin boy'],
    'copycat': ['ape', 'conformist', 'copier', 'copyist', 'counterfeiter', 'cuckoo', 'dissembler', 'dissimulator', 'echo', 'echoer', 'echoist', 'faker'],
    'copyhold': ['equitable estate', 'estate at sufferance', 'estate for life', 'estate for years', 'estate in expectancy', 'estate in fee', 'estate in possession', 'estate tail', 'fee', 'fee simple', 'fee tail', 'feod'],
    'copyist': ['amanuensis', 'ape', 'artisan', 'artist', 'artiste', 'calligrapher', 'chirographer', 'clerk', 'conformist', 'copier', 'copycat', 'counterfeiter'],
    'copyreader': ['city editor', 'columnist', 'copy chief', 'copy editor', 'copyholder', 'copyman', 'correspondent', 'cub reporter', 'diaskeuast', 'editor', 'editorial writer', 'feature editor'],
    'copyright': ['aegis', 'arm', 'arm guard', 'armor', 'backstop', 'blank check', 'bless', 'bound', 'buffer', 'bulwark', 'bumper', 'carte blanche'],
    'copywriter': ['advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'coauthor', 'collaborator', 'columnist', 'compiler', 'composer'],
    'coquetry': ['amorous looks', 'come-hither look', 'coquettish glances', 'coquettishness', 'coyness', 'dabbling', 'dalliance', 'dallying', 'fiddling', 'flirtation', 'flirtatiousness', 'fooling'],
    'coquette': ['circe', 'don juan', 'lorelei', 'parthenope', 'siren', 'captive', 'catch', 'charmer', 'conquest', 'date', 'enchanter', 'enchantress'],
    'coquettish': ['alluring', 'amative', 'amatory', 'appealing', 'appetizing', 'arch', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating'],
    'cora': ['agdistis', 'aides', 'aidoneus', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus'],
    'coral reef': ['ait', 'archipelago', 'atoll', 'bank', 'bar', 'bill', 'breakwater', 'cape', 'cay', 'chersonese', 'continental island', 'coral head'],
    'cord': ['beam', 'billet', 'board', 'boarding', 'braid', 'brail', 'cable', 'clapboard', 'cordwood', 'deal', 'driftwood', 'firewood'],
    'cordage': ['accommodation', 'burden', 'capacity', 'content', 'cording', 'gear', 'limit', 'measure', 'poundage', 'quantity', 'rigging', 'room'],
    'cordial': ['benedictine', 'bohemian', 'chartreuse', 'danziger goldwasser', 'drambuie', 'galliano', 'irish mist', 'strega', 'triple sec', 'ablaze', 'affable', 'afire'],
    'cordiality': ['agreeability', 'agreeableness', 'amiability', 'approbation', 'approval', 'enjoyableness', 'favor', 'geniality', 'gratefulness', 'mutuality', 'pleasance', 'pleasantness'],
    'cordon': ['advance guard', 'armed guard', 'bank guard', 'beleaguer', 'beset', 'besiege', 'block', 'blockade', 'blue ribbon', 'bolt', 'bottleneck', 'bound'],
    'cordon bleu': ['admirable crichton', 'adept', 'artisan', 'artist', 'attache', 'authority', 'blue ribbon', 'connaisseur', 'connoisseur', 'consultant', 'cordon', 'crack shot'],
    'corduroy': ['aralac', 'avisco', 'axminster', 'celanese', 'dacron', 'dynel', 'georgette', 'harris tweed', 'lastex', 'leatherette', 'orlon', 'qiana'],
    'core': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'amidships', 'amount', 'average', 'axiom'],
    'cork': ['carling float', 'air', 'asphyxiate', 'balsa', 'balsa raft', 'bar', 'bark', 'bedarken', 'besmirch', 'bind', 'black', 'blacken'],
    'corkscrew': ['anfractuous', 'aspirator', 'bottle opener', 'can opener', 'church key', 'cirrus', 'clavis', 'cochlear', 'cochleate', 'coil', 'contort', 'corkscrewy'],
    'corn': ['joe miller', 'aftergrass', 'anhydrate', 'bamboo', 'banality', 'barley', 'benign tumor', 'bird seed', 'blast-freeze', 'boil', 'bran', 'brine'],
    'corn belt': ['agricultural region', 'arable land', 'black belt', 'citrus belt', 'cotton belt', 'countryside', 'dust bowl', 'farm belt', 'farm country', 'farmland', 'fruit belt', 'grass roots'],
    'corncob': ['missouri meerschaum', 'auricle', 'briar', 'briar pipe', 'calean', 'calumet', 'churchwarden', 'clay', 'cob', 'corncob pipe', 'ear', 'ear of corn'],
    'corneous': ['bony', 'cement', 'cemental', 'concrete', 'dense', 'diamondlike', 'dure', 'flintlike', 'flinty', 'granitelike', 'granitic', 'hard'],
    'corner': ['a corner on', 'aberrancy', 'aberration', 'absorb', 'alcove', 'angle', 'apex', 'asylum', 'bay', 'bear raid', 'bend', 'bias'],
    'cornered': ['v-shaped', 'y-shaped', 'akimbo', 'angular', 'at bay', 'aux abois', 'bent', 'between two fires', 'crooked', 'crotched', 'endangered', 'forked'],
    'cornerstone': ['bench mark', 'cardinal point', 'chief thing', 'climax', 'core', 'crisis', 'critical point', 'crux', 'essence', 'essential', 'essential matter', 'first stone'],
    'cornet': ['english horn', 'alpenhorn', 'alphorn', 'althorn', 'alto horn', 'ballad horn', 'baritone', 'bass horn', 'bassoon', 'block flute', 'bombard', 'bourdon'],
    'cornucopia': ['abundance', 'accumulation', 'amassment', 'backlog', 'bonanza', 'budget', 'collection', 'commissariat', 'commissary', 'cumulation', 'dump', 'endless supply'],
    'corny': ['back-number', 'banal', 'bewhiskered', 'bromidic', 'cliched', 'common', 'commonplace', 'cut-and-dried', 'fade', 'familiar', 'fusty', 'hackney'],
    'corollary': ['accession', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct', 'adjuvant'],
    'corona': ['havana', 'androecium', 'annular muscle', 'annulus', 'anthelion', 'anther', 'antisun', 'areola', 'aura', 'aureole', 'belvedere', 'box of cigars'],
    'coronary': ['abdominal', 'anal', 'angina', 'angina pectoris', 'annular', 'annulate', 'annulose', 'aortic insufficiency', 'aortic stenosis', 'apoplectic stroke', 'apoplexy', 'appendical'],
    'coronation': ['accedence', 'accession', 'anointing', 'anointment', 'appointment', 'arrogation', 'assignment', 'assumption', 'authorization', 'consecration', 'delegation', 'deputation'],
    'coroner': ['doctor of medicine', 'gp', 'md', 'allopath', 'allopathist', 'attending physician', 'autopsy', 'country doctor', 'croaker', 'doc', 'doctor', 'family doctor'],
    'coronet': ['achievement', 'alerion', 'animal charge', 'anklet', 'annular muscle', 'annulet', 'annulus', 'areola', 'argent', 'armlet', 'armorial bearings', 'armory'],
    'corporal': ['nco', 'acting corporal', 'acting sergeant', 'altar cloth', 'baldacchino', 'baldachin', 'baptismal font', 'bodily', 'carnal', 'centurion', 'cerecloth', 'chancel screen'],
    'corporal punishment': ['bastinado', 'basting', 'battery', 'beating', 'belting', 'buffeting', 'caning', 'clubbing', 'cowhiding', 'cudgeling', 'drubbing', 'flagellation'],
    'corporate': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'cabalistic', 'coincident', 'combined', 'compact', 'comprehensive', 'concurrent', 'confederate'],
    'corporation': ['aktiengesellschaft', 'agency', 'aktiebolag', 'atelier', 'barbershop', 'bay window', 'beauty parlor', 'beauty shop', 'bench', 'body corporate', 'business', 'business establishment'],
    'corporeal': ['bodily', 'carnal', 'corporal', 'earthly', 'fleshly', 'gross', 'hylic', 'material', 'materiate', 'nonspiritual', 'objective', 'phenomenal'],
    'corps': ['bund', 'kp', 'rochdale cooperative', 'adjutant general corps', 'age group', 'air corps', 'alliance', 'armored corps', 'army', 'army corps', 'army group', 'army nurse corps'],
    'corpse': ['ashes', 'barebones', 'bean pole', 'beanstalk', 'body', 'bones', 'broomstick', 'cadaver', 'carcass', 'carrion', 'clay', 'clothes pole'],
    'corpulent': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'broad-bodied', 'bulky', 'bullnecked', 'burly', 'buxom'],
    'corpus': ['a to z', 'a to izzard', 'festschrift', 'acquaintance', 'aggregate', 'all', 'all and sundry', 'alpha and omega', 'ana', 'anatomy', 'anthology', 'aquarium'],
    'corpus christi': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas'],
    'corpus delicti': ['ashes', 'body', 'bones', 'cadaver', 'carcass', 'carrion', 'circumstantial evidence', 'clay', 'collateral evidence', 'corpse', 'crowbait', 'cumulative evidence'],
    'corral': ['accumulate', 'acquire', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'assemble', 'bag', 'batch', 'be seized of', 'beleaguer', 'beset'],
    'correct': ['christian', 'ok', 'absolute', 'accepted', 'accommodate', 'accommodate with', 'accord', 'according to hoyle', 'accurate', 'acknowledged', 'adapt', 'adapt to'],
    'correction': ['admonishment', 'admonition', 'amendment', 'amends', 'appraisal', 'appraisement', 'approximation', 'assessment', 'assize', 'assizement', 'calculation', 'castigation'],
    'corrective': ['fabian', 'adjuvant', 'aid', 'alterative', 'analeptic', 'antidote', 'assistance', 'balm', 'balsam', 'castigatory', 'chastening', 'chastising'],
    'correlate': ['ally', 'alter ego', 'analogon', 'analogue', 'apply', 'associate', 'bind', 'bracket', 'brother', 'close copy', 'close match', 'cognate'],
    'correlated': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'bound', 'bracketed', 'collateral', 'conjugate', 'connected', 'corelated', 'corelational'],
    'correlation': ['allegory', 'analogy', 'balancing', 'comparative anatomy', 'comparative degree', 'comparative grammar', 'comparative judgment', 'comparative linguistics', 'comparative literature', 'comparative method', 'compare', 'comparing'],
    'correlative': ['accessory', 'accompanying', 'affinitive', 'agnate', 'akin', 'allied', 'analogical', 'analogous', 'appertaining', 'associated', 'associative', 'attendant'],
    'correspond': ['accommodate', 'accommodate with', 'accord', 'adapt', 'adapt to', 'adjust', 'adjust to', 'affect', 'agree', 'agree with', 'align', 'amount to'],
    'correspondence': ['esp', 'pp', 'rd', 'rfd', 'accommodation', 'accompaniment', 'accord', 'accordance', 'account', 'acquiescence', 'adaptation', 'adaption'],
    'correspondent': ['accordant', 'accused', 'addressee', 'affirmative', 'agreeable', 'agreeing', 'alike', 'all one', 'all the same', 'ally', 'alter ego', 'analogon'],
    'corresponding': ['accordant', 'affirmative', 'agnate', 'agreeable', 'agreeing', 'akin', 'alike', 'all one', 'all the same', 'amicable', 'anal', 'analogous'],
    'corridor': ['access', 'adit', 'air lane', 'air line', 'air lock', 'air route', 'airspace', 'airway', 'aisle', 'alley', 'ambulatory', 'aperture'],
    'corrigible': ['ameliorable', 'amendable', 'controllable', 'correctable', 'curable', 'domesticable', 'domitable', 'emendable', 'fixable', 'governable', 'handleable', 'improvable'],
    'corroborate': ['affirm', 'attest', 'authenticate', 'back', 'back up', 'bear out', 'bolster', 'buttress', 'certify', 'circumstantiate', 'confirm', 'document'],
    'corrode': ['abate', 'ablate', 'atomize', 'bate', 'be eaten away', 'bite', 'break up', 'canker', 'come apart', 'consume', 'consume away', 'crack up'],
    'corrosion': ['ablation', 'atomization', 'attrition', 'biodegradability', 'biodegradation', 'breakup', 'consumption', 'corruption', 'crumbling', 'decay', 'decomposition', 'decrement'],
    'corrosive': ['ablative', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'actual cautery', 'angry'],
    'corrugated': ['broken', 'bumpy', 'canaliculate', 'canaliculated', 'chamfered', 'channeled', 'choppy', 'coarse', 'coarse-grained', 'cockled', 'cockly', 'corduroy'],
    'corrugation': ['bezel', 'broken ground', 'broken water', 'chamfer', 'chase', 'chink', 'chop', 'cockle', 'corduroy', 'corduroy road', 'crack', 'crankle'],
    'corrupt': ['abandoned', 'abase', 'aberrant', 'abroad', 'abuse', 'adrift', 'adulterate', 'afflict', 'aggrieve', 'alienate', 'all abroad', 'all off'],
    'corruptible': ['approachable', 'bribable', 'brittle', 'buyable', 'capricious', 'changeable', 'corrupt', 'deciduous', 'dying', 'ephemeral', 'evanescent', 'fading'],
    'corrupting': ['baleful', 'baneful', 'corroding', 'corrosive', 'corruptive', 'counterproductive', 'damaging', 'deadly', 'deleterious', 'detrimental', 'disadvantageous', 'disserviceable'],
    'corruption': ['abandon', 'abandonment', 'abjection', 'abomination', 'abuse of terms', 'acrostic', 'adulteration', 'alienation', 'amphibologism', 'amphiboly', 'anagram', 'antiphrasis'],
    'corsage': ['blouse', 'bodice', 'boughpot', 'bouquet', 'boutonniere', 'buttonhole', 'chaplet', 'dickey', 'festoon', 'flower arrangement', 'garland', 'lei'],
    'corset': ['advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'bearer', 'bra', 'brace', 'bracer'],
    'cortege': ['attendance', 'attendant', 'body of retainers', 'burial', 'burial at sea', 'burying', 'caravan', 'cavalcade', 'cohort', 'column', 'court', 'dead march'],
    'cortex': ['armature', 'armor', 'armor plate', 'bark', 'body armor', 'border', 'buckler', 'bulletproof vest', 'chain armor', 'chain mail', 'chitin', 'circumference'],
    'cosmetics': ['base', 'clown white', 'cold cream', 'compact', 'drugstore complexion', 'eye shadow', 'eyebrow pencil', 'foundation', 'foundation cream', 'giftware', 'greasepaint', 'hand cream'],
    'cosmic': ['gargantuan', 'amplitudinous', 'astronomical', 'awesome', 'boundless', 'bulky', 'colossal', 'cosmogonal', 'cosmogonic', 'cosmologic', 'enormous', 'extensive'],
    'cosmical': ['gargantuan', 'amplitudinous', 'astronomical', 'awesome', 'boundless', 'bulky', 'colossal', 'cosmic', 'cosmogonal', 'cosmogonic', 'cosmologic', 'enormous'],
    'cosmology': ['aesthetics', 'astrogony', 'axiology', 'big bang theory', 'casuistry', 'continuous creation theory', 'cosmic evolution', 'cosmic philosophy', 'cosmism', 'cosmogony', 'cosmography', 'epistemology'],
    'cosmopolitan': ['all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'allover', 'blase', 'braw'],
    'cosmos': ['copernican universe', 'einsteinian universe', 'newtonian universe', 'ptolemaic universe', 'all', 'all being', 'all creation', 'allness', 'created nature', 'created universe', 'creation', 'everything that is'],
    'cosset': ['care for', 'caress', 'cater to', 'cherish', 'cocker', 'coddle', 'cradle', 'cultivate', 'dandle', 'dry-nurse', 'favor', 'feed'],
    'cost': ['afford', 'amount', 'amount to', 'bereavement', 'bring', 'bring in', 'budget', 'budget items', 'burden of expenditure', 'carrying charge', 'charge', 'charges'],
    'cost of living': ['budget', 'budget items', 'burden of expenditure', 'carrying charge', 'charges', 'consumer price index', 'cost', 'cost-of-living allowance', 'cost-of-living index', 'costs', 'direct costs', 'disbursals'],
    'costume': ['accouter', 'apparel', 'array', 'attire', 'ballet skirt', 'bedizenment', 'bib and tucker', 'blackface', 'buskin', 'cap and bells', 'caparison', 'clothes'],
    'costume designer': ['mc', 'auteur', 'ballyhoo man', 'barker', 'callboy', 'costumer', 'costumier', 'couturier', 'designer', 'director', 'dress designer', 'emcee'],
    'costume party': ['kaffeeklatsch', 'ball', 'blowout', 'cocktail party', 'coffee klatch', 'dinner', 'dinner party', 'donation party', 'entertainment', 'festivity', 'garden party', 'hen party'],
    'cot': ['colonial bed', 'hollywood bed', 'bassinet', 'bed-davenport', 'berth', 'blockhouse', 'box', 'bungalow', 'bunk', 'bunk bed', 'cabin', 'camp bed'],
    'coterie': ['age group', 'band', 'battalion', 'bevy', 'body', 'brigade', 'bunch', 'cabal', 'cadre', 'camarilla', 'cast', 'cell'],
    'coterminous': ['accompanying', 'adjacent', 'adjoining', 'agreeing', 'bordering', 'coequal', 'coetaneous', 'coeternal', 'coeval', 'coexistent', 'coexisting', 'coextensive'],
    'cottage': ['aldine', 'arabesque', 'byzantine', 'canevari', 'etruscan', 'grolier', 'harleian', 'jansenist', 'maioli', 'roxburgh', 'blockhouse', 'box'],
    'cotton': ['ace bandage', 'aralac', 'avisco', 'axminster', 'band-aid', 'celanese', 'chemstrand', 'dacron', 'dynel', 'georgette', 'harris tweed', 'lastex'],
    'cotton belt': ['agricultural region', 'arable land', 'black belt', 'citrus belt', 'corn belt', 'countryside', 'dust bowl', 'farm belt', 'farm country', 'farmland', 'fruit belt', 'grass roots'],
    'cotton to': ['accord', 'agree', 'agree with', 'associate with', 'be acquainted with', 'be friends', 'be inseparable', 'be smitten', 'become attached to', 'chime in with', 'correspond', 'empathize'],
    'couch': ['analysis', 'bear down', 'bed', 'bed down', 'bedstead', 'bring low', 'bunk', 'burrow', 'cave', 'conceive', 'couch in terms', 'covert'],
    'couchant': ['accumbent', 'couche', 'crawling', 'crouched', 'debased', 'decumbent', 'depressed', 'draped', 'flat', 'groveling', 'knee-high', 'knocked flat'],
    'cough': ['aqua-lung', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'blow', 'breath', 'breath of air', 'breathe', 'breathe hard', 'breathe in', 'breathe out', 'breathing'],
    'council': ['areopagus', 'bund', 'rochdale cooperative', 'advisory council', 'alliance', 'assemblage', 'assemblee', 'assembly', 'assignation', 'association', 'at home', 'audience'],
    'councilman': ['mp', 'member of congress', 'member of parliament', 'alderman', 'archon', 'assemblyman', 'bailie', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor'],
    'counsel': ['dutch uncle', 'polonius', 'admonisher', 'admonition', 'advice', 'advise', 'advise with', 'advisement', 'adviser', 'advising', 'advisor', 'advocacy'],
    'counseling': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'assertiveness training', 'behavior modification', 'behavior therapy', 'bioenergetics', 'biofeedback', 'confrontation therapy'],
    'counselor': ['dutch uncle', 'polonius', 'admonisher', 'adviser', 'advocate', 'agent', 'amicus curiae', 'attorney', 'attorney-at-law', 'backseat driver', 'barrister', 'barrister-at-law'],
    'count': ['brahman', 'a reckoning of', 'account', 'account of', 'accounts', 'accusal', 'accusation', 'accusing', 'add up', 'adjudge', 'adjudicate', 'admit'],
    'count on': ['aspire to', 'bank on', 'bargain for', 'bet on', 'calculate on', 'confide', 'depend on', 'desire', 'expect', 'feel confident', 'figure on', 'forestall'],
    'count out': ['ban', 'bar', 'bar out', 'bate', 'blockade', 'cut off', 'debar', 'eliminate', 'embargo', 'except', 'exclude', 'freeze out'],
    'countenance': ['buddha-like composure', 'ok', 'oriental calm', 'abet', 'abetment', 'accept', 'acceptance', 'adherence', 'admiration', 'admire', 'advocacy', 'advocate'],
    'counter': ['geiger counter', 'wilson chamber', 'x-ray spectrograph', 'x-ray spectrometer', 'abjure', 'adversary', 'adversative', 'adverse', 'adversive', 'advocate', 'against the grain', 'against the tide'],
    'counter culture': ['agreement to disagree', 'alienation', 'apostasy', 'difference', 'disaccord', 'disagreement', 'disapprobation', 'disapproval', 'disparity', 'dissatisfaction', 'dissension', 'dissent'],
    'counter to': ['adverse to', 'against', 'antagonistically', 'at cross-purposes with', 'athwart', 'con', 'contra', 'contrary to', 'counteractively', 'dead against', 'in conflict with', 'in contempt of'],
    'counteract': ['annul', 'antagonize', 'baffle', 'balance', 'balk', 'be antipathetic', 'be at cross-purposes', 'be inimical', 'be opposed to', 'beat against', 'blast', 'brave'],
    'counteraction': ['amends', 'atonement', 'balancing', 'bucking', 'challenge', 'combative reaction', 'commutation', 'compensation', 'complaint', 'contention', 'contradiction', 'contraposition'],
    'counterattack': ['aggravated assault', 'aggression', 'amphibious attack', 'armed assault', 'assailing', 'assailment', 'assault', 'attack', 'backfire', 'banzai attack', 'blitz', 'blitzkrieg'],
    'counterbalance': ['accommodate', 'adjust', 'amend', 'annul', 'antipode', 'antipodes', 'antipole', 'antithesis', 'antonym', 'atone for', 'balance', 'ballast'],
    'counterclaim': ['confutation', 'confute', 'contraremonstrance', 'counteraccusation', 'counterblast', 'countercharge', 'counterdemand', 'counterreply', 'counterstatement', 'defense', 'make a rebuttal', 'rebut'],
    'counterclockwise': ['a rebours', 'a reculons', 'against the grain', 'anticlockwise', 'arear', 'around', 'ass-backwards', 'astern', 'away', 'back', 'backward', 'backwards'],
    'counterespionage': ['bugging', 'cloak-and-dagger work', 'counterintelligence', 'electronic surveillance', 'espial', 'espionage', 'following', 'intelligence', 'intelligence work', 'military intelligence', 'observation', 'secret police'],
    'counterfeit': ['act', 'act a part', 'act like', 'affect', 'affected', 'agent', 'alike', 'alternate', 'alternative', 'analogy', 'ape', 'aped'],
    'counterfeiter': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'actor', 'ape', 'bamboozler', 'befuddler', 'beguiler', 'charmer'],
    'counterfeiting': ['coinage', 'coining', 'copying', 'emulation', 'fakery', 'following', 'forgery', 'hit-off', 'imitation', 'impersonation', 'imposture', 'impression'],
    'counterintelligence': ['bugging', 'cloak-and-dagger work', 'counterespionage', 'electronic surveillance', 'espial', 'espionage', 'following', 'intelligence', 'intelligence bureau', 'intelligence service', 'intelligence work', 'military intelligence'],
    'counterirritant': ['adjuvant', 'antacid', 'antidote', 'buffer', 'carminative', 'counteractant', 'counteractive', 'counteragent', 'emmenagogue', 'expectorant', 'hormone', 'maturative'],
    'countermand': ['abolish', 'abolishment', 'abolition', 'abrogate', 'abrogation', 'annul', 'annulment', 'baffle', 'balk', 'blast', 'brave', 'cancel'],
    'countermeasure': ['antidote', 'backfire', 'comeback', 'corrective', 'counteractant', 'counteractive', 'counteragent', 'counterattack', 'counterblast', 'counterblow', 'counterfire', 'counterinsurgency'],
    'countermine': ['abri', 'angle', 'approach trench', 'brew', 'bunker', 'cabal', 'collude', 'communication trench', 'complot', 'concoct', 'connive', 'conspire'],
    'countermove': ['action', 'ad hoc measure', 'answer', 'artifice', 'contrivance', 'coup', 'course of action', 'demarche', 'device', 'dodge', 'effort', 'expedient'],
    'counterorder': ['abolishment', 'abolition', 'abrogation', 'annulment', 'cancel', 'canceling', 'cancellation', 'cassation', 'countermand', 'defeasance', 'invalidation', 'nullification'],
    'counterpane': ['afghan', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedsheet', 'bedspread', 'blanket', 'buffalo robe', 'case', 'clothes', 'comfort'],
    'counterpart': ['ally', 'alter ego', 'analogon', 'analogue', 'associate', 'brother', 'clone', 'close copy', 'close match', 'coequal', 'cognate', 'companion'],
    'counterpoint': ['alexandrine', 'ambrosian chant', 'accent', 'accentuation', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antipode', 'antipodes', 'antipole', 'antispast'],
    'counterpose': ['analogize', 'antagonize', 'assimilate', 'balance', 'be antipathetic', 'be at cross-purposes', 'be inimical', 'be opposed to', 'beat against', 'bring into analogy', 'bring into comparison', 'clash'],
    'counterproductive': ['baleful', 'baneful', 'barren', 'bootless', 'choking', 'constrictive', 'contrary', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'crosswise'],
    'counterrevolution': ['backfire', 'bloodless revolution', 'bouleversement', 'breakdown', 'breakup', 'cataclysm', 'catastrophe', 'clean slate', 'clean sweep', 'comeback', 'computer revolution', 'convulsion'],
    'countersign': ['id card', 'john hancock', 'ok', 'accept', 'accredit', 'affirm', 'amen', 'approve', 'assure', 'authenticate', 'authorize', 'autograph'],
    'counterstatement': ['answer', 'argument', 'confutation', 'contraremonstrance', 'counteraccusation', 'counterblast', 'countercharge', 'counterclaim', 'counterreply', 'defense', 'demurrer', 'denial'],
    'counterstroke': ['backfire', 'boomerang', 'comeback', 'counter', 'counterattack', 'counterblast', 'counterblow', 'counterfire', 'counterinsurgency', 'countermeasure', 'counterrevolution', 'counterstep'],
    'countervail': ['accommodate', 'adjust', 'amend', 'antagonize', 'atone for', 'balance', 'be antipathetic', 'be at cross-purposes', 'be inimical', 'be opposed to', 'beat against', 'cancel'],
    'countervallation': ['barbed wire', 'contravallation', 'dike', 'fences', 'hedge', 'hedgerow', 'hoarding', 'paling', 'palisade', 'parapet', 'railing', 'rampart'],
    'counterweight': ['act drop', 'asbestos', 'asbestos board', 'backdrop', 'balance', 'balance rudder', 'balance wheel', 'ballast', 'batten', 'border', 'cloth', 'consideration'],
    'counting': ['accounting', 'assimilating', 'census', 'comprising', 'containing', 'covering', 'dactylonomy', 'embracing', 'encircling', 'enclosing', 'encompassing', 'enumeration'],
    'countinghouse': ['boutique', 'chain store', 'co-op', 'concession', 'cooperative', 'country store', 'department store', 'dime store', 'discount house', 'discount store', 'emporium', 'establishment'],
    'countless': ['abundant', 'all-comprehensive', 'all-inclusive', 'ample', 'boundless', 'copious', 'endless', 'eternal', 'exhaustless', 'extending everywhere', 'generous', 'illimitable'],
    'countrified': ['agrestic', 'boorish', 'bucolic', 'campestral', 'churlish', 'cloddish', 'clodhopping', 'clownish', 'country', 'country-born', 'country-bred', 'farmerish'],
    'country': ['arcadian', 'acres', 'agrarian', 'agrestic', 'agricultural', 'airspace', 'alluvion', 'alluvium', 'arable land', 'area', 'belt', 'blue-ribbon jury'],
    'country cousin': ['aunt', 'auntie', 'blood brother', 'brethren', 'brother', 'bub', 'bubba', 'bud', 'buddy', 'cousin', 'cousin once removed', 'cousin twice removed'],
    'country gentleman': ['beneficiary', 'cestui', 'cestui que trust', 'cestui que use', 'deedholder', 'feoffee', 'feudatory', 'householder', 'laird', 'landlady', 'landlord', 'lord'],
    'countryman': ['backwoodsman', 'bumpkin', 'clodhopper', 'clown', 'compatriot', 'congener', 'countrywoman', 'fellah', 'fellow citizen', 'fellow countryman', 'fellow townsman', 'hayseed'],
    'countryside': ['agricultural region', 'arable land', 'black belt', 'citrus belt', 'corn belt', 'cotton belt', 'dust bowl', 'farm belt', 'farm country', 'farmland', 'fruit belt', 'grass roots'],
    'county': ['kreis', 'ally', 'archbishopric', 'archdiocese', 'archduchy', 'archdukedom', 'arrondissement', 'bailiwick', 'bishopric', 'body politic', 'borough', 'buffer state'],
    'coup': ['abduction', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'ad hoc measure', 'adventure', 'answer', 'apprehension', 'arrest'],
    'coup de grace': ['ko', 'bane', 'clincher', 'crusher', 'death', 'death knell', 'death stroke', 'deathblow', 'doom', 'end', 'end-all', 'ender'],
    'couple': ['a few', 'accouple', 'accumulate', 'affiliate', 'agglutinate', 'ally', 'amass', 'apply', 'arrange a match', 'articulate', 'assemble', 'associate'],
    'coupled': ['accessory', 'accompanying', 'affiliate', 'affiliated', 'allied', 'assembled', 'associate', 'associated', 'attendant', 'attending', 'banded together', 'biconjugate'],
    'couplet': ['spenserian stanza', 'antistrophe', 'book', 'both', 'brace', 'burden', 'canto', 'chorus', 'couple', 'distich', 'double harness', 'doublet'],
    'coupling': ['agglomeration', 'agglutination', 'aggregation', 'ankle', 'articulation', 'bond', 'boundary', 'bracketing', 'butt', 'cervix', 'clinch', 'closure'],
    'courage': ['arrogance', 'assurance', 'assuredness', 'audacity', 'backbone', 'balls', 'belief', 'boldness', 'bottle', 'bottom', 'bravery', 'certitude'],
    'courageous': ['audacious', 'bold', 'bold-spirited', 'brave', 'chivalric', 'chivalrous', 'daring', 'dauntless', 'doughty', 'fearless', 'fiery', 'gallant'],
    'courier': ['gyropilot', 'hermes', 'iris', 'mercury', 'paul revere', 'pheidippides', 'automatic pilot', 'bearer', 'boatheader', 'boatsteerer', 'carrier', 'cicerone'],
    'course': ['brownian movement', 'indian file', 'mo', 'zeitgeist', 'academic specialty', 'act', 'adit', 'advance', 'advancement', 'advancing', 'affluence', 'afflux'],
    'course of action': ['action', 'ad hoc measure', 'answer', 'artifice', 'contrivance', 'countermove', 'coup', 'demarche', 'device', 'dodge', 'effort', 'expedient'],
    'courser': ['houyhnhnm', 'nimrod', 'antelope', 'arrow', 'beater', 'big game hunter', 'blue darter', 'blue streak', 'brood mare', 'cannonball', 'charger', 'colt'],
    'court': ['autobahn', 'british cabinet', 'rasputin', 'sanhedrin', 'svengali', 'us cabinet', 'us highway', 'vip', 'access', 'act up to', 'address', 'addresses'],
    'courteous': ['accommodating', 'affable', 'agreeable', 'amiable', 'attentive', 'cap in hand', 'ceremonious', 'civil', 'civilized', 'clubbable', 'clubbish', 'clubby'],
    'courtesan': ['aspasia', 'delilah', 'jezebel', 'messalina', 'phryne', 'thais', 'adventuress', 'demimondaine', 'demimonde', 'demirep', 'fancy woman', 'femme fatale'],
    'courtesy': ['act of courtesy', 'act of grace', 'act of kindness', 'admiration', 'adoration', 'affability', 'amenity', 'amiability', 'apotheosis', 'appreciation', 'approbation', 'approval'],
    'courthouse': ['capitol', 'city hall', 'community center', 'county building', 'county courthouse', 'court', 'courtroom', 'dock', 'fire station', 'firehouse', 'jury box', 'municipal building'],
    'courtier': ['adherent', 'adulator', 'appendage', 'apple-polisher', 'ass-licker', 'attendant', 'backscratcher', 'backslapper', 'blarneyer', 'bootlick', 'bootlicker', 'brown-nose'],
    'courtliness': ['amenities', 'augustness', 'chivalrousness', 'chivalry', 'civilities', 'civility', 'comity', 'convention', 'courtly politeness', 'decencies', 'decorum', 'dignifiedness'],
    'courtly': ['adulatory', 'aristocratic', 'august', 'bland', 'blandishing', 'blarneying', 'buttery', 'cajoling', 'ceremonious', 'chivalric', 'chivalrous', 'civilized'],
    'courtyard': ['arena', 'cincture', 'close', 'confine', 'container', 'coop', 'court', 'curtilage', 'delimited field', 'enclave', 'enclosure', 'field'],
    'cousin': ['aunt', 'auntie', 'blood brother', 'brethren', 'brother', 'bub', 'bubba', 'bud', 'buddy', 'country cousin', 'cousin once removed', 'cousin twice removed'],
    'cove': ['adamite', 'abri', 'alcove', 'antre', 'apse', 'arcade', 'arcature', 'arch', 'arched roof', 'archway', 'arm', 'armlet'],
    'covenant': ['accord', 'agree', 'agree on', 'agree to', 'agree with', 'agreement', 'arrangement', 'bargain', 'bargain for', 'binding agreement', 'bond', 'cartel'],
    'cover': ['american plan', 'european plan', 'smyth sewing', 'a la carte', 'abri', 'account for', 'accouple', 'accumulate', 'act', 'admit', 'afghan', 'agglutinate'],
    'cover charge': ['american plan', 'european plan', 'a la carte', 'admission', 'admission fee', 'anchorage', 'brokerage', 'carfare', 'cellarage', 'charge', 'charges', 'couvert'],
    'cover girl': ['miss america', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'beauty queen', 'belle', 'bunny', 'charmer', 'dazzler', 'dream'],
    'cover story': ['alibi', 'apology', 'blind', 'cloak', 'color', 'cover', 'cover-up', 'device', 'excuse', 'facade', 'feint', 'front'],
    'cover up': ['act', 'act a part', 'affect', 'alibi', 'apology', 'apply to', 'assume', 'be the goat', 'becloud', 'befog', 'blanket', 'blind'],
    'covering': ['assimilating', 'bigness', 'blanket', 'blanketing', 'border', 'brooding', 'burial', 'burying', 'calcimining', 'circumference', 'cloak', 'cloaking'],
    'covert': ['abri', 'abstruse', 'air-raid shelter', 'armored', 'asylum', 'back-door', 'backstairs', 'beclouded', 'between the lines', 'blanket', 'blind', 'bolt-hole'],
    'covet': ['aspire after', 'begrudge', 'cast envious eyes', 'choose', 'crave', 'crave after', 'crawl after', 'desiderate', 'envy', 'grudge', 'hanker after', 'hunger after'],
    'covetous': ['acquisitive', 'assembly', 'avid', 'band', 'bevy', 'bunch', 'cluster', 'covey', 'crew', 'desirous', 'eager', 'envious'],
    'covey': ['a mass of', 'a world of', 'age group', 'army', 'band', 'battalion', 'bevy', 'body', 'brigade', 'bunch', 'cabal', 'cast'],
    'covin': ['artifice', 'cabal', 'chicane', 'chicanery', 'collusion', 'complicity', 'complot', 'confederacy', 'connivance', 'connivery', 'conspiracy', 'contrivance'],
    'cow': ['brahman', 'indian buffalo', 'partlet', 'abash', 'appall', 'aurochs', 'beat down', 'beef', 'beef cattle', 'beeves', 'biddy', 'bison'],
    'coward': ['milquetoast', 'scaramouch', 'baby', 'big baby', 'caitiff', 'chicken', 'chicken liver', 'craven', 'dastard', 'fraid-cat', 'fraidy-cat', 'funk'],
    'cowardice': ['abject fear', 'abulia', 'adynamia', 'affright', 'alarm', 'anemia', 'atony', 'awe', 'blah feeling', 'bloodlessness', 'blue funk', 'cachexia'],
    'cowardly': ['abulic', 'afraid', 'anemic', 'asthenic', 'bashful', 'bloodless', 'caitiff', 'chicken', 'chickenhearted', 'coward', 'cowed', 'craven'],
    'cowboy': ['broncobuster', 'buckaroo', 'caballero', 'cattleman', 'cavalier', 'cavalryman', 'chevalier', 'circus rider', 'cowgirl', 'cowhand', 'cowherd', 'cowman'],
    'cowed': ['afraid', 'aghast', 'appalled', 'ashen', 'astounded', 'awed', 'awestricken', 'awestruck', 'blanched', 'chicken', 'chickenhearted', 'coward'],
    'cower': ['apple-polish', 'bend', 'bend the knee', 'blench', 'bootlick', 'bow', 'bow and scrape', 'crawl', 'creep', 'cringe', 'crouch', 'dodder'],
    'cowhide': ['belt', 'blacksnake', 'bullwhack', 'bullwhip', 'cat', 'crop', 'flagellum', 'horsewhip', 'knout', 'kurbash', 'lash', 'quirt'],
    'cowl': ['blanket', 'cloak', 'coat', 'cover', 'coverage', 'covering', 'covert', 'coverture', 'cowling', 'curtain', 'drape', 'drapery'],
    'cowpuncher': ['broncobuster', 'buckaroo', 'caballero', 'cattleman', 'cavalier', 'cavalryman', 'chevalier', 'circus rider', 'cowboy', 'cowgirl', 'cowhand', 'cowherd'],
    'coxcomb': ['beau brummel', 'beau', 'bladder', 'blade', 'blood', 'boulevardier', 'buck', 'cap and bells', 'clotheshorse', 'dandy', 'dude', 'exquisite'],
    'coxswain': ['gyropilot', 'automatic pilot', 'boatheader', 'boatsteerer', 'cicerone', 'conner', 'courier', 'cowherd', 'cox', 'docking pilot', 'dragoman', 'drover'],
    'coy': ['amative', 'amatory', 'arch', 'bashful', 'capricious', 'caressive', 'confused', 'conscious', 'coquettish', 'decent', 'decorous', 'demure'],
    'cozen': ['beat', 'beguile', 'beguile of', 'betray', 'bilk', 'bunco', 'burn', 'cheat', 'chisel', 'chouse', 'chouse out of', 'cog'],
    'cozy': ['airworthy', 'buddy-buddy', 'charmed', 'chatty', 'cheerful', 'chitchatty', 'chummy', 'colloquial', 'comfortable', 'comfy', 'commodious', 'communicative'],
    'cpa': ['ca', 'accountant', 'accountant general', 'actuary', 'auditor', 'bank accountant', 'bank examiner', 'bookkeeper', 'calculator', 'certified public accountant', 'chartered accountant', 'clerk'],
    'crab': ['chinese windlass', 'dungeness crab', 'japanese crab', 'spanish windlass', 'air a grievance', 'bank', 'beef', 'bellyache', 'bellyacher', 'bitch', 'bleat', 'blue point'],
    'crabbed': ['byzantine', 'acerb', 'acerbate', 'acerbic', 'acescent', 'anile', 'balled up', 'bearish', 'beyond one', 'bitchy', 'blunt', 'brusque'],
    'crabby': ['beefing', 'bellyaching', 'bitching', 'complaining', 'complaintful', 'crabbed', 'crabbing', 'cranky', 'croaking', 'disappointed', 'discontented', 'disgruntled'],
    'crack': ['daedalian', 'parthian shot', 'above par', 'abrade', 'abrasion', 'abysm', 'abyss', 'account for', 'ace', 'address', 'adept', 'adroit'],
    'crack down on': ['ambush', 'asphyxiate', 'assail', 'assault', 'attack', 'blitz', 'bottle up', 'bushwhack', 'censor', 'choke off', 'clamp down on', 'come at'],
    'crack shot': ['admirable crichton', 'nimrod', 'adept', 'archer', 'artilleryman', 'artisan', 'artist', 'attache', 'authority', 'bowman', 'cannoneer', 'carabineer'],
    'crack up': ['ablate', 'accident', 'appulse', 'atomize', 'bang', 'bang into', 'bankruptcy', 'blow', 'brain disease', 'break down', 'break up', 'breakage'],
    'crackbrain': ['aliene', 'bedlamite', 'borderline case', 'crackpot', 'crank', 'cuckoo', 'dement', 'demoniac', 'ding-a-ling', 'energumen', 'fanatic', 'flake'],
    'cracked': ['abnormal', 'absonant', 'aggravated', 'arrested', 'atonal', 'babbling', 'backward', 'batty', 'bereft of reason', 'blemished', 'blithering', 'brainsick'],
    'cracker': ['brussels biscuit', 'klaxon', 'melba toast', 'backwoodsman', 'biscuit', 'boiler factory', 'boiler room', 'bone', 'briar-hopper', 'brush ape', 'bull-roarer', 'bushman'],
    'crackerjack': ['ace', 'adept', 'beaut', 'brick', 'corker', 'crack', 'daisy', 'dandy', 'darb', 'dilly', 'doll', 'dream'],
    'crackle': ['abrasion', 'blemish', 'break', 'burn', 'chafe', 'check', 'chip', 'clack', 'click', 'concussion', 'crack', 'cracking'],
    'crackpot': ['alien', 'aliene', 'bedlamite', 'borderline case', 'case', 'character', 'crackbrain', 'crank', 'cuckoo', 'dement', 'demoniac', 'ding-a-ling'],
    'cradle': ['colonial bed', 'hollywood bed', 'vaterland', 'afford support', 'appease', 'babyhood', 'back', 'back up', 'bassinet', 'bear', 'bear up', 'bed'],
    'craft': ['italian hand', 'ability', 'acuteness', 'address', 'adeptness', 'adroitness', 'aeroplane', 'aircraft', 'airmanship', 'animal cunning', 'argosy', 'art'],
    'craftsman': ['admirable crichton', 'adept', 'ancestors', 'apprentice', 'architect', 'artificer', 'artisan', 'artist', 'artiste', 'attache', 'author', 'authority'],
    'craftsmanship': ['ability', 'address', 'adeptness', 'adroitness', 'airmanship', 'architecture', 'artfulness', 'artisanship', 'artistry', 'assembly', 'bravura', 'brilliance'],
    'crafty': ['byzantine', 'machiavellian', 'machiavellic', 'acute', 'adroit', 'ambidextrous', 'arch', 'artful', 'astute', 'cagey', 'calculating', 'canny'],
    'crag': ['aa', 'abyssal rock', 'basalt', 'bedrock', 'block lava', 'bluff', 'brash', 'breccia', 'cliff', 'cog', 'comb', 'conglomerate'],
    'craggy': ['asperous', 'corrugated', 'cragged', 'crinkled', 'crumpled', 'crystal', 'crystalline', 'gravelly', 'gritty', 'harsh', 'ironbound', 'jagged'],
    'cram': ['allay', 'assault', 'batten', 'bear', 'bear upon', 'bolt', 'bolt down', 'bone up', 'boost', 'brim', 'brush up', 'buck'],
    'crammed': ['sro', 'allayed', 'awash', 'bloated', 'brimful', 'brimming', 'bristling', 'bulging', 'bursting', 'capacity', 'chock-full', 'choked'],
    'cramp': ['jacksonian epilepsy', 'rolandic epilepsy', 'abate', 'abbreviate', 'abdominal epilepsy', 'access', 'ache', 'aching', 'acquired epilepsy', 'activated epilepsy', 'acute pain', 'affect epilepsy'],
    'cramped': ['latinate', 'angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'authoritarian', 'awkward', 'barred', 'beleaguered', 'beset', 'besieged', 'bigot'],
    'crane': ['andiron', 'be lengthy', 'be prolonged', 'belong', 'chain', 'coal tongs', 'crab', 'crane the neck', 'crook', 'damper', 'derrick', 'erector'],
    'craniology': ['anatomy', 'anthropography', 'anthropologist', 'anthropology', 'anthropometry', 'behavioral science', 'craniometry', 'demography', 'ethnography', 'ethnologist', 'ethnology', 'human ecology'],
    'crank': ['tartar', 'abnormal', 'aficionado', 'alien', 'angle', 'angle off', 'anomalous', 'apex', 'bar', 'beam', 'bear', 'bee'],
    'cranky': ['abnormal', 'anomalous', 'antagonistic', 'antipathetic', 'arbitrary', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'bearish', 'beefing'],
    'cranny': ['abysm', 'abyss', 'alcove', 'arroyo', 'asylum', 'bay', 'bezel', 'bolt-hole', 'box canyon', 'breach', 'break', 'cache'],
    'crap': ['bm', 'balls', 'baloney', 'bilge', 'blague', 'blah', 'blah-blah', 'bloody flux', 'bop', 'bosh', 'bowel movement', 'buffalo chips'],
    'crap out': ['black out', 'bomb', 'draw a blank', 'drop a bomb', 'drop the ball', 'fan', 'flop', 'flummox', 'fold', 'fold up', 'get left', 'lay an egg'],
    'crappy': ['amiss', 'bad', 'barfy', 'bum', 'cheesy', 'creepy', 'crummy', 'dirty', 'disgusting', 'dissatisfactory', 'dungy', 'excremental'],
    'craps': ['bingo', 'bird cage', 'bones', 'card games', 'cast', 'chuck and toss', 'chuck farthing', 'chuck-a-luck', 'crack-loo', 'crap', 'crap game', 'crap shooting'],
    'crash': ['waterloo', 'a habit', 'accident', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'addiction', 'alcoholism', 'appulse', 'atomize', 'awake the dead', 'bang'],
    'crass': ['boeotian', 'absolute', 'arrant', 'asinine', 'beef-brained', 'beef-witted', 'blockish', 'bovine', 'broad-bodied', 'bulky', 'bullnecked', 'chumpish'],
    'crate': ['archives', 'armory', 'arsenal', 'attic', 'auto', 'autocar', 'automobile', 'bag', 'bank', 'barrel', 'basement', 'basket'],
    'crater': ['abysm', 'abyss', 'alveolation', 'alveolus', 'antrum', 'armpit', 'basin', 'birthmark', 'blackhead', 'bleb', 'blemish', 'blister'],
    'crave': ['ache', 'adjure', 'appeal', 'appeal to', 'apply for', 'ask', 'ask for', 'aspire after', 'beg', 'beg leave', 'beseech', 'bespeak'],
    'craven': ['base', 'caitiff', 'chicken', 'coward', 'dastard', 'dastardly', 'dunghill', 'dunghilly', 'funk', 'funker', 'gutless', 'lily-livered'],
    'craving': ['a habit', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'addiction', 'alcoholism', 'an universal wolf', 'appetence', 'appetency', 'appetite', 'appetition', 'athirst'],
    'craw': ['abdomen', 'abomasum', 'bay window', 'beerbelly', 'belly', 'breadbasket', 'crop', 'diaphragm', 'embonpoint', 'first stomach', 'gizzard', 'gullet'],
    'crawl': ['australian crawl', 'abound', 'all fours', 'amble', 'andante', 'aquaplaning', 'aquatics', 'backstroke', 'balneation', 'bathe', 'bathing', 'bend the knee'],
    'crawl with': ['abound', 'abound with', 'be alive with', 'beset', 'bespread', 'bristle with', 'burst with', 'clutter', 'creep with', 'crowd', 'diffuse', 'extend throughout'],
    'crawling': ['abject', 'accumbent', 'alive with', 'all fours', 'ambling', 'amphibian', 'anguine', 'atiptoe', 'atmospherics', 'backscratching', 'batrachian', 'beggarly'],
    'crayon': ['air brush', 'art paper', 'black and white', 'brouillon', 'brush', 'camera lucida', 'camera obscura', 'canvas', 'cartoon', 'chalk', 'charcoal', 'charcoal drawing'],
    'craze': ['abandon', 'abrade', 'abrasion', 'band', 'bar', 'bark', 'belt', 'birthmark', 'blackhead', 'bleb', 'blemish', 'blister'],
    'crazy': ['abnormal', 'absurd', 'anamorphous', 'ape', 'apish', 'arrested', 'asinine', 'askew', 'asymmetric', 'avid', 'babbling', 'backward'],
    'crazy about': ['ape about', 'attached to', 'bugs on', 'cracked on', 'devoted to', 'enamored of', 'far gone on', 'fond of', 'freaked-out', 'gaga over', 'gone on', 'hepped up over'],
    'crazy idea': ['absurd idea', 'boutade', 'brainstorm', 'capriccio', 'caprice', 'conceit', 'crank', 'craze', 'crotchet', 'fad', 'fancy', 'fantastic notion'],
    'creak': ['caterwaul', 'chirk', 'chirking', 'chirp', 'chirrup', 'crick', 'howl', 'keen', 'pipe', 'screak', 'scream', 'screech'],
    'cream': ['abstergent', 'aerate', 'alabaster', 'alabastrine', 'albescent', 'albumen', 'aristocracy', 'aureate', 'auric', 'balm', 'balsam', 'barons'],
    'creamy': ['alabaster', 'alabastrine', 'albescent', 'aureate', 'auric', 'beige', 'buff', 'buff-yellow', 'buttery', 'canary', 'canary-yellow', 'citron'],
    'crease': ['autolithograph', 'be a printmaker', 'carve', 'character', 'chisel', 'cocker', 'cockle', 'corrugate', 'corrugation', 'crankle', 'creasing', 'cribble'],
    'create': ['assemble', 'author', 'bear', 'beget', 'block out', 'break ground', 'break the ice', 'breed', 'bring about', 'bring forth', 'bring into being', 'bring to effect'],
    'creation': ['copernican universe', 'einsteinian universe', 'newtonian universe', 'ptolemaic universe', 'abecedarian', 'aboriginal', 'abundant', 'all', 'all being', 'all creation', 'all-knowing', 'all-powerful'],
    'creativity': ['geist', 'muse', 'afflatus', 'authenticity', 'creative thought', 'creativeness', 'daemon', 'daimonion', 'demon', 'divine afflatus', 'fecundity', 'fertile mind'],
    'creator': ['god', 'actor', 'agent', 'ancestors', 'apprentice', 'architect', 'artificer', 'artisan', 'artist', 'artiste', 'author', 'begetter'],
    'creature': ['adamite', 'charlie mccarthy', 'adherent', 'aerobic organism', 'agent', 'an existence', 'anaerobic organism', 'ancilla', 'animal', 'apple-polisher', 'appliance', 'artifact'],
    'creature comfort': ['amenities', 'amusement', 'animal pleasure', 'board', 'bodily pleasure', 'bread', 'bread and butter', 'cakes and ale', 'carnal delight', 'cheer', 'comestibles', 'comfort'],
    'credence': ['communion table', 'acceptance', 'acceptation', 'accepting', 'acception', 'acquiescence', 'admission', 'admitting', 'altar', 'altar carpet', 'altar desk', 'altar facing'],
    'credential': ['advocacy', 'advocating', 'advocation', 'affidavit', 'attestation', 'authority', 'authorization', 'bill of health', 'certificate', 'certificate of character', 'certificate of proficiency', 'certification'],
    'credentials': ['id card', 'badge', 'calligram', 'calling card', 'card', 'certification', 'character', 'countermark', 'countersign', 'documentation', 'documents', 'dog tag'],
    'credibility': ['absolute credibility', 'acceptability', 'believability', 'believableness', 'conceivability', 'credit', 'plausibility', 'reliability', 'tenability', 'trustworthiness', 'truth', 'truth-loving'],
    'credibility gap': ['artfulness', 'craftiness', 'deceitfulness', 'dishonesty', 'disingenuousness', 'doubtfulness', 'falseheartedness', 'falsehood', 'fibbery', 'fibbing', 'forswearing', 'fraud'],
    'credible': ['acknowledgment', 'admissible', 'asset', 'attention', 'authority', 'believable', 'cogent', 'colorable', 'conceivable', 'conclusive', 'confidence', 'convincing'],
    'credit': ['accept', 'accept for gospel', 'accept implicitly', 'acceptability', 'acceptation', 'acception', 'acclaim', 'account', 'account for', 'accounting for', 'accredit', 'accredit with'],
    'credit rating': ['bank credit', 'book credit', 'borrowing power', 'cash credit', 'commercial credit', 'consumer credit', 'credit', 'credit insurance', 'credit union', 'financial condition', 'hire purchase plan', 'installment credit'],
    'credit union': ['bund', 'rochdale cooperative', 'alliance', 'assemblage', 'association', 'axis', 'band', 'bank', 'bank credit', 'bloc', 'body', 'book credit'],
    'creditable': ['christian', 'admirable', 'beyond all praise', 'blameless', 'clean', 'colorable', 'commendable', 'credible', 'decent', 'deserving', 'erect', 'esteemed'],
    'credited': ['accepted', 'accountable', 'accredited', 'alleged', 'ascribable', 'assignable', 'attributable', 'attributed', 'believed', 'charged', 'derivable from', 'derivational'],
    'credo': ['athanasian creed', 'catechism', 'nicene creed', 'weltanschauung', 'articles of faith', 'articles of religion', 'belief', 'catechism', 'credenda', 'creed', 'cult', 'doctrinal statement'],
    'credulous': ['accepting', 'apish', 'asinine', 'batty', 'befooled', 'beguiled', 'believing', 'besotted', 'brainless', 'buffoonish', 'childlike', 'cockeyed'],
    'creed': ['athanasian creed', 'catechism', 'nicene creed', 'weltanschauung', 'affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'articles of faith', 'articles of religion', 'assertion'],
    'creedbound': ['sabbatarian', 'authoritarian', 'bigot', 'bigoted', 'borne', 'closed', 'constricted', 'cramped', 'deaf', 'deaf to reason', 'dogmatic', 'evangelical'],
    'creek': ['adolescent stream', 'arm', 'armlet', 'arroyo', 'bay', 'bayou', 'beck', 'belt', 'bight', 'boca', 'bourn', 'braided stream'],
    'creep': ['sob', 'all fours', 'amble', 'andante', 'bastard', 'bend the knee', 'bootlick', 'bow', 'bow and scrape', 'bugger', 'claudicate', 'claudication'],
    'creep in': ['admit', 'affiliate', 'affiliate with', 'associate', 'barge in', 'be admitted', 'break in', 'break in upon', 'breeze in', 'burst in', 'bust in', 'butt in'],
    'creep with': ['abound', 'abound with', 'be alive with', 'beset', 'bespread', 'bristle with', 'burst with', 'clutter', 'crawl with', 'crowd', 'diffuse', 'extend throughout'],
    'creeper': ['algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'diatom', 'fern', 'fruits and vegetables', 'fucus'],
    'creeping': ['all fours', 'ambling', 'amphibian', 'anguine', 'atiptoe', 'atmospherics', 'batrachian', 'blaring', 'blasting', 'blind spot', 'cautious', 'cautiousness'],
    'creeps': ['ache', 'aching', 'agitation', 'chilblains', 'chill', 'chilliness', 'chilling', 'chills of fear', 'cold creeps', 'cold shivers', 'cold sweat', 'cryopathy'],
    'creepy': ['barfy', 'bum', 'cheesy', 'crappy', 'crawly', 'crummy', 'dirty', 'eerie', 'formicative', 'godawful', 'goshawful', 'grim'],
    'cremation': ['blazing', 'blistering', 'branding', 'burning', 'calcination', 'carbonization', 'cauterization', 'cautery', 'cineration', 'combustion', 'concremation', 'cracking'],
    'crenellate': ['vandyke', 'arm', 'armor', 'armor-plate', 'bank', 'barricade', 'battle', 'blaze', 'blockade', 'bulwark', 'castellate', 'chop'],
    'crepuscule': ['alpenglow', 'aurora', 'brown of dusk', 'brownness', 'candlelight', 'candlelighting', 'cocklight', 'dawnlight', 'dusk', 'duskingtide', 'first light', 'foredawn'],
    'crescendo': ['a cappella', 'abbandono', 'access', 'accession', 'accrescendo', 'accretion', 'accrual', 'accrue', 'accruement', 'accumulate', 'accumulation', 'acme'],
    'crescent': ['autobahn', 'cynthian', 's-shaped', 'us highway', 'achievement', 'alerion', 'alley', 'alleyway', 'animal charge', 'annulet', 'argent', 'armorial bearings'],
    'crest': ['vandyke edge', 'achievement', 'acme', 'alerion', 'amplitude', 'animal charge', 'annulet', 'antinode', 'apex', 'apogee', 'argent', 'armorial bearings'],
    'crestfallen': ['abashed', 'ashamed', 'baffled', 'balked', 'betrayed', 'bilked', 'blasted', 'blighted', 'blushing', 'brooding', 'broody', 'chagrined'],
    'cretin': ['ament', 'born fool', 'clot', 'congenital idiot', 'defective', 'golem', 'half-wit', 'idiot', 'imbecile', 'juggins', 'mongoloid idiot', 'moron'],
    'cretinism': ['acromegaly', 'amentia', 'arrested development', 'backwardness', 'blithering idiocy', 'choriocarcinoma', 'diabetes', 'diabetes insipidus', 'diabetes mellitus', 'dwarfism', 'giantism', 'half-wittedness'],
    'crevasse': ['abysm', 'abyss', 'arroyo', 'box canyon', 'breach', 'break', 'chap', 'chasm', 'check', 'chimney', 'chink', 'cleft'],
    'crevice': ['abysm', 'abyss', 'arroyo', 'box canyon', 'breach', 'break', 'canyon', 'cavity', 'chap', 'chasm', 'check', 'chimney'],
    'crew': ['aerial photographer', 'age group', 'aggregation', 'aircrew', 'aircrewman', 'assembly', 'avigator', 'band', 'battalion', 'belly gunner', 'bevy', 'body'],
    'crib': ['colonial bed', 'hollywood bed', 'nissen hut', 'quonset hut', 'abiding place', 'abode', 'abstract', 'act like', 'address', 'affect', 'amplification', 'and'],
    'crick': ['acute pain', 'bite', 'boring pain', 'branch', 'brook', 'charley horse', 'chirk', 'chirking', 'chirp', 'chirrup', 'cramp', 'cramps'],
    'cricket': ['klaxon', 'boiler factory', 'boiler room', 'bull-roarer', 'candor', 'catcall', 'cherry bomb', 'cicada', 'cicala', 'clack', 'clacker', 'clapper'],
    'crime': ['atrocity', 'breach', 'break', 'crime against humanity', 'criminal tendency', 'criminality', 'criminosis', 'deadly sin', 'delict', 'delinquency', 'dereliction', 'enormity'],
    'criminal': ['judas', 'mafioso', 'aberrant', 'abnormal', 'abominable', 'actionable', 'against the law', 'amoral', 'anarchic', 'anarchistic', 'anomic', 'arraignable'],
    'crimp': ['vandyke', 'abduce', 'abduct', 'abductor', 'aqueduct', 'bar', 'bit', 'blaze', 'bollix', 'bridle', 'bunco artist', 'bunco steerer'],
    'crimson': ['titian', 'titian-red', 'blanch', 'blush', 'bricky', 'cardinal', 'carmine', 'carnation', 'carnelian', 'cerise', 'change color', 'cherry'],
    'cringe': ['apple-polish', 'avoid', 'bend', 'bend the knee', 'bend the neck', 'bend to', 'blench', 'blink', 'bootlick', 'bow', 'bow and scrape', 'bow down'],
    'cringle': ['air hole', 'armhole', 'blowhole', 'boltrope', 'bullet-hole', 'bunghole', 'canvas', 'clew', 'cloth', 'crowd of sail', 'deadeye', 'earing'],
    'crinkle': ['ambages', 'anfractuosity', 'bristle', 'circuitousness', 'circumambages', 'circumbendibus', 'circumlocution', 'circumvolution', 'cocker', 'cockle', 'contort', 'convolution'],
    'cripple': ['abate', 'amputee', 'attenuate', 'blunt', 'bugger', 'burden', 'castrate', 'cramp', 'cumber', 'damage', 'damp', 'dampen'],
    'crippled': ['bad', 'castrated', 'damaged', 'debilitated', 'disabled', 'disarmed', 'disqualified', 'emasculated', 'game', 'halt', 'halting', 'hamstrung'],
    'crisis': ['bench mark', 'boom', 'bottoming out', 'breakers ahead', 'business cycle', 'business fluctuations', 'bust', 'calamity', 'cardhouse', 'cardinal point', 'catastrophe', 'cause for alarm'],
    'crisp': ['siberian', 'spartan', 'abbreviated', 'abridged', 'algid', 'aphoristic', 'aposiopestic', 'arctic', 'axiomatic', 'below zero', 'biting', 'bitter'],
    'crisscross': ['calvary cross', 'christogram', 'greek cross', 'jerusalem cross', 'latin cross', 'maltese cross', 'russian cross', 'across', 'across the grain', 'ankh', 'athwart', 'athwartships'],
    'criterion': ['procrustean law', 'acid test', 'adjudgment', 'antetype', 'antitype', 'archetype', 'assay', 'barometer', 'benchmark', 'biotype', 'blank determination', 'brouillon'],
    'critic': ['advertising writer', 'aficionado', 'allegorist', 'amateur', 'annalist', 'annotator', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'art critic', 'author', 'authoress'],
    'critical': ['herculean', 'abstruse', 'accurate', 'acute', 'alarming', 'allegorizing', 'annotative', 'appreciative', 'arduous', 'attentive', 'bad', 'basic'],
    'critical point': ['bench mark', 'cardinal point', 'chief thing', 'climacteric', 'climax', 'clutch', 'convergence of events', 'core', 'cornerstone', 'crisis', 'critical juncture', 'crossroads'],
    'criticism': ['adverse criticism', 'analysis', 'animadversion', 'appraisal', 'approval', 'aspersion', 'assessment', 'bad notices', 'bad press', 'book review', 'captiousness', 'carping'],
    'criticize': ['annotate', 'appraise', 'assess', 'attack', 'blame', 'blast', 'carp at', 'carper', 'castigate', 'caviler', 'censure', 'comment upon'],
    'critique': ['analysis', 'approval', 'book review', 'censure', 'comment', 'commentary', 'commentation', 'copy', 'critical bibliography', 'critical journal', 'critical notice', 'critical review'],
    'critter': ['brahman', 'houyhnhnm', 'indian buffalo', 'an existence', 'animal', 'aurochs', 'beast', 'beef', 'beef cattle', 'beeves', 'being', 'bison'],
    'croak': ['air a grievance', 'aphonia', 'apprehend', 'artificial voice', 'beef', 'belch', 'bellyache', 'bitch', 'blare', 'blast', 'blat', 'blot out'],
    'crock': ['adobe', 'balker', 'balky horse', 'biscuit', 'bisque', 'bowl', 'brick', 'cement', 'ceramic ware', 'ceramics', 'china', 'crockery'],
    'crockery': ['adobe', 'biscuit', 'bisque', 'bowl', 'brick', 'cement', 'ceramic ware', 'ceramics', 'china', 'crock', 'enamelware', 'firebrick'],
    'croft': ['arable land', 'barnyard', 'barton', 'block', 'cattle ranch', 'chicken farm', 'clos', 'close', 'collective farm', 'cotton plantation', 'dairy farm', 'demesne'],
    'croissant': ['danish', 'danish pastry', 'english muffin', 'parker house roll', 'yorkshire pudding', 'bagel', 'bialy', 'bialystoker', 'bun', 'clover-leaf roll', 'coffee cake', 'crescent roll'],
    'crone': ['bag', 'bat', 'beldam', 'biddy', 'dame', 'dowager', 'drab', 'frump', 'grandam', 'grandmother', 'granny', 'hag'],
    'cronus': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'crony': ['ace', 'adjunct', 'ally', 'amigo', 'associate', 'bedfellow', 'bedmate', 'bosom buddy', 'brother', 'brother-in-arms', 'buddy', 'bunkie'],
    'crook': ['judas', 'malacca cane', 'aberrancy', 'aberration', 'advocate', 'alpenstock', 'andiron', 'angle', 'angle off', 'apex', 'appropriate', 'arc'],
    'crooked': ['machiavellian', 'roman-nosed', 'v-shaped', 'y-shaped', 'agee', 'agee-jawed', 'akimbo', 'ambidextrous', 'amoral', 'anamorphous', 'angular', 'aquiline'],
    'croon': ['anthem', 'ballad', 'carol', 'chant', 'chirp', 'chirrup', 'choir', 'chorus', 'descant', 'do-re-mi', 'hum', 'hymn'],
    'crooner': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso profundo', 'blues singer'],
    'crop': ['abbreviate', 'abdomen', 'abomasum', 'abridge', 'abscind', 'abstract', 'aftermath', 'amputate', 'annihilate', 'bag', 'ban', 'bar'],
    'crop out': ['appear', 'arise', 'be conspicuous', 'be exposed', 'become manifest', 'become visible', 'come', 'come forth', 'come forward', 'come in sight', 'come out', 'come to hand'],
    'crop up': ['appear', 'approach', 'arise', 'be born', 'become', 'break out', 'burst forth', 'chance', 'come along', 'come forth', 'come into being', 'come into existence'],
    'cropped': ['abbreviated', 'abridged', 'abstracted', 'bobbed', 'capsule', 'capsulized', 'clipped', 'compressed', 'condensed', 'curtailed', 'cut short', 'digested'],
    'cropper': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'breakdown', 'coffee-planter', 'collapse', 'collective farm worker', 'comedown', 'crash', 'crofter'],
    'crosier': ['malacca cane', 'alpenstock', 'baton', 'caduceus', 'cane', 'chain of office', 'crook', 'cross', 'cross-staff', 'crutch', 'crutch-stick', 'fasces'],
    'cross': ['agnus dei', 'calvary cross', 'cape colored', 'christogram', 'eurasian', 'greek cross', 'holy grail', 'host', 'jerusalem cross', 'john hancock', 'latin cross', 'malacca cane'],
    'cross examination': ['assize', 'change of venue', 'court-martial', 'cross-interrogation', 'cross-questioning', 'direct examination', 'examination', 'grill', 'grilling', 'hearing', 'inquest', 'inquiry'],
    'cross eye': ['amaurosis', 'blepharitis', 'cast', 'cataract', 'choroiditis', 'conjunctivitis', 'convergent strabismus', 'cross-eyedness', 'defective vision', 'detached retina', 'esotropia', 'exotropia'],
    'cross fire': ['alternation', 'antiaircraft fire', 'battledore and shuttlecock', 'commutation', 'cooperation', 'counterchange', 'curtain fire', 'direct fire', 'dry fire', 'exchange', 'file fire', 'fire'],
    'cross grained': ['across', 'across the grain', 'against the grain', 'athwart', 'athwartships', 'bearish', 'bitchy', 'broken', 'bumpy', 'cankered', 'cantankerous', 'choppy'],
    'cross hatching': ['arabesque', 'band', 'bar', 'basketry', 'basketwork', 'burr', 'cancellation', 'chiseling', 'crossing-out', 'dash', 'delineation', 'demitint'],
    'cross out': ['abbreviate', 'abridge', 'blot', 'blot out', 'blue-pencil', 'bowdlerize', 'cancel', 'censor', 'cut', 'dele', 'delete', 'edit'],
    'cross purposes': ['agreement to disagree', 'antagonism', 'antipathy', 'antithesis', 'bad blood', 'clashing', 'collision', 'competition', 'conflict', 'confrontation', 'contradiction', 'contradistinction'],
    'cross question': ['bone of contention', 'catechism', 'cross-examine', 'cross-interrogate', 'cross-interrogatory', 'debating point', 'demand', 'extract information', 'feeler', 'go over', 'grill', 'inquiry'],
    'cross section': ['adjunct', 'chiasma', 'component', 'contingent', 'crossing', 'cruciation', 'decussation', 'detachment', 'detail', 'division', 'dole', 'embodiment'],
    'crossbones': ['azrael', 'black death', 'calvary cross', 'christogram', 'death', 'greek cross', 'grim reaper', 'jerusalem cross', 'latin cross', 'maltese cross', 'pale death', 'reaper'],
    'crossbreed': ['cape colored', 'eurasian', 'bastard', 'beget', 'breed', 'breed true', 'cattalo', 'citrange', 'copulate', 'cross', 'crossbred', 'engender'],
    'crosscurrent': ['affluence', 'afflux', 'affluxion', 'air current', 'bucking', 'challenge', 'concourse', 'confluence', 'conflux', 'contention', 'contradiction', 'contraposition'],
    'crosshatch': ['autolithograph', 'be a printmaker', 'cartoon', 'carve', 'chalk', 'character', 'charcoal', 'chisel', 'color', 'copy', 'crayon', 'crease'],
    'crossing': ['abjuration', 'abjurement', 'abrogation', 'absolute contradiction', 'annulment', 'approach', 'asymptote', 'bottleneck', 'bucking', 'carrefour', 'challenge', 'cloverleaf'],
    'crosspatch': ['tartar', 'anomaly', 'bear', 'complainer', 'crab', 'crank', 'dragon', 'feist', 'fire-eater', 'freak', 'fury', 'grizzly bear'],
    'crossroads': ['climacteric', 'clutch', 'convergence of events', 'country town', 'crisis', 'critical juncture', 'critical point', 'crucial period', 'crunch', 'emergency', 'exigency', 'extremity'],
    'crosswise': ['across', 'across the grain', 'athwart', 'athwartships', 'awkward', 'bendwise', 'bias', 'biased', 'biaswise', 'bulky', 'catercorner', 'catercornered'],
    'crotchet': ['accidental', 'angle', 'apex', 'bee', 'bend', 'bifurcation', 'bight', 'boutade', 'brainstorm', 'breve', 'cant', 'capriccio'],
    'crotchety': ['abnormal', 'anomalous', 'antagonistic', 'antipathetic', 'arbitrary', 'bearish', 'breakaway', 'cankered', 'capricious', 'clashing', 'conflicting', 'contradicting'],
    'crouch': ['bend', 'bend the knee', 'bend the neck', 'bend to', 'bob', 'bootlick', 'bow', 'bow and scrape', 'bow down', 'bow to', 'couch', 'cower'],
    'croup': ['asiatic flu', 'hong kong flu', 'acute bronchitis', 'adenoiditis', 'aluminosis', 'amygdalitis', 'anthracosilicosis', 'anthracosis', 'asbestosis', 'asthma', 'atypical pneumonia', 'backside'],
    'crow': ['homeric laughter', 'aphonia', 'artificial voice', 'bar', 'bark', 'bawl', 'be in stitches', 'beam', 'bellow', 'belly laugh', 'blare', 'blat'],
    'crowbar': ['aspirator', 'bar', 'beam', 'boom', 'cant hook', 'claw bar', 'corkscrew', 'crank', 'crow', 'extractor', 'forceps', 'get a foothold'],
    'crowd': ['a string', 'amati', 'cremona', 'd string', 'e string', 'g string', 'strad', 'stradivari', 'stradivarius', 'abound with', 'accelerate', 'age group'],
    'crowd in': ['admit', 'barge in', 'be admitted', 'break in', 'break in upon', 'breeze in', 'burst in', 'bust in', 'butt in', 'charge in', 'come barging in', 'come between'],
    'crowded': ['alive with', 'angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'at the double', 'awash', 'bloated', 'brimful', 'brimming', 'bristling', 'bursting'],
    'crown': ['her highness', 'her majesty', 'his majesty', 'old mug', 'achievement', 'acme', 'aggrandize', 'alerion', 'all', 'animal charge', 'anklet', 'annular muscle'],
    'crowned head': ['anointed king', 'chief', 'chieftain', 'dynast', 'emperor', 'grand duke', 'high chief', 'imperator', 'king', 'king-emperor', 'kinglet', 'lord paramount'],
    'crowning': ['arch', 'banner', 'capital', 'capping', 'cardinal', 'central', 'champion', 'chief', 'closing', 'completing', 'completive', 'completory'],
    'crucial': ['aboriginal', 'acute', 'basal', 'basic', 'central', 'charged', 'clamorous', 'climacteric', 'compelling', 'critical', 'crying', 'deciding'],
    'crucible': ['bunsen burner', 'erlenmeyer flask', 'kipp generator', 'acid test', 'affliction', 'agitator', 'alembic', 'anvil', 'aspirator', 'assay', 'beaker', 'beater'],
    'crucified': ['afflicted', 'agonized', 'clawed', 'convulsed', 'distressed', 'harrowed', 'hurt', 'hurting', 'in distress', 'in pain', 'lacerated', 'lancinated'],
    'crucifix': ['agnus dei', 'calvary cross', 'christogram', 'greek cross', 'holy grail', 'host', 'jerusalem cross', 'latin cross', 'maltese cross', 'pieta', 'russian cross', 'sanctus bell'],
    'crucifixion': ['agony', 'anguish', 'atrocious pain', 'beheading', 'burning', 'capital punishment', 'clawing', 'cruciation', 'decapitation', 'decollation', 'defenestration', 'electrocution'],
    'crucify': ['abuse', 'afflict', 'aggrieve', 'agonize', 'ail', 'bedevil', 'befoul', 'behead', 'bewitch', 'bite', 'blight', 'bloody'],
    'crude': ['doric', 'abhorrent', 'abominable', 'amateurish', 'arrested', 'avgas', 'backward', 'barbaric', 'barbarous', 'barnyard', 'base', 'beastly'],
    'crude oil': ['avgas', 'crude', 'ethyl', 'ethyl gas', 'fossil oil', 'gas', 'gasoline', 'high-octane gas', 'high-test', 'kerosene', 'lead-free gas', 'low-lead gas'],
    'crudity': ['callowness', 'coarseness', 'crassness', 'crudeness', 'earthiness', 'gaudiness', 'greenness', 'grossness', 'immatureness', 'immaturity', 'loudness', 'meretriciousness'],
    'cruel': ['draconian', 'tartarean', 'acute', 'afflictive', 'agonizing', 'animal', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bestial'],
    'cruelly': ['abominably', 'agonizingly', 'atrociously', 'awfully', 'baldly', 'balefully', 'barbarously', 'bestially', 'bitterly', 'blatantly', 'brashly', 'brutally'],
    'cruelty': ['animality', 'atrociousness', 'atrocity', 'barbarity', 'barbarousness', 'beastliness', 'bestiality', 'bloodiness', 'bloodlust', 'bloodthirst', 'bloodthirstiness', 'bloody-mindedness'],
    'cruet': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'ark', 'asperger', 'asperges', 'aspergillum', 'bambino', 'beadroll'],
    'cruise': ['aeroplane', 'airlift', 'airplane', 'balloon', 'be airborne', 'boat', 'campaign', 'canoe', 'carry sail', 'circumnavigate', 'coast', 'course'],
    'cruiser': ['black maria', 'lc', 'lsd', 'lsm', 'sc', 'adventurer', 'aircraft carrier', 'aircraft tender', 'almadia', 'alpinist', 'ammunition ship', 'ark'],
    'cruising': ['aeronautics', 'air service', 'airline', 'astronautics', 'aviation', 'ballooning', 'blind flying', 'boating', 'canoeing', 'circumnavigation', 'cloud-seeding', 'coasting'],
    'crumb': ['abrade', 'air pollution', 'atom', 'atomize', 'attritus', 'beat', 'besprinkle', 'bit', 'bite', 'bran', 'bray', 'bread'],
    'crumble': ['abate', 'ablate', 'abrade', 'atomize', 'bate', 'be eaten away', 'beat', 'bite the dust', 'bray', 'break', 'break down', 'break up'],
    'crumbling': ['ablation', 'abrasion', 'atomization', 'attrition', 'beating', 'breakup', 'brecciation', 'coming apart', 'comminution', 'corrosion', 'cracking', 'crushing'],
    'crumbly': ['breakable', 'brittle', 'brittle as glass', 'cheap-jack', 'cobwebby', 'crackable', 'crimp', 'crisp', 'crispy', 'crump', 'crushable', 'dainty'],
    'crummy': ['abject', 'abominable', 'arrant', 'atrocious', 'barfy', 'base', 'beggarly', 'beneath contempt', 'bum', 'cheap', 'cheesy', 'common'],
    'crumpet': ['danish', 'danish pastry', 'english muffin', 'parker house roll', 'yorkshire pudding', 'bagel', 'bialy', 'bialystoker', 'bun', 'clover-leaf roll', 'coffee cake', 'crescent roll'],
    'crumple': ['bend', 'break', 'bristle', 'buckle', 'cave', 'cocker', 'cockle', 'collapse', 'contort', 'corrugate', 'corrugation', 'crankle'],
    'crumpled': ['anamorphous', 'askew', 'asymmetric', 'bent', 'bowed', 'cockeyed', 'cockled', 'cockly', 'contorted', 'corrugate', 'corrugated', 'cragged'],
    'crunch': ['appulse', 'atomize', 'bang', 'bang into', 'belch', 'bind', 'bite', 'blare', 'blat', 'bray', 'break into pieces', 'break to pieces'],
    'crunched': ['anamorphous', 'askew', 'asymmetric', 'bent', 'bowed', 'cockeyed', 'contorted', 'crazy', 'crooked', 'crumpled', 'deviative', 'distorted'],
    'crupper': ['back band', 'backside', 'backstrap', 'bearing rein', 'behind', 'bellyband', 'bit', 'blinders', 'blinds', 'breeching', 'bridle', 'butt'],
    'crusade': ['activity', 'battle', 'campaign', 'cause', 'commitment', 'drive', 'expedition', 'faith', 'fight', 'great cause', 'holy war', 'interest'],
    'crush': ['abase', 'abash', 'abolish', 'abrade', 'affection', 'afflict', 'aggrieve', 'anguish', 'annihilate', 'answer', 'answer conclusively', 'argue down'],
    'crushed': ['abashed', 'ashamed', 'baffled', 'balked', 'betrayed', 'bilked', 'blasted', 'blighted', 'blushing', 'branny', 'broken', 'broken-down'],
    'crusher': ['ko', 'cheese grater', 'clincher', 'comminutor', 'conclusive argument', 'death stroke', 'deathblow', 'end-all', 'ender', 'final stroke', 'finisher', 'finishing stroke'],
    'crushing': ['herculean', 'annoying', 'arduous', 'awkward', 'backbreaking', 'besetting', 'bothersome', 'burdensome', 'chastening', 'disconcerting', 'disturbing', 'effortful'],
    'crust': ['french bread', 'irish soda bread', 'italian bread', 'acres', 'alluvion', 'alluvium', 'arable land', 'black bread', 'border', 'brashness', 'brass', 'bread'],
    'crusty': ['abrupt', 'aggressive', 'backed', 'barnyard', 'bearish', 'beastly', 'biggety', 'bitchy', 'bluff', 'blunt', 'brash', 'brief'],
    'crutch': ['malacca cane', 'advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'baton', 'bearer', 'bra'],
    'crux': ['calvary cross', 'chinese puzzle', 'christogram', 'gordian knot', 'greek cross', 'jerusalem cross', 'latin cross', 'maltese cross', 'russian cross', 'ankh', 'avellan cross', 'baffling problem'],
    'cry': ['pr', 'adjuration', 'advertise', 'alleluia', 'animal noise', 'appeal', 'applaud', 'applause', 'ballyhoo', 'bark', 'barking', 'battle cry'],
    'cry for': ['ache for', 'adjure', 'appeal', 'appeal to', 'ask', 'ask for', 'be dying for', 'be hurting for', 'be indicated', 'beg', 'beseech', 'blackmail'],
    'cry havoc': ['admonish', 'advise', 'alarm', 'alert', 'arouse', 'caution', 'cry wolf', 'fly storm warnings', 'frighten', 'give fair warning', 'give notice', 'give warning'],
    'crybaby': ['milquetoast', 'baby', 'big baby', 'chicken', 'doormat', 'dull tool', 'gutless wonder', 'invertebrate', 'jellyfish', 'lightweight', 'meek soul', 'milksop'],
    'crying': ['acute', 'atrocious', 'bawling', 'blatant', 'blubbering', 'boanergean', 'brawling', 'burning', 'clamant', 'clamorous', 'clamoursome', 'compelling'],
    'cryogenics': ['newtonian physics', 'absolute zero', 'acoustics', 'adiabatic absorption', 'adiabatic demagnetization', 'adiabatic expansion', 'aerophysics', 'air conditioning', 'air cooling', 'algidity', 'applied physics', 'astrophysics'],
    'crypt': ['easter sepulcher', 'alveolation', 'alveolus', 'ambry', 'antrum', 'apse', 'armpit', 'baptistery', 'barrow', 'basement', 'basin', 'beehive tomb'],
    'cryptic': ['abstruse', 'arcane', 'between the lines', 'cabalistic', 'cabbalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'covert', 'dark'],
    'cryptography': ['cipher', 'code', 'coded message', 'coup de plume', 'criticism', 'cryptanalysis', 'cryptoanalysis', 'cryptoanalytics', 'cryptogram', 'cryptograph', 'cryptographer', 'cryptology'],
    'cryptologist': ['allegorist', 'annotator', 'cicerone', 'clarifier', 'commentator', 'critic', 'cryptanalyst', 'cryptographer', 'decoder', 'definer', 'demonstrator', 'demythologizer'],
    'crystal': ['benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'methedrine', 'amphetamine', 'amphetamine sulfate', 'avalanche', 'blizzard', 'clear'],
    'crystal ball': ['aftertime', 'afteryears', 'astrology', 'augury', 'by-and-by', 'clairvoyance', 'course ahead', 'crystal gazing', 'determinism', 'distant future', 'divination', 'divining'],
    'crystal clear': ['apparent', 'clean-cut', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'coherent', 'connected', 'consistent', 'conspicuous', 'crisp', 'crystal'],
    'crystal gazer': ['cassandra', 'druid', 'astrologer', 'augur', 'calamity howler', 'divinator', 'diviner', 'divineress', 'forecaster', 'foreknower', 'foreseer', 'foreshower'],
    'crystalline': ['clean-cut', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'coherent', 'connected', 'consistent', 'craggy', 'crisp', 'crystal', 'crystal-clear'],
    'crystallize': ['cake', 'candy', 'come together', 'concrete', 'condense', 'draw up', 'fall in', 'fall into line', 'fall into place', 'fall into rank', 'form', 'gather around'],
    'crystallized': ['backed', 'calcified', 'callous', 'calloused', 'case-hardened', 'crusted', 'crusty', 'fossilized', 'granulated', 'hardened', 'hornified', 'incrusted'],
    'crystallography': ['newtonian physics', 'acoustics', 'aerophysics', 'applied physics', 'astrophysics', 'basic conductor physics', 'biophysics', 'chemical physics', 'cryogenics', 'cytophysics', 'electron physics', 'electronics'],
    'cub': ['birdling', 'boy', 'bub', 'bubba', 'buck', 'bud', 'buddy', 'calf', 'catling', 'chick', 'chickling', 'chicky'],
    'cub reporter': ['city editor', 'columnist', 'copy chief', 'copy editor', 'copyman', 'copyreader', 'correspondent', 'diaskeuast', 'editor', 'editorial writer', 'feature editor', 'foreign correspondent'],
    'cubbyhole': ['alcove', 'asylum', 'bay', 'bolt-hole', 'cache', 'carrel', 'concealment', 'corner', 'cove', 'cover', 'covert', 'coverture'],
    'cubed': ['cube-shaped', 'cubic', 'cubiform', 'cuboid', 'diced', 'foursquare', 'oblong', 'orthogonal', 'quadrangular', 'quadrate', 'quadriform', 'quadrilateral'],
    'cubehead': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser', 'drug addict'],
    'cubic': ['cube-shaped', 'cubed', 'cubiform', 'cuboid', 'diced', 'dimensional', 'flat', 'foursquare', 'fourth-dimensional', 'oblong', 'orthogonal', 'proportional'],
    'cubical': ['cube-shaped', 'cubed', 'cubic', 'cubiform', 'cuboid', 'diced', 'dimensional', 'flat', 'foursquare', 'fourth-dimensional', 'oblong', 'orthogonal'],
    'cubicle': ['alcove', 'bay', 'bedchamber', 'bedroom', 'boudoir', 'carrel', 'chamber', 'corner', 'cove', 'cranny', 'cubby', 'cubbyhole'],
    'cuckoldry': ['adulterous affair', 'adultery', 'affair', 'amour', 'concubinage', 'criminal conversation', 'entanglement', 'eternal triangle', 'extracurricular sex', 'extramarital relations', 'flirtation', 'forbidden love'],
    'cuckoo': ['philomel', 'ape', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bonkers', 'buggy', 'bughouse', 'bugs'],
    'cud': ['bite', 'bolus', 'cavendish', 'champ', 'chaw', 'chew', 'chewing tobacco', 'chomp', 'cut plug', 'eating tobacco', 'fid', 'gnash'],
    'cuddle': ['bill and coo', 'bundle', 'burrow', 'caress', 'cosset', 'croodle', 'cuddle up', 'curl up', 'dandle', 'embrace', 'enfold', 'fondle'],
    'cudgel': ['baste', 'bastinado', 'bat', 'baton', 'beat', 'belabor', 'belt', 'billy', 'billy club', 'birch', 'blackjack', 'bludgeon'],
    'cue': ['actor', 'advice', 'agate', 'aide-memoire', 'alerting', 'antagonist', 'antihero', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble'],
    'cuff': ['oregon boat', 'bat', 'bilbo', 'blip', 'blow', 'bond', 'bonds', 'box', 'box the ears', 'bridle', 'buffet', 'bust'],
    'cuisine': ['bakehouse', 'bakery', 'baking', 'barbecuing', 'basting', 'board', 'boiling', 'braising', 'bread', 'bread and butter', 'brewing', 'broil'],
    'cull': ['abscind', 'accumulate', 'amass', 'amputate', 'annihilate', 'assemble', 'ban', 'bar', 'bob', 'bolt', 'bring together', 'choose out'],
    'culminate': ['button up', 'cap', 'carry to completion', 'clean up', 'climax', 'close out', 'close up', 'complete', 'conclude', 'consummate', 'crest', 'crown'],
    'culminating': ['capping', 'closing', 'completing', 'completive', 'completory', 'concluding', 'conclusive', 'consummating', 'consummative', 'consummatory', 'crowning', 'culminative'],
    'culmination': ['accomplishment', 'acme', 'acme of perfection', 'apex', 'apodosis', 'apogee', 'bitter end', 'brow', 'cap', 'catastrophe', 'ceasing', 'cessation'],
    'culpability': ['arraignability', 'arraignableness', 'blameworthiness', 'bloody hands', 'burden', 'censurability', 'censurableness', 'chargeability', 'complicity', 'criminality', 'dirty hands', 'fault'],
    'culpable': ['accusable', 'amiss', 'arraignable', 'at fault', 'blamable', 'blameful', 'blameworthy', 'censurable', 'chargeable', 'criminal', 'faulty', 'guilty'],
    'cult': ['sabbatarianism', 'weltanschauung', 'adoration', 'articles of religion', 'catechism', 'celebration', 'ceremonialism', 'church', 'co-worship', 'communion', 'connection', 'credenda'],
    'cultism': ['sabbatarianism', 'adoration', 'celebration', 'ceremonialism', 'churchgoing', 'co-worship', 'conformity', 'cult', 'cultus', 'devotedness', 'devotion', 'devoutness'],
    'cultist': ['christian', 'christianlike', 'christianly', 'adoring', 'believer', 'believing', 'cultish', 'cultistic', 'devoted', 'devout', 'dutiful', 'faithful'],
    'cultivate': ['advance', 'ameliorate', 'apprentice', 'approach', 'backset', 'beautify', 'better', 'break', 'break in', 'break the ice', 'breed', 'bring up'],
    'cultivated': ['abstruse', 'advanced', 'ameliorated', 'aristocratic', 'beautified', 'bettered', 'civilized', 'converted', 'cosmopolitan', 'cultured', 'dainty', 'deep'],
    'cultivation': ['acculturation', 'acquired taste', 'agrarianism', 'agricultural geology', 'agriculture', 'agrology', 'agronomics', 'agronomy', 'appreciation of excellence', 'apprenticeship', 'architecture', 'assembly'],
    'cultural': ['autodidactic', 'coeducational', 'didactic', 'disciplinary', 'edifying', 'educating', 'educational', 'educative', 'enlightening', 'exhortatory', 'homiletic', 'hortatory'],
    'culture': ['acheulean', 'aurignacian', 'azilian', 'chellean', 'eolithic', 'neolithic', 'paleolithic', 'pre-chellean', 'solutrean', 'acculturation', 'acquired taste', 'agrarianism'],
    'cultured': ['abstruse', 'advanced', 'ameliorated', 'beautified', 'bettered', 'civilized', 'converted', 'cultivated', 'dainty', 'deep', 'delicate', 'developed'],
    'culvert': ['aqueduct', 'arroyo', 'bed', 'canal', 'creek bed', 'donga', 'dry bed', 'flume', 'gulch', 'gully', 'gullyhole', 'headrace'],
    'cumbersome': ['all thumbs', 'awkward', 'blunderheaded', 'blundering', 'boorish', 'bulky', 'bumbling', 'bungling', 'burdensome', 'butterfingered', 'careless', 'clownish'],
    'cumbrous': ['latinate', 'awkward', 'bombastic', 'bulky', 'burdensome', 'clogging', 'clumsy', 'cramped', 'cumbersome', 'elephantine', 'encumbering', 'forced'],
    'cumulate': ['accumulate', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'assemble', 'backlog', 'batch', 'bring together', 'bulk', 'bunch', 'bunch together'],
    'cumulation': ['abundance', 'accumulation', 'acervation', 'agglomerate', 'agglomeration', 'aggregate', 'aggregation', 'amassment', 'assembling', 'backlog', 'bringing together', 'budget'],
    'cumulative': ['absolute', 'accumulated', 'accumulative', 'additional', 'additive', 'additory', 'adducible', 'admissible', 'advancing', 'amassed', 'attestative', 'attestive'],
    'cumulus': ['cloudcuckooland', 'alto-cumulus', 'alto-stratus', 'anvil cloud', 'banner cloud', 'billowy cloud', 'cap cloud', 'cirro-cumulus', 'cirro-fillum', 'cirro-nebula', 'cirro-stratus', 'cirro-velum'],
    'cuneiform': ['arrowhead', 'character', 'cuneate', 'cuneated', 'deltoid', 'demotic character', 'determinative', 'grammalogue', 'hieratic symbol', 'hieroglyph', 'hieroglyphic', 'hieroglyphics'],
    'cunning': ['byzantine', 'daedalian', 'machiavellian', 'machiavellianism', 'machiavellic', 'ability', 'acute', 'address', 'adept', 'adeptness', 'adroit', 'adroitness'],
    'cup': ['friday', 'friday the thirteenth', 'old mug', 'alveolation', 'alveolus', 'antrum', 'appointed lot', 'arch', 'armpit', 'astral influences', 'astrology', 'bail'],
    'cupboard': ['canterbury', 'archives', 'armoire', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase'],
    'cupid': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'astarte', 'ate', 'athena', 'bacchus', 'ceres'],
    'cupidity': ['acquisitiveness', 'avarice', 'avariciousness', 'avidity', 'avidness', 'covetousness', 'craving', 'desire', 'eagerness', 'frenzy of desire', 'fury of desire', 'gluttony'],
    'cupola': ['antenna tower', 'apse', 'arcade', 'arcature', 'arch', 'arched roof', 'archway', 'barbican', 'belfry', 'bell tower', 'camber', 'campanile'],
    'cupped': ['boat-shaped', 'boatlike', 'bowl-shaped', 'bowllike', 'cavelike', 'cavernous', 'concave', 'concaved', 'craterlike', 'cup-shaped', 'cymbiform', 'dish-shaped'],
    'cupping': ['aspiration', 'bleeding', 'bloodletting', 'broaching', 'drafting', 'drainage', 'draining', 'drawing', 'emptying', 'leeching', 'milking', 'phlebotomy'],
    'cur': ['animal', 'beast', 'bounder', 'dog', 'hound', 'hyena', 'insect', 'lurcher', 'mongrel', 'mutt', 'pariah dog', 'pig'],
    'curable': ['ameliorable', 'amendable', 'correctable', 'corrigible', 'emendable', 'fixable', 'improvable', 'medicable', 'mendable', 'reclaimable', 'recoverable', 'rectifiable'],
    'curacy': ['abbacy', 'advowson', 'archbishopric', 'archdeaconry', 'archiepiscopacy', 'archiepiscopate', 'benefice', 'bishopdom', 'bishopric', 'canonicate', 'canonry', 'cardinalship'],
    'curate': ['dd', 'doctor of divinity', 'grand penitentiary', 'holy father', 'holy joe', 'abbe', 'abuna', 'antipope', 'archbishop', 'archdeacon', 'archpriest', 'bishop'],
    'curative': ['adjuvant', 'alterative', 'analeptic', 'beneficial', 'corrective', 'curing', 'healing', 'helpful', 'iatric', 'invigorating', 'medicable', 'medicative'],
    'curator': ['mc', 'accountant', 'air warden', 'attendant', 'attorney', 'auditor', 'bailiff', 'bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliomane'],
    'curb': ['american stock exchange', 'amex', 'tarmac', 'tarvia', 'wall street', 'abstain', 'arrest', 'arrestation', 'asphalt', 'back band', 'backpedal', 'backstrap'],
    'curbstone': ['tarmac', 'tarvia', 'asphalt', 'bitumen', 'bituminous macadam', 'blacktop', 'border stone', 'brick', 'cement', 'cobble', 'cobblestone', 'concrete'],
    'curd': ['devonshire cream', 'albumen', 'batter', 'blood clot', 'bonnyclabber', 'butter', 'buttermilk', 'casein', 'certified milk', 'cheese', 'clabber', 'clot'],
    'curdle': ['beat up', 'cake', 'churn', 'clabber', 'clot', 'clump', 'cluster', 'coagulate', 'colloid', 'colloidize', 'concrete', 'condense'],
    'curdled': ['adhesive', 'amylaceous', 'caked', 'cakey', 'clabbered', 'clammy', 'clotted', 'coagulated', 'congealed', 'curded', 'doughy', 'gaumy'],
    'cure': ['administration', 'advowson', 'agency', 'agentship', 'aid', 'air-dry', 'alterative', 'ameliorate', 'analeptic', 'anhydrate', 'antidote', 'arrange'],
    'curing': ['anhydration', 'blast-freezing', 'bottling', 'brining', 'canning', 'corning', 'cure', 'dehydration', 'desiccation', 'dry-curing', 'drying', 'embalming'],
    'curio': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'abnormality', 'anomaly', 'bagatelle', 'bauble', 'bean', 'bibelot', 'bit'],
    'curiosity': ['abnormality', 'amazement', 'anomaly', 'ardor', 'astonishing thing', 'astonishment', 'bauble', 'bric-a-brac', 'cathexis', 'concern', 'concernment', 'concupiscence'],
    'curious': ['aberrant', 'abnormal', 'absurd', 'agape', 'agog', 'all agog', 'analytical', 'attentive', 'attracted', 'barmy', 'bizarre', 'burning with curiosity'],
    'curl': ['arc', 'arch', 'bend', 'bend back', 'bow', 'catacaustic', 'catenary', 'caustic', 'circle', 'cirrus', 'coil', 'conchoid'],
    'curl up': ['bed', 'bed down', 'bundle', 'couch', 'croodle', 'cuddle', 'cuddle up', 'go to bed', 'go to rest', 'lie down', 'loll', 'lounge'],
    'curlicue': ['cirrus', 'coil', 'corkscrew', 'curl', 'evolute', 'gyre', 'helix', 'involute', 'kink', 'ringlet', 'roll', 'screw'],
    'currency': ['pr', 'and pence', 'averageness', 'ballyhoo', 'blurb', 'bon ton', 'bright light', 'cash', 'celebrity', 'circulating medium', 'coin', 'coinage'],
    'current': ['ac', 'brownian movement', 'dc', 'zeitgeist', 'a la mode', 'absorption current', 'accepted', 'accessible', 'accidental', 'accompanying', 'accustomed', 'active current'],
    'curriculum': ['academic specialty', 'area', 'classical education', 'core curriculum', 'course', 'course of study', 'discipline', 'elective', 'field', 'general education', 'general studies', 'humanities'],
    'curried': ['baked', 'boiled', 'braised', 'brisk', 'broiled', 'browned', 'burning', 'coddled', 'cooked', 'deviled', 'fired', 'fricasseed'],
    'curry': ['irish stew', 'bake', 'barbecue', 'baste', 'bed', 'bed down', 'blanch', 'boil', 'bouillabaisse', 'braise', 'break', 'brew'],
    'curse': ['jonah', 'abuse', 'accurse', 'adverse circumstances', 'adversity', 'afflict', 'affliction', 'aggravation', 'aggrieve', 'anathema', 'anathematize', 'annoyance'],
    'cursed': ['accursed', 'blankety-blank', 'blasted', 'blessed', 'confounded', 'cussed', 'damn', 'damnable', 'damned', 'demoniac', 'demonic', 'devilish'],
    'cursing': ['rabelaisian', 'abusive', 'bad language', 'billingsgate', 'blasphemous', 'blue language', 'calumniatory', 'calumnious', 'colorful language', 'comminatory', 'contumelious', 'cussing'],
    'cursive': ['italian hand', 'spencerian writing', 'autograph', 'autographic', 'block letter', 'bold hand', 'book hand', 'calligraphic', 'chancery hand', 'chirographic', 'copperplate hand', 'cursive hand'],
    'cursory': ['airy', 'ankle-deep', 'at odds', 'averse', 'brief', 'careless', 'casual', 'degage', 'depthless', 'desultory', 'differing', 'disagreeing'],
    'curt': ['spartan', 'abbreviated', 'abridged', 'abrupt', 'aggressive', 'aposiopestic', 'bearish', 'beastly', 'bluff', 'blunt', 'brash', 'brief'],
    'curtail': ['abate', 'abbreviate', 'abrade', 'abridge', 'abstract', 'arrest', 'bate', 'bereave', 'bleed', 'bob', 'boil down', 'bridle'],
    'curtailed': ['abated', 'abbreviated', 'ablated', 'abridged', 'abstracted', 'attenuated', 'bated', 'belittled', 'bobbed', 'capsule', 'capsulized', 'clipped'],
    'curtailment': ['abbreviation', 'abridgment', 'abstract', 'apocope', 'arrest', 'arrestation', 'astriction', 'astringency', 'attrition', 'bereavement', 'bottleneck', 'cervix'],
    'curtain': ['abatis', 'act', 'act drop', 'advanced work', 'afterpiece', 'apodosis', 'apply to', 'asbestos', 'asbestos board', 'awning', 'backdrop', 'balistraria'],
    'curtain call': ['act', 'afterpiece', 'bit', 'chaser', 'curtain', 'curtain raiser', 'divertimento', 'divertissement', 'epilogue', 'exode', 'exodus', 'expository scene'],
    'curtain raiser': ['vorspiel', 'act', 'afterpiece', 'bit', 'chaser', 'coming out', 'concert overture', 'curtain', 'curtain call', 'debut', 'descant', 'divertimento'],
    'curtains': ['annihilation', 'apodosis', 'bane', 'biological death', 'catastrophe', 'ceasing', 'cessation', 'cessation of life', 'clinical death', 'coda', 'conclusion', 'consummation'],
    'curtly': ['abruptly', 'aphoristically', 'bearishly', 'bluffly', 'bluntly', 'boorishly', 'brashly', 'briefly', 'brusquely', 'cavalierly', 'churlishly', 'compendiously'],
    'curtness': ['abruptness', 'aggressiveness', 'bearishness', 'beastliness', 'bluntness', 'boorishness', 'brachylogy', 'brashness', 'brevity', 'briefness', 'brusqueness', 'brusquerie'],
    'curtsy': ['accost', 'address', 'bend', 'bend the knee', 'bend the neck', 'bend to', 'bending the knee', 'bid good day', 'bid good morning', 'bob', 'bob a curtsy', 'bob down'],
    'curvaceous': ['junoesque', 'agreeable', 'amply endowed', 'attractive', 'becoming', 'bent', 'billowing', 'billowy', 'bonny', 'braw', 'built', 'built for comfort'],
    'curve': ['aberrancy', 'aberration', 'arc', 'arch', 'artful dodge', 'artifice', 'bag of tricks', 'bear off', 'bend', 'bend back', 'bias', 'blind'],
    'curved': ['arched', 'arciform', 'bending', 'bent', 'billowing', 'billowy', 'bowed', 'curvaceous', 'curvate', 'curvated', 'curve', 'curvesome'],
    'curvy': ['junoesque', 'agreeable', 'amply endowed', 'becoming', 'bendy', 'bent', 'billowing', 'billowy', 'bonny', 'braw', 'built', 'built for comfort'],
    'cushion': ['abate', 'absorb', 'absorb the shock', 'acoustic tile', 'aegis', 'afford support', 'air mattress', 'allay', 'alleviate', 'alleviative', 'alleviator', 'anesthetize'],
    'cushioned': ['comfortable', 'comfy', 'commodious', 'contented', 'convenient', 'cozy', 'cushiony', 'cushy', 'easeful', 'easy', 'friendly', 'homelike'],
    'cushioning': ['abating', 'allaying', 'alleviating', 'assuaging', 'blunting', 'chastening', 'dampening', 'damping', 'deadening', 'diminishing', 'dulling', 'easing'],
    'cushy': ['mickey mouse', 'casual', 'clear', 'comfortable', 'comfy', 'commodious', 'contented', 'convenient', 'cozy', 'cushioned', 'cushiony', 'easeful'],
    'cuspid': ['baby tooth', 'bicuspid', 'bucktooth', 'canine', 'crown', 'cutter', 'deciduous tooth', 'dent', 'denticle', 'denticulation', 'dentil', 'dentition'],
    'cuss': ['bloke', 'boy', 'buck', 'chap', 'curse', 'curse and swear', 'cuss word', 'damn', 'dirty name', 'dirty word', 'dysphemism', 'dysphemize'],
    'cuss out': ['abuse', 'bawl out', 'blackguard', 'call names', 'chew', 'chew ass', 'chew out', 'damn', 'epithet', 'epithetize', 'give a going-over', 'give hail columbia'],
    'cussed': ['baleful', 'bearish', 'bitchy', 'blankety-blank', 'blasted', 'blessed', 'cankered', 'cantankerous', 'churlish', 'confounded', 'crabbed', 'cranky'],
    'cussedness': ['bearishness', 'bitchiness', 'cantankerousness', 'churlishness', 'contrariness', 'crabbedness', 'crankiness', 'crossness', 'crustiness', 'devilment', 'devilry', 'deviltry'],
    'custodial': ['argus-eyed', 'all ears', 'all eyes', 'aux aguets', 'covering', 'defensive', 'eagle-eyed', 'fostering', 'guarded', 'guardian', 'guarding', 'hawk-eyed'],
    'custodian': ['mc', 'air warden', 'attendant', 'attorney', 'bailiff', 'bull', 'butler', 'caretaker', 'castellan', 'cerberus', 'char', 'charwoman'],
    'custody': ['administration', 'auspices', 'captainship', 'care', 'chairmanship', 'charge', 'cold storage', 'confinement', 'conservation', 'convenership', 'cure', 'custodianship'],
    'custom': ['mishnah', 'spiritus mundi', 'sunna', 'talmud', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'ancient wisdom'],
    'custom made': ['assembled', 'bespoke', 'built', 'cast', 'constructed', 'crafted', 'created', 'custom', 'custom-built', 'extracted', 'fabricated', 'fashioned'],
    'customarily': ['according to use', 'accustomedly', 'as a rule', 'as is proper', 'as is usual', 'as per usual', 'as things go', 'as usual', 'chiefly', 'comme il faut', 'commonly', 'consistently'],
    'customary': ['christian', 'accepted', 'accustomed', 'acknowledged', 'admitted', 'approved', 'authentic', 'authoritative', 'average', 'being done', 'canonical', 'chronic'],
    'customer': ['adamite', 'being', 'bloke', 'body', 'buyer', 'cat', 'chap', 'character', 'client', 'consumer', 'creature', 'duck'],
    'customize': ['customise', 'custom-make'],
    'customs': ['internal revenue service', 'vat', 'ad valorem duty', 'alcohol tax', 'amusement tax', 'assessment on default', 'assessor', 'capital gains tax', 'capitation', 'capitation tax', 'corporation tax', 'customhouse'],
    'cut': ['awol', 'french leave', 'parthian shot', 'platonic form', 'platonic idea', 'spartan', 'vandyke', 'abandon', 'abate', 'abatement', 'abbreviate', 'abbreviated'],
    'cut across': ['bar', 'catercorner', 'chiasmal', 'chiasmic', 'chiastic', 'crisscross', 'cross', 'crossbar', 'crosscut', 'crossed', 'crossing', 'cruciate'],
    'cut back': ['abbreviate', 'abridge', 'abstract', 'bob', 'boil down', 'capsulize', 'clip', 'compress', 'condense', 'contract', 'crop', 'curtail'],
    'cut corners': ['blink', 'carefully ignore', 'cold-shoulder', 'curtail expenses', 'cut a corner', 'cut across', 'cut back', 'cut down', 'cut through', 'dodge', 'fudge', 'make a beeline'],
    'cut down': ['abbreviate', 'abridge', 'abstract', 'annihilate', 'beat down', 'bereave of life', 'blow down', 'blow over', 'blow to pieces', 'blow up', 'bob', 'boil down'],
    'cut in': ['barge in', 'break in', 'break in upon', 'burst in', 'butt in', 'charge in', 'chime in', 'chip in', 'come between', 'crash', 'crash in', 'crash the gates'],
    'cut it out': ['abandon', 'abort', 'belay', 'cancel', 'cease', 'desist', 'discontinue', 'drop it', 'end', 'give over', 'halt', 'have done with'],
    'cut loose': ['bail out', 'board', 'boom', 'break away', 'break jail', 'break loose', 'break out', 'carouse', 'cast loose', 'celebrate', 'clap on ratlines', 'clear'],
    'cut off': ['abridge', 'abrupt', 'abscind', 'alienate', 'amputate', 'annihilate', 'ax', 'ban', 'bar', 'bar out', 'bereave', 'bereave of life'],
    'cut out': ['abjure', 'abrupt', 'abscind', 'abstract', 'act for', 'alienate', 'amputate', 'annihilate', 'arrange', 'avulse', 'ban', 'bar'],
    'cut short': ['abbreviate', 'abbreviated', 'abridge', 'abridged', 'abstract', 'abstracted', 'arrest', 'block', 'bob', 'bobbed', 'boil down', 'brake'],
    'cut the mustard': ['be able', 'be up to', 'can', 'can do', 'clear', 'clear the hurdle', 'come along', 'come on', 'contrive', 'cut it', 'engineer', 'get along'],
    'cut up': ['act up', 'afflict', 'aggrieve', 'anguish', 'antic', 'apportion', 'barb the dart', 'behave ill', 'break down', 'bring to tears', 'broken-down', 'brokenhearted'],
    'cutaneous': ['cortical', 'dermal', 'dermic', 'ecderonic', 'ectodermal', 'ectodermic', 'endermatic', 'endermic', 'epicarpal', 'epidermal', 'epidermic', 'furry'],
    'cutback': ['cheeseparing', 'cooling', 'cooling down', 'cooling off', 'curtailment', 'cut', 'economization', 'economizing', 'low growth rate', 'pullback', 'reduction of expenses', 'reduction of spending'],
    'cute': ['daedalian', 'machiavellian', 'machiavellic', 'acute', 'adept', 'adorable', 'adroit', 'apt', 'arch', 'artful', 'artistic', 'astute'],
    'cuticle': ['leatherette', 'leatheroid', 'coat', 'dermis', 'fell', 'fleece', 'flesh', 'fur', 'furring', 'hide', 'imitation fur', 'imitation leather'],
    'cutie': ['babe', 'baby', 'broad', 'chick', 'colleen', 'dame', 'damoiselle', 'damsel', 'demoiselle', 'doll', 'filly', 'frail'],
    'cutlery': ['ax', 'blade', 'cold steel', 'cutter', 'dagger', 'dining utensils', 'edge tools', 'flat silver', 'flatware', 'forks', 'hollow ware', 'knife'],
    'cutoff': ['air line', 'arrest', 'beeline', 'bell', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bourn', 'break boundary', 'breakoff point'],
    'cutter': ['abridger', 'abstracter', 'analyzer', 'ax', 'baby tooth', 'bicuspid', 'blade', 'breaker', 'bucktooth', 'canine', 'centrifuge', 'cold steel'],
    'cutthroat': ['cain', 'apache', 'assassin', 'assassinator', 'barbaric', 'barbarous', 'bloodletter', 'bloodshedder', 'bloodthirsty', 'bloody', 'bloody-minded', 'bravo'],
    'cutting': ['ic analysis', 'siberian', 'abbreviation', 'abscission', 'accidence', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous'],
    'cutting remark': ['parthian shot', 'back answer', 'caustic remark', 'comeback', 'crack', 'cut', 'dig', 'dump', 'fleer', 'flout', 'foolery', 'gibe'],
    'cutup': ['bad boy', 'banana', 'booger', 'buffoon', 'bugger', 'burlesquer', 'caricaturist', 'carouser', 'clown', 'comedian', 'comic', 'contestant'],
    'cwm': ['abysm', 'abyss', 'arroyo', 'box canyon', 'breach', 'break', 'canyon', 'cavity', 'chap', 'chasm', 'check', 'chimney'],
    'cyanosis': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'azure', 'azureness'],
    'cybele': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'cybernation': ['action', 'automatic control', 'automation', 'automatism', 'automatization', 'cascade control', 'control action', 'electronic control', 'feedback control', 'robot control', 'self-action', 'self-activity'],
    'cybernetics': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'automatic electronics', 'autonetics', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science'],
    'cyclamates': ['ambrosia', 'artificial sweetener', 'blackstrap', 'calcium cyclamate', 'cane syrup', 'clover honey', 'comb honey', 'corn syrup', 'edulcoration', 'honey', 'honeycomb', 'honeydew'],
    'cycle': ['ac', 'af', 'cps', 'dc', 'ehf', 'hf', 'hz', 'indian file', 'kekule formula', 'mf', 'platonic year', 'rf'],
    'cyclic': ['alternate', 'annular', 'annulate', 'annulose', 'articulated', 'atomatic', 'atomic', 'atomiferous', 'atomistic', 'beating', 'catenated', 'ceaseless'],
    'cyclical': ['alternate', 'annular', 'annulate', 'annulose', 'articulated', 'atomatic', 'atomic', 'atomiferous', 'atomistic', 'beating', 'catenated', 'ceaseless'],
    'cyclone': ['air mass', 'anticyclone', 'baguio', 'blaze', 'burst', 'cold front', 'cold sector', 'convulsion', 'dirty weather', 'dust devil', 'eruption', 'explosion'],
    'cyclonic': ['aerographic', 'aerologic', 'angry', 'baric', 'barographic', 'barometric', 'circumgyratory', 'circumvolutory', 'climatologic', 'cloudy', 'dirty', 'elemental'],
    'cyclopean': ['antaean', 'atlantean', 'briarean', 'brobdingnagian', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'astronomic', 'colossal', 'elephantine', 'enormous'],
    'cyclopedia': ['atlas', 'bibliography', 'body of knowledge', 'body of learning', 'calendar', 'casebook', 'catalog', 'catalogue raisonne', 'city directory', 'classified catalog', 'concordance', 'diatesseron'],
    'cyclorama': ['abstract', 'abstraction', 'act drop', 'altarpiece', 'asbestos', 'asbestos board', 'backdrop', 'batten', 'block print', 'border', 'cloth', 'collage'],
    'cygnet': ['avifauna', 'baby bird', 'bird', 'bird of jove', 'bird of juno', 'bird of minerva', 'bird of night', 'bird of passage', 'bird of prey', 'birdie', 'birdlife', 'birdy'],
    'cymbal': ['apple fritter', 'battery', 'beignet', 'beignet aux pommes', 'bells', 'bismarck', 'bones', 'castanets', 'celesta', 'chime', 'chimes', 'clappers'],
    'cynic': ['cassandra', 'eeyore', 'thersites', 'backbiter', 'belittler', 'calamity howler', 'calumniator', 'caustic critic', 'debunker', 'decrier', 'defamer', 'defeatist'],
    'cynical': ['cassandra-like', 'cassandran', 'cassandrian', 'rabelaisian', 'timonistic', 'antisocial', 'captious', 'carping', 'caustic', 'caviling', 'critical', 'defeatist'],
    'cynicism': ['timonism', 'antisocial sentiments', 'antisociality', 'causticity', 'defeatism', 'dismalness', 'gloominess', 'gloomy outlook', 'innuendo', 'invective', 'irony', 'malism'],
    'cynosure': ['north star', 'polaris', 'acme', 'adductor', 'apotheosis', 'attractant', 'attrahent', 'beau ideal', 'best type', 'big name', 'celebrity', 'center'],
    'cyst': ['benign tumor', 'boil', 'bump', 'bunion', 'callosity', 'callus', 'cancer', 'carbuncle', 'carcinoma', 'corn', 'dilatation', 'dilation'],
    'cytology': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology', 'biometrics'],
    'cytoplasm': ['animal cell', 'bioplast', 'cell', 'cellular tissue', 'cellule', 'chromatoplasm', 'coenocyte', 'corpuscle', 'ectoplasm', 'endoplasm', 'energid', 'eucaryotic cell'],
    'czar': ['dalai lama', 'holy roman emperor', 'inca', 'kaiser', 'simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'ardri', 'arrogator', 'autarch', 'autocrat'],
    'da': ['ag', 'kc', 'qc', 'ssc', 'us attorney', 'attorney general', 'civilian', 'corporation lawyer', 'court-appointed lawyer', 'criminal lawyer', 'defense counsel', 'district attorney'],
    'dab': ['ace', 'adept', 'apply paint', 'atom', 'authority', 'beak', 'bedaub', 'bedizen', 'begild', 'besmear', 'bit', 'bloodstain'],
    'dabble': ['asperge', 'be innocent of', 'bedabble', 'bedew', 'beguile the time', 'bespatter', 'besprinkle', 'burn daylight', 'consume time', 'coquet', 'coquet with', 'dally'],
    'dabbler': ['sunday painter', 'abecedarian', 'amateur', 'coquet', 'criticaster', 'dabster', 'dallier', 'dilettante', 'dunce', 'flirt', 'fool', 'fribble'],
    'dacha': ['dymaxion house', 'white house', 'adobe house', 'building', 'casa', 'cliff dwelling', 'consulate', 'country house', 'country seat', 'deanery', 'dwelling house', 'edifice'],
    'dactyl': ['alexandrine', 'accent', 'accentuation', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antispast', 'arsis', 'bacchius', 'beat', 'cadence'],
    'dad': ['methuselah', 'abba', 'antediluvian', 'antique', 'back number', 'conservative', 'daddy', 'dodo', 'elder', 'father', 'fogy', 'fossil'],
    'daddy': ['abba', 'dad', 'father', 'foster father', 'genitor', 'governor', 'old man', 'pa', 'pap', 'papa', 'pappy', 'pater'],
    'daddy longlegs': ['arachnid', 'arthropod', 'beetle', 'bug', 'caterpillar', 'centipede', 'chilopod', 'diplopod', 'fly', 'harvestman', 'hexapod', 'insect'],
    'dado': ['baluster', 'balustrade', 'banister', 'base', 'baseboard', 'basement', 'bezel', 'canal', 'canalize', 'carve', 'caryatid', 'chamfer'],
    'daedal': ['byzantine', 'daedalian', 'adept', 'adroit', 'apt', 'artistic', 'authoritative', 'balled up', 'bicolor', 'bicolored', 'bravura', 'brilliant'],
    'daemon': ['geist', 'muse', 'afflatus', 'ancestral spirits', 'angel', 'attendant godling', 'atua', 'control', 'creative thought', 'creativity', 'daimonion', 'demon'],
    'daffy': ['apish', 'asinine', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'befooled', 'beguiled', 'besotted', 'bonkers'],
    'daft': ['abnormal', 'absurd', 'apish', 'asinine', 'batty', 'bedlamite', 'befooled', 'beguiled', 'bereft of reason', 'besotted', 'boneheaded', 'brainless'],
    'daftness': ['aberration', 'abnormality', 'alienation', 'brain damage', 'brainsickness', 'clouded mind', 'craziness', 'dementedness', 'dementia', 'derangement', 'disorientation', 'distraction'],
    'dagger': ['calvary cross', 'christogram', 'greek cross', 'jerusalem cross', 'latin cross', 'maltese cross', 'russian cross', 'ankh', 'avellan cross', 'ax', 'bayonet', 'blade'],
    'dago': ['aussie', 'boche', 'canuck', 'chink', 'guinea', 'hunk', 'hunkie', 'jerry', 'kraut', 'krauthead', 'mick', 'mickey'],
    'daily': ['always', 'annual', 'at all times', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'ceaselessly', 'centenary', 'centennial', 'circadian'],
    'daily bread': ['tlc', 'board', 'bread', 'bread and butter', 'care', 'cheer', 'comestibles', 'creature comfort', 'cuisine', 'eatables', 'economic support', 'edibles'],
    'daintiness': ['acquired taste', 'airiness', 'amiable weakness', 'appreciation of excellence', 'ascent', 'asepsis', 'breakability', 'brittleness', 'bubbliness', 'buoyancy', 'changeableness', 'choiceness'],
    'dainty': ['acute', 'agreeable', 'airy', 'ambrosia', 'ambrosial', 'appetizing', 'attenuate', 'attenuated', 'beautiful', 'bleached', 'bonne bouche', 'bonny'],
    'dairy': ['appetizing store', 'armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bakery', 'bakeshop', 'bindery', 'boatyard', 'bodega', 'boilery'],
    'dairy farmer': ['breaker', 'breeder', 'broncobuster', 'buckaroo', 'cattleman', 'cow keeper', 'cowman', 'dairyman', 'equerry', 'farrier', 'grazier', 'groom'],
    'dairy farming': ['animal husbandry', 'animal rearing', 'bee culture', 'beekeeping', 'breeding', 'cattle-ranching', 'chicken-farming', 'dressage', 'gnotobiotics', 'grazing', 'herding', 'horse training'],
    'dairy products': ['butter', 'buttermilk', 'certified milk', 'cheese', 'condensed milk', 'cream', 'ghee', 'half-and-half', 'heavy cream', 'light cream', 'margarine', 'milk'],
    'dais': ['balcony', 'bench', 'catafalque', 'chair', 'curule chair', 'emplacement', 'estrade', 'floor', 'gallery', 'heliport', 'helm', 'hustings'],
    'daisy': ['ace', 'beaut', 'corker', 'crackerjack', 'dandy', 'darb', 'dilly', 'dream', 'honey', 'humdinger', 'killer-diller', 'knockout'],
    'dalai lama': ['grand lama', 'holy roman emperor', 'inca', 'kaiser', 'panchen lama', 'ardri', 'bey', 'bhikku', 'bonze', 'cacique', 'caesar', 'cham'],
    'dale': ['bottom', 'bottom glade', 'bottoms', 'combe', 'dell', 'dingle', 'gap', 'gill', 'glen', 'grove', 'intervale', 'lunar rill'],
    'dalliance': ['amorous dalliance', 'amorous looks', 'billing and cooing', 'bundling', 'caressing', 'come-hither look', 'coquetry', 'coquettish glances', 'coquettishness', 'coyness', 'cuddling', 'dabbling'],
    'dally': ['abide', 'await', 'bide', 'bide the issue', 'bill and coo', 'caress', 'copulate', 'coquet', 'cosset', 'cuddle', 'dabble', 'dally away'],
    'dallying': ['micawberish', 'backward', 'coquetry', 'dabbling', 'dalliance', 'dawdling', 'delaying', 'dilatoriness', 'dilatory', 'dillydallying', 'dolce far niente', 'dragging'],
    'dam': ['arch dam', 'arrest', 'artificial lake', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier', 'bayou lake', 'bear-trap dam', 'beaver dam'],
    'damage': ['abomination', 'abuse', 'afflict', 'aggravate', 'aggrieve', 'amount', 'atrocity', 'bad', 'bane', 'bankruptcy', 'befoul', 'befoulment'],
    'damaged': ['adulterated', 'aggravated', 'blemished', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped', 'cracked', 'crazed', 'cut'],
    'damages': ['amends', 'amercement', 'atonement', 'blood money', 'compensation', 'consideration', 'distraint', 'distress', 'escheat', 'escheatment', 'fine', 'forfeit'],
    'damaging': ['bad', 'baleful', 'baneful', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'counterproductive', 'deadly', 'deleterious', 'detrimental', 'disadvantageous'],
    'dame': ['eve', 'frau', 'fraulein', 'jane', 'miss', 'mistress', 'mlle', 'mme', 'mmes', 'abbess', 'archduchess', 'babe'],
    'damn': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'abominate', 'abuse', 'accurse', 'accursed', 'accuse', 'ace', 'anathematize'],
    'damnable': ['abhorrent', 'abominable', 'absolute', 'accursed', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'black', 'blamable', 'blamed'],
    'damnation': ['anathema', 'anathematizing', 'arraignment', 'ban', 'blame', 'blasphemy', 'bloodbath', 'blue ruin', 'breakup', 'carnage', 'castigation', 'censure'],
    'damnatory': ['rabelaisian', 'abusive', 'blackening', 'blameful', 'blasphemous', 'calumniatory', 'calumnious', 'censorious', 'comminatory', 'condemnatory', 'contemptuous', 'contumelious'],
    'damned': ['absolute', 'accursed', 'awful', 'awfully', 'big', 'blamed', 'blankety-blank', 'blasted', 'bleeding', 'blessed', 'blighted', 'blinding'],
    'damning': ['absolute', 'adducible', 'admissible', 'attestative', 'attestive', 'authentic', 'based on', 'certain', 'circumstantial', 'conclusive', 'convincing', 'cumulative'],
    'damp': ['abate', 'abridge', 'absorb the shock', 'acoustic tile', 'afterdamp', 'allay', 'alleviate', 'antiknock', 'arrest', 'asperge', 'asphyxiate', 'assimilate to'],
    'dampen': ['abate', 'abridge', 'absorb the shock', 'allay', 'alleviate', 'arrest', 'asperge', 'assuage', 'attemper', 'attenuate', 'baffle', 'bank the fire'],
    'damper': ['acoustic tile', 'andiron', 'antiknock', 'arrest', 'baffler', 'bearing rein', 'bit', 'brake', 'chain', 'check', 'checkrein', 'chill'],
    'dampness': ['bogginess', 'damp', 'dewiness', 'exudation', 'fogginess', 'humectation', 'humor', 'marshiness', 'mistiness', 'moistiness', 'moistness', 'moisture'],
    'damsel': ['babe', 'baby', 'broad', 'chick', 'colleen', 'cutie', 'dame', 'damoiselle', 'demoiselle', 'doll', 'filly', 'frail'],
    'dance': ['charleston', 'highland fling', 'lambeth walk', 'mexican hat dance', 'portland fancy', 'virginia reel', 'watusi', 'acid rock', 'allemande', 'antic', 'arabesque', 'assemblee'],
    'dance hall': ['amphitheater', 'amusement park', 'arena', 'assembly hall', 'auditorium', 'ballroom', 'cabaret', 'cafe chantant', 'cafe dansant', 'casino', 'chapel', 'concert hall'],
    'dancer': ['artist', 'artiste', 'ballerina', 'ballet dancer', 'ballet girl', 'ballroom dancer', 'belly dancer', 'burlesque queen', 'choral dancer', 'chorine', 'chorus boy', 'chorus girl'],
    'dancing': ['aflicker', 'balletic', 'beaming', 'beatific', 'beatified', 'bickering', 'blessed', 'blinking', 'blissful', 'capering', 'cheerful', 'chirping'],
    'dandruff': ['carrion', 'chip', 'corruption', 'decay', 'excrement', 'filth', 'flake', 'floccule', 'flocculus', 'flock', 'foul matter', 'furfur'],
    'dandy': ['beau brummel', 'ok', 'ace', 'ace-high', 'arbiter of fashion', 'bad', 'bang-up', 'beau', 'beaut', 'blade', 'blood', 'bonzer'],
    'danger': ['dangerous ground', 'desultoriness', 'emergency', 'exigency', 'hazard', 'in danger of', 'infirmity', 'insecurity', 'insolidity', 'instability', 'insubstantiality', 'jeopardy'],
    'danger sign': ['early symptom', 'falling barometer', 'gathering clouds', 'high sign', 'omen', 'precursor', 'preliminary sign', 'premonitory sign', 'premonitory symptom', 'prodroma', 'prodrome', 'quarantine flag'],
    'dangerous': ['alarming', 'bad', 'chance', 'chancy', 'critical', 'dangersome', 'desultory', 'explosive', 'fell', 'fraught with danger', 'grievous', 'hairy'],
    'dangle': ['advertise', 'affect', 'air', 'around', 'bag', 'betoken', 'blazon forth', 'bob', 'bobble', 'brandish', 'breathe', 'bring forth'],
    'dangling': ['bagging', 'baggy', 'careening', 'cascading', 'danglement', 'dependence', 'dependency', 'dependent', 'depending', 'drooping', 'easy', 'falling'],
    'danish pastry': ['danish', 'english muffin', 'french pastry', 'parker house roll', 'yorkshire pudding', 'bagel', 'baklava', 'bialy', 'bialystoker', 'blintz', 'bun', 'chocolate eclair'],
    'dank': ['boggy', 'damp', 'dampish', 'dewy', 'fenny', 'humid', 'marshy', 'moist', 'muggy', 'rainy', 'roric', 'roriferous'],
    'dapper': ['bandbox', 'braw', 'chic', 'chichi', 'classy', 'clothes-conscious', 'cosmopolitan', 'dashing', 'doggy', 'dressed to advantage', 'dressed to kill', 'dressy'],
    'dapple': ['quaker-colored', 'acier', 'ashen', 'ashy', 'band', 'bar', 'bespangle', 'bespeckle', 'bespot', 'birthmark', 'blaze', 'blaze a trail'],
    'dapple gray': ['quaker-colored', 'acier', 'ashen', 'ashy', 'bay', 'bayard', 'buckskin', 'calico pony', 'canescent', 'chestnut', 'cinereous', 'cinerous'],
    'dappled': ['quaker-colored', 'acier', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'ashen', 'ashy', 'blended', 'calico', 'canescent', 'cinereous'],
    'dare': ['affront', 'aim to', 'assume', 'attempt', 'attempt to', 'battle cry', 'be a man', 'beard', 'bid defiance', 'bid to combat', 'brave', 'breast'],
    'daredevil': ['adventurer', 'adventuresome', 'adventuress', 'adventurous', 'audacious', 'bold', 'brave', 'brazenface', 'courageous', 'daring', 'dashing', 'death-defying'],
    'daresay': ['account as', 'assume', 'be afraid', 'believe', 'conceive', 'conclude', 'consider', 'deduce', 'deem', 'divine', 'dream', 'esteem'],
    'daring': ['adventuresome', 'adventuresomeness', 'adventurous', 'adventurousness', 'arrogance', 'arrogant', 'audacious', 'audaciousness', 'audacity', 'balls', 'blazon', 'bold'],
    'daringly': ['audaciously', 'boldly', 'bravely', 'bulldoggishly', 'chivalrously', 'courageously', 'dashingly', 'doughtily', 'fearlessly', 'flashily', 'flauntingly', 'foolhardily'],
    'dark': ['egyptian darkness', 'erebus', 'gothicism', 'stygian', 'ableptical', 'abominable', 'abstruse', 'adiaphanous', 'age of ignorance', 'amaurotic', 'amoral', 'amorphous'],
    'dark cloud': ['black magellanic cloud', 'crab nebula', 'angry clouds', 'black cat', 'black clouds', 'bright diffuse nebula', 'broken mirror', 'coalsack', 'dark nebula', 'diffuse nebula', 'dust cloud', 'gaseous nebula'],
    'dark horse': ['also-ran', 'aspirant', 'baby kisser', 'bare possibility', 'candidate', 'defeated candidate', 'dud', 'enigma', 'favorite son', 'fighting chance', 'frontier', 'frontiers of knowledge'],
    'darken': ['attaint', 'bandage', 'beat down', 'becloud', 'bedarken', 'bedaub', 'bedazzle', 'bedim', 'befog', 'begloom', 'bemist', 'benight'],
    'darkened': ['bedazzled', 'besmirched', 'blackened', 'blindfold', 'blindfolded', 'dazed', 'dazzled', 'discolored', 'excecate', 'foxed', 'foxy', 'hoodwinked'],
    'darkening': ['blackening', 'blocking the light', 'burial', 'burying', 'clouding', 'concealedness', 'concealment', 'covering', 'covering up', 'covertness', 'deception', 'denigration'],
    'darkish': ['blackish', 'dark', 'dark-colored', 'darksome', 'dim', 'dimmish', 'dimpsy', 'dusk', 'dusky', 'funereal', 'grave', 'murk'],
    'darkness': ['gothicism', 'ablepsia', 'adiaphanousness', 'age of ignorance', 'amaurosis', 'amorphousness', 'barbarism', 'benightedness', 'benightment', 'blackishness', 'blackness', 'bleakness'],
    'darky': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'darling': ['admired', 'adorable', 'adored', 'alluring', 'ambrosial', 'angel', 'attractive', 'babe', 'baby', 'baby-doll', 'bairn', 'beloved'],
    'darn': ['absolute', 'accurse', 'anathematize', 'blamed', 'blankety-blank', 'blaspheme', 'blast', 'blasted', 'blessed', 'cobble', 'commission', 'condition'],
    'dart': ['antelope', 'arrow', 'arrowhead', 'barb', 'beesting', 'blue darter', 'blue streak', 'bobtailed arrow', 'bolt', 'bowl', 'bustle', 'buzz about'],
    'dash': ['le mans', 'abruptly', 'aggressiveness', 'air race', 'animation', 'ardor', 'asperge', 'automobile race', 'baffle', 'bafflement', 'balk', 'band'],
    'dash off': ['ad-lib', 'author', 'bat out', 'botch', 'bundle', 'bungle', 'bustle', 'cartoon', 'chalk', 'charcoal', 'chase', 'coauthor'],
    'dashed': ['absolute', 'baffled', 'balked', 'betrayed', 'bilked', 'blamed', 'blankety-blank', 'blasted', 'blessed', 'blighted', 'bowed-down', 'cast down'],
    'dashed hope': ['bafflement', 'balk', 'betrayed hope', 'blasted expectation', 'blighted hope', 'blow', 'buffet', 'comedown', 'cruel disappointment', 'dash', 'dashed hopes', 'defeat'],
    'dashing': ['agile', 'alert', 'animate', 'animated', 'brave', 'bravura', 'braw', 'breakneck', 'bright', 'chic', 'chichi', 'classy'],
    'data': ['algol', 'cobol', 'fortran', 'festschrift', 'a priori principle', 'account', 'acquaintance', 'affirmation', 'alphabetic data', 'alphanumeric code', 'ana', 'angular data'],
    'date': ['international date line', 'platonic year', 'accompany', 'aeon', 'age', 'ancient', 'annus magnus', 'antedate', 'antiquate', 'antiquated', 'appointment', 'archaic'],
    'dated': ['ago', 'ahead of time', 'anachronistic', 'annalistic', 'antedated', 'antiquated', 'antique', 'archaic', 'back-number', 'beforehand', 'behind the times', 'behind time'],
    'dateless': ['age-old', 'ageless', 'ancient', 'antique', 'auld', 'ceaseless', 'coeternal', 'constant', 'continual', 'continuous', 'elderly', 'endless'],
    'datum': ['absolute fact', 'accepted fact', 'account', 'acquaintance', 'actual fact', 'admitted fact', 'announcement', 'article', 'aspect', 'axiom', 'bald fact', 'bare fact'],
    'daub': ['abstract', 'abstraction', 'altarpiece', 'anamorphosis', 'anoint', 'apply paint', 'attaint', 'bad likeness', 'bedaub', 'bedizen', 'beeswax', 'begild'],
    'daughter': ['aunt', 'auntie', 'blood brother', 'brethren', 'brother', 'bub', 'bubba', 'bud', 'buddy', 'child', 'country cousin', 'cousin'],
    'daunt': ['admonish', 'alarm', 'appall', 'awe', 'baffle', 'beat down', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'caution'],
    'daunted': ['affrighted', 'afraid', 'alarmed', 'chicken', 'chickenhearted', 'consternated', 'coward', 'cowardly', 'cowed', 'dismayed', 'disquieted', 'fainthearted'],
    'dauntless': ['audacious', 'aweless', 'bold', 'brave', 'confident', 'courageous', 'daring', 'dreadless', 'fearless', 'gallant', 'game', 'gritty'],
    'davy jones': ['davy', 'dylan', 'neptune', 'nereid', 'nereus', 'oceanid', 'oceanus', 'poseidon', 'thetis', 'triton', 'varuna', 'fresh-water nymph'],
    'dawdle': ['abide', 'await', 'bide', 'bide the issue', 'clock watcher', 'continue', 'dallier', 'dally', 'dawdler', 'delay', 'diddle', 'diddler'],
    'dawdler': ['clock watcher', 'dallier', 'dawdle', 'diddler', 'dillydallier', 'do-nothing', 'dolittle', 'doodler', 'drone', 'faineant', 'foot-dragger', 'gentleman of leisure'],
    'dawdling': ['dalliance', 'dallying', 'delaying', 'dilatoriness', 'dilatory', 'dillydallying', 'dolce far niente', 'dragging', 'goofing off', 'idling', 'lag', 'lagging'],
    'dawn': ['advent', 'alpha', 'antemeridian', 'appear', 'appearance', 'arise', 'arrival', 'arrive', 'aurora', 'auroral', 'awakening', 'begin'],
    'dawn on': ['be glimpsed', 'come through', 'come to mind', 'dawn upon one', 'get across', 'get over', 'grab one', 'occur', 'occur to', 'offer itself', 'penetrate', 'present itself'],
    'day': ['international date line', 'platonic year', 'abundant year', 'academic year', 'aeon', 'age', 'annum', 'annus magnus', 'antedate', 'bissextile year', 'broad day', 'calendar month'],
    'day by day': ['again and again', 'cyclically', 'daily', 'day after day', 'epochally', 'every day', 'every hour', 'frequently', 'hour by hour', 'hourly', 'in time', 'many a time'],
    'day of atonement': ['fast of av', 'feast of tabernacles', 'feast of weeks', 'hanukkah', 'high holy days', 'new year', 'ninth of av', 'passover', 'pentecost', 'pesach', 'purim', 'rosh hashanah'],
    'day off': ['awol', 'french leave', 'high holiday', 'high holy day', 'abeyance', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'bank holiday'],
    'daybook': ['domesday book', 'account book', 'accounts payable ledger', 'accounts receivable ledger', 'address book', 'adversaria', 'album', 'annals', 'annual', 'appointment calendar', 'appointment schedule', 'balance sheet'],
    'daybreak': ['aurora', 'break of day', 'brightening', 'chanticleer', 'cockcrow', 'cocklight', 'crack of dawn', 'dawn', 'dawning', 'day-peep', 'daylight', 'dayspring'],
    'daydream': ['walter mitty', 'absence of mind', 'absentmindedness', 'absorption', 'abstractedness', 'abstraction', 'airy nothing', 'autism', 'bad dream', 'be absent', 'bemusement', 'brown study'],
    'daydreamer': ['don quixote', 'quixote', 'walter mitty', 'absence of mind', 'absentmindedness', 'absorption', 'abstractedness', 'abstraction', 'bemusement', 'brown study', 'castle-building', 'daydream'],
    'daylight': ['pr', 'aurora', 'ballyhoo', 'blurb', 'break of day', 'bright light', 'brightening', 'broad day', 'celebrity', 'chanticleer', 'clarity', 'cockcrow'],
    'daystar': ['aldebaran', 'canicula', 'dog star', 'hesper', 'hesperus', 'lucifer', 'north star', 'phosphor', 'phosphorus', 'polaris', 'sirius', 'sol'],
    'daytime': ['broad day', 'dawn', 'day', 'day glow', 'daylight', 'dayshine', 'daytide', 'dusk', 'full sun', 'green flash', 'light of day', 'midday sun'],
    'daze': ['addle', 'addle the wits', 'amaze', 'amazed', 'amnesia', 'astonish', 'astonished', 'astound', 'astounded', 'awe', 'awestrike', 'baffle'],
    'dazed': ['addled', 'apish', 'asinine', 'at a loss', 'baffled', 'bamboozled', 'batty', 'beat', 'bedazzled', 'befooled', 'beguiled', 'besotted'],
    'dazzle': ['addle', 'addle the wits', 'amaze', 'astonish', 'astound', 'awe', 'awestrike', 'ball up', 'bandage', 'be bright', 'beacon', 'beam'],
    'dazzler': ['miss america', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'beauty queen', 'belle', 'bunny', 'charmer', 'cover girl', 'dream'],
    'dazzling': ['beaming', 'bedazzling', 'blinding', 'blooming', 'bright', 'bright and shining', 'brilliant', 'devastating', 'divine', 'effulgent', 'flamboyant', 'flaming'],
    'dc': ['ac', 'absorption current', 'active current', 'alternating current', 'conduction current', 'convection current', 'cycle', 'delta current', 'direct current', 'displacement current', 'eddy current', 'electric current'],
    'ddt': ['ddd', 'paris green', 'antimony', 'arsenic', 'arsenic trioxide', 'beryllium', 'bichloride of mercury', 'cadmium', 'carbolic acid', 'carbon monoxide', 'carbon tetrachloride', 'chlorine'],
    'de emphasize': ['abate', 'allay', 'alleviate', 'assuage', 'attemper', 'bank the fire', 'bedwarf', 'belittle', 'blunt', 'chasten', 'conceal', 'constrain'],
    'de energize': ['bugger', 'cripple', 'debilitate', 'disable', 'disenable', 'drain', 'enfeeble', 'hamstring', 'hors de combat', 'inactivate', 'incapacitate', 'kibosh'],
    'de facto': ['absolute', 'actual', 'actually', 'authentic', 'factual', 'for real', 'genuine', 'genuinely', 'historical', 'honest-to-god', 'positive', 'real'],
    'de rigueur': ['accepted', 'acknowledged', 'admitted', 'approved', 'au fait', 'becoming', 'being done', 'binding', 'comme il faut', 'conformable', 'conventional', 'correct'],
    'de trop': ['dispensable', 'excess', 'expendable', 'expletive', 'extra', 'gratuitous', 'in excess', 'needless', 'nonessential', 'pleonastic', 'prolix', 'redundant'],
    'deacon': ['aaronic priesthood', 'bible clerk', 'bible reader', 'melchizedek priesthood', 'seventy', 'acolyte', 'acolytus', 'almoner', 'anagnost', 'apostle', 'beadle', 'bedral'],
    'deactivate': ['break up', 'debrief', 'decommission', 'demilitarize', 'demob', 'demobilize', 'detach', 'disarm', 'disband', 'discharge', 'disintegrate', 'dismiss'],
    'dead': ['sol', 'a outrance', 'abeyant', 'abrupt', 'abruptly', 'absolute', 'absolutely', 'accurate', 'achromatic', 'achromic', 'ago', 'all bets off'],
    'dead end': ['bar', 'barrier', 'blank', 'blank wall', 'blind', 'blind alley', 'blind gut', 'blind-alley', 'block', 'blockade', 'blockage', 'bottleneck'],
    'dead giveaway': ['babbling', 'betrayal', 'blabbering', 'blabbing', 'communication leak', 'divulgation', 'divulgement', 'divulgence', 'divulging', 'evulgation', 'giveaway', 'indiscretion'],
    'dead letter': ['pastoral epistle', 'aerogram', 'aimlessness', 'air letter', 'airgraph', 'billet-doux', 'bull', 'chain letter', 'dimissorial', 'dimissory letter', 'drop letter', 'emptiness'],
    'dead march': ['andante', 'burial', 'burial at sea', 'burying', 'claudication', 'coronach', 'cortege', 'crawl', 'creep', 'death knell', 'death song', 'deep six'],
    'dead of night': ['egyptian darkness', 'erebus', 'awful silence', 'blackness', 'dark', 'darkness', 'darkness visible', 'dead', 'deathlike silence', 'golden silence', 'hush', 'hush of night'],
    'dead pan': ['anesthesia', 'autism', 'catatonia', 'chill', 'chilliness', 'cold blood', 'cold heart', 'coldheartedness', 'coldness', 'coolness', 'deadpan', 'dispassion'],
    'dead reckoning': ['aspect', 'astronavigation', 'attitude', 'azimuth', 'bearing', 'bearings', 'celestial navigation', 'chronometer', 'coastwise navigation', 'consolan', 'exposure', 'fix'],
    'dead ringer': ['doppelganger', 'actual thing', 'carbon copy', 'companion', 'copy', 'ditto', 'double', 'duplicate', 'effigy', 'equivalent', 'exact counterpart', 'exact likeness'],
    'dead shot': ['admirable crichton', 'nimrod', 'adept', 'archer', 'artilleryman', 'artisan', 'artist', 'attache', 'authority', 'bowman', 'cannoneer', 'carabineer'],
    'dead stop': ['arrest', 'bell', 'cessation', 'check', 'checkmate', 'cutoff', 'dead set', 'dead stand', 'deadlock', 'dying down', 'ebb', 'ebbing'],
    'dead tired': ['all in', 'beat', 'beat up', 'beaten', 'bone-weary', 'bushed', 'dead', 'dead-and-alive', 'deadbeat', 'dog-tired', 'dog-weary', 'done'],
    'dead to': ['a stranger to', 'asleep', 'blind to', 'caught napping', 'deaf to', 'impercipient', 'in ignorance of', 'incognizant', 'insensible', 'insensible to', 'lost to', 'mindless'],
    'deaden': ['ko', 'abate', 'absorb the shock', 'allay', 'alleviate', 'anesthetize', 'appease', 'assuage', 'attemper', 'attenuate', 'baffle', 'bank the fire'],
    'deadening': ['abatement', 'abating', 'allaying', 'allayment', 'alleviating', 'alleviation', 'alleviative', 'analgesia', 'analgesic', 'anesthesia', 'anesthetic', 'anesthetizing'],
    'deadeye': ['nimrod', 'air hole', 'archer', 'armhole', 'artilleryman', 'blowhole', 'bowman', 'bullet-hole', 'bunghole', 'cannoneer', 'carabineer', 'crack shot'],
    'deadfall': ['dionaea', 'baited trap', 'booby trap', 'deathtrap', 'decoy', 'firetrap', 'flytrap', 'gin', 'mine', 'mole trap', 'mousetrap', 'pitfall'],
    'deadline': ['a-day', 'd day', 'h hour', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bourn', 'break boundary', 'breakoff point', 'ceiling'],
    'deadlock': ['tweedledum and tweedledee', 'arrest', 'bell', 'blind alley', 'block', 'box', 'brake', 'bring to', 'bring up short', 'cessation', 'check', 'checkmate'],
    'deadly': ['a la mort', 'abominably', 'accurate', 'agonizingly', 'ashen', 'awful', 'awfully', 'baldly', 'baleful', 'balefully', 'baneful', 'barbaric'],
    'deadness': ['analgesia', 'anesthesia', 'aridity', 'barrenness', 'bloodlessness', 'callousness', 'characterlessness', 'colorlessness', 'dismalness', 'dragginess', 'dreariness', 'dryness'],
    'deadpan': ['blank', 'cold-bloodedly', 'coldheartedly', 'coldly', 'dispassionately', 'empty', 'expressionless', 'fishy', 'glassy', 'heartlessly', 'impassive', 'in cold blood'],
    'deadweight': ['avoirdupois', 'bale', 'beef', 'beefiness', 'burden', 'burdening', 'burthen', 'cargo', 'charge', 'charging', 'cross', 'cumber'],
    'deadwood': ['allowance', 'bine', 'bones', 'bough', 'branch', 'branchedness', 'branchiness', 'bulge', 'burgeon', 'chaff', 'culm', 'dishwater'],
    'deaf': ['authoritarian', 'bigot', 'bigoted', 'blind', 'borne', 'bullheaded', 'closed', 'constricted', 'cramped', 'creedbound', 'deaf and dumb', 'deaf to reason'],
    'deaf mute': ['deaf', 'deaf and dumb', 'deaf-and-dumb person', 'deaf-eared', 'deafened', 'dull-eared', 'dummy', 'earless', 'hard of hearing', 'lip reader', 'mute', 'stone-deaf'],
    'deaf to': ['a stranger to', 'asleep', 'blind to', 'caught napping', 'dead to', 'declinatory', 'disobedient', 'impercipient', 'in ignorance of', 'incognizant', 'insensible', 'insensible to'],
    'deafen': ['awake the dead', 'baffle', 'blast', 'blast the ear', 'boom', 'crash', 'crescendo', 'cushion', 'damp', 'dampen', 'deaden', 'din'],
    'deafening': ['booming', 'ear-piercing', 'ear-rending', 'ear-splitting', 'earthshaking', 'forte', 'fortissimo', 'full', 'intense', 'loud', 'loud-sounding', 'loudish'],
    'deal': ['byzantine intrigues', 'abatement of differences', 'accommodation', 'accord', 'act', 'act on', 'adjustment', 'administer', 'affair', 'afford', 'agreement', 'align'],
    'deal out': ['accord', 'administer', 'afford', 'align', 'allocate', 'allot', 'allow', 'apportion', 'array', 'award', 'bestow', 'bestow on'],
    'deal with': ['accomplish', 'achieve', 'act toward', 'affect', 'air', 'analyze', 'answer to', 'appertain to', 'apply to', 'attain', 'be in connection', 'be in contact'],
    'dealer': ['mafioso', 'wall streeter', 'agent', 'black marketeer', 'bond crowd', 'bootlegger', 'broker', 'businessman', 'businesswoman', 'chandler', 'curb broker', 'distributor'],
    'dealing': ['esp', 'agency', 'answer', 'balance of trade', 'barter', 'bartering', 'big business', 'brokerage', 'business', 'business dealings', 'buying and selling', 'commerce'],
    'dealings': ['esp', 'accomplished fact', 'accomplishment', 'accord', 'achievement', 'act', 'acta', 'action', 'addition', 'adjunct', 'adventure', 'affairs'],
    'dean': ['a per se', 'grand penitentiary', 'holy father', 'abuna', 'academic dean', 'ace', 'administration', 'administrator', 'antipope', 'archbishop', 'archdeacon', 'archon'],
    'deanery': ['dymaxion house', 'white house', 'abbacy', 'adobe house', 'aedileship', 'archbishopric', 'archdeaconry', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'bishopdom', 'bishopric'],
    'dear': ['admired', 'adored', 'affectionate', 'angel', 'at a premium', 'at great cost', 'at great expense', 'at heavy cost', 'babe', 'baby', 'baby-doll', 'beloved'],
    'dearth': ['absence', 'aridity', 'barrenness', 'birth control', 'contraception', 'default', 'defect', 'deficiency', 'dry womb', 'dryness', 'exiguity', 'exiguousness'],
    'death': ['azrael', 'black death', 'grim reaper', 'pale death', 'reaper', 'angel of death', 'annihilation', 'apodosis', 'bane', 'caducity', 'casualty', 'catastrophe'],
    'death dealing': ['baneful', 'brutal', 'deadly', 'death-bringing', 'deathful', 'deathly', 'destructive', 'fatal', 'feral', 'internecine', 'killing', 'lethal'],
    'death grip': ['bear hug', 'bite', 'clamp', 'clasp', 'clench', 'clinch', 'cling', 'clinging', 'clutch', 'embrace', 'firm hold', 'foothold'],
    'death song': ['chant du cygne', 'coronach', 'dead march', 'death knell', 'dirge', 'elegy', 'epicedium', 'eulogy', 'funeral march', 'funeral oration', 'funeral song', 'graveside oration'],
    'death struggle': ['agony', 'all-out war', 'death agonies', 'death groan', 'death rattle', 'death throes', 'deathbed', 'deathwatch', 'dying breath', 'extremity', 'final extremity', 'guerre a mort'],
    'death valley': ['arabia deserta', 'sahara', 'barren', 'barren land', 'barrens', 'brush', 'bush', 'desert', 'desolation', 'dust bowl', 'heath', 'howling wilderness'],
    'death wish': ['schmerz', 'slough of despond', 'blank despondency', 'dejectedness', 'dejection', 'depression', 'despair', 'despondency', 'despondentness', 'discouragement', 'disheartenment', 'dispiritedness'],
    'deathbed': ['agony', 'death agonies', 'death groan', 'death rattle', 'death struggle', 'death throes', 'deathwatch', 'dying breath', 'eleventh-hour', 'extremity', 'final extremity', 'last agony'],
    'deathblow': ['ko', 'waterloo', 'bane', 'beating', 'clincher', 'collapse', 'conquering', 'conquest', 'crash', 'crusher', 'death', 'death knell'],
    'deathless': ['abiding', 'amaranthine', 'embalmed', 'eternal', 'ever-fresh', 'everlasting', 'fadeless', 'frozen', 'immortal', 'imperishable', 'impregnable', 'incorruptible'],
    'deathly': ['a la mort', 'abominably', 'agonizingly', 'appalling', 'awfully', 'baldly', 'balefully', 'baneful', 'bitterly', 'blatantly', 'blue', 'brashly'],
    'deathwatch': ['agony', 'burial service', 'death agonies', 'death groan', 'death rattle', 'death struggle', 'death throes', 'deathbed', 'dirge', 'dying breath', 'eulogy', 'exequies'],
    'deb': ['beau brummel', 'apprentice', 'arbiter of fashion', 'baby', 'beginner', 'catechumen', 'clotheshorse', 'clubman', 'clubwoman', 'dandy', 'debutant', 'debutante'],
    'debacle': ['waterloo', 'beating', 'bloodless revolution', 'bouleversement', 'breakdown', 'breaking up', 'breakup', 'cascade', 'cataclysm', 'cataract', 'catastrophe', 'cave'],
    'debar': ['anticipate', 'avert', 'ban', 'bar', 'bar out', 'barricade', 'bate', 'block', 'block up', 'blockade', 'bolt', 'chock'],
    'debase': ['abase', 'abash', 'abuse', 'adulterate', 'alloy', 'bastardize', 'bear down', 'befoul', 'belittle', 'bring down', 'bring into discredit', 'bring low'],
    'debased': ['abandoned', 'abject', 'abominable', 'arrant', 'atrocious', 'base', 'beggarly', 'cheesy', 'contaminated', 'contemptible', 'corrupt', 'corrupted'],
    'debatable': ['arguable', 'at issue', 'confutable', 'conjectural', 'contestable', 'controversial', 'controvertible', 'deniable', 'disputable', 'doubtable', 'doubtful', 'dubious'],
    'debate': ['kilkenny cats', 'address', 'after-dinner speech', 'agitate', 'air', 'airing', 'allocution', 'altercation', 'analysis', 'analyze', 'application', 'argue'],
    'debater': ['philadelphia lawyer', 'apologist', 'arguer', 'argufier', 'casuist', 'controversialist', 'declaimer', 'demagogue', 'disceptator', 'disputant', 'guardhouse lawyer', 'haranguer'],
    'debauch': ['abuse', 'adulterate', 'alloy', 'bacchanal', 'bacchanalia', 'bacchanalian', 'bastardize', 'bat', 'be promiscuous', 'bender', 'betray', 'binge'],
    'debauched': ['abandoned', 'contaminated', 'corrupt', 'corrupted', 'debased', 'decadent', 'degenerate', 'degraded', 'depraved', 'dissipated', 'dissolute', 'fast'],
    'debauchery': ['carousal', 'carouse', 'debauch', 'debauchment', 'dissipation', 'dissoluteness', 'fastness', 'free living', 'gallantry', 'high living', 'killing pace', 'libertinage'],
    'debenture': ['cd', 'fannie mae', 'federal agency bond', 'ginnie mae', 'iou', 'mo', 'series e bond', 'series h bond', 'acceptance', 'acceptance bill', 'adjustment bond', 'annuity bond'],
    'debilitate': ['abate', 'afflict', 'attenuate', 'beat', 'blunt', 'bugger', 'burn out', 'cramp', 'cripple', 'damp', 'dampen', 'de-energize'],
    'debilitated': ['anemic', 'anile', 'apathetic', 'asthenic', 'benumbed', 'blase', 'bloodless', 'bored', 'cachectic', 'castrated', 'chicken', 'cowardly'],
    'debility': ['advanced age', 'advanced years', 'adynamia', 'age of retirement', 'an incurable disease', 'anemia', 'anility', 'atony', 'blah feeling', 'bloodlessness', 'brain fag', 'cachexia'],
    'debit': ['balance', 'balance the books', 'bereavement', 'book', 'budgeting', 'capitalize', 'carry', 'carry over', 'cast up accounts', 'charge off', 'close out', 'close the books'],
    'debonair': ['affable', 'airy', 'breezy', 'buoyant', 'carefree', 'charming', 'cheerful', 'civil', 'corky', 'courteous', 'dapper', 'dashing'],
    'debouch': ['arise', 'bail out', 'blow out', 'bob up', 'break cover', 'break forth', 'break out', 'break through', 'burst forth', 'cast forth', 'come', 'come forth'],
    'debrief': ['break up', 'brief', 'deactivate', 'demob', 'demobilize', 'detach', 'disband', 'discharge', 'disintegrate', 'dismiss', 'disorganize', 'disperse'],
    'debris': ['afterglow', 'afterimage', 'alluvion', 'alluvium', 'balance', 'breccia', 'butt', 'butt end', 'candle ends', 'chaff', 'clamjamfry', 'deposit'],
    'debt': ['accountability', 'accountable', 'answerable for', 'arrearage', 'arrears', 'beholden', 'borrowing', 'debit', 'debtor', 'default', 'deficit', 'delinquency'],
    'debt service': ['acquitment', 'acquittal', 'acquittance', 'amortization', 'amortizement', 'binder', 'cash', 'cash payment', 'clearance', 'defrayal', 'defrayment', 'deposit'],
    'debug': ['answer', 'bottom', 'clear up', 'crack', 'decipher', 'decode', 'disentangle', 'divine', 'do', 'dope', 'dope out', 'explain'],
    'debunk': ['awaken', 'break the spell', 'burst the bubble', 'correct', 'disabuse', 'disappoint', 'discover', 'disenchant', 'disillude', 'disillusion', 'disillusionize', 'enlighten'],
    'debunker': ['thersites', 'backbiter', 'belittler', 'calumniator', 'caustic critic', 'cynic', 'decrier', 'defamer', 'deflater', 'depreciator', 'derogator', 'detractor'],
    'debut': ['appear', 'benefit', 'bill', 'come out', 'coming out', 'coming-out party', 'curtain raiser', 'embarkation', 'embarkment', 'enter', 'entertainment', 'exhibit'],
    'debutant': ['abecedarian', 'alphabetarian', 'apprentice', 'articled clerk', 'baby', 'beginner', 'boot', 'catechumen', 'deb', 'entrant', 'fledgling', 'freshman'],
    'debutante': ['beau brummel', 'arbiter of fashion', 'clotheshorse', 'clubman', 'clubwoman', 'dandy', 'deb', 'fashion plate', 'fashionable', 'fop', 'man-about-town', 'mondain'],
    'decade': ['big dick', 'decalogue', 'ten commandments', 'abundant year', 'academic year', 'annum', 'bissextile year', 'calendar month', 'calendar year', 'century', 'common year', 'day'],
    'decadence': ['abandon', 'abandonment', 'abjection', 'comedown', 'corruptedness', 'corruption', 'corruptness', 'debasement', 'decadency', 'decadent', 'decayed', 'declension'],
    'decadent': ['abandoned', 'coming apart', 'contaminated', 'corrupt', 'corrupted', 'cracking', 'crumbling', 'debased', 'debauched', 'decaying', 'declining', 'degenerate'],
    'decal': ['adherent', 'adhesive', 'barnacle', 'bramble', 'brier', 'bulldog', 'burr', 'cameography', 'cement', 'decalcomania', 'glass printing', 'glue'],
    'decalogue': ['ten commandments', 'zeitgeist', 'axiology', 'behavioral norm', 'business ethics', 'code', 'code of ethics', 'code of morals', 'ethic', 'ethical system', 'ethics', 'ethos'],
    'decamp': ['abscond', 'absquatulate', 'avoid', 'beat a retreat', 'begone', 'bolt', 'break', 'break camp', 'clear out', 'cut and run', 'depart', 'desert'],
    'decant': ['bail', 'bleed', 'blow out', 'broach', 'bucket', 'cast forth', 'cup', 'debouch', 'dip', 'discharge', 'disembogue', 'disgorge'],
    'decapitate': ['behead', 'bowstring', 'burn', 'crucify', 'decimate', 'decollate', 'defenestrate', 'demolish', 'electrocute', 'execute', 'garrote', 'guillotine'],
    'decathlon': ['bout', 'contest', 'double-header', 'doubles', 'event', 'foursome', 'game', 'games of chance', 'go', 'match', 'meet', 'pentathlon'],
    'decay': ['ablate', 'ablation', 'atomization', 'atomize', 'atrophy', 'biodegradability', 'biodegradation', 'break down', 'break up', 'breakup', 'canker', 'caries'],
    'decease': ['annihilation', 'apodosis', 'bane', 'be lost', 'biological death', 'cash in', 'catastrophe', 'cease to be', 'cease to live', 'ceasing', 'cessation', 'cessation of life'],
    'deceased': ['ago', 'antiquated', 'antique', 'ashes', 'asleep', 'asleep in jesus', 'at rest', 'bereft of life', 'blown over', 'body', 'bones', 'breathless'],
    'deceit': ['art', 'artful dodge', 'artfulness', 'artifice', 'blind', 'cheating', 'chicane', 'chicanery', 'con', 'con game', 'conspiracy', 'contrivance'],
    'deceitful': ['machiavellian', 'machiavellic', 'acute', 'ambidextrous', 'arch', 'artful', 'astute', 'cagey', 'calculating', 'canny', 'chiseling', 'clandestine'],
    'deceive': ['abuse', 'bamboozle', 'be untruthful', 'befool', 'beguile', 'betray', 'bitch', 'bluff', 'bunk', 'cajole', 'cheat', 'cheat on'],
    'deceived': ['gothic', 'philistine', 'barbarous', 'bookless', 'functionally illiterate', 'grammarless', 'heathen', 'hoodwinked', 'ill-educated', 'illiterate', 'led astray', 'lowbrow'],
    'deceiver': ['judas', 'actor', 'affecter', 'bad person', 'betrayer', 'convict', 'criminal', 'crook', 'debaucher', 'defiler', 'delinquent', 'desperado'],
    'deceiving': ['beguiling', 'catchy', 'deceptive', 'deluding', 'delusive', 'delusory', 'dubious', 'fallacious', 'false', 'fishy', 'hallucinatory', 'illusive'],
    'deceleration': ['arrest', 'arrestation', 'catabasis', 'check', 'collapse', 'constraint', 'control', 'cooling', 'cooling down', 'cooling off', 'crash', 'curb'],
    'decencies': ['amenities', 'appropriateness', 'civilities', 'civility', 'comity', 'convention', 'correctitude', 'correctness', 'courtliness', 'decency', 'decorousness', 'decorum'],
    'decency': ['accommodatingness', 'advantage', 'advantageousness', 'advisability', 'affability', 'agreeableness', 'amiability', 'appropriateness', 'assured probity', 'becomingness', 'beneficialness', 'benevolence'],
    'decent': ['christian', 'christlike', 'christly', 'ok', 'acceptable', 'accepted', 'accommodating', 'according to hoyle', 'acknowledged', 'adequate', 'admissible', 'admitted'],
    'decently': ['acceptably', 'adequately', 'advantageously', 'advisably', 'aesthetically', 'appropriately', 'artistically', 'becomingly', 'blamelessly', 'congruously', 'conscientiously', 'conveniently'],
    'deception': ['acting', 'affectation', 'airy nothing', 'appearance', 'artifice', 'attitudinizing', 'autism', 'befooling', 'bluff', 'bluffing', 'bubble', 'burial'],
    'deceptive': ['barmecidal', 'barmecide', 'aberrant', 'abroad', 'adrift', 'airy', 'all abroad', 'all off', 'all wrong', 'amiss', 'apparent', 'apparently sound'],
    'decide': ['adjudge', 'adjudicate', 'advance', 'arbitrate', 'ascertain', 'assure', 'bring', 'call the shots', 'carry', 'certify', 'choose', 'choose to'],
    'decided': ['sol', 'absolute', 'accented', 'accentuated', 'adamant', 'admitting no exception', 'affirmative', 'affirmatory', 'all bets off', 'all off', 'all over', 'all up'],
    'decidedly': ['absolutely', 'actually', 'affirmatively', 'and no mistake', 'assertively', 'assuredly', 'at all events', 'at any rate', 'bec et ongles', 'by all means', 'certainly', 'clearly'],
    'deciduous': ['arborary', 'arboreal', 'arboreous', 'arborescent', 'arboresque', 'arborical', 'arboriform', 'brittle', 'bushlike', 'bushy', 'capricious', 'changeable'],
    'decimal': ['algorismic', 'algorithmic', 'aliquot', 'cardinal', 'decagonal', 'decahedral', 'decasyllabic', 'decuple', 'denary', 'differential', 'digital', 'even'],
    'decimate': ['annihilate', 'bring to ruin', 'butcher', 'commit carnage', 'commit genocide', 'commit mass murder', 'condemn', 'confound', 'consume', 'damn', 'deal destruction', 'demolish'],
    'decipher': ['account for', 'allegorize', 'analyze', 'answer', 'bottom', 'break', 'break down', 'cipher', 'clarify', 'clear up', 'crack', 'cryptanalyze'],
    'decipherable': ['answerable', 'ascertainable', 'capable of solution', 'decodable', 'determinable', 'doable', 'explainable', 'explicable', 'fair', 'in the clear', 'legible', 'open to solution'],
    'decision': ['accommodation', 'accord', 'acquittal', 'action', 'adjustment', 'agreement', 'alternativity', 'animus', 'appetence', 'appetency', 'appetite', 'arbitration'],
    'decisive': ['absolute', 'adducible', 'admissible', 'admitting no exception', 'alert', 'all-out', 'apodictic', 'apt', 'assured', 'assuring', 'attestative', 'attestive'],
    'deck': ['accouter', 'ace', 'adorn', 'apparel', 'appoint', 'array', 'attire', 'bag', 'bale', 'band', 'bang', 'bash'],
    'deckhand': ['bakehead', 'black gang', 'boilerman', 'bungs', 'cabin boy', 'chips', 'commissary steward', 'complement', 'deckie', 'fireman', 'gun loader', 'gunner'],
    'declaim': ['blare', 'blare forth', 'blaze', 'blaze abroad', 'blazon', 'blazon about', 'celebrate', 'chatter', 'converse', 'cry', 'cry out', 'debate'],
    'declamatory': ['gongoresque', 'johnsonian', 'affected', 'aureate', 'bedizened', 'big-sounding', 'bombastic', 'convoluted', 'elevated', 'elocutionary', 'eloquent', 'euphuistic'],
    'declaration': ['parthian shot', 'acceptance', 'acknowledgment', 'address', 'admission', 'advertisement', 'affidavit', 'affirmance', 'affirmation', 'allegation', 'allowance', 'announcement'],
    'declarative': ['absolute', 'affirmative', 'affirmatory', 'annunciatory', 'assertative', 'assertional', 'assertive', 'decided', 'declaratory', 'emphatic', 'enunciative', 'heraldic'],
    'declare': ['acknowledge', 'acquaint', 'admit', 'advertise', 'advise', 'affirm', 'air', 'allege', 'announce', 'annunciate', 'apprise', 'argue'],
    'declared': ['accessible', 'affirmed', 'alleged', 'announced', 'asserted', 'asseverated', 'attested', 'averred', 'avouched', 'avowed', 'broadcast', 'brought to notice'],
    'declension': ['ic analysis', 'abnegation', 'accidence', 'affix', 'affixation', 'allomorph', 'bound morpheme', 'cascade', 'catabasis', 'cataract', 'chute', 'collapse'],
    'declination': ['cartesian coordinates', 'aberrancy', 'aberration', 'abjuration', 'abjurement', 'abnegation', 'abscissa', 'altitude', 'azimuth', 'bend', 'bias', 'branching off'],
    'decline': ['abate', 'abatement', 'abjure', 'ablate', 'abstain', 'abstain from', 'age', 'analyze', 'anility', 'arrear', 'arrearage', 'arrears'],
    'declining': ['abjuration', 'abjurement', 'abnegation', 'aging', 'chucking', 'chucking out', 'collapsing', 'coming apart', 'contempt', 'contractive', 'contradiction', 'cracking'],
    'declivitous': ['collapsing', 'deciduous', 'declined', 'declining', 'declivate', 'declivous', 'decurrent', 'descendant', 'descending', 'dipping', 'down', 'down-reaching'],
    'decoction': ['boil', 'boiling', 'brew', 'chemical solution', 'coction', 'combination', 'composition', 'concentrate', 'concentration', 'concoction', 'confection', 'decoctum'],
    'decode': ['anagram', 'answer', 'bottom', 'break', 'clear up', 'crack', 'cryptanalyze', 'debug', 'decipher', 'decrypt', 'disentangle', 'divine'],
    'decoding': ['edp', 'accomplishment', 'allegorization', 'amplification', 'answer', 'ascertainment', 'bilingual text', 'bit', 'channel', 'clarification', 'clavis', 'clearing up'],
    'decollete': ['bareness', 'birthday suit', 'clothesless', 'disrobed', 'ecdysiast', 'en deshabille', 'garbless', 'garmentless', 'gymnosophist', 'gymnosophy', 'half-clothed', 'in dishabille'],
    'decomposable': ['ablative', 'biodegradable', 'corrosive', 'decomposing', 'degradable', 'dilapidated', 'disintegrable', 'disintegrated', 'disintegrating', 'disintegrative', 'disjunctive', 'disruptive'],
    'decompose': ['ablate', 'anatomize', 'atomize', 'break down', 'break up', 'canker', 'come apart', 'consume', 'corrode', 'corrupt', 'crack up', 'crumble'],
    'decomposed': ['bad', 'cankered', 'carious', 'corrupt', 'decayed', 'festering', 'foul', 'gangrened', 'gangrenous', 'gone bad', 'mortified', 'necrosed'],
    'decomposing': ['ablative', 'biodegradable', 'corrosive', 'decomposable', 'degradable', 'dilapidated', 'disintegrable', 'disintegrated', 'disintegrating', 'disintegrative', 'disjunctive', 'disruptive'],
    'decomposition': ['ablation', 'atomization', 'biodegradability', 'biodegradation', 'breakup', 'caries', 'carrion', 'corrosion', 'corruption', 'crumbling', 'decay', 'degradability'],
    'decontaminate': ['absolve', 'acquit', 'amnesty', 'antisepticize', 'autoclave', 'boil', 'chlorinate', 'clear', 'delouse', 'destigmatize', 'discharge', 'disinfect'],
    'decontamination': ['activity', 'allowance', 'antisepsis', 'artificial radioactivity', 'color', 'contamination', 'curiage', 'disinfection', 'disinfestation', 'extenuating circumstances', 'extenuation', 'extenuative'],
    'decor': ['act drop', 'adjunct', 'adornment', 'arrangement', 'asbestos', 'asbestos board', 'backdrop', 'batten', 'border', 'cloth', 'color', 'color patterns'],
    'decorate': ['accouter', 'add', 'adjoin', 'adorn', 'affix', 'agglutinate', 'annex', 'append', 'appoint', 'array', 'attach', 'beautify'],
    'decorated': ['adorned', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'colored', 'decked out', 'embellished', 'embroidered'],
    'decoration': ['abstract art', 'accolade', 'adjunct', 'adornment', 'armory', 'arrangement', 'art', 'art form', 'artist', 'arts and crafts', 'arts of design', 'award'],
    'decorous': ['christian', 'accepted', 'according to hoyle', 'acknowledged', 'admitted', 'appropriate', 'approved', 'au fait', 'becoming', 'befitting', 'being done', 'ceremonial'],
    'decorum': ['amenities', 'appropriateness', 'becomingness', 'bienseance', 'ceremoniousness', 'civilities', 'civility', 'comity', 'conformity', 'convenance', 'convention', 'conventional usage'],
    'decoy': ['dionaea', 'agent provocateur', 'allure', 'allurement', 'attract', 'attraction', 'bait', 'bait the hook', 'baited trap', 'birdlime', 'blandish', 'booby trap'],
    'decrease': ['abate', 'abatement', 'abbreviate', 'abbreviation', 'ablate', 'ablation', 'abrade', 'abridge', 'abstract', 'allay', 'alleviate', 'apportion'],
    'decree': ['act', 'act on', 'action', 'adjudge', 'announcement', 'appointment', 'authorize', 'award', 'behest', 'bid', 'bidding', 'bill'],
    'decrement': ['abatement', 'ablation', 'abridgment', 'alleviation', 'attenuation', 'attrition', 'consumption', 'contraction', 'corrosion', 'curtailment', 'cut', 'cutting'],
    'decrepit': ['aged', 'ancient', 'anile', 'antiquated', 'battered', 'beat-up', 'beaten up', 'bedraggled', 'broken-down', 'cast-off', 'childish', 'childlike'],
    'decrepitude': ['caducity', 'debilitation', 'debility', 'decay', 'deterioration', 'dilapidation', 'disease', 'dotage', 'enervation', 'feebleness', 'incapacity', 'infirmity'],
    'decrescendo': ['a cappella', 'abbandono', 'accrescendo', 'adagietto', 'adagio', 'affettuoso', 'agilmente', 'agitato', 'allegretto', 'allegro', 'amabile', 'amoroso'],
    'decretory': ['absolute', 'binding', 'commanding', 'compelling', 'compulsory', 'conclusive', 'decisive', 'decretal', 'decretive', 'dictated', 'dictating', 'directive'],
    'decry': ['abuse', 'accuse', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'asperse', 'belittle', 'blame', 'bring down', 'bring into discredit', 'bring low'],
    'dedicate': ['address', 'allot', 'apply', 'appropriate', 'assign', 'beatify', 'bless', 'canonize', 'cleanse', 'commit', 'confide', 'consecrate'],
    'dedicated': ['abandoned', 'afire', 'altruistic', 'ardent', 'beatified', 'blessed', 'bound', 'bound and determined', 'burning', 'canonized', 'committed', 'consecrated'],
    'dedication': ['abandon', 'acknowledgments', 'address', 'adherence', 'allegiance', 'altruism', 'ardency', 'ardor', 'assigned task', 'assignment', 'back', 'back matter'],
    'deduce': ['analyze', 'apply reason', 'arouse', 'assume', 'be afraid', 'believe', 'bring forth', 'bring out', 'bring to light', 'call forth', 'call out', 'call up'],
    'deduct': ['abate', 'abrade', 'abridge', 'abstract', 'allow', 'bate', 'charge off', 'collect', 'compress', 'conclude', 'curtail', 'cut'],
    'deductible': ['accident insurance', 'actuary', 'annuity', 'assurance', 'aviation insurance', 'bail bond', 'bond', 'business life insurance', 'casualty insurance', 'certificate of insurance', 'court bond', 'credit insurance'],
    'deduction': ['baconian method', 'a fortiori reasoning', 'a posteriori reasoning', 'a priori reasoning', 'abatement', 'ablation', 'abrasion', 'abridgment', 'abstraction', 'accord', 'addition', 'adjunct'],
    'deductive': ['a fortiori', 'a posteriori', 'a priori', 'ablative', 'academic', 'analytic', 'categorical', 'conditional', 'conjectural', 'deducible', 'derivable', 'dialectic'],
    'deed': ['abalienate', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adventure', 'agreement', 'alien', 'alienate', 'amortize'],
    'deedholder': ['beneficiary', 'cestui', 'cestui que trust', 'cestui que use', 'feoffee', 'feudatory', 'householder', 'laird', 'landlady', 'landlord', 'lord', 'master'],
    'deem': ['account', 'account as', 'adjudge', 'adjudicate', 'allow', 'assume', 'be afraid', 'be judicious', 'believe', 'calculate', 'conceive', 'conclude'],
    'deep': ['bassalia', 'machiavellian', 'machiavellic', 'absorbed', 'absorbing', 'abstract', 'abstracted', 'abstruse', 'abysm', 'abysmal', 'abyss', 'abyssal'],
    'deep dyed': ['absolute', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'born', 'broad-based', 'chronic', 'clean', 'clear', 'colorfast', 'comprehensive'],
    'deep freeze': ['blast', 'blast-freeze', 'blight', 'congeal', 'deep-freezer', 'freeze', 'freeze solid', 'freezer', 'freezing machine', 'glaciate', 'glacify', 'ice'],
    'deep rooted': ['ankle-deep', 'chronic', 'confirmed', 'deep', 'deep-cut', 'deep-down', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid', 'deep-lying'],
    'deep sea': ['bassalian', 'abyssal', 'aquatic', 'balneal', 'bathyal', 'bathybic', 'bathymetric', 'bathyorographical', 'bathypelagic', 'bathysmal', 'benthal', 'benthonic'],
    'deep seated': ['ankle-deep', 'chronic', 'confirmed', 'congenital', 'connate', 'constitutional', 'deep', 'deep-cut', 'deep-down', 'deep-dyed', 'deep-engraven', 'deep-fixed'],
    'deep six': ['abandon', 'barrow', 'beehive tomb', 'bone house', 'box grave', 'burial', 'burial at sea', 'burial chamber', 'burial mound', 'burying', 'cast', 'cast aside'],
    'deep thought': ['absorbed attention', 'absorption', 'abstraction', 'application', 'brown study', 'close study', 'concentration', 'contemplation', 'contemplativeness', 'deep study', 'engagement', 'engrossment'],
    'deepen': ['accelerate', 'agent provocateur', 'aggravate', 'amplify', 'annoy', 'augment', 'beef up', 'blow up', 'broaden', 'build up', 'burrow', 'complicate'],
    'deepening': ['accelerando', 'acceleration', 'aggravation', 'amplification', 'annoyance', 'augmentation', 'beefing-up', 'blowing up', 'blowup', 'concentration', 'condensation', 'consolidation'],
    'deeply': ['acutely', 'completely', 'deep', 'emotionally', 'entirely', 'extremely', 'gravely', 'greatly', 'heavily', 'intensely', 'irrevocably', 'keenly'],
    'deer': ['cape elk', 'virginia deer', 'antelope', 'buck', 'camel', 'camelopard', 'caribou', 'deerlet', 'doe', 'dromedary', 'eland', 'elk'],
    'deface': ['batter', 'blemish', 'blot', 'check', 'cicatrize', 'contort', 'crack', 'craze', 'damage', 'deform', 'demolish', 'destroy'],
    'defalcation': ['abuse', 'abuse of office', 'arrear', 'arrearage', 'arrears', 'befoulment', 'break', 'conversion', 'corrupt administration', 'debasement', 'decline', 'default'],
    'defamation': ['attack', 'backbiting', 'backstabbing', 'belittlement', 'blackening', 'calumny', 'character assassination', 'defamation of character', 'defilement', 'denigration', 'depreciation', 'disparagement'],
    'defamatory': ['abusive', 'back-biting', 'backbiting', 'belittling', 'bitchy', 'calumniatory', 'calumnious', 'catty', 'censorious', 'contemptuous', 'contumelious', 'deprecatory'],
    'defame': ['asperse', 'attaint', 'bad-mouth', 'belie', 'bespatter', 'blacken', 'blot', 'blow upon', 'brand', 'calumniate', 'cast aspersions on', 'cast reflections on'],
    'default': ['awol', 'french leave', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'arrear', 'arrearage', 'arrears', 'back debts'],
    'defeat': ['ko', 'waterloo', 'answer', 'answer conclusively', 'argue down', 'baffle', 'bafflement', 'balk', 'balking', 'bankruptcy', 'bar', 'bear down'],
    'defeated': ['all up with', 'baffled', 'balked', 'beat', 'beaten', 'bested', 'betrayed', 'bilked', 'blasted', 'blighted', 'chapfallen', 'confounded'],
    'defeating': ['ascendant', 'baffling', 'confounding', 'conquering', 'disconcerting', 'dominant', 'flushed with success', 'frustrating', 'in ascendancy', 'in the ascendant', 'overcoming', 'prevailing'],
    'defeatist': ['cassandra', 'cassandra-like', 'cassandran', 'cassandrian', 'eeyore', 'calamity howler', 'cynic', 'cynical', 'dismal', 'downbeat', 'gloomy', 'killjoy'],
    'defecate': ['blow', 'blow out', 'ca-ca', 'clean out', 'clear', 'clear away', 'clear off', 'clear out', 'clear the decks', 'crap', 'deplete', 'drain'],
    'defect': ['abandon', 'abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'apostacize', 'apostatize', 'arrearage', 'atrophy'],
    'defection': ['abandonment', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'alienation', 'alteration', 'amelioration', 'apostasy', 'backsliding', 'bad debt', 'betrayal'],
    'defective': ['aberrant', 'abroad', 'adrift', 'adulterated', 'all abroad', 'all off', 'all wrong', 'ament', 'amiss', 'amputee', 'arrested', 'askew'],
    'defector': ['apostate', 'backslider', 'bolter', 'collaborationist', 'collaborator', 'convert', 'deserter', 'fifth columnist', 'mugwump', 'proselyte', 'quisling', 'rat'],
    'defend': ['account', 'advocate', 'air', 'allege in support', 'answer', 'argue', 'argue for', 'arm', 'armor', 'assert', 'avert', 'back'],
    'defendant': ['accessory', 'accused', 'bitter-ender', 'brawler', 'correspondent', 'diehard', 'disputant', 'dissentient', 'dissident', 'intransigent', 'irreconcilable', 'last-ditcher'],
    'defender': ['maecenas', 'abettor', 'admirer', 'advocate', 'aficionado', 'angel', 'apologete', 'apologist', 'apologizer', 'backer', 'buff', 'champion'],
    'defense': ['aegis', 'answer', 'apologetic', 'apologetics', 'apologia', 'apology', 'arch dam', 'argument', 'argumentation', 'armament', 'armor', 'arms'],
    'defense counsel': ['ag', 'da', 'kc', 'qc', 'ssc', 'us attorney', 'attorney general', 'civilian', 'corporation lawyer', 'court-appointed lawyer', 'criminal lawyer', 'district attorney'],
    'defense mechanism': ['alienation', 'autism', 'autistic thinking', 'avoidance', 'avoidance mechanism', 'avoidance reaction', 'avoiding reaction', 'blame-shifting', 'block', 'blocking', 'circumvention', 'compensation'],
    'defenseless': ['abandoned', 'aidless', 'bare-handed', 'deserted', 'desolate', 'fatherless', 'forlorn', 'forsaken', 'friendless', 'godforsaken', 'guardless', 'guideless'],
    'defensible': ['admissible', 'allowable', 'balanced', 'condonable', 'defendable', 'deserved', 'dispensable', 'due', 'equitable', 'even', 'evenhanded', 'excusable'],
    'defensive': ['covering', 'custodial', 'defending', 'fostering', 'guardian', 'guarding', 'immunizing', 'parental', 'preventive', 'prophylactic', 'protecting', 'protective'],
    'defer': ['accede', 'accede to', 'accommodate', 'acquiesce', 'adapt', 'adjourn', 'adjust', 'agree', 'agree to', 'assent', 'block', 'bow'],
    'defer to': ['accord respect to', 'admire', 'adore', 'apotheosize', 'appreciate', 'attend to orders', 'bow to', 'comply', 'conform', 'deify', 'entertain respect for', 'esteem'],
    'deference': ['acceptance', 'acquiescence', 'admiration', 'adoration', 'affability', 'agreeableness', 'allegiance', 'amenity', 'apotheosis', 'appreciation', 'approbation', 'approval'],
    'deferential': ['accommodating', 'affable', 'agreeable', 'attentive', 'cap in hand', 'ceremonious', 'civil', 'complaisant', 'conscientious', 'considerate', 'courteous', 'crouching'],
    'defiance': ['audacity', 'boldness', 'bravado', 'brazenness', 'call', 'cartel', 'challenge', 'combative reaction', 'command', 'complaint', 'contempt', 'contrariness'],
    'defiant': ['aggressive', 'antagonistic', 'arrogant', 'audacious', 'belligerent', 'beyond control', 'bold', 'brash', 'brassy', 'brazen', 'breachy', 'bumptious'],
    'deficiency': ['absence', 'adulteration', 'arrearage', 'arrestment', 'baseness', 'beggary', 'blemish', 'break', 'bug', 'callowness', 'catch', 'crack'],
    'deficiency disease': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'cardiovascular disease'],
    'deficient': ['adulterated', 'amiss', 'arrested', 'bad', 'base', 'blemished', 'botched', 'bungling', 'callow', 'clumsy', 'damaged', 'defective'],
    'deficit': ['absence', 'arrear', 'arrearage', 'arrears', 'back debts', 'back payments', 'balance', 'beggary', 'bouncing check', 'break', 'credit', 'decline'],
    'defile': ['abuse', 'abysm', 'abyss', 'access', 'adulterate', 'afflict', 'aggrieve', 'aisle', 'alley', 'alloy', 'ambulatory', 'aperture'],
    'define': ['assign', 'baptize', 'be characteristic', 'bed', 'blaze', 'blaze a trail', 'blemish', 'blotch', 'bound', 'brand', 'call', 'chalk'],
    'defined': ['absolute', 'certain', 'circumscribed', 'circumscript', 'clean-cut', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'coherent', 'concrete', 'connected'],
    'defining': ['categorical', 'characteristic', 'classificational', 'classificatory', 'confining', 'definitive', 'denominative', 'differential', 'distinctive', 'divisional', 'divisionary', 'exclusive'],
    'definite': ['absolute', 'admitting no exception', 'all-out', 'apodictic', 'articulate', 'assigned', 'assured', 'audible', 'bound', 'bound and determined', 'categorical', 'certain'],
    'definitely': ['absolutely', 'and no mistake', 'apparently', 'apprehensibly', 'articulately', 'assuredly', 'at all events', 'at any rate', 'by all means', 'categorically', 'certainly', 'clearly'],
    'definition': ['acutance', 'appellation', 'atmospheric visibility', 'baptism', 'black spot', 'bloom', 'blooping', 'bounding', 'calling', 'ceiling', 'ceiling unlimited', 'characterization'],
    'definitive': ['absolute', 'accurate', 'actual', 'admitting no exception', 'all-out', 'arrant', 'authoritative', 'boundary', 'categorical', 'caudal', 'clarifying', 'classical'],
    'deflagration': ['blaze', 'blazing', 'blistering', 'branding', 'burning', 'burst', 'calcination', 'carbonization', 'cauterization', 'cautery', 'cineration', 'combustion'],
    'deflate': ['abridge', 'beat down', 'belie', 'blow sky-high', 'blow up', 'break', 'cave', 'cave in', 'cheapen', 'collapse', 'compress', 'curtail'],
    'deflated': ['abated', 'ablated', 'attenuated', 'bated', 'belied', 'belittled', 'confounded', 'confuted', 'consumed', 'contracted', 'curtailed', 'decreased'],
    'deflation': ['abasement', 'abatement', 'abridgment', 'alleviation', 'attenuation', 'break', 'breakdown', 'cave-in', 'cheapening', 'collapse', 'comedown', 'contraction'],
    'deflect': ['angle', 'angle off', 'anticipate', 'arch', 'avert', 'bar', 'bear off', 'bend', 'bend back', 'bias', 'blunt', 'bow'],
    'deflection': ['s-curve', 'aberration', 'angle', 'apex', 'atmospheric attenuation', 'bend', 'bending', 'bifurcation', 'bight', 'blind spots', 'bow', 'bowing'],
    'deflower': ['abuse', 'adulterate', 'alloy', 'assault sexually', 'betray', 'canker', 'cheapen', 'coarsen', 'confound', 'contaminate', 'corrupt', 'debase'],
    'defluxion': ['affluence', 'afflux', 'affluxion', 'cascade', 'cataract', 'chute', 'collapse', 'comedown', 'concourse', 'confluence', 'conflux', 'course'],
    'defoliant': ['acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bug bomb', 'carbamate insecticide', 'chemosterilant', 'contact poison', 'disinfectant', 'eradicant', 'fumigant', 'fungicide'],
    'defoliate': ['denude', 'dismember', 'draw and quarter', 'flay', 'lacerate', 'maim', 'mangle', 'mutilate', 'peel', 'pick to pieces', 'pull apart', 'shred'],
    'deform': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'batter', 'better', 'blemish', 'blur', 'break up', 'change', 'check'],
    'deformed': ['abnormal', 'awry', 'bandy', 'bandy-legged', 'baroque', 'bent', 'bizarre', 'blemished', 'bloated', 'bowlegged', 'cacogenic', 'checked'],
    'deformity': ['aberration', 'abnormality', 'absurdity', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'amputee', 'anticness', 'atrophy'],
    'defraud': ['abstract', 'and', 'annex', 'appropriate', 'bag', 'bamboozle', 'beat', 'beguile', 'beguile of', 'bilk', 'boost', 'borrow'],
    'defray': ['acknowledge', 'bear the expense', 'chip in', 'clear', 'cover', 'defray expenses', 'discharge', 'finance', 'foot the bill', 'fund', 'go dutch', 'honor a bill'],
    'defrayment': ['acquitment', 'acquittal', 'acquittance', 'amortization', 'amortizement', 'binder', 'cash', 'cash payment', 'clearance', 'debt service', 'defrayal', 'deposit'],
    'defrock': ['boot', 'bounce', 'break', 'bring into discredit', 'bring low', 'bring shame upon', 'bump', 'bust', 'can', 'cashier', 'cast reproach upon', 'debase'],
    'deft': ['daedalian', 'adept', 'adroit', 'agile', 'apt', 'artistic', 'authoritative', 'bravura', 'brilliant', 'brisk', 'clean', 'clever'],
    'deftly': ['ably', 'adeptly', 'adroitly', 'agilely', 'aptly', 'artfully', 'artistically', 'brilliantly', 'capably', 'cleverly', 'competently', 'cunningly'],
    'deftness': ['ability', 'address', 'adeptness', 'adroitness', 'agility', 'airmanship', 'artfulness', 'artisanship', 'artistry', 'assuredness', 'bravura', 'brilliance'],
    'defunct': ['sol', 'ago', 'all bets off', 'all gone', 'all off', 'all over', 'all up', 'annihilated', 'antiquated', 'antique', 'asleep', 'asleep in jesus'],
    'defuse': ['allay', 'appease', 'calm', 'conciliate', 'cool', 'dulcify', 'lay', 'lay the dust', 'mollify', 'pacify', 'placate', 'pour balm on'],
    'defy': ['affront', 'attack', 'baffle', 'balk', 'battle cry', 'be a man', 'be proof against', 'bear up', 'bear up against', 'beard', 'bid defiance', 'bid to combat'],
    'degage': ['bohemian', 'affable', 'airy', 'blase', 'breezy', 'careless', 'casual', 'common', 'cordial', 'cursory', 'devil-may-care', 'disregardant'],
    'degenerate': ['abandoned', 'adulterate', 'alloy', 'alter', 'altered', 'ameliorate', 'apostate', 'apostatize', 'backslide', 'backslider', 'bad egg', 'bad lot'],
    'degeneration': ['abandon', 'abandonment', 'abjection', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'alteration', 'amelioration', 'apostasy', 'atrophy', 'betterment'],
    'degradable': ['ablative', 'biodegradable', 'corrosive', 'decomposable', 'decomposing', 'dilapidated', 'disintegrable', 'disintegrated', 'disintegrating', 'disintegrative', 'disjunctive', 'disruptive'],
    'degradation': ['abandon', 'abandonment', 'abasement', 'abjection', 'abjectness', 'ablation', 'abominableness', 'atomization', 'atrociousness', 'banishment', 'baseness', 'beggarliness'],
    'degrade': ['abase', 'abash', 'adulterate', 'alloy', 'belittle', 'boot', 'bounce', 'break', 'bring down', 'bring into discredit', 'bring low', 'bring shame upon'],
    'degrading': ['abasement', 'abusive', 'atrocious', 'backhand', 'backhanded', 'beneath one', 'bump', 'bust', 'calumnious', 'casting down', 'cheap', 'contumelious'],
    'degree': ['aa', 'ab', 'am', 'associate of arts', 'bs', 'bachelor of arts', 'bachelor of divinity', 'bachelor of science', 'dd', 'dds', 'doctor of divinity', 'doctor of laws'],
    'dehumidify': ['air-dry', 'anhydrate', 'bake', 'blot', 'brush', 'burn', 'cure', 'dehydrate', 'desiccate', 'drain', 'dry', 'evaporate'],
    'dehydrate': ['air-dry', 'anhydrate', 'bake', 'blast-freeze', 'blot', 'brine', 'brush', 'burn', 'corn', 'cure', 'dehumidify', 'desiccate'],
    'dehydrated': ['adust', 'baked', 'burnt', 'corky', 'desiccated', 'dried', 'dried-up', 'evaporated', 'exsiccated', 'mummified', 'parched', 'scorched'],
    'dehydration': ['air-drying', 'anhydration', 'blast-freezing', 'bottling', 'brining', 'canning', 'corning', 'curing', 'dehumidification', 'desiccation', 'drainage', 'dry-curing'],
    'deification': ['accolade', 'admiration', 'adoration', 'adulation', 'aggrandizement', 'apotheosis', 'appreciation', 'approbation', 'approval', 'ascent', 'assumption', 'awe'],
    'deify': ['accord respect to', 'admire', 'adore', 'adulate', 'aggrandize', 'apotheose', 'apotheosize', 'appreciate', 'beatify', 'belaud', 'bepraise', 'bless'],
    'deign': ['ok', 'accede to', 'accept', 'accord to', 'agree', 'agree to', 'approve', 'approve of', 'assent', 'be willing', 'concede', 'condescend'],
    'deism': ['acosmism', 'allotheism', 'anthropolatry', 'anthropomorphism', 'anthropotheism', 'autotheism', 'cosmotheism', 'ditheism', 'dualism', 'dyotheism', 'henotheism', 'hylotheism'],
    'deist': ['allotheist', 'anthropolater', 'anthropotheist', 'autotheist', 'cosmotheist', 'ditheist', 'dualist', 'henotheist', 'hylotheist', 'monotheist', 'multitheist', 'myriotheist'],
    'deity': ['aides', 'aidoneus', 'amen-ra', 'amor', 'aphrodite', 'apollo', 'apollo musagetes', 'ares', 'artemis', 'ashtoreth', 'astarte', 'astraea'],
    'deject': ['beat down', 'cast down', 'chill', 'damp', 'dampen', 'dampen the spirits', 'darken', 'dash', 'demoralize', 'depress', 'discourage', 'dishearten'],
    'dejected': ['beetle-browed', 'black', 'black-browed', 'blue', 'bowed-down', 'cast down', 'crestfallen', 'dark', 'dashed', 'depressed', 'despairing', 'despondent'],
    'dejection': ['bm', 'schmerz', 'slough of despond', 'abstraction', 'abulia', 'alienation', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'blank despondency', 'bloody flux'],
    'delay': ['abide', 'adjourn', 'afterthought', 'arrest', 'arrestation', 'arrestment', 'await', 'backpedal', 'backwater', 'be a sideliner', 'be still', 'bide'],
    'delayed': ['arrested', 'back', 'backward', 'behind', 'behindhand', 'belated', 'blocked', 'checked', 'delayed-action', 'detained', 'held up', 'hung up'],
    'delaying': ['micawberish', 'backward', 'dallying', 'dawdling', 'dilatory', 'dillydallying', 'dragging', 'easygoing', 'foot-dragging', 'lackadaisical', 'laggard', 'lagging'],
    'dele': ['blot', 'blot out', 'cancel', 'cross out', 'delete', 'efface', 'erase', 'expunge', 'obliterate', 'raze', 'rub out', 'rule out'],
    'delectable': ['adorable', 'agreeable', 'ambrosial', 'choice', 'dainty', 'darling', 'delicate', 'delicious', 'delightful', 'exquisite', 'flavorsome', 'good'],
    'delegate': ['accredit', 'agent', 'alternate', 'ambassador', 'appoint', 'ascribe', 'assign', 'authorize', 'buck', 'catchpole', 'charge', 'charter'],
    'delegation': ['accession', 'agency', 'agentship', 'anointing', 'anointment', 'appointment', 'arrogation', 'assignment', 'assumption', 'authority', 'authorization', 'brevet'],
    'delete': ['ko', 'abbreviate', 'abridge', 'abrupt', 'alienate', 'annul', 'black out', 'blot', 'blot out', 'blue-pencil', 'bowdlerize', 'call off'],
    'deleted': ['sol', 'absconded', 'absent', 'all bets off', 'all off', 'all over', 'all up', 'at an end', 'away', 'canceled', 'complete', 'concluded'],
    'deleterious': ['baleful', 'baneful', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'counterproductive', 'damaging', 'deadly', 'destroying', 'destructive', 'detrimental'],
    'deletion': ['abbreviation', 'abridgment', 'blot', 'blotting', 'blotting out', 'blue-penciling', 'bowdlerization', 'cancel', 'cancellation', 'censoring', 'censorship', 'editing'],
    'deli': ['appetizing store', 'bakery', 'bakeshop', 'bodega', 'butcher shop', 'creamery', 'dairy', 'delicatessen', 'food shop', 'food store', 'fruit stand', 'grocery'],
    'deliberate': ['advise with', 'advised', 'aforethought', 'aimed', 'aimed at', 'air', 'ambling', 'analyze', 'back down', 'balance', 'bargain', 'be abstracted'],
    'deliberately': ['advisedly', 'by design', 'calculatedly', 'calculatingly', 'cautiously', 'circumspectly', 'consciously', 'contemplatedly', 'crawlingly', 'creepingly', 'designedly', 'dilatorily'],
    'deliberateness': ['aforethought', 'calculatedness', 'calculation', 'canniness', 'care', 'careful consideration', 'carefulness', 'caution', 'cautiousness', 'circumspection', 'creeping', 'deliberate stages'],
    'deliberation': ['advisement', 'aforethought', 'airing', 'analysis', 'application', 'brainwork', 'brooding', 'buzz session', 'calculatedness', 'calculation', 'canniness', 'canvassing'],
    'delicacy': ['absoluteness', 'accommodatingness', 'accuracy', 'acquired taste', 'affectivity', 'agreeableness', 'airiness', 'airy texture', 'allergy', 'ambrosia', 'amiable weakness', 'anaphylaxis'],
    'delicate': ['herculean', 'victorian', 'abstruse', 'accommodating', 'accommodative', 'accurate', 'adept', 'aerial', 'agreeable', 'airy', 'allergic', 'ambrosial'],
    'delicate health': ['cachexia', 'cachexy', 'chronic ill health', 'debilitation', 'debility', 'decrepitude', 'delicacy', 'enervation', 'exhaustion', 'feebleness', 'fragility', 'frailty'],
    'delicately': ['compliantly', 'cunningly', 'cutely', 'daintily', 'easily', 'effeminately', 'faintly', 'feebly', 'gently', 'infirmly', 'languorously', 'listlessly'],
    'delicatessen': ['appetizing store', 'bakery', 'bakeshop', 'bodega', 'butcher shop', 'creamery', 'dairy', 'deli', 'food shop', 'food store', 'fruit stand', 'grocery'],
    'delicious': ['ok', 'ace-high', 'adorable', 'agreeable', 'ambrosial', 'amusing', 'appetizing', 'bad', 'bang-up', 'bonzer', 'boss', 'bully'],
    'delight': ['a thing for', 'adore', 'affinity', 'allure', 'amuse', 'appreciate', 'aptitude', 'aptness', 'attract', 'be in heaven', 'be pleased', 'beam'],
    'delight in': ['adore', 'appreciate', 'bask in', 'be fond of', 'be partial to', 'be pleased with', 'cherish', 'derive pleasure from', 'devour', 'eat up', 'enjoy', 'feast on'],
    'delighted': ['amused', 'charmed', 'comfortable', 'content', 'contented', 'cozy', 'diverted', 'easy', 'enchanted', 'entertained', 'eupeptic', 'euphoric'],
    'delightful': ['adorable', 'agreeable', 'alluring', 'ambrosial', 'amusing', 'appealing', 'attractive', 'beautiful', 'beguiling', 'bewitching', 'captivating', 'charming'],
    'delightfully': ['appealingly', 'bewitchingly', 'charmingly', 'enchantingly', 'engagingly', 'enravishingly', 'entrancingly', 'exquisitely', 'fascinatingly', 'intriguingly', 'invitingly', 'luxuriously'],
    'delilah': ['aspasia', 'jezebel', 'messalina', 'phryne', 'thais', 'adventuress', 'courtesan', 'demimondaine', 'demimonde', 'demirep', 'femme fatale', 'harem girl'],
    'delimit': ['bar', 'blaze', 'blaze a trail', 'blemish', 'blotch', 'bound', 'brand', 'chalk', 'chalk up', 'check', 'check off', 'cicatrize'],
    'delimitation': ['border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bounding', 'bourn', 'break boundary', 'breakoff point', 'ceiling', 'circling-in', 'circumscribing'],
    'delineate': ['block in', 'block out', 'brief', 'bring to life', 'cartoon', 'catch a likeness', 'chalk', 'chalk out', 'character', 'characterize', 'charcoal', 'chart'],
    'delineation': ['account', 'alphabet', 'art', 'band', 'bar', 'black and white', 'blueprint', 'brouillon', 'cameo', 'cartoon', 'catalog', 'cataloging'],
    'delinquency': ['aberrance', 'aberrancy', 'abnormality', 'amorality', 'arrear', 'arrearage', 'arrears', 'atrocity', 'backsliding', 'bad debt', 'breach', 'carnality'],
    'delinquent': ['aberrant', 'abnormal', 'abominable', 'atrocious', 'bad person', 'behindhand', 'careless', 'criminal', 'crook', 'culprit', 'deceiver', 'defaulter'],
    'deliquescent': ['contractive', 'declining', 'decoagulated', 'decreasing', 'decrescendo', 'decrescent', 'diminishing', 'diminuendo', 'dwindling', 'in solution', 'in suspension', 'languishing'],
    'delirious': ['abandoned', 'ablaze', 'afire', 'all agog', 'amok', 'ardent', 'at fever pitch', 'babbling', 'bellowing', 'berserk', 'bewildered', 'boiling over'],
    'delirium': ['abandon', 'afebrile delirium', 'agnosia', 'apparition', 'ardor', 'block', 'blocking', 'brainchild', 'brainstorm', 'bubble', 'calenture', 'childbed fever'],
    'delirium tremens': ['alcoholic addiction', 'alcoholic psychosis', 'alcoholism', 'bottle nose', 'delirium alcoholicum', 'dementia a potu', 'dipsomania', 'dream', 'ebriosity', 'grog blossom', 'habitual drunkenness', 'hallucination'],
    'deliver': ['abalienate', 'administer', 'affranchise', 'alien', 'alienate', 'amortize', 'announce', 'articulate', 'assign', 'barter', 'bear', 'bequeath'],
    'deliverance': ['emancipation proclamation', 'abalienation', 'accommodation', 'accordance', 'action', 'affranchisement', 'alienation', 'amortization', 'amortizement', 'assignation', 'assignment', 'award'],
    'deliverer': ['audubon society', 'national wildlife service', 'sierra club', 'conservationist', 'conservator', 'forest ranger', 'freer', 'game warden', 'keeper', 'liberator', 'lifesaver', 'manumitter'],
    'delivery': ['emancipation proclamation', 'abalienation', 'accommodation', 'accordance', 'accouchement', 'affranchisement', 'alienation', 'amortization', 'amortizement', 'articulation', 'assignation', 'assignment'],
    'dell': ['abysm', 'abyss', 'arroyo', 'bottom', 'bottom glade', 'bottoms', 'box canyon', 'breach', 'break', 'canyon', 'cavity', 'chap'],
    'delouse': ['antisepticize', 'autoclave', 'bleach', 'boil', 'bowdlerize', 'chlorinate', 'clean', 'clean out', 'clean up', 'cleanse', 'clear out', 'decontaminate'],
    'delta': ['alkali flat', 'alluvial plain', 'basin', 'bill', 'bottomland', 'branch', 'breakwater', 'bushveld', 'campo', 'cape', 'champaign', 'champaign country'],
    'deltoid': ['centrifugal', 'cuneate', 'cuneated', 'cuneiform', 'delta-shaped', 'deltalike', 'divaricate', 'divaricating', 'divergent', 'diverging', 'fan-shape', 'fan-shaped'],
    'deludable': ['cullible', 'deceivable', 'dupable', 'easy', 'exploitable', 'foolable', 'green', 'gullible', 'hoaxable', 'hoodwinkable', 'humbugable', 'ingenuous'],
    'delude': ['bamboozle', 'beguile', 'betray', 'bluff', 'cajole', 'cheat on', 'circumvent', 'conjure', 'deceive', 'diddle', 'double-cross', 'dupe'],
    'deluder': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'actor', 'bamboozler', 'befuddler', 'beguiler', 'charmer', 'counterfeiter'],
    'deluge': ['niagara', 'abound', 'affusion', 'alluvion', 'alluvium', 'army', 'aspergation', 'aspersion', 'avalanche', 'baptism', 'baptize', 'bath'],
    'delusion': ['aberrancy', 'aberration', 'acting', 'affectation', 'agnosia', 'airy nothing', 'apparition', 'appearance', 'artifice', 'attitudinizing', 'autism', 'bamboozlement'],
    'delusive': ['barmecidal', 'barmecide', 'aberrant', 'abroad', 'adrift', 'airy', 'all abroad', 'all off', 'all wrong', 'amiss', 'apparent', 'apparitional'],
    'deluxe': ['babylonian', 'corinthian', 'awe-inspiring', 'awful', 'barbaric', 'choice', 'dainty', 'delicate', 'elaborate', 'elegant', 'exquisite', 'extravagant'],
    'delve': ['backset', 'beat the bushes', 'bore', 'burrow', 'cavity', 'cultivate', 'culture', 'cut', 'dig', 'dig out', 'dike', 'dredge'],
    'demagogue': ['agent provocateur', 'agitator', 'agitprop', 'catalyst', 'debate', 'debater', 'declaim', 'declaimer', 'elocute', 'exciter', 'firebrand', 'fomenter'],
    'demagoguery': ['debating', 'declamation', 'demagogism', 'elocution', 'eloquence', 'forensics', 'homiletics', 'lecturing', 'oratory', 'platform oratory', 'public speaking', 'pyrotechnics'],
    'demand': ['address', 'admission', 'admission fee', 'anchorage', 'application', 'apply for', 'appoint', 'appurtenance', 'ask', 'ask a question', 'ask about', 'ask for'],
    'demand draft': ['cd', 'iou', 'mo', 'acceptance', 'acceptance bill', 'bank acceptance', 'bank check', 'bill', 'bill of draft', 'bill of exchange', 'blank check', 'certificate'],
    'demanding': ['herculean', 'spartan', 'spartanic', 'abstruse', 'accurate', 'arduous', 'astringent', 'attentive', 'austere', 'authoritarian', 'brutal', 'burdensome'],
    'demarcate': ['analyze', 'be characteristic', 'blaze', 'blaze a trail', 'blemish', 'blotch', 'bound', 'brand', 'chalk', 'chalk up', 'characterize', 'check'],
    'demarcation': ['alteration', 'analysis', 'anatomization', 'atomization', 'ban', 'bar', 'barring', 'blockade', 'bounding', 'boycott', 'change', 'circling-in'],
    'demasculinize': ['castrate', 'desex', 'desexualize', 'devitalize', 'effeminate', 'effeminatize', 'effeminize', 'emasculate', 'enervate', 'etiolate', 'exhaust', 'geld'],
    'dematerialize': ['attenuate', 'be consumed', 'be gone', 'cease', 'cease to be', 'cease to exist', 'depart', 'die', 'die away', 'die out', 'disappear', 'disembody'],
    'demean': ['abase', 'abash', 'acquit', 'act', 'bear', 'belittle', 'bring down', 'bring low', 'carry', 'cast down', 'comport', 'conduct'],
    'demeaning': ['beneath one', 'cheap', 'common', 'debasing', 'degrading', 'deplorable', 'disadvantaged', 'disgraceful', 'gutter', 'humble', 'humiliating', 'humiliative'],
    'demeanor': ['action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'bearing', 'behavior', 'behavior pattern', 'behavioral norm', 'behavioral science'],
    'demented': ['abnormal', 'bereft of reason', 'brainsick', 'crackbrained', 'cracked', 'crazed', 'crazy', 'daft', 'delirious', 'deluded', 'deprived of reason', 'deranged'],
    'dementia': ['aberration', 'abnormality', 'alienation', 'brain damage', 'brainsickness', 'clouded mind', 'craziness', 'daftness', 'dementedness', 'derangement', 'disorientation', 'distraction'],
    'demerol': ['amytal', 'amytal pill', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal', 'tuinal pill'],
    'demesne': ['acres', 'ambit', 'arable land', 'area', 'arena', 'bailiwick', 'barnyard', 'barton', 'beat', 'border', 'borderland', 'cattle ranch'],
    'demeter': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ashtoreth', 'astarte', 'ate', 'athena', 'baal'],
    'demigod': ['achilles', 'david', 'hector', 'roland', 'samson', 'a man', 'brave', 'bulldog', 'chutzpanik', 'decorated hero', 'demigoddess', 'fighting cock'],
    'demimonde': ['aspasia', 'delilah', 'jezebel', 'messalina', 'phryne', 'thais', 'adventuress', 'courtesan', 'demimondaine', 'demirep', 'fancy woman', 'femme fatale'],
    'demise': ['abalienation', 'alienation', 'amortization', 'amortizement', 'annihilation', 'assignation', 'assignment', 'bane', 'bargain and sale', 'barter', 'bequeathal', 'biological death'],
    'demised': ['asleep', 'asleep in jesus', 'at rest', 'bereft of life', 'breathless', 'called home', 'carrion', 'croaked', 'dead', 'dead and gone', 'death-struck', 'deceased'],
    'demobilization': ['breakup', 'deactivation', 'demilitarization', 'detachment', 'diaspora', 'disarmament', 'disbanding', 'disbandment', 'discharge', 'disintegration', 'dismissal', 'disorganization'],
    'demobilize': ['break up', 'cast loose', 'deactivate', 'debrief', 'decommission', 'demilitarize', 'demob', 'detach', 'disarm', 'disband', 'discharge', 'disintegrate'],
    'democracy': ['absolute monarchy', 'aristocracy', 'autarchy', 'autocracy', 'autonomy', 'coalition government', 'collective farm', 'collectivism', 'collectivity', 'collegiality', 'colonialism', 'common ownership'],
    'democrat': ['conservative', 'labourite', 'republican', 'tory', 'whig', 'heeler', 'loyalist', 'partisan', 'party faithful', 'party hack', 'party man', 'party member'],
    'democratic': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'civic', 'civil', 'classless', 'constitutional', 'despotic', 'dictatorial'],
    'democratic party': ['american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party', 'greenback party', 'know-nothing party'],
    'demolish': ['annihilate', 'answer', 'answer conclusively', 'argue down', 'atomize', 'break', 'break into pieces', 'break to pieces', 'break up', 'burst', 'cleave', 'confound'],
    'demolition': ['answer', 'complete answer', 'confounding', 'confutation', 'contradiction', 'controversion', 'demolishment', 'denial', 'disassembly', 'discrediting', 'dismantlement', 'effective rejoinder'],
    'demon': ['his satanic majesty', 'lucifer', 'satan', 'satanas', 'the adversary', 'the arch-fiend', 'the common enemy', 'the demon', 'the devil', 'the devil incarnate', 'the evil one', 'the evil spirit'],
    'demoniac': ['aliene', 'bedlamite', 'borderline case', 'crackbrain', 'crackpot', 'crazed', 'crazy', 'dement', 'demonic', 'devilish', 'diabolic', 'energumen'],
    'demoniacal': ['draconian', 'mephistophelian', 'tartarean', 'abandoned', 'amok', 'animal', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bellowing'],
    'demonism': ['black mass', 'druidism', 'parsiism', 'sabaism', 'satanism', 'zoroastrianism', 'animal worship', 'black magic', 'chthonian worship', 'demonography', 'demonolatry', 'demonology'],
    'demonstrable': ['absolute', 'actual', 'admitting no question', 'apodictic', 'apparent', 'attestable', 'authenticatable', 'certain', 'checkable', 'conclusive', 'confirmable', 'demonstratable'],
    'demonstrate': ['account for', 'adumbrate', 'advertise', 'affect', 'afford proof of', 'air', 'allegorize', 'approve', 'argue', 'ascertain', 'attest', 'audit'],
    'demonstration': ['absolute indication', 'allegorization', 'alphabet', 'art', 'beef', 'bitch', 'blazon', 'blueprint', 'boycott', 'bravura', 'brilliancy', 'burden of proof'],
    'demonstrative': ['christophanic', 'satanophanic', 'accessible', 'adoring', 'affectional', 'affectionate', 'affective', 'allegorizing', 'angelophanic', 'annotative', 'apodictic', 'appearing'],
    'demonstrator': ['allegorist', 'annotator', 'cicerone', 'clarifier', 'commentator', 'critic', 'cryptanalyst', 'cryptographer', 'cryptologist', 'decoder', 'definer', 'demythologizer'],
    'demoralize': ['agitate', 'bastardize', 'bewilder', 'bludgeon', 'bluster', 'bluster out of', 'browbeat', 'brutalize', 'bulldoze', 'bully', 'chill', 'confuse'],
    'demote': ['abase', 'boot', 'bounce', 'break', 'bump', 'bust', 'can', 'cashier', 'debase', 'defrock', 'degrade', 'demean'],
    'demotion': ['banishment', 'blackballing', 'comedown', 'concavity', 'de-escalation', 'debasement', 'decadence', 'decadency', 'declension', 'declination', 'decline', 'deformation'],
    'demulcent': ['alleviating', 'alleviative', 'analgesic', 'anesthetic', 'anodyne', 'assuasive', 'balm', 'balmy', 'balsam', 'balsamic', 'benumbing', 'brilliantine'],
    'demur': ['aversion', 'back down', 'balance', 'balk', 'bashfulness', 'beef', 'bitch', 'blench', 'boggle', 'boggling', 'boycott', 'call in question'],
    'demure': ['quakerish', 'victorian', 'backward', 'bashful', 'censorious', 'close', 'confused', 'conscious', 'coy', 'decent', 'decorous', 'diffident'],
    'demurrer': ['answer', 'apostate', 'argument', 'beef', 'bitch', 'boycott', 'challenge', 'complaint', 'compunction', 'counterstatement', 'defense', 'demonstration'],
    'demythologize': ['account for', 'allegorize', 'clarify', 'clear up', 'crack', 'decipher', 'demonstrate', 'elucidate', 'enlighten', 'euhemerize', 'exemplify', 'explain'],
    'den': ['babylon', 'gomorrah', 'sodom', 'adytum', 'ashram', 'asylum', 'bolt-hole', 'booking office', 'bordello', 'box office', 'branch', 'branch office'],
    'den of iniquity': ['babylon', 'gomorrah', 'sodom', 'bagnio', 'bawdyhouse', 'bordello', 'brothel', 'cathouse', 'crib', 'den', 'den of vice', 'disorderly house'],
    'denature': ['accommodate', 'adapt', 'adjust', 'adulterate', 'alloy', 'alter', 'ameliorate', 'bastardize', 'better', 'break up', 'canker', 'change'],
    'deniable': ['arguable', 'at issue', 'confutable', 'conjectural', 'contestable', 'controversial', 'controvertible', 'debatable', 'disputable', 'doubtable', 'doubtful', 'dubious'],
    'denial': ['eighteenth amendment', 'prohibition party', 'volstead act', 'abjuration', 'abjurement', 'abnegation', 'abrogation', 'absolute contradiction', 'abstaining', 'agnosticism', 'annulment', 'answer'],
    'denied': ['belied', 'confounded', 'confuted', 'contemned', 'declined', 'declined with thanks', 'deflated', 'despised', 'disapproved', 'discarded', 'discounted', 'discredited'],
    'denigrate': ['asperse', 'bedarken', 'besmirch', 'bespatter', 'black', 'blacken', 'blackwash', 'blot', 'blotch', 'call names', 'calumniate', 'charcoal'],
    'denizen': ['addressee', 'artist-in-residence', 'citizen', 'colonize', 'dweller', 'empeople', 'frequenter', 'habitant', 'haunter', 'house detective', 'incumbent', 'inhabit'],
    'denomination': ['amish', 'anglicanism', 'anglo-catholicism', 'arianism', 'athanasianism', 'boehmenism', 'calvinism', 'catholicism', 'christian science', 'confucianism', 'congregationalism', 'conservative judaism'],
    'denotative': ['allegorical', 'associational', 'connotational', 'connotative', 'definable', 'demonstrative', 'denominative', 'denotational', 'designative', 'diagnostic', 'emblematic', 'evidential'],
    'denote': ['add up to', 'advert to', 'allude to', 'announce', 'approve', 'argue', 'attest', 'be construed as', 'be indicative of', 'be significant of', 'be symptomatic of', 'be taken as'],
    'denouement': ['accomplishment', 'action', 'anagnorisis', 'angle', 'answer', 'apodosis', 'architectonics', 'architecture', 'argument', 'ascertainment', 'atmosphere', 'background'],
    'denounce': ['accuse', 'allege', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'article', 'assail', 'attack', 'attaint', 'be imminent', 'betray'],
    'dense': ['boeotian', 'adamantine', 'asinine', 'beef-brained', 'beef-witted', 'blockheaded', 'blockish', 'bony', 'bovine', 'bristling', 'broad-bodied', 'bulky'],
    'density': ['asininity', 'blockishness', 'body', 'boobishness', 'boorishness', 'bovinity', 'callosity', 'callousness', 'cloddishness', 'concreteness', 'crassness', 'crudeness'],
    'dent': ['alveolation', 'alveolus', 'baby tooth', 'bicuspid', 'boss', 'bucktooth', 'bump', 'canine', 'colophon', 'concavity', 'convexity', 'crown'],
    'dental': ['accented', 'allopathic', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bicuspid', 'bilabial'],
    'dentate': ['battlemented', 'chopped', 'clawed', 'crenate', 'crenated', 'crenellated', 'crenulate', 'dentated', 'digital', 'digitate', 'digitated', 'embrasured'],
    'denticle': ['baby tooth', 'bicuspid', 'bucktooth', 'canine', 'crown', 'cuspid', 'cutter', 'deciduous tooth', 'dent', 'denticulation', 'dentil', 'dentition'],
    'dentifrice': ['abstergent', 'cathartic', 'cleaner', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing cream', 'cold cream', 'cream', 'depurant', 'detergent', 'diuretic'],
    'denude': ['bankrupt', 'bare', 'bleed', 'bleed white', 'defoliate', 'denudate', 'deplume', 'deprive', 'despoil', 'dismantle', 'dismember', 'displume'],
    'denuded': ['bare', 'bared', 'bereaved', 'bereaved of', 'bereft', 'cut off', 'denudated', 'deprived of', 'divested', 'exposed', 'lacking', 'laid bare'],
    'denunciate': ['accuse', 'allege', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'article', 'attaint', 'blacklist', 'blame', 'book', 'bring accusation'],
    'denunciation': ['accusal', 'accusation', 'accusing', 'allegation', 'allegement', 'anathema', 'anathematizing', 'arraignment', 'ban', 'bill of particulars', 'blame', 'blasphemy'],
    'deny': ['abandon', 'abjure', 'abstain', 'answer', 'answer conclusively', 'argue down', 'assert the contrary', 'avoid', 'back down', 'back out', 'backwater', 'ban'],
    'deodorize': ['belie', 'camouflage', 'color', 'disguise', 'distort', 'dress up', 'embellish', 'embroider', 'falsify', 'freshen the air', 'fudge', 'fumigate'],
    'depart': ['abandon', 'abrupt', 'abscond', 'absquatulate', 'alienate', 'be consumed', 'be getting along', 'be gone', 'be lost', 'beat a retreat', 'beat it', 'blow'],
    'depart from': ['abandon', 'back out', 'be distinct', 'be distinguished', 'bear off', 'beg off', 'bend', 'branch off', 'change the bearing', 'clash with', 'conflict with', 'contrast with'],
    'departed': ['absconded', 'absent', 'ago', 'antiquated', 'antique', 'ashes', 'asleep', 'asleep in jesus', 'at rest', 'away', 'bereft of life', 'blown over'],
    'departed spirit': ['masan', 'apparition', 'appearance', 'astral', 'astral spirit', 'banshee', 'control', 'disembodied spirit', 'duppy', 'dybbuk', 'eidolon', 'form'],
    'department': ['airspace', 'ambit', 'area', 'arena', 'bailiwick', 'beat', 'belt', 'border', 'borderland', 'branch', 'bureau', 'circle'],
    'department store': ['boutique', 'chain store', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'dime store', 'discount house', 'discount store', 'emporium', 'establishment'],
    'departure': ['awol', 'french leave', 'aberrancy', 'aberration', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'annihilation', 'bane'],
    'depend': ['all depend', 'bag', 'bank', 'bank on', 'base', 'be based on', 'be contingent on', 'be dependent on', 'be predicated on', 'bottom', 'build', 'cascade'],
    'depend on': ['accrue from', 'arise from', 'bank on', 'be based on', 'be contingent on', 'be dependent on', 'be due to', 'be predicated on', 'bet on', 'bud from', 'calculate on', 'come from'],
    'dependable': ['calculable', 'fail-safe', 'faithful', 'faithworthy', 'fast', 'firm', 'guaranteed', 'harmless', 'incorruptible', 'invincible', 'inviolable', 'invulnerable'],
    'dependence': ['maecenas', 'a habit', 'abettor', 'acceptation', 'acception', 'acquiescence', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'addiction', 'admirer', 'advocate'],
    'dependent': ['accessory', 'addicted', 'addicted to', 'adherent', 'ancillary', 'appendage', 'appurtenant', 'at issue', 'attendant', 'based on', 'boxed in', 'buff'],
    'dependent on': ['addicted', 'addicted to', 'answerable for', 'apt to', 'arising from', 'attributable to', 'based on', 'boxed in', 'capable of', 'caused by', 'circumscribed by', 'coming from'],
    'depict': ['act a part', 'act out', 'bring to life', 'cartoon', 'catch a likeness', 'chalk', 'character', 'characterize', 'charcoal', 'chart', 'color', 'copy'],
    'depiction': ['alphabet', 'art', 'blueprint', 'cameo', 'catalog', 'cataloging', 'character', 'character sketch', 'charactering', 'characterization', 'chart', 'choreography'],
    'deplane': ['alight', 'come to land', 'debark', 'debus', 'detrain', 'disembark', 'disemplane', 'dock', 'drop anchor', 'go ashore', 'land', 'make a landfall'],
    'deplete': ['ablate', 'absorb', 'assimilate', 'bankrupt', 'bleed', 'bleed white', 'blow', 'blow out', 'burn up', 'clean out', 'clear', 'clear away'],
    'depletion': ['ablation', 'absorption', 'assimilation', 'attrition', 'burning up', 'cleaning out', 'clearance', 'clearing', 'consumption', 'corrosion', 'curtailment', 'cut'],
    'depletion allowance': ['aid', 'alimony', 'allotment', 'allowance', 'annuity', 'assistance', 'bounty', 'dole', 'fellowship', 'financial assistance', 'grant', 'grant-in-aid'],
    'deplorable': ['abominable', 'affecting', 'afflictive', 'appalling', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beneath contempt', 'beneath one'],
    'deplore': ['be sorry for', 'bemoan', 'bewail', 'cry', 'deprecate', 'dirge', 'disapprove', 'elegize', 'give sorrow words', 'grieve', 'keen', 'knell'],
    'deploy': ['aberrate', 'adduce', 'advance', 'allege', 'allocate', 'arrange', 'array', 'assign', 'branch', 'branch out', 'bring forward', 'bring on'],
    'deployment': ['aberration', 'addition', 'adjunct', 'aggrandizement', 'allocation', 'allotment', 'ampliation', 'amplification', 'apportionment', 'arrangement', 'array', 'arraying'],
    'deplume': ['abase', 'bleed', 'bleed white', 'boot', 'bounce', 'break', 'bring into discredit', 'bring low', 'bring shame upon', 'bump', 'bust', 'can'],
    'deport': ['abstract', 'acquit', 'act', 'assign', 'ban', 'banish', 'bear', 'blackball', 'carry', 'carry over', 'cast off', 'cast out'],
    'deportment': ['action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'bearing', 'behavior', 'behavior pattern', 'behavioral norm', 'behavioral science'],
    'deposal': ['abdication', 'cashiering', 'conge', 'deconsecration', 'defrocking', 'demission', 'deposition', 'deprivation', 'dethronement', 'disbarment', 'disbarring', 'discharge'],
    'depose': ['acknowledge', 'affirm', 'allege', 'and candle', 'assert under oath', 'asseverate', 'assure', 'attest', 'aver', 'avouch', 'avow', 'bank'],
    'deposit': ['accumulation', 'acquitment', 'acquittal', 'acquittance', 'allocation', 'alluvion', 'alluvium', 'amortization', 'amortizement', 'ash', 'assignment', 'bank'],
    'depositary': ['accountant', 'auditor', 'bookkeeper', 'bursar', 'cashier', 'cashkeeper', 'chamberlain', 'comptroller', 'controller', 'curator', 'depository', 'fiduciary'],
    'deposition': ['admission', 'affidavit', 'affirmation', 'allegation', 'allocation', 'alluvion', 'alluvium', 'ash', 'assertion', 'asseveration', 'assignment', 'attest'],
    'depository': ['fort knox', 'archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box'],
    'depot': ['archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box', 'bunker'],
    'depravation': ['abandon', 'abandonment', 'abjection', 'comedown', 'corruptedness', 'corruption', 'corruptness', 'debasement', 'decadence', 'decadency', 'declension', 'declination'],
    'deprave': ['abuse', 'adulterate', 'afflict', 'aggrieve', 'alloy', 'bastardize', 'befoul', 'bewitch', 'blight', 'brutalize', 'canker', 'cheapen'],
    'depraved': ['abandoned', 'abject', 'abominable', 'arrant', 'atrocious', 'base', 'beggarly', 'cheesy', 'contaminated', 'contemptible', 'corrupt', 'corrupted'],
    'depravity': ['abandon', 'abandonment', 'abjection', 'abjectness', 'abominableness', 'atrociousness', 'baseness', 'beggarliness', 'contemptibility', 'contemptibleness', 'corruptedness', 'corruption'],
    'deprecate': ['belittle', 'bemoan', 'bewail', 'de-emphasize', 'denigrate', 'deplore', 'depreciate', 'derogate', 'despise', 'detract', 'discommend', 'discountenance'],
    'deprecatory': ['abusive', 'back-biting', 'belittling', 'bitchy', 'blackening', 'blameful', 'calumniatory', 'calumnious', 'catty', 'censorious', 'condemnatory', 'contemptuous'],
    'depreciate': ['abate', 'ablate', 'abrade', 'abridge', 'abstract', 'abuse', 'allow', 'bate', 'beat down', 'belittle', 'break', 'bring down'],
    'depreciation': ['abatement', 'ablation', 'abridgment', 'agio', 'alleviation', 'allowance', 'attenuation', 'attrition', 'backbiting', 'backstabbing', 'bank discount', 'belittlement'],
    'depredate': ['bring to ruin', 'condemn', 'confound', 'consume', 'damn', 'deal destruction', 'decimate', 'desecrate', 'desolate', 'despoil', 'destroy', 'devastate'],
    'depredation': ['banditry', 'bloodbath', 'blue ruin', 'breakup', 'brigandage', 'brigandism', 'carnage', 'consumption', 'damnation', 'decimation', 'desolation', 'despoiling'],
    'depress': ['abridge', 'bear down', 'beat down', 'bring down', 'bring low', 'burden', 'cast down', 'cheapen', 'compress', 'couch', 'countersink', 'curtail'],
    'depressant': ['amytal', 'amytal pill', 'demerol', 'dial', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill'],
    'depressed': ['alveolar', 'alveolate', 'anguished', 'anxious', 'bad', 'badly off', 'blue', 'bored', 'bowed-down', 'cast down', 'cheerless', 'couchant'],
    'depressing': ['affecting', 'afflictive', 'bitter', 'black', 'bleak', 'cheerless', 'comfortless', 'deplorable', 'depressant', 'depressive', 'discomforting', 'discouraging'],
    'depression': ['schmerz', 'slough of despond', 'abatement', 'abridgment', 'abstraction', 'abulia', 'aching heart', 'agony', 'agony of mind', 'alienation', 'alleviation', 'alveolation'],
    'deprivation': ['abnegation', 'abridgment', 'absence', 'awayness', 'banishment', 'bare cupboard', 'bare subsistence', 'beggarliness', 'beggary', 'bereavement', 'blackballing', 'blank'],
    'deprive': ['abridge', 'bankrupt', 'bare', 'bereave', 'bleed', 'boot', 'bounce', 'break', 'bump', 'bust', 'can', 'cashier'],
    'deprived': ['badly off', 'beggared', 'beggarly', 'bereaved', 'bereft', 'depressed', 'destitute', 'disadvantaged', 'fatherless', 'fleeced', 'ghettoized', 'impoverished'],
    'deprived of': ['bankrupt in', 'bare of', 'bereaved', 'bereaved of', 'bereft', 'bereft of', 'cut off', 'denuded', 'denuded of', 'destitute of', 'devoid of', 'divested'],
    'depth': ['french pitch', 'sophia', 'abstruseness', 'abysm', 'abyss', 'acumen', 'amplitude', 'area', 'astuteness', 'bigness', 'bodily size', 'body'],
    'depthless': ['ankle-deep', 'cursory', 'epidermal', 'few', 'footling', 'inconsequential', 'inconsiderable', 'insignificant', 'jejune', 'knee-deep', 'light', 'little'],
    'deputation': ['accession', 'agency', 'agentship', 'anointing', 'anointment', 'appointment', 'arrogation', 'assignment', 'assumption', 'authority', 'authorization', 'brevet'],
    'deputize': ['accredit', 'act for', 'answer for', 'appear for', 'arm', 'assign', 'authorize', 'back up', 'charge', 'charter', 'clothe', 'clothe with power'],
    'deputy': ['g-man', 'mp', 'acolyte', 'adjutant', 'administrator', 'advocate', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider', 'alternate'],
    'derange': ['afflict', 'clutter', 'craze', 'debilitate', 'dement', 'devitalize', 'disable', 'disarrange', 'disarray', 'discommode', 'discompose', 'dishevel'],
    'deranged': ['abnormal', 'amiss', 'askew', 'awry', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'bereft of reason', 'berserk', 'bonkers'],
    'derangement': ['aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'alienation', 'amorphism', 'anomalism', 'anomalousness', 'anomaly', 'brain damage', 'brainsickness'],
    'derby': ['le mans', 'olympic games', 'olympics', 'air race', 'automobile race', 'bicycle race', 'boat race', 'bout', 'concours', 'contest', 'contest of speed', 'cross-country race'],
    'dereism': ['airy nothing', 'alienation', 'autism', 'autistic thinking', 'avoidance mechanism', 'blame-shifting', 'bubble', 'chimera', 'compensation', 'daydream', 'deception', 'decompensation'],
    'derelict': ['bowery bum', 'dp', 'ishmael', 'abandoned', 'battered', 'beachcomber', 'beat-up', 'beaten up', 'beggar', 'beggarly fellow', 'behindhand', 'blighter'],
    'dereliction': ['punic faith', 'abuse', 'apostasy', 'atrocity', 'bad faith', 'barratry', 'betrayal', 'bolt', 'breach', 'breach of faith', 'breach of promise', 'breach of trust'],
    'deride': ['banter', 'be above', 'be contemptuous of', 'belittle', 'care nothing for', 'chaff', 'contemn', 'dare', 'despise', 'diminish', 'disdain', 'disparage'],
    'derision': ['burlesque', 'butt', 'caricature', 'contempt', 'contumely', 'disrespect', 'jest', 'joke', 'lampoon', 'laughter', 'mock', 'mockery'],
    'derisive': ['abusive', 'arrogant', 'audacious', 'aweless', 'back-biting', 'bantering', 'belittling', 'biggety', 'bitchy', 'blackening', 'blameful', 'bluff'],
    'derivation': ['ic analysis', 'acceptance', 'accidence', 'acquisition', 'admission', 'admittance', 'adoption', 'affiliation', 'affix', 'affixation', 'allomorph', 'ancestry'],
    'derivative': ['accountable', 'acquired', 'alleged', 'ascribable', 'assignable', 'attributable', 'attributed', 'borrowed', 'by-product', 'charged', 'conjugate', 'consequent'],
    'derive': ['accept', 'acquire', 'admit', 'arouse', 'arrive at', 'assume', 'bag', 'be seized of', 'bring forth', 'bring out', 'bring to light', 'call forth'],
    'derive from': ['accept', 'accrue from', 'acquire', 'admit', 'adopt', 'affiliate to', 'appropriate', 'arise', 'arise from', 'assume', 'be contingent on', 'be due to'],
    'dermal': ['cortical', 'cutaneous', 'dermic', 'ecderonic', 'ectodermal', 'ectodermic', 'endermatic', 'endermic', 'epicarpal', 'epidermal', 'epidermic', 'furry'],
    'dermatitis': ['lombardy leprosy', 'acne', 'acne vulgaris', 'anemia', 'ariboflavinosis', 'beriberi', 'cachexia', 'chlorosis', 'deficiency anemia', 'dermamycosis', 'dermatosis', 'eczema'],
    'dermis': ['leatherette', 'leatheroid', 'blastoderm', 'coat', 'corium', 'cuticle', 'cutis', 'cutis vera', 'derma', 'ectoblast', 'ectoderm', 'endothelium'],
    'derogation': ['attrition', 'belittling', 'comedown', 'contempt', 'curtailment', 'cut', 'cutting', 'debasement', 'decadence', 'decadency', 'declension', 'declination'],
    'derogative': ['abusive', 'back-biting', 'belittling', 'bitchy', 'calumniatory', 'calumnious', 'catty', 'censorious', 'contemptuous', 'contumelious', 'defamatory', 'deprecatory'],
    'derogatory': ['abasing', 'abusive', 'back-biting', 'belittling', 'bitchy', 'calumniatory', 'calumnious', 'catty', 'censorious', 'contemptuous', 'contumelious', 'debasing'],
    'derrick': ['antenna tower', 'barbican', 'belfry', 'bell tower', 'campanile', 'colossus', 'column', 'crab', 'crane', 'cupola', 'dome', 'erector'],
    'dervish': ['albigensian', 'black muslim', 'catharist', 'franciscan', 'mohammedan', 'moslem', 'motazilite', 'muhammadan', 'muslim', 'mussulman', 'sabbatarian', 'sectary'],
    'descant': ['nachtmusik', 'vorspiel', 'absolute music', 'accompaniment', 'adaptation', 'air', 'air varie', 'aleatory', 'aleatory music', 'alto', 'amplify', 'anthem'],
    'descend': ['advance', 'alight', 'ascend', 'assault', 'attack', 'back', 'back up', 'bank', 'be shamed', 'budge', 'cant', 'careen'],
    'descend upon': ['alight upon', 'ambush', 'assail', 'assault', 'attack', 'blitz', 'bushwhack', 'come at', 'come down on', 'crack down on', 'descend on', 'drop on'],
    'descendant': ['aftermath', 'backup man', 'breed', 'brood', 'by-product', 'child', 'children', 'conclusion', 'consequence', 'daughter', 'derivative', 'descendants'],
    'descending': ['ascending', 'axial', 'back', 'back-flowing', 'backward', 'collapsing', 'deciduous', 'declined', 'declining', 'declivate', 'declivitous', 'declivous'],
    'descent': ['brownian movement', 'indian file', 'abasement', 'advance', 'affiliation', 'altitude peak', 'angular motion', 'apparentation', 'array', 'articulation', 'ascending', 'ascent'],
    'describe': ['be characteristic', 'bring to life', 'character', 'characterize', 'chronicle', 'construe', 'define', 'delineate', 'demarcate', 'depict', 'detail', 'diagnose'],
    'description': ['account', 'anecdote', 'blood', 'brand', 'breed', 'cast', 'category', 'character', 'characterization', 'chronicle', 'clan', 'class'],
    'descriptive': ['constructional', 'constructive', 'definitional', 'delineative', 'depictive', 'diagnostic', 'exegetic', 'expositive', 'expressive', 'faithful', 'glottochronological', 'grammatic'],
    'descry': ['appreciate', 'behold', 'catch', 'catch sight of', 'clap eyes on', 'come alive', 'comprehend', 'detect', 'discern', 'discover', 'distinguish', 'encounter'],
    'desecrate': ['abuse', 'adulterate', 'alloy', 'befoul', 'canker', 'cheapen', 'coarsen', 'commit sacrilege', 'confound', 'contaminate', 'convert', 'corrupt'],
    'desecration': ['abomination', 'abuse', 'abuse of office', 'atrocity', 'befoulment', 'blasphemousness', 'blasphemy', 'conversion', 'corrupt administration', 'debasement', 'defalcation', 'defilement'],
    'desensitize': ['ko', 'anesthetize', 'bedaze', 'benumb', 'besot', 'blunt', 'chloroform', 'coldcock', 'deaden', 'dope', 'drug', 'dull'],
    'desert': ['arabia deserta', 'death valley', 'lebensraum', 'sahara', 'saharan', 'abandon', 'abscond', 'absquatulate', 'acarpous', 'advantageousness', 'agreeableness', 'air space'],
    'deserted': ['abandoned', 'abjured', 'antiquated', 'antique', 'apostasy', 'archaic', 'available', 'bar', 'bare', 'castaway', 'defenseless', 'demand'],
    'deserter': ['sabbath-breaker', 'absconder', 'apostasy', 'apostate', 'atheist', 'backslider', 'betrayal', 'blasphemer', 'bolt', 'bolter', 'breakaway', 'collaborationist'],
    'desertion': ['awol', 'french leave', 'abandonment', 'absence without leave', 'absquatulation', 'apostasy', 'atheism', 'backsliding', 'betrayal', 'bolt', 'breakaway', 'crossing-over'],
    'deserts': ['castigation', 'chastening', 'chastisement', 'comeuppance', 'compensation', 'condign punishment', 'correction', 'desert', 'disciplinary measures', 'discipline', 'due reward', 'dues'],
    'deserved': ['appropriate', 'balanced', 'condign', 'defensible', 'due', 'earned', 'entitled', 'equitable', 'even', 'evenhanded', 'fair', 'fair and square'],
    'deserving': ['admirable', 'ascribable', 'attributable', 'beyond all praise', 'comeuppance', 'commendable', 'creditable', 'deserts', 'due', 'entitled to', 'estimable', 'exemplary'],
    'desiccate': ['air-dry', 'anhydrate', 'bake', 'blast-freeze', 'blot', 'brine', 'brush', 'burn', 'corn', 'cure', 'decay', 'dehumidify'],
    'desideratum': ['aim', 'ambition', 'animus', 'aspiration', 'bare necessities', 'call for', 'catch', 'counsel', 'dearest wish', 'demand', 'demand for', 'desideration'],
    'design': ['abstract art', 'action', 'aim', 'aim at', 'ambition', 'anagnorisis', 'angle', 'animus', 'approach', 'architectonics', 'architecture', 'argument'],
    'designate': ['advert to', 'allocate', 'allot', 'allude to', 'appoint', 'apportion', 'appropriate', 'assign', 'baptize', 'be taken as', 'call', 'choose'],
    'designation': ['allocation', 'appellation', 'appellative', 'appointment', 'assignment', 'attribution', 'baptism', 'binomen', 'binomial name', 'blood', 'brand', 'breed'],
    'designed': ['advised', 'aforethought', 'aimed', 'aimed at', 'arranged', 'blueprinted', 'calculated', 'charted', 'conscious', 'considered', 'contemplated', 'contrived'],
    'designer': ['ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner', 'builder', 'conceiver', 'conniver', 'conspirator'],
    'designing': ['byzantine', 'machiavellian', 'machiavellic', 'abstract art', 'acute', 'arch', 'art', 'art form', 'artful', 'artist', 'arts and crafts', 'arts of design'],
    'desirable': ['acceptable', 'admirable', 'admissible', 'adorable', 'advantageous', 'advisable', 'affable', 'agreeable', 'alluring', 'amiable', 'amicable', 'appetizing'],
    'desire': ['amor', 'christian love', 'eros', 'platonic love', 'address', 'admiration', 'adoration', 'affection', 'agape', 'aim', 'aim at', 'ambition'],
    'desirous': ['acquisitive', 'agog', 'alacritous', 'all agog', 'amative', 'amatory', 'amorous', 'animated', 'anxious', 'appetitive', 'ardent', 'avid'],
    'desirous of': ['aching for', 'begrudging', 'bent on', 'covetous', 'crazy to', 'dying for', 'dying to', 'envious', 'envying', 'fain of', 'fond of', 'green with envy'],
    'desist': ['abandon', 'abdicate', 'abjure', 'abort', 'acknowledge defeat', 'belay', 'cancel', 'cease', 'cede', 'come off', 'cry quits', 'cut it out'],
    'desk': ['agency', 'ambo', 'atelier', 'bar', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'board', 'buffet', 'butcher shop', 'company'],
    'desolate': ['abandoned', 'acarpous', 'acheronian', 'afflict', 'aggrieve', 'agonize', 'alone', 'anguish', 'annihilate', 'arid', 'bare', 'barren'],
    'desolated': ['ausgespielt', 'bankrupt', 'blasted', 'blighted', 'broken', 'broken-down', 'brokenhearted', 'crushed', 'cut up', 'destroyed', 'devastated', 'done for'],
    'desolating': ['agonizing', 'baneful', 'calamitous', 'cataclysmal', 'cataclysmic', 'catastrophic', 'consuming', 'consumptive', 'deadly', 'demolishing', 'demolitionary', 'depredatory'],
    'desolation': ['arabia deserta', 'death valley', 'sahara', 'abandonment', 'aching heart', 'agonizingness', 'agony', 'agony of mind', 'anguish', 'bale', 'barren', 'barren land'],
    'despair': ['schmerz', 'slough of despond', 'abandon', 'abandon hope', 'acedia', 'aching heart', 'agony', 'agony of mind', 'anguish', 'apathy', 'bale', 'become suicidal'],
    'desperado': ['cain', 'judas', 'apache', 'assassin', 'assassinator', 'badman', 'bandit', 'betrayer', 'bloodletter', 'bloodshedder', 'bravo', 'bucko'],
    'desperate': ['dionysiac', 'accident-prone', 'aching for', 'acute', 'affording no hope', 'amok', 'apathetic', 'atrocious', 'bacchic', 'baffled', 'balked', 'berserk'],
    'desperately': ['a corps perdu', 'carelessly', 'demonically', 'fanatically', 'fiercely', 'forlornly', 'frantically', 'frenetically', 'furiously', 'happen what may', 'hastily', 'head over heels'],
    'desperation': ['acedia', 'anguish', 'anxiety', 'anxiousness', 'apathy', 'cave of trophonius', 'cave of despair', 'defeatism', 'dejection', 'depression', 'despair', 'desperateness'],
    'despicable': ['abhorrent', 'abject', 'abominable', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beggarly', 'below contempt', 'beneath contempt', 'blameworthy'],
    'despise': ['abhor', 'abjure', 'abominate', 'avoid', 'be above', 'be contemptuous of', 'brush aside', 'care nothing for', 'chuck', 'chuck out', 'contemn', 'contradict'],
    'despised': ['contemned', 'declined', 'declined with thanks', 'denied', 'disapproved', 'discarded', 'discounted', 'disdained', 'disliked', 'dismissed', 'disowned', 'excepted'],
    'despite': ['schadenfreude', 'abhorrence', 'abomination', 'affront', 'airs', 'arrogance', 'aspersion', 'at all costs', 'at any cost', 'atrocity', 'audacity', 'aversion'],
    'despiteful': ['acrid', 'antagonistic', 'antipathetic', 'belligerent', 'bitchy', 'bitter', 'cattish', 'catty', 'caustic', 'clashing', 'colliding', 'conflicting'],
    'despoil': ['abuse', 'adulterate', 'afflict', 'aggrieve', 'alloy', 'befoul', 'betray', 'bewitch', 'bleed', 'bleed white', 'blight', 'bring to ruin'],
    'despoliation': ['abomination', 'atrocity', 'bad', 'banditry', 'bane', 'befoulment', 'blight', 'bloodbath', 'blue ruin', 'breakup', 'brigandage', 'brigandism'],
    'despond': ['abandon hope', 'become suicidal', 'brood', 'despair', 'despair of', 'droop', 'falter', 'give up', 'give up hope', 'give way', 'hit rock bottom', 'languish'],
    'despondency': ['schmerz', 'slough of despond', 'acedia', 'apathy', 'blank despondency', 'cave of trophonius', 'cave of despair', 'death wish', 'dejectedness', 'dejection', 'depression', 'despair'],
    'despondent': ['affording no hope', 'apathetic', 'bleak', 'blue', 'bowed-down', 'cast down', 'cheerless', 'comfortless', 'dashed', 'dejected', 'depressed', 'despairing'],
    'despot': ['simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'autocrat', 'caesar', 'commissar', 'czar', 'dictator', 'disciplinarian'],
    'despotic': ['absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'autarchic', 'authoritarian', 'authoritative', 'autocratic', 'autonomous', 'bossy'],
    'despotism': ['caesarism', 'stalinism', 'absolute monarchy', 'absolutism', 'argumentum baculinum', 'autarchy', 'authoritarianism', 'autocracy', 'benevolent despotism', 'big stick', 'czarism', 'dictatorship'],
    'dessert': ['ambrosia', 'antepast', 'bonne bouche', 'cate', 'choice morsel', 'course', 'cover', 'dainty', 'delicacy', 'dish', 'entree', 'entremets'],
    'destigmatize': ['absolve', 'account for', 'acquit', 'amnesty', 'clear', 'cry sour grapes', 'decontaminate', 'discharge', 'dismiss', 'dispense from', 'do justice to', 'exculpate'],
    'destination': ['friday', 'friday the thirteenth', 'address', 'aim', 'anchorage', 'apodosis', 'appointed lot', 'astral influences', 'astrology', 'billhead', 'book of fate', 'bourn'],
    'destine': ['aim', 'aim at', 'allocate', 'allot', 'appoint', 'appropriate to', 'aspire after', 'aspire to', 'assign', 'assign to', 'be after', 'design'],
    'destined': ['appointed', 'approaching', 'bound', 'certain', 'coming', 'designed', 'desired', 'destinal', 'determined', 'devoted', 'doomed', 'emergent'],
    'destiny': ['friday', 'friday the thirteenth', 'heaven', 'paradise', 'a better place', 'accidentality', 'actuarial calculation', 'adventitiousness', 'afterlife', 'afterworld', 'allotment', 'allowance'],
    'destitute': ['badly off', 'bankrupt', 'bereft of', 'broke', 'broken', 'busted', 'deficient', 'depleted', 'deprived of', 'destitute of', 'devoid of', 'divested'],
    'destitution': ['absence', 'adversity', 'bare cupboard', 'bare subsistence', 'beggarliness', 'beggary', 'dearth', 'defectiveness', 'deficiency', 'deficit', 'deprivation', 'drought'],
    'destroy': ['abolish', 'abuse', 'afflict', 'aggrieve', 'annihilate', 'annul', 'assault', 'atomize', 'attack', 'baffle', 'balk', 'barbarize'],
    'destroyed': ['ausgespielt', 'bankrupt', 'blasted', 'blighted', 'botched', 'broken', 'desolated', 'devastated', 'done for', 'done in', 'down-and-out', 'fallen'],
    'destroyer': ['animal', 'annihilator', 'anthropophagite', 'arsonist', 'bane', 'barbarian', 'battleship', 'battlewagon', 'beast', 'biblioclast', 'bomber', 'brute'],
    'destruction': ['waterloo', 'abomination', 'abscission', 'amputation', 'annihilation', 'assassination', 'atrocity', 'bad', 'bane', 'bankruptcy', 'beating', 'befoulment'],
    'destructive': ['adverse', 'annihilative', 'antithetical', 'bad', 'baleful', 'baneful', 'black', 'brutal', 'calamitous', 'cataclysmal', 'cataclysmic', 'catastrophic'],
    'desuetude': ['abandonment', 'absentation', 'abstention', 'abstinence', 'casting away', 'cease', 'cessation', 'close', 'closing', 'closure', 'conclusion', 'discontinuance'],
    'desultory': ['aberrant', 'aberrative', 'adrift', 'afloat', 'aimless', 'alternating', 'amorphous', 'broken', 'by the way', 'capricious', 'careening', 'casual'],
    'detach': ['abstract', 'accredit', 'assign', 'authorize', 'break up', 'call up', 'cast off', 'charge', 'charter', 'commandeer', 'commission', 'commit'],
    'detached': ['laodicean', 'olympian', 'abstract', 'afoot and lighthearted', 'alien', 'alienated', 'alone', 'aloof', 'apart', 'apathetic', 'at large', 'at liberty'],
    'detached retina': ['amaurosis', 'blepharitis', 'cataract', 'choroiditis', 'conjunctivitis', 'cross-eye', 'defective vision', 'esotropia', 'eye defect', 'glaucoma', 'gutta serena', 'iritis'],
    'detachment': ['jim crow', 'kp', 'olympian detachment', 'abstraction', 'abulia', 'accidia', 'acedia', 'adjunct', 'age group', 'alienation', 'aloneness', 'aloofness'],
    'detail': ['kp', 'accredit', 'accuracy', 'add up', 'adduce', 'adjunct', 'age group', 'allocate', 'allot', 'amplify', 'anatomize', 'appoint'],
    'detailed': ['absolute', 'abundant', 'accurate', 'attentive', 'blow-by-blow', 'certain', 'circumstantial', 'close', 'complete', 'complex', 'complicated', 'comprehensive'],
    'details': ['brass tacks', 'bric-a-brac', 'cameo', 'catalog', 'cataloging', 'chaff', 'character', 'character sketch', 'characterization', 'chicken feed', 'chickenshit', 'delineation'],
    'detain': ['apprehend', 'arrest', 'backpedal', 'backwater', 'block', 'bog down', 'bottle up', 'box up', 'brake', 'bust', 'buttonhole', 'cage'],
    'detect': ['ascertain', 'catch', 'descry', 'determine', 'dig up', 'discern', 'discover', 'distinguish', 'encounter', 'espy', 'feel', 'find'],
    'detectable': ['apparent', 'appreciable', 'beholdable', 'determinable', 'discernible', 'disclosable', 'disclosed', 'discoverable', 'evident', 'exposable', 'exposed', 'exposed to view'],
    'detection': ['amassing evidence', 'blind flying', 'blind landing', 'bringing to light', 'casual discovery', 'catching', 'chance discovery', 'close inquiry', 'department of investigation', 'detective work', 'determination', 'determining'],
    'detective': ['bow street runner', 'fbi', 'fbi agent', 'federal', 'g-man', 'mp', 'secret service', 'sherlock', 'sherlock holmes', 't-man', 'asker', 'bailiff'],
    'detector': ['calorimeter', 'chemical detector', 'clinical thermometer', 'cryometer', 'electric thermometer', 'electronic counter', 'electronic detector', 'error corrector', 'error detector', 'galvanothermometer', 'gas thermometer', 'liquid-level sensor'],
    'detente': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'united nations troops', 'appeasement', 'balance of power', 'brinkmanship', 'calming', 'coexistence', 'colonialism', 'compromise'],
    'detention': ['afterthought', 'apprehension', 'arrest', 'arrestation', 'arrestment', 'bind', 'block', 'blockage', 'blocking', 'bureaucratic delay', 'captivity', 'check'],
    'deter': ['anticipate', 'avert', 'awe', 'bar', 'block', 'blunt', 'check', 'chill', 'cool', 'damp', 'dampen', 'daunt'],
    'detergent': ['abstergent', 'cathartic', 'cleaner', 'cleaning', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing', 'cleansing cream', 'cold cream', 'cream', 'dentifrice'],
    'deteriorate': ['agent provocateur', 'aggravate', 'alter', 'ameliorate', 'amplify', 'annoy', 'augment', 'be changed', 'be converted into', 'be renewed', 'bottom out', 'break'],
    'deterioration': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'aggravation', 'alteration', 'amelioration', 'amplification', 'annoyance', 'apostasy', 'atrophy', 'augmentation'],
    'determinant': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory', 'allele'],
    'determinate': ['absolute', 'admitting no exception', 'all-out', 'apodictic', 'ascertained', 'assured', 'attested', 'bound', 'categorical', 'certain', 'certified', 'circumscribed'],
    'determination': ['absolute indication', 'accomplishment', 'acid test', 'action', 'aim', 'allocation', 'ambition', 'animus', 'answer', 'appetence', 'appetency', 'appetite'],
    'determinative': ['absolute', 'adducible', 'admissible', 'antecedents', 'arrowhead', 'article', 'assuring', 'attestative', 'attestive', 'authentic', 'authoritative', 'base'],
    'determine': ['abort', 'act on', 'actuate', 'adjudge', 'advance', 'affect', 'afford proof of', 'aim', 'aim at', 'arbitrate', 'ascertain', 'aspire after'],
    'determined': ['actual', 'adamant', 'approaching', 'arrogant', 'ascertained', 'assured', 'attested', 'authenticated', 'bent', 'borne out', 'bound', 'bound and determined'],
    'determinism': ['calvinism', 'aftertime', 'afteryears', 'by-and-by', 'course ahead', 'crystal ball', 'distant future', 'election', 'eventuality', 'expectation', 'fatalism', 'foresight'],
    'deterrent': ['admonishing', 'admonitory', 'alarming', 'awing', 'bar', 'block', 'blockade', 'bottleneck', 'catch', 'cautionary', 'cautioning', 'check'],
    'detestable': ['abhorrent', 'abominable', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'below contempt', 'beneath contempt', 'blameworthy', 'brutal', 'contemptible'],
    'dethrone': ['break', 'bust', 'cashier', 'deconsecrate', 'defrock', 'depose', 'disbar', 'discrown', 'disenthrone', 'dismiss', 'displace', 'drum out'],
    'detonate': ['backfire', 'bang', 'bark', 'blast', 'blow out', 'blow up', 'burst', 'bust', 'charge', 'coal', 'cock', 'crack'],
    'detonation': ['backfire', 'bang', 'bark', 'blast', 'blowout', 'blowup', 'boom', 'bowshot', 'bullet', 'burst', 'cannon', 'crack'],
    'detour': ['aberrancy', 'aberration', 'ambages', 'back door', 'back road', 'back stairs', 'back street', 'back way', 'bear off', 'bend', 'bias', 'branch off'],
    'detract': ['abate', 'abrade', 'abstract', 'bate', 'beguile', 'call away', 'curtail', 'decrease', 'deduct', 'depreciate', 'derogate', 'detract attention'],
    'detract from': ['bedwarf', 'belittle', 'bring down', 'bring into discredit', 'bring low', 'cry down', 'de-emphasize', 'debase', 'decrease', 'decry', 'degrade', 'depreciate'],
    'detraction': ['aspersion', 'backbiting', 'backstabbing', 'belittlement', 'calumniation', 'calumny', 'character assassination', 'damage', 'defamation', 'depreciation', 'disparagement', 'harm'],
    'detrain': ['alight', 'come to land', 'debark', 'debus', 'deplane', 'disembark', 'disemplane', 'dock', 'drop anchor', 'go ashore', 'land', 'make a landfall'],
    'detriment': ['abomination', 'atrocity', 'bad', 'bane', 'bankruptcy', 'befoulment', 'bereavement', 'blight', 'breakage', 'breakdown', 'collapse', 'corruption'],
    'detrimental': ['adverse', 'antagonistic', 'bad', 'baleful', 'baneful', 'conflicting', 'contrary', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'counter'],
    'detritus': ['afterglow', 'afterimage', 'alluvion', 'alluvium', 'balance', 'breccia', 'butt', 'butt end', 'candle ends', 'chaff', 'debris', 'deposit'],
    'deuce': ['ace', 'best bower', 'bower', 'cards', 'clubs', 'craps', 'deck', 'diamonds', 'doubleton', 'dummy', 'face cards', 'flush'],
    'devaluate': ['beat down', 'break', 'cheapen', 'circulate', 'cut', 'cut prices', 'decline', 'decry', 'deflate', 'demonetize', 'depreciate', 'devalue'],
    'devalue': ['adulterate', 'alloy', 'canker', 'cheapen', 'circulate', 'coarsen', 'confound', 'contaminate', 'corrupt', 'debase', 'debauch', 'decry'],
    'devastate': ['abash', 'bring to ruin', 'chagrin', 'condemn', 'confound', 'consume', 'damn', 'deal destruction', 'decimate', 'demolish', 'depopulate', 'depredate'],
    'devastating': ['acid', 'baneful', 'beaming', 'bewitching', 'bitter', 'blooming', 'bright', 'brilliant', 'calamitous', 'captivating', 'cataclysmal', 'cataclysmic'],
    'devastation': ['bloodbath', 'blue ruin', 'breakup', 'carnage', 'confusion', 'consumption', 'damnation', 'decimation', 'depopulation', 'depredation', 'desolation', 'despoilment'],
    'develop': ['accrue', 'accumulate', 'achieve', 'acquire', 'actualize', 'add to', 'advance', 'affect', 'age', 'aggrandize', 'ameliorate', 'amend'],
    'developed': ['advanced', 'aged', 'ameliorated', 'archetypical', 'beautified', 'bettered', 'blooming', 'blossoming', 'budding', 'burgeoning', 'civilized', 'classic'],
    'developer': ['architect', 'contriver', 'designer', 'deviser', 'enterpriser', 'entrepreneur', 'fixer', 'fixing bath', 'framer', 'hypo', 'organizer', 'planner'],
    'development': ['abiogenesis', 'access', 'accession', 'accomplishment', 'accretion', 'accrual', 'accruement', 'accumulation', 'action', 'addition', 'advance', 'advancement'],
    'deviant': ['aberrant', 'abnormal', 'bent', 'bizarre', 'curious', 'deviate', 'deviating', 'different', 'divergent', 'eccentric', 'freaky', 'homosexual'],
    'deviate': ['alter', 'ameliorate', 'angle', 'angle off', 'be changed', 'be converted into', 'be distinct', 'be distinguished', 'be in error', 'be mistaken', 'be renewed', 'be wrong'],
    'deviating': ['o-shaped', 'aberrant', 'aberrative', 'ambagious', 'assorted', 'at odds', 'at variance', 'backhanded', 'capricious', 'changeable', 'changing', 'choppy'],
    'deviation': ['aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'allowance', 'alteration', 'ambages'],
    'device': ['am receiver', 'am tuner', 'am-fm receiver', 'am-fm tuner', 'cb', 'charlie mccarthy', 'fathometer', 'flexowriter typewriter', 'geiger counter', 'john hancock', 'rdf', 'x-ray microscope'],
    'devil': ['abaddon', 'apollyon', 'baba yaga', 'beelzebub', 'belial', 'bowery bum', 'lilith', 'linotyper', 'lucifer', 'mafioso', 'mephistopheles', 'old nick'],
    'devil worship': ['black mass', 'druidism', 'parsiism', 'sabaism', 'satanism', 'zoroastrianism', 'animal worship', 'black magic', 'chthonian worship', 'demonism', 'demonography', 'demonolatry'],
    'devilish': ['acherontic', 'draconian', 'lethean', 'mephistophelian', 'plutonian', 'plutonic', 'stygian', 'tartarean', 'accursed', 'animal', 'anthropophagous', 'arch'],
    'devilment': ['aggravation', 'annoyance', 'bad news', 'bedevilment', 'bitchiness', 'bore', 'bother', 'botheration', 'bothersomeness', 'crashing bore', 'cussedness', 'devilishness'],
    'devilry': ['black mass', 'satanism', 'arrantness', 'badness', 'baseness', 'bitchiness', 'black magic', 'chthonian worship', 'cruelty', 'cussedness', 'demonism', 'demonography'],
    'devious': ['byzantine', 'o-shaped', 'aberrant', 'aberrative', 'ambagious', 'amoral', 'anfractuous', 'artful', 'backhand', 'backhanded', 'balled up', 'bending'],
    'devise': ['add a codicil', 'arrange', 'assemble', 'assign', 'attested copy', 'beget', 'bequeath', 'bequeathal', 'bequest', 'bestow', 'blueprint', 'breed'],
    'devising': ['architecture', 'assembly', 'authorship', 'beginning', 'building', 'casting', 'coinage', 'composition', 'conception', 'concoction', 'construction', 'contrivance'],
    'devitalize': ['abate', 'afflict', 'attenuate', 'blunt', 'castrate', 'cramp', 'cripple', 'damp', 'dampen', 'deaden', 'debilitate', 'demasculinize'],
    'devitalized': ['ausgespielt', 'burned-out', 'castrated', 'debilitated', 'demasculinized', 'disabled', 'drained', 'effeminized', 'effete', 'emasculate', 'emasculated', 'enervated'],
    'devoid': ['bankrupt in', 'bare', 'bare of', 'barren', 'bereft of', 'bland', 'blank', 'bleached', 'characterless', 'clear', 'deficient', 'denuded of'],
    'devolve': ['accredit', 'assign', 'authorize', 'change hands', 'change ownership', 'charge', 'charter', 'commission', 'commit', 'consign', 'delegate', 'depute'],
    'devote': ['allocate', 'allot', 'apply', 'appoint', 'appropriate', 'assign', 'attempt', 'attend to business', 'beatify', 'bend', 'bestow', 'bless'],
    'devoted': ['christian', 'christianlike', 'christianly', 'abandoned', 'absorbed', 'absorbed in', 'acquiescent', 'active', 'adoring', 'affectionate', 'afire', 'altruistic'],
    'devotee': ['christian', 'god-fearing man', 'accepter', 'addict', 'adherent', 'admirer', 'aficionado', 'amateur', 'aspirant', 'aspirer', 'believer', 'booster'],
    'devotion': ['amor', 'christian love', 'eros', 'platonic love', 'abandon', 'adherence', 'adhesion', 'admiration', 'adoration', 'affection', 'agape', 'allegiance'],
    'devotions': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'mass', 'paternoster', 'aid prayer', 'appeal', 'beadroll', 'beads', 'bedtime prayer'],
    'devour': ['absorb', 'adore', 'and sinker', 'annihilate', 'appreciate', 'bask in', 'batten', 'be a sucker', 'be pleased with', 'be taken in', 'bite', 'bolt'],
    'devouring': ['a hog for', 'acquisitive', 'all-devouring', 'appetite', 'avaricious', 'avid', 'bottomless', 'cannibalism', 'carnivorism', 'carnivority', 'carnivorousness', 'chewing'],
    'devout': ['christian', 'christianlike', 'christianly', 'abandoned', 'active', 'adorant', 'adoring', 'afire', 'ardent', 'assured', 'believing', 'burning'],
    'dew': ['asperge', 'bedew', 'bespatter', 'besprinkle', 'dabble', 'damp', 'dampen', 'dash', 'dawn dew', 'dewdrops', 'douche', 'evening damp'],
    'dewy': ['boggy', 'budding', 'callow', 'damp', 'dampish', 'dank', 'ever-new', 'evergreen', 'fenny', 'firsthand', 'fledgling', 'fresh'],
    'dewy eyed': ['airy', 'autistic', 'dereistic', 'idealistic', 'impractical', 'in the clouds', 'otherworldly', 'poetic', 'quixotic', 'romancing', 'romantic', 'romanticized'],
    'dexedrine': ['benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine pill', 'methedrine', 'amphetamine', 'amphetamine sulfate', 'cocaine', 'coke', 'crystal', 'dextroamphetamine sulfate'],
    'dexter': ['astarboard', 'auspicious', 'benign', 'bright', 'clockwise', 'conservative', 'dextrad', 'dextral', 'dextrally', 'dextrocardial', 'dextrocerebral', 'dextrocular'],
    'dexterity': ['ability', 'acuity', 'acuteness', 'address', 'adeptness', 'adroitness', 'airmanship', 'aptitude', 'aptness', 'art', 'artfulness', 'artisanship'],
    'dexterous': ['daedalian', 'adept', 'adroit', 'agile', 'apt', 'artful', 'artistic', 'astute', 'authoritative', 'brainy', 'bravura', 'bright'],
    'dextral': ['clockwise', 'conservative', 'dexter', 'dextrocardial', 'dextrocerebral', 'dextrocular', 'dextrogyrate', 'dextrogyratory', 'dextropedal', 'dextrorotary', 'dextrorse', 'off'],
    'dextrous': ['daedalian', 'adept', 'adroit', 'apt', 'artistic', 'authoritative', 'bravura', 'brilliant', 'clean', 'clever', 'coordinated', 'crack'],
    'dharma': ['body-build', 'brand', 'cast', 'character', 'characteristic', 'characteristics', 'complexion', 'composition', 'constituents', 'constitution', 'crasis', 'diathesis'],
    'diabetic': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'cancerous', 'chlorotic', 'colicky', 'consumptive', 'dropsical', 'dyspeptic', 'edematous'],
    'diabolic': ['draconian', 'mephistophelian', 'tartarean', 'abominable', 'accursed', 'animal', 'anthropophagous', 'appalling', 'atrocious', 'awful', 'bad', 'barbaric'],
    'diabolical': ['draconian', 'mephistophelian', 'tartarean', 'animal', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bestial', 'bloodthirsty', 'bloody'],
    'diabolism': ['black mass', 'satanism', 'black magic', 'chthonian worship', 'demonism', 'demonography', 'demonolatry', 'demonology', 'demonomancy', 'demonomy', 'demonry', 'devil lore'],
    'diadem': ['anklet', 'annular muscle', 'annulus', 'areola', 'armlet', 'aureole', 'bangle', 'beads', 'bijou', 'bracelet', 'breastpin', 'brooch'],
    'diaeresis': ['alexandrine', 'accent', 'accentuation', 'amphibrach', 'amphimacer', 'anacrusis', 'analysis', 'anapest', 'anatomy', 'antispast', 'arsis', 'bacchius'],
    'diagnose': ['bandage', 'bathe', 'care for', 'construe', 'cure', 'define', 'describe', 'determinate', 'determine', 'distinguish', 'doctor', 'finger'],
    'diagnosis': ['pap test', 'action', 'anatomic diagnosis', 'award', 'biological diagnosis', 'biopsy', 'clinical diagnosis', 'condemnation', 'consideration', 'construction', 'cytodiagnosis', 'decision'],
    'diagnostic': ['characteristic', 'characterizing', 'connotative', 'constructional', 'constructive', 'contrastive', 'definitional', 'demonstrative', 'denominative', 'denotative', 'descriptive', 'designative'],
    'diagonal': ['across', 'air line', 'athwart', 'axis', 'band', 'bar', 'beeline', 'bend', 'bendwise', 'bevel', 'beveled', 'bias'],
    'diagram': ['alphabet', 'art', 'black and white', 'blueprint', 'brouillon', 'cartoon', 'catalog', 'catalogue raisonne', 'catch a likeness', 'chalk', 'character', 'charactering'],
    'dial': ['appraise', 'appreciate', 'assay', 'assess', 'buzz', 'calculate', 'calibrate', 'caliper', 'call', 'call up', 'check a parameter', 'compute'],
    'dialect': ['acadian', 'anglo-indian', 'brooklynese', 'cajun', 'canadian french', 'cockney', 'french canadian', 'gullah', 'midland', 'midland dialect', 'new england dialect', 'pennsylvania dutch'],
    'dialectic': ['aristotelian logic', 'boolean algebra', 'ramistic logic', 'airing', 'algebra of classes', 'algebra of relations', 'analysis', 'buzz session', 'canvassing', 'colloquium', 'conference', 'consideration'],
    'dialectical': ['a fortiori', 'a posteriori', 'a priori', 'analytic', 'argumental', 'argumentative', 'categorical', 'combative', 'conditional', 'contentious', 'controversial', 'deductive'],
    'dialectical materialism': ['bolshevism', 'castroism', 'communist information bureau', 'communist party', 'maoism', 'marxian socialism', 'marxism', 'marxism-leninism', 'stalinism', 'titoism', 'trotskyism', 'animalism'],
    'dialectics': ['aristotelian logic', 'boolean algebra', 'ramistic logic', 'algebra of classes', 'algebra of relations', 'dialectic', 'doctrine of inference', 'doctrine of terms', 'epistemological logic', 'experimental logic', 'formal logic', 'logic'],
    'dialogue': ['grand guignol', 'passion play', 'tom show', 'airing', 'analysis', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'bull session', 'burlesque show'],
    'diameter': ['air line', 'amplitude', 'area', 'axis', 'beeline', 'bigness', 'bisector', 'body', 'bore', 'boundary', 'breadth', 'bulk'],
    'diamond': ['acceptable person', 'ace', 'adamant', 'agate', 'alexandrite', 'amethyst', 'aquamarine', 'archery ground', 'athletic field', 'badminton court', 'baseball field', 'basketball court'],
    'diana': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ashtoreth', 'astarte', 'ate', 'athena', 'bacchus'],
    'diapason': ['english horn', 'accord', 'accordance', 'air', 'attune', 'attunement', 'bassoon', 'baton', 'block flute', 'bombard', 'bourdon', 'carry'],
    'diaphanous': ['airy', 'attenuate', 'attenuated', 'boyish', 'clear', 'clear as crystal', 'cloudless', 'crystal', 'crystal-clear', 'crystalline', 'delicate', 'diaphane'],
    'diaphony': ['atonalism', 'atonality', 'cacophony', 'clinker', 'discord', 'discordance', 'discordancy', 'disharmony', 'dissonance', 'dissonancy', 'dissonant chord', 'flatness'],
    'diaphragm': ['iud', 'abdomen', 'abomasum', 'acoustical network', 'bag', 'barrier', 'bay window', 'beerbelly', 'belly', 'birth control device', 'brattice', 'breadbasket'],
    'diarist': ['boswell', 'advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'autobiographer', 'autobiographist', 'belletrist', 'bibliographer', 'biographer', 'calendar maker'],
    'diarrhea': ['bm', 'abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache'],
    'diary': ['clio', 'domesday book', 'muse of history', 'account book', 'address book', 'adventures', 'adversaria', 'album', 'annals', 'annual', 'appointment calendar', 'appointment schedule'],
    'diastole': ['arsis', 'beat', 'bloat', 'bloatedness', 'bloating', 'blowing up', 'bout', 'circle', 'circuit', 'course', 'cycle', 'dilatation'],
    'diathesis': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory', 'a thing for'],
    'diatribe': ['abuse', 'address', 'after-dinner speech', 'allocution', 'assailing', 'assault', 'attack', 'berating', 'bitter words', 'blackening', 'chalk talk', 'contumely'],
    'dibble': ['angle', 'bait the hook', 'bed', 'bob', 'broadcast', 'clam', 'dap', 'dib', 'disseminate', 'drill', 'drive', 'fish'],
    'dice': ['bird cage', 'bones', 'cashier', 'cast', 'crap game', 'crap shooting', 'craps', 'crooked dice', 'cube', 'cubes', 'die', 'form fours'],
    'diced': ['cube-shaped', 'cubed', 'cubic', 'cubiform', 'cuboid', 'foursquare', 'oblong', 'orthogonal', 'quadrangular', 'quadrate', 'quadriform', 'quadrilateral'],
    'dicey': ['accidental', 'adventitious', 'adventurous', 'agnostic', 'aleatory', 'ambiguous', 'capricious', 'casual', 'causeless', 'chance', 'chancy', 'changeable'],
    'dichotomy': ['janus', 'abscission', 'ambiguity', 'ambivalence', 'amputation', 'bifidity', 'biformity', 'bifurcation', 'bipartition', 'bisection', 'branching', 'butchering'],
    'dichromatic': ['bicolor', 'bicolored', 'chromatic', 'cold', 'colorful', 'colorific', 'coloring', 'colory', 'cool', 'crazy', 'daedal', 'divers-colored'],
    'dick': ['dogberry', 'john law', 'sherlock', 'beagle', 'bluecoat', 'bobby', 'bull', 'cop', 'copper', 'eye', 'flatfoot', 'flattie'],
    'dicker': ['bargain', 'barter', 'beat down', 'bid', 'bid for', 'chaffer', 'cheapen', 'deal', 'drive a bargain', 'haggle', 'higgle', 'huckster'],
    'dicotyledon': ['angiospermae', 'cycadales', 'ginkgoales', 'gnetales', 'monocotyledones', 'pinales', 'amphibian', 'angiosperm', 'angiosperms', 'annual', 'aquatic plant', 'biennial'],
    'dictate': ['a priori truth', 'act', 'adage', 'ana', 'analects', 'aphorism', 'apothegm', 'appoint', 'authorize', 'axiom', 'behest', 'bestride'],
    'dictator': ['simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'authoritarian', 'authoritative', 'autocrat', 'caesar', 'commissar', 'czar'],
    'dictatorial': ['absolute', 'absolutist', 'absolutistic', 'all-powerful', 'arbitrary', 'aristocratic', 'arrogant', 'authoritarian', 'authoritative', 'autocratic', 'autonomous', 'bossy'],
    'dictatorship': ['caesarism', 'stalinism', 'absolute monarchy', 'absolutism', 'aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'autarchy', 'authoritarianism', 'autocracy'],
    'diction': ['articulation', 'delivery', 'elocution', 'enunciation', 'expression', 'expressiveness', 'inflection', 'intonation', 'language', 'oratory', 'parlance', 'phrase'],
    'dictionary': ['biographical dictionary', 'cant', 'chemical dictionary', 'desk dictionary', 'dialect dictionary', 'dictionary of quotations', 'electronics dictionary', 'etymological dictionary', 'foreign-language dictionary', 'gazetteer', 'general dictionary', 'geological dictionary'],
    'dictum': ['parthian shot', 'a priori truth', 'action', 'adage', 'address', 'affirmance', 'affirmation', 'allegation', 'ana', 'analects', 'announcement', 'annunciation'],
    'didactic': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'admonitory', 'advisory', 'authoritative', 'autodidactic'],
    'didactics': ['catechization', 'coaching', 'direction', 'edification', 'education', 'enlightenment', 'guidance', 'illumination', 'information', 'instruction', 'pedagogics', 'pedagogy'],
    'diddle': ['ball', 'bamboozle', 'be intimate', 'beat', 'beguile', 'beguile of', 'beguile the time', 'betray', 'bilk', 'bluff', 'bunco', 'burn'],
    'dido': ['antic', 'bauble', 'bibelot', 'caper', 'curio', 'frolic', 'gewgaw', 'gimcrack', 'lark', 'monkeyshine', 'shenanigan', 'shines'],
    'die': ['baluster', 'balustrade', 'banister', 'base', 'be all over', 'be annihilated', 'be consumed', 'be destroyed', 'be done for', 'be gone', 'be lost', 'be no more'],
    'die away': ['abate', 'ablate', 'bate', 'be all over', 'be annihilated', 'be consumed', 'be destroyed', 'be eaten away', 'be gone', 'be no more', 'be wiped out', 'become extinct'],
    'die down': ['abate', 'bate', 'calm', 'calm down', 'cease', 'disappear', 'dwindle', 'ease off', 'ebb', 'fall', 'halt', 'let up'],
    'die hard': ['backward', 'balk', 'be determined', 'be in earnest', 'be resolved', 'buckle down', 'buckle to', 'conservative', 'cross the rubicon', 'die fighting', 'die game', 'die in harness'],
    'die out': ['be annihilated', 'be consumed', 'be destroyed', 'be gone', 'be no more', 'be wiped out', 'become extinct', 'burn out', 'cease', 'cease to be', 'cease to exist', 'dematerialize'],
    'diehard': ['bircher', 'bourbon', 'tory', 'ass', 'bigot', 'bitter-ender', 'brawler', 'bullethead', 'conservationist', 'conservatist', 'conservative', 'defendant'],
    'dielectric': ['conductance', 'conduction', 'conductivity', 'conductor', 'electric conduction', 'gas conduction', 'insulator', 'ionic conduction', 'liquid conduction', 'metallic conduction', 'mho', 'nonconducting'],
    'diet': ['british cabinet', 'sanhedrin', 'us cabinet', 'abstain', 'acid-ash diet', 'advisory body', 'aliment', 'allergy diet', 'assemblee', 'assembly', 'assignation', 'association'],
    'dietetic': ['cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietary', 'dietic', 'dining', 'eating', 'feeding', 'flesh-eating', 'fruitarian', 'gastronomic'],
    'dietetics': ['acid-ash diet', 'allergy diet', 'bland diet', 'calorie chart', 'calorie counter', 'diabetic diet', 'diet', 'diet book', 'dietary', 'dieting', 'dietotherapy', 'enzymology'],
    'dieting': ['acid-ash diet', 'allergy diet', 'appetite', 'bland diet', 'calorie chart', 'calorie counter', 'cannibalism', 'carnivorism', 'carnivority', 'carnivorousness', 'chewing', 'consumption'],
    'differ': ['agree to differ', 'agree to disagree', 'altercate', 'argue', 'be at cross-purposes', 'be at variance', 'be distinct', 'be distinguished', 'be in dissent', 'bear no resemblance', 'beg to differ', 'bicker'],
    'difference': ['aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'about-face', 'accommodation', 'account', 'achievement', 'adaptation', 'adjustment', 'aggregate'],
    'different': ['aberrant', 'abnormal', 'absolute', 'abundant', 'amorphous', 'anomalistic', 'anomalous', 'another', 'assorted', 'at odds', 'at variance', 'bizarre'],
    'differential': ['hydromatic', 'accurate', 'algorismic', 'algorithmic', 'aliquot', 'appreciative', 'aroma', 'attribute', 'automatic transmission', 'badge', 'brand', 'cachet'],
    'differentiate': ['adapt', 'adjust', 'alter', 'analyze', 'anatomize', 'argue', 'atomize', 'be characteristic', 'be indicative of', 'be significant of', 'be symptomatic of', 'bespeak'],
    'differentiation': ['addition', 'alteration', 'analysis', 'anatomization', 'approximation', 'atomization', 'capriciousness', 'change', 'changeability', 'changeableness', 'characterization', 'choppiness'],
    'differing': ['alienated', 'antagonistic', 'antiestablishment', 'antipathetic', 'assorted', 'at cross-purposes', 'at loggerheads', 'at odds', 'at odds with', 'at variance', 'at variance with', 'at war'],
    'difficult': ['herculean', 'abstruse', 'adverse', 'antagonistic', 'arduous', 'awkward', 'baffling', 'beyond one', 'bloody-minded', 'brutal', 'burdensome', 'cantankerous'],
    'difficulties': ['adverse circumstances', 'adversity', 'affliction', 'aggravation', 'annoyance', 'blight', 'broken fortune', 'bummer', 'care', 'cross', 'curse', 'difficulty'],
    'difficulty': ['gordian knot', 'abstruseness', 'adverse circumstances', 'adversity', 'affliction', 'aggravation', 'agreement to disagree', 'altercation', 'annoyance', 'arduousness', 'asperity', 'bad news'],
    'diffidence': ['pyrrhonism', 'afraidness', 'apprehension', 'bashfulness', 'boggle', 'boggling', 'caution', 'cautiousness', 'compunction', 'demur', 'demurral', 'distrust'],
    'diffident': ['bashful', 'boggling', 'cautious', 'cowardly', 'coy', 'demure', 'demurring', 'deprecative', 'deprecatory', 'faltering', 'fearful', 'fearing'],
    'diffraction': ['amplitude', 'antinode', 'attenuation', 'broadcast', 'broadcasting', 'circumfusion', 'crest', 'de broglie wave', 'deflection', 'deflexure', 'diffusion', 'dilution'],
    'diffuse': ['abounding', 'abundant', 'affluent', 'all-sufficing', 'ambagious', 'ample', 'aplenty', 'assign', 'atomize', 'bend', 'bespread', 'bestrew'],
    'dig': ['parthian shot', 'abide', 'absorb', 'abysm', 'abyss', 'accept', 'appreciate', 'apprehend', 'assault', 'assimilate', 'back answer', 'backset'],
    'dig in': ['arm', 'armor', 'armor-plate', 'bank', 'barricade', 'battle', 'blockade', 'bulwark', 'castellate', 'crenellate', 'embattle', 'entrench'],
    'dig up': ['accumulate', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'assemble', 'avulse', 'batch', 'be curious', 'bring to light', 'bring together', 'bulk'],
    'digest': ['code napoleon', 'napoleonic code', 'abbreviate', 'abbreviation', 'abbreviature', 'abide', 'ablate', 'abrege', 'abridge', 'abridgement', 'abridgment', 'absorb'],
    'digestion': ['ablation', 'absorbency', 'absorbent', 'absorption', 'adsorbent', 'adsorption', 'assimilation', 'attrition', 'bile', 'blending', 'blotter', 'blotting'],
    'diggings': ['abysm', 'abyss', 'accommodations', 'bank', 'berth', 'chasm', 'coal mine', 'colliery', 'dig', 'digs', 'excavation', 'gold mine'],
    'digit': ['annulary', 'arch', 'binary digit', 'bit', 'character', 'cipher', 'clubfoot', 'dactylion', 'dog', 'extremity', 'fetlock', 'figure'],
    'digital': ['algorismic', 'algorithmic', 'aliquot', 'cardinal', 'clawed', 'decimal', 'dentate', 'differential', 'digitate', 'digitated', 'even', 'exponential'],
    'dignified': ['aristocratic', 'august', 'courtly', 'distingue', 'distinguished', 'elegant', 'elevated', 'exalted', 'formal', 'grand', 'grave', 'honorable'],
    'dignify': ['adorn', 'aggrandize', 'bestow honor upon', 'better', 'celebrate', 'confer distinction on', 'conventionalize', 'distinguish', 'elevate', 'enhance', 'ennoble', 'erect'],
    'dignitary': ['establishment', 'vip', 'baron', 'big cheese', 'big gun', 'big man', 'big name', 'big noise', 'big shot', 'big wheel', 'bigwig', 'brass'],
    'dignity': ['atticism', 'establishment', 'vip', 'address', 'appropriateness', 'augustness', 'baron', 'big gun', 'big man', 'big name', 'bigwig', 'brass'],
    'digress': ['bear off', 'bend', 'branch off', 'bypass', 'change the bearing', 'curve', 'depart', 'depart from', 'detour', 'deviate', 'divagate', 'divaricate'],
    'digression': ['aberrancy', 'aberration', 'ambages', 'apostrophe', 'aside', 'bend', 'bias', 'branching off', 'bypass', 'bypath', 'byway', 'circling'],
    'digressive': ['o-shaped', 'aberrant', 'aberrative', 'aimless', 'ambagious', 'backhand', 'backhanded', 'by the way', 'circuitous', 'circular', 'deflectional', 'departing'],
    'dike': ['autobahn', 'us highway', 'abatis', 'abysm', 'abyss', 'advanced work', 'alley', 'alleyway', 'aqueduct', 'arch dam', 'arroyo', 'arterial'],
    'dilapidated': ['ablative', 'battered', 'beat-up', 'beaten up', 'bedraggled', 'biodegradable', 'blowzy', 'broken-down', 'careless', 'chintzy', 'corrosive', 'crumbling'],
    'dilapidation': ['ablation', 'atomization', 'bankruptcy', 'biodegradability', 'biodegradation', 'breakage', 'breakdown', 'breakup', 'collapse', 'corrosion', 'corruption', 'crack-up'],
    'dilate': ['add to', 'aggrandize', 'amplify', 'augment', 'bag', 'balloon', 'belly', 'belly out', 'bilge', 'billow', 'bloat', 'blow up'],
    'dilation': ['aggrandizement', 'amplification', 'ballyhoo', 'big talk', 'bloat', 'bloatedness', 'bloating', 'blowing up', 'boil', 'bump', 'bunion', 'burlesque'],
    'dilatory': ['micawberish', 'apathetic', 'backward', 'balking', 'balky', 'bone-lazy', 'cadging', 'dallying', 'dawdling', 'delaying', 'deliberate', 'dillydallying'],
    'dilemma': ['aristotelian sorites', 'goclenian sorites', 'gordian knot', 'scylla and charybdis', 'baffle', 'bafflement', 'bewilderment', 'bind', 'bother', 'box', 'categorical syllogism', 'choice of hercules'],
    'dilettante': ['sunday painter', 'abecedarian', 'admirer', 'aesthete', 'aficionado', 'amateur', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'authority', 'bon vivant', 'booster'],
    'diligence': ['advertence', 'advertency', 'alertness', 'application', 'ardor', 'assiduity', 'assiduousness', 'attention', 'attention span', 'attentiveness', 'awareness', 'bookishness'],
    'diligent': ['academic', 'advertent', 'agog', 'alert', 'all ears', 'all eyes', 'ardent', 'assiduous', 'attentive', 'aware', 'bookish', 'careful'],
    'diligently': ['ardently', 'assiduously', 'carefully', 'cautiously', 'circumspectly', 'considerately', 'devotedly', 'doggedly', 'energetically', 'faithfully', 'fervently', 'heedfully'],
    'dilly': ['absurd', 'ace', 'balmy', 'beaut', 'corker', 'crackerjack', 'crazy', 'daisy', 'dally', 'dandy', 'darb', 'dillydally'],
    'dillydally': ['abide', 'await', 'bide', 'bide the issue', 'dally', 'dawdle', 'delay', 'diddle', 'dilly', 'doodle', 'drag', 'falter'],
    'dilute': ['abate', 'adulterate', 'adulterated', 'alleviate', 'alter', 'attenuate', 'baptize', 'bastardize', 'bate', 'blow off', 'cast forth', 'clear away'],
    'diluted': ['adulterated', 'airy', 'attenuate', 'attenuated', 'boyish', 'cut', 'dead', 'delicate', 'diaphanous', 'dilute', 'ethereal', 'fade'],
    'diluvium': ['alluvion', 'alluvium', 'ash', 'cinder', 'clinker', 'debris', 'deposit', 'deposition', 'deposits', 'detritus', 'draff', 'dregs'],
    'dim': ['achromatic', 'achromatize', 'achromic', 'amorphous', 'anemic', 'ashen', 'ashy', 'banausic', 'bandage', 'barely audible', 'becloud', 'bedarken'],
    'dim sighted': ['ableptical', 'amaurotic', 'benighted', 'bereft of light', 'blear-eyed', 'bleary-eyed', 'blind', 'blindfold', 'blindfolded', 'color-blind', 'dark', 'dim'],
    'dim view': ['ban', 'blackball', 'blackballing', 'complaint', 'disagreement', 'disappointment', 'disapprobation', 'disapproval', 'discontent', 'discontentedness', 'discontentment', 'disenchantment'],
    'dim witted': ['blunt', 'blunt-witted', 'dim', 'dopey', 'dull', 'dull of mind', 'dull-headed', 'dull-pated', 'dull-witted', 'fat-witted', 'gross-headed', 'heavy'],
    'dime': ['c-note', 'g-note', 'buck', 'cartwheel', 'cent', 'century', 'copper', 'dollar', 'dollar bill', 'fifty cents', 'fin', 'fish'],
    'dime store': ['boutique', 'chain store', 'cheap as dirt', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dirt cheap', 'discount house', 'discount store'],
    'dimension': ['acreage', 'ambit', 'amplitude', 'area', 'bigness', 'body', 'breadth', 'bulk', 'caliber', 'circle', 'compass', 'confines'],
    'diminish': ['abase', 'abash', 'abate', 'abbreviate', 'ablate', 'abrade', 'abridge', 'abstract', 'abuse', 'adjust to', 'allay', 'alleviate'],
    'diminishing': ['abating', 'allaying', 'alleviating', 'assuaging', 'blunting', 'chastening', 'contractive', 'cushioning', 'dampening', 'damping', 'deadening', 'declining'],
    'diminution': ['abatement', 'abridgment', 'allayment', 'alleviation', 'analgesia', 'anesthesia', 'anesthetizing', 'appeasement', 'assuagement', 'attenuation', 'attrition', 'blunting'],
    'diminutive': ['lilliputian', 'affectionate name', 'baby', 'baby-sized', 'bantam', 'banty', 'button', 'byname', 'chit', 'cognomen', 'cognominal', 'compact'],
    'dimness': ['adiaphanousness', 'anemia', 'ashiness', 'asininity', 'bad light', 'bleariness', 'blockishness', 'bloodlessness', 'blur', 'blurriness', 'boobishness', 'boorishness'],
    'dimple': ['alveolation', 'alveolus', 'cockle', 'dent', 'depress', 'dint', 'engrave', 'fret', 'furrow', 'gouge', 'honeycomb', 'impress'],
    'dimwit': ['boeotian', 'block', 'clod', 'cluck', 'dolt', 'donkey', 'dope', 'dullard', 'dumb', 'dumb cluck', 'dumbbell', 'dummy'],
    'din': ['bedlam let loose', 'awake the dead', 'babel', 'beat', 'bedlam', 'blast', 'blast the ear', 'blatancy', 'bobbery', 'boisterousness', 'boom', 'brawl'],
    'dine': ['banquet', 'board', 'bread', 'break bread', 'break bread with', 'breakfast', 'cook out', 'dine out', 'dinner', 'eat', 'eat out', 'feast'],
    'diner': ['brillat-savarin', 'lucullus', 'pullman', 'pullman car', 'tv dinner', 'alfresco meal', 'automat', 'baggage car', 'barbecue', 'beanery', 'bistro', 'board-and-roomer'],
    'ding': ['bang', 'bash', 'beat', 'belt', 'best', 'better', 'biff', 'catch', 'change ringing', 'chime', 'chiming', 'chink'],
    'dingdong': ['alliterating', 'alliteration', 'alliterative', 'asshole', 'assiduously', 'assonance', 'assonant', 'belabored', 'boob', 'booby', 'change ringing', 'chanting'],
    'dingy': ['quaker-colored', 'achromatic', 'achromic', 'acier', 'anemic', 'ashen', 'ashy', 'besmirched', 'bled white', 'bloodless', 'blotchy', 'broken-down'],
    'dining': ['appetite', 'cannibal', 'cannibalism', 'cannibalistic', 'carnivorism', 'carnivority', 'carnivorous', 'carnivorousness', 'chewing', 'commensal', 'consumption', 'cropping'],
    'dining room': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop'],
    'dinky': ['anal', 'back-burner', 'cramped', 'dispensable', 'exiguous', 'half-pint', 'immaterial', 'inappreciable', 'inconsequential', 'inconsiderable', 'inessential', 'inferior'],
    'dinner': ['kaffeeklatsch', 'tv dinner', 'alfresco meal', 'ball', 'banquet', 'barbecue', 'blowout', 'breakfast', 'brunch', 'buffet supper', 'clambake', 'cocktail party'],
    'dinnerware': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'durable goods', 'durables', 'earthenware', 'enamelware', 'fixtures', 'flatware', 'glassware'],
    'dinosaur': ['alligator', 'ammonite', 'ankylosaur', 'archaeohippus', 'archaeotherium', 'archelon', 'arthrodiran', 'aurochs', 'bothriolepis', 'brachiosaur', 'brontops', 'brontothere'],
    'dint': ['alveolation', 'alveolus', 'amperage', 'armipotence', 'authority', 'bang', 'bash', 'bat', 'beating', 'beef', 'belt', 'biff'],
    'diocese': ['kreis', 'archbishopric', 'archdiocese', 'arrondissement', 'bailiwick', 'bishopric', 'borough', 'canton', 'city', 'commune', 'conference', 'congressional district'],
    'dionysus': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ashtoreth', 'astarte', 'ate', 'athena', 'baal'],
    'diorama': ['airscape', 'cityscape', 'cloudscape', 'cosmorama', 'cyclorama', 'display', 'exhibit', 'exhibition', 'exposition', 'exterior', 'farmscape', 'georama'],
    'dip': ['acid bath', 'alveolation', 'alveolus', 'antrum', 'apply paint', 'armpit', 'ascend', 'asperge', 'attrition', 'bail', 'bank', 'baptism'],
    'dip into': ['browse', 'examine cursorily', 'flip', 'give the once-over', 'glance at', 'glance over', 'glance through', 'page through', 'pass over lightly', 'run over', 'run through', 'scan'],
    'diphtheria': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'diphthong': ['allophone', 'alveolar', 'apico-alveolar', 'apico-dental', 'articulation', 'aspiration', 'assimilation', 'bilabial', 'cacuminal', 'cerebral', 'check', 'consonant'],
    'diploma': ['affidavit', 'attestation', 'authority', 'authorization', 'bill of health', 'brevet', 'certificate', 'certificate of proficiency', 'certification', 'charter', 'concession', 'credential'],
    'diplomacy': ['eisenhower doctrine', 'machiavellianism', 'machiavellism', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'ability', 'address', 'adeptness', 'adroitness', 'airmanship', 'appeasement'],
    'diplomat': ['admirable crichton', 'machiavel', 'machiavellian', 'machiavellianist', 'adept', 'ambassador', 'ambassadress', 'apostolic delegate', 'artisan', 'artist', 'attache', 'authority'],
    'diplomatic': ['daedalian', 'machiavellian', 'machiavellic', 'acute', 'adept', 'adroit', 'ambassadorial', 'apt', 'arch', 'artful', 'artistic', 'astute'],
    'dipping': ['baptism', 'burial', 'declined', 'declining', 'declivate', 'declivitous', 'declivous', 'descending', 'dip', 'dousing', 'downgrade', 'downhill'],
    'dipsomania': ['a habit', 'abulia', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'addiction', 'alcoholic addiction', 'alcoholic psychosis', 'alcoholism', 'arteriosclerotic psychosis', 'barbiturate addiction', 'barbiturism'],
    'dipsomaniac': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'alcoholic addict', 'bacchanal', 'bacchanalian', 'bibber', 'big drunk', 'boozer', 'carouser', 'chain smoker'],
    'diptych': ['domesday book', 'abstract', 'abstraction', 'account book', 'address book', 'adversaria', 'album', 'altarpiece', 'annual', 'appointment calendar', 'appointment schedule', 'blankbook'],
    'dire': ['abominable', 'apocalyptic', 'appalling', 'arrant', 'astounding', 'atrocious', 'awe-inspiring', 'awesome', 'awful', 'bad', 'badly off', 'baleful'],
    'direct': ['attic', 'ciceronian', 'spartan', 'address', 'address to', 'administer', 'administrate', 'advise', 'advocate', 'aim', 'aim at', 'allude to'],
    'direct current': ['ac', 'dc', 'absorption current', 'active current', 'alternating current', 'conduction current', 'convection current', 'cycle', 'delta current', 'displacement current', 'eddy current', 'electric current'],
    'direct line': ['affiliation', 'air line', 'apparentation', 'axis', 'beeline', 'birth', 'blood', 'bloodline', 'branch', 'breed', 'chord', 'common ancestry'],
    'directing': ['administrative', 'bureaucratic', 'chief', 'commanding', 'controlling', 'directive', 'directorial', 'directory', 'executive', 'governing', 'guiding', 'head'],
    'direction': ['zeitgeist', 'action', 'actuation', 'address', 'administering', 'administration', 'admonition', 'advice', 'advising', 'advocacy', 'agency', 'angle'],
    'direction finder': ['bourdon tube', 'gyropilot', 'gyrosin compass', 'hfdf', 'mach meter', 'rdf', 'absolute altimeter', 'accelerometer', 'aerial reconnaissance camera', 'aerometer', 'aeroscope', 'air log'],
    'directive': ['actuating', 'admonitory', 'advisory', 'aimable', 'aimed', 'animating', 'causal', 'causative', 'cautionary', 'chief', 'commanding', 'communication'],
    'directly': ['pdq', 'absolutely', 'after a while', 'all joking aside', 'anon', 'apace', 'at once', 'before long', 'betimes', 'bluffly', 'bluntly', 'broadly'],
    'directness': ['atticism', 'appropriateness', 'artlessness', 'austerity', 'baldness', 'bareness', 'bluffness', 'bluntness', 'broadness', 'brusqueness', 'candidness', 'candor'],
    'director': ['kapellmeister', 'mc', 'administrator', 'auteur', 'ballyhoo man', 'band leader', 'band major', 'bandmaster', 'banker', 'barker', 'baron', 'big boss'],
    'directorate': ['board', 'board of directors', 'board of regents', 'board of trustees', 'bureaucracy', 'cabinet', 'cadre', 'captainship', 'chairmanship', 'convenership', 'council', 'custody'],
    'directorship': ['acme', 'aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'authority', 'authorization', 'be-all and end-all', 'bishopric', 'blue ribbon', 'captainship'],
    'directory': ['almanach de gotha', 'baedeker', 'british cabinet', 'red book', 'royal kalendar', 'sanhedrin', 'social register', 'us cabinet', 'yellow pages', 'account', 'acquaintance', 'advisory body'],
    'dirge': ['brautlied', 'christmas carol', 'dry mass', 'english sonnet', 'eucharistic rites', 'horatian ode', 'italian sonnet', 'kunstlied', 'lady mass', 'liebeslied', 'low mass', 'mass'],
    'dirt': ['rabelaisianism', 'x-rated movie', 'acres', 'alluvion', 'alluvium', 'arable land', 'bawdiness', 'bawdry', 'blue movie', 'character assassination', 'clay', 'clod'],
    'dirt free': ['bleached', 'bright', 'clean', 'cleanly', 'dainty', 'fair', 'fastidious', 'fresh', 'immaculate', 'kosher', 'nonpolluted', 'of cleanly habits'],
    'dirty': ['fescennine', 'rabelaisian', 'abject', 'abominable', 'abusive', 'angry', 'animal', 'aphrodisiomaniacal', 'arrant', 'atrocious', 'attaint', 'bad'],
    'dirty language': ['bad language', 'billingsgate', 'blue language', 'colorful language', 'cursing', 'cussing', 'dirty talk', 'dysphemism', 'evil speaking', 'filth', 'filthy language', 'foul language'],
    'dirty trick': ['artful dodge', 'artifice', 'bag of tricks', 'blind', 'bluff', 'bosey', 'catch', 'chicanery', 'chouse', 'curve', 'curve-ball', 'design'],
    'dirty work': ['dirty pool', 'dirty trick', 'donkeywork', 'double-dealing', 'drudgery', 'duplicity', 'employment', 'fag', 'falseheartedness', 'fatigue', 'foul play', 'grind'],
    'dis': ['agdistis', 'aides', 'aidoneus', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus'],
    'disability': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'cardiovascular disease'],
    'disable': ['afflict', 'attenuate', 'batter', 'blunt', 'bugger', 'castrate', 'cripple', 'de-energize', 'debilitate', 'derange', 'devitalize', 'disarm'],
    'disabled': ['ausgespielt', 'bad', 'burned-out', 'castrated', 'crippled', 'damaged', 'devitalized', 'disarmed', 'disqualified', 'drained', 'effete', 'emasculated'],
    'disabuse': ['amend', 'awaken', 'break the spell', 'burst the bubble', 'conflict', 'contention', 'correct', 'debunk', 'difference', 'disaccord', 'disappoint', 'disenchant'],
    'disaccord': ['agree to disagree', 'agreement to disagree', 'alienation', 'antagonism', 'antipathy', 'apostasy', 'argumentation', 'bad blood', 'be at cross-purposes', 'be at variance', 'be distinct', 'be distinguished'],
    'disaccordant': ['adversary', 'adversative', 'adverse', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'assorted', 'at cross-purposes', 'at loggerheads', 'at odds'],
    'disaccustomed': ['a stranger to', 'ignorant', 'inexperienced', 'new to', 'rusty', 'unaccustomed', 'unacquainted with', 'unconversant with', 'unfamiliar with', 'unhabituated', 'unhardened', 'uninured'],
    'disadvantage': ['abuse', 'ado', 'afflict', 'aggrieve', 'annoyance', 'anxiety', 'bar', 'befoul', 'besetment', 'bewitch', 'blight', 'blocking'],
    'disadvantaged': ['beggared', 'beggarly', 'bereaved', 'bereft', 'chronic poor', 'chronic poverty area', 'common', 'demeaning', 'depressed', 'depressed class', 'depressed population', 'deprived'],
    'disadvantageous': ['baleful', 'baneful', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'counterproductive', 'damaging', 'deadly', 'deleterious', 'depreciative', 'depreciatory'],
    'disaffected': ['alienated', 'allergic', 'averse', 'derelict', 'disenchanted', 'disinclined', 'disloyal', 'displeased', 'disunited', 'divided', 'estranged', 'faithless'],
    'disaffection': ['punic faith', 'alienation', 'bad faith', 'barratry', 'breach', 'breach of faith', 'breach of friendship', 'breach of promise', 'breach of trust', 'break', 'cleavage', 'cleft'],
    'disaffinity': ['discordia', 'eris', 'animosity', 'antigravity', 'bad feeling', 'centrifugal force', 'chill', 'chilliness', 'clash', 'clashing', 'coldness', 'conflict'],
    'disaffirm': ['abjure', 'assert the contrary', 'belie', 'contest', 'contradict', 'contravene', 'controvert', 'counter', 'cross', 'deny', 'disallow', 'disavow'],
    'disaffirmation': ['abjuration', 'abjurement', 'abrogation', 'absolute contradiction', 'annulment', 'contradiction', 'contrary assertion', 'contravention', 'controversion', 'countering', 'crossing', 'denial'],
    'disagree': ['agree to differ', 'agree to disagree', 'argue', 'be at cross-purposes', 'be at variance', 'be distinct', 'be distinguished', 'be in dissent', 'be unmoved', 'be unwilling', 'beg off', 'beg to differ'],
    'disagreeable': ['abominable', 'abrupt', 'annoying', 'antagonistic', 'antipathetic', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'bad-tempered', 'bearish'],
    'disagreeableness': ['disagreeability', 'displeasingness', 'displeasure', 'distastefulness', 'inhospitableness', 'inhospitality', 'ugliness', 'unamiability', 'unappealingness', 'unattractiveness', 'unbenignity', 'unbenignness'],
    'disagreeing': ['alienated', 'antagonistic', 'antiestablishment', 'antipathetic', 'assorted', 'at cross-purposes', 'at loggerheads', 'at odds', 'at odds with', 'at variance', 'at variance with', 'at war'],
    'disagreement': ['abnegation', 'agreement to disagree', 'alienation', 'altercation', 'antagonism', 'antipathy', 'antithesis', 'apostasy', 'argument', 'averseness', 'aversion', 'backwardness'],
    'disallow': ['abjure', 'assert the contrary', 'ban', 'bar', 'be unmoved', 'be unwilling', 'beg off', 'belie', 'blackball', 'categorically reject', 'contest', 'contradict'],
    'disappear': ['abandon', 'abscond', 'be all over', 'be annihilated', 'be consumed', 'be destroyed', 'be done for', 'be gone', 'be incognito', 'be no more', 'be past', 'be unseen'],
    'disappearance': ['awol', 'french leave', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'absquatulation', 'bolt', 'concealment', 'cut'],
    'disappoint': ['awaken', 'baffle', 'balk', 'beat', 'bilk', 'break the spell', 'burst the bubble', 'cast down', 'circumvent', 'correct', 'cross', 'dash'],
    'disappointed': ['against', 'baffled', 'balked', 'beefing', 'bellyaching', 'betrayed', 'bilked', 'bitching', 'blase', 'blasted', 'blighted', 'chapfallen'],
    'disappointing': ['disconcerting', 'discouraging', 'disheartening', 'displeasing', 'dissatisfactory', 'falling short', 'inadequate', 'incommensurate', 'inferior', 'insufficient', 'not good enough', 'pathetic'],
    'disappointment': ['faustianism', 'awakening', 'ban', 'blackball', 'blackballing', 'blighted hope', 'blow', 'calamity', 'chagrin', 'cold comfort', 'complaint', 'dashed hopes'],
    'disapproval': ['abjuration', 'abjurement', 'aggravation', 'agreement to disagree', 'alienation', 'annoyance', 'apostasy', 'belittling', 'censure', 'chucking', 'chucking out', 'comedown'],
    'disapprove': ['abjure', 'attaint', 'ban', 'belittle', 'bespatter', 'blackball', 'blacken', 'blame', 'blot', 'blow upon', 'brand', 'brush aside'],
    'disapprove of': ['abhor', 'ban', 'be hostile to', 'belittle', 'blackball', 'bring down', 'bring into discredit', 'bring low', 'categorically reject', 'cry down', 'debase', 'decry'],
    'disapproved': ['contemned', 'declined', 'declined with thanks', 'denied', 'despised', 'discarded', 'discounted', 'disdained', 'dismissed', 'disowned', 'excepted', 'excluded'],
    'disarm': ['allure', 'appease', 'attract', 'bewitch', 'captivate', 'charm', 'conciliate', 'cripple', 'deactivate', 'decommission', 'deflate', 'demilitarize'],
    'disarming': ['bland', 'buttery', 'deferential', 'fair-spoken', 'fine-spoken', 'fulsome', 'glib', 'honey-mouthed', 'honey-tongued', 'ingratiating', 'insinuating', 'insinuative'],
    'disarrange': ['agitate', 'beat', 'beat up', 'break', 'break off', 'churn', 'churn up', 'clutter', 'confuse', 'convulse', 'derange', 'disarray'],
    'disarranged': ['amiss', 'askew', 'awry', 'cockeyed', 'confused', 'convulsed', 'deranged', 'discomfited', 'discomposed', 'disconcerted', 'disjointed', 'dislocated'],
    'disarrangement': ['doppler effect', 'deracination', 'derangement', 'disarray', 'disarticulation', 'discomfiture', 'discomposure', 'disconcertedness', 'discontinuity', 'disharmony', 'dishevelment', 'disintegration'],
    'disarray': ['ataxia', 'chaos', 'clutter', 'derange', 'derangement', 'disarrange', 'disarrangement', 'disarticulation', 'discomfiture', 'discompose', 'discomposure', 'disconcertedness'],
    'disarticulate': ['abrupt', 'alienate', 'cast off', 'cast out', 'cut adrift', 'cut off', 'cut out', 'delete', 'depart', 'disarrange', 'disconnect', 'disengage'],
    'disarticulated': ['aimless', 'alienated', 'amorphous', 'capricious', 'casual', 'desultory', 'detached', 'disconnected', 'discontinuous', 'disengaged', 'disjoined', 'disjoint'],
    'disassemble': ['atomize', 'break to pieces', 'cleave', 'demolish', 'disintegrate', 'dismantle', 'dismember', 'dismount', 'fragment', 'make mincemeat of', 'pick to pieces', 'pull in pieces'],
    'disassociation': ['abstraction', 'alienation', 'detachment', 'disarticulation', 'disconnectedness', 'disconnection', 'discontinuity', 'discreteness', 'disengagement', 'disjointing', 'disjunction', 'disjuncture'],
    'disaster': ['accident', 'act of god', 'adversity', 'apoplexy', 'blow', 'breakdown', 'breaking up', 'breakup', 'calamity', 'casualty', 'cataclysm', 'catastrophe'],
    'disastrous': ['appalling', 'awful', 'baneful', 'black', 'calamitous', 'cataclysmal', 'cataclysmic', 'catastrophic', 'consuming', 'consumptive', 'convulsive', 'deadly'],
    'disavow': ['abjure', 'assert the contrary', 'back down', 'back out', 'backwater', 'belie', 'climb down', 'contest', 'contradict', 'contravene', 'controvert', 'counter'],
    'disavowal': ['abjuration', 'abjurement', 'abrogation', 'absolute contradiction', 'annulment', 'contradiction', 'contrary assertion', 'contravention', 'controversion', 'countering', 'crossing', 'denial'],
    'disband': ['break up', 'deactivate', 'debrief', 'decommission', 'demilitarize', 'demob', 'demobilize', 'detach', 'dichotomize', 'disarm', 'discharge', 'disintegrate'],
    'disbandment': ['breakup', 'deactivation', 'demilitarization', 'demobilization', 'detachment', 'diaspora', 'disarmament', 'disbanding', 'disintegration', 'dismissal', 'disorganization', 'dispersal'],
    'disbar': ['boot', 'bounce', 'break', 'bump', 'bust', 'can', 'cashier', 'deconsecrate', 'defrock', 'degrade', 'demote', 'deplume'],
    'disbarment': ['banishment', 'blackballing', 'cashiering', 'deconsecration', 'defrocking', 'degradation', 'demotion', 'depluming', 'deportation', 'deposal', 'deposition', 'deprivation'],
    'disbelief': ['agnosticism', 'atheism', 'confutability', 'contestability', 'controvertibility', 'deism', 'deniability', 'denial', 'discredit', 'disputability', 'doubt', 'doubtfulness'],
    'disbelieve': ['be skeptical', 'deny', 'discredit', 'distrust', 'doubt', 'eschew', 'gag on', 'misbelieve', 'mistrust', 'negate', 'not accept', 'not admit'],
    'disbelieving': ['atheist', 'atheistic', 'creedless', 'faithless', 'heathen', 'heretical', 'incredulous', 'infidel', 'infidelic', 'irreligious', 'minimifidian', 'nonbelieving'],
    'disburden': ['abridge', 'alleviate', 'be light', 'bereave', 'bleed', 'break bulk', 'clear', 'curtail', 'cut off', 'deprive', 'deprive of', 'discharge'],
    'disbursal': ['acquitment', 'acquittal', 'acquittance', 'administration', 'amortization', 'amortizement', 'binder', 'budgeting', 'cash', 'cash payment', 'clearance', 'costing'],
    'disburse': ['administer', 'budget', 'cost', 'cost out', 'deal', 'deal out', 'dispense', 'disperse', 'dispose', 'distribute', 'dole', 'dole out'],
    'disc': ['bulletin board', 'card', 'cartridge', 'cassette', 'catalog card', 'electrical transcription', 'file', 'filing card', 'film', 'index card', 'library catalog', 'magnetic tape'],
    'discard': ['abandon', 'abdicate', 'abjuration', 'abjure', 'abjurement', 'back out', 'beg off', 'boot out', 'bounce', 'brush aside', 'cashier', 'cast'],
    'discarded': ['abandoned', 'belied', 'cast-off', 'castaway', 'confounded', 'confuted', 'contemned', 'declined', 'declined with thanks', 'deflated', 'denied', 'derelict'],
    'discarnate': ['airy', 'asomatous', 'astral', 'bodiless', 'decarnate', 'decarnated', 'disembodied', 'ethereal', 'extramundane', 'ghostly', 'immaterial', 'impalpable'],
    'discern': ['anticipate', 'appreciate', 'apprehend', 'ascertain', 'be acquainted with', 'be apprised of', 'be aware of', 'be cognizant of', 'be conscious of', 'be conversant with', 'be informed', 'behold'],
    'discernible': ['apparent', 'appreciable', 'apprehensible', 'ascertainable', 'beholdable', 'clear', 'clear as crystal', 'cognizable', 'comprehensible', 'conceivable', 'conspicuous', 'crystal-clear'],
    'discerning': ['acute', 'apperceptive', 'appercipient', 'argute', 'astute', 'cogent', 'farseeing', 'farsighted', 'foreseeing', 'foresighted', 'forethoughted', 'forethoughtful'],
    'discernment': ['acuity', 'acumen', 'acuteness', 'apperception', 'astuteness', 'clear sight', 'cogency', 'color vision', 'cone vision', 'critical discernment', 'day vision', 'daylight vision'],
    'discharge': ['ac arc', 'poulsen arc', 'abide by', 'abrogate', 'absolution', 'absolve', 'accomplish', 'accomplished fact', 'accomplishment', 'accordance', 'achieve', 'achievement'],
    'discharged': ['accomplished', 'achieved', 'acquitted', 'attained', 'compassed', 'consummated', 'dispatched', 'disposed of', 'effected', 'effectuated', 'executed', 'expended'],
    'disciple': ['ambrose of milan', 'athanasius', 'barnabas', 'basil', 'christian', 'clement of alexandria', 'clement of rome', 'cyprian of carthage', 'cyril of jerusalem', 'god-fearing man', 'gregory of nyssa', 'hermas'],
    'disciplinarian': ['simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'autocrat', 'caesar', 'commissar', 'czar', 'despot', 'dictator'],
    'disciplinary': ['autodidactic', 'castigatory', 'chastening', 'chastising', 'coeducational', 'corrective', 'cultural', 'didactic', 'edifying', 'educating', 'educational', 'educative'],
    'discipline': ['spartanism', 'academic discipline', 'academic specialty', 'accommodate', 'accommodate with', 'accord', 'adapt', 'adapt to', 'adjust', 'adjust to', 'administer', 'administrate'],
    'disciplined': ['spartan', 'accepting', 'armed with patience', 'bound', 'bounded', 'conditioned', 'confined', 'copyrighted', 'cramped', 'endurant', 'enduring', 'finite'],
    'disclaim': ['abjure', 'assert the contrary', 'back down', 'back out', 'backwater', 'be unmoved', 'be unwilling', 'beg off', 'belie', 'belittle', 'brush aside', 'challenge'],
    'disclaimer': ['abjuration', 'abjurement', 'abnegation', 'abrogation', 'absolute contradiction', 'annulment', 'contradiction', 'contrary assertion', 'contravention', 'controversion', 'countering', 'crossing'],
    'disclose': ['acknowledge', 'acquaint', 'admit', 'advertise', 'advertise of', 'advise', 'affect', 'affirm', 'allege', 'apprise', 'argue', 'articulate'],
    'disclosed': ['apparent', 'bald', 'bare', 'beholdable', 'clear', 'cleared', 'detectable', 'discernible', 'evident', 'exposed', 'exposed to view', 'free'],
    'disclosive': ['christophanic', 'satanophanic', 'angelophanic', 'apocalyptic', 'appearing', 'betraying', 'demonstrating', 'demonstrative', 'disclosing', 'displaying', 'epiphanic', 'evidential'],
    'disclosure': ['christophany', 'satanophany', 'admission', 'affidavit', 'affirmation', 'allegation', 'angelophany', 'announcement', 'apparition', 'appearance', 'appearing', 'arising'],
    'discolor': ['achromatize', 'attaint', 'bedaub', 'besmear', 'besmirch', 'besmoke', 'bestain', 'blacken', 'blanch', 'blaze', 'blaze a trail', 'bleach'],
    'discoloration': ['achromatization', 'birthmark', 'blanching', 'blaze', 'bleach', 'bleaching', 'blemish', 'blotch', 'brand', 'bruise', 'caste mark', 'check'],
    'discolored': ['achromatic', 'achromic', 'anemic', 'ashen', 'ashy', 'besmirched', 'blackened', 'bled white', 'bloodless', 'cadaverous', 'chloranemic', 'colorless'],
    'discombobulate': ['addle', 'addle the wits', 'agitate', 'ball up', 'becloud', 'bedazzle', 'befuddle', 'bewilder', 'bother', 'bug', 'cloud', 'confuse'],
    'discomfit': ['abash', 'addle', 'addle the wits', 'annoy', 'appall', 'astound', 'baffle', 'balk', 'ball up', 'becloud', 'bedazzle', 'befuddle'],
    'discomfited': ['abashed', 'afflicted', 'agitated', 'all up with', 'amiss', 'askew', 'awry', 'beat', 'beaten', 'beset', 'bested', 'bothered'],
    'discomfiture': ['abashment', 'agitation', 'bafflement', 'balk', 'balking', 'beating', 'befuddlement', 'betrayed hope', 'bewilderment', 'blasted expectation', 'blighted hope', 'blow'],
    'discomfort': ['schmerz', 'ache', 'aches and pains', 'afflict', 'agitate', 'angst', 'anguish', 'anxiety', 'bitterness', 'bleakness', 'boredom', 'bother'],
    'discommode': ['ail', 'be the matter', 'beset', 'bother', 'complicate matters', 'concern', 'disaccommodate', 'disadvantage', 'disoblige', 'distress', 'disturb', 'flurry'],
    'discompose': ['abash', 'addle', 'addle the wits', 'aggravate', 'agitate', 'annoy', 'badger', 'bait', 'ball up', 'be at', 'be tedious', 'beat'],
    'discomposed': ['abashed', 'abroad', 'adrift', 'afflicted', 'agitated', 'amiss', 'askew', 'astray', 'at sea', 'awry', 'balled-up', 'beset'],
    'discomposure': ['abashment', 'agitation', 'angst', 'anguish', 'anxiety', 'baffle', 'bafflement', 'befuddlement', 'bewilderment', 'bluster', 'bobbery', 'boil'],
    'disconcert': ['abash', 'addle', 'addle the wits', 'agitate', 'appall', 'astound', 'baffle', 'balk', 'ball up', 'becloud', 'bedazzle', 'befuddle'],
    'disconcerted': ['abashed', 'abroad', 'adrift', 'afflicted', 'agitated', 'all shook up', 'amiss', 'askew', 'astray', 'at sea', 'awry', 'baffled'],
    'disconcerting': ['alarming', 'awing', 'awkward', 'baffling', 'bewildering', 'bothering', 'chilling', 'confounding', 'confusing', 'crushing', 'daunting', 'defeating'],
    'disconnect': ['abrupt', 'abstract', 'alienate', 'break off', 'cast off', 'cast out', 'cut adrift', 'cut apart', 'cut off', 'cut out', 'delete', 'depart'],
    'disconnected': ['alien', 'alienated', 'aloof', 'apart', 'broken', 'broken off', 'capricious', 'careening', 'catchy', 'chopped-off', 'choppy', 'confused'],
    'disconnection': ['abstraction', 'alienation', 'alternating personality', 'broken thread', 'brokenness', 'depersonalization', 'detachment', 'disarticulation', 'disassociation', 'disconnectedness', 'discontinuance', 'discontinuation'],
    'disconsolate': ['affording no hope', 'apathetic', 'bad', 'black', 'bleak', 'cheerless', 'cold', 'comfortless', 'crestfallen', 'crushed', 'cut up', 'deep-troubled'],
    'disconsonant': ['absonant', 'atonal', 'cacophonous', 'conflicting', 'cracked', 'diaphonic', 'discordant', 'discrepant', 'disharmonic', 'disharmonious', 'dissonant', 'flat'],
    'discontent': ['aggravation', 'anger', 'angst', 'anguish', 'annoyance', 'anxiety', 'asperity', 'bad humor', 'bad temper', 'ban', 'be tedious', 'bile'],
    'discontented': ['acid', 'against', 'angry', 'annoyed', 'beefing', 'bellyaching', 'bitching', 'browned off', 'caustic', 'cheerless', 'complaining', 'complaintful'],
    'discontinuance': ['abandonment', 'abeyance', 'abjuration', 'abjurement', 'breakoff', 'broken thread', 'brokenness', 'cease', 'ceasing', 'cessation', 'close', 'closing'],
    'discontinue': ['abandon', 'abjure', 'abort', 'belay', 'break', 'break off', 'break the habit', 'cancel', 'cease', 'come off', 'cut it out', 'cut out'],
    'discontinued': ['abandoned', 'abjured', 'antiquated', 'antique', 'archaic', 'broken', 'broken off', 'chopped-off', 'choppy', 'decousu', 'deserted', 'disconnected'],
    'discontinuity': ['doppler effect', 'about-face', 'abstraction', 'accommodation', 'adaptation', 'adjustment', 'alienation', 'alteration', 'amelioration', 'apostasy', 'arrearage', 'arrhythmia'],
    'discontinuous': ['aimless', 'aloof', 'amorphous', 'apart', 'asunder', 'bipartite', 'broken', 'broken off', 'capricious', 'careening', 'casual', 'catchy'],
    'discord': ['bedlam let loose', 'discordia', 'eris', 'animosity', 'antagonism', 'antipathy', 'argumentation', 'bedlam', 'blast', 'bobbery', 'brawl', 'brouhaha'],
    'discordant': ['absonant', 'adversative', 'adverse', 'adversive', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'antonymous', 'assorted', 'at cross-purposes', 'at loggerheads'],
    'discotheque': ['amusement park', 'ballroom', 'cabaret', 'cafe', 'cafe chantant', 'cafe dansant', 'casino', 'dance floor', 'dance hall', 'dancing pavilion', 'entertainment industry', 'fun-fair'],
    'discount': ['abate', 'abatement', 'abjure', 'abuse', 'admit', 'admit exceptions', 'allow', 'allow for', 'allowance', 'bate', 'belittle', 'blink at'],
    'discount rate': ['bank rate', 'compensatory interest', 'compound interest', 'exorbitant interest', 'gross interest', 'interest', 'interest rate', 'lucrative interest', 'mortgage points', 'net interest', 'penal interest', 'premium'],
    'discount store': ['boutique', 'chain store', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dime store', 'discount house', 'emporium', 'establishment'],
    'discountenance': ['abash', 'abashment', 'baffle', 'balk', 'be against', 'be agin', 'blast', 'brave', 'chagrin', 'challenge', 'checkmate', 'circumvent'],
    'discourage': ['afflict', 'anticipate', 'avert', 'awe', 'bar', 'beat down', 'blunt', 'bother', 'cast down', 'check', 'chill', 'cool'],
    'discouraging': ['admonitory', 'alarming', 'awing', 'black', 'bleak', 'cautionary', 'chilling', 'daunting', 'depressant', 'depressing', 'depressive', 'deterrent'],
    'discourse': ['accents', 'act', 'address', 'air', 'amplify', 'analyze', 'argue', 'article', 'assignment', 'bandy words', 'canvass', 'causerie'],
    'discourser': ['boanerges', 'author', 'chalk talker', 'collocutor', 'colloquialist', 'conversational partner', 'conversationalist', 'converser', 'descanter', 'dialogist', 'disquisitor', 'essayist'],
    'discourteous': ['abrupt', 'aweless', 'boorish', 'brusque', 'curt', 'derisive', 'disparaging', 'disrespectful', 'ill-bred', 'ill-mannered', 'impertinent', 'impolite'],
    'discourtesy': ['badness', 'correct deportment', 'courtesy', 'disesteem', 'dishonor', 'disorder', 'disorderliness', 'disorderly conduct', 'disparagement', 'disrespect', 'disrespectfulness', 'disruption'],
    'discover': ['advertise', 'ascertain', 'bare', 'be informed', 'become acquainted with', 'beget', 'behold', 'betray', 'break the seal', 'breed', 'bring forth', 'bring into being'],
    'discovery': ['apocalypse', 'ascertaining', 'baring', 'bonus', 'breakthrough', 'buried treasure', 'coinage', 'conception', 'detection', 'determining', 'development', 'disclosing'],
    'discredit': ['agnosticism', 'asperse', 'aspersion', 'atheism', 'bad character', 'bad name', 'bad odor', 'bad report', 'bad reputation', 'bad repute', 'belie', 'belittle'],
    'discredited': ['at a discount', 'belied', 'confounded', 'confuted', 'contested', 'deflated', 'denied', 'disbelieved', 'discarded', 'disgraced', 'dismissed', 'disproved'],
    'discreet': ['olympian', 'aloof', 'backward', 'bashful', 'blank', 'calculating', 'canny', 'careful', 'cautious', 'chary', 'chilled', 'chilly'],
    'discreetly': ['artfully', 'astutely', 'cannily', 'carefully', 'cautiously', 'circumspectly', 'cleverly', 'considerately', 'cunningly', 'discerningly', 'easy', 'gingerly'],
    'discrepancy': ['antagonism', 'antipathy', 'antithesis', 'argumentation', 'balance', 'clashing', 'collision', 'conflict', 'confrontation', 'contradiction', 'contradistinction', 'contraindication'],
    'discrepant': ['adversative', 'adverse', 'adversive', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'antonymous', 'assorted', 'at cross-purposes', 'at loggerheads', 'at odds'],
    'discrete': ['alien', 'aloof', 'apart', 'assorted', 'asunder', 'at odds', 'at variance', 'bipartite', 'broadcast', 'broken', 'broken off', 'chopped-off'],
    'discretion': ['airtight secrecy', 'aloofness', 'alternate choice', 'alternative', 'animus', 'anticipation', 'appetence', 'appetency', 'appetite', 'backwardness', 'bashfulness', 'blankness'],
    'discretionary': ['arbitrary', 'autonomous', 'discretional', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'nonmandatory', 'offered', 'optional', 'proffered'],
    'discriminate': ['analyze', 'anatomize', 'atomize', 'change', 'chop logic', 'collate', 'compare', 'contradistinguish', 'contrast', 'demarcate', 'demark', 'desynonymize'],
    'discriminating': ['accurate', 'adoptive', 'appointive', 'appreciative', 'careful', 'censorious', 'characteristic', 'characterizing', 'choicy', 'choosing', 'choosy', 'circumspect'],
    'discrimination': ['atticism', 'jim crow', 'jim crow law', 'acquired taste', 'acumen', 'adjudgment', 'adjudication', 'aestheticism', 'alteration', 'analysis', 'anatomization', 'anti-semitism'],
    'discursion': ['wanderjahr', 'aberrancy', 'aberration', 'afoot and lighthearted', 'aside', 'bend', 'bias', 'branching off', 'bumming', 'bypath', 'byway', 'circuitousness'],
    'discursive': ['o-shaped', 'a fortiori', 'a posteriori', 'a priori', 'aberrant', 'aberrative', 'aimless', 'ambagious', 'analytic', 'backhanded', 'bright', 'by the way'],
    'discus': ['annular muscle', 'annulus', 'areola', 'aureole', 'ball', 'chaplet', 'circle', 'circuit', 'circumference', 'circus', 'closed circle', 'corona'],
    'discuss': ['advise with', 'agitate', 'air', 'analyze', 'argue', 'bargain', 'call in', 'canvass', 'collogue', 'comment upon', 'compare notes', 'confer'],
    'discussion': ['airing', 'analysis', 'argument', 'article', 'audience', 'bargaining', 'bargaining session', 'bull session', 'buzz session', 'canvassing', 'causerie', 'chat'],
    'disdain': ['abhor', 'abjure', 'airs', 'antipathetic', 'antipathy', 'aristocratic disdain', 'arrogance', 'arrogant', 'audacity', 'averse', 'aversion', 'be above'],
    'disdainful': ['abjuratory', 'arrogant', 'audacious', 'bold', 'brash', 'brassy', 'brazen', 'bumptious', 'cavalier', 'challenging', 'cheeky', 'clannish'],
    'disease': ['affection', 'affliction', 'ailment', 'bane', 'blight', 'bug', 'bugbear', 'burden', 'calamity', 'cancer', 'complaint', 'condition'],
    'diseased': ['abed', 'abnormal', 'afflicted', 'ailing', 'bad', 'cankered', 'contaminated', 'gangrened', 'gangrenous', 'ill', 'infected', 'infirm'],
    'disembark': ['alight', 'anchor', 'cast anchor', 'come to anchor', 'come to land', 'debark', 'debus', 'deplane', 'detrain', 'disemplane', 'dock', 'drop anchor'],
    'disembarrass': ['break loose', 'break out', 'clear', 'cut loose', 'disburden', 'disembroil', 'disencumber', 'disengage', 'disentangle', 'disinvolve', 'dislodge', 'extricate'],
    'disembodied': ['airy', 'asomatous', 'astral', 'bodiless', 'decarnate', 'decarnated', 'discarnate', 'ethereal', 'extramundane', 'ghostly', 'immaterial', 'impalpable'],
    'disembroil': ['break loose', 'break out', 'clarify', 'clear', 'clear up', 'cut loose', 'disburden', 'disembarrass', 'disencumber', 'disengage', 'disentangle', 'disintricate'],
    'disenchant': ['awaken', 'break the spell', 'burst the bubble', 'correct', 'debunk', 'disabuse', 'disappoint', 'disillude', 'disillusion', 'disillusionize', 'enlighten', 'expose'],
    'disenchanted': ['against', 'allergic', 'averse', 'blase', 'con', 'cynical', 'disabused', 'disaffected', 'disappointed', 'disapprobatory', 'disapproving', 'discontented'],
    'disenchantment': ['about-face', 'awakening', 'backing', 'backsliding', 'ban', 'blackball', 'blackballing', 'complaint', 'debunking', 'dim view', 'disagreement', 'disappointment'],
    'disencumber': ['alleviate', 'be light', 'clear', 'disburden', 'disembarrass', 'disembroil', 'disengage', 'disentangle', 'disinvolve', 'ease', 'extricate', 'free'],
    'disenfranchise': ['deprive of freedom', 'disfranchise', 'dominate', 'enslave', 'enthrall', 'hold captive', 'hold down', 'hold in bondage', 'hold in captivity', 'hold in leash', 'hold in subjection', 'keep down'],
    'disengage': ['abrupt', 'abstract', 'alienate', 'back down', 'back out', 'beat a retreat', 'break loose', 'break out', 'break with', 'cast off', 'cast out', 'clear'],
    'disengaged': ['afoot and lighthearted', 'alienated', 'at large', 'at leisure', 'at liberty', 'at loose ends', 'available', 'clear', 'detached', 'disarticulated', 'disconnected', 'disjoined'],
    'disengagement': ['abstraction', 'alienation', 'breaking out', 'clearing', 'detachment', 'disarticulation', 'disassociation', 'disburdening', 'disconnectedness', 'disconnection', 'discontinuity', 'disembarrassment'],
    'disentangle': ['answer', 'avulse', 'bottom', 'break loose', 'break out', 'clarify', 'clear', 'clear up', 'crack', 'cut loose', 'cut out', 'debug'],
    'disentanglement': ['accomplishment', 'answer', 'ascertainment', 'avulsion', 'breaking out', 'clearing', 'clearing up', 'cracking', 'cutting out', 'decipherment', 'decoding', 'determination'],
    'disenthrone': ['break', 'bust', 'cashier', 'deconsecrate', 'defrock', 'depose', 'dethrone', 'disbar', 'discrown', 'dismiss', 'displace', 'drum out'],
    'disesteem': ['bad character', 'bad name', 'bad odor', 'bad report', 'bad reputation', 'bad repute', 'ban', 'be disrespectful', 'be overfamiliar with', 'blackball', 'blackballing', 'complaint'],
    'disfavor': ['abhor', 'alienation', 'aversion', 'bad books', 'bad character', 'bad name', 'bad odor', 'bad report', 'bad reputation', 'bad repute', 'ban', 'be hostile to'],
    'disfigure': ['blemish', 'blot', 'check', 'cicatrize', 'crack', 'craze', 'deface', 'deform', 'disproportion', 'distort', 'dysphemize', 'flaw'],
    'disfigured': ['bandy', 'bandy-legged', 'beautiless', 'blemished', 'bloated', 'blotted', 'bowlegged', 'cacophonic', 'cacophonous', 'checked', 'cicatrized', 'club-footed'],
    'disfigurement': ['birthmark', 'blackhead', 'bleb', 'blemish', 'blister', 'bowlegs', 'bulla', 'cacophony', 'camelback', 'check', 'cicatrix', 'cleft palate'],
    'disgorge': ['abandon', 'abjure', 'barf', 'be seasick', 'be sick', 'belch', 'blow open', 'blow out', 'break out', 'bring up', 'burst forth', 'burst out'],
    'disgorgement': ['barf', 'blowout', 'discharge', 'egesta', 'egestion', 'ejaculation', 'emission', 'eructation', 'eruption', 'expulsion', 'extravasation', 'gagging'],
    'disgrace': ['abasement', 'abomination', 'asperse', 'aspersion', 'atrocity', 'bad', 'belittle', 'belittling', 'besmirch', 'black eye', 'black mark', 'blacken'],
    'disgraceful': ['aberrant', 'abnormal', 'abominable', 'arrant', 'atrocious', 'bad', 'base', 'beneath one', 'black', 'blamable', 'blameworthy', 'cheap'],
    'disgruntled': ['against', 'annoyed', 'bad-tempered', 'beefing', 'bellyaching', 'bitching', 'browned off', 'complaining', 'complaintful', 'con', 'crabbing', 'crabby'],
    'disguise': ['accouter', 'acting', 'affect', 'affectation', 'appearance', 'assume', 'attitudinizing', 'bad copy', 'bad likeness', 'ballet skirt', 'becloud', 'befog'],
    'disguised': ['appareled', 'arrayed', 'attired', 'bedecked', 'behind the curtain', 'behind the scenes', 'boozy', 'breeched', 'camouflaged', 'canned', 'capped', 'chausse'],
    'disgust': ['abhorrence', 'abomination', 'allergy', 'animosity', 'animus', 'antagonism', 'antipathy', 'appall', 'aversion', 'cold sweat', 'contempt', 'creeping flesh'],
    'disgusted': ['abhorrent', 'allayed', 'anguished', 'anxious', 'averse to', 'bored', 'cheerless', 'cloyed', 'crammed', 'depressed', 'engorged', 'fed-up'],
    'disgusting': ['abhorrent', 'abject', 'abominable', 'arrant', 'atrocious', 'awful', 'barfy', 'base', 'beastly', 'beggarly', 'below contempt', 'beneath contempt'],
    'dish': ['ko', 'antepast', 'autoclave', 'babble', 'baffle', 'bail', 'balk', 'billy', 'blast', 'boil', 'bowl', 'brave'],
    'dish out': ['accord', 'administer', 'afford', 'allot', 'allow', 'award', 'bail', 'bestow', 'bestow on', 'bucket', 'communicate', 'confer'],
    'dishabille': ['bathrobe', 'bed jacket', 'brunch coat', 'casual clothes', 'dressing gown', 'housecoat', 'kimono', 'lounging robe', 'morning dress', 'neglige', 'negligee', 'robe'],
    'disharmonious': ['absonant', 'antagonistic', 'antipathetic', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'atonal', 'cacophonic', 'cacophonous', 'clashing'],
    'disharmony': ['discordia', 'eris', 'antagonism', 'argumentation', 'atonalism', 'atonality', 'cacophony', 'clash', 'clashing', 'clinker', 'conflict', 'contention'],
    'dishearten': ['anticipate', 'avert', 'awe', 'bar', 'beat down', 'cast down', 'chill', 'damp', 'dampen', 'dampen the spirits', 'darken', 'dash'],
    'disheartened': ['bowed-down', 'cast down', 'dashed', 'dejected', 'depressed', 'despairing', 'despondent', 'desponding', 'discouraged', 'dispirited', 'down', 'downcast'],
    'disheartening': ['alarming', 'awing', 'black', 'bleak', 'chilling', 'daunting', 'depressant', 'depressing', 'depressive', 'despondent', 'deterrent', 'deterring'],
    'dishevel': ['clutter', 'confuse', 'derange', 'disarrange', 'disarray', 'discompose', 'dislocate', 'disorder', 'disorganize', 'disturb', 'jumble', 'knock galley-west'],
    'disheveled': ['matted', 'messed up', 'messy', 'mussed up', 'raunchy', 'ruffled', 'rumpled', 'shaggy', 'slipshod', 'sloppy', 'snaggy', 'snarled'],
    'dishonest': ['machiavellian', 'ambidextrous', 'amoral', 'artful', 'bent', 'casuistic', 'cheating', 'conscienceless', 'corrupt', 'corrupted', 'counterfeit', 'crafty'],
    'dishonesty': ['machiavellianism', 'ambidexterity', 'artifice', 'bad faith', 'ballot-box stuffing', 'bunco', 'cardsharping', 'cheat', 'cheating', 'chicane', 'chicanery', 'corruptedness'],
    'dishonor': ['abase', 'abuse', 'affront', 'aspersion', 'bad character', 'bad debt', 'bad name', 'bad odor', 'bad report', 'bad reputation', 'bad repute', 'belittlement'],
    'dishonorable': ['amoral', 'bad', 'base', 'conscienceless', 'contemptible', 'corrupt', 'corrupted', 'criminal', 'crooked', 'dark', 'debased', 'degrading'],
    'dishpan': ['aquamanile', 'automatic dishwasher', 'basin', 'bath', 'bathtub', 'bidet', 'dishwasher', 'ewer', 'finger bowl', 'kitchen sink', 'lavabo', 'lavatory'],
    'dishwasher': ['aquamanile', 'automatic dishwasher', 'basin', 'bath', 'bathtub', 'bidet', 'dishpan', 'dishwiper', 'dry cleaner', 'ewer', 'finger bowl', 'kitchen sink'],
    'dishwater': ['bilge', 'bilgewater', 'bones', 'cambric tea', 'carrion', 'chaff', 'cobweb', 'culm', 'deadwood', 'ditchwater', 'draff', 'dregs'],
    'disillusion': ['awaken', 'awakening', 'baffle', 'balk', 'ban', 'bilk', 'blackball', 'blackballing', 'break the spell', 'burst the bubble', 'cast down', 'complaint'],
    'disillusioned': ['against', 'baffled', 'balked', 'betrayed', 'bilked', 'blase', 'blasted', 'blighted', 'chapfallen', 'con', 'crestfallen', 'crossed'],
    'disillusionment': ['bafflement', 'balk', 'ban', 'betrayed hope', 'blackball', 'blackballing', 'blasted expectation', 'blighted hope', 'blow', 'buffet', 'comedown', 'complaint'],
    'disinclination': ['antipathy', 'averseness', 'aversion', 'backwardness', 'bad books', 'cursoriness', 'disaffection', 'disaffinity', 'disagreement', 'disapprobation', 'disapproval', 'disfavor'],
    'disincline': ['blunt', 'chill', 'cool', 'damp', 'dampen', 'deflect', 'deter', 'disaffect', 'discourage', 'disinterest', 'distract', 'divert'],
    'disinclined': ['afraid', 'allergic', 'antipathetic', 'at odds', 'averse', 'backward', 'balking', 'boggling', 'cursory', 'differing', 'disaffected', 'disagreeing'],
    'disinfectant': ['acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bactericide', 'bleaching powder', 'bug bomb', 'carbamate insecticide', 'carbolic acid', 'chemosterilant', 'chlorine', 'cleaner'],
    'disingenuous': ['apparently sound', 'artful', 'calculating', 'casuistic', 'clever', 'colorable', 'contriving', 'crafty', 'cunning', 'deceitful', 'deceptive', 'designing'],
    'disintegrate': ['ablate', 'abrade', 'atomize', 'beat', 'bite the dust', 'blow to pieces', 'blow up', 'brain', 'bray', 'break', 'break down', 'break open'],
    'disintegrating': ['ablative', 'biodegradable', 'coming apart', 'corrosive', 'cracking', 'crumbling', 'decadent', 'declining', 'decomposable', 'decomposing', 'decrepit', 'degenerate'],
    'disintegration': ['abrasion', 'amiable weakness', 'atomization', 'attrition', 'beating', 'biodegradability', 'biodegradation', 'bloodbath', 'blue ruin', 'breakability', 'breakup', 'brecciation'],
    'disinterest': ['olympian detachment', 'accidia', 'acedia', 'aloofness', 'altruism', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'blunt'],
    'disinterested': ['laodicean', 'olympian', 'abstract', 'aloof', 'altruistic', 'apathetic', 'ataractic', 'benumbed', 'blah', 'blase', 'bored', 'candid'],
    'disinvolve': ['break loose', 'break out', 'clarify', 'clear', 'clear up', 'cut loose', 'disburden', 'disembarrass', 'disembroil', 'disencumber', 'disengage', 'disentangle'],
    'disjoin': ['ablate', 'abrupt', 'alienate', 'analyze', 'anatomize', 'atomize', 'break', 'break off', 'break up', 'cast off', 'cast out', 'change'],
    'disjoint': ['abrupt', 'alienate', 'break up', 'cast off', 'cast out', 'cut adrift', 'cut off', 'cut out', 'delete', 'depart', 'disarrange', 'disarray'],
    'disjointed': ['aimless', 'alienated', 'confused', 'detached', 'directionless', 'disarranged', 'disarticulated', 'disconnected', 'discontinuous', 'disengaged', 'disjoined', 'disjoint'],
    'disjunct': ['aimless', 'alien', 'alienated', 'amorphous', 'apart', 'capricious', 'casual', 'desultory', 'detached', 'disarticulated', 'disconnected', 'discontinuous'],
    'disjunction': ['ablation', 'abstraction', 'accord', 'addition', 'adjunct', 'affairs', 'affiliation', 'affinity', 'alienation', 'alliance', 'aloofness', 'alteration'],
    'disjunctive': ['ablative', 'adjectival', 'adjective', 'adverb', 'adverbial', 'adversative conjunction', 'alternative', 'attributive', 'biodegradable', 'broken', 'broken off', 'chopped-off'],
    'disk': ['annular muscle', 'annulus', 'areola', 'aureole', 'carousel', 'chaplet', 'circle', 'circuit', 'circumference', 'circus', 'closed circle', 'coat'],
    'dislike': ['anglophobia', 'russophobia', 'abhor', 'abhorrence', 'abominate', 'abomination', 'angst', 'anguish', 'animosity', 'animus', 'antagonism', 'anti-semitism'],
    'dislocate': ['clutter', 'derange', 'disarrange', 'disarray', 'disarticulate', 'discompose', 'dishevel', 'disjoint', 'disorder', 'disorganize', 'displace', 'disrupt'],
    'dislocated': ['alienated', 'amiss', 'askew', 'awry', 'cockeyed', 'convulsed', 'deranged', 'detached', 'disarranged', 'disarticulated', 'discomfited', 'discomposed'],
    'dislocation': ['abstraction', 'alienation', 'convulsion', 'derangement', 'detachment', 'disarrangement', 'disarticulation', 'disassociation', 'discomposure', 'disconnectedness', 'disconnection', 'discontinuity'],
    'dislodge': ['break loose', 'break out', 'buck off', 'carry away', 'carry off', 'cart away', 'clear', 'cut loose', 'delocalize', 'depose', 'deracinate', 'disembarrass'],
    'disloyal': ['alienated', 'apostate', 'collaborative', 'deceitful', 'derelict', 'disaffected', 'estranged', 'faithless', 'false', 'fickle', 'heretical', 'inconstant'],
    'disloyalty': ['punic faith', 'apostasy', 'backsliding', 'bad faith', 'barratry', 'betrayal', 'bolt', 'breach of faith', 'breach of promise', 'breach of trust', 'breakaway', 'defection'],
    'dismal': ['cassandra-like', 'cassandran', 'cassandrian', 'quaker-colored', 'acier', 'affecting', 'afflictive', 'affording no hope', 'apathetic', 'arid', 'ashen', 'ashy'],
    'dismantle': ['annihilate', 'atomize', 'bankrupt', 'bare', 'break to pieces', 'cleave', 'decimate', 'demolish', 'denudate', 'denude', 'deprive', 'disarray'],
    'dismay': ['abash', 'abject fear', 'affright', 'agitate', 'agitation', 'alarm', 'anxiety', 'appall', 'apprehension', 'astound', 'awe', 'bewilder'],
    'dismayed': ['abashed', 'abroad', 'adrift', 'affrighted', 'afraid', 'agape', 'alarmed', 'astray', 'at sea', 'bewildered', 'bothered', 'chicken'],
    'dismaying': ['affecting', 'afflictive', 'alarming', 'awing', 'baffling', 'bewildering', 'bitter', 'bleak', 'bothering', 'cheerless', 'chilling', 'comfortless'],
    'dismember': ['cripple', 'defoliate', 'denude', 'disassemble', 'dismantle', 'draw and quarter', 'flay', 'grill', 'impale', 'keelhaul', 'lacerate', 'maim'],
    'dismiss': ['abandon', 'abjure', 'absolve', 'acquit', 'amnesty', 'answer', 'answer conclusively', 'argue down', 'ax', 'banish', 'beat back', 'belittle'],
    'dismissal': ['abjuration', 'abjurement', 'absolution', 'acquittal', 'acquittance', 'adjournment', 'bounce', 'breakup', 'brush-off', 'cancellation', 'cashiering', 'chucking'],
    'dismissed': ['belied', 'confounded', 'confuted', 'contemned', 'declined', 'declined with thanks', 'deflated', 'denied', 'despised', 'disapproved', 'discarded', 'discounted'],
    'dismount': ['alight', 'buck off', 'climb down', 'demolish', 'depose', 'deracinate', 'detach', 'disassemble', 'disconnect', 'disengage', 'disjoin', 'dislodge'],
    'disobedience': ['abnegation', 'antipathy', 'averseness', 'aversion', 'backwardness', 'contradiction', 'cursoriness', 'declension', 'declination', 'declinature', 'declining', 'denial'],
    'disobedient': ['anarchic', 'at odds', 'averse', 'bad', 'contrary', 'contumacious', 'cross-grained', 'cursory', 'deaf to', 'declinatory', 'defiant', 'delinquent'],
    'disobey': ['break', 'break the law', 'care naught for', 'contravene', 'defy', 'disregard', 'flout', 'go counter to', 'ignore', 'infringe', 'mutiny', 'not conform'],
    'disoblige': ['affront', 'bother', 'call names', 'disaccommodate', 'disadvantage', 'discommode', 'dishonor', 'dump on', 'fleer at', 'flout', 'gibe at', 'give offense to'],
    'disorder': ['abnormality', 'acute disease', 'affection', 'afflict', 'affliction', 'affray', 'agitation', 'ailment', 'allergic disease', 'allergy', 'aloofness', 'amorphia'],
    'disordered': ['aimless', 'aleatoric', 'aleatory', 'amiss', 'amorphous', 'askew', 'awry', 'balled-up', 'batty', 'bedlamite', 'blobby', 'blurred'],
    'disorderly': ['amiss', 'amorphic', 'amorphous', 'anarchial', 'anarchic', 'anarchistic', 'antinomian', 'askew', 'awry', 'bad', 'baggy', 'blobby'],
    'disorderly conduct': ['badness', 'discourtesy', 'disorder', 'disorderliness', 'disruption', 'disruptiveness', 'frowned-upon behavior', 'hooliganism', 'horseplay', 'impropriety', 'misbehavior', 'misconduct'],
    'disorganization': ['ablation', 'anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism', 'atomization', 'befuddlement', 'bewilderment', 'biodegradability', 'biodegradation', 'bloodbath', 'blue ruin'],
    'disorganize': ['ablate', 'addle', 'addle the wits', 'atomize', 'ball up', 'becloud', 'bedazzle', 'befuddle', 'bewilder', 'bother', 'break up', 'bug'],
    'disorganized': ['amiss', 'anarchial', 'anarchic', 'anarchistic', 'antinomian', 'askew', 'awry', 'balled-up', 'bothered', 'chaotic', 'cockeyed', 'confused'],
    'disorient': ['addle', 'addle the wits', 'ball up', 'becloud', 'bedazzle', 'befuddle', 'bewilder', 'bother', 'bug', 'cloud', 'confuse', 'daze'],
    'disorientation': ['aberration', 'abnormality', 'accommodation', 'adaptation', 'adjustment', 'agnosia', 'alienation', 'alignment', 'bearings', 'befuddlement', 'bewilderment', 'block'],
    'disoriented': ['abashed', 'abnormal', 'abroad', 'adrift', 'astray', 'at sea', 'bereft of reason', 'bewildered', 'bothered', 'brainsick', 'clueless', 'confused'],
    'disown': ['abjure', 'assert the contrary', 'back down', 'back out', 'backwater', 'belie', 'brush aside', 'chuck', 'chuck out', 'climb down', 'contemn', 'contest'],
    'disowned': ['abandoned', 'cast-off', 'castaway', 'contemned', 'declined', 'declined with thanks', 'denied', 'derelict', 'despised', 'disapproved', 'discarded', 'discounted'],
    'disownment': ['abjuration', 'abjurement', 'abrogation', 'absolute contradiction', 'annulment', 'chucking', 'chucking out', 'contempt', 'contradiction', 'contrary assertion', 'contravention', 'controversion'],
    'disparage': ['abate', 'abrade', 'abstract', 'abuse', 'attaint', 'backbite', 'bad-mouth', 'bate', 'be above', 'be contemptuous of', 'be disrespectful', 'be overfamiliar with'],
    'disparagement': ['airs', 'animadversion', 'arrogance', 'aspersion', 'attaint', 'attrition', 'backbiting', 'backstabbing', 'badge of infamy', 'bar sinister', 'baton', 'belittlement'],
    'disparager': ['thersites', 'backbiter', 'belittler', 'calumniator', 'caustic critic', 'cynic', 'debunker', 'decrier', 'defamer', 'deflater', 'depreciator', 'derogator'],
    'disparaging': ['abusive', 'aweless', 'back-biting', 'belittling', 'bitchy', 'blackening', 'blameful', 'calumniatory', 'calumnious', 'catty', 'censorious', 'condemnatory'],
    'disparate': ['assorted', 'asymmetric', 'at odds', 'at variance', 'contrary', 'contrasted', 'contrasting', 'counter', 'departing', 'deviating', 'deviative', 'different'],
    'disparity': ['agreement to disagree', 'alienation', 'antagonism', 'apostasy', 'argumentation', 'asymmetry', 'bad copy', 'bad likeness', 'camouflage', 'clashing', 'conflict', 'contradiction'],
    'dispassion': ['olympian detachment', 'abnegation', 'abstinence', 'accidia', 'acedia', 'aloofness', 'anesthesia', 'apathy', 'ataraxia', 'ataraxy', 'autism', 'benumbedness'],
    'dispassionate': ['olympian', 'aboveboard', 'abstract', 'affectless', 'aloof', 'anesthetized', 'apathetic', 'arctic', 'ataractic', 'autistic', 'blase', 'blunt'],
    'dispassionately': ['apathetically', 'calmly', 'carelessly', 'cold-bloodedly', 'coldheartedly', 'coldly', 'composedly', 'conservatively', 'coolly', 'deadpan', 'deservedly', 'disinterestedly'],
    'dispatch': ['accelerate', 'accomplish', 'accomplished fact', 'accomplishment', 'account', 'achieve', 'achievement', 'acknowledgment', 'acquaintance', 'address', 'administration', 'advice'],
    'dispatcher': ['baggage man', 'bakehead', 'brakeman', 'brakie', 'butcher', 'conductor', 'fireman', 'footplate man', 'guard', 'lineman', 'porter', 'railroad man'],
    'dispel': ['attenuate', 'be consumed', 'be gone', 'blow off', 'break up', 'cast forth', 'cast off', 'cease', 'cease to be', 'cease to exist', 'clear away', 'crumble'],
    'dispensable': ['admissible', 'allocated', 'allowable', 'apportionable', 'apportioned', 'back-burner', 'condonable', 'de trop', 'defensible', 'dinky', 'disposable', 'distributable'],
    'dispensary': ['x ray', 'blood bank', 'charity ward', 'chemist', 'clinic', 'consultation room', 'delivery room', 'dispensatory', 'drugstore', 'emergency', 'examining room', 'fever ward'],
    'dispensation': ['ok', 'abandonment', 'abjuration', 'administration', 'admission', 'allowance', 'attenuation', 'blank check', 'broadcast', 'broadcasting', 'carte blanche', 'cession'],
    'dispense': ['ok', 'abolish', 'abstain from', 'accord', 'administer', 'admit', 'afford', 'allocate', 'allot', 'allow', 'apply', 'apportion'],
    'dispense with': ['abandon', 'abjure', 'absolve', 'abstain', 'cede', 'discharge', 'disgorge', 'dispense from', 'dispose of', 'do without', 'drop', 'dump'],
    'dispersal': ['aloofness', 'anarchy', 'attenuation', 'breakup', 'broadcast', 'broadcasting', 'chaos', 'circumfusion', 'confusion', 'crack-up', 'deactivation', 'demobilization'],
    'disperse': ['administer', 'atomize', 'be consumed', 'be gone', 'bend', 'bestrew', 'bias', 'branch', 'branch out', 'break into pieces', 'break to pieces', 'break up'],
    'dispersed': ['aimless', 'alienated', 'amorphous', 'broadcast', 'capricious', 'casual', 'deflected', 'deflective', 'desultory', 'detached', 'diffracted', 'diffractive'],
    'dispersion': ['addition', 'adjunct', 'administration', 'aggrandizement', 'aloofness', 'ampliation', 'amplification', 'anarchy', 'augmentation', 'blackout', 'blocking', 'breakup'],
    'dispirit': ['beat down', 'cast down', 'chill', 'damp', 'dampen', 'dampen the spirits', 'darken', 'dash', 'deject', 'demoralize', 'depress', 'discourage'],
    'dispirited': ['blase', 'blue', 'bowed-down', 'cast down', 'dashed', 'dejected', 'depressed', 'despairing', 'despondent', 'desponding', 'disconsolate', 'discouraged'],
    'displace': ['act for', 'attend', 'banish', 'boot', 'bounce', 'break', 'bump', 'bust', 'can', 'carry away', 'carry off', 'cart away'],
    'displaced person': ['dp', 'ishmael', 'uitlander', 'absconder', 'alien', 'barbarian', 'bolter', 'castaway', 'declasse', 'deported population', 'deportee', 'deracine'],
    'displacement': ['doppler effect', 'agency', 'alienation', 'amotion', 'autism', 'autistic thinking', 'avatar', 'avoidance mechanism', 'banishment', 'blame-shifting', 'cashiering', 'catabolism'],
    'display': ['crt spot', 'century', 'dm display', 'doppler signal', 'doric', 'egyptian', 'elzevir', 'garamond', 'gothic', 'if signal', 'im display', 'ionic'],
    'displease': ['anger', 'annoy', 'be disagreeable', 'bug', 'chafe', 'disappoint', 'discontent', 'disgruntle', 'dishearten', 'dissatisfy', 'exasperate', 'frustrate'],
    'displeased': ['against', 'allergic', 'averse', 'beefing', 'bellyaching', 'bitching', 'complaining', 'complaintful', 'con', 'crabbing', 'crabby', 'cranky'],
    'displeasing': ['abhorrent', 'annoying', 'bitter', 'bothersome', 'disagreeable', 'disappointing', 'disheartening', 'dislikable', 'dissatisfactory', 'distasteful', 'foul-tasting', 'had'],
    'displeasure': ['aggravation', 'anger', 'angst', 'anguish', 'annoyance', 'anxiety', 'aversion', 'bad books', 'ban', 'blackball', 'blackballing', 'boredom'],
    'disport': ['acquit', 'act', 'antic', 'bear', 'brandish', 'caper', 'caracole', 'carry', 'carry on', 'cavort', 'comport', 'conduct'],
    'disposal': ['abalienation', 'abandonment', 'abjuration', 'administration', 'alienation', 'allocation', 'allotment', 'amortization', 'amortizement', 'apportionment', 'arrangement', 'array'],
    'dispose': ['adjust', 'administer', 'affect', 'aim', 'align', 'allocate', 'allot', 'apportion', 'arrange', 'array', 'assign', 'bear'],
    'dispose of': ['ko', 'abandon', 'abjure', 'abstract', 'accomplish', 'achieve', 'annihilate', 'answer', 'answer conclusively', 'argue down', 'attain', 'bereave of life'],
    'disposed': ['acquiescent', 'agreeable', 'alacritous', 'aligned', 'amenable', 'apt', 'apt to', 'ardent', 'arranged', 'arrayed', 'assorted', 'bent'],
    'disposition': ['a thing for', 'abalienation', 'abandonment', 'abjuration', 'administration', 'affinity', 'alienation', 'allocation', 'allotment', 'amortization', 'amortizement', 'animus'],
    'dispossess': ['bereave', 'boot out', 'bounce', 'cut off', 'disendow', 'disherison', 'disinherit', 'dislodge', 'disown', 'disseise', 'divest', 'drive out'],
    'dispossession': ['bereavement', 'cost', 'damage', 'dead loss', 'debit', 'denial', 'denudation', 'deprivation', 'deprivement', 'despoilment', 'destruction', 'detriment'],
    'disproof': ['abjuration', 'abjurement', 'abrogation', 'absolute contradiction', 'annulment', 'contradiction', 'contrary assertion', 'contravention', 'controversion', 'countering', 'crossing', 'denial'],
    'disproportion': ['ambiguity', 'ambivalence', 'anamorphism', 'anamorphosis', 'antinomy', 'asymmetry', 'buckle', 'contortion', 'contrariety', 'crookedness', 'derangement', 'detorsion'],
    'disproportionate': ['abnormal', 'absurd', 'aggrandized', 'aimless', 'amorphous', 'amplified', 'anomalous', 'antagonistic', 'antipathetic', 'asymmetric', 'asymmetrical', 'at cross-purposes'],
    'disprove': ['abjure', 'assert the contrary', 'belie', 'blow sky-high', 'blow up', 'break', 'confound', 'confute', 'contest', 'contradict', 'contravene', 'controvert'],
    'disproved': ['belied', 'confounded', 'confuted', 'deflated', 'denied', 'discarded', 'discredited', 'dismissed', 'disputed', 'exploded', 'exposed', 'impugned'],
    'disputable': ['arguable', 'at issue', 'confutable', 'conjectural', 'contestable', 'controversial', 'controvertible', 'debatable', 'deniable', 'doubtable', 'doubtful', 'dubious'],
    'disputant': ['philadelphia lawyer', 'apologist', 'arguer', 'argufier', 'battler', 'belligerent', 'belted knight', 'bickerer', 'bitter-ender', 'blade', 'bravo', 'brawler'],
    'disputatious': ['aggressive', 'argumental', 'argumentative', 'bellicose', 'belligerent', 'bickering', 'cat-and-dog', 'cat-and-doggish', 'combative', 'complaining', 'contentious', 'controversial'],
    'dispute': ['kilkenny cats', 'socratic method', 'abjure', 'agitate', 'altercate', 'altercation', 'apologetics', 'apologia', 'apology', 'argue', 'argufy', 'argument'],
    'disputed': ['belied', 'confounded', 'confuted', 'contested', 'deflated', 'denied', 'disbelieved', 'discarded', 'discredited', 'dismissed', 'disproved', 'doubted'],
    'disqualification': ['ad lib', 'disability', 'disablement', 'extemporaneousness', 'imbecility', 'improvisation', 'inability', 'inadequacy', 'incapability', 'incapacitation', 'incapacity', 'incompetence'],
    'disqualified': ['crippled', 'disabled', 'disarmed', 'hamstrung', 'hog-tied', 'ill-equipped', 'ill-fitted', 'ill-furnished', 'ill-provided', 'incapable', 'incapacitated', 'incompetent'],
    'disqualify': ['bar', 'bate', 'close out', 'debar', 'disable', 'disenable', 'eliminate', 'except', 'exclude', 'incapacitate', 'invalidate', 'make impossible'],
    'disquiet': ['afflict', 'affright', 'agitate', 'agitation', 'ailment', 'alarm', 'all-overs', 'angst', 'anguish', 'anxiety', 'anxiety hysteria', 'anxiety neurosis'],
    'disquieted': ['abashed', 'afflicted', 'affrighted', 'agitated', 'alarmed', 'all-overish', 'anxious', 'anxioused up', 'apprehensive', 'beset', 'bothered', 'cast down'],
    'disquieting': ['agitating', 'alarming', 'annoying', 'awing', 'bothersome', 'breathtaking', 'chafing', 'charged', 'chilling', 'cliff-hanging', 'daunting', 'deterrent'],
    'disregard': ['abide with', 'abjuration', 'abjure', 'abjurement', 'absentmindedness', 'accept', 'accidia', 'acedia', 'admit', 'admit exceptions', 'allow', 'allow for'],
    'disregarded': ['abandoned', 'absolved', 'acquitted', 'blotted', 'canceled', 'condoned', 'deserted', 'exculpated', 'excused', 'exonerated', 'forgiven', 'forgotten'],
    'disregardful': ['airy', 'apathetic', 'arrogant', 'ataractic', 'audacious', 'behindhand', 'blase', 'bold', 'brash', 'brassy', 'brazen', 'bumptious'],
    'disrepair': ['bankruptcy', 'breakage', 'breakdown', 'collapse', 'crack-up', 'crippling', 'damage', 'decay', 'destruction', 'deterioration', 'detriment', 'dilapidation'],
    'disreputable': ['abject', 'bad', 'base', 'bedraggled', 'beggarly', 'cheap', 'contemptible', 'contemptuous', 'decrepit', 'derogatory', 'despicable', 'dilapidated'],
    'disrespect': ['ban', 'be disrespectful', 'be overfamiliar with', 'blackball', 'blackballing', 'boldness', 'cheek', 'complaint', 'dim view', 'disagreement', 'disappointment', 'disapprobation'],
    'disrespectful': ['aweless', 'biggety', 'bluff', 'brash', 'cheeky', 'chutzpadik', 'cocky', 'contemptuous', 'crusty', 'derisive', 'discourteous', 'disparaging'],
    'disrobed': ['clothesless', 'decollete', 'en deshabille', 'garbless', 'garmentless', 'half-clothed', 'in dishabille', 'low-cut', 'nudish', 'raimentless', 'strapless', 'topless'],
    'disrupt': ['agitate', 'atomize', 'baffle', 'balk', 'blast', 'brave', 'breach', 'break in', 'break into', 'break into pieces', 'break to pieces', 'break up'],
    'disruption': ['alienation', 'anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism', 'badness', 'bloodbath', 'blue ruin', 'breach', 'breach of friendship', 'break', 'breakup'],
    'disruptive': ['ablative', 'bad', 'biodegradable', 'corrosive', 'decomposable', 'decomposing', 'degradable', 'dilapidated', 'disintegrable', 'disintegrated', 'disintegrating', 'disintegrative'],
    'dissatisfaction': ['faustianism', 'aggravation', 'agreement to disagree', 'alienation', 'angst', 'anguish', 'annoyance', 'anxiety', 'apostasy', 'aversion', 'bad books', 'bafflement'],
    'dissatisfied': ['against', 'annoyed', 'baffled', 'balked', 'beefing', 'bellyaching', 'betrayed', 'bilked', 'bitching', 'blasted', 'blighted', 'bothered'],
    'dissatisfy': ['baffle', 'balk', 'bilk', 'cast down', 'cross', 'dash', 'defeat', 'defeat expectation', 'disappoint', 'discontent', 'disgruntle', 'dishearten'],
    'dissect': ['analyze', 'anatomize', 'assay', 'break down', 'break up', 'carve', 'cleave', 'cut', 'decompose', 'dichotomize', 'disjoin', 'disjoint'],
    'dissection': ['analysis', 'analyzation', 'anatomizing', 'anatomy', 'assay', 'assaying', 'breakdown', 'breaking down', 'breaking up', 'breakup', 'criticism', 'critique'],
    'dissemblance': ['acting', 'affectation', 'appearance', 'attitudinizing', 'bad copy', 'bad likeness', 'bluff', 'bluffing', 'camouflage', 'cheating', 'color', 'coloring'],
    'disseminate': ['advertise', 'announce', 'annunciate', 'assign', 'bed', 'bestrew', 'blazon', 'broadcast', 'carry over', 'circulate', 'circumfuse', 'communicate'],
    'disseminated': ['accessible', 'affirmed', 'announced', 'broadcast', 'brought to notice', 'circulated', 'common knowledge', 'common property', 'current', 'declared', 'diffuse', 'diffused'],
    'dissemination': ['airing', 'attenuation', 'bandying', 'book', 'broadcast', 'broadcasting', 'bruiting', 'bruiting about', 'circulation', 'circumfusion', 'communication', 'conduction'],
    'dissension': ['aggressiveness', 'agreement to disagree', 'alienation', 'altercation', 'antagonism', 'antipathy', 'apostasy', 'argument', 'argumentation', 'bad blood', 'bellicosity', 'belligerence'],
    'dissent': ['evangelicalism', 'protestantism', 'reform', 'zwinglianism', 'abnegation', 'aggressiveness', 'agree to differ', 'agree to disagree', 'antagonism', 'antipathy', 'apostasy', 'argumentation'],
    'dissenter': ['bohemian', 'evangelical', 'protestant', 'reformationist', 'reformed believer', 'zwinglian', 'apostate', 'beatnik', 'demurrer', 'deviant', 'dissentient', 'dissident'],
    'dissenting': ['against', 'alienated', 'antiestablishment', 'at odds with', 'at variance with', 'breakaway', 'complaining', 'con', 'contrary', 'counter-culture', 'deviant', 'differing'],
    'dissertation': ['argumentation', 'article', 'causerie', 'descant', 'discourse', 'discussion', 'disputation', 'disquisition', 'essay', 'etude', 'examination', 'excursus'],
    'disservice': ['atrocity', 'bad deed', 'bad turn', 'damage', 'disfavor', 'great wrong', 'grievance', 'gross injustice', 'harm', 'ill service', 'ill turn', 'imposition'],
    'dissidence': ['aggressiveness', 'agreement to disagree', 'alienation', 'antagonism', 'apostasy', 'argumentation', 'bellicosity', 'belligerence', 'bickering', 'clashing', 'combativeness', 'conflict'],
    'dissident': ['alienated', 'antagonistic', 'antiestablishment', 'antipathetic', 'apostate', 'at cross-purposes', 'at loggerheads', 'at odds', 'at odds with', 'at variance', 'at variance with', 'at war'],
    'dissimilar': ['antithetical', 'antonymous', 'assorted', 'at odds', 'at variance', 'contradictory', 'contrary', 'contrasted', 'contrasting', 'counter', 'departing', 'deviating'],
    'dissimilarity': ['contrariety', 'contrast', 'departure', 'deviation', 'difference', 'disaccord', 'disaccordance', 'disagreement', 'disconformity', 'discongruity', 'discord', 'discordance'],
    'dissimulation': ['tartuffe', 'cloaking', 'concealing', 'cunning', 'deceit', 'deception', 'dissemblance', 'dissembler', 'dissembling', 'dissimulator', 'double-dealing', 'duplicity'],
    'dissipate': ['ablate', 'attenuate', 'be consumed', 'be gone', 'be promiscuous', 'blow', 'blow off', 'blunder away', 'break up', 'burn up', 'carouse', 'cast forth'],
    'dissipated': ['abandoned', 'abated', 'ablated', 'attenuated', 'bated', 'belittled', 'broadcast', 'burnt up', 'by the board', 'consumed', 'contracted', 'curtailed'],
    'dissipation': ['abandon', 'abandonment', 'ablation', 'amusement', 'attenuation', 'attrition', 'blackout', 'blocking', 'broadcast', 'broadcasting', 'carousal', 'carouse'],
    'dissociate': ['abrupt', 'abstract', 'alienate', 'cast off', 'cast out', 'catalyze', 'cut adrift', 'cut off', 'cut out', 'delete', 'depart', 'detach'],
    'dissociation': ['alienation', 'alpha decay', 'alternating personality', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction', 'atomization', 'autism', 'autistic thinking', 'avoidance mechanism', 'beta decay'],
    'dissolute': ['abandoned', 'amoral', 'contaminated', 'corrupt', 'corrupted', 'debased', 'debauched', 'decadent', 'degenerate', 'degraded', 'depraved', 'dissipated'],
    'dissolution': ['ablation', 'adjournment', 'aloofness', 'anarchy', 'annihilation', 'atomization', 'attrition', 'bane', 'biodegradability', 'biodegradation', 'biological death', 'blackout'],
    'dissolve': ['ablate', 'abrogate', 'adjourn', 'annihilate', 'atomize', 'attenuate', 'be annihilated', 'be consumed', 'be destroyed', 'be gone', 'be no more', 'be wiped out'],
    'dissolving': ['colliquative', 'disappearing', 'dissolutional', 'dissolutive', 'evanescent', 'evaporating', 'fading', 'fleeting', 'flying', 'fugitive', 'fusing', 'liquefactive'],
    'dissonance': ['antagonism', 'argumentation', 'atonalism', 'atonality', 'cacophony', 'clashing', 'clinker', 'conflict', 'contention', 'contradiction', 'contrariety', 'contrast'],
    'dissonant': ['absonant', 'antagonistic', 'antipathetic', 'assorted', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'atonal', 'cacophonic', 'cacophonous'],
    'dissuade': ['admonish', 'advise', 'caution', 'counsel', 'cry out against', 'daunt', 'derail', 'deter', 'discourage', 'divert', 'exhort', 'expostulate'],
    'distaff side': ['affiliation', 'agnate', 'ancestry', 'apparentation', 'birth', 'blood', 'blood relation', 'blood relative', 'bloodline', 'branch', 'breed', 'clansman'],
    'distance': ['aloofness', 'ambit', 'amplitude', 'angle', 'area', 'arena', 'back', 'backdrop', 'background', 'backwardness', 'base', 'bashfulness'],
    'distant': ['olympian', 'above all that', 'aloof', 'apart', 'apathetic', 'arrogant', 'asunder', 'at a distance', 'away', 'backward', 'barely audible', 'bashful'],
    'distaste': ['abhorrence', 'antipathy', 'averseness', 'aversion', 'backwardness', 'bad books', 'ban', 'blackball', 'blackballing', 'complaint', 'cursoriness', 'dim view'],
    'distasteful': ['abhorrent', 'abominable', 'bitter', 'detestable', 'disagreeable', 'disgusting', 'dislikable', 'displeasing', 'flat', 'flavorless', 'foul', 'foul-tasting'],
    'distemper': ['texas fever', 'abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'anarchism', 'anarchy', 'anthrax', 'aphthous fever'],
    'distend': ['add to', 'aggrandize', 'amplify', 'augment', 'bag', 'balloon', 'belly', 'belly out', 'bilge', 'billow', 'bloat', 'blow up'],
    'distended': ['adipose', 'bagging', 'baggy', 'ballooning', 'beefy', 'bellying', 'big-bellied', 'billowing', 'billowy', 'bloated', 'blown up', 'blowzy'],
    'distension': ['bloat', 'bloatedness', 'bloating', 'blowing up', 'boil', 'breaking point', 'bump', 'bunion', 'carbuncle', 'corn', 'cyst', 'diastole'],
    'distill': ['aerate', 'aerify', 'atomize', 'boil', 'bolt', 'bootleg', 'brew', 'carbonate', 'chlorinate', 'clarify', 'clear', 'concentrate'],
    'distillate': ['by-product', 'concentrate', 'concentration', 'consequence', 'consequent', 'core', 'corollary', 'decoction', 'derivation', 'derivative', 'development', 'distillation'],
    'distillation': ['aeration', 'aerification', 'artifact', 'atomization', 'blazing', 'blistering', 'bolting', 'brainchild', 'branding', 'burning', 'calcination', 'carbonization'],
    'distilled': ['absolute', 'bare', 'clarified', 'clear', 'naked', 'neat', 'purified', 'rectified', 'sheer', 'straight', 'unadulterated', 'unalloyed'],
    'distillery': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery', 'bottling works', 'brewery', 'brickyard'],
    'distinct': ['absolute', 'apart', 'apparent', 'articulate', 'assorted', 'asunder', 'at odds', 'at variance', 'audible', 'bipartite', 'categorical', 'certain'],
    'distinction': ['atticism', 'accolade', 'account', 'alteration', 'analysis', 'anatomization', 'ancestry', 'appropriateness', 'aristocracy', 'aristocraticalness', 'atomization', 'award'],
    'distinctive': ['accurate', 'appreciative', 'appropriate', 'articulate', 'audible', 'categorical', 'characteristic', 'characterizing', 'classificational', 'classificatory', 'clear', 'contrastive'],
    'distinctly': ['absolutely', 'aloud', 'and no mistake', 'apparently', 'apprehensibly', 'articulately', 'assuredly', 'at all events', 'at any rate', 'audibly', 'by all means', 'certainly'],
    'distinguish': ['adorn', 'aggrandize', 'analyze', 'anatomize', 'atomize', 'be characteristic', 'behold', 'bestow honor upon', 'call attention to', 'catch sight of', 'categorize', 'change'],
    'distinguished': ['a cut above', 'above', 'absolute', 'acclaimed', 'ahead', 'appropriate', 'aristocratic', 'ascendant', 'assorted', 'at odds', 'at variance', 'august'],
    'distinguishing': ['accurate', 'appreciative', 'characteristic', 'characterizing', 'contrastive', 'critical', 'delicate', 'diacritical', 'diagnostic', 'differencing', 'differential', 'differentiative'],
    'distort': ['adulterate', 'alloy', 'alter', 'argue insincerely', 'belie', 'bend', 'bias', 'blemish', 'blur', 'buckle', 'burlesque', 'camouflage'],
    'distorted': ['aberrant', 'abroad', 'adrift', 'affected', 'all abroad', 'all off', 'all wrong', 'amiss', 'anamorphous', 'apocryphal', 'artificial', 'askew'],
    'distortion': ['aberrancy', 'aberration', 'abstractionism', 'abuse of terms', 'anamorphosis', 'apparent soundness', 'bad likeness', 'birdies', 'birthmark', 'blackhead', 'bleb', 'blemish'],
    'distract': ['absorb', 'addle', 'agitate', 'amuse', 'ball up', 'befuddle', 'beguile', 'bemuse', 'bewilder', 'blunt', 'bother', 'bug'],
    'distracted': ['abandoned', 'abashed', 'abroad', 'adrift', 'amok', 'astray', 'at sea', 'bellowing', 'berserk', 'bewildered', 'bothered', 'careless'],
    'distraction': ['aberration', 'abnormality', 'absentmindedness', 'agitation', 'alienation', 'amusement', 'befuddlement', 'bewilderment', 'brain damage', 'brainsickness', 'carelessness', 'clouded mind'],
    'distraught': ['abashed', 'abnormal', 'abroad', 'addled', 'adrift', 'agitated', 'astray', 'at sea', 'batty', 'bereft of reason', 'berserk', 'bewildered'],
    'distress': ['schmerz', 'abashment', 'abuse', 'ache', 'aches and pains', 'aching', 'adversity', 'afflict', 'affliction', 'aggrieve', 'agitate', 'agitation'],
    'distressed': ['abashed', 'afflicted', 'agitated', 'agonized', 'annoyed', 'anxious', 'badly off', 'beset', 'bothered', 'cast down', 'chagrined', 'chapfallen'],
    'distressing': ['acute', 'affecting', 'afflictive', 'agonizing', 'annoying', 'atrocious', 'baleful', 'baneful', 'biting', 'bitter', 'bleak', 'bothersome'],
    'distressingly': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly', 'damnably', 'deadly'],
    'distribute': ['administer', 'align', 'allocate', 'allot', 'apportion', 'arrange', 'array', 'assign', 'assort', 'bestow', 'bestrew', 'broadcast'],
    'distributed': ['accessible', 'affirmed', 'announced', 'broadcast', 'brought to notice', 'circulated', 'common knowledge', 'common property', 'current', 'declared', 'diffuse', 'diffused'],
    'distribution': ['administration', 'allocation', 'allotment', 'apportionment', 'arrangement', 'array', 'arraying', 'assignment', 'attenuation', 'broadcast', 'broadcasting', 'cataloguing'],
    'distributive': ['attenuative', 'diffractional', 'diffractive', 'diffusive', 'dispersive', 'disseminative', 'dissipative', 'distributional', 'equal', 'even stephen', 'fifty-fifty', 'half'],
    'distributor': ['agent', 'broker', 'chandler', 'connection', 'dealer', 'go-between', 'importer', 'intermediary', 'intermedium', 'jobber', 'liaison', 'link'],
    'district': ['kreis', 'abode', 'airspace', 'apportion', 'archbishopric', 'archdiocese', 'area', 'arrondissement', 'bailiwick', 'bearings', 'belt', 'bench mark'],
    'district attorney': ['ag', 'da', 'kc', 'qc', 'ssc', 'us attorney', 'attorney general', 'civilian', 'corporation lawyer', 'court-appointed lawyer', 'criminal lawyer', 'defense counsel'],
    'distrust': ['pyrrhonism', 'apprehension', 'awake a doubt', 'be diffident', 'be doubtful', 'be dubious', 'be possessive', 'be skeptical', 'be uncertain', 'cageyness', 'call in question', 'caution'],
    'distrustful': ['pyrrhonic', 'agnostic', 'cagey', 'cautious', 'chary', 'cynical', 'disbelieving', 'doubtful', 'doubting', 'dubious', 'envious', 'from missouri'],
    'disturb': ['abash', 'addle', 'addle the wits', 'affect', 'afflict', 'aggravate', 'agitate', 'ail', 'alarm', 'annoy', 'badger', 'bait'],
    'disturbance': ['abashment', 'ado', 'affray', 'agitation', 'all-overs', 'angst', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat'],
    'disturbed': ['abashed', 'abroad', 'adrift', 'afflicted', 'aggravated', 'agitated', 'all-overish', 'amiss', 'angry', 'annoyed', 'anxious', 'anxioused up'],
    'disturbing': ['aggravating', 'agitating', 'alarming', 'annoying', 'awkward', 'baffling', 'bewildering', 'bothering', 'bothersome', 'breathtaking', 'chafing', 'charged'],
    'disunion': ['abstraction', 'alienation', 'antagonism', 'argumentation', 'breach', 'breach of friendship', 'break', 'clashing', 'cleavage', 'cleft', 'conflict', 'contention'],
    'disunite': ['abrupt', 'aggravate', 'alien', 'alienate', 'cast off', 'cast out', 'come between', 'cut adrift', 'cut off', 'cut out', 'delete', 'depart'],
    'disunited': ['alienated', 'detached', 'disaffected', 'disarticulated', 'disconnected', 'disengaged', 'disjoined', 'disjoint', 'disjointed', 'disjunct', 'dislocated', 'dispersed'],
    'disuse': ['abandonment', 'abjure', 'absentation', 'antiquation', 'casting away', 'cessation', 'come off', 'cut out', 'desist', 'desuetude', 'discontinue', 'drop'],
    'disused': ['abandoned', 'abjured', 'antiquated', 'antique', 'archaic', 'castaway', 'dated', 'dead', 'derelict', 'deserted', 'discarded', 'discontinued'],
    'ditch': ['abandon', 'abri', 'abysm', 'abyss', 'adit', 'alight', 'approach trench', 'aqueduct', 'arch dam', 'arroyo', 'backstop', 'bamboo curtain'],
    'ditheism': ['acosmism', 'allotheism', 'anthropolatry', 'anthropomorphism', 'anthropotheism', 'autotheism', 'cosmotheism', 'deism', 'dualism', 'dyotheism', 'henotheism', 'hylotheism'],
    'dither': ['ache', 'aching', 'agitation', 'all-overs', 'alternate', 'babble', 'back and fill', 'be cold', 'be stupid', 'blab', 'blabber', 'blather'],
    'ditto': ['doppelganger', 'photostat', 'xerox', 'accord', 'act like', 'actual thing', 'affect', 'afresh', 'again', 'agree', 'agree in opinion', 'agree with'],
    'ditty': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'alba', 'ana', 'anthem', 'art song', 'aubade', 'ballad', 'ballade'],
    'diuretic': ['abstergent', 'aperient', 'carminative', 'cathartic', 'cleaner', 'cleaning', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing', 'cleansing cream', 'cold cream'],
    'diurnal': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'circadian', 'daily', 'daytime', 'decennial'],
    'diva': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso profundo', 'blues singer'],
    'divagate': ['angle', 'angle off', 'bat around', 'be absent', 'bear off', 'bend', 'bias', 'branch off', 'bum', 'change the bearing', 'count ties', 'crook'],
    'divan': ['british cabinet', 'sanhedrin', 'us cabinet', 'advisory body', 'advisory council', 'assembly', 'association', 'bench', 'board', 'body of advisers', 'borough council', 'brain trust'],
    'divaricate': ['aberrate', 'be distinct', 'be distinguished', 'bear off', 'bend', 'bifurcate', 'branch', 'branch off', 'branch out', 'break up', 'broach', 'capricious'],
    'dive': ['abate', 'ablate', 'acrobatics', 'aerobatics', 'alehouse', 'bagnio', 'banking', 'bar', 'barrel house', 'barroom', 'bate', 'bathe'],
    'dive into': ['attack', 'begin', 'blast away', 'blast off', 'commence', 'dive in', 'enter on', 'enter upon', 'fall to', 'get busy', 'get cracking', 'get going'],
    'diver': ['bather', 'bathing beauty', 'bathing girl', 'cannon', 'cutpurse', 'deep-sea diver', 'dip', 'free diver', 'frogman', 'jumper', 'mermaid', 'merman'],
    'diverge': ['aberrate', 'agree to disagree', 'alter', 'ameliorate', 'angle', 'angle off', 'be changed', 'be converted into', 'be distinct', 'be distinguished', 'be renewed', 'bear off'],
    'divergence': ['aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'aesthetic distance', 'alienation', 'alteration'],
    'divergent': ['aberrant', 'abnormal', 'altered', 'amorphous', 'anomalistic', 'anomalous', 'antagonistic', 'antipathetic', 'antithetical', 'apart', 'assorted', 'asunder'],
    'divers': ['assorted', 'at odds', 'at variance', 'contrary', 'contrasted', 'contrasting', 'departing', 'deviating', 'deviative', 'different', 'differentiated', 'differing'],
    'diverse': ['assorted', 'at odds', 'at variance', 'contradictory', 'contrary', 'contrasted', 'contrasting', 'contrastive', 'counter', 'departing', 'deviating', 'deviative'],
    'diversification': ['proteus', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'allotropism', 'allotropy', 'alteration', 'amelioration', 'analysis', 'anatomization', 'apostasy'],
    'diversified': ['assorted', 'at odds', 'at variance', 'capricious', 'changeable', 'changing', 'choppy', 'contrary', 'contrasted', 'contrasting', 'departing', 'deviating'],
    'diversify': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'analyze', 'anatomize', 'atomize', 'be changed', 'be converted into', 'be renewed', 'better'],
    'diversion': ['aberrancy', 'aberration', 'about-face', 'abuse', 'abuse of office', 'accommodation', 'adaptation', 'adjustment', 'aerial tactics', 'aggravated assault', 'aggression', 'airborne tactics'],
    'diversity': ['proteus', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'agreement to disagree', 'alienation', 'allotropism', 'allotropy', 'alteration', 'amelioration', 'antagonism'],
    'divert': ['absorb', 'abstract', 'abuse', 'alter', 'amuse', 'avert', 'befoul', 'beguile', 'bend', 'bias', 'blunt', 'call away'],
    'divertissement': ['act', 'afterpiece', 'amusement', 'bit', 'capriccio', 'caprice', 'chaser', 'curtain', 'curtain call', 'curtain raiser', 'dissipation', 'distraction'],
    'divest': ['abridge', 'bankrupt', 'bare', 'bereave', 'bleed', 'bleed white', 'curtail', 'cut off', 'denudate', 'denude', 'deplume', 'deprive'],
    'divested': ['bared', 'bereaved', 'bereaved of', 'bereft', 'cut off', 'denudated', 'denuded', 'deprived of', 'exposed', 'lacking', 'laid bare', 'minus'],
    'divestment': ['abridgment', 'bereavement', 'cost', 'curtailment', 'damage', 'dead loss', 'debit', 'denial', 'denudation', 'deprivation', 'deprivement', 'despoilment'],
    'divide': ['continental divide', 'great divide', 'aberrate', 'abrupt', 'add', 'aggravate', 'agree to differ', 'agree to disagree', 'algebraize', 'alienate', 'allocate', 'allot'],
    'divided': ['alienated', 'bifurcated', 'bisected', 'branched', 'branching', 'cleft', 'cloven', 'detached', 'dichotomous', 'dimidiate', 'disaffected', 'disarticulated'],
    'dividend': ['accrued dividends', 'accumulated dividends', 'allotment', 'allowance', 'avails', 'balance', 'big end', 'bigger half', 'bit', 'bite', 'bonus', 'box office'],
    'divination': ['alchemy', 'astrodiagnosis', 'astrology', 'astromancy', 'augury', 'bewitchery', 'charm', 'clairvoyance', 'crystal ball', 'crystal gazing', 'divining', 'enchantment'],
    'divinatory': ['anticipant', 'anticipatory', 'apocalyptic', 'augural', 'auguring', 'clairvoyant', 'farseeing', 'farsighted', 'fatidic', 'forecasting', 'forehanded', 'foreknowing'],
    'divine': ['christlike', 'christly', 'dd', 'doctor of divinity', 'elysian', 'holy joe', 'mariological', 'abbe', 'ace', 'admirable', 'angelic', 'answer'],
    'divine right': ['absolute power', 'absolutism', 'appurtenance', 'authority', 'birthright', 'claim', 'competence', 'competency', 'conjugal right', 'constituted authority', 'delegated authority', 'demand'],
    'diviner': ['cassandra', 'comus', 'druid', 'faust', 'astrologer', 'augur', 'calamity howler', 'conjurer', 'crystal gazer', 'diabolist', 'divinator', 'divineress'],
    'diving': ['australian crawl', 'acrobatics', 'aerobatics', 'aquaplaning', 'aquatics', 'backstroke', 'balneation', 'banking', 'bathe', 'bathing', 'breaststroke', 'butterfly'],
    'divinity': ['buddhology', 'fatherhood', 'mariolatry', 'mariology', 'mercersburg theology', 'apologetics', 'canonics', 'crisis theology', 'dea', 'deity', 'deus', 'deva'],
    'division': ['australian ballot', 'hare system', 'jim crow', 'kp', 'naval construction battalion', 'rn', 'royal navy', 'seabees', 'usn', 'united states navy', 'aberration', 'abstraction'],
    'divisional': ['categorical', 'characteristic', 'classificational', 'classificatory', 'defining', 'denominative', 'differential', 'distinctive', 'divisionary', 'ordinal', 'particular', 'peculiar'],
    'divisive': ['aggressive', 'bellicose', 'belligerent', 'bickering', 'combative', 'disputatious', 'eristic', 'factional', 'factious', 'irascible', 'irritable', 'litigious'],
    'divorce': ['abrupt', 'abstraction', 'alienate', 'alienation', 'annul', 'break up', 'cancel', 'cast off', 'cast out', 'cut adrift', 'cut off', 'cut out'],
    'divorced': ['alienated', 'detached', 'disarticulated', 'disconnected', 'disengaged', 'disjoined', 'disjoint', 'disjointed', 'disjunct', 'dislocated', 'dispersed', 'disunited'],
    'divulge': ['affect', 'air', 'betoken', 'betray', 'brandish', 'break it to', 'break the news', 'breathe', 'bring forth', 'bring forward', 'bring into view', 'bring out'],
    'divulgence': ['babbling', 'betrayal', 'blabbering', 'blabbing', 'communication leak', 'dead giveaway', 'divulgation', 'divulgement', 'divulging', 'evulgation', 'giveaway', 'indiscretion'],
    'divvy up': ['apportion', 'be partners in', 'carve', 'carve up', 'cooperate', 'cut', 'cut up', 'district', 'divide', 'divide into shares', 'divide up', 'divide with'],
    'dixie': ['dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'middle west', 'new england', 'north', 'north central region', 'northeast', 'northwest', 'pacific northwest'],
    'dizen': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'color', 'dandify', 'deck', 'deck out', 'decorate', 'doll up'],
    'dizziness': ['abscess', 'addleheadedness', 'addlepatedness', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy'],
    'dizzy': ['addle', 'addlebrained', 'addled', 'addleheaded', 'addlepated', 'adrift', 'afloat', 'alternating', 'amorphous', 'apish', 'asinine', 'babbling'],
    'dna': ['altmann theory', 'dna double helix', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory', 'allele'],
    'do': ['i beg you', 'mardi gras', 'saturnalia', 'accompany', 'accomplish', 'achieve', 'acquit', 'act', 'act a part', 'act as', 'act like', 'act out'],
    'do away with': ['abolish', 'abrogate', 'annihilate', 'annul', 'bereave of life', 'cancel', 'carry away', 'carry off', 'cast off', 'chloroform', 'countermand', 'counterorder'],
    'do business': ['barter', 'be employed', 'buy and sell', 'carry on business', 'change', 'deal', 'exchange', 'follow a trade', 'give in exchange', 'have a job', 'horse-trade', 'interchange'],
    'do in': ['ko', 'assassinate', 'bankrupt', 'beat', 'beat all hollow', 'beat hollow', 'beguile of', 'best', 'bilk', 'blast', 'blot out', 'bump off'],
    'do justice to': ['abide by', 'account for', 'act up to', 'adhere to', 'attend to', 'banquet', 'be fair', 'be faithful to', 'be just', 'bend over backwards', 'clear', 'comply with'],
    'do nothing': ['be a sideliner', 'be conservative', 'be still', 'bone-lazy', 'bum', 'bum around', 'cadging', 'clock watcher', 'coast', 'contemplative', 'dallier', 'dawdle'],
    'do over': ['assimilate to', 'become', 'bring to', 'change', 'change into', 'change over', 'come again', 'convert', 'copy', 'ditto', 'do a repeat', 'do again'],
    'do the trick': ['accomplish', 'achieve', 'advance', 'advantage', 'answer', 'attain', 'avail', 'be handy', 'be of use', 'be right', 'befit', 'befitting'],
    'do time': ['alternate', 'be imprisoned', 'cover', 'do a hitch', 'do a stint', 'do a tour', 'enlist', 'fill in for', 'have a go', 'have tenure', 'hold office', 'keep a watch'],
    'do without': ['abandon', 'abjure', 'abstain', 'abstain from', 'avoid', 'cede', 'disgorge', 'dispense with', 'dispose of', 'drop', 'dump', 'eschew'],
    'dobbin': ['houyhnhnm', 'brood mare', 'charger', 'colt', 'courser', 'critter', 'entire', 'entire horse', 'equine', 'filly', 'foal', 'gelding'],
    'docile': ['acquiescent', 'adaptable', 'agreeable', 'alacritous', 'amenable', 'apt', 'ardent', 'biddable', 'bright', 'clever', 'compliant', 'consenting'],
    'dock': ['abbreviate', 'abridge', 'abscind', 'abstract', 'acting area', 'alight', 'amputate', 'anchor', 'anchorage', 'anchorage ground', 'annihilate', 'apron'],
    'dockage': ['admission', 'admission fee', 'anchorage', 'anchorage ground', 'basin', 'berth', 'breakwater', 'brokerage', 'bulkhead', 'carfare', 'cellarage', 'charge'],
    'docked': ['spartan', 'abbreviated', 'abridged', 'abstracted', 'aposiopestic', 'bobbed', 'brief', 'brusque', 'butchered', 'capsule', 'capsulized', 'castrated'],
    'docket': ['domesday book', 'account book', 'address book', 'adversaria', 'agenda', 'aide-memoire', 'album', 'annotation', 'annual', 'appointment calendar', 'appointment schedule', 'balance'],
    'docking': ['earth insertion', 'lem', 'lm', 'apogee', 'attitude-control rocket', 'ballistic capsule', 'burn', 'capsule', 'debarkation', 'deep-space ship', 'disembarkation', 'disembarkment'],
    'dockyard': ['anchorage', 'anchorage ground', 'armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'basin', 'berth', 'bindery', 'boatyard', 'boilery'],
    'doctor': ['doctor of medicine', 'gp', 'md', 'md', 'abecedarian', 'abet', 'adulterate', 'aid', 'allopath', 'allopathist', 'alter', 'assist'],
    'doctrinaire': ['antiblack', 'armchair authority', 'authoritarian', 'authoritative', 'biased', 'bigot', 'bigoted', 'bullheaded', 'chauvinist', 'chauvinistic', 'colored', 'conceited'],
    'doctrine': ['athanasian creed', 'catechism', 'nicene creed', 'a belief', 'article of faith', 'articles of faith', 'articles of religion', 'axiom', 'basic', 'belief', 'canon', 'concept'],
    'document': ['adduce', 'affirm', 'anatomize', 'archives', 'article', 'atomize', 'attest', 'authenticate', 'autograph', 'back', 'back up', 'bear out'],
    'documentary': ['cinemascope', 'cinerama', 'technicolor', 'western', 'absolute', 'actual', 'adducible', 'admissible', 'animated cartoon', 'archival', 'ascertained', 'attestative'],
    'documentation': ['account', 'affirmation', 'annals', 'attestation', 'authentication', 'backing', 'backing up', 'basis for belief', 'bearing out', 'body of evidence', 'bolstering', 'buttressing'],
    'documented': ['absolute', 'adducible', 'admissible', 'attestative', 'attestive', 'authentic', 'based on', 'booked', 'certain', 'circumstantial', 'conclusive', 'convincing'],
    'dodder': ['age', 'cheat the undertaker', 'cower', 'decline', 'fade', 'fail', 'get along', 'get on', 'grow old', 'halt', 'limp', 'quiver'],
    'doddering': ['aged', 'anile', 'childish', 'childlike', 'crabbed', 'debilitated', 'decrepit', 'dilapidated', 'doddered', 'doddery', 'doited', 'doting'],
    'dodge': ['about the bush', 'action', 'ad hoc measure', 'answer', 'around the bush', 'art', 'artful dodge', 'artifice', 'avoid', 'avoidance', 'avoiding reaction', 'back and fill'],
    'dodger': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'philadelphia lawyer', 'yankee horse trader', 'actor', 'aegis', 'arm guard', 'ash cake'],
    'dodging': ['bickering', 'boggling', 'captiousness', 'caviling', 'chicane', 'chicanery', 'clock-watching', 'ducking', 'equivocation', 'evasion', 'fencing', 'goofing off'],
    'dodo': ['methuselah', 'antediluvian', 'antique', 'back number', 'boob', 'conservative', 'dad', 'dimwit', 'dolt', 'dummy', 'elder', 'fogy'],
    'doe': ['belgian hare', 'cape elk', 'partlet', 'virginia deer', 'antelope', 'biddy', 'billy', 'billy goat', 'bitch', 'bossy', 'brood mare', 'buck'],
    'doer': ['activist', 'ball of fire', 'beaver', 'big-time operator', 'bustler', 'busy bee', 'eager beaver', 'enthusiast', 'go-getter', 'human dynamo', 'hustler', 'live wire'],
    'doff': ['cast off', 'detach', 'disengage', 'douse', 'drop', 'free', 'liberate', 'loose', 'loosen', 'put off', 'release', 'remove'],
    'dog': ['afghan hound', 'alaskan malamute', 'bedlington terrier', 'border terrier', 'boston bull', 'cairn terrier', 'chihuahua', 'dalmatian', 'doberman pinscher', 'english toy spaniel', 'eskimo dog', 'gordon setter'],
    'dog days': ['broiling sun', 'canicular days', 'fair weather', 'good old summertime', 'growing season', 'heat wave', 'high summer', 'hot wave', 'hot weather', 'humid weather', 'midday sun', 'midsummer'],
    'dog eared': ['auriculate', 'bare', 'big-eared', 'creased', 'crimped', 'crop-eared', 'deep-worn', 'doubled', 'ear-minded', 'eared', 'flexible', 'flop-eared'],
    'dog tag': ['id card', 'badge', 'calligram', 'calling card', 'card', 'countermark', 'countersign', 'credentials', 'identification', 'identification badge', 'identification tag', 'initials'],
    'dog tired': ['all in', 'beat', 'beat up', 'beaten', 'bone-weary', 'bushed', 'dead', 'dead-and-alive', 'dead-tired', 'deadbeat', 'dog-weary', 'done'],
    'dog-eat-dog': ['bowelless', 'cruel', 'flinty', 'hard', 'harsh', 'heartless', 'inclement', 'inexorable', 'merciless', 'pitiless', 'relentless', 'remorseless'],
    'dogface': ['zouave', 'bersagliere', 'carabineer', 'chasseur', 'doughfoot', 'expert rifleman', 'foot soldier', 'footslogger', 'fusileer', 'grenadier', 'grunt', 'infantryman'],
    'dogged': ['adamant', 'assiduous', 'badgered', 'baited', 'balking', 'balky', 'bedeviled', 'beset', 'bigoted', 'bugged', 'bulldogged', 'bulletheaded'],
    'doggedly': ['assiduously', 'bullheadedly', 'devotedly', 'diligently', 'faithfully', 'headstrongly', 'indefatigably', 'industriously', 'insistently', 'loyally', 'obstinately', 'patiently'],
    'doggerel': ['doric', 'hudibrastic verse', 'amphigory', 'barbaric', 'barbarous', 'burlesque', 'cacophonous', 'caricatural', 'clumsy', 'coarse', 'crambo', 'crambo clink'],
    'dogging': ['aggravation', 'annoyance', 'bad news', 'bedevilment', 'bore', 'bother', 'botheration', 'bothersomeness', 'chase', 'chasing', 'crashing bore', 'devilment'],
    'dogie': ['arab', 'brahman', 'indian buffalo', 'aurochs', 'beach bum', 'beachcomber', 'beef', 'beef cattle', 'beeves', 'beggar', 'birdling', 'bison'],
    'dogleg': ['aberrancy', 'aberration', 'angle', 'apex', 'bend', 'bias', 'bifurcation', 'bight', 'branching off', 'cant', 'chevron', 'circuitousness'],
    'dogma': ['athanasian creed', 'catechism', 'nicene creed', 'a belief', 'article of faith', 'articles of faith', 'articles of religion', 'axiom', 'belief', 'canon', 'conviction', 'credenda'],
    'dogmatic': ['sabbatarian', 'a priori', 'antiblack', 'arbitrary', 'arrogant', 'assertive', 'assured', 'authoritarian', 'authoritative', 'balking', 'balky', 'believing'],
    'dogmatics': ['buddhology', 'mariolatry', 'mariology', 'mercersburg theology', 'apologetics', 'canonics', 'crisis theology', 'dialogical theology', 'divinity', 'doctrinalism', 'doctrinism', 'eschatology'],
    'dogmatism': ['sabbatarianism', 'balkiness', 'bibliolatry', 'bigotry', 'blindness', 'bullheadedness', 'deafness', 'determination', 'doggedness', 'dogmaticalness', 'evangelicalism', 'fanaticism'],
    'dogmatist': ['ass', 'bigot', 'bitter-ender', 'bullethead', 'chauvinist', 'diehard', 'doctrinaire', 'dogmatizer', 'donkey', 'fanatic', 'hardnose', 'illiberal'],
    'dogtrot': ['amble', 'andante', 'burst', 'burst of speed', 'canter', 'claudicate', 'claudication', 'crawl', 'creep', 'dash', 'dead march', 'dead run'],
    'dogwatch': ['anchor watch', 'bit', 'day shift', 'full time', 'graveyard shift', 'half time', 'lobster trick', 'night shift', 'overtime', 'part time', 'relay', 'shift'],
    'dohickey': ['affair', 'article', 'artifact', 'dingus', 'dofunny', 'dojigger', 'dojiggy', 'domajig', 'domajigger', 'doodad', 'dowhacky', 'eppes'],
    'doing': ['accidental', 'accompanying', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'acting', 'action', 'actions', 'activism', 'activity'],
    'doings': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'actions', 'activeness', 'activism', 'activity', 'acts', 'address'],
    'dojigger': ['affair', 'article', 'artifact', 'dingus', 'dofunny', 'dohickey', 'dojiggy', 'domajig', 'domajigger', 'doodad', 'dowhacky', 'eppes'],
    'dolce': ['a cappella', 'abbandono', 'accrescendo', 'affettuoso', 'agilmente', 'agitato', 'amabile', 'amoroso', 'appassionatamente', 'appassionato', 'brillante', 'capriccioso'],
    'doldrums': ['anticyclone', 'antitrades', 'apathy', 'blahs', 'blue devils', 'blues', 'boredom', 'calm', 'cold storage', 'dead calm', 'deathlike calm', 'dejection'],
    'dole': ['accord', 'ace', 'adjunct', 'administer', 'administration', 'adversity', 'affliction', 'afford', 'aid', 'alimony', 'allocate', 'allocation'],
    'doleful': ['affecting', 'afflicted', 'aggrieved', 'anguished', 'blue', 'careworn', 'cast down', 'cheerless', 'crestfallen', 'dejected', 'depressed', 'depressing'],
    'dolittle': ['bum', 'clock watcher', 'dallier', 'dawdle', 'dawdler', 'diddler', 'dillydallier', 'do-nothing', 'doodler', 'faineant', 'gentleman of leisure', 'goldbrick'],
    'doll': ['elzevir', 'jane', 'agate', 'angel', 'babe', 'baby', 'baby-doll', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble'],
    'doll up': ['adorn', 'array', 'beautify', 'become one', 'bedeck', 'bedizen', 'blazon', 'color', 'dandify', 'deck', 'deck out', 'decorate'],
    'dollar': ['c-note', 'deutschmark', 'g-note', 'mark', 'reichsmark', 'afghani', 'anna', 'baht', 'bawbee', 'bill', 'bone', 'buck'],
    'dollhouse': ['agate', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble', 'blocks', 'checkerboard', 'chessboard', 'club', 'cockhorse', 'cricket bat'],
    'dollop': ['bit', 'butt', 'chip', 'chunk', 'clip', 'clipping', 'collop', 'crumb', 'cut', 'cutting', 'dram', 'drop'],
    'dolly': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'dolmen': ['arch', 'barrow', 'beehive tomb', 'bone house', 'boundary stone', 'box grave', 'brass', 'burial', 'burial chamber', 'burial mound', 'bust', 'cairn'],
    'dolor': ['schmerz', 'ache', 'aches and pains', 'aching', 'agony', 'blow', 'cramp', 'cut', 'discomfort', 'distress', 'grief', 'hurt'],
    'dolorous': ['affecting', 'afflicted', 'afflictive', 'aggrieved', 'anguished', 'bitter', 'bleak', 'calamitous', 'careworn', 'cheerless', 'comfortless', 'deplorable'],
    'dolphin': ['chiroptera', 'lagomorpha', 'loch ness monster', 'primates', 'rodentia', 'alevin', 'benthon', 'benthos', 'cetacean', 'fingerling', 'fish', 'fry'],
    'dolt': ['boeotian', 'ass', 'birdbrain', 'block', 'blockhead', 'blunderer', 'blunderhead', 'bonehead', 'boob', 'booby', 'boor', 'botcher'],
    'doltish': ['boeotian', 'asinine', 'beef-brained', 'beef-witted', 'beetleheaded', 'blockheaded', 'blockish', 'bovine', 'chumpish', 'cloddish', 'cowish', 'crass'],
    'domain': ['academic discipline', 'academic specialty', 'acres', 'ally', 'ambit', 'animal kingdom', 'applied science', 'archduchy', 'archdukedom', 'area', 'arena', 'art'],
    'dome': ['antenna tower', 'apse', 'arcade', 'arcature', 'arch', 'arched roof', 'archway', 'barbican', 'bean', 'belfry', 'bell tower', 'bend'],
    'domestic': ['anchoritic', 'autochthonous', 'cloistered', 'domal', 'domestic servant', 'domesticated', 'domiciliary', 'drudge', 'eremitic', 'family', 'help', 'hermitic'],
    'domestic science': ['baking', 'barbecuing', 'basting', 'boiling', 'braising', 'brewing', 'broil', 'broiling', 'catering', 'cookery', 'cooking', 'cuisine'],
    'domesticate': ['acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'anchor', 'billet at', 'bivouac', 'break', 'break in', 'break to harness'],
    'domesticated': ['broken', 'brought low', 'chastened', 'crushed', 'domestic', 'dovelike', 'gentle', 'housebroke', 'housebroken', 'humble', 'humbled', 'humiliated'],
    'domicile': ['abide', 'abiding place', 'abode', 'accommodations', 'address', 'bed', 'berth', 'bestow', 'billet', 'board', 'bunk', 'cantonment'],
    'dominance': ['ascendance', 'ascendancy', 'authority', 'balance of power', 'charisma', 'charm', 'clout', 'consequence', 'control', 'credit', 'dominancy', 'domination'],
    'dominant': ['absolute', 'accidental', 'all-absorbing', 'arch', 'ascendant', 'assertive', 'at the head', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'average'],
    'dominate': ['be in', 'be in force', 'be the rage', 'be the rule', 'be the thing', 'bestraddle', 'bestride', 'carry authority', 'clear', 'command', 'control', 'crack the whip'],
    'domination': ['absolutism', 'argumentum baculinum', 'ascendance', 'ascendancy', 'authority', 'balance of power', 'big stick', 'bond service', 'bondage', 'captivity', 'charisma', 'charm'],
    'domineer': ['beat down', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'clamp down on', 'coerce', 'compel', 'cow', 'daunt', 'despotize'],
    'domineering': ['olympian detachment', 'olympian loftiness', 'absolute', 'absolutist', 'absolutistic', 'arbitrariness', 'arbitrary', 'argumentum baculinum', 'aristocratic', 'arrogance', 'arrogant', 'arrogantness'],
    'dominican': ['augustinian', 'augustinian hermit', 'austin friar', 'benedictine', 'bernardine', 'black friar', 'black monk', 'bonhomme', 'brigittine', 'capuchin', 'carmelite', 'carthusian'],
    'dominion': ['acme', 'administration', 'ally', 'ambit', 'antecedence', 'antecedency', 'anteposition', 'anteriority', 'archduchy', 'archdukedom', 'area', 'arena'],
    'don': ['herr', 'master', 'mister', 'abecedarian', 'assume', 'bwana', 'certified teacher', 'change', 'docent', 'doctor', 'dominie', 'draw on'],
    'don juan': ['artful dodger', 'casanova', 'circe', 'lorelei', 'lothario', 'machiavel', 'machiavelli', 'machiavellian', 'parthenope', 'romeo', 'siren', 'actor'],
    'don quixote': ['bayard', 'gawain', 'lancelot', 'quixote', 'ritter', 'sidney', 'sir galahad', 'bachelor', 'banneret', 'baronet', 'caballero', 'cavalier'],
    'donar': ['aesir', 'balder', 'bor', 'bori', 'bragi', 'forseti', 'frey', 'freya', 'freyja', 'freyr', 'frigg', 'frigga'],
    'donate': ['accommodate', 'accord', 'administer', 'afford', 'allot', 'allow', 'award', 'bequeath', 'bestow', 'bestow on', 'chip in', 'clothe'],
    'donation': ['accommodation', 'accordance', 'aid', 'allotment', 'allowance', 'alms', 'alms fee', 'appropriation', 'assistance', 'award', 'awarding', 'benefaction'],
    'done': ['sol', 'agreed', 'all bets off', 'all in', 'all off', 'all over', 'all up', 'amen', 'at an end', 'ausgespielt', 'be it so', 'beat'],
    'done for': ['sol', 'all bets off', 'all gone', 'all off', 'all over', 'all up', 'all up with', 'annihilated', 'asleep', 'asleep in jesus', 'at an end', 'at rest'],
    'done with': ['sol', 'abandoned', 'abjured', 'all bets off', 'all off', 'all over', 'all up', 'antiquated', 'antique', 'archaic', 'at an end', 'canceled'],
    'dong': ['chime', 'chink', 'clang', 'clangor', 'clank', 'clink', 'ding', 'dingdong', 'gong', 'jangle', 'jingle', 'jinglejangle'],
    'donkey': ['boeotian', 'rocky mountain canary', 'ass', 'bigot', 'bitter-ender', 'block', 'bullethead', 'burro', 'clod', 'cuddy', 'dickey', 'diehard'],
    'donna': ['eve', 'frau', 'fraulein', 'miss', 'mistress', 'mlle', 'mme', 'mmes', 'dame', 'daughter of eve', 'distaff', 'domina'],
    'donnish': ['academic', 'bibliophagic', 'bluestocking', 'book-fed', 'book-learned', 'book-loving', 'book-minded', 'book-read', 'book-wise', 'bookish', 'booky', 'devoted to studies'],
    'donnybrook': ['bedlam let loose', 'ado', 'affray', 'altercation', 'argument', 'bedlam', 'bicker', 'blast', 'blood feud', 'bobbery', 'bother', 'brawl'],
    'donor': ['maecenas', 'santa claus', 'almoner', 'almsgiver', 'angel', 'assignor', 'awarder', 'backer', 'benefactor', 'benefactress', 'bestower', 'caterer'],
    'doodad': ['affair', 'article', 'artifact', 'business', 'dingus', 'dofunny', 'dohickey', 'dojigger', 'dojiggy', 'domajig', 'domajigger', 'dowhacky'],
    'doodle': ['ass', 'bagpipe', 'beat', 'beguile the time', 'bilk', 'black and white', 'blow', 'blow a horn', 'born fool', 'brouillon', 'buffoon', 'bugle'],
    'doom': ['day of judgment', 'friday', 'friday the thirteenth', 'judgment day', 'abuse', 'act on', 'action', 'afflict', 'aggrieve', 'anathematize', 'anathematizing', 'annihilation'],
    'doomed': ['accursed', 'appointed', 'bewitched', 'condemned', 'cursed', 'damned', 'destined', 'devoted', 'fatal', 'fated', 'fateful', 'foredoomed'],
    'doomful': ['apocalyptic', 'bad', 'badly off', 'baleful', 'baneful', 'black', 'bodeful', 'boding', 'calamitous', 'cataclysmal', 'cataclysmic', 'catastrophic'],
    'door': ['french door', 'access', 'adit', 'admission', 'admittance', 'archway', 'avenue', 'back door', 'barway', 'blowhole', 'bulkhead', 'carriage entrance'],
    'doorbell': ['bell', 'chimes', 'church bell', 'clapper', 'cowbell', 'dinner bell', 'dinner gong', 'fire bell', 'gong', 'gong bell', 'hand bell', 'jingle bell'],
    'doorjamb': ['french door', 'samson post', 'archway', 'back door', 'baluster', 'balustrade', 'banister', 'barway', 'bulkhead', 'carriage entrance', 'cellar door', 'cellarway'],
    'doorkeeper': ['acolyte', 'acolytus', 'cerberus', 'concierge', 'deacon', 'diaconus', 'doorman', 'exorcist', 'exorcista', 'gatekeeper', 'holy orders', 'janitor'],
    'doormat': ['milquetoast', 'baby', 'big baby', 'carpet', 'carpeting', 'chicken', 'crybaby', 'drop cloth', 'duckboards', 'dull tool', 'floorboards', 'flooring'],
    'doorpost': ['french door', 'samson post', 'archway', 'back door', 'baluster', 'balustrade', 'banister', 'barway', 'bulkhead', 'carriage entrance', 'cellar door', 'cellarway'],
    'doorstop': ['arrest', 'bearing rein', 'bit', 'brake', 'chain', 'check', 'checkrein', 'chock', 'clog', 'countercheck', 'curb', 'curb bit'],
    'doorway': ['french door', 'archway', 'back door', 'barway', 'bulkhead', 'carriage entrance', 'cellar door', 'cellarway', 'door', 'doorjamb', 'doorpost', 'entrance'],
    'dope': ['boeotian', 'ko', 'mickey finn', 'account', 'acquaintance', 'add', 'addictive drug', 'alcohol', 'algebraize', 'analgesic', 'anesthetic', 'anesthetize'],
    'dope fiend': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'doper', 'drug abuser', 'drug addict'],
    'dope out': ['arrange', 'blueprint', 'cast', 'chart', 'cipher', 'clear up', 'collect', 'conclude', 'decipher', 'deduce', 'deduct', 'derive'],
    'doped': ['anesthetized', 'asleep', 'cataleptic', 'catatonic', 'cold', 'comatose', 'dead', 'dozy', 'dreamy', 'drowsy', 'drugged', 'drugged with sleep'],
    'dopey': ['abeyant', 'apathetic', 'bedazzled', 'benumbed', 'blase', 'blunt', 'blunt-witted', 'bored', 'cataleptic', 'catatonic', 'comatose', 'dazed'],
    'doppelganger': ['actual thing', 'carbon copy', 'co-walker', 'copy', 'dead ringer', 'ditto', 'double', 'doubleganger', 'duplicate', 'equivalent', 'etheric double', 'exact counterpart'],
    'dorm': ['boardinghouse', 'dormitory', 'doss house', 'drowse', 'fleabag', 'flophouse', 'guest house', 'hospice', 'hostel', 'hostelry', 'hotel', 'inn'],
    'dormancy': ['a wise passiveness', 'abeyance', 'apathy', 'catalepsy', 'catatonia', 'cold storage', 'contemplation', 'contemplative life', 'deadliness', 'deathliness', 'delitescence', 'do-nothing policy'],
    'dormant': ['abeyant', 'apathetic', 'asleep', 'at rest', 'benumbed', 'between the lines', 'blase', 'bored', 'cataleptic', 'catatonic', 'comatose', 'concealed'],
    'dormer': ['bay', 'bay window', 'bow window', 'casement', 'casement window', 'fan window', 'fanlight', 'grille', 'lancet window', 'lantern', 'lattice', 'light'],
    'dormitory': ['bedchamber', 'bedroom', 'boardinghouse', 'boudoir', 'chamber', 'cubicle', 'cubiculum', 'dorm', 'doss house', 'fleabag', 'flophouse', 'guest house'],
    'dorsal': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'dose': ['french disease', 'spanish pox', 'vd', 'acquired syphilis', 'administer', 'amount', 'anoint', 'apply', 'bag', 'balanitis gangrenosa', 'bang', 'batch'],
    'doss': ['assembly-line housing', 'beauty sleep', 'bed', 'beddy-bye', 'bedstead', 'bedtime', 'billeting', 'blanket drill', 'bunk', 'bye-bye', 'couch', 'domiciliation'],
    'dossier': ['blank', 'chirograph', 'docket', 'document', 'file', 'form', 'holograph', 'instrument', 'legal document', 'legal instrument', 'legal paper', 'official document'],
    'dot': ['accent', 'accent mark', 'ace', 'appanage', 'atom', 'band', 'bar', 'bespangle', 'bespeckle', 'bespot', 'besprinkle', 'birthmark'],
    'dotage': ['advanced age', 'advanced years', 'age', 'age of retirement', 'an incurable disease', 'anility', 'blind faith', 'caducity', 'childishness', 'credulity', 'credulousness', 'debility'],
    'dotard': ['father time', 'methuselah', 'nestor', 'old paar', 'centenarian', 'elder', 'fogy', 'fuddy-duddy', 'gaffer', 'geezer', 'golden-ager', 'gramps'],
    'dote': ['adore', 'babble', 'be fond of', 'be insane', 'be stupid', 'blather', 'blither', 'burble', 'coddle', 'dither', 'drivel', 'drool'],
    'doting': ['affectionate', 'aging', 'apish', 'asinine', 'batty', 'befooled', 'beguiled', 'besotted', 'brainless', 'buffoonish', 'childish', 'childlike'],
    'dotted': ['bespangled', 'blotched', 'blotchy', 'dotty', 'dusted', 'flea-bitten', 'flecked', 'fleckered', 'frecked', 'freckled', 'freckly', 'macular'],
    'dotty': ['abnormal', 'absurd', 'anomalous', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'besotted', 'bespangled', 'blotched'],
    'double': ['doppelganger', 'janus-like', 'machiavellian', 'photostat', 'xerox', 'aberrancy', 'aberration', 'accelerate', 'act for', 'actual thing', 'agent', 'aggravate'],
    'double agent': ['benedict arnold', 'brutus', 'cia man', 'judas', 'judas iscariot', 'quisling', 'archtraitor', 'betrayer', 'cloak-and-dagger operative', 'cockatrice', 'conniver', 'conspirator'],
    'double check': ['audit', 'balance', 'balance the books', 'check', 'check and doublecheck', 'check out', 'check over', 'collate', 'confirm', 'cross-check', 'demonstrate', 'inventory'],
    'double cross': ['judas kiss', 'bamboozle', 'beguile', 'betray', 'betrayal', 'bluff', 'cajole', 'cheat on', 'circumvent', 'conjure', 'deceive', 'delude'],
    'double dealer': ['artful dodger', 'benedict arnold', 'brutus', 'casanova', 'don juan', 'judas', 'judas iscariot', 'machiavel', 'machiavelli', 'machiavellian', 'quisling', 'actor'],
    'double dealing': ['machiavellian', 'machiavellianism', 'ambidexterity', 'ambidextrous', 'artful', 'artifice', 'bad faith', 'chicane', 'chicanery', 'crafty', 'crooked', 'cunning'],
    'double dutch': ['aesopian language', 'babel', 'greek', 'argot', 'babble', 'cant', 'cipher', 'code', 'cryptogram', 'garble', 'gibberish', 'gift of tongues'],
    'double edged': ['acid', 'acidulous', 'acrid', 'acrimonious', 'acute', 'astringent', 'biting', 'bitter', 'caustic', 'cutting', 'edged', 'escharotic'],
    'double entendre': ['ambiguity', 'ambiguousness', 'amphibology', 'belly laugh', 'blue story', 'complexity of meaning', 'counterword', 'dirty joke', 'dirty story', 'double meaning', 'double reference', 'equivocacy'],
    'double header': ['bout', 'contest', 'decathlon', 'doubles', 'event', 'foursome', 'game', 'games of chance', 'go', 'match', 'meet', 'pentathlon'],
    'double meaning': ['ambiguity', 'ambiguousness', 'amphibology', 'complexity of meaning', 'double entendre', 'double reference', 'equivocacy', 'equivocality', 'equivocalness', 'equivocation', 'equivoque', 'irony'],
    'double personality': ['alcoholic', 'alternating personality', 'antisocial personality', 'catatonia', 'catatonic schizophrenia', 'dementia praecox', 'depersonalization', 'disconnection', 'disordered personality', 'dissociation', 'dissociation of personality', 'disturbed personality'],
    'double quick': ['acceleration', 'agile', 'amain', 'apace', 'at flank speed', 'at the double', 'breakneck', 'crowded', 'dashing', 'double march', 'double time', 'double-quick time'],
    'double take': ['ps', 'parthian shot', 'addendum', 'afterthought', 'appendix', 'back matter', 'bind', 'block', 'blockage', 'bureaucratic delay', 'chorus', 'coda'],
    'double talk': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'blabber', 'blather', 'bombast', 'claptrap', 'drivel', 'drool'],
    'double time': ['trinkgeld', 'acceleration', 'at the double', 'bonus', 'bounty', 'bribe', 'bundle', 'bustle', 'chase', 'consideration', 'crowd', 'crowded'],
    'doubled': ['creased', 'crimped', 'dog-eared', 'duplicated', 'echoed', 'flexible', 'flounced', 'fluted', 'foldable', 'folded', 'folding', 'gathered'],
    'doubles': ['bout', 'contest', 'decathlon', 'double-header', 'event', 'foursome', 'game', 'games of chance', 'go', 'match', 'meet', 'pentathlon'],
    'doublet': ['both', 'brace', 'cognate', 'couple', 'couplet', 'derivation', 'derivative', 'distich', 'double harness', 'duad', 'duet', 'duo'],
    'doublethink': ['janus', 'ambiguity', 'ambivalence', 'biformity', 'bifurcation', 'conjugation', 'dichotomy', 'doubleness', 'doubling', 'dualism', 'duality', 'duplexity'],
    'doubling': ['janus', 'ambiguity', 'ambivalence', 'biformity', 'bifurcation', 'bush', 'bushing', 'conduplication', 'conjugation', 'copying', 'crease', 'creasing'],
    'doubloon': ['coin', 'crown', 'double eagle', 'ducat', 'eagle', 'five-dollar gold piece', 'gold piece', 'guinea', 'half crown', 'half eagle', 'hard money', 'moidore'],
    'doubt': ['humism', 'pyrrhonism', 'agnosticism', 'agonize over', 'all-overs', 'anxiety', 'apprehension', 'apprehensiveness', 'awake a doubt', 'be at sea', 'be diffident', 'be doubtful'],
    'doubtful': ['humean', 'pyrrhonic', 'a bit thick', 'a bit thin', 'absurd', 'agnostic', 'ambiguous', 'amoral', 'arguable', 'at issue', 'beyond belief', 'borderline'],
    'doubting': ['pyrrhonic', 'agnostic', 'ambiguous', 'capricious', 'chancy', 'changeable', 'dicey', 'distrustful', 'doubtful', 'dubious', 'equivocal', 'erratic'],
    'doubtless': ['absolutely', 'admittedly', 'assumably', 'assured', 'believing', 'beyond doubt', 'beyond question', 'by all odds', 'certain', 'certainly', 'confident', 'convinced'],
    'doubtlessly': ['absolutely', 'admittedly', 'beyond doubt', 'beyond question', 'by all odds', 'definitely', 'dollars to doughnuts', 'doubtless', 'easily', 'in all likelihood', 'in all probability', 'incontestably'],
    'douche': ['finnish bath', 'japanese bath', 'russian bath', 'swedish bath', 'turkish bath', 'ablution', 'aerosol', 'asperge', 'aspergil', 'aspergillum', 'atomizer', 'baptize'],
    'dough': ['albumen', 'batter', 'blubber', 'blunt', 'bonnyclabber', 'boodle', 'brass', 'bread', 'breeze', 'bucks', 'butter', 'cabbage'],
    'doughboy': ['anzac', 'aussie', 'boche', 'fritz', 'gi', 'heinie', 'hun', 'jerry', 'johnny', 'kraut', 'tommy', 'tommy atkins'],
    'doughy': ['adhesive', 'amylaceous', 'ashen', 'ashy', 'baccate', 'blanched', 'clabbered', 'clammy', 'clayey', 'clotted', 'coagulated', 'colorless'],
    'dour': ['spartan', 'spartanic', 'adamant', 'adamantine', 'astringent', 'austere', 'authoritarian', 'beetle-browed', 'black', 'black-browed', 'bleak', 'cast-iron'],
    'douse': ['bang', 'baptize', 'bash', 'bat', 'belt', 'blow out', 'bop', 'bury', 'cast off', 'choke', 'crack', 'damp'],
    'dousing': ['baptism', 'burial', 'burning out', 'controlling', 'damping', 'dip', 'dipping', 'duck', 'ducking', 'dunking', 'dying', 'engulfment'],
    'dove': ['angel', 'avifauna', 'babe', 'baby bird', 'bird', 'bird of jove', 'bird of juno', 'bird of minerva', 'bird of night', 'bird of passage', 'bird of prey', 'birdie'],
    'dovelike': ['altricial', 'angelic', 'anserine', 'anserous', 'aquiline', 'avian', 'avicular', 'birdlike', 'birdy', 'blameless', 'broken', 'chastened'],
    'dovetail': ['accord', 'agree', 'ankle', 'answer to', 'articulate', 'articulation', 'assent', 'assort with', 'batten', 'batten down', 'be consistent', 'be of one'],
    'dovetailing': ['a propos', 'ad rem', 'adapted', 'applicable', 'apposite', 'appropriate', 'apropos', 'apt', 'becoming', 'befitting', 'felicitous', 'fit'],
    'dowager': ['eve', 'frau', 'abbess', 'beldam', 'chatelaine', 'crone', 'dame', 'daughter of eve', 'distaff', 'domina', 'donna', 'femme'],
    'dowdy': ['archaic', 'blowsy', 'bygone', 'dated', 'demode', 'down-at-heel', 'down-at-the-heels', 'drab', 'draggletailed', 'dull', 'frayed', 'frazzled'],
    'dower': ['ability', 'accouter', 'appanage', 'appoint', 'bless with', 'bump', 'caliber', 'capability', 'capacity', 'dot', 'dowry', 'endow'],
    'down': ['cod', 'vandyke', 'actively', 'adown', 'ailing', 'air', 'alkali flat', 'all up with', 'alluvial plain', 'anthill', 'backset', 'bad'],
    'down the drain': ['all gone', 'annihilated', 'consumed', 'dead', 'defunct', 'dissipated', 'done for', 'expired', 'extinct', 'gone', 'gone glimmering', 'gone to waste'],
    'down under': ['africa', 'america', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'east', 'eastern hemisphere', 'eurasia', 'europe', 'far east'],
    'down-and-out': ['ausgespielt', 'bankrupt', 'blasted', 'blighted', 'broken', 'desolated', 'destitute', 'destroyed', 'devastated', 'done for', 'done in', 'fallen'],
    'down-to-earth': ['earthy', 'hard', 'hard-boiled', 'hardheaded', 'matter', 'matter-of-fact', 'positivistic', 'practical', 'practical-minded', 'pragmatic', 'pragmatical', 'rational'],
    'downbeat': ['cassandra-like', 'cassandran', 'cassandrian', 'arsis', 'bar beat', 'beat', 'bout', 'circle', 'circuit', 'course', 'cycle', 'cynical'],
    'downcast': ['beating', 'bowed-down', 'cast down', 'dashed', 'debacle', 'debased', 'defeasance', 'dejected', 'depressed', 'despairing', 'despondent', 'desponding'],
    'downdraft': ['air current', 'crosscurrent', 'current', 'current of air', 'draft', 'fall wind', 'flow of air', 'following wind', 'head wind', 'indraft', 'inflow', 'inhalation'],
    'downer': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'schmerz', 'seconal', 'seconal pill'],
    'downfall': ['waterloo', 'atrophy', 'bane', 'beating', 'bouleversement', 'brash', 'breakdown', 'burst of rain', 'cascade', 'cataract', 'chute', 'cloudburst'],
    'downgrade': ['abase', 'abridge', 'adown', 'aslant', 'aslantwise', 'aslope', 'at a slant', 'atilt', 'atrophy', 'belittle', 'below', 'break'],
    'downhearted': ['blue', 'bowed-down', 'cast down', 'dashed', 'dejected', 'depressed', 'despairing', 'despondent', 'desponding', 'disconsolate', 'discouraged', 'disheartened'],
    'downhill': ['adown', 'aslant', 'aslantwise', 'aslope', 'at a slant', 'atilt', 'below', 'collapsing', 'deciduous', 'decline', 'declined', 'declining'],
    'downpour': ['affluence', 'afflux', 'affluxion', 'brash', 'burst of rain', 'cascade', 'cataract', 'chute', 'cloudburst', 'collapse', 'comedown', 'concourse'],
    'downright': ['a outrance', 'absolute', 'absolutely', 'admitting no exception', 'adown', 'all out', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'arrant', 'artless'],
    'downtime': ['break', 'breath', 'breather', 'breathing place', 'breathing space', 'breathing spell', 'breathing time', 'cigarette break', 'cocktail hour', 'coffee break', 'enforced respite', 'half time'],
    'downtown': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'barrio', 'black ghetto', 'blighted area', 'burghal'],
    'downtrodden': ['abject', 'abused', 'afflicted', 'beat', 'beaten', 'browbeaten', 'burdened', 'cowed', 'downtrod', 'ground down', 'henpecked', 'in leading strings'],
    'downturn': ['boom', 'bottoming out', 'business cycle', 'business fluctuations', 'bust', 'cascade', 'catabasis', 'cataract', 'chute', 'collapse', 'comedown', 'cooling off'],
    'downward': ['adown', 'ascending', 'axial', 'back', 'back-flowing', 'backward', 'below', 'collapsing', 'deciduous', 'declining', 'declivitous', 'decurrent'],
    'downward trend': ['cascade', 'cataract', 'chute', 'collapse', 'comedown', 'crash', 'debacle', 'debasement', 'decadence', 'decadency', 'declension', 'declination'],
    'downy': ['airy', 'artful', 'astute', 'attenuate', 'attenuated', 'bubbly', 'crafty', 'cunning', 'dainty', 'deep', 'delicate', 'ethereal'],
    'dowry': ['ability', 'appanage', 'bump', 'caliber', 'capability', 'capacity', 'dot', 'dower', 'endowment', 'equipment', 'faculty', 'flair'],
    'doxology': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'negro spiritual', 'nunc dimittis', 'te deum', 'trisagion'],
    'doxy': ['chippy', 'concubine', 'floozy', 'girl friend', 'grisette', 'inamorata', 'kept mistress', 'kept woman', 'lover', 'mistress', 'nymph', 'nymphet'],
    'doyen': ['artist', 'authority', 'bell cow', 'bellwether', 'chief', 'dean', 'doyenne', 'elder', 'eldest', 'father', 'first-born', 'firstling'],
    'doze': ['beauty sleep', 'beddy-bye', 'bedtime', 'blanket drill', 'bye-bye', 'catnap', 'dorm', 'doze off', 'dozy', 'dreamland', 'drop off', 'drowse'],
    'dozen': ['sexagesima', 'boxcar', 'boxcars', 'duodecimo', 'eighty', 'eleven', 'fifteen', 'fifty', 'five and twenty', 'fortnight', 'forty', 'four and twenty'],
    'dp': ['ishmael', 'uitlander', 'absconder', 'alien', 'barbarian', 'bolter', 'castaway', 'declasse', 'deported population', 'deportee', 'deracine', 'derelict'],
    'drab': ['bag', 'bat', 'bawd', 'beige', 'beldam', 'biddy', 'bleak', 'boring', 'brown', 'brownish', 'brownish-yellow', 'brunet'],
    'draconian': ['tartarean', 'animal', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bestial', 'bloodthirsty', 'bloody', 'bloody-minded', 'brutal'],
    'dracula': ['frankenstein', 'wolf-man', 'bogey', 'bogeyman', 'bugaboo', 'bugbear', 'fee-faw-fum', 'frightener', 'ghost', 'ghoul', 'hobgoblin', 'holy terror'],
    'draft': ['cd', 'iou', 'mo', 'abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'acceptance', 'acceptance bill', 'adumbrate', 'air current'],
    'draft animal': ['siberian husky', 'ass', 'beast of burden', 'camel', 'dromedary', 'elephant', 'horse', 'husky', 'llama', 'malamute', 'mule', 'ox'],
    'drafting': ['aspiration', 'black and white', 'bleeding', 'bloodletting', 'broaching', 'call', 'call-up', 'charcoal', 'compulsory military service', 'conscription', 'cupping', 'delineation'],
    'drafty': ['aeolian', 'airish', 'airy', 'blasty', 'blowy', 'blustering', 'blusterous', 'blustery', 'boreal', 'breezy', 'brisk', 'favonian'],
    'drag': ['adduct', 'adduction', 'affinity', 'aggravation', 'allurement', 'amble', 'annoyance', 'arrest', 'artery', 'attract', 'attractance', 'attraction'],
    'drag in': ['edge in', 'foist', 'foist in', 'fudge in', 'implant in', 'impose on', 'inject in', 'insert in', 'insinuate in', 'intercalate', 'interjaculate', 'interject'],
    'drag on': ['abide', 'be infinitely repetitive', 'be tedious', 'bide', 'carry on', 'cease not', 'continue', 'continue the same', 'crawl', 'creep', 'drag', 'drag along'],
    'drag out': ['adjourn', 'amble', 'arouse', 'bring forth', 'bring out', 'bring to light', 'call forth', 'call out', 'call up', 'chatter', 'claudicate', 'continue'],
    'dragged out': ['drawn', 'drawn out', 'drawn-out', 'elongated', 'extended', 'interminable', 'languishing', 'lasting', 'lengthened', 'lingering', 'long', 'long-continuing'],
    'draggle': ['bag', 'bedrabble', 'bedraggle', 'cascade', 'daggle', 'dangle', 'depend', 'drabble', 'drag', 'drape', 'draw', 'droop'],
    'draggled': ['beat-up', 'bedraggled', 'befouled', 'besmirched', 'blowzy', 'careless', 'chintzy', 'defiled', 'dilapidated', 'dirtied', 'drabbled', 'drabbletailed'],
    'dragnet': ['abduction', 'apprehension', 'arrest', 'arrestation', 'bait', 'birdlime', 'bola', 'capture', 'catch', 'catching', 'cobweb', 'collaring'],
    'dragon': ['argus', 'briareus', 'cerberus', 'charybdis', 'cyclops', 'echidna', 'gila monster', 'gorgon', 'harpy', 'hydra', 'loch ness monster', 'mafioso'],
    'dragoon': ['blackjack', 'bludgeon', 'bluster', 'bluster out of', 'browbeat', 'bulldoze', 'bully', 'bullyrag', 'cavalryman', 'coerce', 'cossack', 'cow'],
    'drain': ['abate', 'ablate', 'ablation', 'abrade', 'abridge', 'absorb', 'absorption', 'abstract', 'abuse', 'achromatize', 'acquire', 'air-dry'],
    'drainage': ['air-drying', 'anhydration', 'aspiration', 'bleeding', 'bloodletting', 'broaching', 'cleaning out', 'clearance', 'clearing', 'cupping', 'defecation', 'defluxion'],
    'drained': ['ablated', 'acarpous', 'all in', 'arid', 'ausgespielt', 'barren', 'beat', 'beat up', 'beaten', 'blanched', 'bleached', 'bleached white'],
    'draining': ['aspiration', 'bleeding', 'bloodletting', 'breakdown', 'broaching', 'clamant', 'clamorous', 'cleaning out', 'clearance', 'clearing', 'collapse', 'coming apart'],
    'drake': ['bantam', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'billy', 'billy goat', 'boar', 'broiler', 'brooder', 'broody hen', 'bubbly-jock'],
    'dram': ['ace', 'atom', 'beverage', 'bit', 'bumper', 'carat', 'centigram', 'crumb', 'dab', 'dash', 'decagram', 'decigram'],
    'drama': ['broadway', 'grand guignol', 'passion play', 'tom show', 'acting', 'alphabet', 'antimasque', 'art', 'audience success', 'ballet', 'blueprint', 'boards'],
    'dramatic': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'actor-proof', 'all-star', 'alto', 'ballet'],
    'dramatics': ['thespian art', 'amateur theatricals', 'blazon', 'bravura', 'brilliancy', 'daring', 'dash', 'demonstration', 'display', 'dramatic art', 'dramatic form', 'dramatic irony'],
    'dramatist': ['advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'choreographer', 'coauthor', 'collaborator', 'columnist', 'comedian'],
    'dramatize': ['act a part', 'affect', 'assume', 'be a gas', 'be a hit', 'betoken', 'bill', 'bomb', 'brandish', 'breathe', 'bring forth', 'bring forward'],
    'drape': ['adorn', 'apparel', 'array', 'attire', 'awning', 'bag', 'beach umbrella', 'bedeck', 'bedrape', 'blanket', 'blind', 'bundle up'],
    'draper': ['baker', 'bookdealer', 'bookseller', 'butcher', 'chandler', 'clothier', 'clothing merchant', 'confectioner', 'costumer', 'costumier', 'dry goods dealer', 'drysalter'],
    'drapery': ['aglet', 'aigrette', 'apparel', 'applique', 'arabesque', 'arras', 'array', 'attire', 'awning', 'batik', 'beach umbrella', 'beading'],
    'drastic': ['draconian', 'acute', 'cutting', 'desperate', 'dire', 'excessive', 'exorbitant', 'extravagant', 'extreme', 'fierce', 'forceful', 'furious'],
    'draught': ['cd', 'iou', 'mo', 'abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'acceptance', 'acceptance bill', 'air current', 'arrangement'],
    'draughtsman': ['cd', 'iou', 'mo', 'abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'acceptance', 'acceptance bill', 'air current', 'arrangement'],
    'draughty': ['cd', 'iou', 'mo', 'abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'acceptance', 'acceptance bill', 'air current', 'arrangement'],
    'draw': ['tweedledum and tweedledee', 'abbreviate', 'abysm', 'abyss', 'accept', 'acquire', 'act on', 'adduct', 'adduction', 'admit', 'advance', 'affinity'],
    'draw and quarter': ['defoliate', 'denude', 'dismember', 'flay', 'grill', 'impale', 'keelhaul', 'lacerate', 'maim', 'mangle', 'mutilate', 'peel'],
    'draw back': ['avoid', 'back down', 'back out', 'beat a retreat', 'blench', 'blink', 'cringe', 'discount', 'disengage', 'dodge', 'draw in', 'draw off'],
    'draw in': ['abbreviate', 'absorb', 'allure', 'argue', 'aspirate', 'bait', 'bait the hook', 'blandish', 'breathe in', 'bring around', 'cajole', 'catch up in'],
    'draw near': ['accost', 'advance', 'anticipate', 'approach', 'appropinquate', 'approximate', 'await', 'be destined', 'be fated', 'be imminent', 'be in store', 'be to be'],
    'draw on': ['act on', 'allure', 'anticipate', 'appear', 'approach', 'argue', 'arise', 'assume', 'attract', 'await', 'bait', 'bait the hook'],
    'draw out': ['arouse', 'avulse', 'bring forth', 'bring out', 'bring to light', 'call forth', 'call out', 'call up', 'chatter', 'continue', 'cut out', 'dawdle'],
    'draw the line': ['analyze', 'balk at', 'be unwilling', 'begrudge', 'bound', 'condition', 'confine', 'contain', 'contradistinguish', 'copyright', 'demarcate', 'demark'],
    'draw up': ['bring up', 'bring up short', 'cease fire', 'come together', 'come up short', 'copy', 'copy out', 'crystallize', 'draft', 'drag up', 'dredge', 'dredge up'],
    'drawback': ['abatement', 'agio', 'allowance', 'bank discount', 'blemish', 'block', 'blockade', 'bottleneck', 'breakage', 'bug', 'cash discount', 'catch'],
    'drawbridge': ['bifrost', 'abatis', 'advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'bascule bridge'],
    'drawer': ['architectural draftsman', 'archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box'],
    'drawing': ['adductive', 'alluring', 'alphabet', 'appealing', 'art', 'aspiration', 'attracting', 'attraction', 'attractive', 'attrahent', 'avulsion', 'bewitching'],
    'drawing room': ['pullman', 'pullman car', 'vanity fair', 'baggage car', 'beau monde', 'beautiful people', 'best people', 'best room', 'boxcar', 'caboose', 'cafe society', 'car'],
    'drawl': ['accent', 'bark', 'bawl', 'bellow', 'blare', 'blat', 'blubber', 'boom', 'bray', 'breathe', 'broad accent', 'brogue'],
    'drawn': ['alike', 'at par', 'au pair', 'careworn', 'commensurate', 'dragged out', 'drawn out', 'elongated', 'equal', 'equalized', 'even', 'even stephen'],
    'drawn out': ['dragged out', 'dragging', 'drawn', 'elongated', 'extended', 'interminable', 'languishing', 'lasting', 'lengthened', 'lengthy', 'lingering', 'long'],
    'drayage': ['air express', 'airfreight', 'airlift', 'asportation', 'attraction', 'bearing', 'carriage', 'carry', 'carrying', 'cartage', 'conveyance', 'draft'],
    'dread': ['abject fear', 'affright', 'agitation', 'alarm', 'all-overs', 'angst', 'anguish', 'anticipate', 'anticipation', 'anxiety', 'anxiety hysteria', 'anxiety neurosis'],
    'dreadful': ['bildungsroman', 'gothic novel', 'abominable', 'alarming', 'appalling', 'arrant', 'astounding', 'atrocious', 'august', 'awe-inspiring', 'awesome', 'awful'],
    'dreadfully': ['abominably', 'agonizingly', 'alarmingly', 'appallingly', 'astoundingly', 'atrociously', 'awful', 'awfully', 'baldly', 'balefully', 'banefully', 'basely'],
    'dream': ['miss america', 'walter mitty', 'absence of mind', 'absentmindedness', 'absorption', 'abstractedness', 'abstraction', 'ace', 'ache', 'airy hope', 'airy nothing', 'aspiration'],
    'dream up': ['beget', 'breed', 'bring forth', 'bring into being', 'call into being', 'coin', 'conceit', 'conceive', 'conceptualize', 'concoct', 'contrive', 'cook up'],
    'dreamer': ['don quixote', 'quixote', 'utopian', 'daydreamer', 'dreamer of dreams', 'enthusiast', 'escapist', 'idealist', 'idealizer', 'illusionist', 'lotus-eater', 'prophet'],
    'dreaming': ['walter mitty', 'absence of mind', 'absent', 'absentminded', 'absentmindedness', 'absorbed', 'absorption', 'abstracted', 'abstractedness', 'abstraction', 'bemused', 'bemusement'],
    'dreamland': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley'],
    'dreamlike': ['chimerical', 'delusional', 'delusionary', 'delusive', 'delusory', 'fancied', 'fanciful', 'fantastic', 'hallucinational', 'hallucinative', 'hallucinatory', 'illusional'],
    'dreamworld': ['airy nothing', 'autism', 'bubble', 'chimera', 'daydream', 'deception', 'deluded belief', 'delusion', 'dereism', 'dream', 'dream vision', 'dreamland'],
    'dreamy': ['barmecidal', 'barmecide', 'absent', 'absent-minded', 'absentminded', 'absorbed', 'abstracted', 'airy', 'anesthetized', 'apparent', 'apparitional', 'appeasing'],
    'dreary': ['quaker-colored', 'acier', 'affecting', 'afflictive', 'apocalyptic', 'arid', 'ashen', 'ashy', 'bad', 'baleful', 'banausic', 'baneful'],
    'dredge': ['avulse', 'besprinkle', 'bore', 'bread', 'breathe', 'brew', 'burrow', 'color', 'crumb', 'cut out', 'decoct', 'delve'],
    'dredge up': ['accumulate', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'assemble', 'avulse', 'batch', 'bring together', 'bulk', 'bunch', 'bunch together'],
    'dregs': ['alluvion', 'alluvium', 'ash', 'bones', 'canaille', 'cattle', 'chaff', 'children of darkness', 'cinder', 'clinker', 'culm', 'deadwood'],
    'drench': ['bathe', 'bed', 'bed down', 'beverage', 'break', 'brew', 'brewing', 'bridle', 'brush', 'bumper', 'choke', 'congest'],
    'drenched': ['addled', 'awash', 'bathed', 'beery', 'bemused', 'besotted', 'blind drunk', 'bloated', 'bursting', 'choked', 'congested', 'crammed'],
    'drenching': ['brewing', 'dampening', 'drench', 'ducking', 'dunking', 'humectant', 'imbruement', 'imbuement', 'impregnation', 'infiltration', 'infusion', 'injection'],
    'dress': ['mother hubbard', 'accouter', 'adorn', 'anoint', 'apparel', 'appoint', 'arm', 'armory', 'arrange', 'array', 'attire', 'backset'],
    'dress circle': ['auditorium', 'balcony', 'box', 'box seat', 'fauteuil', 'gallery', 'loge', 'nigger heaven', 'orchestra', 'orchestra circle', 'paradise', 'parquet'],
    'dress down': ['call down', 'come down on', 'flax', 'give a dressing-down', 'give it to', 'hide', 'jump all over', 'jump on', 'larrup', 'lather', 'leather', 'lick'],
    'dress up': ['adorn', 'apparel', 'array', 'attire', 'beautify', 'bedeck', 'bedizen', 'belie', 'blazon', 'camouflage', 'clad', 'clothe'],
    'dressed to kill': ['braw', 'chic', 'classy', 'clothes-conscious', 'cosmopolitan', 'dapper', 'dashing', 'dressed to advantage', 'elegant', 'exquisite', 'genteel', 'jaunty'],
    'dressing': ['ace bandage', 'band-aid', 'ablation', 'abrasion', 'abrasive', 'adhesive tape', 'ammonia', 'apparel', 'application', 'array', 'ass-reaming', 'attire'],
    'dressing room': ['acting area', 'apron', 'apron stage', 'backstage', 'band shell', 'bandstand', 'board', 'bridge', 'cloakroom', 'closet', 'clothes closet', 'coulisse'],
    'dribble': ['ace', 'atom', 'bit', 'condensation', 'condense', 'dab', 'distill', 'distillation', 'dole', 'dot', 'dram', 'driblet'],
    'dribble away': ['ablate', 'atrophy', 'blow', 'blunder away', 'consume', 'consume away', 'dally away', 'decrease', 'deplete', 'depreciate', 'diddle away', 'dissipate'],
    'driblet': ['ace', 'atom', 'bit', 'dab', 'dole', 'dot', 'dram', 'dribble', 'droplet', 'dwarf', 'farthing', 'fleck'],
    'dried': ['adust', 'baked', 'burnt', 'corky', 'dehydrated', 'desiccated', 'dried-up', 'evaporated', 'exsiccated', 'mummified', 'parched', 'scorched'],
    'dried up': ['sanforized', 'acarpous', 'adust', 'arid', 'atrophied', 'attenuated', 'baked', 'barren', 'brittle', 'burnt', 'celibate', 'childless'],
    'drier': ['air brush', 'art paper', 'brush', 'camera lucida', 'camera obscura', 'canvas', 'chalk', 'charcoal', 'chromogen', 'clothes-drier', 'coat', 'coat of paint'],
    'drift': ['brownian movement', 'zeitgeist', 'aberrancy', 'aberration', 'accumulation', 'advance', 'aeroplane', 'affective meaning', 'affluence', 'afflux', 'affluxion', 'aim'],
    'drift away': ['decline', 'die away', 'diminish', 'dwindle', 'ebb', 'fade', 'fade away', 'go', 'go away', 'move away', 'move off', 'pull away'],
    'drifter': ['ahasuerus', 'ancient mariner', 'argonaut', 'bowery bum', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'angler', 'beachcomber'],
    'drifting': ['ascending', 'axial', 'back', 'back-flowing', 'backward', 'circumforaneous', 'descending', 'discursive', 'divagatory', 'down-trending', 'downward', 'errant'],
    'drill': ['sop', 'accustom', 'aculeus', 'acumination', 'application', 'apprentice', 'apprenticeship', 'athletics', 'auger', 'basic training', 'bed', 'bit'],
    'drink': ['bs', 'bronx cocktail', 'bull shot', 'cuba libre', 'dubonnet cocktail', 'green dragon', 'guggenheim', 'harvey wallbanger', 'irish coffee', 'john barleycorn', 'mai-tai', 'manhattan'],
    'drink in': ['absorb', 'adsorb', 'advert to', 'assimilate', 'attend to', 'be aware of', 'be engrossed in', 'bib', 'blot', 'blot up', 'booze', 'chemisorb'],
    'drink to': ['bib', 'booze', 'drain the cup', 'drink', 'drink in', 'drink off', 'drink up', 'guzzle', 'imbibe', 'pledge', 'pull', 'quaff'],
    'drink up': ['absorb', 'adsorb', 'assimilate', 'bib', 'blot', 'blot up', 'booze', 'chemisorb', 'chemosorb', 'digest', 'drain the cup', 'dram'],
    'drip': ['balderdash', 'baloney', 'boob', 'bore', 'bull', 'bunk', 'bushwa', 'buttonholer', 'chump', 'clod', 'condensation', 'condense'],
    'dripping wet': ['awash', 'bathed', 'deluged', 'dipped', 'drenched', 'dribbling', 'dripping', 'drowned', 'engulfed', 'flooded', 'immersed', 'inundated'],
    'drive': ['autobahn', 'sunday drive', 'us highway', 'acceleration', 'activity', 'actuate', 'advance', 'advance against', 'advance upon', 'adventuresomeness', 'adventurousness', 'aggravated assault'],
    'drive away': ['attenuate', 'beat back', 'blow off', 'brush off', 'cast forth', 'chase', 'chase away', 'chase off', 'clear away', 'cut', 'dilute', 'dismiss'],
    'drive back': ['beat back', 'beat off', 'block', 'brush off', 'chase', 'chase away', 'chase off', 'check', 'counter', 'cut', 'dismiss', 'drive away'],
    'drive in': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'cinema'],
    'drive on': ['accelerate', 'actuate', 'animate', 'bundle', 'bustle', 'cheer on', 'compel', 'crowd', 'dispatch', 'drive', 'egg on', 'expedite'],
    'drivel': ['greek', 'absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'balls', 'baloney', 'be insane', 'be stupid', 'bibble-babble', 'blabber'],
    'driver': ['jehu', 'simon legree', 'sunday driver', 'absolute monarch', 'absolute ruler', 'agent', 'airscrew', 'all-powerful ruler', 'arrogator', 'autarch', 'autocrat', 'backseat driver'],
    'driveway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'driving': ['acid', 'action', 'active', 'actuating', 'advancing', 'adventuresome', 'adventurous', 'agency', 'aggressive', 'ambitious', 'animating', 'assailing'],
    'driving force': ['bunt', 'butt', 'clout', 'compulsion', 'drive', 'impellent', 'impelling force', 'impetus', 'impulse', 'impulsion', 'incentive', 'incitement'],
    'drizzle': ['scotch mist', 'blood rain', 'drum', 'evening mist', 'fall', 'flurry', 'gout of rain', 'mist', 'misty rain', 'mizzle', 'moisture', 'patter'],
    'droit': ['appurtenance', 'authority', 'birthright', 'claim', 'conjugal right', 'demand', 'divine right', 'due', 'faculty', 'inalienable right', 'interest', 'natural right'],
    'droll': ['attic', 'absurd', 'amusing', 'biting', 'bizarre', 'brilliant', 'clever', 'comedian', 'comic', 'comical', 'eccentric', 'facetious'],
    'dromedary': ['cape elk', 'siberian husky', 'virginia deer', 'antelope', 'ass', 'beast of burden', 'buck', 'camel', 'camelopard', 'caribou', 'deer', 'deerlet'],
    'drone': ['indian file', 'accompaniment', 'alliteration', 'alto', 'array', 'articulation', 'assonance', 'bagpipe', 'bagpipes', 'bank', 'baritone', 'bass'],
    'droning': ['birring', 'bombilation', 'bombinating', 'bombination', 'booming', 'burring', 'buzzing', 'drone', 'gabble', 'gibber', 'gibbering', 'hum'],
    'drool': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'baloney', 'be insane', 'be stupid', 'bibble-babble', 'blabber', 'blather', 'blither'],
    'droop': ['amble', 'bad', 'bag', 'become suicidal', 'blow', 'blue', 'break', 'break down', 'burn out', 'cadence', 'cascade', 'cast down'],
    'drooping': ['anemic', 'asthenic', 'bagging', 'baggy', 'ballooning', 'bloodless', 'bowed-down', 'cast down', 'chicken', 'collapsing', 'coming apart', 'cowardly'],
    'droopy': ['anemic', 'apathetic', 'asthenic', 'bagging', 'baggy', 'ballooning', 'benumbed', 'blase', 'bloodless', 'bored', 'bowed-down', 'cast down'],
    'drop': ['abandon', 'abate', 'abdicate', 'abeyance', 'abjure', 'ablate', 'acknowledge defeat', 'act drop', 'advantage', 'asbestos', 'asbestos board', 'ascend'],
    'drop in': ['admit', 'barge in', 'be admitted', 'break in', 'breeze in', 'burst in', 'bust in', 'call', 'call on', 'call upon', 'come barging in', 'come breezing in'],
    'drop it': ['abandon', 'abort', 'belay', 'cancel', 'cease', 'cut it out', 'desist', 'discontinue', 'end', 'forget it', 'give over', 'halt'],
    'drop off': ['abate', 'ablate', 'bate', 'be eaten away', 'buy it', 'cascade', 'cash in', 'cataract', 'check in', 'check out', 'collapse', 'come down'],
    'drop out': ['abandon', 'agree to differ', 'agree to disagree', 'back out', 'be at variance', 'be in dissent', 'beg off', 'beg to differ', 'break bounds', 'break step', 'cry off', 'depart from'],
    'drop the subject': ['abandon', 'brush aside', 'brush off', 'dismiss', 'forget', 'forget about it', 'forget it', 'lay aside', 'let it go', 'let slip', 'push aside', 'put aside'],
    'droplet': ['bead', 'crumb', 'dewdrop', 'dot', 'driblet', 'drop', 'fleck', 'flyspeck', 'globule', 'gnat', 'gobbet', 'grain'],
    'dropout': ['bohemian', 'beatnik', 'deviant', 'dissenter', 'flower child', 'freak', 'heretic', 'hippie', 'maverick', 'misfit', 'nonconformist', 'nonjuror'],
    'droppings': ['bm', 'bowel movement', 'buffalo chips', 'ca-ca', 'coprolite', 'coprolith', 'cow chips', 'cow flops', 'cow pats', 'crap', 'defecation', 'dingleberry'],
    'dropsy': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'bleeding'],
    'dross': ['alluvion', 'alluvium', 'ash', 'ashes', 'brand', 'calx', 'carbon', 'charcoal', 'cinder', 'clinker', 'coal', 'coke'],
    'drought': ['absence', 'appetite', 'aridity', 'aridness', 'beggary', 'canine appetite', 'corkiness', 'defectiveness', 'deficiency', 'deficit', 'deprivation', 'destitution'],
    'drove': ['army', 'bunch', 'cage', 'colony', 'corral', 'crush', 'drift', 'drive', 'flock', 'gam', 'gang', 'goad'],
    'drover': ['gyropilot', 'automatic pilot', 'boatheader', 'boatsteerer', 'cattleman', 'cicerone', 'courier', 'cowboy', 'cowgirl', 'cowhand', 'cowherd', 'cowman'],
    'drown': ['od', 'asphyxiate', 'baptize', 'be clobbered', 'be felled', 'be killed', 'be poleaxed', 'be staggered', 'be stricken', 'bottle up', 'burke', 'bury'],
    'drowned': ['afloat', 'at flood', 'awash', 'bathed', 'buried', 'deluged', 'dipped', 'drenched', 'dribbling', 'dripping', 'dripping wet', 'engulfed'],
    'drowse': ['beauty sleep', 'beddy-bye', 'bedtime', 'blanket drill', 'bye-bye', 'dorm', 'doze', 'dreamland', 'fitful sleep', 'hibernation', 'land of nod', 'light sleep'],
    'drowsiness': ['acedia', 'apathy', 'boredom', 'doziness', 'dullness', 'enervation', 'ennui', 'fatigue', 'heaviness', 'hebetude', 'inanimation', 'indifference'],
    'drowsy': ['anesthetized', 'appeasing', 'calming', 'cataleptic', 'comatose', 'cradling', 'doped', 'dozy', 'dreamy', 'drugged', 'drugged with sleep', 'gentling'],
    'drub': ['bang', 'bash', 'baste', 'bastinado', 'bat', 'batter', 'beat', 'beat all hollow', 'beat hollow', 'beating', 'belabor', 'belt'],
    'drudge': ['administer to', 'attend', 'attend on', 'be busy', 'beast of burden', 'care for', 'chore', 'dance attendance upon', 'dig', 'do for', 'do service to', 'domestic'],
    'drudgery': ['chore', 'dirty work', 'donkeywork', 'employment', 'fag', 'fatigue', 'grind', 'handiwork', 'handwork', 'industry', 'labor', 'lick'],
    'drug': ['adrenalin', 'benzedrine', 'dexamyl', 'dexedrine', 'ko', 'methedrine', 'mickey finn', 'aloes', 'ammonium carbonate', 'amphetamine', 'amphetamine sulphate', 'analgesic'],
    'drug addict': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser'],
    'drug addiction': ['a habit', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'addiction', 'alcoholism', 'barbiturate addiction', 'barbiturism', 'chain smoking', 'chronic alcoholism', 'cocainism', 'crash'],
    'drug culture': ['a habit', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'addiction', 'alcoholism', 'barbiturate addiction', 'barbiturism', 'chain smoking', 'chronic alcoholism', 'cocainism', 'crash'],
    'drug user': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'alternating personality', 'antisocial personality', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'disordered personality'],
    'drugged': ['affectless', 'anesthetized', 'apathetic', 'arctic', 'asleep', 'autistic', 'benumbed', 'blase', 'blunt', 'bored', 'cataleptic', 'catatonic'],
    'drugstore': ['antique store', 'apothecary', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'chemist', 'cigar store', 'clothiers', 'clothing store', 'confectionery', 'dispensary'],
    'drugstore cowboy': ['tv-viewer', 'beholder', 'bird-watcher', 'bystander', 'eyewitness', 'gaper', 'gazer', 'gazer-on', 'girl-watcher', 'goggler', 'kibitzer', 'looker'],
    'druid': ['cassandra', 'druidess', 'parsi', 'sabaist', 'zoroastrian', 'animal worshiper', 'anthropolater', 'arborolater', 'archaeolater', 'astrologer', 'augur', 'calamity howler'],
    'drum': ['barrage', 'barrel', 'beat', 'beat a ruffle', 'beat a tattoo', 'beat the drum', 'beat time', 'beating', 'bole', 'bongo drum', 'cackle', 'call'],
    'drum out': ['boot', 'bounce', 'break', 'bump', 'bust', 'can', 'cashier', 'chase out', 'deconsecrate', 'defrock', 'degrade', 'demote'],
    'drumbeat': ['barrage', 'beat', 'beating', 'drum', 'drum music', 'drumfire', 'drumming', 'flutter', 'palpitation', 'paradiddle', 'patter', 'pitapat'],
    'drumhead': ['bender', 'bloat', 'blotter', 'booze', 'boozehound', 'boozer', 'brannigan', 'bust', 'drunk', 'guzzler', 'inebriate', 'jag'],
    'drumming': ['arrhythmia', 'bang', 'barrage', 'bash', 'bat', 'beat', 'beating', 'belt', 'biff', 'blinding', 'blow', 'bonk'],
    'drumstick': ['ankle', 'bayonet legs', 'bongo drum', 'bowlegs', 'breast', 'calf', 'chicken foot', 'cnemis', 'conga', 'dark meat', 'drum', 'drumhead'],
    'drunk': ['ablaze', 'addled', 'afire', 'aflame', 'alcoholic', 'alcoholic addict', 'animated', 'ardent', 'bacchanal', 'bacchanalia', 'bacchanalian', 'bat'],
    'drunkard': ['bowery bum', 'lsd user', 'acidhead', 'addict', 'alcoholic', 'alcoholic addict', 'bacchanal', 'bacchanalian', 'beachcomber', 'beggar', 'beggarly fellow', 'bibber'],
    'drunken': ['addicted to drink', 'addled', 'beery', 'bemused', 'besotted', 'bibacious', 'bibulous', 'blind drunk', 'crapulent', 'crapulous', 'dizzy', 'drenched'],
    'drunkenness': ['dutch courage', 'a high', 'alcoholism', 'befuddlement', 'besottedness', 'bibulousness', 'compotation', 'crapulence', 'crapulency', 'crapulousness', 'dipsomania', 'dizziness'],
    'druthers': ['affinity', 'alternative', 'bag', 'bent', 'bias', 'chosen kind', 'cup of tea', 'election', 'fancy', 'favor', 'inclination', 'leaning'],
    'dry': ['rabelaisian', 'saharan', 'spartan', 'wctu', 'acarpous', 'acerb', 'acerbate', 'acerbic', 'acescent', 'acetose', 'acid', 'acidulous'],
    'dry clean': ['bleach', 'bowdlerize', 'clean', 'clean out', 'clean up', 'cleanse', 'clear out', 'delouse', 'depurate', 'deterge', 'dust', 'dust off'],
    'dry cure': ['anhydrate', 'blast-freeze', 'brine', 'corn', 'cure', 'dehydrate', 'desiccate', 'dry', 'dry-salt', 'embalm', 'evaporate', 'freeze'],
    'dry dock': ['anchorage', 'anchorage ground', 'basin', 'berth', 'breakwater', 'bulkhead', 'dock', 'dockage', 'dockyard', 'embankment', 'groin', 'harbor'],
    'dry land': ['acres', 'alluvion', 'alluvium', 'arable land', 'clay', 'clod', 'crust', 'dirt', 'dust', 'earth', 'freehold', 'glebe'],
    'dry nurse': ['aliment', 'amah', 'ayah', 'breast-feed', 'care for', 'cherish', 'coddle', 'cosset', 'cradle', 'cultivate', 'fatten', 'fatten up'],
    'dry rot': ['blast', 'blight', 'cancer', 'canker', 'caries', 'carrion', 'decay', 'decomposition', 'foulness', 'fungus', 'gangrene', 'mildew'],
    'dry run': ['gedankenexperiment', 'action', 'air cover', 'air raid', 'air support', 'amphibious operations', 'audition', 'bench test', 'bombing', 'combined operations', 'cover', 'flight test'],
    'dry up': ['sanforize', 'air-dry', 'anhydrate', 'attenuate', 'bake', 'be consumed', 'be used up', 'blot', 'brush', 'burn', 'consume', 'cure'],
    'dryasdust': ['jonathan oldbuck', 'miniver cheevy', 'pre-raphaelite', 'academic', 'antiquarian', 'antiquary', 'antique collector', 'antique dealer', 'antique-car collector', 'archaeologist', 'archaist', 'arid'],
    'drying': ['sanforizing', 'air-drying', 'anhydration', 'atrophy', 'attenuation', 'blast-freezing', 'bottling', 'brining', 'canning', 'consumption', 'corning', 'curing'],
    'dryness': ['acerbity', 'acescency', 'acidity', 'acidulousness', 'appetite', 'aridity', 'aridness', 'barrenness', 'birth control', 'bloodlessness', 'cacophony', 'canine appetite'],
    'drypoint': ['aquatint', 'cerography', 'chalcography', 'crayon engraving', 'cribbling', 'etching', 'intaglio', 'metal cut', 'mezzotint', 'photoengraving', 'plate engraving', 'pyrogravure'],
    'dual': ['janus-like', 'ambidextrous', 'bifacial', 'bifold', 'biform', 'bifurcated', 'bilateral', 'binary', 'binate', 'biparous', 'bipartisan', 'bipartite'],
    'dual personality': ['alcoholic', 'alternating personality', 'antisocial personality', 'catatonia', 'catatonic schizophrenia', 'dementia praecox', 'depersonalization', 'disconnection', 'disordered personality', 'dissociation', 'dissociation of personality', 'disturbed personality'],
    'dualism': ['janus', 'acosmism', 'allotheism', 'ambiguity', 'ambivalence', 'anthropolatry', 'anthropomorphism', 'anthropotheism', 'autotheism', 'biformity', 'bifurcation', 'conjugation'],
    'dualistic': ['bifold', 'biform', 'bifurcated', 'bilateral', 'binary', 'bipartisan', 'bipartite', 'dichotomous', 'double', 'double-barreled', 'duadic', 'dual'],
    'dub': ['baptize', 'blow', 'blunder', 'bobble', 'boggle', 'bollix', 'butterfingers', 'call', 'christen', 'clumsy', 'dab', 'define'],
    'dubious': ['humean', 'pyrrhonic', 'a bit thick', 'a bit thin', 'absurd', 'agnostic', 'ambitendent', 'ambivalent', 'amoral', 'arguable', 'at issue', 'at loose ends'],
    'ducal': ['aristocratic', 'chivalrous', 'exalted', 'genteel', 'gentle', 'gentlemanlike', 'gentlemanly', 'high', 'kinglike', 'kingly', 'knightly', 'ladylike'],
    'ducat': ['coin', 'crown', 'double eagle', 'doubloon', 'eagle', 'five-dollar gold piece', 'gold piece', 'guinea', 'half crown', 'half eagle', 'hard money', 'moidore'],
    'duce': ['mahdi', 'simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'autocrat', 'bell cow', 'bell mare', 'bellwether', 'born leader'],
    'duchy': ['kreis', 'ally', 'archbishopric', 'archdiocese', 'archduchy', 'archdukedom', 'arrondissement', 'bailiwick', 'bishopric', 'body politic', 'borough', 'buffer state'],
    'duck': ['adamite', 'bantam', 'cornish hen', 'about the bush', 'also-ran', 'angel', 'avert', 'avoid', 'avoidance', 'avoiding reaction', 'babe', 'baby'],
    'duck out': ['beat it', 'blow', 'bow out', 'depart', 'disappear', 'dog it', 'duck and run', 'escape', 'exit', 'go on furlough', 'go on leave', 'lam'],
    'duckling': ['bantam', 'cornish hen', 'angel', 'babe', 'baby', 'baby-doll', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'birdling', 'broiler'],
    'ducky': ['ok', 'ace-high', 'bad', 'bang-up', 'bonzer', 'boss', 'bully', 'but good', 'cool', 'corking', 'crackerjack', 'dandy'],
    'duct': ['eustachian tube', 'fallopian tube', 'adit', 'aqueduct', 'canal', 'channel', 'conduit', 'course', 'ditch', 'egress', 'emunctory', 'entrance'],
    'ductile': ['adaptable', 'bendable', 'bending', 'biddable', 'compliant', 'convenient', 'docile', 'elastic', 'extensible', 'extensile', 'fabricable', 'facile'],
    'dud': ['abortion', 'abortive attempt', 'also-ran', 'aspirant', 'baby kisser', 'bankrupt', 'blank cartridge', 'bogy', 'bomb', 'bugaboo', 'bugbear', 'bust'],
    'dude': ['beau brummel', 'beau', 'blade', 'blood', 'boulevardier', 'buck', 'chap', 'clotheshorse', 'coxcomb', 'dandy', 'exquisite', 'fashion plate'],
    'dude ranch': ['arable land', 'barnyard', 'barton', 'cattle ranch', 'chicken farm', 'collective farm', 'cotton plantation', 'croft', 'dairy farm', 'demesne', 'demesne farm', 'dry farm'],
    'dudgeon': ['ferment', 'fret', 'fume', 'fury', 'high dudgeon', 'huff', 'humor', 'ire', 'miff', 'mood', 'pet', 'pique'],
    'duds': ['apparel', 'array', 'attire', 'bedizenment', 'clothes', 'clothing', 'costume', 'drapery', 'dress', 'dressing', 'fashion', 'fatigues'],
    'due': ['according to hoyle', 'accountable', 'accounts payable', 'accounts receivable', 'acknowledgment', 'adequate', 'alleged', 'amount due', 'ample', 'anticipated', 'appropriate', 'appurtenance'],
    'due process': ['actionability', 'applicability', 'constitutional validity', 'constitutionalism', 'constitutionality', 'jurisdiction', 'justice', 'justiciability', 'lawfulness', 'legal form', 'legal process', 'legalism'],
    'due to': ['after', 'arising from', 'attributable to', 'because of', 'by reason of', 'by virtue of', 'caused by', 'coming from', 'considering', 'contingent on', 'dependent on', 'derivable from'],
    'duel': ['affair of honor', 'battle', 'box', 'brawl', 'broil', 'buck', 'clash', 'close', 'collide', 'combat', 'come to blows', 'contend'],
    'duelist': ['battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'combatant', 'competitor', 'contender'],
    'duenna': ['abigail', 'amah', 'au pair girl', 'ayah', 'betweenmaid', 'biddy', 'bodyguard', 'cavalier', 'chambermaid', 'chaperon', 'companion', 'conductor'],
    'dues': ['accounts payable', 'accounts receivable', 'admission', 'admission fee', 'amount due', 'anchorage', 'bad debts', 'bill', 'bills', 'borrowing', 'brokerage', 'carfare'],
    'duet': ['bipartisanship', 'both', 'brace', 'coaction', 'coadjuvancy', 'coadministration', 'coagency', 'cochairmanship', 'codirectorship', 'collaboration', 'collaborativeness', 'collectivism'],
    'duff': ['arse', 'bad', 'beat', 'behind', 'bilk', 'bottom', 'broken', 'butt', 'can', 'cheat', 'counterfeit', 'cozen'],
    'duffel': ['accouterments', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'bag and baggage', 'baggage', 'conveniences', 'dunnage', 'equipage', 'equipment'],
    'duffer': ['arab', 'blockhead', 'blunderer', 'boob', 'bungler', 'butterfingers', 'clumsy', 'dimwit', 'dolt', 'dope', 'dub', 'dumbbell'],
    'dugout': ['abri', 'air-raid shelter', 'antre', 'approach trench', 'asylum', 'bolt-hole', 'bomb shelter', 'bombproof', 'bunker', 'burrow', 'cache', 'cave'],
    'duke': ['brahman', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'blue blood', 'count', 'daimio', 'earl', 'esquire', 'gentleman'],
    'dukedom': ['ally', 'archduchy', 'archdukedom', 'baronetcy', 'barony', 'body politic', 'buffer state', 'captive nation', 'chieftaincy', 'chieftainry', 'city-state', 'colony'],
    'dulcet': ['achingly sweet', 'affable', 'agreeable', 'agreeable-sounding', 'amiable', 'amicable', 'appealing', 'ariose', 'arioso', 'blissful', 'canorous', 'cantabile'],
    'dulcify': ['allay', 'appease', 'calm', 'calm down', 'candy', 'compose', 'conciliate', 'cool', 'cradle', 'defuse', 'ease', 'edulcorate'],
    'dull': ['ko', 'laodicean', 'olympian', 'quaker-colored', 'spartan', 'abate', 'abeyant', 'abrupt', 'achromatic', 'achromatize', 'achromic', 'acier'],
    'dullard': ['boeotian', 'block', 'clod', 'dimwit', 'dolt', 'donkey', 'dope', 'dullhead', 'dumb cluck', 'dumbbell', 'dummkopf', 'dummy'],
    'dulling': ['abating', 'allaying', 'alleviating', 'alleviative', 'analgesic', 'anesthetic', 'anodyne', 'assuaging', 'assuasive', 'balmy', 'balsamic', 'benumbing'],
    'dullness': ['abruptness', 'absence of color', 'acedia', 'achromaticity', 'achromatism', 'adynamia', 'aloofness', 'analgesia', 'anemia', 'anesthesia', 'angst', 'anguish'],
    'duly': ['accordingly', 'appropriately', 'as is proper', 'as is right', 'by right', 'by rights', 'condignly', 'correctly', 'deservedly', 'disinterestedly', 'dispassionately', 'equally'],
    'duly constituted': ['absolute', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'clothed with authority', 'commanding', 'competent', 'consequential', 'considerable', 'controlling'],
    'dumb': ['boeotian', 'abiotic', 'anaudic', 'animal', 'animalian', 'animalic', 'animalistic', 'aphasic', 'aphonic', 'apish', 'asinine', 'awkward'],
    'dumb show': ['acting', 'aping', 'bearing', 'beck', 'beckon', 'body language', 'carriage', 'characterization', 'charade', 'chironomy', 'dactylology', 'deaf-and-dumb alphabet'],
    'dumbbell': ['boeotian', 'indian club', 'barbell', 'block', 'clod', 'dimwit', 'dolt', 'donkey', 'dope', 'dullard', 'dullhead', 'dumb cluck'],
    'dumbfound': ['amaze', 'astonish', 'astound', 'awe', 'awestrike', 'bedaze', 'bedazzle', 'bewilder', 'boggle', 'bowl down', 'bowl over', 'choke'],
    'dumbfounded': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'anaudic', 'aphasic', 'aphonic', 'astonished', 'astounded', 'at gaze', 'awed'],
    'dumbness': ['anaudia', 'aphasia', 'aphonia', 'asininity', 'blockishness', 'boobishness', 'boorishness', 'bovinity', 'brevity', 'briefness', 'brusqueness', 'cloddishness'],
    'dumbstruck': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'anaudic', 'aphasic', 'aphonic', 'astonished', 'astounded', 'at gaze', 'awed'],
    'dummy': ['boeotian', 'charlie mccarthy', 'intertype', 'linotype', 'monotype', 'a nobody', 'a nothing', 'ace', 'adherent', 'advocate', 'affected', 'agent'],
    'dump': ['augean stables', 'parthian shot', 'abandon', 'abase', 'abasement', 'abash', 'abjure', 'abundance', 'accumulation', 'affront', 'amassment', 'ammo dump'],
    'dump on': ['abase', 'abash', 'affront', 'barrack', 'be above', 'be contemptuous of', 'bring down', 'bring low', 'call names', 'care nothing for', 'chaff', 'contemn'],
    'dumpling': ['italian paste', 'blimp', 'fedellini', 'fettuccine', 'knaydlach', 'lasagne', 'macaroni', 'matzo balls', 'noodles', 'pasta', 'paste', 'ravioli'],
    'dumps': ['blahs', 'blue devils', 'blues', 'dejection', 'depression', 'dismals', 'dods', 'doldrums', 'dolefuls', 'dorts', 'frumps', 'gloom'],
    'dumpy': ['lilliputian', 'tom thumb', 'adipose', 'beefy', 'big-bellied', 'bloated', 'blocky', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom'],
    'dun': ['account', 'annoy', 'apply pressure', 'bay', 'bayard', 'bedevil', 'beige', 'beleaguer', 'beset', 'besiege', 'bill', 'bill collector'],
    'dunce': ['boeotian', 'block', 'blockhead', 'bonehead', 'boob', 'booby', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead', 'chump', 'clod'],
    'dunderhead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead'],
    'dune': ['anthill', 'bank', 'barrow', 'brae', 'butte', 'cock', 'down', 'drift', 'drumlin', 'embankment', 'fell', 'foothills'],
    'dung': ['bm', 'ammonia', 'bowel movement', 'buffalo chips', 'ca-ca', 'castor-bean meal', 'commercial fertilizer', 'compost', 'coprolite', 'coprolith', 'cow', 'cow chips'],
    'dungarees': ['bermuda shorts', 'capri pants', 'bags', 'bells', 'bloomers', 'blue jeans', 'breeks', 'buckskins', 'chivarras', 'clam diggers', 'cords', 'corduroys'],
    'dungeon': ['pow camp', 'bastille', 'black hole', 'borstal', 'borstal institution', 'bridewell', 'brig', 'cell', 'concentration camp', 'condemned cell', 'death cell', 'death house'],
    'dunk': ['baptize', 'bury', 'deluge', 'dip', 'douse', 'drown', 'duck', 'engulf', 'float', 'flood', 'flow on', 'immerge'],
    'dunking': ['baptism', 'brewing', 'burial', 'dip', 'dipping', 'dousing', 'drench', 'drenching', 'duck', 'ducking', 'engulfment', 'imbruement'],
    'dunning': ['blandishment', 'buttonholing', 'cajolement', 'cajolery', 'cajoling', 'coaxing', 'demanding', 'importunate', 'importunateness', 'importunity', 'insistent', 'nagging'],
    'duo': ['both', 'brace', 'couple', 'couplet', 'distich', 'double harness', 'doublet', 'duad', 'duet', 'duettino', 'dyad', 'ensemble music'],
    'duodenal': ['abdominal', 'anal', 'appendical', 'cardiac', 'cecal', 'colic', 'colonic', 'coronary', 'duodecimal', 'duodenary', 'enteric', 'gastric'],
    'duodenum': ['abdomen', 'anus', 'appendix', 'blind gut', 'bowels', 'brain', 'cecum', 'colon', 'endocardium', 'entrails', 'foregut', 'giblets'],
    'duologue': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'bull session', 'burlesque show', 'charade', 'chinfest'],
    'dupable': ['cullible', 'deceivable', 'deludable', 'easy', 'exploitable', 'foolable', 'green', 'gullible', 'hoaxable', 'hoodwinkable', 'humbugable', 'ingenuous'],
    'dupe': ['charlie mccarthy', 'federal', 'photostat', 'xerox', 'agent', 'amanuensis', 'ancilla', 'apple-polisher', 'appliance', 'ass-licker', 'babe', 'backscratcher'],
    'duplex': ['janus-like', 'ambidextrous', 'apartment house', 'bifacial', 'bifold', 'biform', 'bifurcated', 'bilateral', 'binary', 'binate', 'biparous', 'bipartisan'],
    'duplicate': ['doppelganger', 'janus-like', 'photostat', 'xerox', 'xerox copy', 'actual thing', 'alike', 'all one', 'all the same', 'ambidextrous', 'analogous', 'bifacial'],
    'duplicated': ['biform', 'bifurcated', 'bilateral', 'bipartisan', 'bipartite', 'dichotomous', 'double', 'doubled', 'duadic', 'dual', 'dualistic', 'duplex'],
    'duplication': ['janus', 'ambiguity', 'ambivalence', 'bedizenment', 'biformity', 'bifurcation', 'burlesque', 'clone', 'conjugation', 'copy', 'counterpart', 'dichotomy'],
    'duplicity': ['janus', 'machiavellianism', 'ambidexterity', 'ambiguity', 'ambivalence', 'artfulness', 'artifice', 'bad faith', 'biformity', 'bifurcation', 'conjugation', 'craft'],
    'durability': ['abidingness', 'body', 'ceaselessness', 'changelessness', 'coeternity', 'cohesiveness', 'concreteness', 'constancy', 'continualness', 'continuance', 'density', 'durableness'],
    'durable': ['abiding', 'adamantine', 'age-long', 'aged', 'ancient', 'antique', 'bulky', 'cartilaginous', 'changeless', 'chewy', 'chronic', 'cohesive'],
    'durables': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'dinnerware', 'durable goods', 'earthenware', 'enamelware', 'fixtures', 'flatware', 'glassware'],
    'duration': ['abidingness', 'age', 'antiquity', 'changelessness', 'chronology', 'constancy', 'continuance', 'continuation', 'continuity', 'defeat of time', 'defiance of time', 'diuturnity'],
    'duress': ['amperage', 'argumentum baculinum', 'armipotence', 'authority', 'beef', 'black power', 'brute force', 'captivity', 'charge', 'charisma', 'close arrest', 'clout'],
    'dusk': ['bad light', 'blackish', 'broad day', 'brown of dusk', 'brownness', 'caliginous', 'candlelight', 'candlelighting', 'cocklight', 'crepuscular', 'crepuscule', 'dark'],
    'dusky': ['acheronian', 'ambiguous', 'amphibological', 'black', 'blackish', 'bleak', 'brunet', 'caliginous', 'cheerless', 'crepuscular', 'dark', 'dark-colored'],
    'dust': ['acres', 'air', 'air pollution', 'alluvion', 'alluvium', 'altercation', 'arable land', 'ashes', 'attritus', 'bamboozle', 'barrel', 'beat'],
    'dust bowl': ['arabia deserta', 'death valley', 'sahara', 'agricultural region', 'arable land', 'barren', 'barren land', 'barrens', 'black belt', 'brush', 'bush', 'citrus belt'],
    'dusty': ['quaker-colored', 'saharan', 'acier', 'anhydrous', 'arid', 'ashen', 'ashy', 'athirst', 'barren', 'blah', 'blank', 'bloodless'],
    'dutch uncle': ['polonius', 'admonisher', 'adviser', 'backseat driver', 'buttinsky', 'confidant', 'consultant', 'counsel', 'counselor', 'expert', 'guide', 'instructor'],
    'duteous': ['acquiescent', 'active', 'compliant', 'complying', 'conforming', 'conscientious', 'constant', 'deferential', 'devoted', 'devout', 'dutiful', 'ethical'],
    'dutiful': ['christian', 'christianlike', 'christianly', 'accommodating', 'acquiescent', 'active', 'adoring', 'attentive', 'believing', 'cap in hand', 'ceremonious', 'compliant'],
    'duty': ['mass', 'vat', 'accountability', 'active service', 'ad valorem duty', 'admiration', 'adoration', 'alcohol tax', 'allegiance', 'amenability', 'amusement tax', 'answerability'],
    'dwarf': ['ariel', 'befind', 'corrigan', 'finnbeara', 'lilliputian', 'mab', 'oberon', 'titania', 'tom thumb', 'ace', 'atom', 'banshee'],
    'dwarfed': ['lenten', 'lilliputian', 'spartan', 'tom thumb', 'abstemious', 'ascetic', 'austere', 'bandy', 'bandy-legged', 'blemished', 'bloated', 'bowlegged'],
    'dwell': ['abide', 'berth', 'bide', 'bunk', 'carry on', 'cohabit', 'continue', 'continue to be', 'defeat time', 'defy time', 'dig', 'domicile'],
    'dwell in': ['abide in', 'be coextensive with', 'be comprised in', 'be constituted by', 'be contained in', 'be found', 'be located', 'be met with', 'be present', 'be present in', 'be situated', 'be there'],
    'dwell on': ['accent', 'accentuate', 'always trot out', 'bear in mind', 'belabor', 'breathe vengeance', 'brood over', 'cherish', 'continue', 'dawdle', 'drag out', 'draw out'],
    'dweller': ['addressee', 'artist-in-residence', 'denizen', 'habitant', 'house detective', 'incumbent', 'inhabitant', 'inhabiter', 'inmate', 'inpatient', 'intern', 'live-in maid'],
    'dwelling': ['abiding', 'abiding place', 'abode', 'address', 'cantonment', 'cohabitation', 'commorancy', 'commorant', 'crash pad', 'crib', 'domicile', 'domus'],
    'dwindle': ['abate', 'ablate', 'attenuate', 'bate', 'be consumed', 'be eaten away', 'be gone', 'calm', 'calm down', 'cease', 'cease to be', 'cease to exist'],
    'dwindling': ['at rest', 'calm', 'catabasis', 'cloistered', 'collapse', 'coming apart', 'contractive', 'cool', 'cracking', 'crash', 'crumbling', 'decadent'],
    'dyad': ['both', 'brace', 'couple', 'couplet', 'distich', 'double harness', 'doublet', 'duad', 'duet', 'duo', 'match', 'mates'],
    'dybbuk': ['baba yaga', 'lilith', 'masan', 'afreet', 'apparition', 'appearance', 'astral', 'astral spirit', 'banshee', 'barghest', 'cacodemon', 'control'],
    'dye': ['acid color', 'aniline', 'aniline dye', 'apply paint', 'artificial dye', 'bedaub', 'bedizen', 'begild', 'besmear', 'besprinkle', 'breathe', 'brew'],
    'dyed-in-the-wool': ['absolute', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'born', 'broad-based', 'chronic', 'clean', 'clear', 'colorfast', 'comprehensive'],
    'dying': ['abatement', 'abridgment', 'alleviation', 'annihilation', 'attenuation', 'bad', 'bane', 'biological death', 'brittle', 'burning out', 'burnout', 'capricious'],
    'dyke': ['amazon', 'androgyne', 'auntie', 'bi-guy', 'bisexual', 'bull dyke', 'butch', 'catamite', 'chicken', 'fag', 'faggot', 'fairy'],
    'dynamic': ['activating', 'active', 'acute', 'adventuresome', 'adventurous', 'aggressive', 'alive', 'ambitious', 'animated', 'armipotent', 'authoritative', 'brisk'],
    'dynamics': ['activity', 'actuation', 'aerodynamics', 'barodynamics', 'biodynamics', 'fluid dynamics', 'geodynamics', 'going', 'hydrodynamics', 'kinematics', 'kinesiology', 'kinesipathy'],
    'dynamism': ['adventuresomeness', 'adventurousness', 'aggression', 'aggressiveness', 'ambitiousness', 'demonic energy', 'drive', 'energy', 'enterprise', 'enterprisingness', 'ergal', 'force'],
    'dynamite': ['ballistite', 'tnt', 'annihilate', 'cellulose nitrate', 'cordite', 'decimate', 'demolish', 'dismantle', 'dissolve', 'explosive', 'gunpowder', 'high explosive'],
    'dynamiter': ['annihilator', 'arsonist', 'biblioclast', 'bomber', 'burner', 'demolisher', 'destroyer', 'dynamitard', 'exterminator', 'hun', 'iconoclast', 'idol breaker'],
    'dynast': ['anointed king', 'chief', 'chieftain', 'crowned head', 'emperor', 'grand duke', 'high chief', 'imperator', 'king', 'king-emperor', 'kinglet', 'lord paramount'],
    'dyne': ['atomerg', 'calorie', 'carat', 'centigram', 'decagram', 'decigram', 'dinamode', 'dram', 'dram avoirdupois', 'energid', 'erg', 'foot-pound'],
    'dysentery': ['african lethargy', 'asiatic cholera', 'bm', 'chagres fever', 'german measles', 'haverhill fever', 'abscess', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery'],
    'dyspepsia': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'bleeding'],
    'dyspeptic': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'bitter', 'cancerous', 'case', 'chlorotic', 'choleric', 'colicky', 'consumptive'],
    'dysphasia': ['aphasia', 'aphonia', 'artificial voice', 'broken speech', 'broken tones', 'broken voice', 'childish treble', 'choked voice', 'cracked voice', 'croak', 'crow', 'dysarthria'],
    'dystopia': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley'],
    'each': ['all', 'all and some', 'all and sundry', 'any', 'apiece', 'aside', 'each and all', 'each and every', 'each one', 'each to each', 'every', 'every one'],
    'eager': ['accordant', 'acquiescent', 'acquisitive', 'affirmative', 'agape', 'agog', 'agreeable', 'agreeing', 'alacritous', 'all agog', 'ambitious', 'amenable'],
    'eager beaver': ['activist', 'addict', 'ball of fire', 'beaver', 'big-time operator', 'bug', 'bustler', 'busy bee', 'collector', 'demon', 'doer', 'energumen'],
    'eagerly': ['animatedly', 'anxiously', 'ardently', 'avidly', 'breathlessly', 'de bonne volonte', 'enthusiastically', 'impatiently', 'keenly', 'promptly', 'quickly', 'readily'],
    'eagerness': ['ok', 'a thing for', 'acceptance', 'accord', 'acquiescence', 'affinity', 'affirmation', 'affirmative', 'affirmative voice', 'agreeability', 'agreeableness', 'agreement'],
    'eagle': ['argus', 'hershey bar', 'achievement', 'alerion', 'animal charge', 'annulet', 'antelope', 'argent', 'armorial bearings', 'armory', 'arms', 'arrow'],
    'eagle eye': ['x-ray eye', 'custodianship', 'custody', 'eye', 'gimlet eye', 'guard', 'guardedness', 'guardianship', 'invigilation', 'keen eye', 'lookout', 'monitoring'],
    'ear': ['eustachian tube', 'advertence', 'advertency', 'alertness', 'anvil', 'assiduity', 'assiduousness', 'attention', 'attention span', 'attentiveness', 'audibility', 'audience'],
    'ear lobe': ['eustachian tube', 'anvil', 'auditory apparatus', 'auditory canal', 'auditory meatus', 'auditory nerve', 'auditory ossicles', 'auditory tube', 'auricle', 'basilar membrane', 'bony labyrinth', 'cauliflower ear'],
    'ear piercing': ['acute', 'argute', 'booming', 'creaky', 'deafening', 'ear-rending', 'ear-splitting', 'earthshaking', 'forte', 'fortissimo', 'full', 'howling'],
    'ear splitting': ['booming', 'deafening', 'ear-piercing', 'ear-rending', 'earthshaking', 'forte', 'fortissimo', 'full', 'loud', 'loud-sounding', 'loudish', 'pealing'],
    'eardrum': ['eustachian tube', 'allantoic membrane', 'amnion', 'amniotic sac', 'anvil', 'arachnoid membrane', 'auditory apparatus', 'auditory canal', 'auditory meatus', 'auditory nerve', 'auditory ossicles', 'auditory tube'],
    'earl': ['brahman', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'blue blood', 'count', 'daimio', 'duke', 'esquire', 'gentleman'],
    'earlier': ['aforetime', 'already', 'antecedent', 'anterior', 'anticipatory', 'as yet', 'before', 'before all', 'before now', 'beforehand', 'beforetime', 'ci-devant'],
    'earliness': ['anachronism', 'antecedence', 'antecedency', 'antedate', 'antedating', 'anteriority', 'anticipation', 'earlier state', 'historical error', 'lateness', 'metachronism', 'misdate'],
    'early': ['a priori', 'advanced', 'ages ago', 'ahead', 'ahead of time', 'already', 'anachronistic', 'ancient', 'anciently', 'antecedent', 'antedated', 'antediluvian'],
    'earmark': ['allocate', 'allot', 'appoint', 'appropriate to', 'aroma', 'assign', 'assign to', 'attribute', 'badge', 'banner', 'be characteristic', 'birthmark'],
    'earn': ['acquire', 'attain', 'bag', 'be deserving', 'be entitled to', 'be paid', 'be remunerated', 'be salaried', 'be seized of', 'be worthy of', 'bring in', 'capture'],
    'earnest': ['abandoned', 'acquitment', 'acquittal', 'acquittance', 'advertent', 'afire', 'agog', 'alert', 'all ears', 'all eyes', 'amortization', 'amortizement'],
    'earnestly': ['actively', 'ardently', 'assiduously', 'bec et ongles', 'committedly', 'decidedly', 'decisively', 'decorously', 'demurely', 'determinedly', 'devotedly', 'devoutly'],
    'earnestness': ['abandon', 'absorption', 'advertence', 'advertency', 'alertness', 'ardency', 'ardor', 'assiduity', 'assiduousness', 'attention', 'attention span', 'attentiveness'],
    'earnings': ['accession', 'acquirement', 'acquisition', 'addition', 'attainment', 'avails', 'base pay', 'box office', 'capital gains', 'cleanup', 'clear profit', 'coming by'],
    'earphone': ['acoustical network', 'capacitor speaker', 'coaxial speaker', 'cone', 'crossover network', 'diaphragm', 'dynamic speaker', 'electrodynamic speaker', 'electromagnetic speaker', 'electrostatic speaker', 'excited-field speaker', 'full-fidelity speaker'],
    'earring': ['anklet', 'armlet', 'band', 'bangle', 'beads', 'belt', 'bijou', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet'],
    'earshot': ['ace', 'auditory range', 'bit', 'bowshot', 'brief span', 'carrying distance', 'close quarters', 'close range', 'crack', 'earreach', 'gunshot', 'hair'],
    'earth': ['gaea', 'ge', 'jupiter', 'mars', 'mercury', 'neptune', 'pluto', 'saturn', 'tellus', 'terra', 'uranus', 'venus'],
    'earthborn': ['adamite', 'adamitic', 'anthropocentric', 'anthropological', 'baseborn', 'below the salt', 'cockney', 'common', 'commonplace', 'earthy', 'finite', 'fleshly'],
    'earthbound': ['arid', 'barren', 'dry', 'dull', 'earth', 'earthly', 'fluvioterrestrial', 'geophilous', 'infecund', 'infertile', 'literal', 'mundane'],
    'earthenware': ['kinkozan ware', 'leeds pottery', 'limoges', 'meissen ware', 'nabeshima ware', 'satsuma ware', 'seto ware', 'appliances', 'basalt', 'brassware', 'china', 'chinaware'],
    'earthiness': ['adam', 'philistinism', 'animalism', 'animality', 'beastliness', 'bestiality', 'brutality', 'brutishness', 'carnal nature', 'carnal-mindedness', 'carnality', 'coarseness'],
    'earthling': ['adamite', 'antichristian', 'being', 'body', 'cat', 'chap', 'character', 'creature', 'customer', 'duck', 'fellow', 'groundling'],
    'earthly': ['philistine', 'base', 'bodily', 'carnal', 'carnal-minded', 'conceivable', 'corporal', 'corporeal', 'earth', 'earthbound', 'earthy', 'feasible'],
    'earthquake': ['apoplexy', 'breakup', 'cataclysm', 'climax', 'convulsion', 'diastrophism', 'disaster', 'fit', 'overthrow', 'paroxysm', 'quake', 'quaker'],
    'earthshaker': ['astonishment', 'blockbuster', 'blow', 'bomb', 'bombshell', 'catch', 'eye-opener', 'joker', 'kicker', 'peripeteia', 'revelation', 'shocker'],
    'earthshaking': ['big', 'big-league', 'big-name', 'big-time', 'bigwig', 'bigwigged', 'booming', 'consequential', 'considerable', 'deafening', 'double-barreled', 'ear-piercing'],
    'earthwork': ['abatis', 'advanced work', 'arch dam', 'backstop', 'balistraria', 'bamboo curtain', 'bank', 'banquette', 'bar', 'barbed-wire entanglement', 'barbican', 'barrage'],
    'earthy': ['adamic', 'adamite', 'adamitic', 'circean', 'philistine', 'abandoned', 'adobe', 'animal', 'animalistic', 'anthropocentric', 'anthropological', 'banausic'],
    'ease': ['atticism', 'bohemianism', 'easy street', 'abandon', 'abate', 'abatement', 'abet', 'abundance', 'acceptance', 'adeptness', 'adroitness', 'advance'],
    'ease off': ['abate', 'arrest', 'avert', 'backpedal', 'backwater', 'bate', 'bear off', 'brake', 'check', 'clip the wings', 'curb', 'decelerate'],
    'ease up': ['abate', 'arrest', 'backpedal', 'backwater', 'bate', 'brake', 'check', 'clip the wings', 'curb', 'decelerate', 'delay', 'detain'],
    'easel': ['air brush', 'art paper', 'brush', 'camera lucida', 'camera obscura', 'canvas', 'chalk', 'charcoal', 'crayon', 'drawing paper', 'drawing pencil', 'drier'],
    'easement': ['abatement', 'absolute interest', 'aid and comfort', 'allayment', 'alleviation', 'analgesia', 'anesthesia', 'anesthetizing', 'appeasement', 'assuagement', 'assurance', 'benefit'],
    'easily': ['absolutely', 'actually', 'assuredly', 'by far', 'cautiously', 'certainly', 'circumspectly', 'clearly', 'comfortably', 'commodiously', 'competently', 'compliantly'],
    'easing': ['abatement', 'abating', 'allaying', 'allayment', 'alleviating', 'alleviation', 'alleviative', 'analgesia', 'analgesic', 'anesthesia', 'anesthetic', 'anesthetizing'],
    'east': ['antarctic', 'arctic', 'austral', 'boreal', 'cardinal points', 'compass card', 'compass rose', 'degrees', 'eastabout', 'eastbound', 'easterly', 'eastermost'],
    'easter': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas'],
    'easterly': ['euroclydon', 'tehuantepec wind', 'tehuantepecer', 'antarctic', 'arctic', 'austral', 'bise', 'boreal', 'east', 'east wind', 'eastabout', 'eastbound'],
    'easy': ['attic', 'bohemian', 'ciceronian', 'mickey mouse', 'paphian', 'accepting', 'accommodating', 'acquiescent', 'affable', 'affluent', 'agreeable', 'ambling'],
    'easy going': ['clarity', 'clear coast', 'clear road', 'ease', 'easiness', 'effortlessness', 'facileness', 'facility', 'freedom', 'highroad', 'intelligibility', 'lack of hindrance'],
    'easy mark': ['babe', 'boob', 'butt', 'chump', 'cinch', 'credulous person', 'cull', 'dupe', 'easy pickings', 'fall guy', 'fish', 'fool'],
    'easy street': ['affluence', 'bed of roses', 'clover', 'comfort', 'ease', 'easy circumstances', 'felicity', 'fleshpots', 'gracious life', 'gracious living', 'happiness', 'lap of luxury'],
    'easygoing': ['bohemian', 'micawberish', 'accepting', 'affable', 'afoot and lighthearted', 'airy', 'apathetic', 'at ease', 'at large', 'at liberty', 'ataractic', 'backward'],
    'eat': ['ablate', 'absorb', 'assimilate', 'bite', 'bleed white', 'break bread', 'burn up', 'canker', 'consume', 'corrode', 'count calories', 'deplete'],
    'eat away': ['abate', 'abrade', 'abstract', 'bate', 'bite', 'canker', 'corrode', 'curtail', 'decrease', 'deduct', 'depreciate', 'derogate'],
    'eat crow': ['abjure', 'back down', 'back out', 'backwater', 'climb down', 'crawfish out', 'deny', 'disavow', 'disclaim', 'disown', 'eat dirt', 'eat humble pie'],
    'eat up': ['ablate', 'absorb', 'adore', 'and sinker', 'appreciate', 'assimilate', 'banquet', 'bask in', 'be a sucker', 'be pleased with', 'be taken in', 'bite'],
    'eating': ['cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'dining', 'drinking', 'engorgement', 'engulfment', 'feeding', 'flesh-eating', 'fruitarian'],
    'eaves': ['ceiling', 'housetop', 'lantern', 'overhead', 'penthouse', 'plafond', 'ridgepole', 'roof', 'roof garden', 'roof-deck', 'roofage', 'roofing'],
    'eavesdrop': ['attend', 'attend to', 'auscultate', 'be all ears', 'bend an ear', 'bug', 'cock the ears', 'examine by ear', 'give attention', 'give audience to', 'give ear', 'hark'],
    'eavesdropper': ['paul pry', 'peeping tom', 'audient', 'auditor', 'busybody', 'gossip', 'hearer', 'hearkener', 'inquirer', 'inquisitive', 'inquisitor', 'listener'],
    'ebb': ['abate', 'ablate', 'advance', 'ascend', 'back', 'back up', 'bate', 'be eaten away', 'budge', 'calm', 'calm down', 'catabasis'],
    'ebb and flow': ['lissajous figure', 'alternate', 'alternation', 'back and fill', 'back-and-forth', 'battledore and shuttlecock', 'be poised', 'billow', 'break', 'comb', 'come and go', 'coming and going'],
    'ebb tide': ['dead low water', 'direct tide', 'ebb', 'ebb and flow', 'flood', 'flood tide', 'flow', 'flux', 'flux and reflux', 'full tide', 'high tide', 'high water'],
    'ebony': ['acacia', 'ailanthus', 'alder', 'alligator pear', 'allspice', 'almond', 'apple', 'apricot', 'ash', 'aspen', 'atramentous', 'avocado'],
    'ebullient': ['active', 'activist', 'activistic', 'agog', 'alive', 'animated', 'aquiver', 'ardent', 'aroused', 'atingle', 'atwitter', 'baking'],
    'ebullition': ['ado', 'agitation', 'bluster', 'bobbery', 'boil', 'boiling', 'brawl', 'broil', 'brouhaha', 'bubbliness', 'bubbling', 'bustle'],
    'eccentric': ['aberrant', 'abnormal', 'absurd', 'adrift', 'afloat', 'alien', 'alternating', 'amorphous', 'amusing', 'anomalistic', 'anomalous', 'beezer'],
    'eccentricity': ['aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'absurdity', 'absurdness', 'amorphism', 'animus', 'anomalism', 'anomalousness', 'anomaly'],
    'ecclesiastic': ['dd', 'doctor of divinity', 'holy joe', 'abbe', 'chaplain', 'churchman', 'clergyman', 'cleric', 'clerical', 'clerk', 'curate', 'cure'],
    'ecclesiastical': ['abbatial', 'abbatical', 'apostolic', 'archiepiscopal', 'canonical', 'capitular', 'capitulary', 'cathedral-like', 'cathedralesque', 'church', 'churchish', 'churchlike'],
    'echelon': ['battle array', 'caste', 'class', 'close formation', 'condition', 'deployment', 'disposition', 'file', 'footing', 'formation', 'formation flying', 'hierarchy'],
    'echo': ['crt spot', 'dm display', 'doppler signal', 'if signal', 'im display', 'rf echoes', 'accord', 'acknowledge', 'acknowledgment', 'act like', 'action and reaction', 'adumbration'],
    'echoic': ['answering', 'antiphonal', 'apish', 'battological', 'booming', 'confutative', 'conjugate', 'delineatory', 'depictive', 'derivative', 'duplicative', 'echoing'],
    'echoing': ['answering', 'antiphonal', 'battological', 'booming', 'confutative', 'duplicative', 'echoic', 'growling', 'imitative', 'iterative', 'lingering', 'parrotlike'],
    'eclair': ['danish pastry', 'french pastry', 'baklava', 'blintz', 'chocolate eclair', 'cream puff', 'dowdy', 'pandowdy', 'pastry', 'pasty', 'patisserie', 'patty'],
    'eclampsia': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'akinetic epilepsy', 'apoplexy', 'arrest', 'attack', 'autonomic epilepsy'],
    'eclat': ['pr', 'acclaim', 'acclamation', 'applause', 'ballyhoo', 'bang', 'big hand', 'blazon', 'blurb', 'bravura', 'bright light', 'brilliance'],
    'eclectic': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'adoptive', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'animist', 'animistic'],
    'eclipse': ['adumbrate', 'annular eclipse', 'apply to', 'bandage', 'becloud', 'bedarken', 'bedazzle', 'bedim', 'befog', 'begloom', 'benight', 'black'],
    'ecliptic': ['anklet', 'aphelion', 'apogee', 'armlet', 'astronomical longitude', 'autumnal equinox', 'band', 'belt', 'bracelet', 'celestial equator', 'celestial longitude', 'celestial meridian'],
    'ecology': ['aerobiology', 'agrobiology', 'anatomy', 'animal physiology', 'anthropology', 'astrobiology', 'autecology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology'],
    'economic': ['scotch', 'budget', 'budgetary', 'canny', 'careful', 'chary', 'cheap', 'cheeseparing', 'commercial', 'conserving', 'easy', 'economizing'],
    'economical': ['scotch', 'budget', 'canny', 'careful', 'chary', 'cheap', 'cheeseparing', 'close', 'conservative', 'conserving', 'easy', 'economic'],
    'economically': ['briefly', 'cannily', 'carefully', 'charily', 'compendiously', 'concisely', 'curtly', 'frugally', 'husbandly', 'in brief compass', 'providently', 'prudently'],
    'economics': ['keynesian economics', 'keynesianism', 'lombard street', 'wall street banking', 'classical economics', 'dynamic economics', 'econ', 'econometrics', 'economic determinism', 'economic man', 'economic science', 'economism'],
    'economizing': ['scotch', 'canny', 'careful', 'chary', 'cheeseparing', 'conserving', 'cooling', 'cooling down', 'cooling off', 'curtailment', 'cutback', 'economic'],
    'economy': ['gnp', 'barter economy', 'brevity', 'briefness', 'budget', 'capitalistic economy', 'carefulness', 'cheap', 'cheeseparing', 'collectivized economy', 'compactness', 'conciseness'],
    'ecosphere': ['aerosphere', 'all that lives', 'atmosphere', 'biochore', 'biocycle', 'biosphere', 'biota', 'biotope', 'brawn', 'fiber', 'flesh', 'flora and fauna'],
    'ecru': ['aureate', 'auric', 'beige', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'buff', 'buff-yellow', 'canary', 'canary-yellow', 'chocolate'],
    'ecstasy': ['abandon', 'affection', 'affectionateness', 'afflatus', 'amativeness', 'amorousness', 'ardency', 'ardor', 'beatification', 'beatitude', 'bewitchment', 'blessedness'],
    'ecstatic': ['abandoned', 'absent', 'absentminded', 'absorbed', 'abstracted', 'amok', 'bellowing', 'bemused', 'berserk', 'blissful', 'bursting with happiness', 'carried away'],
    'ectoplasm': ['animal cell', 'aura', 'bioplast', 'cell', 'cellular tissue', 'cellule', 'chromatoplasm', 'coenocyte', 'corpuscle', 'cytoplasm', 'ectoplasy', 'effluvium'],
    'ectoplasmic': ['astral', 'ethereal', 'etheric', 'ghostish', 'ghostlike', 'ghostly', 'ghosty', 'incorporeal', 'phantasmal', 'phantasmic', 'phantom', 'phantomic'],
    'ecumenical': ['all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'allover', 'broad', 'broad-gauged'],
    'ecumenism': ['anschluss', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'amalgamation', 'assimilation', 'association', 'bipartisanship', 'blend'],
    'eczema': ['acne', 'acne vulgaris', 'allergen', 'allergic disorder', 'allergy', 'asthma', 'conjunctivitis', 'cosmetic dermatitis', 'dermamycosis', 'dermatitis', 'dermatosis', 'elephantiasis'],
    'eddy': ['charybdis', 'maelstrom', 'ado', 'agitation', 'back', 'back stream', 'backflow', 'backwash', 'backwater', 'brouhaha', 'bustle', 'centrifugate'],
    'edema': ['abscess', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'aggrandizement', 'ague', 'amplification'],
    'eden': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley', 'land of youth'],
    'edge': ['acerbity', 'acidity', 'acidulousness', 'acme', 'acridity', 'acrimony', 'acuity', 'aculeate', 'acuminate', 'acumination', 'acuteness', 'adjoin'],
    'edge in': ['admit', 'barge in', 'be admitted', 'break in', 'break in upon', 'breeze in', 'burst in', 'bust in', 'butt in', 'charge in', 'come barging in', 'come between'],
    'edge tool': ['adz', 'ax', 'blade', 'bread knife', 'bushwhacker', 'butcher knife', 'carving knife', 'chaser', 'chisel', 'cleaver', 'clipper', 'clippers'],
    'edgewise': ['aside', 'askance', 'askant', 'asquint', 'broadside', 'broadside on', 'crabwise', 'edgeway', 'edgeways', 'glancingly', 'laterad', 'laterally'],
    'edgy': ['agitable', 'all nerves', 'antsy', 'antsy-pantsy', 'anxious', 'apprehensive', 'breathless', 'chafing', 'combustible', 'eager', 'emotional', 'emotionally unstable'],
    'edible': ['board', 'bread', 'bread and butter', 'cheer', 'comestible', 'comestibles', 'creature comfort', 'cuisine', 'daily bread', 'dainty', 'delicious', 'digestible'],
    'edict': ['act', 'announcement', 'annunciation', 'appointment', 'bill', 'brevet', 'bull', 'bulletin board', 'bylaw', 'canon', 'circular', 'communique'],
    'edification': ['accomplishments', 'acquisition of knowledge', 'acquisitions', 'attainments', 'catechization', 'coaching', 'didactics', 'direction', 'education', 'enlightening', 'enlightenment', 'guidance'],
    'edifice': ['dymaxion house', 'white house', 'adobe house', 'architecture', 'building', 'casa', 'cliff dwelling', 'construct', 'construction', 'consulate', 'country house', 'country seat'],
    'edify': ['acculturate', 'advance', 'ameliorate', 'amend', 'better', 'boost', 'bring forward', 'broaden the mind', 'catechize', 'civilize', 'demonstrate', 'direct'],
    'edifying': ['autodidactic', 'coeducational', 'cultural', 'didactic', 'disciplinary', 'educating', 'educational', 'educative', 'enlightening', 'exhortatory', 'homiletic', 'hortatory'],
    'edit': ['abbreviate', 'abridge', 'adapt', 'alter', 'amend', 'annotate', 'arrange', 'assemble', 'blip', 'blot out', 'blue-pencil', 'bowdlerize'],
    'edition': ['arrangement', 'back number', 'collection', 'composite reading', 'conflation', 'copy', 'critical edition', 'diplomatic text', 'draft', 'edited text', 'hymnal', 'hymnbook'],
    'editor': ['allegorist', 'annotator', 'bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliomane', 'bibliomaniac', 'bibliopegist', 'bibliophage', 'bibliophile', 'bibliopole'],
    'editorial': ['allegorizing', 'analysis', 'annotative', 'article', 'clarifying', 'column', 'comment', 'commentary', 'commentation', 'critical', 'critical review', 'criticism'],
    'editorialize': ['author', 'coauthor', 'collaborate', 'compose', 'dash off', 'formulate', 'free-lance', 'ghost', 'ghostwrite', 'indite', 'knock off', 'knock out'],
    'educable': ['apt', 'bright', 'clever', 'docile', 'facile', 'formable', 'impressionable', 'instructable', 'intelligent', 'malleable', 'moldable', 'motivated'],
    'educate': ['acculturate', 'advance', 'ameliorate', 'amend', 'better', 'boost', 'brief', 'bring forward', 'bring up', 'broaden the mind', 'catechize', 'civilize'],
    'educated': ['abreast of', 'abstruse', 'advanced', 'ameliorated', 'au courant', 'autodidactic', 'beautified', 'bettered', 'briefed', 'civilized', 'converted', 'critical'],
    'education': ['accomplishments', 'acculturation', 'acquisition of knowledge', 'acquisitions', 'attainments', 'broadening the mind', 'catechization', 'civility', 'civilization', 'coaching', 'course of study', 'cultivation'],
    'educational': ['academic', 'advisory', 'autodidactic', 'coeducational', 'communicative', 'cultural', 'didactic', 'disciplinary', 'edifying', 'educating', 'educative', 'enlightening'],
    'educator': ['abecedarian', 'certified teacher', 'docent', 'doctor', 'dominie', 'don', 'educationist', 'fellow', 'guide', 'guru', 'instructor', 'maestro'],
    'educe': ['arouse', 'bring forth', 'bring out', 'bring to light', 'call forth', 'call out', 'call up', 'deduce', 'derive', 'distill', 'drag', 'drag out'],
    'edulcorate': ['bolt', 'candy', 'clarify', 'clear', 'decrassify', 'depurate', 'distill', 'dulcify', 'elute', 'essentialize', 'extract', 'filter'],
    'eerie': ['arcane', 'awe-inspiring', 'awesome', 'awful', 'awing', 'bizarre', 'blue', 'cadaverous', 'corpselike', 'crawly', 'creepy', 'deadly'],
    'eeriness': ['hippocratic face', 'alarmingness', 'appallingness', 'awfulness', 'cadaverousness', 'corpselikeness', 'creepiness', 'deadliness', 'deathlikeness', 'deathliness', 'direness', 'disconcertingness'],
    'efface': ['annul', 'black out', 'blot', 'blot out', 'cancel', 'cross out', 'dele', 'delete', 'eliminate', 'eradicate', 'erase', 'exclude'],
    'effect': ['abide by', 'accomplish', 'achieve', 'actualize', 'actually', 'adhere to', 'administer', 'affective meaning', 'aftereffect', 'aftermath', 'aim', 'ambition'],
    'effective': ['able', 'acid', 'active', 'actual', 'adequate', 'armipotent', 'authoritative', 'banausic', 'basic', 'biting', 'capable', 'charismatic'],
    'effectively': ['ably', 'adequately', 'advantageously', 'ardently', 'capably', 'cogently', 'competently', 'conveniently', 'dynamically', 'effectually', 'efficiently', 'eloquently'],
    'effectiveness': ['acme', 'amperage', 'applicability', 'armipotence', 'authority', 'authorization', 'availability', 'be-all and end-all', 'beef', 'bite', 'bitingness', 'black power'],
    'effects': ['acquest', 'belongings', 'catalog goods', 'chattels', 'clobber', 'commodities', 'consumer goods', 'consumer items', 'crap', 'estate and effects', 'gear', 'goods'],
    'effectual': ['able', 'achieving', 'active', 'actual', 'adequate', 'ascertained', 'attested', 'authenticated', 'authoritative', 'banausic', 'behind the scenes', 'binding'],
    'effectuate': ['abide by', 'accomplish', 'achieve', 'act', 'adhere to', 'administer', 'attain', 'author', 'be productive', 'bear', 'beget', 'breed'],
    'effeminate': ['ac-dc', 'amphierotic', 'autoerotic', 'bent', 'bisexed', 'bisexual', 'breakable', 'brittle', 'butch', 'campy', 'cheap-jack', 'chicken'],
    'effeminize': ['castrate', 'demasculinize', 'desex', 'desexualize', 'devitalize', 'effeminate', 'effeminatize', 'emasculate', 'enervate', 'etiolate', 'exhaust', 'geld'],
    'effervesce': ['assibilate', 'be enthusiastic', 'blubber', 'boil', 'boil over', 'bubble', 'bubble over', 'bubble up', 'burble', 'buzz', 'carry on over', 'enthuse'],
    'effervescence': ['ado', 'agitation', 'animation', 'assibilation', 'boiling', 'breeziness', 'briskness', 'brouhaha', 'bubbliness', 'bubbling', 'buoyancy', 'bustle'],
    'effervescent': ['active', 'activist', 'activistic', 'agog', 'airy', 'alive', 'animated', 'aquiver', 'aroused', 'atingle', 'atwitter', 'beaten'],
    'effete': ['ablated', 'all in', 'anemic', 'arid', 'asthenic', 'ausgespielt', 'barren', 'blah', 'blank', 'bleary', 'bloodless', 'bootless'],
    'efficacious': ['able', 'active', 'adequate', 'authoritative', 'capable', 'charismatic', 'charming', 'competent', 'consequential', 'effective', 'effectual', 'efficient'],
    'efficiency': ['ability', 'able', 'ableness', 'address', 'adept', 'adeptness', 'adequacy', 'adroitness', 'airmanship', 'applicability', 'artfulness', 'artisanship'],
    'efficient': ['able', 'active', 'adequate', 'au fait', 'banausic', 'capable', 'competent', 'economic', 'effective', 'effectual', 'efficacious', 'equal to'],
    'efficiently': ['ably', 'adeptly', 'adequately', 'adroitly', 'advantageously', 'agilely', 'aptly', 'artfully', 'artistically', 'brilliantly', 'capably', 'cleverly'],
    'effigy': ['companion', 'copy', 'dead ringer', 'double', 'duplicate', 'exact likeness', 'fellow', 'icon', 'idol', 'image', 'likeness', 'living image'],
    'effluent': ['affluent', 'bayou', 'billabong', 'branch', 'confluent', 'confluent stream', 'dejecta', 'dejection', 'dejecture', 'dendritic drainage pattern', 'discharge', 'effused'],
    'effluvium': ['afterdamp', 'aroma', 'aura', 'blackdamp', 'breath', 'chokedamp', 'cloud', 'coal gas', 'damp', 'definite odor', 'detectable odor', 'ectoplasm'],
    'effort': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'ad hoc measure', 'adventure', 'affair', 'answer', 'application', 'approach'],
    'effortless': ['mickey mouse', 'adept', 'casual', 'clear', 'cursive', 'cushy', 'easy', 'easy as pie', 'expert', 'facile', 'flowing', 'fluent'],
    'effortlessly': ['adeptly', 'adroitly', 'easily', 'efficiently', 'expertly', 'facilely', 'freely', 'hands down', 'lightly', 'like clockwork', 'like nothing', 'no sweat'],
    'effrontery': ['arrogance', 'assurance', 'audacity', 'boldness', 'brashness', 'brass', 'brazenness', 'bumptiousness', 'cheek', 'confidence', 'contumely', 'crust'],
    'effuse': ['abounding', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'arise', 'bail out', 'bleed', 'bottomless', 'bounteous', 'bountiful'],
    'effusive': ['abundant', 'accessible', 'all jaw', 'approachable', 'candid', 'chatty', 'cloying', 'communicative', 'conversable', 'conversational', 'copious', 'demonstrative'],
    'egest': ['barf', 'be seasick', 'be sick', 'bring up', 'chuck up', 'discharge', 'disgorge', 'effuse', 'eliminate', 'emit', 'excrete', 'extravasate'],
    'egg': ['anlage', 'albumen', 'boiled eggs', 'bud', 'caviar', 'coddled eggs', 'deviled eggs', 'dropped eggs', 'egg cell', 'egg white', 'eggs', 'eggshell'],
    'egg on': ['agitate', 'arouse', 'cheer on', 'drive', 'drive on', 'excite', 'exhort', 'goad', 'goad on', 'hasten on', 'hie on', 'hound on'],
    'egg white': ['albumen', 'batter', 'bonnyclabber', 'butter', 'caviar', 'clabber', 'cornstarch', 'cream', 'curd', 'dough', 'egg', 'eggshell'],
    'eggbeater': ['agitator', 'beater', 'blender', 'cement mixer', 'chopper', 'churn', 'copter', 'crucible', 'emulsifier', 'helicopter', 'jiggler', 'melting pot'],
    'eggshell': ['alabaster', 'alabastrine', 'albescent', 'albumen', 'bubble', 'caviar', 'china', 'cream', 'creamy', 'delicate', 'dun-white', 'egg'],
    'ego': ['i myself', 'alter', 'alter ego', 'alterum', 'anima', 'anima humana', 'atman', 'ba', 'better self', 'breath', 'breath of life', 'buddhi'],
    'ego trip': ['acquisitiveness', 'amour-propre', 'autism', 'autoeroticism', 'boast', 'careerism', 'complacency', 'consequentiality', 'egotism', 'fish for compliments', 'graspingness', 'greed'],
    'egocentric': ['narcissus', 'braggart', 'compare', 'conceited', 'egocentristic', 'egoist', 'egoistic', 'egomaniacal', 'egotist', 'egotistic', 'egotistical', 'individualist'],
    'egotism': ['acquisitiveness', 'arrogance', 'autism', 'boastfulness', 'boasting', 'bragging', 'careerism', 'conceit', 'conceitedness', 'contempt', 'ego', 'ego trip'],
    'egotist': ['narcissus', 'braggart', 'careerist', 'egocentric', 'egoist', 'fortune hunter', 'hog', 'individualist', 'know-it-all', 'lone wolf', 'loner', 'monopolist'],
    'egotistic': ['acquisitive', 'ambitious for self', 'autistic', 'boastful', 'careerist', 'cocky', 'conceited', 'egocentric', 'egocentristic', 'egoistic', 'egomaniacal', 'egotistical'],
    'egotistical': ['acquisitive', 'ambitious for self', 'autistic', 'boastful', 'boasting', 'bragging', 'careerist', 'conceited', 'crowing', 'egocentric', 'egocentristic', 'egoistic'],
    'egregious': ['a bit much', 'abandoned', 'abominable', 'absolute', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'appalling', 'arrant', 'astonishing', 'atrocious'],
    'egress': ['abandonment', 'adit', 'avenue', 'blowhole', 'bow out', 'channel', 'chute', 'cleaning out', 'clearance', 'clearing', 'conduit', 'course'],
    'eiderdown': ['afghan', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedsheet', 'bedspread', 'blanket', 'blubber', 'breeze', 'buffalo robe', 'butter'],
    'eidolon': ['masan', 'angle', 'apparition', 'appearance', 'aspect', 'astral', 'astral spirit', 'banshee', 'brainchild', 'bubble', 'chimera', 'configuration'],
    'eight': ['octateuch', 'cast', 'company', 'complement', 'crew', 'eighter from decatur', 'eleven', 'first string', 'first team', 'five', 'nine', 'octad'],
    'eighth': ['contraoctave', 'double contraoctave', 'eightfold', 'four-foot octave', 'four-line octave', 'great octave', 'octadic', 'octagonal', 'octahedral', 'octal', 'octan', 'octaploid'],
    'eighty six': ['abandon', 'cast', 'cast aside', 'cast away', 'cast off', 'chuck', 'deep-six', 'discard', 'dispose of', 'ditch', 'dump', 'eliminate'],
    'either': ['a certain', 'a deux', 'an', 'any', 'any one', 'anybody', 'anyone', 'anything', 'atomic', 'aught', 'both', 'correspondingly'],
    'ejaculate': ['achieve satisfaction', 'blat', 'blow out', 'blurt', 'blurt out', 'bolt', 'burst out', 'cast forth', 'climax', 'come', 'cry', 'debouch'],
    'ejaculation': ['blowout', 'blurt', 'discharge', 'disgorgement', 'ecphonesis', 'effusion', 'egestion', 'ejection', 'elimination', 'emission', 'eructation', 'eruption'],
    'ejaculatory': ['blurting', 'concupiscent', 'goatish', 'horny', 'hot', 'hot-blooded', 'itching', 'lascivious', 'libidinous', 'lickerish', 'lustful', 'orgasmic'],
    'eject': ['abrupt', 'abstract', 'alienate', 'axe', 'belch', 'blow open', 'blow out', 'boot out', 'bounce', 'break out', 'bump', 'burst forth'],
    'ejection': ['banishment', 'bowshot', 'bullet', 'cannon', 'cashiering', 'clearance', 'conge', 'dejecta', 'dejection', 'dejecture', 'deportation', 'detachment'],
    'ejection seat': ['mae west', 'bolt-hole', 'breeches buoy', 'buoy', 'cork jacket', 'ejection capsule', 'ejector seat', 'emergency exit', 'escape hatch', 'fire escape', 'inflatable slide', 'life belt'],
    'eke out': ['accomplish', 'bring to completion', 'bring to fruition', 'complete', 'cope', 'fill in', 'fill out', 'fulfill', 'get by', 'keep afloat', 'make ends meet', 'make good'],
    'el': ['amtrak', 'baggage train', 'branch', 'cable railroad', 'cable railway', 'choo-choo', 'cog railroad', 'cog railway', 'electric', 'electric railway', 'electric train', 'elevated'],
    'elaborate': ['babylonian', 'byzantine', 'corinthian', 'gongoresque', 'gongoristic', 'marinistic', 'adorn', 'affected', 'amplify', 'arabesque', 'artificial', 'assemble'],
    'elaborateness': ['babylonian splendor', 'arabesque', 'baroque', 'baroqueness', 'brilliance', 'chinoiserie', 'elegance', 'fanciness', 'fineness', 'flamboyance', 'floridity', 'floridness'],
    'elaboration': ['accomplishment', 'adjunct', 'adornment', 'advance', 'advancement', 'amplification', 'architecture', 'arrangement', 'assembly', 'beautification', 'blossoming', 'building'],
    'elan': ['activity', 'alacrity', 'animal spirits', 'animation', 'anxiety', 'anxiousness', 'appetite', 'ardor', 'avidity', 'avidness', 'breathless impatience', 'brio'],
    'elapse': ['advance', 'be all over', 'be gone', 'be past', 'continue', 'die', 'disappear', 'endure', 'expire', 'flit', 'flow', 'flow on'],
    'elapsed': ['ago', 'antiquated', 'antique', 'blown over', 'by', 'bygone', 'bypast', 'dated', 'dead', 'dead and buried', 'deceased', 'defunct'],
    'elastic': ['lastex', 'accommodating', 'adaptable', 'adaptive', 'adjustable', 'airy', 'animated', 'baleen', 'battledore', 'bendable', 'bending', 'bouncy'],
    'elasticity': ['adaptability', 'adjustability', 'agreeability', 'amenability', 'beef', 'beefiness', 'bendability', 'brawn', 'brawniness', 'ductibility', 'ductility', 'extendibility'],
    'elate': ['brighten', 'buoy', 'cheer', 'cheer up', 'delight', 'do proud', 'elevate', 'encourage', 'exalt', 'excite', 'exhilarate', 'flush'],
    'elated': ['beaming', 'blissful', 'blithe', 'blithesome', 'bloated', 'bloated with pride', 'bright', 'bright and sunny', 'bursting with happiness', 'carried away', 'cheerful', 'cheery'],
    'elation': ['abstraction', 'abulia', 'alienation', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss'],
    'elbow': ['angle', 'angle off', 'ankle', 'apex', 'arm', 'articulation', 'assault', 'barge in', 'bear', 'bear upon', 'bend', 'biceps'],
    'elbowroom': ['air space', 'ample scope', 'blank check', 'carte blanche', 'clearance', 'field', 'free course', 'free hand', 'free play', 'free scope', 'full scope', 'full swing'],
    'elder': ['aaronic priesthood', 'bible clerk', 'bible reader', 'establishment', 'father time', 'melchizedek priesthood', 'methuselah', 'nestor', 'old paar', 'seventy', 'vip', 'acolyte'],
    'elder statesman': ['admirable crichton', 'adept', 'artisan', 'artist', 'attache', 'authority', 'connaisseur', 'connoisseur', 'consultant', 'cordon bleu', 'crack shot', 'craftsman'],
    'elderly': ['advanced', 'advanced in life', 'advanced in years', 'age-old', 'aged', 'ageing', 'ageless', 'aging', 'along in years', 'ancient', 'anile', 'antique'],
    'elect': ['ffvs', 'accept', 'accepted', 'admit', 'adopted', 'ancienne noblesse', 'appoint', 'appointed', 'approved', 'aristocracy', 'back', 'back up'],
    'elected': ['accepted', 'adopted', 'appointed', 'approved', 'carried', 'chosen', 'designated', 'elect', 'elected by acclamation', 'embraced', 'espoused', 'handpicked'],
    'election': ['calvinism', 'accession', 'alternative', 'alternativity', 'anointing', 'anointment', 'apostolic orders', 'appointment', 'arrogation', 'assignment', 'assumption', 'authorization'],
    'elective': ['academic specialty', 'adoptive', 'alternative', 'appointive', 'arbitrary', 'area', 'autonomous', 'choosing', 'choosy', 'classical education', 'constituent', 'core curriculum'],
    'electorate': ['kreis', 'archbishopric', 'archdiocese', 'arrondissement', 'bailiwick', 'bishopric', 'borough', 'canton', 'chooser', 'city', 'commune', 'congressional district'],
    'electric': ['amtrak', 'baggage train', 'cable railroad', 'charged', 'choo-choo', 'cog railroad', 'cog railway', 'el', 'electric car', 'electric train', 'electrifying', 'elevated'],
    'electric chair': ['ax', 'block', 'cross', 'death chair', 'death chamber', 'drop', 'gallows', 'gallows-tree', 'gas chamber', 'gibbet', 'guillotine', 'halter'],
    'electric current': ['ac', 'dc', 'absorption current', 'active current', 'alternating current', 'base current', 'cathode current', 'collector current', 'conduction current', 'convection current', 'cycle', 'delta current'],
    'electric meter': ['vom', 'vtvm', 'ammeter', 'ampere-hour meter', 'coulometer', 'dynamometer', 'expansion ammeter', 'faradmeter', 'galvanometer', 'hysteresis meter', 'magnetometer', 'megohmmeter'],
    'electric power': ['atomic power', 'electric horsepower', 'electropower', 'horsepower', 'hydraulic power', 'hydroelectric power', 'hydroelectricity', 'impulse', 'jet power', 'manpower', 'nuclear power', 'piston power'],
    'electric wire': ['bx cable', 'armored cable', 'battery cable', 'bell wire', 'coaxial cable', 'electric cable', 'electric cord', 'highline', 'hookup wire', 'lead', 'line', 'power line'],
    'electrical': ['agitating', 'battery-powered', 'breathtaking', 'charged', 'cliff-hanging', 'disquieting', 'distracting', 'disturbing', 'dynamoelectric', 'electric', 'electric-powered', 'electrified'],
    'electricity': ['telautography', 'teletype', 'teletype network', 'teletyping', 'antelope', 'ardor', 'arrow', 'benzine', 'blue darter', 'blue streak', 'cannonball', 'closed-circuit telegraphy'],
    'electrified': ['battery-powered', 'bowled down', 'charged', 'dynamoelectric', 'electric', 'electric-powered', 'electrifying', 'electrochemical', 'electrodynamic', 'electrokinetic', 'electromechanical', 'electrometric'],
    'electrify': ['agitate', 'amaze', 'amplify', 'animate', 'arouse', 'astonish', 'astound', 'bowl down', 'bowl over', 'charge', 'discombobulate', 'discompose'],
    'electrifying': ['abrupt', 'astonishing', 'battery-powered', 'dynamoelectric', 'electric', 'electric-powered', 'electrified', 'electrochemical', 'electrodynamic', 'electrokinetic', 'electromechanical', 'electrometric'],
    'electrocution': ['beheading', 'burning', 'capital punishment', 'crucifixion', 'decapitation', 'decollation', 'defenestration', 'execution', 'fusillade', 'garrote', 'gassing', 'hanging'],
    'electrolysis': ['acetification', 'acidification', 'acidulation', 'alkalization', 'anion', 'bloodless surgery', 'carbonation', 'catalysis', 'cation', 'cauterization', 'cautery', 'chemicalization'],
    'electrolyze': ['acetify', 'acidify', 'acidulate', 'alkalify', 'alkalize', 'borate', 'carbonate', 'catalyze', 'chemical', 'chlorinate', 'dialyze', 'dissociate'],
    'electromagnetism': ['diamagnetism', 'ferromagnetism', 'gilbert', 'hysteresis', 'hysteresis curve', 'magnetic circuit', 'magnetic conductivity', 'magnetic creeping', 'magnetic curves', 'magnetic dip', 'magnetic elements', 'magnetic figures'],
    'electron': ['kern', 'nmr', 'alpha particle', 'antibaryon', 'antilepton', 'antimeson', 'atom', 'atomic nucleus', 'atomic particle', 'baryon', 'beta particle', 'cathode particle'],
    'electron emission': ['becquerel ray', 'grenz ray', 'roentgen ray', 'x radiation', 'x ray', 'actinic ray', 'alpha radiation', 'alpha ray', 'anode ray', 'beta radiation', 'beta ray', 'canal ray'],
    'electronics': ['newtonian physics', 'acoustics', 'aerophysics', 'applied physics', 'astrophysics', 'basic conductor physics', 'biophysics', 'chemical physics', 'cryogenics', 'crystallography', 'cytophysics', 'electron physics'],
    'electroplating': ['anion', 'anodized aluminum', 'cation', 'chromium plate', 'copperplate', 'electrocoating', 'electroetching', 'electrogalvanization', 'electrogilding', 'electrograving', 'electrolysis', 'electrolyte'],
    'electrostatic': ['battery-powered', 'biostatic', 'dynamoelectric', 'electric', 'electric-powered', 'electrified', 'electrifying', 'electrochemical', 'electrodynamic', 'electrokinetic', 'electromechanical', 'electrometric'],
    'eleemosynary': ['almsgiving', 'altruistic', 'beneficent', 'benevolent', 'bighearted', 'charitable', 'complimentary', 'costless', 'expenseless', 'for free', 'for love', 'for nothing'],
    'elegance': ['babylonian splendor', 'acquired taste', 'amenities', 'appreciation of excellence', 'arabesque', 'attractiveness', 'baroque', 'baroqueness', 'beauteousness', 'beautifulness', 'beauty', 'beauty unadorned'],
    'elegant': ['attic', 'babylonian', 'ciceronian', 'corinthian', 'advantageous', 'aesthetic', 'aesthetically appealing', 'apt', 'arabesque', 'artistic', 'attractive', 'august'],
    'elegiac': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'bardic', 'bucolic', 'didactic', 'dirgelike'],
    'elegist': ['meistersinger', 'parnassian', 'arch-poet', 'ballad maker', 'balladmonger', 'bard', 'beat poet', 'bucoliast', 'epic poet', 'fili', 'idyllist', 'imagist'],
    'elegize': ['bemoan', 'bewail', 'climb parnassus', 'compose poetry', 'deplore', 'dirge', 'give sorrow words', 'grieve', 'keen', 'knell', 'lament', 'lisp in numbers'],
    'elegy': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'element': ['acid', 'acidity', 'addend', 'adjunct', 'agent', 'air', 'alkali', 'alkalinity', 'alloisomer', 'americium', 'anion', 'antacid'],
    'elemental': ['ab ovo', 'abecedarian', 'aboriginal', 'acid', 'aerographic', 'aerologic', 'alkali', 'antenatal', 'autochthonous', 'baric', 'barographic', 'barometric'],
    'elementary': ['ab ovo', 'abecedarian', 'aboriginal', 'acid', 'alkali', 'antenatal', 'austere', 'autochthonous', 'bare', 'basal', 'basic', 'basilar'],
    'elementary education': ['abecedarium', 'abecedary', 'adult education', 'and arithmetic', 'continuing education', 'elements', 'first steps', 'graduate education', 'higher education', 'hornbook', 'initiation', 'introduction'],
    'elementary particle': ['kern', 'nmr', 'air', 'alpha particle', 'antibaryon', 'antilepton', 'antimeson', 'atom', 'atomic nucleus', 'atomic particle', 'atomic particles', 'baryon'],
    'elements': ['communion', 'eucharist', 'holy communion', 'host', 'last supper', 'sacrament sunday', 'abecedarium', 'abecedary', 'alphabet', 'altar bread', 'and arithmetic', 'basics'],
    'elephant': ['angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'indian buffalo', 'jumbo', 'kodiak bear', 'siberian husky', 'virginia deer', 'aardvark', 'aardwolf', 'alpaca'],
    'elephantine': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'latinate', 'abysmal', 'arid', 'astronomic', 'awkward', 'barren'],
    'elevate': ['acculturate', 'advance', 'aggrandize', 'ameliorate', 'amend', 'apotheose', 'apotheosize', 'beatify', 'better', 'boost', 'bring forward', 'buoy up'],
    'elevated': ['amtrak', 'gongoresque', 'johnsonian', 'olympian', 'accelerated', 'aerial', 'affected', 'afflicted', 'aggrandized', 'airy', 'altitudinous', 'amplified'],
    'elevation': ['olympian heights', 'access', 'accession', 'acclivity', 'accretion', 'accrual', 'accruement', 'accumulation', 'acme', 'addition', 'advance', 'advancement'],
    'eleven': ['sexagesima', 'boxcar', 'boxcars', 'cast', 'company', 'complement', 'crew', 'dozen', 'duodecimo', 'eight', 'eighty', 'fifteen'],
    'eleventh hour': ['a-day', 'd day', 'h hour', 'bedtime', 'belatedness', 'charged moment', 'critical moment', 'crucial moment', 'curfew', 'deadline', 'deathbed', 'decisive moment'],
    'elf': ['ariel', 'befind', 'corrigan', 'dingbelle', 'fifinella', 'finnbeara', 'hob', 'hobgoblin', 'jd', 'lilliputian', 'mab', 'oberon'],
    'elfdom': ['eeriness', 'faerie', 'miraculousness', 'mysteriousness', 'mystery', 'numinousness', 'otherworldliness', 'preternaturalism', 'superhumanity', 'supernaturalism', 'supernaturality', 'supernaturalness'],
    'elfin': ['lilliputian', 'tom thumb', 'arch', 'dainty', 'diminutive', 'dumpy', 'dwarf', 'dwarfed', 'dwarfish', 'elfish', 'elflike', 'elvish'],
    'elfish': ['arch', 'devilish', 'elfin', 'elflike', 'elvish', 'faery', 'fairy', 'fairyish', 'fairylike', 'fay', 'foolish', 'full of mischief'],
    'elicit': ['arouse', 'bring', 'bring about', 'bring forth', 'bring on', 'bring out', 'bring to light', 'call forth', 'call out', 'call up', 'cause', 'contrive'],
    'elide': ['abbreviate', 'abridge', 'abstract', 'bob', 'boil down', 'capsulize', 'cast off', 'cast out', 'chuck', 'clear', 'clear away', 'clear out'],
    'eligibility': ['acceptability', 'admissibility', 'admission', 'assimilation', 'completeness', 'comprehension', 'comprehensiveness', 'comprisal', 'coverage', 'desirability', 'eligible', 'embodiment'],
    'eligible': ['acceptability', 'acceptable', 'admissible', 'appropriate', 'available', 'capable', 'desirability', 'desirable', 'eligibility', 'enfranchised', 'fit', 'fitness'],
    'eliminate': ['abandon', 'abscind', 'abstract', 'amputate', 'annihilate', 'assassinate', 'ban', 'bar', 'bate', 'blow', 'blow out', 'bob'],
    'elimination': ['abolishment', 'abolition', 'abscission', 'amputation', 'annihilation', 'annulment', 'assassination', 'bloody murder', 'bumping-off', 'castaway', 'castoff', 'choking'],
    'elision': ['abbreviation', 'abridgment', 'abstract', 'apocope', 'aposiopesis', 'clipping', 'compression', 'condensation', 'conspectus', 'contraction', 'crasis', 'curtailment'],
    'elite': ['ffvs', 'vanity fair', 'ancienne noblesse', 'aristocracy', 'baronage', 'baronetage', 'barons', 'beau monde', 'beautiful people', 'best', 'best people', 'bunch'],
    'elitist': ['brahmin', 'aristocratic', 'dictatorial', 'egghead', 'high and mighty', 'highbrow', 'highbrowed', 'hubristic', 'imperious', 'intellectual', 'intellectualistic', 'lordly'],
    'elixir': ['axiom', 'balm', 'balsam', 'base', 'basis', 'broad-spectrum drug', 'catholicon', 'center', 'compound', 'concentrate', 'concentration', 'core'],
    'elk': ['cape elk', 'virginia deer', 'antelope', 'buck', 'camel', 'camelopard', 'caribou', 'deer', 'deerlet', 'doe', 'dromedary', 'eland'],
    'ell': ['addition', 'angle', 'annex', 'apex', 'arm', 'bend', 'bifurcation', 'bight', 'block', 'cant', 'chevron', 'coin'],
    'ellipse': ['arc', 'bow', 'catacaustic', 'catenary', 'caustic', 'circle', 'conchoid', 'crook', 'curl', 'curve', 'diacaustic', 'festoon'],
    'ellipsis': ['abbreviation', 'abridgment', 'abstract', 'apocope', 'aposiopesis', 'clipping', 'compression', 'condensation', 'conspectus', 'contraction', 'crasis', 'curtailment'],
    'ellipsoid': ['ball', 'balloon', 'bladder', 'blob', 'boll', 'bolus', 'bubble', 'bulb', 'bulbil', 'bulblet', 'geoid', 'globe'],
    'ellipsoidal': ['bell-like', 'bell-shaped', 'bulblike', 'bulbous', 'campaniform', 'campanular', 'campanulate', 'ellipsoid', 'elliptic', 'global', 'globate', 'globe-shaped'],
    'elliptic': ['spartan', 'abbreviated', 'abridged', 'abstracted', 'aposiopestic', 'bell-like', 'bell-shaped', 'bobbed', 'brief', 'brusque', 'campaniform', 'campanular'],
    'elliptical': ['spartan', 'abbreviated', 'abridged', 'abstracted', 'aposiopestic', 'bell-like', 'bell-shaped', 'bobbed', 'brief', 'brusque', 'campaniform', 'campanular'],
    'elocution': ['accents', 'chatter', 'comment', 'conversation', 'debating', 'declamation', 'demagogism', 'discourse', 'eloquence', 'forensics', 'gab', 'homiletics'],
    'elongate': ['continue', 'drag out', 'draw', 'draw out', 'elongated', 'extend', 'extended', 'lengthen', 'lengthen out', 'lengthened', 'lengthy', 'let out'],
    'elongated': ['dragged out', 'drawn', 'drawn out', 'drawn-out', 'elliptical', 'elongate', 'extended', 'lengthened', 'lengthy', 'oblong', 'oblongated', 'oblongitudinal'],
    'elope': ['abscond', 'absquatulate', 'beat a retreat', 'bolt', 'clear out', 'cut and run', 'decamp', 'depart', 'desert', 'flee', 'fly', 'fugitate'],
    'elopement': ['awol', 'french leave', 'gretna green wedding', 'absence without leave', 'absquatulation', 'banns', 'bolt', 'bridal', 'bridal suite', 'bridechamber', 'chuppah', 'church wedding'],
    'eloquence': ['articulacy', 'articulateness', 'debating', 'declamation', 'demagogism', 'elocution', 'expression', 'expressiveness', 'facility of speech', 'facundity', 'fervor', 'force'],
    'eloquent': ['ciceronian', 'demosthenian', 'demosthenic', 'tullian', 'affecting', 'ardent', 'articulate', 'cogent', 'convincing', 'declamatory', 'effective', 'elocutionary'],
    'else': ['above', 'added', 'additionally', 'again', 'alias', 'all included', 'also', 'altogether', 'among other things', 'and all', 'and also', 'and so'],
    'elsewhere': ['abroad', 'absent', 'absentminded', 'absorbed', 'abstracted', 'away', 'bemused', 'castle-building', 'daydreaming', 'daydreamy', 'dreaming', 'dreamy'],
    'elucidate': ['account for', 'allegorize', 'annotate', 'clarify', 'clear', 'clear up', 'crack', 'decipher', 'demonstrate', 'demythologize', 'enlighten', 'euhemerize'],
    'elucidation': ['allegorization', 'clarification', 'cracking', 'decipherment', 'decoding', 'demonstration', 'demythologization', 'editing', 'emendation', 'enlightenment', 'euhemerism', 'exegesis'],
    'elucidative': ['allegorizing', 'annotative', 'clarifying', 'critical', 'demonstrative', 'demythologizing', 'editorial', 'enlightening', 'euhemeristic', 'exegetic', 'exemplificative', 'explaining'],
    'elude': ['avoid', 'baffle', 'balk', 'beg', 'bewilder', 'bilk', 'blast', 'brave', 'challenge', 'checkmate', 'circumvent', 'confound'],
    'elusion': ['avoidance', 'avoiding reaction', 'buck-passing', 'circumvention', 'defense mechanism', 'dodge', 'duck', 'elusiveness', 'equivocation', 'escape', 'eschewal', 'evasion'],
    'elusive': ['baffling', 'cagey', 'elusory', 'evanescent', 'evasive', 'fleeting', 'fugitive', 'impalpable', 'imponderable', 'incomprehensible', 'indefinable', 'insubstantial'],
    'elysian': ['olympian', 'beatific', 'beatified', 'blessed', 'blissful', 'celestial', 'divine', 'empyreal', 'empyrean', 'ethereal', 'extramundane', 'extraterrestrial'],
    'emaciate': ['sanforize', 'atrophy', 'attenuate', 'consume', 'consume away', 'dilute', 'dribble away', 'dry up', 'emacerate', 'macerate', 'parch', 'pine away'],
    'emaciated': ['sanforized', 'anorectic', 'anorexic', 'atrophied', 'attenuated', 'bony', 'brittle', 'cadaverous', 'consumed', 'consumptive', 'corky', 'corpselike'],
    'emanate': ['accrue from', 'arise', 'arise from', 'attend', 'bail out', 'be contingent on', 'be due to', 'birth', 'break cover', 'break forth', 'bud from', 'burst forth'],
    'emanation': ['aroma', 'aura', 'breath', 'definite odor', 'detectable odor', 'diffusion', 'discharge', 'dispersion', 'ectoplasm', 'ectoplasy', 'effluvium', 'emergence'],
    'emancipate': ['affranchise', 'deliver', 'discharge', 'disenthrall', 'enfranchise', 'free', 'let go', 'let loose', 'liberate', 'loose', 'loosen', 'manumit'],
    'emancipated': ['afoot and lighthearted', 'at large', 'at liberty', 'clear', 'delivered', 'detached', 'disengaged', 'easygoing', 'extricated', 'footloose', 'footloose and fancy-free', 'free'],
    'emasculate': ['alter', 'castrate', 'cripple', 'debilitate', 'demasculinize', 'desex', 'desexualize', 'devitalize', 'disable', 'effeminate', 'effeminatize', 'effeminize'],
    'emasculated': ['asexual', 'bad', 'castrated', 'cold', 'crippled', 'debilitated', 'demasculinized', 'devitalized', 'disabled', 'effeminized', 'emasculate', 'enervated'],
    'embalm': ['anhydrate', 'aromatize', 'blast-freeze', 'brine', 'cense', 'corn', 'cure', 'dehydrate', 'desiccate', 'dry', 'dry-cure', 'dry-salt'],
    'embalming': ['anhydration', 'blast-freezing', 'bottling', 'brining', 'canning', 'corning', 'curing', 'dehydration', 'desiccation', 'dry-curing', 'drying', 'embalmment'],
    'embankment': ['abutment', 'anchorage', 'anchorage ground', 'anthill', 'arc-boutant', 'arch dam', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier'],
    'embargo': ['eighteenth amendment', 'prohibition party', 'volstead act', 'ban', 'bar', 'bar out', 'barrier', 'barring', 'block', 'blockade', 'blockage', 'boycott'],
    'embark': ['air-express', 'airfreight', 'airmail', 'assume', 'begin', 'board', 'commence', 'consign', 'dispatch', 'drop a letter', 'embark on', 'embus'],
    'embark upon': ['accept', 'assume', 'attack', 'attempt', 'buckle to', 'come out', 'embark in', 'embark on', 'endeavor', 'engage in', 'enter', 'enter on'],
    'embarkation': ['boarding', 'coming out', 'curtain raiser', 'debut', 'disembarkation', 'embarkment', 'emplanement', 'enplanement', 'entrainment', 'first appearance', 'floating', 'flotation'],
    'embarrass': ['abash', 'absorb', 'addle', 'addle the wits', 'agitate', 'awkward', 'ball up', 'becloud', 'bedazzle', 'befuddle', 'bewilder', 'bother'],
    'embarrassed': ['abashed', 'abroad', 'adrift', 'afflicted', 'agitated', 'annoyed', 'anxious', 'ashamed', 'astray', 'at sea', 'badly off', 'balled-up'],
    'embarrassing': ['awkward', 'baffling', 'bewildering', 'bothering', 'chastening', 'confounding', 'confusing', 'crushing', 'discomposing', 'disconcerting', 'dismaying', 'distracting'],
    'embarrassment': ['abasement', 'abashment', 'absorption', 'agitation', 'awkwardness', 'baffle', 'bafflement', 'bashfulness', 'befuddlement', 'bewilderment', 'bind', 'bother'],
    'embassy': ['dymaxion house', 'white house', 'adobe house', 'advice', 'agency', 'agentship', 'assignment', 'authority', 'authorization', 'booking office', 'box office', 'branch'],
    'embattle': ['arm', 'armor', 'armor-plate', 'bank', 'barricade', 'battle', 'blockade', 'bulwark', 'castellate', 'crenellate', 'dig in', 'entrench'],
    'embed': ['bed', 'bed in', 'comprise', 'confirm', 'contain', 'deep-dye', 'define', 'enclose', 'enfold', 'engraft', 'engrave', 'entrench'],
    'embellish': ['adorn', 'apparel', 'array', 'beautify', 'bedeck', 'bedizen', 'belie', 'blazon', 'camouflage', 'caparison', 'color', 'convolute'],
    'embellished': ['adorned', 'advanced', 'affected', 'ameliorated', 'apocryphal', 'artificial', 'assumed', 'bastard', 'beaded', 'beautified', 'bedecked', 'bedizened'],
    'embellishment': ['acciaccatura', 'adjunct', 'adornment', 'appoggiatura', 'arabesque', 'arrangement', 'beauties', 'beautification', 'bedizenment', 'cadence', 'cadenza', 'color'],
    'ember': ['alluvion', 'alluvium', 'ash', 'brand', 'burning ember', 'cinder', 'clinker', 'coal', 'deposition', 'deposits', 'diluvium', 'draff'],
    'ember days': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas'],
    'embezzle': ['abstract', 'abuse', 'and', 'annex', 'appropriate', 'bag', 'befoul', 'boost', 'borrow', 'convert', 'cop', 'crib'],
    'embezzlement': ['abstraction', 'abuse', 'abuse of office', 'annexation', 'appropriation', 'befoulment', 'boosting', 'conversion', 'conveyance', 'corrupt administration', 'debasement', 'defalcation'],
    'embitter': ['acerbate', 'afflict', 'agent provocateur', 'aggravate', 'aggrieve', 'alienate', 'amplify', 'anguish', 'annoy', 'antagonize', 'arouse', 'augment'],
    'embittered': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrimonious', 'aggravated', 'amplified', 'angry', 'annoyed'],
    'emblazon': ['adorn', 'adulate', 'advertise', 'air', 'apotheosize', 'apply paint', 'array', 'beautify', 'bedaub', 'bedeck', 'bedizen', 'begild'],
    'emblem': ['adumbration', 'allegory', 'armory', 'attribute', 'badge', 'badge of office', 'badges', 'baton', 'blazonry', 'brassard', 'button', 'cap and gown'],
    'embodied': ['compact of', 'composed of', 'composing', 'comprising', 'consisting of', 'constituting', 'contained in', 'containing', 'embodied in', 'embodying', 'formed of', 'incarnate'],
    'embodiment': ['anschluss', 'christophany', 'satanophany', 'acting', 'actualization', 'addition', 'admissibility', 'admission', 'affiliation', 'agglomeration', 'aggregation', 'agreement'],
    'embody': ['absorb', 'actualize', 'add', 'admit', 'adumbrate', 'affect', 'amalgamate', 'assemble', 'assimilate', 'betoken', 'blend', 'body'],
    'embolden': ['abet', 'advocate', 'aid and abet', 'animate', 'assure', 'bolster', 'brace up', 'buck up', 'chance', 'cheer', 'chirk up', 'comfort'],
    'embolism': ['bar', 'barrier', 'blank wall', 'blind alley', 'blind gut', 'block', 'blockade', 'blockage', 'bottleneck', 'cecum', 'choking', 'choking off'],
    'embossed': ['anaglyphic', 'anaglyptic', 'anastatic', 'bold', 'bossed', 'bossy', 'carved', 'ceroplastic', 'chased', 'confirmed', 'deep-dyed', 'deep-engraven'],
    'embossment': ['anaglyph', 'bas-relief', 'bellying', 'boldness', 'boss', 'bulging', 'bump', 'cameo', 'cameo glass', 'cavo-rilievo', 'colophon', 'concavity'],
    'embrace': ['abduct', 'accept', 'accommodate', 'accost', 'accouple', 'accueil', 'accumulate', 'address', 'adhere', 'adhere to', 'admit', 'adopt'],
    'embracing': ['adoption', 'ambient', 'assimilating', 'circling', 'circumambient', 'circumferential', 'circumflex', 'circumfluent', 'circumfluous', 'circumjacent', 'comprising', 'containing'],
    'embrocate': ['anoint', 'beeswax', 'daub', 'dope', 'dose', 'dress', 'drug', 'glycerolate', 'grease', 'grease the wheels', 'lard', 'lubricate'],
    'embroider': ['adorn', 'aggrandize', 'amplify', 'applique', 'array', 'baste', 'beautify', 'bedeck', 'bedizen', 'belie', 'bind', 'blazon'],
    'embroidered': ['adorned', 'affected', 'apocryphal', 'artificial', 'assumed', 'bastard', 'befrilled', 'bogus', 'brummagem', 'colorable', 'colored', 'counterfeit'],
    'embroidery': ['adjunct', 'adornment', 'applique', 'arrangement', 'basting', 'beauties', 'binding', 'buttonholing', 'color', 'color patterns', 'colors', 'colors of rhetoric'],
    'embroilment': ['action', 'ado', 'aerial combat', 'affray', 'agitation', 'altercation', 'argument', 'armored combat', 'battle', 'battle royal', 'bicker', 'bickering'],
    'embryology': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology', 'biometrics'],
    'embryonic': ['abecedarian', 'aboriginal', 'antenatal', 'arrested', 'atomic', 'autochthonous', 'backward', 'basal', 'basic', 'beginning', 'budding', 'callow'],
    'emcee': ['aftra', 'abbot of unreason', 'dj', 'lord of misrule', 'mc', 'anchor man', 'announcer', 'attorney', 'auteur', 'bailiff', 'ballyhoo man', 'barker'],
    'emend': ['acculturate', 'advance', 'alter', 'ameliorate', 'amend', 'better', 'blue-pencil', 'boost', 'bring forward', 'civilize', 'compensate', 'correct'],
    'emerald': ['adamant', 'aestival', 'agate', 'alexandrite', 'amethyst', 'aquamarine', 'beryl', 'beryl-green', 'berylline', 'bloodstone', 'blue-green', 'bluish-green'],
    'emerge': ['accrue from', 'appear', 'arise', 'arise from', 'bail out', 'be contingent on', 'be due to', 'be revealed', 'become known', 'become manifest', 'become visible', 'break cover'],
    'emergence': ['apparition', 'appearance', 'appearing', 'arising', 'avatar', 'break', 'breakout', 'coming', 'coming into being', 'coming-forth', 'deliverance', 'delivery'],
    'emergency': ['x ray', 'blood bank', 'breakers ahead', 'cardhouse', 'cause for alarm', 'charity ward', 'climacteric', 'clinic', 'clutch', 'consultation room', 'contingency', 'convergence of events'],
    'emergent': ['approaching', 'arising', 'charged', 'climacteric', 'coming', 'critical', 'crucial', 'decisive', 'desired', 'destinal', 'destined', 'determined'],
    'emeritus': ['assistant', 'assistant professor', 'associate', 'associate professor', 'in retirement', 'instructor', 'lecturer', 'on pension', 'pensioned', 'pensioned off', 'professor', 'professor emeritus'],
    'emery': ['aluminum oxide', 'auto polish', 'colcothar', 'corundum', 'crocus', 'emery board', 'emery paper', 'file', 'garnet', 'grindstone', 'hone', 'nail file'],
    'emetic': ['abstergent', 'cathartic', 'cleaner', 'cleaning', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing', 'cleansing cream', 'cold cream', 'cream', 'dentifrice'],
    'emigrant': ['dp', 'alien', 'arriviste', 'colonist', 'departer', 'displaced person', 'emigre', 'evacue', 'evacuee', 'exile', 'expatriate', 'fugitive'],
    'emigrate': ['depart', 'deport', 'exile', 'expatriate', 'flit', 'forsake', 'go from home', 'immigrate', 'in-migrate', 'intermigrate', 'leave', 'leave home'],
    'eminence': ['olympian heights', 'vip', 'acme', 'aerial heights', 'altitude', 'apex', 'ascendancy', 'august', 'authority', 'bas-relief', 'bellying', 'big-name'],
    'eminent': ['olympian', 'a cut above', 'above', 'absolute', 'aerial', 'aggrandized', 'ahead', 'airy', 'altitudinous', 'apotheosized', 'ascendant', 'ascending'],
    'eminent domain': ['angary', 'annexation', 'annexure', 'ascendance', 'ascendancy', 'attachment', 'balance of power', 'collectivization', 'commandeering', 'communalization', 'communization', 'confiscation'],
    'eminently': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'celebratedly', 'consequentially', 'conspicuously', 'copiously', 'egregiously', 'emphatically'],
    'emir': ['esquire', 'great mogul', 'master', 'mister', 'mogul', 'muslim rulers', 'prinz', 'sir', 'atheling', 'caliph', 'cham', 'crown prince'],
    'emissary': ['hermes', 'iris', 'mercury', 'paul revere', 'pheidippides', 'ambassador', 'ambassadress', 'apostolic delegate', 'attache', 'bearer', 'career diplomat', 'carrier'],
    'emission': ['blowout', 'discharge', 'disgorgement', 'effusion', 'egestion', 'ejaculation', 'ejection', 'elimination', 'emanation', 'emergence', 'emersion', 'eructation'],
    'emit': ['aerate', 'aerify', 'articulate', 'atomize', 'bleed', 'blow', 'breathe', 'breathe out', 'bring out', 'carbonate', 'chime', 'chlorinate'],
    'emollient': ['alleviating', 'alleviative', 'analgesic', 'anesthetic', 'anodyne', 'assuasive', 'balm', 'balmy', 'balsam', 'balsamic', 'benumbing', 'brilliantine'],
    'emote': ['act', 'act as foil', 'appear', 'barnstorm', 'be theatrical', 'carry on', 'come out', 'emotionalize', 'get top billing', 'gush', 'ham it up', 'make a scene'],
    'emotion': ['a high', 'affect', 'affection', 'affectivity', 'arousal', 'attitude', 'emotional charge', 'emotional shade', 'emotivity', 'excitability', 'excitedness', 'excitement'],
    'emotional': ['affecting', 'affectional', 'affective', 'agitable', 'agitated', 'ardent', 'characteristic', 'constitutional', 'demonstrative', 'dispositional', 'edgy', 'emote'],
    'emotionalism': ['abstraction', 'abulia', 'agitability', 'alienation', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'blood and thunder', 'catatonic stupor', 'combustibility', 'compulsion'],
    'emotionalize': ['act', 'act as foil', 'appear', 'barnstorm', 'be theatrical', 'come out', 'emote', 'get top billing', 'gush', 'ham it up', 'make a scene', 'mime'],
    'emotionless': ['chill', 'cold', 'cold-blooded', 'cool', 'dispassionate', 'distant', 'frigid', 'glacial', 'heartless', 'icy', 'immovable', 'impassive'],
    'emotive': ['affecting', 'affectional', 'affective', 'demonstrative', 'emotiometabolic', 'emotiomotor', 'emotional', 'emotionalistic', 'emotiovascular', 'feeling', 'glandular', 'gut'],
    'empathetic': ['accordant', 'agreeable', 'agreeing', 'akin', 'allergic', 'amicable', 'anaphylactic', 'at one', 'attuned', 'compatible', 'concordant', 'congenial'],
    'empathize': ['accord', 'agree', 'agree with', 'be affected', 'be in tune', 'be inspired', 'be involved', 'be moved', 'care about', 'catch the flame', 'catch the infection', 'change color'],
    'empathy': ['accent', 'accentuation', 'accord', 'accordance', 'affinity', 'agape', 'agreement', 'allergy', 'amity', 'anaphylaxis', 'appreciation', 'attention'],
    'emperor': ['anointed king', 'chief', 'chieftain', 'crowned head', 'dynast', 'grand duke', 'high chief', 'imperator', 'king', 'king-emperor', 'kinglet', 'lord paramount'],
    'emphasis': ['alexandrine', 'accent', 'accentuation', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antispast', 'arsis', 'attention', 'bacchius', 'beat'],
    'emphasize': ['accent', 'accentuate', 'assert', 'bear down on', 'belabor', 'call attention to', 'charge', 'dwell on', 'feature', 'give emphasis to', 'harp on', 'highlight'],
    'emphatic': ['absolute', 'accented', 'accentuated', 'affirmative', 'affirmatory', 'aggressive', 'ardent', 'assertative', 'assertional', 'assertive', 'burning', 'categorical'],
    'emphatically': ['absolutely', 'abundantly', 'acutely', 'affirmatively', 'amazingly', 'amply', 'assertively', 'astonishingly', 'awesomely', 'conspicuously', 'copiously', 'decidedly'],
    'emphysema': ['asiatic flu', 'hong kong flu', 'acute bronchitis', 'adenoiditis', 'aluminosis', 'amygdalitis', 'anthracosilicosis', 'anthracosis', 'asbestosis', 'asthma', 'atypical pneumonia', 'bituminosis'],
    'empire': ['administration', 'ally', 'archduchy', 'archdukedom', 'authority', 'body politic', 'buffer state', 'caliphate', 'captive nation', 'chieftaincy', 'chieftainry', 'city-state'],
    'empirical': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'animist', 'animistic', 'atomistic', 'cosmotheistic', 'cut-and-try', 'eclectic', 'eudaemonistic'],
    'empiricism': ['christian ethics', 'marxism', 'r and d', 'stoicism', 'altruistic ethics', 'animalism', 'aretaics', 'atomism', 'behaviorism', 'casuistry', 'categorical imperative', 'commonsense realism'],
    'emplacement': ['abode', 'allocation', 'area', 'assignment', 'balcony', 'bearings', 'bench mark', 'catafalque', 'collocation', 'dais', 'deployment', 'deposit'],
    'employ': ['active use', 'activities', 'activity', 'add', 'affair', 'affairs', 'appliance', 'application', 'apply', 'attend to business', 'attendance', 'avail'],
    'employable': ['accessible', 'advantageous', 'agential', 'agentival', 'agentive', 'appropriate', 'assisting', 'banausic', 'beneficial', 'commodious', 'conducive', 'expedient'],
    'employed': ['applied', 'at it', 'at work', 'busy', 'chartered', 'engaged', 'exercised', 'exerted', 'full of business', 'hard at it', 'hard at work', 'hired'],
    'employee': ['assistant', 'blue-collar worker', 'breadwinner', 'casual', 'casual laborer', 'common laborer', 'day laborer', 'factory worker', 'flunky', 'free lance', 'free-lancer', 'full-time worker'],
    'employer': ['boss', 'business', 'bwana', 'chef', 'chief', 'church dignitary', 'company', 'consumer', 'corporation', 'director', 'ecclesiarch', 'elder'],
    'employment': ['act', 'acting', 'action', 'active use', 'activism', 'activities', 'activity', 'affair', 'affairs', 'appliance', 'application', 'appointment'],
    'emporium': ['auto show', 'bazaar', 'boat show', 'boutique', 'chain store', 'co-op', 'commercial complex', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store'],
    'empower': ['accredit', 'arm', 'assign', 'authorize', 'certificate', 'certify', 'charge', 'charter', 'clothe', 'clothe with power', 'commission', 'commit'],
    'empowered': ['absolute', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'chartered', 'clothed with authority', 'commanding', 'competent', 'consequential', 'considerable'],
    'emptiness': ['absence', 'absence of mind', 'absurdity', 'acreage', 'aimlessness', 'angst', 'anguish', 'anxiety', 'appetite', 'area', 'aridity', 'bareness'],
    'empty': ['abandoned', 'absurd', 'aimless', 'airy', 'apparently sound', 'arid', 'asinine', 'awkward', 'banal', 'bare', 'barren', 'baseless'],
    'empty handed': ['bare-handed', 'beggarly', 'famished', 'half-starved', 'ill off', 'ill-equipped', 'ill-furnished', 'ill-provided', 'impoverished', 'on short commons', 'pauperized', 'poor'],
    'empty headed': ['awkward', 'benighted', 'blank', 'blankminded', 'brainless', 'callow', 'calm', 'dizzy', 'dumb', 'empty', 'empty-minded', 'empty-pated'],
    'empty of': ['bankrupt in', 'bare of', 'bereft of', 'denuded of', 'deprived of', 'destitute of', 'devoid of', 'for want of', 'forlorn of', 'free of', 'in default of', 'in want of'],
    'emptying': ['aspiration', 'bleeding', 'bloodletting', 'broaching', 'cleaning out', 'clearance', 'clearing', 'cupping', 'defecation', 'depletion', 'discharging cargo', 'drafting'],
    'emulate': ['challenge', 'challenge comparison', 'compete', 'compete with', 'cope', 'copy after', 'equal', 'follow', 'follow like sheep', 'follow suit', 'jockey', 'meet'],
    'emulsify': ['admix', 'alloy', 'amalgamate', 'beat up', 'bemingle', 'blend', 'churn', 'clabber', 'clot', 'coagulate', 'coalesce', 'colloid'],
    'emulsion': ['backing', 'bibliofilm', 'bipack', 'black-and-white film', 'cartridge', 'colloid', 'colloider', 'color film', 'color negative film', 'dope', 'dry plate', 'emulsification'],
    'en bloc': ['across the board', 'all', 'all put together', 'altogether', 'as a body', 'as a whole', 'at large', 'bodily', 'collectively', 'corporately', 'en masse', 'entirely'],
    'en masse': ['across the board', 'all', 'all at once', 'all in all', 'all put together', 'altogether', 'as a body', 'as a whole', 'at large', 'bodily', 'collectively', 'communally'],
    'en rapport': ['accordant', 'affable', 'affinitive', 'affirmative', 'agreeable', 'agreeing', 'akin', 'amiable', 'amicable', 'answerable', 'appertaining', 'associative'],
    'en route to': ['against', 'ahead', 'along', 'for', 'forth', 'forward', 'forwards', 'headed for', 'in passage to', 'in transit to', 'on', 'on route to'],
    'enable': ['ok', 'accredit', 'adapt', 'adjust', 'agree to', 'aid', 'allow', 'approve', 'arm', 'assent to', 'assign', 'assist'],
    'enact': ['accomplish', 'achieve', 'act', 'act a part', 'act as', 'act out', 'affect', 'ape', 'attain', 'authorize', 'betoken', 'brandish'],
    'enactment': ['accomplishment', 'achievement', 'act', 'acting', 'administration', 'aping', 'bill', 'bylaw', 'canon', 'characterization', 'commission', 'completion'],
    'enamel': ['apply paint', 'bedaub', 'bedizen', 'begild', 'besmear', 'brush on paint', 'butter', 'calcimine', 'china', 'clay', 'coat', 'coating'],
    'enamor': ['allure', 'attract', 'becharm', 'bewitch', 'captivate', 'carry away', 'charm', 'draw on', 'endear', 'enrapture', 'fascinate', 'hold in thrall'],
    'enamored': ['attached to', 'becharmed', 'bewitched', 'captivated', 'charmed', 'crazy about', 'devoted to', 'enamored of', 'enchanted', 'enraptured', 'far gone on', 'fascinated'],
    'encampment': ['konzentrationslager', 'lager', 'barrack', 'barracks', 'bivouac', 'bivouacking', 'camp', 'campground', 'camping', 'campsite', 'cantonment', 'casern'],
    'encapsulate': ['box', 'case', 'crate', 'embox', 'embrace', 'encase', 'enfold', 'enshroud', 'envelop', 'enwrap', 'invest', 'lap'],
    'encase': ['bag', 'barrel', 'basket', 'bottle', 'bottle up', 'box', 'box in', 'box up', 'cabin', 'can', 'capsule', 'carton'],
    'encephalitis': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis'],
    'enchant': ['absorb', 'absorb the attention', 'allure', 'arrest', 'attract', 'becharm', 'beguile', 'bewitch', 'captivate', 'carry away', 'cast a spell', 'catch'],
    'enchanted': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'arrested', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'becharmed'],
    'enchanter': ['artful dodger', 'casanova', 'circe', 'don juan', 'euryale', 'gorgon', 'lorelei', 'machiavel', 'machiavelli', 'machiavellian', 'medea', 'medusa'],
    'enchanting': ['circean', 'absorbing', 'alluring', 'appealing', 'appetizing', 'arresting', 'attractive', 'authoritative', 'beguiling', 'bewitching', 'blandishing', 'cajoling'],
    'enchantment': ['jonah', 'affection', 'affectionateness', 'agacerie', 'alchemy', 'allure', 'allurement', 'amativeness', 'amorousness', 'appeal', 'appealingness', 'ascendancy'],
    'enchantress': ['circe', 'don juan', 'euryale', 'gorgon', 'lorelei', 'medea', 'medusa', 'miss america', 'parthenope', 'siren', 'stheno', 'bathing beauty'],
    'enchased': ['carved', 'creased', 'cut', 'engraved', 'furrowed', 'glyphic', 'graved', 'graven', 'grooved', 'impressed', 'imprinted', 'incised'],
    'encircle': ['admit', 'assimilate', 'band', 'begird', 'beleaguer', 'belt', 'belt in', 'beset', 'besiege', 'blockade', 'bound', 'box in'],
    'encircled': ['begirt', 'belted', 'cinctured', 'circled', 'circumscribed', 'circumscript', 'defined', 'definite', 'delimited', 'demarcated', 'determinate', 'determined'],
    'encirclement': ['aerial tactics', 'airborne tactics', 'applied tactics', 'armored tactics', 'barrier tactics', 'beleaguerment', 'besiegement', 'blockade', 'blockading', 'cavalry tactics', 'cincture', 'circling'],
    'encircling': ['ambient', 'assimilating', 'circling', 'circumambient', 'circumferential', 'circumflex', 'circumfluent', 'circumfluous', 'circumjacent', 'comprising', 'containing', 'counting'],
    'enclave': ['arena', 'block', 'cincture', 'clos', 'close', 'confine', 'container', 'coop', 'court', 'courtyard', 'croft', 'curtilage'],
    'enclose': ['admit', 'assimilate', 'beleaguer', 'beset', 'besiege', 'blockade', 'bottle up', 'bound', 'box in', 'box up', 'cage', 'chamber'],
    'enclosed': ['barred', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'cabined', 'caged', 'cloistered', 'closed-in', 'compassed', 'confined'],
    'enclosing': ['ambient', 'assimilating', 'circling', 'circumambient', 'circumferential', 'circumflex', 'circumfluent', 'circumfluous', 'circumjacent', 'claustral', 'comprising', 'confining'],
    'enclosure': ['abatis', 'advanced work', 'arena', 'bailey', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barnyard', 'barricade', 'barrier'],
    'encomium': ['acclaim', 'acclamation', 'accolade', 'applause', 'approval', 'citation', 'commendation', 'compliment', 'eulogy', 'kudos', 'laud', 'laudation'],
    'encompass': ['accouple', 'accumulate', 'add', 'admit', 'agglutinate', 'amalgamate', 'amass', 'articulate', 'assemble', 'assimilate', 'associate', 'band'],
    'encore': ['acclaim', 'acclamation', 'afresh', 'again', 'anew', 'another time', 'applause', 'big hand', 'bis', 'burst of applause', 'cheer', 'clap'],
    'encounter': ['olympic games', 'olympics', 'accost', 'action', 'advance', 'affront', 'alight upon', 'altercation', 'approach', 'appropinquate', 'approximate', 'appulse'],
    'encounter therapy': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'assertiveness training', 'behavior modification', 'behavior therapy', 'bioenergetics', 'biofeedback', 'confrontation therapy'],
    'encourage': ['abet', 'admonish', 'advance', 'advantage', 'advocate', 'aid', 'aid and abet', 'animate', 'ask for', 'assist', 'assure', 'bear up'],
    'encouragement': ['abetment', 'advocacy', 'aegis', 'aid', 'aid and comfort', 'animating', 'animation', 'assurance', 'auspices', 'backing', 'bait', 'boost'],
    'encouraging': ['alluring', 'animating', 'assuring', 'auspicious', 'bright with promise', 'challenging', 'cheerful', 'cheering', 'cheery', 'comforting', 'condolatory', 'condolent'],
    'encroach': ['abuse a privilege', 'adopt', 'advance upon', 'appropriate', 'arrogate', 'assume', 'barge in', 'bother', 'break bounds', 'break in', 'break in upon', 'burst in'],
    'encroachment': ['adoption', 'appropriation', 'arrogation', 'assumption', 'entrance', 'entrenchment', 'impingement', 'imposition', 'incursion', 'infiltration', 'influx', 'infraction'],
    'encumber': ['add', 'adjoin', 'affix', 'agglutinate', 'annex', 'append', 'attach', 'bear hard upon', 'block', 'burden', 'burthen', 'charge'],
    'encumbered': ['burdened', 'burdened with debt', 'charged', 'cumbered', 'deep in debt', 'embarrassed', 'fraught', 'freighted', 'hampered', 'in debt', 'in difficulties', 'in embarrassed circumstances'],
    'encumbrance': ['affliction', 'albatross', 'bale', 'bitter cup', 'bitter draft', 'bitter draught', 'bitter pill', 'burden', 'burden of care', 'burdening', 'burthen', 'cankerworm of care'],
    'encyclical': ['pastoral epistle', 'aerogram', 'air letter', 'airgraph', 'announcement', 'annunciation', 'billet-doux', 'bull', 'bulletin board', 'chain letter', 'circular', 'communique'],
    'encyclopedia': ['atlas', 'bibliography', 'body of knowledge', 'body of learning', 'calendar', 'casebook', 'catalog', 'catalogue raisonne', 'city directory', 'classified catalog', 'concordance', 'cyclopedia'],
    'encyclopedic': ['abstruse', 'across-the-board', 'all-comprehensive', 'all-embracing', 'all-inclusive', 'blanket', 'broad', 'civilized', 'compendious', 'complete', 'comprehensive', 'cultivated'],
    'end': ['friday', 'friday the thirteenth', 'abandon', 'abort', 'accomplishment', 'acme', 'afterglow', 'afterimage', 'aim', 'all', 'allotment', 'allowance'],
    'end all': ['ko', 'clincher', 'crusher', 'death stroke', 'deathblow', 'ender', 'final stroke', 'finisher', 'finishing stroke', 'kayo', 'kayo punch', 'knockout'],
    'end result': ['accomplishment', 'answer', 'ascertainment', 'bitter end', 'catastrophe', 'clearing up', 'climax', 'completion', 'conclusion', 'consummation', 'cracking', 'culmination'],
    'endanger': ['chance', 'compromise', 'encounter danger', 'expose', 'gamble', 'gamble with', 'hazard', 'imperil', 'incur danger', 'jeopard', 'jeopardize', 'jeopardy'],
    'endear': ['allure', 'attract', 'becharm', 'bewitch', 'captivate', 'carry away', 'charm', 'draw on', 'enamor', 'enrapture', 'fascinate', 'hold in thrall'],
    'endearment': ['artful endearments', 'bait', 'baited trap', 'blandishments', 'caress', 'charm', 'come-on', 'decoy', 'decoy duck', 'drawcard', 'drawing card', 'ground bait'],
    'endeavor': ['accept', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'address', 'adventure', 'aim', 'aim to', 'apply'],
    'ended': ['sol', 'all bets off', 'all off', 'all over', 'all up', 'at an end', 'canceled', 'cleaned up', 'complete', 'completed', 'concluded', 'dead'],
    'endemic': ['abnormality', 'aboriginal', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'autochthonous', 'bacterial disease', 'birth defect'],
    'ending': ['annihilation', 'apodosis', 'arrest', 'bane', 'bell', 'biological death', 'capping', 'catastrophe', 'ceasing', 'cessation', 'cessation of life', 'check'],
    'endless': ['ageless', 'all-comprehensive', 'all-inclusive', 'amaranthine', 'articulated', 'boundless', 'catenated', 'ceaseless', 'coeternal', 'concatenated', 'connected', 'constant'],
    'endlessly': ['ad infinitum', 'again and again', 'at a stretch', 'boresomely', 'boringly', 'boundlessly', 'ceaselessly', 'connectedly', 'constantly', 'continually', 'continuously', 'cumulatively'],
    'endocrine': ['adrenal', 'autacoid', 'bile', 'chalone', 'digestive secretion', 'eccrine', 'exocrine', 'gall', 'gastric juice', 'glandular', 'glandulous', 'gonadal'],
    'endorse': ['ok', 'abet', 'accede to', 'accept', 'accord to', 'accredit', 'admire', 'advocate', 'affirm', 'agree to', 'aid and abet', 'amen'],
    'endorsement': ['john hancock', 'ok', 'acceptance', 'accord', 'acquiescence', 'adherence', 'admiration', 'affirmance', 'affirmation', 'affirmative', 'affirmative voice', 'agreement'],
    'endorser': ['maecenas', 'abettor', 'admirer', 'advocate', 'aficionado', 'angel', 'apologist', 'approver', 'backer', 'buff', 'certifier', 'champion'],
    'endow': ['accommodate', 'accord', 'afford', 'arm', 'authorize', 'award', 'back', 'bequeath', 'bestow', 'bless with', 'clothe', 'clothe with power'],
    'endowed': ['accoutered', 'armed', 'blessed with', 'born for', 'catered', 'cut out for', 'dotal', 'dower', 'dowered', 'dowry', 'enfeoffed', 'equipped'],
    'endowment': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'tlc', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory'],
    'endpaper': ['acknowledgments', 'back', 'back matter', 'bastard title', 'bibliography', 'catch line', 'catchword', 'colophon', 'contents', 'contents page', 'copyright page', 'dedication'],
    'endue': ['accouter', 'apparel', 'arm', 'array', 'attire', 'authorize', 'bedeck', 'bedrape', 'bundle up', 'clothe', 'clothe with power', 'deck'],
    'endurance': ['abidingness', 'acceptance', 'age', 'antiquity', 'application', 'assiduity', 'assiduousness', 'bulldog tenacity', 'changelessness', 'concentration', 'constancy', 'continualness'],
    'endure': ['abide', 'abide with', 'abiding', 'advance', 'afford', 'allow for', 'be exposed to', 'be proof against', 'be spared', 'be subjected to', 'be tough', 'bear'],
    'enduring': ['spartan', 'abiding', 'accepting', 'adamantine', 'age-long', 'aged', 'alive', 'ancient', 'antique', 'armed with patience', 'assiduous', 'bulky'],
    'endways': ['adjacent', 'adjoining', 'along', 'at attention', 'at length', 'bolt upright', 'bordering', 'connecting', 'conterminous', 'contiguous', 'coterminous', 'end to end'],
    'enema': ['ablution', 'abstergent', 'aerosol', 'aspergil', 'aspergillum', 'atomizer', 'cathartic', 'cleaner', 'cleaning agent', 'cleaning out', 'cleaning solvent', 'cleanser'],
    'enemy': ['adversary', 'adversative', 'adverse', 'aggressive', 'alien', 'antagonist', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'archenemy', 'assailant'],
    'energetic': ['active', 'activist', 'activistic', 'acute', 'aggressive', 'alive', 'animated', 'ardent', 'armipotent', 'assiduous', 'authoritative', 'bouncing'],
    'energetically': ['actively', 'all out', 'allegretto', 'allegro', 'animatedly', 'ardently', 'assiduously', 'breezily', 'briskly', 'busily', 'cogently', 'con brio'],
    'energize': ['activate', 'actuate', 'amplify', 'animate', 'arm', 'arouse', 'breathe life into', 'bring into being', 'bring into existence', 'bring to life', 'build up', 'call into being'],
    'energizer': ['abettor', 'activator', 'actuator', 'animator', 'arouser', 'cajoler', 'coax', 'coaxer', 'encourager', 'firer', 'gadfly', 'galvanizer'],
    'energizing': ['activating', 'alluring', 'animating', 'animation', 'animative', 'bracing', 'brisk', 'challenging', 'cheering', 'cordial', 'crisp', 'crispy'],
    'energy': ['activity', 'amperage', 'animation', 'application', 'ardor', 'armipotence', 'assiduity', 'assiduousness', 'authority', 'beef', 'birr', 'black power'],
    'enervate': ['abate', 'afflict', 'attenuate', 'beat', 'blunt', 'break', 'burn out', 'castrate', 'cramp', 'cripple', 'damp', 'dampen'],
    'enervated': ['apathetic', 'ausgespielt', 'benumbed', 'blase', 'bored', 'burned-out', 'cachectic', 'castrated', 'dead', 'debilitated', 'decadent', 'degenerate'],
    'enfant terrible': ['jd', 'bad boy', 'booger', 'brat', 'buffoon', 'bugger', 'cutup', 'devil', 'elf', 'funmaker', 'gamin', 'holy terror'],
    'enfeeble': ['abate', 'afflict', 'attenuate', 'blunt', 'bugger', 'cramp', 'cripple', 'damp', 'dampen', 'de-energize', 'deaden', 'debilitate'],
    'enfeebled': ['ausgespielt', 'burned-out', 'debilitated', 'devitalized', 'disabled', 'drained', 'drooping', 'droopy', 'effete', 'enervated', 'eviscerated', 'exhausted'],
    'enfold': ['bosom', 'box', 'case', 'clasp', 'clinch', 'clip', 'close', 'compass', 'compass about', 'comprise', 'contain', 'cover'],
    'enforce': ['abide by', 'accomplish', 'adhere to', 'administer', 'apply', 'bestow', 'bind', 'bring to bear', 'browbeat', 'bully', 'carry out', 'carry through'],
    'enforcement': ['carrying out', 'coaction', 'completion', 'compulsion', 'compulsiveness', 'constraint', 'discharge', 'effectuation', 'execution', 'forcing', 'fulfillment', 'inevitability'],
    'enfranchise': ['affranchise', 'authorize', 'certificate', 'certify', 'charter', 'deliver', 'disenthrall', 'emancipate', 'empower', 'enable', 'entitle', 'extricate'],
    'enfranchised': ['acceptable', 'admissible', 'authorized', 'chartered', 'desirable', 'eligible', 'empowered', 'entitled', 'fit', 'fitted', 'franchised', 'licensed'],
    'engage': ['absorb', 'absorb the attention', 'accept obligation', 'affiance', 'agree', 'agree to', 'answer for', 'appeal', 'approach', 'arrest', 'assault', 'assay'],
    'engage in': ['accept', 'assume', 'attack', 'attempt', 'be about', 'be doing', 'be engaged in', 'be occupied with', 'buckle to', 'carry on', 'conduct', 'do'],
    'engaged': ['absorbed', 'absorbed in', 'accessory', 'affianced', 'agreed', 'armed', 'arranged', 'arrayed', 'assured', 'at it', 'at work', 'battled'],
    'engagement': ['olympic games', 'olympics', 'absorbed attention', 'absorption', 'action', 'affair', 'affiance', 'agreement', 'allurement', 'alternation', 'application', 'appointment'],
    'engaging': ['absorbing', 'agreeable', 'alluring', 'appealing', 'appetizing', 'arresting', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating'],
    'engender': ['arouse', 'author', 'be fruitful', 'be productive', 'bear', 'beget', 'birth', 'breed', 'breed true', 'bring about', 'bring forth', 'bring into being'],
    'engine': ['ac motor', 'corliss engine', 'otto engine', 'wankel engine', 'aeromotor', 'air engine', 'alembic', 'anvil', 'apparatus', 'appliance', 'arc-jet engine', 'axial-flow turbojet'],
    'engineer': ['seabee', 'accomplish', 'achieve', 'act', 'aeronautical engineer', 'agent', 'agricultural engineer', 'ancestors', 'angle', 'apprentice', 'architect', 'arrange'],
    'english': ['abnaki', 'afghan', 'afghani', 'afrikaans', 'ainu', 'akan', 'akkadian', 'albanian', 'aleut', 'algonquin', 'amharic', 'andaman'],
    'english horn': ['pandean pipe', 'aulos', 'basset horn', 'basset oboe', 'bassoon', 'block flute', 'bombard', 'bourdon', 'cello', 'claribel', 'clarinet', 'clarion'],
    'engorge': ['allay', 'batten', 'bolt', 'bolt down', 'bring to ruin', 'cloy', 'condemn', 'confound', 'consume', 'cram', 'damn', 'deal destruction'],
    'engorged': ['allayed', 'cloyed', 'crammed', 'disgusted', 'fed-up', 'full', 'full of', 'glutted', 'gorged', 'jaded', 'overfed', 'overfull'],
    'engram': ['mnemosyne', 'affect memory', 'anterograde memory', 'archetypal pattern', 'archetype', 'atavism', 'collective memory', 'computer memory', 'disk memory', 'drum memory', 'emotional response', 'father image'],
    'engrave': ['assemble', 'autolithograph', 'be a printmaker', 'bead', 'bed', 'bejewel', 'beribbon', 'bespangle', 'blaze', 'blaze a trail', 'blemish', 'blotch'],
    'engraved': ['alveolar', 'alveolate', 'canaliculate', 'canaliculated', 'carved', 'chamfered', 'channeled', 'confirmed', 'corduroy', 'corduroyed', 'corrugate', 'corrugated'],
    'engraver': ['accountant', 'amanuensis', 'archivist', 'bookkeeper', 'burinist', 'carver', 'cerographer', 'chalcographer', 'clerk', 'documentalist', 'etcher', 'filing clerk'],
    'engraving': ['cysp sculpture', 'abstract', 'abstract art', 'abstraction', 'altarpiece', 'anaglyph', 'anaglyptics', 'anaglyptography', 'aquatint', 'architectural sculpture', 'art', 'art form'],
    'engross': ['absorb', 'absorb the attention', 'adsorb', 'apply', 'arrest', 'assimilate', 'attract', 'become overweight', 'blot', 'blot up', 'busy', 'buy'],
    'engrossed': ['absent', 'absentminded', 'absorbed', 'absorbed in', 'abstracted', 'assiduous', 'autograph', 'autographic', 'bemused', 'buried in', 'buried in thought', 'busy'],
    'engrossing': ['absorbing', 'all-consuming', 'arresting', 'attractive', 'consuming', 'controlling', 'enchanting', 'engaging', 'enthralling', 'exciting', 'fascinating', 'gripping'],
    'engulf': ['baptize', 'be prodigal with', 'bury', 'cascade', 'cataract', 'deluge', 'devour', 'dip', 'douse', 'drink', 'drown', 'duck'],
    'engulfed': ['afloat', 'at flood', 'awash', 'bathed', 'buried', 'deluged', 'dipped', 'drenched', 'dribbling', 'dripping', 'dripping wet', 'drowned'],
    'enhance': ['accelerate', 'acculturate', 'add to', 'adorn', 'advance', 'agent provocateur', 'aggravate', 'ameliorate', 'amend', 'amplify', 'annoy', 'augment'],
    'enhanced': ['accelerated', 'advanced', 'aggrandized', 'aggravated', 'ameliorated', 'amplified', 'annoyed', 'augmented', 'beautified', 'beefed-up', 'bettered', 'bloated'],
    'enhancement': ['great leap forward', 'accelerando', 'acceleration', 'advance', 'advancement', 'aggrandizement', 'aggravation', 'amelioration', 'amendment', 'amplification', 'annoyance', 'ascent'],
    'enigma': ['chinese puzzle', 'gordian knot', 'arcanum', 'baffle', 'bafflement', 'baffling problem', 'bewilderment', 'bother', 'brain twister', 'cabala', 'classified information', 'confidence'],
    'enigmatic': ['able', 'ambiguous', 'amphibological', 'amphibolous', 'arcane', 'baffling', 'beguiling', 'bewildering', 'bothering', 'cabalistic', 'censored', 'classified'],
    'enjoin': ['adjure', 'admonish', 'advise', 'appreciate', 'arrest', 'ban', 'bar', 'bid', 'boast', 'bridle', 'burden with', 'call on'],
    'enjoy': ['adore', 'appreciate', 'bask in', 'be enfeoffed of', 'be fond of', 'be partial to', 'be pleased with', 'be possessed of', 'be seized of', 'benefit from', 'boast', 'claim'],
    'enjoyable': ['affable', 'agreeable', 'amiable', 'amicable', 'blissful', 'cheerful', 'compatible', 'complaisant', 'congenial', 'cordial', 'desirable', 'dulcet'],
    'enjoyment': ['advantage', 'amusement', 'animal pleasure', 'benefit', 'bodily pleasure', 'carnal delight', 'comfort', 'content', 'contentment', 'coziness', 'creature comforts', 'delectation'],
    'enlace': ['braid', 'entwine', 'interknit', 'interlace', 'intertie', 'intertissue', 'intertwine', 'intertwist', 'interweave', 'intort', 'knit', 'lace'],
    'enlarge': ['add to', 'agent provocateur', 'aggrandize', 'aggravate', 'amplify', 'annoy', 'augment', 'balloon', 'beef up', 'bloat', 'blow up', 'blueprint'],
    'enlarged': ['accelerated', 'aggrandized', 'aggravated', 'ampliate', 'amplified', 'annoyed', 'augmented', 'beefed-up', 'bloated', 'boosted', 'broadened', 'built-up'],
    'enlargement': ['ditto copy', 'photostat', 'xerox', 'xerox copy', 'access', 'accession', 'accomplishment', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition'],
    'enlighten': ['account for', 'acculturate', 'acquaint', 'advance', 'advertise', 'advertise of', 'advise', 'allegorize', 'ameliorate', 'amend', 'apprise', 'awaken'],
    'enlightened': ['ablaze', 'abreast of', 'aglow', 'alight', 'au courant', 'aware', 'bathed with light', 'bespangled', 'blase', 'briefed', 'brightened', 'broad-minded'],
    'enlightener': ['adviser', 'announcer', 'annunciator', 'authority', 'channel', 'communicant', 'communicator', 'expert witness', 'gossipmonger', 'grapevine', 'informant', 'information center'],
    'enlightening': ['advisory', 'allegorizing', 'annotative', 'autodidactic', 'brightening', 'broadening', 'clarifying', 'coeducational', 'communicative', 'critical', 'cultural', 'demonstrative'],
    'enlightenment': ['accomplishments', 'account', 'acculturation', 'acquaintance', 'acquisition of knowledge', 'acquisitions', 'allegorization', 'announcement', 'arc lighting', 'attainments', 'awakening', 'black and white'],
    'enlist': ['affiliate', 'affiliate with', 'alternate', 'associate', 'bring', 'call up', 'carry', 'combine', 'come into', 'commandeer', 'conscript', 'cover'],
    'enlistment': ['acceptance', 'admission', 'admittance', 'allurement', 'baptism', 'blandishment', 'booking', 'cajolement', 'cajolery', 'call', 'call-up', 'cataloging'],
    'enliven': ['amuse', 'animate', 'arouse', 'awaken', 'beguile', 'boost', 'brace', 'brace up', 'brighten', 'brisk', 'brisken', 'buck up'],
    'enlivened': ['aboveground', 'alive', 'alive and kicking', 'among the living', 'animate', 'animated', 'breathing', 'capable of life', 'conscious', 'endowed with life', 'existent', 'in the flesh'],
    'enmesh': ['absorb', 'allure', 'bag', 'bait the hook', 'birdlime', 'burden', 'catch', 'catch out', 'catch up in', 'concern', 'cramp', 'cripple'],
    'enmity': ['discordia', 'eris', 'kilkenny cats', 'abhorrence', 'abomination', 'alienation', 'allergy', 'altercation', 'animosity', 'animus', 'antagonism', 'antipathy'],
    'ennoble': ['advance', 'aggrandize', 'apotheose', 'apotheosize', 'beatify', 'canonize', 'crown', 'deify', 'dignify', 'distinguish', 'elevate', 'enshrine'],
    'ennui': ['acedia', 'angst', 'anguish', 'anxiety', 'apathy', 'blues', 'boredness', 'boredom', 'cheerlessness', 'dejection', 'depression', 'discomfort'],
    'enormity': ['abjectness', 'abominableness', 'affront', 'ampleness', 'amplitude', 'aspersion', 'atrociousness', 'atrocity', 'barbarity', 'baseness', 'beggarliness', 'bigness'],
    'enormous': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'a bit much', 'abandoned', 'abominable', 'abysmal', 'amplitudinous', 'arrant'],
    'enough': ['abundance', 'abundantly', 'acceptably', 'adequacy', 'adequate', 'adequate supply', 'adequately', 'adequateness', 'admissibly', 'agreeably', 'ample', 'ampleness'],
    'enquire': ['ask', 'ask a question', 'ask about', 'ask questions', 'be curious', 'bring into question', 'burn with curiosity', 'demand', 'dig around for', 'dig up', 'gape', 'gawk'],
    'enquirer': ['ask', 'ask a question', 'ask about', 'ask questions', 'be curious', 'bring into question', 'burn with curiosity', 'demand', 'dig around for', 'dig up', 'gape', 'gawk'],
    'enquiry': ['ask', 'ask a question', 'ask about', 'ask questions', 'be curious', 'bring into question', 'burn with curiosity', 'demand', 'dig around for', 'dig up', 'gape', 'gawk'],
    'enrage': ['anger', 'annoy', 'arouse', 'awake', 'awaken', 'blow the coals', 'blow up', 'call forth', 'call up', 'enkindle', 'excite', 'fan'],
    'enrapture': ['allure', 'attract', 'becharm', 'beguile', 'bewitch', 'captivate', 'carry away', 'cast a spell', 'charm', 'delectate', 'delight', 'draw on'],
    'enraptured': ['abandoned', 'agape', 'aghast', 'agog', 'all agog', 'amazed', 'amok', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck'],
    'enravish': ['becharm', 'beguile', 'bewitch', 'captivate', 'carry away', 'cast a spell', 'charm', 'delectate', 'delight', 'enchant', 'enrapture', 'enthrall'],
    'enravished': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled', 'bewildered'],
    'enrich': ['acculturate', 'add to', 'adorn', 'advance', 'ameliorate', 'amend', 'array', 'beautify', 'bedeck', 'bedizen', 'better', 'blazon'],
    'enrichment': ['great leap forward', 'advance', 'advancement', 'amelioration', 'amendment', 'ascent', 'augmentation', 'bettering', 'betterment', 'boost', 'complement', 'enhancement'],
    'enrobe': ['apparel', 'array', 'attire', 'bedeck', 'bedrape', 'bundle up', 'clothe', 'deck', 'dight', 'drape', 'dress', 'dud'],
    'enroll': ['affiliate', 'affiliate with', 'associate', 'book', 'calendar', 'call up', 'carve', 'catalog', 'chalk', 'chalk up', 'check in', 'chronicle'],
    'enrollment': ['acceptance', 'admission', 'admittance', 'baptism', 'booking', 'call', 'call-up', 'cataloging', 'chronicling', 'compulsory military service', 'conscription', 'draft'],
    'ensconce': ['anchor', 'becloud', 'befog', 'billet at', 'bivouac', 'blanket', 'blind', 'burrow', 'bury', 'cache', 'camouflage', 'camp'],
    'ensemble': ['german band', 'liederkranz', 'liedertafel', 'philharmonic', 'a cappella', 'acting company', 'admixture', 'agglomeration', 'aggregate', 'all at once', 'alloy', 'amalgam'],
    'enshrine': ['aggrandize', 'apotheose', 'apotheosize', 'beatify', 'beleaguer', 'beset', 'besiege', 'bless', 'blockade', 'bound', 'box in', 'bury'],
    'enshroud': ['apparel', 'array', 'attire', 'becloud', 'bedeck', 'bedrape', 'befog', 'blanket', 'blind', 'box', 'bundle up', 'camouflage'],
    'ensign': ['dannebrog', 'jolly roger', 'old glory', 'star-spangled banner', 'stars and stripes', 'union flag', 'union jack', 'admiral', 'and blue', 'armory', 'badge', 'badge of office'],
    'ensilage': ['barley', 'bird seed', 'bran', 'cat food', 'chicken feed', 'chop', 'corn', 'dog food', 'eatage', 'feed', 'fodder', 'forage'],
    'enslave': ['adopt', 'appropriate', 'arrogate', 'assume', 'beat down', 'bind', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'clamp down on'],
    'ensnare': ['allure', 'bag', 'bait', 'bait the hook', 'birdlime', 'blandish', 'cajole', 'capture', 'catch', 'catch out', 'catch up', 'coax'],
    'ensnarl': ['allure', 'bait the hook', 'birdlime', 'burden', 'catch', 'catch out', 'cramp', 'cripple', 'cumber', 'decoy', 'embarrass', 'embrangle'],
    'ensue': ['attend', 'become of', 'come about', 'come after', 'come next', 'come of', 'come on', 'come out', 'derive', 'develop', 'displace', 'emanate'],
    'ensuing': ['after', 'appendant', 'attendant', 'cadet', 'coming', 'consecutive', 'consequent', 'consequential', 'derivational', 'derivative', 'final', 'following'],
    'ensure': ['arm', 'armor', 'arrange', 'ascertain', 'assure', 'attest', 'back', 'be sponsor for', 'bless', 'bond', 'certify', 'champion'],
    'entail': ['add a codicil', 'affect', 'allegorize', 'allude to', 'argue', 'assume', 'be indicative of', 'be significant of', 'be symptomatic of', 'bequeath', 'bequeathal', 'bequest'],
    'entailed': ['absolute', 'binding', 'compulsory', 'conclusive', 'decisive', 'decretory', 'dictated', 'final', 'hard-and-fast', 'imperative', 'imposed', 'irrevocable'],
    'entangle': ['absorb', 'addle', 'addle the wits', 'allure', 'bag', 'bait the hook', 'ball up', 'becloud', 'bedazzle', 'befuddle', 'bewilder', 'birdlime'],
    'entanglement': ['abatis', 'absorption', 'adulterous affair', 'adultery', 'advanced work', 'affair', 'amour', 'association', 'balistraria', 'bamboozlement', 'bank', 'banquette'],
    'entente': ['nato', 'seato', 'alliance', 'capitulation', 'cartel', 'compact', 'concord', 'concordat', 'consortium', 'convention', 'cordial understanding', 'entente cordiale'],
    'enter': ['admit', 'affiliate', 'affiliate with', 'appear', 'arise', 'associate', 'balance', 'balance the books', 'barge in', 'be admitted', 'become manifest', 'become visible'],
    'enter into': ['assemble', 'be enfranchised', 'be implicated in', 'bear a hand', 'build', 'build up', 'chip in', 'combine', 'compose', 'consist of', 'constitute', 'construct'],
    'enter upon': ['accept', 'assume', 'attack', 'attempt', 'buckle to', 'come out', 'dive into', 'embark in', 'embark on', 'embark upon', 'endeavor', 'engage in'],
    'entered': ['booked', 'cadastral', 'cataloged', 'documented', 'down', 'enrolled', 'enumerated', 'filed', 'indexed', 'inscribed', 'inventorial', 'itemized'],
    'enteric': ['abdominal', 'anal', 'appendical', 'cardiac', 'cecal', 'colic', 'colonic', 'coronary', 'duodenal', 'gastric', 'ileac', 'intestinal'],
    'entering': ['approaching', 'arriving', 'booking', 'cataloging', 'chronicling', 'coming', 'enlistment', 'enrollment', 'entry', 'homeward', 'homeward-bound', 'impanelment'],
    'enteritis': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis'],
    'enterprise': ['aktiengesellschaft', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'activities', 'activity', 'adventure', 'adventuresomeness', 'adventurousness'],
    'enterprising': ['active', 'acute', 'adventuresome', 'adventurous', 'aggressive', 'ambitious', 'animated', 'aspiring', 'assiduous', 'audacious', 'bold', 'brave'],
    'entertain': ['accommodate', 'admit', 'allow', 'amuse', 'amusement', 'bear', 'beguile', 'bestow', 'billet', 'board', 'bosom', 'cater to'],
    'entertaining': ['amusing', 'beguiling', 'comic', 'delightful', 'diverting', 'engaging', 'enjoyable', 'fun', 'funny', 'humorous', 'interesting', 'pleasant'],
    'entertainment': ['kaffeeklatsch', 'amusement', 'animal pleasure', 'ball', 'benefit', 'bill', 'blowout', 'board', 'bodily pleasure', 'carnal delight', 'cocktail party', 'coffee klatch'],
    'enthrall': ['absorb', 'absorb the attention', 'arrest', 'becharm', 'beguile', 'bewitch', 'captivate', 'carry away', 'cast a spell', 'catch', 'catch up', 'charm'],
    'enthralled': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'arrested', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled'],
    'enthralling': ['absorbing', 'alluring', 'appealing', 'appetizing', 'arresting', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching'],
    'enthrone': ['aggrandize', 'anoint', 'apotheose', 'apotheosize', 'beatify', 'canonize', 'chair', 'crown', 'deify', 'elevate', 'ennoble', 'enshrine'],
    'enthusiasm': ['acquiescence', 'activity', 'agreeability', 'agreeableness', 'alacrity', 'amenability', 'amusement', 'animation', 'ardency', 'ardor', 'avidity', 'brio'],
    'enthusiast': ['don quixote', 'quixote', 'activist', 'addict', 'adherent', 'admirer', 'aficionado', 'ball of fire', 'bear', 'beaver', 'big-time operator', 'bigot'],
    'enthusiastic': ['ablaze', 'acquiescent', 'active', 'acute', 'afire', 'aggressive', 'agreeable', 'alacritous', 'amenable', 'animated', 'ardent', 'attracted'],
    'entice': ['allure', 'attract', 'bait', 'bait the hook', 'beguile', 'blandish', 'cajole', 'coax', 'decoy', 'draw', 'draw in', 'draw on'],
    'enticement': ['agacerie', 'allure', 'allurement', 'appeal', 'attraction', 'attractiveness', 'bait', 'beguilement', 'beguiling', 'bewitchery', 'bewitchment', 'blandishment'],
    'enticing': ['circean', 'alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching', 'charismatic'],
    'entire': ['absolute', 'admitting no exception', 'aggregate', 'all', 'all-embracing', 'all-inclusive', 'all-out', 'categorical', 'clear', 'compacted', 'complete', 'comprehensive'],
    'entirely': ['absolutely', 'across the board', 'all', 'all out', 'all put together', 'alone', 'altogether', 'as a body', 'as a whole', 'at large', 'bodily', 'but'],
    'entirety': ['aggregate', 'all', 'allness', 'be-all and end-all', 'collectiveness', 'collectivity', 'completeness', 'complex', 'comprehensiveness', 'embodiment', 'entireness', 'everything'],
    'entitle': ['allow', 'authorize', 'baptize', 'call', 'certificate', 'certify', 'charter', 'christen', 'define', 'denominate', 'designate', 'dub'],
    'entitled': ['ascribable', 'attributable', 'authorized', 'chartered', 'deserved', 'deserving', 'due', 'earned', 'empowered', 'enfranchised', 'entitled to', 'franchised'],
    'entity': ['an existence', 'article', 'being', 'body', 'creature', 'critter', 'ens', 'entelechy', 'esse', 'essence', 'existence', 'existent'],
    'entomb': ['bottle up', 'box in', 'box up', 'bury', 'cabin', 'casket', 'cloister', 'closet', 'coffin', 'conduct a funeral', 'confine', 'cramp'],
    'entomology': ['anatomy', 'animal physiology', 'anthropology', 'biology', 'comparative anatomy', 'conchology', 'ecology', 'ethology', 'helminthology', 'herpetology', 'ichthyology', 'malacology'],
    'entourage': ['alentours', 'ambience', 'ambit', 'associates', 'attendance', 'attendant', 'attendants', 'body of retainers', 'borderlands', 'circle', 'circuit', 'circumambiencies'],
    'entrails': ['abdomen', 'anus', 'appendix', 'blind gut', 'bowels', 'brain', 'cecum', 'colon', 'duodenum', 'endocardium', 'foregut', 'giblets'],
    'entrain': ['bicycle', 'bike', 'board', 'bus', 'catch a train', 'chauffeur', 'cycle', 'drive', 'embark', 'embus', 'emplane', 'enplane'],
    'entrance': ['access', 'adit', 'admission', 'admittance', 'air lock', 'anesthetize', 'aperture', 'appearance', 'approach', 'arrival', 'attract', 'becharm'],
    'entranced': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled', 'bewildered'],
    'entrancing': ['circean', 'alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching', 'charismatic'],
    'entrant': ['abecedarian', 'alphabetarian', 'apprentice', 'arrival', 'articled clerk', 'baby', 'beginner', 'boot', 'catechumen', 'comer', 'competitor', 'contender'],
    'entrap': ['allure', 'bag', 'bait', 'bait the hook', 'birdlime', 'burden', 'catch', 'catch out', 'catch up', 'cramp', 'cripple', 'cumber'],
    'entrapment': ['agacerie', 'allure', 'allurement', 'appeal', 'attraction', 'attractiveness', 'bamboozlement', 'befooling', 'beguilement', 'beguiling', 'bewitchery', 'bewitchment'],
    'entreat': ['adjure', 'appeal', 'appeal to', 'beg', 'beseech', 'blandish', 'call for help', 'call on', 'call upon', 'clamor for', 'coax', 'conjure'],
    'entreaty': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'adjuration', 'aid prayer', 'appeal', 'application', 'beadroll', 'beads'],
    'entree': ['access', 'adit', 'admission', 'admittance', 'antepast', 'boil', 'broil', 'casserole', 'course', 'cover', 'culinary masterpiece', 'culinary preparation'],
    'entrench': ['arm', 'armor', 'armor-plate', 'bank', 'barge in', 'barricade', 'battle', 'bed', 'blockade', 'break in', 'break in upon', 'bulwark'],
    'entrenchment': ['abri', 'approach trench', 'aqueduct', 'bunker', 'canal', 'canalization', 'channel', 'communication trench', 'confirmation', 'countermine', 'coupure', 'crimp'],
    'entrepreneur': ['administrator', 'architect', 'backer', 'banker', 'baron', 'big boss', 'big businessman', 'business leader', 'businessman', 'captain of industry', 'contractor', 'contriver'],
    'entropy': ['edp', 'abeyance', 'aloofness', 'amorphia', 'amorphism', 'amorphousness', 'anarchy', 'apathy', 'bit', 'blurriness', 'catalepsy', 'catatonia'],
    'entrust': ['accredit', 'allocate', 'allot', 'assign', 'authorize', 'carry', 'charge', 'charter', 'commend', 'commission', 'commit', 'confer'],
    'entry': ['access', 'account', 'adit', 'admission', 'admittance', 'adversaria', 'adversary', 'aide-memoire', 'air lock', 'annotation', 'approach', 'arrival'],
    'entwine': ['braid', 'burden', 'coil', 'corkscrew', 'cramp', 'cripple', 'cumber', 'curl', 'embarrass', 'encumber', 'enlace', 'enmesh'],
    'enumerate': ['block out', 'book', 'calendar', 'call off', 'call over', 'call the roll', 'catalog', 'census', 'count', 'detail', 'enroll', 'enter'],
    'enumeration': ['accounting', 'active list', 'blacklist', 'blocking', 'census', 'checklist', 'civil list', 'counting', 'dactylonomy', 'detailing', 'foliation', 'inventory'],
    'enunciate': ['advance', 'affirm', 'allege', 'announce', 'annunciate', 'argue', 'articulate', 'assert', 'assever', 'asseverate', 'aver', 'avouch'],
    'enunciated': ['affirmed', 'alleged', 'announced', 'articulated', 'asserted', 'asseverated', 'attested', 'averred', 'avouched', 'avowed', 'certified', 'declared'],
    'enunciation': ['affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'articulation', 'assertion', 'asseveration', 'attack', 'averment', 'avouchment', 'avowal'],
    'envelop': ['apparel', 'array', 'attire', 'becloud', 'bedeck', 'bedrape', 'befog', 'beleaguer', 'beset', 'besiege', 'blanket', 'blind'],
    'envelope': ['aura', 'bandage', 'bandaging', 'binder', 'binding', 'blaze of glory', 'border', 'brilliance', 'brilliancy', 'charisma', 'circumference', 'cortex'],
    'enveloped': ['armored', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'compassed', 'coped', 'covered', 'covert', 'cowled', 'curtained'],
    'envelopment': ['bandage', 'bandaging', 'beleaguerment', 'besetment', 'besiegement', 'binder', 'binding', 'blanketing', 'blockade', 'blockading', 'blocking', 'blotting out'],
    'envenom': ['abuse', 'acerbate', 'afflict', 'aggravate', 'aggrieve', 'alienate', 'antagonize', 'befoul', 'bewitch', 'bitter', 'blight', 'condemn'],
    'enviable': ['acceptable', 'adorable', 'agreeable', 'appetizing', 'attractive', 'desirable', 'desired', 'exciting', 'in demand', 'likable', 'lovable', 'mouth-watering'],
    'envious': ['beefing', 'begrudging', 'bellyaching', 'bitching', 'complaining', 'complaintful', 'coveting', 'covetous', 'crabbing', 'crabby', 'cranky', 'croaking'],
    'environment': ['ambience', 'ambient', 'atmosphere', 'backdrop', 'background', 'cincture', 'circling', 'circumambience', 'circumambiency', 'circumcincture', 'circumflexion', 'circumjacence'],
    'environs': ['airspace', 'alentours', 'ambience', 'ambit', 'approach', 'approximation', 'area', 'belt', 'borderlands', 'boundary', 'bounds', 'circle'],
    'envisage': ['admit', 'affront', 'anticipate', 'assimilate', 'behold', 'brave', 'breast', 'bring before', 'bring forward', 'bring up', 'call to mind', 'call up'],
    'envision': ['anticipate', 'call to mind', 'call up', 'conceive', 'conjure up', 'contemplate', 'envisage', 'fancy', 'feature', 'forecast', 'foreglimpse', 'foresee'],
    'envisioning': ['vorstellung', 'concept', 'conception', 'conceptualization', 'eidetic image', 'envisaging', 'image', 'imagery', 'imagery study', 'imaging', 'imagism', 'imagistic poetry'],
    'envoy': ['agent', 'ambassador', 'ambassadress', 'apostolic delegate', 'attache', 'bearer', 'career diplomat', 'carrier', 'chancellor', 'charge', 'commercial attache', 'commissar'],
    'envy': ['faustianism', 'acedia', 'anger', 'avarice', 'avaritia', 'begrudge', 'cast envious eyes', 'cold comfort', 'covet', 'covetousness', 'crave', 'deadly sin'],
    'enzyme': ['beta-amylase', 'carbohydrase', 'coenzyme', 'deoxyribonuclease', 'digestant', 'digester', 'digestive', 'esterase', 'holoenzyme', 'insulinase', 'lipase', 'lipoxidase'],
    'eolith': ['ancient manuscript', 'antique', 'antiquity', 'archaism', 'artifact', 'cave painting', 'fossil', 'mezzolith', 'microlith', 'neolith', 'paleolith', 'petrification'],
    'eon': ['platonic year', 'aeon', 'age', 'ages', 'annus magnus', 'century', 'cycle', 'cycle of indiction', 'date', 'day', 'eternity', 'generation'],
    'epaulet': ['hershey bar', 'aviation badge', 'badge', 'bar', 'chevron', 'chicken', 'eagle', 'hash mark', 'insignia of branch', 'oak leaf', 'organization insignia', 'overseas bar'],
    'ephemeral': ['brief', 'brittle', 'capricious', 'changeable', 'corruptible', 'deciduous', 'dying', 'episodic', 'evanescent', 'evergreen', 'fading', 'fickle'],
    'epic': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'account', 'alba', 'anacreontic', 'anecdotage', 'anecdote'],
    'epicure': ['brillat-savarin', 'cyrenaic', 'heliogabalus', 'lucullus', 'sardanapalus', 'aesthete', 'amateur', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'authority', 'board-and-roomer'],
    'epicurean': ['cyrenaic', 'heliogabalus', 'sardanapalus', 'amateur', 'appetitive', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'authority', 'bent on pleasure', 'bon vivant', 'carnal'],
    'epicureanism': ['cyrenaic hedonism', 'cyrenaicism', 'aesthetics', 'appetite', 'appetitiveness', 'artistic taste', 'connoisseurship', 'dilettantism', 'epicurism', 'ethical hedonism', 'eudaemonism', 'expertise'],
    'epidemic': ['abounding', 'abundant', 'affluent', 'all-sufficing', 'ambulatory plague', 'ample', 'aplenty', 'average', 'besetting', 'black death', 'black plague', 'bottomless'],
    'epidemiology': ['aerial infection', 'airborne infection', 'carrier', 'communicability', 'contagion', 'contagiousness', 'contamination', 'cryptogenic infection', 'direct infection', 'droplet infection', 'dust infection', 'hand infection'],
    'epidermal': ['ankle-deep', 'cortical', 'cursory', 'cutaneous', 'depthless', 'dermal', 'dermic', 'ecderonic', 'ectodermal', 'ectodermic', 'endermatic', 'endermic'],
    'epidermis': ['blastoderm', 'border', 'circumference', 'corium', 'cortex', 'covering', 'crust', 'cursoriness', 'cutis', 'cutis vera', 'derma', 'dermis'],
    'epigram': ['atticism', 'english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'abridgment', 'adage', 'alba', 'ana'],
    'epigrammatic': ['aphoristic', 'apophthegmatic', 'apothegmatic', 'compendious', 'concise', 'laconic', 'piquant', 'pithy', 'pointed', 'proverbial', 'punchy', 'pungent'],
    'epigraph': ['banner', 'banner head', 'caption', 'catchword', 'device', 'drop head', 'dropline', 'epithet', 'hanger', 'head', 'heading', 'headline'],
    'epilepsy': ['jacksonian epilepsy', 'ms', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'akinetic epilepsy', 'amyotrophic lateral sclerosis', 'apoplexy', 'arrest'],
    'epileptic': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'cancerous', 'case', 'chlorotic', 'colicky', 'consumptive', 'dropsical', 'dyspeptic'],
    'epilogue': ['ps', 'parthian shot', 'act', 'addendum', 'affix', 'afterpiece', 'afterthought', 'afterword', 'allonge', 'apodosis', 'appendix', 'back matter'],
    'epiphany': ['christophany', 'satanophany', 'afflatus', 'angelophany', 'apocalypse', 'apparition', 'appearance', 'appearing', 'arising', 'avatar', 'coming', 'coming into being'],
    'episcopacy': ['abbacy', 'aedileship', 'archbishopric', 'archdeaconry', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'bishopdom', 'bishopric', 'canonicate', 'canonry', 'cardinalship'],
    'episcopal': ['abbatial', 'abbatical', 'archiepiscopal', 'canonical', 'capitular', 'capitulary', 'churchly', 'clerical', 'ecclesiastic', 'episcopalian', 'evangelistic', 'ministerial'],
    'episode': ['action', 'adventure', 'affair', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'argument', 'aside', 'atmosphere', 'background', 'broken thread'],
    'episodic': ['aimless', 'broken', 'broken off', 'by the way', 'chopped-off', 'choppy', 'decousu', 'desultory', 'deviative', 'digressive', 'disconnected', 'discontinued'],
    'epistemology': ['aesthetics', 'axiology', 'casuistry', 'cosmology', 'ethics', 'first philosophy', 'gnosiology', 'logic', 'mental philosophy', 'metaphysics', 'moral philosophy', 'ontology'],
    'epithet': ['abuse', 'appellation', 'appellative', 'binomen', 'binomial name', 'blackguard', 'byword', 'call names', 'catchword', 'cognomen', 'cryptonym', 'curse'],
    'epitome': ['abbreviation', 'abbreviature', 'abrege', 'abridgement', 'abridgment', 'abstract', 'antetype', 'antitype', 'apocope', 'archetype', 'biotype', 'breviary'],
    'epitomize': ['abbreviate', 'abridge', 'abstract', 'bob', 'boil down', 'capsulize', 'clip', 'compress', 'condense', 'contract', 'crop', 'curtail'],
    'epoch': ['bronze age', 'dark ages', 'depression era', 'golden age', 'ice age', 'iron age', 'jacksonian age', 'middle ages', 'new deal era', 'prohibition era', 'silver age', 'steel age'],
    'epochal': ['alternate', 'beating', 'circling', 'consequential', 'cyclic', 'even', 'every other', 'far-reaching', 'important', 'intermittent', 'isochronal', 'measured'],
    'equable': ['accordant', 'alike', 'automatic', 'balanced', 'calm', 'collected', 'composed', 'consistent', 'consonant', 'constant', 'continuous', 'cool'],
    'equal': ['accord', 'accordant', 'agent', 'agree', 'aligned', 'alike', 'alter ego', 'alternate', 'alternative', 'amount to', 'analogous', 'analogy'],
    'equal to': ['able', 'adequate', 'alert for', 'ample', 'au fait', 'barely sufficient', 'capable', 'commensurate', 'competent', 'corresponding', 'decent', 'due'],
    'equality': ['agreement', 'analogy', 'balance', 'bilateral symmetry', 'coequality', 'coincidence', 'comparability', 'comparison', 'conformity', 'congruence', 'congruity', 'consistency'],
    'equalize': ['accommodate', 'accord', 'adapt', 'adjust', 'adjust to', 'align', 'assimilate', 'assimilate to', 'attune', 'balance', 'cancel', 'compensate'],
    'equalizer': ['ko', 'clincher', 'crusher', 'death stroke', 'deathblow', 'end-all', 'ender', 'final stroke', 'finisher', 'finishing stroke', 'kayo', 'kayo punch'],
    'equalizing': ['accommodation', 'adjustment', 'changeable', 'commutable', 'commutative', 'convertible', 'coordination', 'equal', 'equalization', 'equating', 'equation', 'equilibration'],
    'equally': ['according to circumstances', 'accordingly', 'ad eundem', 'alike', 'as', 'as is', 'as it is', 'as matters stand', 'as well', 'at that rate', 'ceteris paribus', 'coequally'],
    'equanimity': ['accordance', 'aplomb', 'assurance', 'ataraxy', 'balance', 'calm', 'calmness', 'composure', 'confidence', 'consistency', 'consonance', 'constancy'],
    'equate': ['accommodate', 'adjust', 'align', 'ally', 'apply', 'assimilate', 'associate', 'balance', 'bind', 'bracket', 'cancel', 'collimate'],
    'equation': ['accommodation', 'addend', 'adjustment', 'antilogarithm', 'argument', 'balance', 'base', 'binomial', 'characteristic', 'coefficient', 'coequality', 'coextension'],
    'equator': ['antarctic zone', 'arctic circle', 'arctic zone', 'frigid zones', 'torrid zone', 'tropic of cancer', 'tropic of capricorn', 'variable zones', 'anklet', 'aphelion', 'apogee', 'armlet'],
    'equatorial': ['aestival', 'amidships', 'average', 'blood-hot', 'blood-warm', 'calid', 'central', 'core', 'equidistant', 'genial', 'halfway', 'interior'],
    'equerry': ['boy', 'breaker', 'breeder', 'broncobuster', 'buckaroo', 'butler', 'cattleman', 'chauffeur', 'coachman', 'cow keeper', 'cowman', 'dairy farmer'],
    'equestrian': ['asinine', 'bovid', 'bovine', 'broncobuster', 'buckaroo', 'caballero', 'caprid', 'caprine', 'cavalier', 'cavalryman', 'chevalier', 'circus rider'],
    'equidistant': ['aligned', 'amidships', 'analogous', 'average', 'center', 'centermost', 'central', 'coextending', 'coextensive', 'collateral', 'concurrent', 'core'],
    'equilateral': ['balanced', 'coequal', 'coordinate', 'equal', 'equiangular', 'equidimensional', 'equiproportional', 'equisided', 'equisized', 'equispaced', 'eurythmic', 'even'],
    'equilibrium': ['accordance', 'aplomb', 'assurance', 'balance', 'balanced personality', 'beauty', 'bilateral symmetry', 'calm', 'coequality', 'coextension', 'communion', 'community'],
    'equine': ['houyhnhnm', 'asinine', 'bovid', 'bovine', 'brood mare', 'caprid', 'caprine', 'charger', 'colt', 'courser', 'cowish', 'cowlike'],
    'equinox': ['aphelion', 'apogee', 'astronomical longitude', 'autumnal equinox', 'celestial equator', 'celestial longitude', 'celestial meridian', 'circle', 'colures', 'ecliptic', 'equator', 'equinoctial'],
    'equip': ['accouter', 'adapt', 'adjust', 'appoint', 'arm', 'array', 'attire', 'attune', 'capacitate', 'caparison', 'clothe', 'condition'],
    'equipage': ['accouterments', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'conveniences', 'duffel', 'equipment', 'facilities', 'facility', 'fittings'],
    'equipment': ['lecher wires', 'rc oscillator', 'vom', 'vtvm', 'ability', 'accessories', 'accouterment', 'accouterments', 'adaptation', 'adjustment', 'ammeter', 'anemometer'],
    'equipoise': ['balance', 'ballast', 'coequality', 'coextension', 'consideration', 'correspondence', 'counterbalance', 'counterpoise', 'counterweight', 'equality', 'equation', 'equilibrium'],
    'equipped': ['accoutered', 'all ready', 'all set', 'armed', 'armed and ready', 'booted and spurred', 'briefed', 'catered', 'coached', 'cocked', 'endowed', 'familiarized'],
    'equispaced': ['aligned', 'analogous', 'coextending', 'coextensive', 'collateral', 'concurrent', 'equal', 'equiangular', 'equidimensional', 'equidistant', 'equilateral', 'equiproportional'],
    'equitable': ['balanced', 'defensible', 'deserved', 'detached', 'disinterested', 'dispassionate', 'due', 'equal', 'equivalent', 'ethical', 'even', 'evenhanded'],
    'equity': ['code napoleon', 'corpus juris canonici', 'napoleonic code', 'roman law', 'absolute interest', 'admiralty law', 'assessable stock', 'authorized capital stock', 'balance', 'benefit', 'blue chip', 'blue chip stock'],
    'equivalence': ['accord', 'accordance', 'affinity', 'agreement', 'analogousness', 'assent', 'balance', 'chorus', 'coequality', 'coextension', 'coherence', 'coincidence'],
    'equivalent': ['doppelganger', 'accordant', 'actual thing', 'affirmative', 'agent', 'agnate', 'agreeable', 'agreeing', 'akin', 'alike', 'all one', 'all the same'],
    'equivocal': ['agnostic', 'amalgamated', 'ambagious', 'ambiguous', 'ambivalent', 'amphibious', 'amphibolic', 'amphibological', 'amphibolous', 'antinomic', 'blended', 'borderline'],
    'equivocate': ['about the bush', 'alternate', 'around the bush', 'avoid', 'back and fill', 'be untruthful', 'beat about', 'beat around', 'beg the question', 'bicker', 'boggle', 'cavil'],
    'equivocation': ['ambiguity', 'ambivalence', 'amphibology', 'antinomy', 'apparent soundness', 'avoidance', 'avoiding reaction', 'bickering', 'boggling', 'captiousness', 'casuistry', 'caviling'],
    'era': ['bronze age', 'dark ages', 'depression era', 'golden age', 'ice age', 'iron age', 'jacksonian age', 'middle ages', 'new deal era', 'prohibition era', 'silver age', 'steel age'],
    'eradicate': ['abate', 'abolish', 'abscind', 'abstract', 'amputate', 'annihilate', 'avulse', 'ban', 'bar', 'blot', 'bob', 'cast off'],
    'eradicative': ['all-consuming', 'all-devouring', 'annihilative', 'arousing', 'educible', 'eductive', 'elicitory', 'evocative', 'exacting', 'exactive', 'exterminatory', 'extirpative'],
    'erase': ['abbreviate', 'ablate', 'abolish', 'abrade', 'abrase', 'abridge', 'annul', 'bark', 'black out', 'blast', 'blot', 'blot out'],
    'erasure': ['abbreviation', 'ablation', 'abrasion', 'abrasive', 'abridgment', 'attrition', 'blackout', 'blocking', 'blot', 'blotting', 'blotting out', 'blue-penciling'],
    'erato': ['apollo', 'apollo musagetes', 'bragi', 'calliope', 'castilian spring', 'clio', 'euterpe', 'helicon', 'hippocrene', 'melpomene', 'muse', 'orpheus'],
    'ere': ['already', 'ante', 'before', 'before all', 'earlier', 'early', 'ere then', 'erenow', 'formerly', 'heretofore', 'hitherto', 'in advance of'],
    'erebus': ['aides', 'aidoneus', 'cerberus', 'charon', 'cora', 'despoina', 'dis', 'dis pater', 'egyptian darkness', 'hades', 'hel', 'kore'],
    'erect': ['christian', 'aggrandize', 'assemble', 'blameless', 'bolt upright', 'boost', 'build', 'buoy up', 'cast', 'cast up', 'clean', 'compose'],
    'erection': ['dymaxion house', 'white house', 'adobe house', 'apotheosis', 'architecture', 'ascent', 'assembly', 'assumption', 'beatification', 'building', 'canonization', 'casa'],
    'ergo': ['accordingly', 'because of that', 'because of this', 'consequently', 'for that', 'for that cause', 'for that reason', 'for this cause', 'for this reason', 'for which reason', 'hence', 'hereat'],
    'ermine': ['australian seal', 'achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'azure', 'bandeau', 'bar'],
    'erode': ['abate', 'ablate', 'abrade', 'abrase', 'absorb', 'abstract', 'assimilate', 'atomize', 'bark', 'bate', 'be consumed', 'be eaten away'],
    'eroded': ['abated', 'ablated', 'attenuated', 'bated', 'belittled', 'blanched', 'bleached', 'burnt up', 'by the board', 'consumed', 'contracted', 'corroded'],
    'erogenous': ['amorous', 'carnal', 'erogenic', 'erotic', 'erotogenic', 'fleshly', 'gamic', 'heterosexual', 'libidinal', 'nuptial', 'oversexed', 'potent'],
    'eros': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'astarte', 'ate', 'athena', 'bacchus', 'ceres'],
    'erosion': ['ablation', 'abrading', 'abrasion', 'abrasive', 'absorption', 'abstraction', 'assimilation', 'atomization', 'attrition', 'breakup', 'buffing', 'burning up'],
    'erotic': ['amative', 'amatory', 'amorous', 'anacreontic', 'animal', 'aphrodisiac', 'aphrodisiomaniacal', 'ardent', 'arousing', 'bawdy', 'blue', 'canal'],
    'erotica': ['french literature', 'renaissance literature', 'ancient literature', 'belles lettres', 'classics', 'contemporary literature', 'erotic literature', 'folk literature', 'humane letters', 'kitsch', 'letters', 'literature'],
    'eroticism': ['andromania', 'animality', 'aphrodisia', 'bawdiness', 'biological urge', 'bodily appetite', 'carnal desire', 'carnality', 'clitoromania', 'concupiscence', 'desire', 'dirtiness'],
    'err': ['backslide', 'be in error', 'be mistaken', 'be wrong', 'blunder', 'bungle', 'commit sin', 'degenerate', 'deviate', 'divagate', 'do amiss', 'do wrong'],
    'errancy': ['aberrancy', 'aberration', 'defectiveness', 'delusion', 'deviancy', 'distortion', 'errability', 'erroneousness', 'error', 'fallaciousness', 'fallacy', 'fallibility'],
    'errand': ['agency', 'agentship', 'assignment', 'authority', 'authorization', 'brevet', 'busywork', 'care', 'chare', 'charge', 'chore', 'commission'],
    'errand boy': ['ganymede', 'hebe', 'airline hostess', 'airline stewardess', 'attendant', 'batman', 'bellboy', 'bellhop', 'bellman', 'bootblack', 'boots', 'cabin boy'],
    'errant': ['aberrant', 'aberrative', 'abroad', 'adrift', 'all abroad', 'all off', 'all wrong', 'amiss', 'askew', 'astray', 'at fault', 'awry'],
    'errantry': ['wanderjahr', 'aberrancy', 'aberration', 'afoot and lighthearted', 'bend', 'bias', 'bigheartedness', 'bigness', 'branching off', 'bumming', 'chivalrousness', 'chivalry'],
    'errata': ['acknowledgments', 'back', 'back matter', 'bastard title', 'bibliography', 'catch line', 'catchword', 'colophon', 'contents', 'contents page', 'copyright page', 'dedication'],
    'erratic': ['aberrant', 'aberrative', 'abnormal', 'adrift', 'afloat', 'agnostic', 'aimless', 'alternating', 'ambiguous', 'amorphous', 'anomalistic', 'anomalous'],
    'erratum': ['clerical error', 'corrigendum', 'error', 'failure', 'fault', 'faute', 'human error', 'misapprehension', 'miscalculation', 'miscarriage', 'misconception', 'miscount'],
    'erroneous': ['albigensian', 'arian', 'catharist', 'donatist', 'ebionitist', 'erastian', 'gnostic', 'jansenist', 'jansenistic', 'jovinianist', 'jovinianistic', 'lollard'],
    'error': ['algol', 'albigensianism', 'arianism', 'cobol', 'catharism', 'ebionitism', 'erastianism', 'fortran', 'gnosticism', 'jovinianism', 'lollardy', 'manichaeanism'],
    'ersatz': ['affected', 'agent', 'alike', 'alternate', 'alternative', 'analogy', 'aped', 'apocryphal', 'artificial', 'assumed', 'backup', 'bastard'],
    'erstwhile': ['already', 'ancient', 'bygone', 'earlier', 'early', 'fore', 'former', 'formerly', 'heretofore', 'immemorial', 'late', 'old'],
    'eruct': ['belch', 'blow open', 'blow out', 'break out', 'burp', 'burst forth', 'burst out', 'cast forth', 'debouch', 'decant', 'discharge', 'disembogue'],
    'erudite': ['abstruse', 'civilized', 'cultivated', 'cultured', 'deep', 'educated', 'encyclopedic', 'learned', 'lettered', 'literate', 'pansophic', 'polyhistoric'],
    'erudition': ['sophia', 'bibliolatry', 'bibliomania', 'bluestockingism', 'book learning', 'book madness', 'bookiness', 'bookishness', 'booklore', 'broad-mindedness', 'broadening the mind', 'classical scholarship'],
    'erupt': ['od', 'appear', 'arise', 'bail out', 'be born', 'be brought down', 'be felled', 'be struck down', 'be traumatized', 'become', 'belch', 'blow open'],
    'eruption': ['access', 'belch', 'blaze', 'blaze of temper', 'blowout', 'blowup', 'breaking out', 'burst', 'cascade', 'convulsion', 'cyclone', 'debouchment'],
    'eruptive': ['agitable', 'bursting', 'detonating', 'edgy', 'emotional', 'emotionally unstable', 'excitable', 'explodable', 'explosible', 'explosive', 'fulminating', 'high-mettled'],
    'erwhelming': ['perturbing', 'piquant', 'prepossessing', 'provocative', 'provoking', 'provoquant', 'radiant', 'raving', 'resplendent', 'seducing', 'seductive', 'sensuous'],
    'erythrocyte': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'antibody', 'antigen', 'arterial blood', 'blood', 'blood bank', 'blood cell', 'blood count'],
    'escalate': ['boost', 'broaden', 'buoy up', 'cast up', 'climb', 'elevate', 'enlarge', 'erect', 'escalade', 'expand', 'grow', 'heave'],
    'escalation': ['apotheosis', 'ascent', 'assumption', 'beatification', 'canonization', 'deification', 'elevation', 'enshrinement', 'erection', 'exaltation', 'height', 'lifting'],
    'escapade': ['antic', 'bat', 'bender', 'binge', 'bout', 'bust', 'caper', 'carousal', 'carouse', 'celebration', 'debauch', 'drinking bout'],
    'escape': ['abandonment', 'abscond', 'alienation', 'autism', 'autistic thinking', 'avenue', 'avoid', 'avoidance', 'avoidance mechanism', 'avoiding reaction', 'baffle', 'bail out'],
    'escape hatch': ['alternative', 'back door', 'back stairs', 'back way', 'bolt-hole', 'boundary condition', 'catch', 'choice', 'clause', 'condition', 'covert way', 'donnee'],
    'escape notice': ['be latent', 'be missed', 'be unseen', 'blush unseen', 'disappear', 'escape attention', 'escape one', 'get by', 'hibernate', 'lie beneath', 'lie dormant', 'lie hid'],
    'escapism': ['alienation', 'autism', 'autistic thinking', 'avoidance mechanism', 'blame-shifting', 'break', 'breakout', 'compensation', 'decompensation', 'defense mechanism', 'deliverance', 'delivery'],
    'escapist': ['don quixote', 'quixote', 'alcoholic', 'alternating personality', 'antisocial personality', 'daydreamer', 'disordered personality', 'disturbed personality', 'double personality', 'dreamer', 'dreamer of dreams', 'drug user'],
    'escarpment': ['abatis', 'advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'bastion', 'battlement'],
    'eschatology': ['buddhology', 'day of judgment', 'judgment day', 'mariolatry', 'mariology', 'mercersburg theology', 'apodosis', 'apologetics', 'canonics', 'catastrophe', 'ceasing', 'cessation'],
    'eschew': ['abstain', 'abstain from', 'avoid', 'bilk', 'do without', 'double', 'duck', 'elude', 'evade', 'forbear', 'forgo', 'hold aloof from'],
    'escort': ['accompany', 'attend', 'attendant', 'bear', 'beau', 'bodyguard', 'boyfriend', 'bring', 'carry', 'cavalier', 'chaperon', 'cicerone'],
    'escrow': ['bail', 'bond', 'earnest', 'earnest money', 'gage', 'handsel', 'hock', 'hostage', 'mainprise', 'pawn', 'pignus', 'pledge'],
    'escutcheon': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'azure', 'bandeau', 'bar', 'bar sinister'],
    'esoteric': ['absolute', 'abstract', 'abstruse', 'anagogic', 'arcane', 'auricular', 'between the lines', 'between us', 'cabalic', 'cabalistic', 'censored', 'certain'],
    'esoterica': ['abstruseness', 'arcanum', 'cabala', 'classified information', 'complexity', 'complication', 'confidence', 'confidential communication', 'crabbedness', 'crampedness', 'deepness', 'difficulty'],
    'esoterics': ['anagoge', 'anagogics', 'anthroposophy', 'cabala', 'cabalism', 'esotericism', 'esoterism', 'esotery', 'hocus-pocus', 'mumbo jumbo', 'mystery', 'mysticism'],
    'esp': ['answer', 'clairsentience', 'clairvoyance', 'commerce', 'communication', 'communion', 'congress', 'connection', 'contact', 'conversation', 'converse', 'correspondence'],
    'especial': ['absolute', 'certain', 'concrete', 'defined', 'definite', 'detailed', 'determinate', 'different', 'distinct', 'distinguished', 'dominant', 'esoteric'],
    'especially': ['a fortiori', 'above all', 'all the more', 'chiefly', 'concretely', 'conspicuously', 'definitely', 'distinctively', 'distinctly', 'dominantly', 'eminently', 'even'],
    'esperanto': ['arulo', 'blaia zimondal', 'esperantido', 'europan', 'idiom neutral', 'interlingua', 'latinesce', 'lingualumina', 'lingvo kosmopolita', 'monario', 'nov-esperanto', 'nov-latin'],
    'espial': ['bringing to light', 'bugging', 'casual discovery', 'catching', 'chance discovery', 'cloak-and-dagger work', 'counterespionage', 'counterintelligence', 'detection', 'determination', 'determining', 'disclosure'],
    'espionage': ['bugging', 'cloak-and-dagger work', 'counterespionage', 'counterintelligence', 'electronic surveillance', 'espial', 'following', 'intelligence', 'intelligence work', 'looking', 'lookout', 'military intelligence'],
    'esplanade': ['alameda', 'beaten path', 'beaten track', 'berm', 'bicycle path', 'billiard table', 'boardwalk', 'bowling green', 'bridle path', 'catwalk', 'dead flat', 'dead level'],
    'espousal': ['gretna green wedding', 'acceptance', 'adoption', 'advocacy', 'affiance', 'affiliation', 'aid', 'approval', 'banns', 'banns of matrimony', 'betrothal', 'betrothing'],
    'espouse': ['accept', 'adopt', 'advocate', 'affiliate', 'allege in support', 'answer', 'approve', 'argue for', 'assert', 'back', 'be made one', 'be spliced'],
    'esprit': ['atticism', 'vernunft', 'accord', 'accordance', 'acuity', 'acumen', 'acuteness', 'adroitness', 'affinity', 'agape', 'agile wit', 'agreement'],
    'esprit de corps': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'amity', 'bipartisanship', 'bonds of harmony', 'boon companionship', 'brotherhood', 'brotherliness', 'brotherly love'],
    'espy': ['behold', 'catch', 'catch sight of', 'clap eyes on', 'descry', 'detect', 'discern', 'discover', 'distinguish', 'encounter', 'glimpse', 'have in sight'],
    'esquire': ['brahman', 'casanova', 'don juan', 'lothario', 'romeo', 'amoroso', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'beau'],
    'essay': ['acid test', 'approach', 'article', 'assay', 'attempt', 'autograph', 'bid', 'blank determination', 'brainchild', 'bring to test', 'brouillon', 'causerie'],
    'essayist': ['advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'coauthor', 'collaborator', 'columnist', 'compiler', 'composer'],
    'essence': ['affective meaning', 'ambergris', 'ambrosia', 'aroma', 'aromatic', 'aromatic gum', 'aromatic water', 'artifact', 'aspect', 'at bottom', 'attar', 'attar of roses'],
    'essential': ['ab ovo', 'austere', 'axiom', 'bare', 'bare necessities', 'basal', 'basic', 'basilar', 'bedrock', 'bench mark', 'brass tacks', 'call for'],
    'essentially': ['a outrance', 'absolutely', 'actually', 'all but', 'all in all', 'all out', 'almost entirely', 'approximately', 'as good as', 'as much as', 'at bottom', 'at heart'],
    'establish': ['acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'advertise', 'affirm', 'afford proof of', 'ascertain', 'assure', 'authenticate'],
    'established': ['accepted', 'acknowledged', 'actual', 'admitted', 'ascertained', 'assigned', 'assured', 'attested', 'authenticated', 'borne out', 'categorically true', 'certain'],
    'establishment': ['john bull', 'rasputin', 'svengali', 'uncle sam', 'vip', 'washington', 'whitehall', 'access', 'bad influence', 'baron', 'big gun', 'big man'],
    'estate': ['everyman', 'john doe', 'public', 'absolute interest', 'acres', 'assets', 'bearings', 'belongings', 'benefit', 'blood', 'body politic', 'bracket'],
    'esteem': ['ok', 'accept', 'acceptance', 'accord respect to', 'account', 'account as', 'adherence', 'adjudge', 'adjudicate', 'admiration', 'admire', 'adoration'],
    'esteemed': ['admired', 'adored', 'appreciated', 'beloved', 'celebrated', 'cherished', 'conspicuous', 'creditable', 'darling', 'dear', 'dearly beloved', 'distinguished'],
    'ester': ['animal oil', 'cerate', 'drying oil', 'essential oil', 'fat', 'fatty oil', 'fixed oil', 'glycerin', 'glycerin jelly', 'glycerogel', 'glycerogelatin', 'glycerol'],
    'estimable': ['christian', 'admirable', 'admired', 'advantageous', 'appraisable', 'appreciable', 'assessable', 'august', 'auspicious', 'authoritative', 'awe-inspiring', 'awesome'],
    'estimate': ['account as', 'add', 'adjudge', 'adjudicate', 'algebraize', 'analyzing', 'appraisal', 'appraise', 'appraisement', 'appraising', 'appreciate', 'appreciation'],
    'estimation': ['account', 'adding', 'admiration', 'adoration', 'analyzing', 'apotheosis', 'appraisal', 'appraisement', 'appraising', 'appreciation', 'apprizal', 'approbation'],
    'estop': ['anticipate', 'avert', 'bar', 'debar', 'deflect', 'deter', 'discourage', 'dishearten', 'exclude', 'fend', 'fend off', 'forbid'],
    'estrange': ['abrupt', 'aggravate', 'alien', 'alienate', 'antagonize', 'break up', 'cast off', 'cast out', 'come between', 'cut adrift', 'cut off', 'cut out'],
    'estranged': ['alienated', 'detached', 'disaffected', 'disarticulated', 'disassociated', 'disconnected', 'disengaged', 'disjoined', 'disjoint', 'disjointed', 'disjunct', 'dislocated'],
    'estuarine': ['alluvial', 'aquatic', 'balneal', 'bayed', 'deep-sea', 'embayed', 'fluviomarine', 'grallatorial', 'gulfed', 'gulflike', 'gulfy', 'littoral'],
    'estuary': ['arm', 'armlet', 'avenue', 'bay', 'bayou', 'belt', 'bight', 'blowhole', 'boca', 'channel', 'chute', 'cove'],
    'et cetera': ['and all', 'and all that', 'and everything else', 'and other things', 'and others', 'and so forth', 'and so on', 'and suchlike', 'and the following', 'and the like', 'and the rest', 'and then some'],
    'etch': ['bed', 'bite', 'bring home to', 'carve', 'confirm', 'corrode', 'cut', 'deep-dye', 'define', 'delineate', 'depict', 'describe'],
    'etched': ['confirmed', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid', 'deep-rooted', 'deep-seated', 'deep-set', 'deep-settled', 'dyed-in-the-wool', 'embedded'],
    'etching': ['abstract art', 'aquatint', 'art', 'art form', 'artist', 'arts and crafts', 'arts of design', 'autolithograph', 'block', 'block print', 'burr', 'calligraphy'],
    'eternal': ['ageless', 'all-comprehensive', 'all-inclusive', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'boundless', 'ceaseless', 'changeless', 'coeternal'],
    'eternally': ['ad infinitum', 'always', 'boundlessly', 'ceaselessly', 'constantly', 'continually', 'endlessly', 'ever', 'everlastingly', 'evermore', 'forever', 'forevermore'],
    'eternity': ['beulah', 'beulah land', 'heaven', 'land of beulah', 'paradise', 'a better place', 'aeon', 'afterlife', 'age', 'ages', 'all-comprehensiveness', 'all-inclusiveness'],
    'ethane': ['alcohol', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coke', 'combustible', 'dope', 'ethanol'],
    'ether': ['caelus', 'dry ice', 'freon', 'olympian heights', 'pentothal', 'acme', 'aerial heights', 'air', 'airy nothing', 'ammonia', 'apex', 'azure'],
    'ethereal': ['elysian', 'olympian', 'adulterated', 'aerial', 'aeriform', 'aerodynamic', 'aerostatic', 'aery', 'air-built', 'airish', 'airlike', 'airy'],
    'etherealize': ['adulterate', 'attenuate', 'cut', 'dematerialize', 'dilute', 'disembody', 'disincarnate', 'enervate', 'expand', 'idealize', 'immaterialize', 'rarefy'],
    'etherize': ['ko', 'aerate', 'aerify', 'anesthetize', 'atomize', 'bedaze', 'benumb', 'besot', 'blunt', 'carbonate', 'chlorinate', 'chloroform'],
    'ethical': ['christian', 'axiological', 'blameless', 'clean', 'conscientious', 'correct', 'creditable', 'decent', 'deferential', 'duteous', 'dutiful', 'elevated'],
    'ethics': ['aesthetics', 'allegiance', 'assigned task', 'axiology', 'bounden duty', 'burden', 'business', 'call of duty', 'casuistry', 'charge', 'commitment', 'cosmology'],
    'ethnic group': ['breakaway group', 'camp', 'caucus', 'community', 'culture', 'division', 'faction', 'interest', 'interest group', 'minority group', 'nation', 'nationality'],
    'ethnocentric': ['clannish', 'cliquey', 'cliquish', 'exceptional', 'excluding', 'exclusive', 'exclusory', 'inadmissible', 'insular', 'narrow', 'parochial', 'preclusive'],
    'ethos': ['ten commandments', 'weltanschauung', 'zeitgeist', 'acculturation', 'assumption', 'attitude', 'axiology', 'behavioral norm', 'body of ideas', 'body-build', 'brand', 'business ethics'],
    'ethyl': ['avgas', 'crude', 'crude oil', 'ethyl gas', 'fossil oil', 'gas', 'gasoline', 'high-octane gas', 'high-test', 'kerosene', 'lead-free gas', 'low-lead gas'],
    'etiology': ['accounting for', 'answerability', 'antecedents', 'application', 'arrogation', 'ascription', 'assignation', 'assignment', 'attachment', 'attribution', 'base', 'basis'],
    'etiquette': ['amenities', 'approbatory', 'approving', 'behavior', 'bienseance', 'bon ton', 'civilities', 'civility', 'comity', 'commendatory', 'complimentary', 'conduct'],
    'etude': ['nachtmusik', 'absolute music', 'adaptation', 'air varie', 'aleatory', 'aleatory music', 'arrangement', 'article', 'causerie', 'chamber music', 'chamber orchestra', 'composition'],
    'etymology': ['bowwow theory', 'comparative linguistics', 'derivation', 'descriptive linguistics', 'dialectology', 'dingdong theory', 'eponymy', 'folk etymology', 'glossematics', 'glossology', 'glottochronology', 'glottology'],
    'eucharist': ['communion', 'holy communion', 'host', 'last supper', 'sacrament sunday', 'altar bread', 'baptism', 'bread', 'bread and wine', 'confirmation', 'consecrated bread', 'consecrated elements'],
    'euchre': ['beat', 'beguile of', 'bilk', 'bunco', 'burn', 'cheat', 'chisel', 'chouse', 'chouse out of', 'cog', 'cog the dice', 'con'],
    'eugenics': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'great leap forward', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory'],
    'eulogize': ['acclaim', 'adulate', 'apotheosize', 'applaud', 'appreciate', 'belaud', 'bepraise', 'bless', 'blow up', 'boast of', 'brag about', 'celebrate'],
    'eulogy': ['acclaim', 'acclamation', 'accolade', 'address', 'adulation', 'after-dinner speech', 'allocution', 'apotheosis', 'applause', 'bepraisement', 'burial service', 'chalk talk'],
    'eupeptic': ['accepting', 'alive and kicking', 'at ease', 'beaming', 'blithe', 'blithesome', 'bright', 'bright and sunny', 'bright-eyed and bushy-tailed', 'charmed', 'cheerful', 'cheery'],
    'euphemism': ['gongorism', 'affectation', 'affectedness', 'amelioration', 'artfulness', 'artifice', 'artificiality', 'cushioning', 'elegance', 'euphuism', 'exquisiteness', 'formalism'],
    'euphemistic': ['elegant', 'euphuistic', 'exquisite', 'formalistic', 'goody good-good', 'goody-goody', 'mincing', 'namby-pamby', 'overnice', 'overprecise', 'overrefined', 'pedantic'],
    'euphonious': ['achingly sweet', 'agreeable', 'agreeable-sounding', 'appealing', 'ariose', 'arioso', 'balanced', 'canorous', 'cantabile', 'catchy', 'concinnate', 'concinnous'],
    'euphony': ['accord', 'accordance', 'attune', 'attunement', 'balance', 'beauty', 'chime', 'chiming', 'concentus', 'concert', 'concinnity', 'concord'],
    'euphoria': ['abstraction', 'abulia', 'acceptance', 'alienation', 'amusement', 'animal pleasure', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'bodily pleasure', 'carnal delight'],
    'euphoric': ['accepting', 'at ease', 'beaming', 'blithe', 'blithesome', 'bright', 'bright and sunny', 'charmed', 'cheerful', 'cheery', 'comfortable', 'composed'],
    'euphuism': ['gongorism', 'affectation', 'affectedness', 'artfulness', 'artifice', 'artificiality', 'asiaticism', 'device', 'elegance', 'euphemism', 'exquisiteness', 'figurative language'],
    'eurasian': ['cape colored', 'cattalo', 'citrange', 'cross', 'crossbreed', 'griffe', 'half blood', 'half-bred', 'half-breed', 'half-caste', 'high yellow', 'hinny'],
    'europe': ['africa', 'america', 'antarctica', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'australia', 'east', 'eastern hemisphere', 'eurasia'],
    'eurythmics': ['balance', 'bilateral symmetry', 'calisthenics', 'conformity', 'congruity', 'consistency', 'correspondence', 'dynamic symmetry', 'equality', 'equilibrium', 'eurythmy', 'evenness'],
    'euterpe': ['apollo', 'apollo musagetes', 'bragi', 'calliope', 'castilian spring', 'clio', 'erato', 'helicon', 'hippocrene', 'melpomene', 'muse', 'orpheus'],
    'euthanasia': ['bane', 'blood', 'bloodletting', 'bloodshed', 'braining', 'dealing death', 'destruction', 'destruction of life', 'dispatch', 'execution', 'extermination', 'flow of blood'],
    'evacuate': ['abandon', 'abscond', 'back out', 'beat a retreat', 'beg off', 'blow', 'blow out', 'bow out', 'breathe out', 'ca-ca', 'clean out', 'clear'],
    'evacuation': ['bm', 'abandonment', 'absentation', 'bloody flux', 'bowel movement', 'casting away', 'catharsis', 'cessation', 'cleaning out', 'clearance', 'clearing', 'crap'],
    'evacuee': ['dp', 'absconder', 'bolter', 'displaced person', 'eloper', 'emigrant', 'emigre', 'escapee', 'evacue', 'exile', 'expatriate', 'fleer'],
    'evade': ['abstain', 'around the bush', 'avoid', 'back and fill', 'bail out', 'beat about', 'beg', 'beg the question', 'bicker', 'bilk', 'blench', 'blink'],
    'evaluate': ['appraise', 'appreciate', 'approximate', 'ascertain', 'assay', 'assess', 'calculate', 'calibrate', 'caliper', 'call', 'catalog', 'categorize'],
    'evaluation': ['analyzing', 'appraisal', 'appraisement', 'appraising', 'appreciation', 'apprizal', 'approximation', 'assessing', 'assessment', 'assize', 'assizement', 'calculation'],
    'evanescent': ['atomic', 'brittle', 'capricious', 'changeable', 'corpuscular', 'corruptible', 'deciduous', 'disappearing', 'dissolving', 'dying', 'embryonic', 'ephemeral'],
    'evangelical': ['biblical', 'christian', 'gospel', 'mosaic', 'new-testament', 'old-testament', 'sabbatarian', 'accepted', 'apocalyptic', 'apostolic', 'approved', 'authentic'],
    'evangelist': ['ambrose of milan', 'athanasius', 'barnabas', 'basil', 'clement of alexandria', 'clement of rome', 'cyprian of carthage', 'cyril of jerusalem', 'gabriel', 'gregory of nyssa', 'hermas', 'ignatius'],
    'evangelistic': ['biblical', 'gospel', 'mosaic', 'new-testament', 'old-testament', 'abbatial', 'abbatical', 'apocalyptic', 'apostolic', 'archiepiscopal', 'canonical', 'capitular'],
    'evaporate': ['aerate', 'aerify', 'air-dry', 'anhydrate', 'atomize', 'attenuate', 'bake', 'be annihilated', 'be consumed', 'be destroyed', 'be gone', 'be no more'],
    'evaporated': ['adust', 'baked', 'burnt', 'corky', 'dehydrated', 'desiccated', 'dried', 'dried-up', 'exsiccated', 'mummified', 'parched', 'scorched'],
    'evaporation': ['ablation', 'aeration', 'aerification', 'air-drying', 'anhydration', 'atomization', 'attenuation', 'blackout', 'blast-freezing', 'blocking', 'bottling', 'brining'],
    'evasion': ['abstention', 'airtight secrecy', 'anythingarianism', 'artifice', 'avoidance', 'avoiding reaction', 'bickering', 'boggling', 'break', 'breakout', 'buck-passing', 'captiousness'],
    'evasive': ['ambiguous', 'amoral', 'bickering', 'cagey', 'captious', 'casuistic', 'caviling', 'choplogic', 'close', 'closemouthed', 'conscienceless', 'corrupt'],
    'even': ['laodicean', 'a fortiori', 'above all', 'absolutely', 'accommodate', 'accordant', 'adjust', 'after all', 'again', 'albeit', 'algorismic', 'algorithmic'],
    'even tempered': ['bovine', 'calm', 'cool', 'dispassionate', 'dull', 'equable', 'even', 'impassive', 'imperturbable', 'inexcitable', 'inirritable', 'levelheaded'],
    'evenhanded': ['balanced', 'defensible', 'deserved', 'detached', 'disinterested', 'dispassionate', 'due', 'equitable', 'even', 'fair', 'fair and square', 'fit'],
    'evening': ['accommodation', 'adjustment', 'afternoon', 'balancing', 'close of day', 'cockshut', 'coordination', 'crepuscular', 'dimpsy', 'dusk', 'duskiness', 'duskness'],
    'evenly': ['ad eundem', 'as', 'as well', 'at full length', 'calmly', 'ceteris paribus', 'composedly', 'conservatively', 'coolly', 'correspondingly', 'deservedly', 'disinterestedly'],
    'evenness': ['abnegation', 'abstinence', 'accordance', 'balance', 'bilateral symmetry', 'calm', 'calmness', 'clockwork regularity', 'coequality', 'coextension', 'conformity', 'congruity'],
    'evensong': ['mass', 'bedtime prayer', 'camp meeting', 'church', 'church service', 'close of day', 'cockshut', 'compline', 'crepuscular', 'devotions', 'divine service', 'dusk'],
    'event': ['accident', 'achievement', 'act', 'action', 'adventure', 'affair', 'aftereffect', 'aftermath', 'anyhow', 'anyway', 'at any rate', 'bout'],
    'eventful': ['active', 'bustling', 'busy', 'consequential', 'exciting', 'full', 'full of incident', 'important', 'interesting', 'lively', 'memorable', 'momentous'],
    'eventide': ['close of day', 'cockshut', 'dimpsy', 'dusk', 'eve', 'even', 'evening', 'evensong', 'gloaming', 'grayness', 'nightfall', 'setting sun'],
    'eventual': ['anticipated', 'closing', 'concluding', 'consequent', 'destined', 'due', 'ending', 'endmost', 'ensuing', 'expected', 'final', 'foreordained'],
    'eventuality': ['accident', 'aftereffect', 'aftermath', 'aftertime', 'afteryears', 'aptitude', 'aptness', 'bare possibility', 'by-and-by', 'by-product', 'case', 'chance'],
    'eventually': ['after all', 'as things go', 'as times go', 'at last', 'at length', 'at long last', 'at the end', 'at the last', 'conclusively', 'finally', 'in conclusion', 'in due course'],
    'ever': ['all the time', 'always', 'annoyingly', 'anytime', 'anyway', 'anywise', 'at all', 'at all times', 'at any cost', 'at any time', 'aye', 'by any chance'],
    'ever so': ['a deal', 'a fortiori', 'a great deal', 'a lot', 'above all', 'abundantly', 'all the more', 'as all creation', 'as all get-out', 'beaucoup', 'chiefly', 'considerable'],
    'everglade': ['baygall', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'fen', 'fenland', 'glade', 'hog wallow', 'holm', 'marais'],
    'evergreen': ['abiding', 'age-long', 'aged', 'amphibian', 'ancient', 'angiosperm', 'annual', 'antique', 'aquatic plant', 'arborary', 'arboreal', 'arboreous'],
    'everlasting': ['ageless', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'amaranthine', 'blah', 'boundless', 'broken-record', 'ceaseless', 'changeless'],
    'evermore': ['always', 'aye', 'eternally', 'ever', 'ever and again', 'ever and anon', 'for all time', 'for aye', 'for good', 'for keeps', 'forever', 'forever and aye'],
    'everted': ['arsy-varsy', 'ass over elbows', 'back-to-front', 'backwards', 'capsized', 'chiastic', 'hyperbatic', 'inside out', 'introverted', 'invaginated', 'inversed', 'inverted'],
    'every other': ['alternate', 'alternately', 'beating', 'by turns', 'circling', 'cyclic', 'epochal', 'even', 'in rotation', 'in turns', 'intermittent', 'isochronal'],
    'everybody': ['everyman', 'john doe', 'public', 'all', 'all hands', 'all the world', 'body politic', 'citizenry', 'common man', 'commonwealth', 'community', 'community at large'],
    'everyday': ['attic', 'accepted', 'accustomed', 'average', 'chaste', 'circadian', 'classic', 'classical', 'colloquial', 'common', 'commonplace', 'conformable'],
    'everyman': ['cockney', 'john doe', 'john smith', 'public', 'average', 'average man', 'body politic', 'bourgeois', 'citizenry', 'common man', 'common run', 'commoner'],
    'everyone': ['everyman', 'john doe', 'public', 'all', 'all and sundry', 'all hands', 'all the world', 'body politic', 'citizenry', 'common man', 'commonwealth', 'community'],
    'everything': ['a to z', 'a to izzard', 'aggregate', 'all', 'all and sundry', 'alpha and omega', 'assemblage', 'be-all', 'be-all and end-all', 'beginning and end', 'complement', 'each and every'],
    'everywhere': ['all over', 'all over hell', 'all round', 'all-present', 'always', 'and everywhere', 'around', 'at large', 'cosmically', 'diffusely', 'dispersedly', 'every which way'],
    'evict': ['boot out', 'chase', 'chuck', 'cut off', 'disendow', 'disherison', 'disinherit', 'dislodge', 'dismiss', 'disown', 'dispossess', 'disseise'],
    'eviction': ['disendowment', 'disherison', 'disinheritance', 'dislodgment', 'disownment', 'dispossession', 'disseisin', 'ejection', 'expropriation', 'expulsion', 'foreclosure', 'ouster'],
    'evidence': ['christophany', 'satanophany', 'account', 'acquaintance', 'affect', 'affidavit', 'affirmation', 'angelophany', 'announcement', 'apparentness', 'appearance', 'approve'],
    'evident': ['apparent', 'beholdable', 'clean-cut', 'clear', 'clear as crystal', 'clear-cut', 'comprehensible', 'conspicuous', 'crystal-clear', 'defined', 'definite', 'detectable'],
    'evidential': ['christophanic', 'satanophanic', 'absolute', 'adducible', 'admissible', 'angelophanic', 'appearing', 'attestative', 'attestive', 'authentic', 'based on', 'certain'],
    'evidently': ['apparently', 'certainly', 'clearly', 'conspicuously', 'definitely', 'discernibly', 'distinctly', 'doubtlessly', 'explicitly', 'expressly', 'glaringly', 'incontestably'],
    'evil': ['loki', 'nemesis', 'set', 'typhon', 'aberrant', 'abnormal', 'abominable', 'abomination', 'accursed', 'ado', 'affliction', 'agony'],
    'evil eye': ['jonah', 'anathema', 'bad blood', 'bad influence', 'bad temper', 'bad will', 'ban', 'bedroom eyes', 'blasphemy', 'blighting glance', 'cantrip', 'charm'],
    'evil looking': ['evil-eyed', 'evil-faced', 'evil-fashioned', 'evil-favored', 'evil-gotten', 'evil-minded', 'grim', 'grim-faced', 'grim-visaged', 'hard-favored', 'hard-featured', 'hard-visaged'],
    'evil minded': ['base-minded', 'dirty', 'dirty-minded', 'evil-eyed', 'evil-faced', 'evil-fashioned', 'evil-favored', 'evil-gotten', 'evil-looking', 'evilhearted', 'ill-affected', 'ill-conceived'],
    'evil nature': ['amorality', 'backsliding', 'carnality', 'criminality', 'delinquency', 'evil', 'immorality', 'impurity', 'moral delinquency', 'peccability', 'prodigality', 'recidivism'],
    'evil spirit': ['baba yaga', 'lilith', 'afreet', 'atua', 'barghest', 'cacodemon', 'daemon', 'daeva', 'demon', 'devil', 'dybbuk', 'evil genius'],
    'evil-minded': ['bad', 'depraved', 'dirty-minded', 'evil', 'filthy', 'flagitious', 'foul-mouthed', 'hateful', 'lascivious', 'lecherous', 'lewd', 'licentious'],
    'evildoing': ['crime', 'criminal', 'criminal tendency', 'criminality', 'criminosis', 'evil courses', 'felonious', 'feloniousness', 'iniquitous', 'lawbreaking', 'malefactory', 'malfeasance'],
    'evilness': ['arrantness', 'badness', 'baseness', 'damnability', 'devilishness', 'devilry', 'deviltry', 'fiendishness', 'flagitiousness', 'foulness', 'heinousness', 'hellishness'],
    'evince': ['affect', 'approve', 'argue', 'attest', 'bespeak', 'betoken', 'brandish', 'breathe', 'bring about', 'bring forth', 'bring forward', 'bring into view'],
    'eviscerate': ['abate', 'attenuate', 'blunt', 'bowel', 'cramp', 'cripple', 'damp', 'dampen', 'deaden', 'debilitate', 'devitalize', 'disembowel'],
    'evisceration': ['abatement', 'attenuation', 'attrition', 'blunting', 'damping', 'deadening', 'debilitation', 'devitalization', 'dilution', 'disembowelment', 'dulling', 'effemination'],
    'evocation': ['arousal', 'beck', 'beck and call', 'bidding', 'bringing out', 'call', 'calling', 'calling forth', 'cameo', 'catalog', 'cataloging', 'character'],
    'evocative': ['arousing', 'causing', 'educible', 'eductive', 'elicitory', 'eradicative', 'exacting', 'exactive', 'extortionary', 'extortionate', 'extortive', 'extractive'],
    'evoke': ['ape', 'appear like', 'approach', 'approximate', 'arouse', 'awake', 'awaken', 'be like', 'be redolent of', 'bear resemblance', 'bid come', 'bring'],
    'evolution': ['addition', 'advance', 'approximation', 'beautification', 'change', 'developing', 'development', 'differentiation', 'division', 'elaboration', 'embellishment', 'equation'],
    'evolutionary': ['advancing', 'bradytelic', 'developing', 'evolutional', 'evolutionist', 'evolutionistic', 'evolving', 'genetic', 'horotelic', 'maturational', 'maturative', 'maturing'],
    'evolve': ['advance', 'alter into', 'amplify', 'assemble', 'avulse', 'be converted into', 'bear fruit', 'beautify', 'become', 'beget', 'bloom', 'blossom'],
    'evolving': ['accomplishment', 'advance', 'advancement', 'advancing', 'amplification', 'blossoming', 'bradytelic', 'developing', 'development', 'developmental change', 'elaboration', 'enlargement'],
    'evulsion': ['avulsion', 'cutting out', 'deracination', 'disentanglement', 'drawing', 'drawing out', 'dredging', 'drilling', 'enucleation', 'eradication', 'evolvement', 'excavation'],
    'ewe': ['partlet', 'bellwether', 'biddy', 'bitch', 'bossy', 'brood mare', 'cow', 'doe', 'ewe lamb', 'filly', 'guinea hen', 'gyp'],
    'ex': ['aside from', 'bar', 'barring', 'beside', 'besides', 'except', 'except for', 'excepting', 'excluding', 'exclusive of', 'from', 'leaving out'],
    'ex officio': ['absolute', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'clothed with authority', 'commanding', 'competent', 'consequential', 'considerable', 'controlling'],
    'ex post facto': ['a priori', 'after', 'after all', 'after that', 'afterwards', 'back', 'backward', 'early', 'in the aftermath', 'in the sequel', 'into the past', 'later'],
    'exacerbate': ['accelerate', 'acerbate', 'agent provocateur', 'aggravate', 'alienate', 'amplify', 'annoy', 'antagonize', 'augment', 'beef up', 'bitter', 'blow up'],
    'exacerbation': ['accelerando', 'acceleration', 'aggravation', 'agitation', 'amplification', 'animation', 'annoyance', 'arousal', 'arousing', 'augmentation', 'beefing-up', 'blowing up'],
    'exact': ['accurate', 'appreciative', 'ask', 'ask for', 'assess', 'attentive', 'badger', 'be hurting for', 'be indicated', 'blackmail', 'brook no denial', 'burden with'],
    'exacting': ['herculean', 'spartan', 'spartanic', 'abstruse', 'accurate', 'arduous', 'arousing', 'astringent', 'attentive', 'austere', 'authoritarian', 'brutal'],
    'exaction': ['admission', 'admission fee', 'anchorage', 'blackmail', 'bother', 'brokerage', 'burdening', 'call', 'call for', 'carfare', 'cellarage', 'charge'],
    'exactly': ['ok', 'roger', 'absolutely', 'accurately', 'all', 'all in all', 'all right', 'alright', 'alrighty', 'altogether', 'amen', 'as well'],
    'exactness': ['absoluteness', 'accuracy', 'attention to detail', 'attention to fact', 'care for truth', 'circumstantiality', 'conscientiousness', 'correctness', 'criticality', 'criticalness', 'definiteness', 'delicacy'],
    'exaggerate': ['accelerate', 'aggrandize', 'aggravate', 'amplify', 'ballyhoo', 'be untruthful', 'beef up', 'belie', 'blow up', 'build up', 'burlesque', 'camouflage'],
    'exaggerated': ['a bit much', 'abandoned', 'aggrandized', 'amplified', 'ballyhooed', 'boundless', 'disproportionate', 'egregious', 'enormous', 'excessive', 'exorbitant', 'extravagant'],
    'exaggeration': ['abandon', 'abstractionism', 'accelerando', 'acceleration', 'affectation', 'aggrandizement', 'aggravation', 'amplification', 'beefing-up', 'blague', 'blowing up', 'blowup'],
    'exalt': ['acclaim', 'accord respect to', 'add to', 'admire', 'adore', 'adulate', 'advance', 'aggrandize', 'amplify', 'animate', 'apotheose', 'apotheosize'],
    'exaltation': ['accolade', 'adulation', 'advance', 'advancement', 'aggrandizement', 'altitude', 'apotheosis', 'ascent', 'assumption', 'beatification', 'beatitude', 'bepraisement'],
    'exalted': ['olympian', 'aerial', 'aggrandized', 'airy', 'altitudinous', 'analysis', 'apotheosized', 'aristocratic', 'ascending', 'aspiring', 'assay', 'astral'],
    'exam': ['audition', 'blue book', 'examen', 'examination', 'final', 'final examination', 'great go', 'hearing', 'honors', 'midsemester', 'midterm', 'oral'],
    'examination': ['pap test', 'socratic method', 'airing', 'analysis', 'anatomic diagnosis', 'appraisal', 'article', 'asking', 'assessment', 'assize', 'audition', 'biological diagnosis'],
    'examine': ['air', 'analyze', 'appraise', 'archetype', 'asleep', 'assess', 'autopsy', 'beau ideal', 'bone', 'canvass', 'case', 'case history'],
    'examiner': ['analyst', 'analyzer', 'asker', 'catechist', 'cross-interrogator', 'cross-questioner', 'detective', 'examinant', 'inquirer', 'inquisitionist', 'inquisitor', 'inspector'],
    'examining': ['analytic', 'examinational', 'examinatorial', 'explorational', 'explorative', 'exploratory', 'fact-finding', 'feeling', 'groping', 'heuristic', 'indagative', 'inspectional'],
    'example': ['admonishment', 'admonition', 'alarm', 'archetype', 'as an example', 'benchmark', 'call to mind', 'case', 'case in point', 'caution', 'caveat', 'citation'],
    'exasperate': ['tb', 'aggravate', 'agitate', 'annoy', 'arouse', 'badger', 'bait', 'be at', 'bedevil', 'beset', 'bother', 'bristle'],
    'exasperated': ['aggravated', 'amplified', 'angry', 'annoyed', 'augmented', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'chafed', 'deliberately provoked', 'disturbed'],
    'exasperating': ['aggravating', 'aggravative', 'annoying', 'bothering', 'bothersome', 'contentious', 'disturbing', 'exasperative', 'galling', 'harassing', 'importunate', 'importune'],
    'exasperation': ['aggravation', 'agitation', 'amplification', 'animation', 'annoyance', 'annoyingness', 'arousal', 'arousing', 'augmentation', 'bad news', 'bedevilment', 'besetment'],
    'excavate': ['avulse', 'bore', 'bring to light', 'bring up', 'burrow', 'clear', 'countersink', 'cut out', 'deepen', 'delve', 'depress', 'deracinate'],
    'excavation': ['abysm', 'abyss', 'arroyo', 'avulsion', 'box canyon', 'breach', 'break', 'bringing to light', 'burrow', 'canyon', 'casual discovery', 'catching'],
    'exceed': ['beat', 'best', 'better', 'bulk', 'bulk large', 'cap', 'dare', 'eclipse', 'exaggerate', 'excel', 'go beyond', 'go one better'],
    'exceedingly': ['almighty', 'awfully', 'considerably', 'egregiously', 'eminently', 'enormously', 'especially', 'exceptionally', 'excessively', 'extraordinarily', 'extremely', 'far and away'],
    'excel': ['be born for', 'be master of', 'beat', 'best', 'better', 'cap', 'dominate', 'eclipse', 'exceed', 'go beyond', 'go one better', 'improve on'],
    'excellence': ['accomplishment', 'acquired taste', 'advantageousness', 'agreeableness', 'appreciation of excellence', 'arete', 'ascendancy', 'auspiciousness', 'beneficialness', 'benevolence', 'benignity', 'choiceness'],
    'excellent': ['al', 'attic', 'daedalian', 'grade a', 'a cut above', 'above', 'adept', 'admirable', 'adroit', 'advantageous', 'aesthetic', 'aggrandized'],
    'except': ['abjure', 'abscind', 'absolve', 'amputate', 'annihilate', 'apart from', 'aside from', 'ban', 'bar', 'barring', 'bate', 'beside'],
    'excepted': ['chartered', 'contemned', 'declined', 'declined with thanks', 'denied', 'despised', 'disapproved', 'discarded', 'discounted', 'disdained', 'dismissed', 'disowned'],
    'excepting': ['aside from', 'bar', 'barring', 'beside', 'besides', 'but', 'discounting', 'ex', 'except', 'except for', 'except that', 'exception taken of'],
    'exception': ['abjuration', 'abjurement', 'abnormality', 'adverse criticism', 'allowance', 'amazement', 'animadversion', 'anomaly', 'answer', 'argument', 'aspersion', 'astonishing thing'],
    'exceptional': ['aberrant', 'abnormal', 'absolute', 'anomalous', 'appalling', 'astonishing', 'beguiling', 'bewildering', 'celebrated', 'certain', 'concrete', 'conspicuous'],
    'exceptionally': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'beguilingly', 'bewilderingly', 'choose', 'cite', 'conspicuously', 'copiously'],
    'excerpt': ['choose out', 'citation', 'cite', 'cull', 'cull out', 'decide between', 'excerption', 'extract', 'extraction', 'glean', 'handpick', 'make a selection'],
    'excess': ['saturnalia', 'aggrandizement', 'amplification', 'ballyhoo', 'big talk', 'blowing up', 'burlesque', 'caricature', 'crapulence', 'crapulency', 'crapulousness', 'de trop'],
    'excessive': ['a bit much', 'abandoned', 'acute', 'aggrandized', 'amplified', 'ballyhooed', 'bibulous', 'boundless', 'cloying', 'crapulent', 'crapulous', 'cutthroat'],
    'excessively': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'beyond all bounds', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly', 'damnably'],
    'excessiveness': ['abandon', 'bigotry', 'boundlessness', 'crapulence', 'crapulency', 'crapulousness', 'drunkenness', 'egregiousness', 'enormousness', 'exaggeration', 'excess', 'exorbitance'],
    'exchange': ['american stock exchange', 'amex', 'esp', 'wall street', 'abalienate', 'abalienation', 'agency', 'agent', 'alien', 'alienate', 'alienation', 'altercation'],
    'exchequer': ['fort knox', 'swiss bank account', 'archives', 'armory', 'arsenal', 'assets', 'attic', 'balance', 'bank', 'bank account', 'basement', 'bay'],
    'excise': ['vat', 'abscind', 'ad valorem duty', 'alcohol tax', 'amputate', 'amusement tax', 'annihilate', 'assessment on default', 'avulse', 'ax', 'ban', 'bar'],
    'excision': ['abscission', 'amputation', 'anastomotic operation', 'annihilation', 'avulsion', 'bloodless operation', 'butchering', 'capital operation', 'chopping', 'cleavage', 'compensating operation', 'corneal transplant'],
    'excitable': ['agitable', 'all nerves', 'apprehensive', 'bearish', 'bitchy', 'cankered', 'cantankerous', 'churlish', 'combustible', 'crabbed', 'cranky', 'cross'],
    'excite': ['activate', 'affect the interest', 'agitate', 'anger', 'animate', 'annoy', 'arouse', 'attract', 'awake', 'awaken', 'beat', 'beat up'],
    'excited': ['ablaze', 'active', 'afire', 'aflame', 'agitated', 'agog', 'animated', 'antsy', 'antsy-pantsy', 'anxious', 'aquiver', 'ardent'],
    'excitement': ['action', 'activity', 'ado', 'aggravation', 'agitation', 'anger', 'animation', 'anxiety', 'ardency', 'ardor', 'arousal', 'arousing'],
    'exciting': ['acceptable', 'adorable', 'agitating', 'agreeable', 'alluring', 'amazing', 'appealing', 'appetizing', 'ardent', 'arresting', 'astonishing', 'astounding'],
    'exclaim': ['allude to', 'bark', 'bawl', 'bellow', 'blare', 'blat', 'blubber', 'blurt', 'blurt out', 'bolt', 'boom', 'bray'],
    'exclamation': ['parthian shot', 'address', 'affirmation', 'allegation', 'answer', 'apostrophe', 'assertion', 'averment', 'bellow', 'blurt', 'call', 'comment'],
    'exclude': ['abjure', 'abscind', 'amputate', 'annihilate', 'anticipate', 'avert', 'ban', 'banish', 'bar', 'bar out', 'bate', 'blackball'],
    'excluded': ['absurd', 'banned', 'barred', 'closed-out', 'contemned', 'contrary to reason', 'debarred', 'declined', 'declined with thanks', 'denied', 'deported', 'despised'],
    'excluding': ['aside from', 'bar', 'barring', 'beside', 'besides', 'but', 'discounting', 'ethnocentric', 'ex', 'except', 'except for', 'excepting'],
    'exclusion': ['eighteenth amendment', 'prohibition party', 'volstead act', 'abjuration', 'abjurement', 'abscission', 'amputation', 'annihilation', 'ban', 'banishment', 'bar', 'blackball'],
    'exclusive': ['olympian', 'a certain', 'absolute', 'aloof', 'an', 'any', 'any one', 'apart from', 'aristocratic', 'arrogant', 'article', 'atomic'],
    'exclusive of': ['aside from', 'bar', 'barring', 'beside', 'besides', 'but', 'discounting', 'ex', 'except', 'except for', 'excepting', 'exception taken of'],
    'exclusively': ['alone', 'barely', 'but', 'completely', 'entirely', 'integrally', 'irreducibly', 'just', 'merely', 'only', 'particularly', 'plainly'],
    'exclusiveness': ['jim crow', 'airs', 'alien', 'apartheid', 'arrogance', 'clannishness', 'clanship', 'cliqueyness', 'cliquishness', 'cliquism', 'color bar', 'contempt'],
    'excogitate': ['cogitate', 'contemplate', 'contrive', 'develop', 'educe', 'evolve', 'give thought to', 'invent', 'mind', 'perpend', 'ponder', 'puzzle out'],
    'excommunicate': ['accurse', 'anathematize', 'attaint', 'ban', 'banish', 'blackball', 'blacklist', 'blaspheme', 'blast', 'break', 'bring home to', 'bust'],
    'excoriate': ['abrade', 'assail', 'attack', 'bark', 'blister', 'castigate', 'decorticate', 'flay', 'fret', 'fustigate', 'gall', 'lash'],
    'excrement': ['carrion', 'corruption', 'dandruff', 'decay', 'dejecta', 'dejection', 'dejecture', 'discharge', 'effluent', 'egesta', 'ejecta', 'ejectamenta'],
    'excrete': ['bleed', 'discharge', 'effuse', 'egest', 'eliminate', 'emit', 'exfiltrate', 'extravasate', 'exudate', 'exude', 'filter', 'filtrate'],
    'excretion': ['cleaning out', 'clearance', 'clearing', 'defecation', 'depletion', 'discharging cargo', 'drainage', 'draining', 'effusion', 'egress', 'elimination', 'emptying'],
    'excretory': ['egestive', 'eliminative', 'excretionary', 'excretive', 'exudative', 'lachrymal', 'lachrymose', 'lacrimatory', 'lactational', 'lacteal', 'lacteous', 'leaky'],
    'excruciating': ['acute', 'afflictive', 'agonizing', 'atrocious', 'biting', 'consuming', 'cramping', 'cruel', 'desolating', 'distressful', 'distressing', 'exquisite'],
    'excruciatingly': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly', 'damnably', 'deadly'],
    'exculpate': ['absolve', 'account for', 'acquit', 'amnesty', 'clear', 'condone', 'cry sour grapes', 'decontaminate', 'destigmatize', 'discharge', 'dismiss', 'dispense from'],
    'exculpation': ['absolution', 'acquittal', 'acquittance', 'amnesty', 'clearance', 'clearing', 'compurgation', 'destigmatization', 'destigmatizing', 'discharge', 'disculpation', 'dismissal'],
    'excursion': ['aberrancy', 'aberration', 'airing', 'ambages', 'aside', 'bend', 'bias', 'branching off', 'bypass', 'bypath', 'byway', 'campaign'],
    'excursive': ['o-shaped', 'aberrant', 'aberrative', 'aimless', 'ambagious', 'backhand', 'backhanded', 'by the way', 'circuitous', 'circular', 'deflectional', 'departing'],
    'excusable': ['admissible', 'allowable', 'condonable', 'defensible', 'dispensable', 'exemptible', 'expiable', 'forgivable', 'inoffensive', 'justifiable', 'legitimate', 'pardonable'],
    'excuse': ['abject apology', 'absolution', 'absolve', 'acknowledgment', 'acquit', 'acquittal', 'acquittance', 'alibi', 'alibi out of', 'allow', 'amnesty', 'apologize for'],
    'excused': ['absolved', 'acquitted', 'blotted', 'canceled', 'chartered', 'condoned', 'disregarded', 'excepted', 'exculpated', 'exempt', 'exempted', 'exonerated'],
    'execrable': ['abhorrent', 'abject', 'abominable', 'accursed', 'arrant', 'atrocious', 'bad', 'base', 'beastly', 'beggarly', 'below contempt', 'beneath contempt'],
    'execrate': ['abhor', 'abominate', 'abuse', 'accurse', 'anathematize', 'ban', 'bark at', 'berate', 'betongue', 'blacken', 'blaspheme', 'blast'],
    'execration': ['anglophobia', 'russophobia', 'abhorrence', 'abomination', 'abuse', 'anathema', 'anti-semitism', 'antipathy', 'assailing', 'assault', 'attack', 'aversion'],
    'execute': ['abide by', 'accompany', 'accomplish', 'achieve', 'act', 'adhere to', 'administer', 'administrate', 'annihilate', 'assassinate', 'attain', 'be productive'],
    'executed': ['accomplished', 'achieved', 'attained', 'brought about', 'caused', 'compassed', 'consummated', 'discharged', 'dispatched', 'disposed of', 'done', 'effected'],
    'execution': ['accomplished fact', 'accomplishment', 'accordance', 'achievement', 'acquittal', 'acquittance', 'action', 'adherence', 'administration', 'agency', 'angary', 'annexation'],
    'executive': ['administrating', 'administration', 'administrative', 'administrator', 'archon', 'big cheese', 'board', 'board of directors', 'board of regents', 'board of trustees', 'boss', 'bureaucratic'],
    'executive officer': ['adc', 'co', 'od', 'acolyte', 'adjutant', 'advocate', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider', 'alter ego'],
    'executor': ['actor', 'agent', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner', 'builder', 'conceiver'],
    'exegesis': ['allegorization', 'annotation', 'apparatus criticus', 'clarification', 'comment', 'commentary', 'commentation', 'construction', 'cracking', 'decipherment', 'decoding', 'demonstration'],
    'exemplar': ['geistesgeschichte', 'hegelian idea', 'kantian idea', 'platonic form', 'platonic idea', 'archetype', 'beau ideal', 'case', 'case in point', 'classic', 'complex idea', 'demonstration'],
    'exemplary': ['admirable', 'admonishing', 'admonitory', 'archetypal', 'archetypical', 'beyond all praise', 'blameless', 'cautionary', 'cautioning', 'characteristic', 'classic', 'classical'],
    'exemplification': ['allegorization', 'alphabet', 'art', 'blueprint', 'case', 'case in point', 'charactering', 'characterization', 'chart', 'choreography', 'citation', 'clarification'],
    'exemplify': ['absolve', 'account for', 'adumbrate', 'allegorize', 'body forth', 'call to mind', 'cite', 'cite a particular', 'clarify', 'clear up', 'crack', 'decipher'],
    'exempt': ['absolve', 'acquit', 'amnesty', 'chartered', 'clear', 'decontaminate', 'destigmatize', 'discharge', 'dismiss', 'dispense from', 'dispense with', 'except'],
    'exemption': ['absolution', 'allowance', 'amnesty', 'cession', 'charter', 'circumscription', 'concession', 'diplomatic immunity', 'discharge', 'dispensation', 'exception', 'exclusion'],
    'exercise': ['nachtmusik', 'abrade', 'absolute music', 'absorb', 'absorb the attention', 'act', 'acting', 'action', 'active use', 'activism', 'activity', 'adaptation'],
    'exert': ['apply', 'attempt', 'bring into play', 'bring to bear', 'bust a gut', 'do with', 'employ', 'endeavor', 'exercise', 'expend', 'go all out', 'handle'],
    'exertion': ['action', 'active use', 'activity', 'appliance', 'application', 'assiduity', 'assiduousness', 'consumption', 'determination', 'diligence', 'drive', 'effort'],
    'exfoliate': ['arrange in layers', 'breach', 'break', 'burst', 'bust', 'check', 'chip', 'crack', 'delaminate', 'desquamate', 'fissure', 'flake'],
    'exhalation': ['air', 'breath', 'effluvium', 'emanation', 'emission', 'evaporation', 'exhaust', 'expiration', 'fog', 'fume', 'gas', 'mist'],
    'exhale': ['aerate', 'aerify', 'atomize', 'be aromatic', 'be redolent of', 'blow', 'blow off', 'breathe', 'breathe hard', 'breathe in', 'breathe out', 'carbonate'],
    'exhaust': ['abate', 'ablate', 'absorb', 'assimilate', 'attenuate', 'avenue', 'backwash', 'bankrupt', 'beat', 'blackdamp', 'bleed', 'bleed white'],
    'exhausted': ['ablated', 'acarpous', 'all in', 'arid', 'at an end', 'ausgespielt', 'bare', 'barren', 'beat', 'beat up', 'beaten', 'bleary'],
    'exhausting': ['arduous', 'burdensome', 'crippling', 'debilitating', 'devitalizing', 'difficult', 'draining', 'enervating', 'enfeebling', 'fatiguesome', 'fatiguing', 'grinding'],
    'exhaustion': ['abatement', 'ablation', 'absorption', 'assimilation', 'attenuation', 'attrition', 'blunting', 'breakdown', 'burning up', 'cachexia', 'cachexy', 'chronic ill health'],
    'exhaustive': ['absolute', 'aggregate', 'all', 'all-embracing', 'all-encompassing', 'all-inclusive', 'all-out', 'all-pervading', 'born', 'broad-based', 'clean', 'clear'],
    'exhibit': ['advertise', 'affect', 'air', 'approve', 'argue', 'attest', 'basis for belief', 'benefit', 'bespeak', 'betoken', 'betray', 'bill'],
    'exhibition': ['benefit', 'bill', 'blazon', 'bravura', 'brilliancy', 'cosmorama', 'cyclorama', 'daring', 'dash', 'debut', 'demo', 'demonstration'],
    'exhibitionism': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'baring', 'bisexuality', 'blazon', 'boldness', 'bravura', 'brazenness', 'brilliancy'],
    'exhibitionist': ['bugger', 'coprophiliac', 'erotomaniac', 'fetishist', 'flaunter', 'grandstand player', 'grandstander', 'hot dog', 'masochist', 'narcissist', 'necrophiliac', 'nymphomaniac'],
    'exhilarate': ['amuse', 'animate', 'arouse', 'beguile', 'boost', 'brace', 'brace up', 'brighten', 'brisk', 'brisken', 'buck up', 'buoy'],
    'exhilarated': ['agog', 'animated', 'aquiver', 'aroused', 'atingle', 'atwitter', 'beaming', 'blithe', 'blithesome', 'bright', 'bright and sunny', 'bursting'],
    'exhilarating': ['activating', 'agitating', 'animating', 'animative', 'bracing', 'breathtaking', 'brisk', 'charged', 'cheerful', 'cheering', 'cheery', 'cliff-hanging'],
    'exhilaration': ['a high', 'afflatus', 'aggravation', 'agitation', 'animating spirit', 'animation', 'animus', 'arousal', 'arousing', 'beatification', 'beatitude', 'bewitchment'],
    'exhort': ['admonish', 'advocate', 'blandish', 'cajole', 'call on', 'call upon', 'caution', 'charge', 'coax', 'egg on', 'encourage', 'enjoin'],
    'exhortation': ['address', 'admonition', 'advice', 'advising', 'advocacy', 'after-dinner speech', 'allocution', 'allurement', 'blandishment', 'briefing', 'bugle call', 'cajolement'],
    'exigency': ['case of need', 'climacteric', 'clutch', 'compulsion', 'constraint', 'contingency', 'convergence of events', 'crisis', 'critical juncture', 'critical point', 'crossroads', 'crucial period'],
    'exigent': ['spartan', 'spartanic', 'accurate', 'acute', 'astringent', 'attentive', 'austere', 'authoritarian', 'burdensome', 'burning', 'charged', 'choiceless'],
    'exiguity': ['lenten fare', 'airiness', 'airy texture', 'attenuation', 'austerity', 'chinchiness', 'chintziness', 'daintiness', 'delicacy', 'diaphanousness', 'dilutedness', 'dilution'],
    'exiguous': ['lenten', 'spartan', 'abstemious', 'ascetic', 'austere', 'cheeseparing', 'chinchy', 'chintzy', 'cramped', 'dinky', 'dwarfed', 'dwarfish'],
    'exile': ['dp', 'ishmael', 'uitlander', 'abstract', 'alien', 'alienate', 'ban', 'banish', 'banishment', 'bar', 'barbarian', 'blackball'],
    'exiled': ['banned', 'barred', 'debarred', 'deported', 'ejected', 'excluded', 'expelled', 'homeless', 'houseless', 'left out', 'liquidated', 'not in it'],
    'exist': ['be', 'abide', 'abide in', 'be', 'be alive', 'be animate', 'be coextensive with', 'be comprised in', 'be constituted by', 'be contained in', 'be extant', 'be found'],
    'existence': ['accessibility', 'actual presence', 'actuality', 'an existence', 'animal spirits', 'animate existence', 'animation', 'availability', 'being', 'being alive', 'being here', 'being there'],
    'existent': ['aboveground', 'actual', 'alive', 'alive and kicking', 'among the living', 'animate', 'animated', 'around', 'as is', 'being', 'breathing', 'capable of life'],
    'existential': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'animist', 'animistic', 'atomistic', 'cosmotheistic', 'eclectic', 'empirical', 'eudaemonistic'],
    'existing': ['actual', 'alive', 'around', 'as is', 'being', 'contemporaneous', 'contemporary', 'current', 'existent', 'extant', 'fresh', 'immanent'],
    'exit': ['awol', 'french leave', 'abandonment', 'absence without leave', 'absquatulation', 'access', 'adit', 'aisle', 'alley', 'ambulatory', 'annihilation', 'aperture'],
    'exodus': ['abandonment', 'act', 'afterpiece', 'bit', 'chaser', 'curtain', 'curtain call', 'curtain raiser', 'decampment', 'departure', 'divertimento', 'divertissement'],
    'exonerate': ['absolve', 'acquit', 'amnesty', 'clear', 'decontaminate', 'destigmatize', 'disburden', 'discharge', 'dismiss', 'dispense from', 'exculpate', 'excuse'],
    'exoneration': ['absolution', 'acquittal', 'acquittance', 'amnesty', 'clearance', 'clearing', 'compurgation', 'destigmatization', 'destigmatizing', 'discharge', 'disculpation', 'dismissal'],
    'exorbitance': ['abandon', 'aggrandizement', 'amplification', 'ballyhoo', 'big talk', 'blowing up', 'boundlessness', 'burlesque', 'caricature', 'dilatation', 'dilation', 'egregiousness'],
    'exorbitant': ['a bit much', 'abandoned', 'acute', 'aggrandized', 'amplified', 'ballyhooed', 'boundless', 'clamant', 'clamorous', 'crying', 'cutthroat', 'cutting'],
    'exorcism': ['cantrip', 'charm', 'conjuration', 'conjurement', 'curse', 'evil eye', 'evocation', 'exorcisation', 'exsufflation', 'glamour', 'hex', 'incantation'],
    'exorcist': ['acolyte', 'acolytus', 'deacon', 'diaconus', 'doorkeeper', 'exorciser', 'exorcista', 'holy orders', 'lector', 'major orders', 'medicine man', 'minor orders'],
    'exotic': ['alien', 'alluring', 'apart', 'appealing', 'appetizing', 'asunder', 'at a distance', 'attractive', 'away', 'barbarian', 'barbaric', 'barbarous'],
    'expand': ['add to', 'adulterate', 'aggrandize', 'amplify', 'attenuate', 'augment', 'balloon', 'beef up', 'bloat', 'blow up', 'bolster', 'boost'],
    'expanded': ['accelerated', 'aggrandized', 'ampliate', 'amplified', 'augmented', 'beefed-up', 'bloated', 'boosted', 'broadened', 'built-up', 'crescendoed', 'deepened'],
    'expanding': ['amplifying', 'crescendoing', 'crescent', 'developmental', 'dilatative', 'dilative', 'enlarging', 'expatiating', 'growing', 'increasing', 'incremental', 'intensifying'],
    'expanse': ['acreage', 'ampleness', 'amplitude', 'area', 'beam', 'bigness', 'body', 'boundlessness', 'breadth', 'broadness', 'bulk', 'caliber'],
    'expansion': ['access', 'accession', 'accomplishment', 'accretion', 'accrual', 'accruement', 'accumulation', 'acreage', 'addition', 'advance', 'advancement', 'aggrandizement'],
    'expansive': ['accessible', 'affable', 'airy', 'all jaw', 'all-embracing', 'all-inclusive', 'amiable', 'ample', 'amplitudinous', 'approachable', 'big', 'bouncy'],
    'expatiate': ['amplify', 'descant', 'detail', 'develop', 'dilate', 'discuss', 'dissert', 'dissertate', 'elaborate', 'enlarge', 'enlarge upon', 'evolve'],
    'expatriate': ['dp', 'ishmael', 'abstract', 'ban', 'banish', 'blackball', 'cast off', 'cast out', 'castaway', 'chuck', 'clear', 'clear away'],
    'expect': ['account as', 'anticipate', 'apprehend', 'approach', 'aspire to', 'assume', 'await', 'bank on', 'be afraid', 'be destined', 'be fated', 'be imminent'],
    'expectant': ['agape', 'agog', 'alert', 'all agog', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'anxious', 'apprehensive', 'aspiring', 'assured'],
    'expectation': ['aftertime', 'afteryears', 'anticipation', 'apprehension', 'apprehensiveness', 'aptitude', 'aspiration', 'assumption', 'assurance', 'assured faith', 'awelessness', 'belief'],
    'expected': ['anticipated', 'awaited', 'aweless', 'calm', 'composed', 'cool', 'due', 'expecting', 'foreseen', 'hoped-for', 'imminent', 'in prospect'],
    'expecting': ['agape', 'agog', 'all agog', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'atiptoe', 'awaiting', 'aweless', 'big', 'big with child'],
    'expedience': ['advantageousness', 'agreeableness', 'appropriateness', 'auspiciousness', 'beneficialness', 'benevolence', 'benignity', 'chargedness', 'class', 'cogency', 'convenience', 'criticality'],
    'expediency': ['appositeness', 'appropriateness', 'aptness', 'careworn', 'convenience', 'dernier ressort', 'design', 'expedient', 'fitness', 'makeshift', 'measure', 'meetness'],
    'expedient': ['action', 'ad hoc measure', 'advantageous', 'advisable', 'agency', 'answer', 'applicable', 'appropriate', 'apropos', 'art', 'artful dodge', 'artifice'],
    'expedite': ['accelerate', 'advance', 'advantage', 'aid', 'air-express', 'airfreight', 'airmail', 'boost', 'bundle', 'bustle', 'clear the way', 'conduce to'],
    'expedition': ['advance', 'advancement', 'adventure', 'agility', 'air speed', 'alacrity', 'briskness', 'campaign', 'celerity', 'circuit', 'clarification', 'course'],
    'expeditious': ['agile', 'alacritous', 'alert', 'apt', 'breakneck', 'brisk', 'cursory', 'dashing', 'decisive', 'diligent', 'dispatchful', 'double-quick'],
    'expeditiously': ['pdq', 'agilely', 'amain', 'apace', 'at flank speed', 'at once', 'by forced marches', 'cursorily', 'decisively', 'directly', 'double-quick', 'effectively'],
    'expel': ['abrupt', 'abstract', 'alienate', 'assign', 'ban', 'banish', 'bar', 'belch', 'blackball', 'blow', 'blow off', 'blow out'],
    'expend': ['ablate', 'absorb', 'assimilate', 'bestow', 'bleed white', 'blow', 'budget', 'burn up', 'consecrate to', 'consume', 'cost', 'cost out'],
    'expendable': ['consumable', 'de trop', 'dispensable', 'disposable', 'excess', 'expletive', 'gratuitous', 'in excess', 'inessential', 'insignificant', 'needless', 'no-deposit'],
    'expended': ['ablated', 'acquitted', 'by the board', 'consumed', 'depleted', 'discharged', 'dissipated', 'eroded', 'forfeit', 'forfeited', 'gone', 'hired'],
    'expenditure': ['ablation', 'absorption', 'accounts', 'accounts payable', 'accounts receivable', 'amount', 'assets', 'assimilation', 'attrition', 'budget', 'budgeting', 'burning up'],
    'expense': ['amount', 'bereavement', 'budget', 'budget items', 'burden of expenditure', 'carrying charge', 'charge', 'charges', 'cost', 'cost of living', 'cost-of-living allowance', 'cost-of-living index'],
    'expensive': ['cheap', 'costly', 'dear', 'dear-bought', 'extravagant', 'fancy', 'high', 'high-priced', 'immoderate', 'luxurious', 'not affordable', 'of great cost'],
    'experience': ['accept', 'acquaintance', 'adventure', 'affair', 'affect', 'affection', 'apprehend', 'awareness', 'background', 'be aware of', 'be conscious of', 'be exposed to'],
    'experienced': ['acclimated', 'acclimatized', 'accommodated', 'accomplished', 'accustomed', 'adapted', 'adept', 'adjusted', 'au fait', 'blase', 'capable', 'case-hardened'],
    'experiment': ['analysis', 'analyze', 'approach', 'assay', 'attempt', 'bid', 'bring to test', 'confirm', 'crack', 'cut and try', 'effort', 'endeavor'],
    'experimental': ['conjectural', 'cut-and-try', 'determined', 'developmental', 'empirical', 'experiential', 'exploratory', 'heuristic', 'hit-or-miss', 'hypothetical', 'pilot', 'preliminary'],
    'experimentation': ['r and d', 'control', 'control experiment', 'controlled experiment', 'cut and try', 'empiricism', 'experiment', 'experimental design', 'experimental method', 'experimental proof', 'experimentalism', 'hit and miss'],
    'expert': ['admirable crichton', 'daedalian', 'dutch uncle', 'polonius', 'accomplished', 'ace', 'acquainted with', 'adept', 'adept in', 'admonisher', 'adroit', 'adviser'],
    'expertise': ['ability', 'acquaintance', 'address', 'adeptness', 'adroitness', 'aesthetics', 'airmanship', 'all-knowingness', 'art', 'artfulness', 'artisanship', 'artistic taste'],
    'expertly': ['ably', 'adeptly', 'adroitly', 'agilely', 'aptly', 'artfully', 'artistically', 'brilliantly', 'capably', 'cleverly', 'competently', 'cunningly'],
    'expiate': ['amend', 'atone', 'atone for', 'compensate', 'compensate for', 'correct', 'cover', 'do penance', 'fill up', 'give and take', 'give satisfaction', 'indemnify'],
    'expiation': ['amends', 'atonement', 'balancing', 'commutation', 'compensation', 'composition', 'compromise', 'counteraction', 'counterbalancing', 'expiatory offering', 'indemnification', 'indemnity'],
    'expiration': ['aqua-lung', 'annihilation', 'apodosis', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'bane', 'biological death', 'breath', 'breath of air', 'breathing', 'broken wind'],
    'expire': ['advance', 'be all over', 'be annihilated', 'be destroyed', 'be done for', 'be lost', 'be no more', 'be wiped out', 'become extinct', 'become void', 'blow', 'blow over'],
    'expired': ['ago', 'all gone', 'annihilated', 'antiquated', 'antique', 'blown over', 'by', 'bygone', 'bypast', 'dated', 'dead', 'dead and buried'],
    'explain': ['absolve', 'account', 'account for', 'acquit', 'aid', 'allegorize', 'analyze', 'answer', 'bottom', 'break down', 'clarify', 'clear'],
    'explanation': ['abstraction', 'accomplishment', 'account', 'allegorization', 'analysis', 'answer', 'ascertainment', 'body of theory', 'case', 'case in point', 'cause', 'clarification'],
    'explanatory': ['allegorizing', 'annotative', 'clarifying', 'critical', 'demonstrative', 'demythologizing', 'descriptive', 'discursive', 'editorial', 'elucidative', 'enlightening', 'euhemeristic'],
    'expletive': ['battology', 'bedizenment', 'blurt', 'curse', 'cuss', 'cuss word', 'de trop', 'dirty name', 'dirty word', 'dispensable', 'duplication', 'duplication of effort'],
    'explicable': ['englishable', 'accountable', 'alleged', 'answerable', 'ascertainable', 'ascribable', 'assignable', 'attributable', 'attributed', 'capable of solution', 'charged', 'construable'],
    'explicate': ['account for', 'allegorize', 'amplify', 'clarify', 'clear up', 'construe', 'crack', 'decipher', 'demonstrate', 'demythologize', 'descant', 'detail'],
    'explicit': ['absolute', 'accurate', 'admitting no exception', 'all-out', 'apparent', 'artless', 'bluff', 'blunt', 'broad', 'brusque', 'candid', 'categorical'],
    'explode': ['backfire', 'bang', 'bark', 'be angry', 'be excitable', 'belie', 'bellow', 'blast', 'blow a fuse', 'blow a gasket', 'blow out', 'blow sky-high'],
    'exploded': ['belied', 'confounded', 'confuted', 'contested', 'deflated', 'denied', 'disbelieved', 'discarded', 'discredited', 'dismissed', 'disproved', 'disputed'],
    'exploit': ['abuse', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adventure', 'apply', 'aristeia', 'attainment', 'beguile'],
    'exploitable': ['appliable', 'applicable', 'compliant', 'cullible', 'deceivable', 'deludable', 'dupable', 'easy', 'foolable', 'green', 'gullible', 'hoaxable'],
    'exploration': ['adventure', 'analysis', 'domiciliary visit', 'dragnet', 'emprise', 'enquiry', 'examination', 'expedition', 'forage', 'frisk', 'house-search', 'hunt'],
    'exploratory': ['advanced', 'analytic', 'avant-garde', 'examinational', 'examinatorial', 'examining', 'explorational', 'explorative', 'fact-finding', 'feeling', 'groping', 'heuristic'],
    'explore': ['beat the bushes', 'burrow', 'delve', 'delve into', 'dig', 'dig into', 'examine', 'fathom', 'forage', 'frisk', 'go into', 'go through'],
    'explorer': ['adventurer', 'alpinist', 'ancestor', 'announcer', 'antecedent', 'astronaut', 'avant-garde', 'bellwether', 'buccinator', 'bushwhacker', 'camper', 'climber'],
    'explosion': ['accelerando', 'acceleration', 'access', 'aggravation', 'backfire', 'bang', 'bark', 'beefing-up', 'blast', 'blaze', 'blaze of temper', 'blowing up'],
    'explosive': ['ballistite', 'tnt', 'agitable', 'alarming', 'allophone', 'alveolar', 'anxious', 'apico-alveolar', 'apico-dental', 'articulation', 'aspiration', 'assimilation'],
    'exponent': ['maecenas', 'abettor', 'admirer', 'advocate', 'aficionado', 'allegorist', 'alter ego', 'alternate', 'amicus curiae', 'angel', 'annotator', 'apologist'],
    'exponential': ['algorismic', 'algorithmic', 'aliquot', 'cardinal', 'decimal', 'differential', 'digital', 'even', 'figural', 'figurate', 'figurative', 'finite'],
    'export': ['air-express', 'airfreight', 'airmail', 'assign', 'carry over', 'communicate', 'communication', 'conduction', 'consign', 'contagion', 'convection', 'deliver'],
    'expose': ['advertise', 'air', 'apocalypse', 'attaint', 'awaken', 'bare', 'baring', 'belie', 'bespatter', 'betray', 'blacken', 'blot'],
    'exposed': ['aerial', 'aeriform', 'aery', 'airish', 'airlike', 'airy', 'alfresco', 'answerable for', 'apparent', 'apt to', 'atmospheric', 'bald'],
    'exposition': ['allegorization', 'anacrusis', 'apocalypse', 'article', 'assignment', 'auto show', 'baring', 'bass passage', 'bazaar', 'boat show', 'bourdon', 'bridge'],
    'expositive': ['allegorizing', 'annotative', 'clarifying', 'commentative', 'commentatorial', 'critical', 'delineative', 'demonstrative', 'demythologizing', 'depictive', 'descriptive', 'discoursive'],
    'expositor': ['boanerges', 'allegorist', 'annotator', 'author', 'book reviewer', 'chalk talker', 'cicerone', 'clarifier', 'commentator', 'commenter', 'critic', 'cryptanalyst'],
    'expostulate': ['admonish', 'argue', 'beef', 'bitch', 'boggle', 'boycott', 'call in question', 'caution', 'challenge', 'charge', 'combat', 'complain'],
    'exposure': ['asa exposure index', 'din number', 'pr', 'acquaintance', 'airing', 'apocalypse', 'apparition', 'appearance', 'appearing', 'arising', 'aspect', 'attitude'],
    'expound': ['account for', 'allegorize', 'clarify', 'clear up', 'comment', 'construe', 'crack', 'decipher', 'delineate', 'demonstrate', 'demythologize', 'describe'],
    'express': ['amtrak', 'aquarius', 'ganymede', 'hebe', 'hermes', 'iris', 'mercury', 'pp', 'paul revere', 'pheidippides', 'rd', 'rfd'],
    'expression': ['christophany', 'parthian shot', 'satanophany', 'accent', 'adage', 'address', 'adjectival phrase', 'affirmation', 'air', 'airing', 'allegation', 'ana'],
    'expressionism': ['abstractionism', 'coloring', 'deformation', 'distortion', 'exaggeration', 'false coloring', 'falsification', 'garbling', 'hyperbole', 'inaccuracy', 'injustice', 'litotes'],
    'expressionless': ['olympian', 'aloof', 'backward', 'bashful', 'blank', 'chilled', 'chilly', 'cold', 'constrained', 'cool', 'dead', 'deadpan'],
    'expressive': ['christophanic', 'satanophanic', 'alive', 'allegorical', 'allusive', 'angelophanic', 'appearing', 'associational', 'connotational', 'connotative', 'definable', 'delineative'],
    'expressly': ['absolutely', 'apparently', 'apprehensibly', 'articulately', 'as well', 'categorically', 'clearly', 'coherently', 'comprehensibly', 'concretely', 'dead', 'definitely'],
    'expressway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'expropriate': ['accroach', 'annex', 'arrogate', 'attach', 'collectivize', 'commandeer', 'communalize', 'communize', 'confiscate', 'cut off', 'disendow', 'disherison'],
    'expulsion': ['banishment', 'blowout', 'booting out', 'cashiering', 'clearance', 'communication', 'conduction', 'contagion', 'convection', 'deconsecration', 'defenestration', 'defrocking'],
    'expunge': ['ko', 'abbreviate', 'abridge', 'annihilate', 'annul', 'black out', 'blot', 'blot out', 'blue-pencil', 'bowdlerize', 'call off', 'cancel'],
    'expunged': ['sol', 'all bets off', 'all off', 'all over', 'all up', 'at an end', 'canceled', 'complete', 'concluded', 'dead', 'decided', 'defunct'],
    'expurgate': ['abbreviate', 'abridge', 'bleach', 'blot out', 'blue-pencil', 'bowdlerize', 'cancel', 'censor', 'clean', 'clean out', 'clean up', 'cleanse'],
    'exquisite': ['beau brummel', 'accurate', 'acute', 'aesthetic', 'aesthetically appealing', 'agreeable', 'ambrosial', 'appealing', 'attentive', 'attractive', 'beauteous', 'beautiful'],
    'exquisitely': ['abundantly', 'accurately', 'acutely', 'amazingly', 'amply', 'appealingly', 'astonishingly', 'attractively', 'awesomely', 'beauteously', 'beautifully', 'becomingly'],
    'extant': ['actual', 'alive', 'around', 'as is', 'being', 'contemporaneous', 'contemporary', 'current', 'existent', 'existing', 'fresh', 'immanent'],
    'extemporaneous': ['ad lib', 'ad libitum', 'ad-lib', 'casual', 'caught napping', 'caught off balance', 'caught short', 'extemporary', 'extempore', 'extemporized', 'haphazard', 'hasty'],
    'extemporize': ['ad-lib', 'be caught napping', 'be surprised', 'be taken unawares', 'be unprepared', 'cook up', 'dash off', 'do offhand', 'fake', 'go off half-cocked', 'have no plan', 'improvisate'],
    'extend': ['abide', 'accord', 'add to', 'adjourn', 'administer', 'advance', 'afford', 'aggrandize', 'allocate', 'allot', 'allow', 'amplify'],
    'extended': ['accelerated', 'aggrandized', 'allegorical', 'ample', 'ampliate', 'amplified', 'amplitudinous', 'associational', 'augmented', 'beefed-up', 'bloated', 'boosted'],
    'extension': ['access', 'accession', 'accessory', 'accompaniment', 'accretion', 'accrual', 'accruement', 'accumulation', 'acreage', 'addenda', 'addendum', 'additament'],
    'extensive': ['gargantuan', 'a mile long', 'all-embracing', 'ample', 'amplitudinous', 'astronomical', 'awesome', 'big', 'boundless', 'broad', 'bulky', 'capacious'],
    'extent': ['acreage', 'aesthetic distance', 'ambit', 'amount', 'amplitude', 'area', 'beam', 'bigness', 'body', 'bounds', 'breadth', 'broadness'],
    'extenuate': ['abate', 'allay', 'alleviate', 'allow for', 'apologize', 'assuage', 'attemper', 'attenuate', 'bank the fire', 'bate', 'blunt', 'chasten'],
    'extenuating': ['altering', 'apologetic', 'assuasive', 'bounding', 'diminishing', 'excusatory', 'excusing', 'extenuative', 'extenuatory', 'justificatory', 'justifying', 'lenitive'],
    'exterior': ['airscape', 'alien', 'apparent', 'apparent character', 'appearances', 'border', 'circumference', 'cityscape', 'cloudscape', 'coating', 'cortex', 'cortical'],
    'exteriority': ['cursoriness', 'epidermis', 'gloss', 'mere scratch', 'no depth', 'no water', 'pinprick', 'rind', 'scratch', 'shallowness', 'shoaliness', 'skin'],
    'exterminate': ['abate', 'abolish', 'annihilate', 'bereave of life', 'blot out', 'bump off', 'butcher', 'carry away', 'carry off', 'cast off', 'chloroform', 'cut down'],
    'extermination': ['abolishment', 'abolition', 'annihilation', 'annulment', 'bane', 'blood', 'bloodletting', 'bloodshed', 'braining', 'choking', 'choking off', 'dealing death'],
    'exterminator': ['cain', 'annihilator', 'apache', 'arsonist', 'assassin', 'assassinator', 'biblioclast', 'bloodletter', 'bloodshedder', 'bomber', 'bravo', 'burker'],
    'external': ['alien', 'apparent', 'border', 'circumference', 'cortex', 'cortical', 'covering', 'crust', 'envelope', 'epidermic', 'epidermis', 'exomorphic'],
    'externals': ['apparent character', 'appearances', 'display', 'exteriors', 'external appearance', 'facade', 'front', 'gaudiness', 'mere externals', 'meretriciousness', 'ostent', 'outward appearance'],
    'exterrestrial': ['alien', 'exterritorial', 'extragalactic', 'extralateral', 'extraliminal', 'extramundane', 'extramural', 'extrapolar', 'extraprovincial', 'extrasolar', 'extraterrene', 'extraterrestrial'],
    'extinct': ['sol', 'ago', 'all bets off', 'all gone', 'all off', 'all over', 'all up', 'ancient', 'annihilated', 'antediluvian', 'antiquated', 'antique'],
    'extinction': ['abolishment', 'abolition', 'abscission', 'amputation', 'annihilation', 'annulment', 'bane', 'biological death', 'blackout', 'blocking', 'burning out', 'burnout'],
    'extinguish': ['ko', 'abate', 'abolish', 'abscind', 'adumbrate', 'amputate', 'annihilate', 'asphyxiate', 'ban', 'banish', 'bar', 'blot out'],
    'extinguisher': ['foamite', 'acid', 'automatic sprinkler', 'carbon tet', 'carbon tetrachloride', 'carbon-dioxide foam', 'deck gun', 'deluge set', 'fire apparatus', 'fire engine', 'fire hose', 'fire hydrant'],
    'extirpate': ['abate', 'abolish', 'abscind', 'amputate', 'annihilate', 'ban', 'bar', 'blot', 'bob', 'clip', 'crop', 'cull'],
    'extol': ['acclaim', 'adulate', 'apotheosize', 'applaud', 'belaud', 'bepraise', 'bless', 'bless the lord', 'blow up', 'boast of', 'brag about', 'celebrate'],
    'extort': ['abstract', 'and', 'annex', 'appropriate', 'ask', 'ask for', 'badger', 'bag', 'blackmail', 'bleed', 'boost', 'borrow'],
    'extortion': ['armed robbery', 'asportation', 'assault and robbery', 'badger game', 'banditry', 'bank robbery', 'blackmail', 'bloodsucking', 'call', 'call for', 'cattle lifting', 'cattle stealing'],
    'extortionate': ['all-devouring', 'all-engulfing', 'arousing', 'bloodsucking', 'clamant', 'clamorous', 'crying', 'cutthroat', 'demanding', 'draining', 'educible', 'eductive'],
    'extra': ['above', 'accessory', 'accident', 'accidental', 'added', 'addendum', 'addition', 'additional', 'additionally', 'adjunct', 'adscititious', 'adventitious'],
    'extract': ['abate', 'abrade', 'abridge', 'abstract', 'ambergris', 'ambrosia', 'aromatic', 'aromatic gum', 'aromatic water', 'artifact', 'attar', 'attar of roses'],
    'extraction': ['affiliation', 'ancestry', 'apparentation', 'architecture', 'assembly', 'attraction', 'attrition', 'birth', 'blood', 'bloodline', 'bolting', 'branch'],
    'extradite': ['assign', 'ban', 'banish', 'blackball', 'bring back', 'carry over', 'cast out', 'communicate', 'consign', 'cut', 'deliver', 'deport'],
    'extradition': ['banishment', 'blackballing', 'communication', 'conduction', 'contagion', 'convection', 'defrocking', 'degradation', 'delivery', 'demotion', 'depluming', 'deportation'],
    'extramundane': ['elysian', 'olympian', 'airy', 'alien', 'arcane', 'asomatous', 'astral', 'beatific', 'beatified', 'blessed', 'bodiless', 'celestial'],
    'extramural': ['academic', 'alien', 'classroom', 'collegiate', 'exterrestrial', 'exterritorial', 'extragalactic', 'extralateral', 'extraliminal', 'extramundane', 'extrapolar', 'extraprovincial'],
    'extraneous': ['accidental', 'added', 'additional', 'adrift', 'adventitious', 'alien', 'apart', 'barbarian', 'barbaric', 'barbarous', 'beside the mark', 'beside the point'],
    'extraordinarily': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'beguilingly', 'bewilderingly', 'conspicuously', 'copiously', 'eminently', 'emphatically'],
    'extraordinary': ['abnormal', 'absolute', 'amazing', 'appalling', 'astonishing', 'astounding', 'beguiling', 'bewildering', 'bizarre', 'celebrated', 'certain', 'concrete'],
    'extrapolated': ['approaching', 'coming', 'desired', 'destinal', 'destined', 'determined', 'emergent', 'eventual', 'fatal', 'fated', 'fatidic', 'forthcoming'],
    'extrapolation': ['accession', 'accessory', 'accompaniment', 'actualization', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct'],
    'extraterrestrial': ['elysian', 'olympian', 'alien', 'arcane', 'barbarian', 'barbaric', 'barbarous', 'beatific', 'beatified', 'blessed', 'celestial', 'eerie'],
    'extravagance': ['abandon', 'absurdity', 'abundance', 'affluence', 'aggrandizement', 'amenity', 'ample sufficiency', 'ampleness', 'amplification', 'amplitude', 'avalanche', 'ballyhoo'],
    'extravagant': ['babylonian', 'corinthian', 'gothic', 'a bit much', 'abandoned', 'abounding', 'absurd', 'abundant', 'acute', 'affluent', 'aggrandized', 'all-sufficing'],
    'extravagantly': ['abominably', 'abundantly', 'affluently', 'agonizingly', 'aplenty', 'awfully', 'baldly', 'balefully', 'beyond measure', 'bitterly', 'blatantly', 'bottomlessly'],
    'extravaganza': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'blatancy', 'bomb', 'brazenness', 'broadcast drama', 'burlesque show', 'canard'],
    'extreme': ['draconian', 'thule', 'ultima thule', 'a bit much', 'abandon', 'abandoned', 'abnormal', 'acme', 'acute', 'aggrandized', 'aggrandizement', 'all'],
    'extreme unction': ['baptism', 'burial service', 'chrism', 'chrismal', 'chrismation', 'chrismatory', 'chrisom', 'confirmation', 'deathwatch', 'dirge', 'eulogy', 'exequies'],
    'extremely': ['a bit', 'a little', 'a outrance', 'absolutely', 'all out', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure', 'bloody', 'completely', 'damned'],
    'extremism': ['fabianism', 'jacobinism', 'new left', 'old left', 'abandon', 'anarchism', 'anarcho-syndicalism', 'bigotry', 'boundlessness', 'conversion', 'criminal syndicalism', 'egregiousness'],
    'extremist': ['bolshevik', 'fabian', 'jacobin', 'wobbly', 'agitator', 'anarchist', 'anarchistic', 'anarcho-syndicalist', 'bigoted', 'brawler', 'extravagant', 'extreme'],
    'extremity': ['thule', 'ultima thule', 'abandon', 'abstract', 'aching heart', 'acme', 'acuteness', 'agony', 'agony of mind', 'all', 'anguish', 'animality'],
    'extricate': ['avulse', 'break loose', 'break out', 'clear', 'cut loose', 'cut out', 'deliver', 'deracinate', 'dig out', 'dig up', 'disburden', 'disembarrass'],
    'extrication': ['avulsion', 'break', 'breaking out', 'breakout', 'clearing', 'cutting out', 'deliverance', 'delivery', 'deracination', 'disburdening', 'disembarrassment', 'disembroilment'],
    'extrinsic': ['acquired', 'adrift', 'alien', 'apparent', 'barbarian', 'barbaric', 'barbarous', 'beside the mark', 'beside the point', 'beside the question', 'conventionalized', 'cortical'],
    'extrinsicality': ['alienage', 'alienism', 'appearance', 'buckram', 'ceremonial', 'ceremoniousness', 'ceremony', 'dignity', 'exteriority', 'externality', 'externalness', 'extraneousness'],
    'extroversion': ['accessibility', 'ambiversion', 'approachability', 'candor', 'communicativeness', 'complexion', 'conversableness', 'cycloid personality', 'cyclothymia', 'ectomorphism', 'ectomorphy', 'endomorphism'],
    'extroverted': ['accessible', 'approachable', 'candid', 'communicative', 'conversable', 'demonstrative', 'effusive', 'expansive', 'extroversive', 'extrovert', 'frank', 'free'],
    'extrude': ['arise', 'assemble', 'bail out', 'boot out', 'bounce', 'break cover', 'break forth', 'bristle up', 'build', 'burst forth', 'cast', 'cast out'],
    'extrusion': ['bas-relief', 'bellying', 'boldness', 'booting out', 'bulging', 'defenestration', 'detrusion', 'discharge', 'effusion', 'egestion', 'ejaculation', 'ejection'],
    'exuberance': ['abandon', 'abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'animal spirits', 'animation', 'ardor', 'avalanche', 'beatification', 'beatitude'],
    'exuberant': ['ablaze', 'abounding', 'abundant', 'affluent', 'afire', 'all-sufficing', 'ample', 'animated', 'antic', 'aplenty', 'ardent', 'balmy'],
    'exude': ['bleed', 'discharge', 'drip', 'effuse', 'egest', 'eliminate', 'emanate', 'emit', 'excrete', 'exfiltrate', 'extravasate', 'exudate'],
    'exult': ['be proud of', 'boast', 'brag', 'caper', 'caracole', 'carol', 'celebrate', 'chirp', 'chirrup', 'clap hands', 'crow', 'crow over'],
    'exultant': ['bursting with happiness', 'carried away', 'cock-a-hoop', 'crowing', 'delighted', 'delighting', 'ecstatic', 'elate', 'elated', 'enchanted', 'enraptured', 'enravished'],
    'exurb': ['stadt', 'banlieue', 'boom town', 'borough', 'bourg', 'burg', 'burgh', 'city', 'conurbation', 'exurbia', 'faubourg', 'ghost town'],
    'eye': ['anschauung', 'sherlock', 'sherlock holmes', 'accountability', 'air hole', 'amaurosis', 'angle', 'angle of vision', 'annulet', 'armhole', 'assumption', 'attend'],
    'eye opener': ['mickey', 'mickey finn', 'aperitif', 'astonishment', 'blockbuster', 'blow', 'bomb', 'bombshell', 'catch', 'chaser', 'cocktail', 'doch-an-dorrach'],
    'eye opening': ['amazing', 'apocalyptic', 'astonishing', 'astounding', 'betraying', 'breathtaking', 'confounding', 'disclosing', 'disclosive', 'exposing', 'mind-boggling', 'overwhelming'],
    'eyeball': ['baby blues', 'banjo eyes', 'be vigilant', 'be watchful', 'bright eyes', 'clear eyes', 'cornea', 'eye', 'eyelid', 'follow', 'gaze at', 'goggle eyes'],
    'eyeball to eyeball': ['adversative', 'adverse', 'adversive', 'against the grain', 'against the tide', 'against the wind', 'antagonistic', 'anti', 'antipathetic', 'antipodal', 'antithetic', 'antonymous'],
    'eyeful': ['beaut', 'dekko', 'eye', 'knockout', 'leer', 'leering look', 'look', 'look-in', 'looker', 'lovely', 'lustful leer', 'picture'],
    'eyeglass': ['polaroid glasses', 'achromatic lens', 'astigmatic lens', 'bifocals', 'blinkers', 'burning glass', 'camera', 'cheaters', 'coated lens', 'colored glasses', 'concave lens', 'concavo-convex lens'],
    'eyelet': ['air hole', 'annulet', 'armhole', 'blowhole', 'bullet-hole', 'bunghole', 'circlet', 'cringle', 'deadeye', 'eye', 'gasket', 'grommet'],
    'eyesight': ['clear sight', 'color vision', 'command', 'cone vision', 'day vision', 'daylight vision', 'discernment', 'domination', 'eye', 'eye-mindedness', 'eyereach', 'eyeshot'],
    'eyesore': ['baboon', 'bag', 'blemish', 'bloodstain', 'blot', 'blotch', 'blur', 'brand', 'dab', 'daub', 'dog', 'fleck'],
    'eyestrain': ['brain fag', 'debilitation', 'debility', 'enervation', 'enfeeblement', 'faintness', 'fatigue', 'goneness', 'heart strain', 'jadedness', 'languor', 'lassitude'],
    'eyewash': ['adulation', 'balls', 'balm', 'baloney', 'balsam', 'bilge', 'blague', 'blandishment', 'blarney', 'bosh', 'brilliantine', 'bull'],
    'eyewitness': ['tv-viewer', 'absolute', 'adducible', 'admissible', 'attestant', 'attestative', 'attestator', 'attester', 'attestive', 'authentic', 'based on', 'beholder'],
    'fab': ['ok', 'ace-high', 'bad', 'bang-up', 'bonzer', 'boss', 'bully', 'but good', 'cool', 'corking', 'crackerjack', 'dandy'],
    'fabian': ['fabian socialist', 'fourierist', 'fourieristic', 'marxist', 'owenite', 'saint-simonian', 'collectivist', 'collectivistic', 'corrective', 'emendatory', 'extremist', 'gradualistic'],
    'fable': ['marchen', 'western', 'western story', 'westerner', 'action', 'adventure story', 'allegory', 'anagnorisis', 'angle', 'apologue', 'architectonics', 'architecture'],
    'fabled': ['acclaimed', 'celebrated', 'distinguished', 'famed', 'famous', 'far-famed', 'far-heard', 'honored', 'legendary', 'marked', 'much acclaimed', 'mythical'],
    'fabric': ['aralac', 'avisco', 'axminster', 'celanese', 'dacron', 'dymaxion house', 'dynel', 'georgette', 'harris tweed', 'lastex', 'leatherette', 'orlon'],
    'fabricate': ['assemble', 'beget', 'breed', 'bring forth', 'bring into being', 'build', 'build up', 'call into being', 'cast', 'coin', 'combine', 'compose'],
    'fabricated': ['assembled', 'built', 'cast', 'coined', 'conceived', 'concocted', 'constructed', 'cooked-up', 'crafted', 'created', 'custom', 'custom-built'],
    'fabrication': ['anatomy', 'architectonics', 'architecture', 'arrangement', 'artifact', 'assemblage', 'assembly', 'authorship', 'beginning', 'build', 'building', 'buildup'],
    'fabulous': ['a bit much', 'abandoned', 'ace', 'allegoric', 'amazing', 'appalling', 'astonishing', 'astounding', 'beguiling', 'bewildering', 'boundless', 'celebrated'],
    'facade': ['acting', 'affectation', 'affectedness', 'airs', 'airs and graces', 'alibi', 'anteriority', 'apology', 'apparent character', 'appearance', 'appearances', 'artificiality'],
    'face': ['communist threat', 'western imperialism', 'accept', 'account', 'acknowledge', 'acting', 'admit', 'affectation', 'affront', 'air', 'allow', 'anteriority'],
    'face down': ['brazen out', 'challenge', 'complain', 'complain loudly', 'confront', 'contend with', 'dispute', 'dissent', 'face out', 'face up to', 'front', 'kick against'],
    'face lift': ['furbish', 'furbishment', 'recondition', 'reconditioning', 'refit', 'refresh', 'refreshment', 'refurbish', 'refurbishment', 'renew', 'renewal', 'renovate'],
    'face to face': ['aboveboard', 'adjacent', 'adjoining', 'at opposite extremes', 'back to back', 'before one', 'bordering', 'connecting', 'conterminous', 'contiguous', 'contrariwise', 'contrary'],
    'face up to': ['affront', 'beard', 'bell the cat', 'bite the bullet', 'brave', 'brazen', 'brazen out', 'challenge', 'chance', 'complain', 'complain loudly', 'confront'],
    'face value': ['account', 'asking price', 'bearish prices', 'bid price', 'book value', 'bullish prices', 'call price', 'closing price', 'conversion factor', 'decline', 'face', 'fixed price'],
    'facet': ['angle', 'anteriority', 'article', 'aspect', 'bold front', 'border', 'brave face', 'brave front', 'case', 'circumference', 'configuration', 'cortex'],
    'facetious': ['attic', 'biting', 'blithe', 'brilliant', 'clever', 'comic', 'comical', 'droll', 'funny', 'humorous', 'humorsome', 'jesting'],
    'facetiousness': ['brilliance', 'cleverness', 'funniness', 'humorousness', 'jocoseness', 'jocularity', 'joking', 'joshing', 'keen-wittedness', 'keenness', 'nimble-wittedness', 'pleasantry'],
    'facia': ['anteriority', 'bold front', 'brave face', 'brave front', 'display', 'facade', 'face', 'facet', 'fore', 'forefront', 'foreground', 'forehand'],
    'facile': ['mickey mouse', 'adaptable', 'adroit', 'apt', 'bendable', 'bending', 'biddable', 'bright', 'casual', 'clear', 'clever', 'compliant'],
    'facilitate': ['act for', 'advance', 'advantage', 'aid', 'assist', 'be instrumental', 'boost', 'clear the way', 'conduce to', 'contribute to', 'ease', 'encourage'],
    'facilities': ['accommodation', 'accommodations', 'accouterments', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'bed', 'bed and board', 'board', 'board and room'],
    'facility': ['wc', 'abandon', 'ability', 'ableness', 'accommodation', 'accouterments', 'adaptability', 'address', 'adeptness', 'adequacy', 'adroitness', 'advantage'],
    'facing': ['across', 'against', 'antipodal', 'antithetic', 'bush', 'bushing', 'coat', 'coating', 'confronting', 'contra', 'contrapositive', 'converse'],
    'facsimile': ['doppelganger', 'photoradiogram', 'telephoto', 'wirephoto', 'actual thing', 'burlesque', 'carbon', 'carbon copy', 'clone', 'copy', 'counterpart', 'dead ringer'],
    'fact': ['absolute fact', 'accepted fact', 'accomplishment', 'act', 'actual fact', 'actuality', 'actually', 'admitted fact', 'adventure', 'article', 'aspect', 'authenticity'],
    'fact finding': ['analytic', 'examinational', 'examinatorial', 'examining', 'explorational', 'explorative', 'exploratory', 'feeling', 'groping', 'heuristic', 'indagative', 'inspectional'],
    'faction': ['american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party', 'greenback party'],
    'factious': ['aggressive', 'alienated', 'argumentative', 'at loggerheads', 'at odds', 'bellicose', 'belligerent', 'bickering', 'breakaway', 'combative', 'conflicting', 'contending'],
    'factitious': ['affected', 'artificial', 'assumed', 'bogus', 'counterfeit', 'counterfeited', 'engineered', 'fabricated', 'faked', 'false', 'falsified', 'feigned'],
    'factor': ['altmann theory', 'dna', 'de vries theory', 'federal', 'galtonian theory', 'mc', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism'],
    'factory': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery', 'brewery', 'brickyard', 'cannery'],
    'facts': ['account', 'acquaintance', 'announcement', 'basis for belief', 'blue book', 'body of evidence', 'brass tacks', 'briefing', 'bulletin', 'chain of evidence', 'clue', 'communication'],
    'factual': ['absolute', 'accurate', 'actual', 'adducible', 'admissible', 'admitting no question', 'ascertained', 'attestative', 'attested', 'attestive', 'authentic', 'authenticated'],
    'faculty': ['ability', 'ableness', 'absolute power', 'absolutism', 'adequacy', 'adroitness', 'appurtenance', 'aptitude', 'aptness', 'authority', 'authorization', 'bent'],
    'fad': ['best seller', 'big hit', 'boutade', 'brainstorm', 'brilliant success', 'capriccio', 'caprice', 'chic', 'conceit', 'crank', 'craze', 'crazy idea'],
    'faddish': ['changeable', 'coquettish', 'faddy', 'fickle', 'flighty', 'flirtatious', 'inconstant', 'light', 'mercurial', 'quicksilver', 'skittish', 'toying'],
    'faddist': ['addict', 'bug', 'collector', 'craze', 'demon', 'eager beaver', 'energumen', 'enthusiast', 'fad', 'faddiness', 'faddishness', 'faddism'],
    'fade': ['abate', 'achromatize', 'age', 'ante', 'ante up', 'antiquate', 'arid', 'attenuate', 'avoid', 'back', 'back-number', 'banal'],
    'fade in': ['appear', 'arise', 'become manifest', 'become visible', 'come', 'come forth', 'come forward', 'come in sight', 'come out', 'come to hand', 'come to light', 'crop out'],
    'fade out': ['fcc', 'fm broadcasting', 'abatement', 'abridgment', 'alleviation', 'atmospherics', 'attenuation', 'be annihilated', 'be consumed', 'be destroyed', 'be gone', 'be no more'],
    'faded': ['achromatic', 'achromic', 'anemic', 'ashen', 'ashy', 'bedraggled', 'blanched', 'bleached', 'bled white', 'bloodless', 'cadaverous', 'chloranemic'],
    'fading': ['achromatization', 'aging', 'atmospherics', 'blackout', 'blanching', 'blaring', 'blasting', 'bleach', 'bleaching', 'blind spot', 'blocking', 'brittle'],
    'faerie': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley'],
    'fag': ['auntie', 'beast of burden', 'beat', 'bi-guy', 'bisexual', 'bugger', 'bull dyke', 'burden', 'burn out', 'busy', 'butch', 'butt'],
    'fag end': ['thule', 'ultima thule', 'afterglow', 'afterimage', 'balance', 'bitter end', 'bottom dollar', 'boundary', 'butt', 'butt end', 'candle ends', 'chaff'],
    'fagged': ['all in', 'beat', 'beat up', 'beaten', 'bone-weary', 'bushed', 'dead', 'dead-and-alive', 'dead-tired', 'deadbeat', 'debilitated', 'dog-tired'],
    'faggot': ['auntie', 'bi-guy', 'bisexual', 'bull dyke', 'butch', 'catamite', 'chicken', 'dyke', 'fag', 'fairy', 'femme', 'flit'],
    'fagot': ['backlog', 'bale', 'bavin', 'bindle', 'bolt', 'bouquet', 'brush', 'brushwood', 'budget', 'bundle', 'deck', 'fardel'],
    'fail': ['abandon', 'abort', 'age', 'bankrupt', 'be a gas', 'be a hit', 'be caught napping', 'be found wanting', 'be inferior', 'be insufficient', 'be neglectful', 'be negligent'],
    'failed': ['abortive', 'bankrupt', 'bootless', 'broke', 'broken', 'busted', 'destitute', 'failing', 'fruitless', 'futile', 'in receivership', 'ineffective'],
    'failing': ['abortive', 'arrested', 'bad habit', 'besetting sin', 'blemish', 'blind spot', 'bootless', 'bug', 'cachectic', 'callow', 'catch', 'comedown'],
    'failure': ['grand guignol', 'passion play', 'sisyphean labor', 'tom show', 'waterloo', 'also-ran', 'antimasque', 'arrear', 'arrearage', 'arrears', 'atrocity', 'audience success'],
    'fain': ['aching for', 'acquiescent', 'agreeable', 'alacritous', 'amenable', 'ardent', 'bent on', 'compliant', 'consenting', 'content', 'cooperative', 'crazy to'],
    'faint': ['ko', 'abulic', 'achromatic', 'achromic', 'afraid', 'ailing', 'anemic', 'ashen', 'ashy', 'asthenic', 'bad', 'balmy'],
    'faint praise': ['belittling', 'comedown', 'contempt', 'decrial', 'depreciation', 'derogation', 'detraction', 'disapproval', 'discrediting', 'disgrace', 'disparagement', 'indignity'],
    'faint-hearted': ['afraid', 'chicken', 'cowardly', 'diffident', 'faint', 'feckless', 'feeble', 'frightened', 'ineffectual', 'irresolute', 'lily-livered', 'puny'],
    'fainthearted': ['abulic', 'afraid', 'chicken', 'chickenhearted', 'coward', 'cowardly', 'cowed', 'daunted', 'dismayed', 'faint', 'fearful', 'feeble'],
    'fair': ['christian', 'junoesque', 'mardi gras', 'ok', 'saturnalia', 'saturnian', 'acceptable', 'accommodating', 'adequate', 'admissible', 'advantageous', 'affable'],
    'fair game': ['a leg up', 'butt', 'byword', 'byword of reproach', 'chance', 'clear stage', 'derision', 'dupe', 'fair field', 'figure of fun', 'fool', 'game'],
    'fair shake': ['tweedledum and tweedledee', 'candor', 'cricket', 'dead heat', 'deadlock', 'draw', 'even break', 'even chance', 'fair play', 'fair-mindedness', 'fairness', 'fifty-fifty'],
    'fair spoken': ['adulatory', 'bland', 'blandishing', 'blarneying', 'buttery', 'cajoling', 'complimentary', 'courtierly', 'courtly', 'disarming', 'fawning', 'fine-spoken'],
    'fair to middling': ['betwixt and between', 'dull', 'fair', 'fairish', 'indifferent', 'insipid', 'lackluster', 'mediocre', 'medium', 'middling', 'moderate', 'modest'],
    'fair trade': ['appraise', 'assess', 'balance of trade', 'big business', 'business', 'business dealings', 'commerce', 'commercial affairs', 'commercial relations', 'dealing', 'dealings', 'evaluate'],
    'fair weather': ['saturnia regna', 'saturnian age', 'age of aquarius', 'bright side', 'brightness', 'broiling sun', 'calm weather', 'canicular days', 'cheerfulness', 'climate', 'clime', 'cold weather'],
    'fairly': ['a bit', 'a little', 'absolutely', 'acceptably', 'actually', 'adequately', 'after a fashion', 'appreciably', 'at any rate', 'at best', 'at least', 'at most'],
    'fairness': ['achroma', 'achromasia', 'achromatosis', 'advantageousness', 'agreeability', 'agreeableness', 'albescence', 'albinism', 'albino', 'albinoism', 'anemia', 'ashiness'],
    'fairway': ['astroturf', 'airstrip', 'approaches', 'apron', 'archery ground', 'artificial turf', 'athletic field', 'badminton court', 'baseball field', 'basketball court', 'billiard parlor', 'bowling alley'],
    'fairy': ['ariel', 'befind', 'corrigan', 'finnbeara', 'mab', 'oberon', 'titania', 'air', 'auntie', 'banshee', 'bi-guy', 'bisexual'],
    'fairy godmother': ['maecenas', 'santa claus', 'almoner', 'almsgiver', 'ancestral spirits', 'angel', 'assignor', 'attendant godling', 'awarder', 'backer', 'bestower', 'cheerful giver'],
    'fairy tale': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'apologue', 'bedtime story', 'blague', 'cock-and-bull story', 'detective story', 'exaggeration'],
    'fairyland': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley'],
    'fait accompli': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'actuality', 'adventure', 'attainment', 'authenticity', 'blow', 'carrying out'],
    'faith': ['weltanschauung', 'abandon', 'acceptation', 'acception', 'acquiescence', 'activity', 'adherence', 'adherents', 'adhesion', 'adoration', 'allegiance', 'apostolic faith'],
    'faithful': ['christian', 'christianlike', 'christianly', 'abandoned', 'accepted', 'accurate', 'acquiescent', 'active', 'adoring', 'affectionate', 'afire', 'approved'],
    'faithful servant': ['apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bootlick', 'bootlicker', 'brown-nose', 'brownie', 'clawback', 'courtier', 'creature', 'cringer'],
    'faithfully': ['absolutely', 'acquiescently', 'assiduously', 'bona fide', 'compliantly', 'consistently', 'constantly', 'dead', 'definitely', 'descriptively', 'devotedly', 'diligently'],
    'faithless': ['machiavellian', 'agnostic', 'ambidextrous', 'apostate', 'artful', 'atheist', 'atheistic', 'capricious', 'changeable', 'changeful', 'collaborative', 'conscienceless'],
    'faithworthy': ['calculable', 'dependable', 'faithful', 'fast', 'firm', 'incorruptible', 'invincible', 'inviolable', 'predictable', 'proven', 'reliable', 'responsible'],
    'fake': ['act', 'act a part', 'act like', 'actor', 'ad-lib', 'adulterate', 'affect', 'affected', 'affecter', 'agent', 'alike', 'alter'],
    'fake up': ['bat out', 'botch', 'bungle', 'dash off', 'do anyhow', 'do by halves', 'do carelessly', 'do offhand', 'fudge up', 'jury-rig', 'knock off', 'knock out'],
    'fakery': ['acting', 'affectation', 'appearance', 'attitudinizing', 'bluff', 'bluffing', 'cheating', 'color', 'coloring', 'copying', 'counterfeiting', 'deception'],
    'fakir': ['albigensian', 'catharist', 'franciscan', 'sabbatarian', 'trappist', 'waldensian', 'abdal', 'abstainer', 'anchorite', 'ascetic', 'bhikshu', 'dervish'],
    'falcate': ['cynthian', 's-shaped', 'bicorn', 'corniform', 'crescent', 'crescent-shaped', 'crescentic', 'crescentiform', 'crescentlike', 'falciform', 'horn-shaped', 'horned'],
    'falderal': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'absurdity', 'amphigory', 'anacrusis', 'babble', 'babblement', 'bagatelle', 'balderdash'],
    'fall': ['niagara', 'scotch mist', 'waterloo', 'abate', 'abatement', 'ablate', 'accept', 'apostasy', 'ascend', 'assail', 'assault', 'associate with'],
    'fall away': ['abate', 'ablate', 'apostacize', 'apostatize', 'ascend', 'bank', 'bate', 'be eaten away', 'be found wanting', 'bolt', 'break away', 'cant'],
    'fall back': ['avoid', 'back', 'back down', 'back out', 'back up', 'backslide', 'beat a retreat', 'blench', 'blink', 'come after', 'come last', 'cringe'],
    'fall behind': ['back', 'back up', 'backslide', 'cock', 'come after', 'come last', 'dawdle', 'drag', 'fall astern', 'fall back', 'follow', 'get behind'],
    'fall flat': ['bomb', 'break down', 'capsize', 'careen', 'collapse', 'come a cropper', 'come to naught', 'come to nothing', 'crash', 'fall', 'fall dead', 'fall down'],
    'fall for': ['and sinker', 'be a sucker', 'be smitten', 'be taken in', 'become attached to', 'bite', 'cotton to', 'devour', 'eat up', 'fall in love', 'go for', 'gobble up'],
    'fall from grace': ['apostasy', 'atheism', 'backslide', 'backsliding', 'desertion', 'fall', 'fall again into', 'fall back', 'fall of adam', 'fall of man', 'have a relapse', 'impiety'],
    'fall guy': ['also-ran', 'babe', 'boob', 'booby', 'butt', 'chump', 'cinch', 'credulous person', 'cull', 'defeatee', 'duck', 'dupe'],
    'fall in': ['break down', 'cave', 'cave in', 'collapse', 'come together', 'crash', 'crystallize', 'deflate', 'draw up', 'fall', 'fall dead', 'fall down'],
    'fall in with': ['accommodate', 'accommodate with', 'accord', 'acquiesce', 'acquire', 'adapt', 'adapt to', 'adjust', 'adjust to', 'agree', 'agree in opinion', 'agree with'],
    'fall into': ['accept', 'acquire', 'alter into', 'assume', 'attack', 'attempt', 'be converted into', 'be responsible for', 'become', 'bring down', 'bring on', 'bring upon'],
    'fall off': ['abate', 'ablate', 'apostacize', 'apostatize', 'ascend', 'bank', 'bate', 'be eaten away', 'bolt', 'break away', 'cant', 'careen'],
    'fall out': ['agree to disagree', 'attend', 'become of', 'befall', 'betide', 'bicker', 'break', 'break with', 'caterwaul', 'chance', 'come about', 'come of'],
    'fall short': ['be disappointing', 'be found wanting', 'be inferior', 'be insufficient', 'collapse', 'come short', 'crash', 'decline', 'fail', 'fail of', 'fall', 'fall away'],
    'fall through': ['break down', 'collapse', 'come to naught', 'come to nothing', 'crash', 'fall', 'fall dead', 'fall down', 'fall flat', 'fall in', 'fall short', 'fall stillborn'],
    'fall to': ['accept', 'assume', 'attack', 'attempt', 'begin', 'blast away', 'blast off', 'break bread', 'buckle down', 'buckle to', 'commence', 'count calories'],
    'fall to pieces': ['ablate', 'atomize', 'bite the dust', 'break', 'break open', 'break up', 'burst', 'canker', 'carry away', 'come apart', 'come off', 'come to dust'],
    'fall upon': ['alight upon', 'ambush', 'appear unexpectedly', 'arrive at', 'arrive upon', 'assail', 'assault', 'attack', 'be unexpected', 'blitz', 'bob up', 'bump into'],
    'fallacious': ['albigensian', 'arian', 'barmecidal', 'barmecide', 'catharist', 'donatist', 'ebionitist', 'erastian', 'gnostic', 'jansenist', 'jansenistic', 'jovinianist'],
    'fallacy': ['albigensianism', 'arianism', 'catharism', 'ebionitism', 'erastianism', 'gnosticism', 'jovinianism', 'lollardy', 'manichaeanism', 'manichaeism', 'monophysism', 'monophysitism'],
    'fallback': ['avoidance', 'cringe', 'disengagement', 'dodge', 'duck', 'evasion', 'flinch', 'pullback', 'pullout', 'recoil', 'reculade', 'retirement'],
    'fallen': ['adamic', 'circean', 'abated', 'ablated', 'all up with', 'animal', 'animalistic', 'apostate', 'asleep', 'asleep in jesus', 'at rest', 'atheistic'],
    'fallen angel': ['backslider', 'bad egg', 'bad lot', 'black sheep', 'degenerate', 'lecher', 'lost sheep', 'lost soul', 'miscreant', 'pervert', 'pimp', 'profligate'],
    'fallible': ['adulterated', 'blemished', 'careless', 'damaged', 'defective', 'deficient', 'errable', 'errant', 'erroneous', 'error-prone', 'faulty', 'found wanting'],
    'falling': ['cascading', 'collapsing', 'coming apart', 'cracking', 'crumbling', 'dangling', 'decadent', 'deciduous', 'declined', 'declining', 'declivate', 'declivitous'],
    'falling out': ['alienation', 'altercation', 'beef', 'bickering', 'breach', 'breach of friendship', 'break', 'cleavage', 'cleft', 'controversy', 'disaffection', 'disfavor'],
    'falling sickness': ['jacksonian epilepsy', 'ms', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'akinetic epilepsy', 'amyotrophic lateral sclerosis', 'apoplexy', 'arrest'],
    'fallout': ['a-blast', 'a-bomb shelter', 'h-blast', 'mach front', 'activity', 'air pollution', 'airborne radioactivity', 'artificial radioactivity', 'atom blast', 'attritus', 'blast wave', 'bran'],
    'fallout shelter': ['a-blast', 'a-bomb shelter', 'h-blast', 'mach front', 'abri', 'air-raid shelter', 'airborne radioactivity', 'atom blast', 'blast wave', 'bomb shelter', 'bombproof', 'bunker'],
    'fallow': ['acarpous', 'achromatic', 'achromic', 'anemic', 'arable land', 'arid', 'ashen', 'ashy', 'at leisure', 'at liberty', 'at loose ends', 'aureate'],
    'false': ['barmecidal', 'barmecide', 'machiavellian', 'tartuffian', 'tartuffish', 'aberrant', 'abroad', 'adrift', 'affected', 'airy', 'all abroad', 'all off'],
    'false front': ['acting', 'affectation', 'affectedness', 'airs', 'airs and graces', 'anteriority', 'appearance', 'artificiality', 'attitudinizing', 'blazon', 'bluff', 'bluffing'],
    'false modesty': ['quakerishness', 'censoriousness', 'demureness', 'demurity', 'hideboundness', 'mauvaise honte', 'narrowness', 'overmodesty', 'priggishness', 'primness', 'prudery', 'prudishness'],
    'false move': ['balk', 'bevue', 'false step', 'inadvertence', 'inadvertency', 'lapse', 'lapsus calami', 'lapsus linguae', 'loose thread', 'miscue', 'misstep', 'omission'],
    'false show': ['prospero', 'acting', 'affectation', 'affectedness', 'airiness', 'airs', 'airs and graces', 'appearance', 'artificiality', 'attitudinizing', 'bluff', 'bluffing'],
    'false step': ['balk', 'bevue', 'false move', 'inadvertence', 'inadvertency', 'lapse', 'lapsus calami', 'lapsus linguae', 'loose thread', 'miscue', 'misstep', 'omission'],
    'false witness': ['ananias', 'baron munchausen', 'father of lies', 'satan', 'sir john mandeville', 'consummate liar', 'dirty liar', 'equivocator', 'fabricator', 'fabulist', 'falsifier', 'fibber'],
    'falsehearted': ['machiavellian', 'ambidextrous', 'artful', 'calculating', 'chiseling', 'collusive', 'covinous', 'crafty', 'crooked', 'cunning', 'deceitful', 'dishonest'],
    'falsehood': ['blague', 'canard', 'cock-and-bull story', 'credibility gap', 'deceit', 'dishonesty', 'dissimulation', 'distortion', 'erroneousness', 'error', 'exaggeration', 'fabrication'],
    'falsely': ['amiss', 'apparently', 'artificially', 'astray', 'beguilingly', 'deceptively', 'delusively', 'erroneously', 'factitiously', 'fallaciously', 'faultfully', 'faultily'],
    'falseness': ['machiavellianism', 'prospero', 'punic faith', 'tartuffery', 'tartuffism', 'aberrancy', 'aberration', 'affectation', 'airiness', 'ambidexterity', 'apostasy', 'appearance'],
    'falsetto': ['alto', 'aphonia', 'artificial voice', 'baritone', 'bass', 'bourdon', 'bravura', 'broken speech', 'broken tones', 'broken voice', 'burden', 'chest voice'],
    'falsification': ['abstractionism', 'coloring', 'confabulation', 'deformation', 'distortion', 'equivocation', 'exaggeration', 'expressionism', 'false coloring', 'false swearing', 'falsifying', 'garbling'],
    'falsified': ['affected', 'apocryphal', 'artificial', 'assumed', 'bastard', 'bogus', 'brummagem', 'colorable', 'colored', 'counterfeit', 'counterfeited', 'distorted'],
    'falsify': ['alter', 'be untruthful', 'belie', 'burlesque', 'camouflage', 'caricature', 'change', 'cheat', 'color', 'contort', 'contradict', 'contravene'],
    'falsity': ['punic faith', 'aberrancy', 'aberration', 'acting', 'affectation', 'appearance', 'attitudinizing', 'bad faith', 'barratry', 'blague', 'bluff', 'bluffing'],
    'falter': ['bebung', 'abandon hope', 'back down', 'back out', 'balance', 'bashfulness', 'blench', 'blunder', 'bob', 'bobble', 'boggle', 'boggling'],
    'faltering': ['ambling', 'balbutient', 'bashful', 'boggling', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'deliberate', 'demurring'],
    'fame': ['pr', 'acclaim', 'acclamation', 'acknowledgment', 'applause', 'ballyhoo', 'blurb', 'bright light', 'celebrity', 'character', 'common knowledge', 'consequence'],
    'familiar': ['bohemian', 'abreast', 'accepted', 'accustomed', 'acquaintance', 'acquainted', 'acquainted with', 'advocate', 'affable', 'alter ego', 'amicable', 'amigo'],
    'familiarity': ['bohemianism', 'acquaintance', 'affability', 'affinity', 'amiability', 'assumption', 'awareness', 'boldness', 'casualness', 'chumminess', 'civility', 'closeness'],
    'familiarize': ['acclimate', 'acclimatize', 'accommodate', 'accustom', 'acquaint', 'adapt', 'adjust', 'advertise', 'advertise of', 'advise', 'apprise', 'break'],
    'family': ['affiliation', 'agnate', 'ancestors', 'ancestry', 'animal kingdom', 'antonomasia', 'apparentation', 'ashram', 'binomial nomenclature', 'biosystematics', 'biosystematy', 'biotype'],
    'family planning': ['aridity', 'barrenness', 'birth control', 'contraception', 'dearth', 'dry womb', 'dryness', 'famine', 'impotence', 'ineffectualness', 'infecundity', 'infertility'],
    'famine': ['absence', 'aridity', 'barrenness', 'beggary', 'birth control', 'contraception', 'dearth', 'defectiveness', 'deficiency', 'deficit', 'deprivation', 'destitution'],
    'famished': ['bare-handed', 'beggarly', 'craving', 'dog-hungry', 'empty', 'empty-handed', 'famishing', 'fasting', 'half-famished', 'half-starved', 'hungering', 'hungry'],
    'famous': ['acclaimed', 'advantageous', 'august', 'auspicious', 'beneficial', 'benevolent', 'bon', 'bonny', 'braw', 'bueno', 'capital', 'celebrated'],
    'famously': ['abundantly', 'acutely', 'amazingly', 'amply', 'aright', 'astonishingly', 'awesomely', 'capitally', 'celebratedly', 'conspicuously', 'copiously', 'eminently'],
    'fan': ['maecenas', 'abettor', 'adherent', 'admirer', 'advocate', 'aerate', 'aerator', 'aficionado', 'agitate', 'air', 'air conditioner', 'air cooler'],
    'fan out': ['aberrate', 'bestrew', 'branch', 'branch out', 'broadcast', 'circumfuse', 'deal out', 'deploy', 'diffract', 'diffuse', 'dispense', 'disperse'],
    'fan shaped': ['centrifugal', 'delta-shaped', 'deltalike', 'deltoid', 'divaricate', 'divaricating', 'divergent', 'diverging', 'fan-shape', 'fanlike', 'fanned', 'fanning'],
    'fan the flame': ['aggravate', 'agitate', 'alienate', 'annoy', 'arouse', 'awake', 'awaken', 'bank', 'blow the coals', 'blow up', 'burn', 'call forth'],
    'fanatic': ['christian', 'god-fearing man', 'accepter', 'addict', 'aficionado', 'alien', 'aliene', 'ass', 'bedlamite', 'believer', 'bigot', 'bitter-ender'],
    'fanatical': ['agog', 'ardent', 'at fever pitch', 'authoritarian', 'balking', 'balky', 'bigot', 'bigoted', 'borne', 'bulldogged', 'bulletheaded', 'bullheaded'],
    'fanaticism': ['agitation', 'authoritarianism', 'balkiness', 'bias', 'bibliolatry', 'bigotry', 'blind side', 'blind spot', 'blinders', 'bluster', 'brawl', 'broil'],
    'fancied': ['concocted', 'cooked-up', 'fabricated', 'fabulous', 'fanciful', 'fantasied', 'fantastic', 'fictional', 'fictitious', 'fictive', 'figmental', 'forged'],
    'fanciful': ['gothic', 'absurd', 'air-built', 'airy', 'antic', 'apocryphal', 'arbitrary', 'baroque', 'bizarre', 'brain-born', 'capricious', 'changeable'],
    'fancy': ['amor', 'babylonian', 'byzantine', 'christian love', 'corinthian', 'daedalian', 'eros', 'platonic love', 'a bit much', 'abandoned', 'account as', 'adept'],
    'fanfare': ['aldine', 'arabesque', 'byzantine', 'canevari', 'etruscan', 'grolier', 'harleian', 'jansenist', 'maioli', 'roxburgh', 'ado', 'anniversaries'],
    'fanfaronade': ['anniversaries', 'blazon', 'bluff', 'bluster', 'bluster and bluff', 'blustering', 'boast', 'boastfulness', 'boasting', 'bombast', 'brag', 'braggadocio'],
    'fang': ['baby tooth', 'beesting', 'bicuspid', 'bucktooth', 'canine', 'claws', 'clutches', 'cog', 'comb', 'crag', 'crown', 'cuspid'],
    'fanged': ['bicuspid', 'clawed', 'dental', 'dentate', 'dentiform', 'dentoid', 'digital', 'digitate', 'digitated', 'fingered', 'jawed', 'molar'],
    'fannie mae': ['federal agency bond', 'ginnie mae', 'series e bond', 'series h bond', 'adjustment bond', 'annuity bond', 'appreciation bond', 'assented bond', 'assumed bond', 'baby bond', 'bearer bond', 'bearer certificate'],
    'fanny': ['arse', 'ass', 'backside', 'behind', 'bottom', 'bum', 'can', 'cheeks', 'derriere', 'heinie', 'hind end', 'keister'],
    'fantail': ['brush', 'cauda', 'caudal appendage', 'caudation', 'counter', 'cue', 'dock', 'heel', 'pigtail', 'poop', 'queue', 'rattail'],
    'fantasize': ['coin', 'conceit', 'conceive', 'conceptualize', 'concoct', 'cook up', 'counterfeit', 'create', 'dream', 'dream up', 'envisage', 'envision'],
    'fantastic': ['barmecidal', 'barmecide', 'gothic', 'absurd', 'adroit', 'airy', 'alien', 'antic', 'appalling', 'apparent', 'apparitional', 'arbitrary'],
    'fantastical': ['barmecidal', 'barmecide', 'gothic', 'absurd', 'airy', 'antic', 'appalling', 'apparent', 'apparitional', 'arbitrary', 'astonishing', 'autistic'],
    'fantasy': ['marchen', 'walter mitty', 'western', 'western story', 'westerner', 'absence of mind', 'absentmindedness', 'absorption', 'abstractedness', 'abstraction', 'adventure story', 'alienation'],
    'far': ['abase', 'afar', 'afar off', 'apart', 'asunder', 'at a distance', 'away', 'by far', 'considerably', 'distal', 'distant', 'exotic'],
    'far and away': ['absolutely', 'by all odds', 'by far', 'decidedly', 'definitely', 'doubtless', 'egregiously', 'eminently', 'exceedingly', 'far', 'far and wide', 'incomparably'],
    'far and wide': ['abroad', 'all', 'all over', 'broadly', 'by far', 'distantly and broadly', 'extensively', 'far', 'far and away', 'far and near', 'infinitely', 'on all sides'],
    'far cry': ['aphelion', 'apogee', 'contrariety', 'contrast', 'departure', 'deviation', 'difference', 'disaccord', 'disaccordance', 'disagreement', 'disconformity', 'discongruity'],
    'far flung': ['a mile long', 'broad', 'diffuse', 'extensive', 'far', 'far-embracing', 'far-extending', 'far-flying', 'far-going', 'far-off', 'far-ranging', 'far-reaching'],
    'far gone': ['absorbed in', 'addled', 'all in', 'attached to', 'ausgespielt', 'beery', 'bemused', 'besotted', 'bleary', 'blind drunk', 'caught up in', 'crapulent'],
    'far out': ['bohemian', 'a la mode', 'advanced', 'at the height', 'at the limit', 'avant-garde', 'beat', 'breakaway', 'contemporary', 'extreme', 'fashionable', 'forward-looking'],
    'far reaching': ['a mile long', 'ample', 'amplitudinous', 'broad', 'capacious', 'commodious', 'deep', 'diffuse', 'expansive', 'extended', 'extending', 'extensive'],
    'faraway': ['absent', 'absentminded', 'absorbed', 'abstracted', 'apart', 'asunder', 'at a distance', 'away', 'bemused', 'castle-building', 'daydreaming', 'daydreamy'],
    'farce': ['atticism', 'thalia', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'agile wit', 'arlequinade', 'bagatelle', 'bauble', 'bean'],
    'farcer': ['choreographer', 'comedian', 'comedienne', 'comic', 'dramatist', 'dramatizer', 'dramaturge', 'farceur', 'farceuse', 'farcist', 'funnyman', 'gagman'],
    'farcical': ['absurd', 'amusing', 'broad', 'burlesque', 'camp', 'campy', 'caricatural', 'comic', 'comical', 'doggerel', 'droll', 'extravagant'],
    'fare': ['admission', 'admission fee', 'advance', 'adventurer', 'alpinist', 'anchorage', 'astronaut', 'attend', 'be so', 'be such', 'become of', 'board'],
    'fare well': ['advance', 'be blooded', 'be successful', 'catch on', 'click', 'come along', 'come off', 'come on', 'connect', 'do well', 'enjoy prosperity', 'farewell'],
    'farewell': ['godspeed', 'adieu', 'aloha', 'by', 'bye-bye', 'conge', 'departing', 'departure', 'doch-an-dorrach', 'final', 'good-bye', 'last'],
    'farina': ['air pollution', 'attritus', 'bran', 'breakfast food', 'cereal', 'cornflakes', 'cosmic dust', 'crumb', 'crumble', 'dry cereal', 'dust', 'dust ball'],
    'farinaceous': ['botanic', 'branny', 'bulbous', 'cereal', 'chalklike', 'chalky', 'comminute', 'comminuted', 'crushed', 'detrital', 'detrited', 'disintegrated'],
    'farm': ['arcadian', 'dymaxion house', 'white house', 'acreage', 'adobe house', 'agrarian', 'agrestic', 'agricultural', 'agronomic', 'allotment', 'arable', 'arable land'],
    'farm machinery': ['all-crop harvester', 'baler', 'bean harvester', 'beet harvester', 'binder', 'breaker', 'cast plow', 'combine', 'cotton picker', 'cultivator', 'disk', 'disk harrow'],
    'farm out': ['charter', 'farm', 'hire', 'hire out', 'job', 'lease', 'lease out', 'lease-back', 'lease-lend', 'lend-lease', 'let', 'let off'],
    'farmer': ['bauer', 'internal revenue service', 'accumulator', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'assessor', 'bill collector', 'boor', 'bucolic', 'bumpkin'],
    'farmhand': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'coffee-planter', 'collective farm worker', 'crofter', 'cropper', 'cultivator', 'dirt farmer', 'dry farmer'],
    'farming': ['agrarian', 'agrarianism', 'agricultural', 'agricultural geology', 'agriculture', 'agrology', 'agronomic', 'agronomics', 'agronomy', 'arable', 'contour farming', 'cultivation'],
    'farmland': ['agricultural region', 'arable land', 'barnyard', 'barton', 'black belt', 'cattle ranch', 'chicken farm', 'citrus belt', 'collective farm', 'corn belt', 'cotton belt', 'cotton plantation'],
    'farmstead': ['arable land', 'barnyard', 'barton', 'cattle ranch', 'chicken farm', 'collective farm', 'cotton plantation', 'croft', 'dairy farm', 'demesne', 'demesne farm', 'dry farm'],
    'farseeing': ['argus-eyed', 'acute', 'anticipant', 'anticipatory', 'apperceptive', 'appercipient', 'argute', 'astute', 'cat-eyed', 'clairvoyant', 'clear-eyed', 'clear-sighted'],
    'farsighted': ['argus-eyed', 'acute', 'anticipant', 'anticipatory', 'apperceptive', 'appercipient', 'argute', 'asquint', 'astigmatic', 'astute', 'blink-eyed', 'blinking'],
    'fart': ['sob', 'bastard', 'break wind', 'bugger', 'creep', 'flatulence', 'flatulency', 'flatuosity', 'flatus', 'gas', 'heel', 'hood'],
    'farther': ['above', 'accessory', 'added', 'additional', 'additionally', 'again', 'all included', 'also', 'altogether', 'among other things', 'ancillary', 'and all'],
    'farthest': ['boundary', 'caudal', 'conclusive', 'definitive', 'determinative', 'endmost', 'eventual', 'extreme', 'farthermost', 'farthest off', 'final', 'furthermost'],
    'farthing': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'ace', 'atom', 'bagatelle', 'bauble', 'bawbee', 'bean', 'bibelot'],
    'fasces': ['armory', 'badge', 'badge of office', 'badges', 'bale', 'baton', 'bindle', 'blazonry', 'bolt', 'bouquet', 'brassard', 'budget'],
    'fascia': ['mystik tape', 'scotch tape', 'adhesive tape', 'anklet', 'armlet', 'band', 'bandage', 'batten', 'belt', 'bracelet', 'cellophane tape', 'cincture'],
    'fascinate': ['absorb', 'absorb the attention', 'affect', 'affect the interest', 'allure', 'appeal', 'arrest', 'attract', 'becharm', 'beguile', 'bewitch', 'captivate'],
    'fascinated': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'arrested', 'astonished', 'astounded', 'at gaze', 'attracted', 'awed', 'awestruck'],
    'fascinating': ['circean', 'absorbing', 'alluring', 'appealing', 'appetizing', 'arresting', 'attractive', 'beguiling', 'bewildering', 'bewitching', 'blandishing', 'cajoling'],
    'fascination': ['admiration', 'affinity', 'agacerie', 'allure', 'allurement', 'amaze', 'amazement', 'animal magnetism', 'appeal', 'astonishment', 'astoundment', 'attraction'],
    'fascism': ['jim crow', 'jim crow law', 'nazism', 'anti-semitism', 'apartheid', 'argumentum baculinum', 'big stick', 'black power', 'black supremacy', 'centralism', 'chauvinism', 'class consciousness'],
    'fascist': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'civic', 'civil', 'constitutional', 'democratic', 'despotic', 'dictatorial'],
    'fashion': ['mo', 'platonic form', 'platonic idea', 'aesthetic form', 'affectation', 'algorithm', 'anatomy', 'angle', 'apparel', 'approach', 'archetype', 'architectonics'],
    'fashion plate': ['beau brummel', 'arbiter of fashion', 'beau', 'blade', 'blood', 'boulevardier', 'clotheshorse', 'clubman', 'clubwoman', 'coxcomb', 'dandy', 'deb'],
    'fashionable': ['beau brummel', 'a la mode', 'advanced', 'all the rage', 'all the thing', 'arbiter of fashion', 'avant-garde', 'chic', 'clotheshorse', 'clubman', 'clubwoman', 'contemporary'],
    'fast': ['barmecidal feast', 'encratism', 'friday', 'lenten diet', 'lenten entertainment', 'lenten fare', 'pythagoreanism', 'pythagorism', 'rechabitism', 'sabbath', 'shakerism', 'spartan fare'],
    'fast and loose': ['adrift', 'afloat', 'alternating', 'amorphous', 'capricious', 'changeable', 'changeful', 'desultory', 'deviable', 'dizzy', 'eccentric', 'erratic'],
    'fast food': ['board', 'bread', 'bread and butter', 'cheer', 'comestibles', 'creature comfort', 'cuisine', 'daily bread', 'eatables', 'edibles', 'fare', 'feast'],
    'fastball': ['bowl', 'cast', 'change of pace', 'change-up', 'chuck', 'chunk', 'curve', 'downcurve', 'fling', 'flip', 'forward pass', 'heave'],
    'fasten': ['address', 'adhere', 'affix', 'aim', 'anchor', 'annex', 'apply', 'attach', 'bang', 'bar', 'barricade', 'batten'],
    'fasten upon': ['account for', 'accredit with', 'accrete to', 'accuse', 'acknowledge', 'allege', 'apply to', 'arraign', 'article', 'ascribe to', 'assign to', 'attach to'],
    'fastened': ['aground', 'anchored', 'bonded', 'caught', 'cemented', 'chained', 'close', 'fast', 'firm', 'fixed', 'glued', 'grounded'],
    'fastener': ['adhesive', 'affixation', 'anchor', 'annexation', 'attachment', 'band', 'bandage', 'bar', 'barrette', 'bellyband', 'belt', 'bind'],
    'fasthold': ['acropolis', 'bastion', 'beachhead', 'blockhouse', 'bridgehead', 'bunker', 'castle', 'citadel', 'donjon', 'fastness', 'fort', 'fortress'],
    'fastidious': ['accurate', 'appreciative', 'bleached', 'bright', 'careful', 'censorious', 'choicy', 'choosy', 'civilized', 'clean', 'cleanly', 'conscientious'],
    'fasting': ['albigensianism', 'catharism', 'day of atonement', 'franciscanism', 'lenten', 'sabbatarianism', 'trappism', 'waldensianism', 'yoga', 'yom kippur', 'abstinence', 'anchoritic monasticism'],
    'fat': ['boeotian', 'haliver oil', 'abounding', 'abounding in riches', 'abundant', 'adipose', 'adipose tissue', 'advantageous', 'affluent', 'all-sufficing', 'ample', 'animal oil'],
    'fat back': ['bacon', 'butt', 'chitterlings', 'cochon de lait', 'cracklings', 'flitch', 'gammon', 'ham', 'ham steak', 'haslet', 'headcheese', 'jambon'],
    'fat cat': ['daddy warbucks', 'big cheese', 'big chief', 'big shot', 'big-timer', 'billionaire', 'bloated plutocrat', 'capitalist', 'heavyweight', 'man of means', 'man of substance', 'man of wealth'],
    'fata morgana': ['autoluminescence', 'bioluminescence', 'cathode luminescence', 'chemicoluminescence', 'chemiluminescence', 'corposant', 'crystalloluminescence', 'double corposant', 'electroluminescence', 'fluorescence', 'fox fire', 'ignis fatuus'],
    'fatal': ['accidental', 'adventitious', 'aleatory', 'appointed', 'approaching', 'awe-inspiring', 'badly off', 'baleful', 'baneful', 'black', 'brutal', 'calamitous'],
    'fatality': ['friday', 'friday the thirteenth', 'appointed lot', 'astral influences', 'astrology', 'balefulness', 'banefulness', 'bodefulness', 'book of fate', 'calamity', 'casualty', 'cataclysm'],
    'fate': ['friday', 'friday the thirteenth', 'heaven', 'paradise', 'a better place', 'accidentality', 'act of god', 'actuarial calculation', 'adventitiousness', 'afterlife', 'afterworld', 'allocate'],
    'fated': ['appointed', 'approaching', 'certain', 'coming', 'cursed', 'damned', 'decided', 'decreed', 'desired', 'destinal', 'destined', 'determined'],
    'fateful': ['acute', 'apocalyptic', 'appointed', 'awe-inspiring', 'bad', 'baleful', 'baneful', 'black', 'bodeful', 'boding', 'calamitous', 'cataclysmal'],
    'fates': ['atropos', 'clotho', 'dame fortune', 'decuma', 'fata', 'fortuna', 'heaven', 'lachesis', 'moirai', 'morta', 'nona', 'norns'],
    'fathead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'boob', 'booby', 'bufflehead', 'cabbagehead'],
    'father': ['establishment', 'vip', 'abba', 'abbe', 'affiliate to', 'agent', 'ancestor', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist'],
    'father time': ['cronus', 'kronos', 'methuselah', 'nestor', 'old paar', 'time', 'centenarian', 'dotard', 'elder', 'gaffer', 'geezer', 'golden-ager'],
    'fatherhood': ['affiliation', 'agnation', 'alliance', 'ancestry', 'blood', 'blood relationship', 'brotherhood', 'brothership', 'cognation', 'common ancestry', 'common descent', 'connection'],
    'fatherless': ['abandoned', 'aidless', 'baseborn', 'bastard', 'bereaved', 'bereft', 'defenseless', 'deprived', 'deserted', 'desolate', 'forlorn', 'forsaken'],
    'fatherly': ['affectionate', 'amiable', 'ancestorial', 'ancestral', 'benevolent', 'benign', 'caring', 'fatherlike', 'friendly', 'grandfatherly', 'grandmotherly', 'grandparental'],
    'fathom': ['absorb', 'answer', 'appraise', 'appreciate', 'apprehend', 'ascertain', 'assay', 'assess', 'assimilate', 'be acquainted with', 'be apprised of', 'be aware of'],
    'fathomable': ['appraisable', 'appreciable', 'apprehensible', 'articulate', 'assessable', 'calculable', 'cognizable', 'comprehensible', 'computable', 'determinable', 'easily understood', 'easy to understand'],
    'fatigue': ['abatement', 'abscess', 'acedia', 'adynamia', 'ague', 'anemia', 'ankylosis', 'annoy', 'anoxia', 'apathy', 'apnea', 'asphyxiation'],
    'fatigued': ['all in', 'ausgespielt', 'beat', 'buggered', 'burned-out', 'bushed', 'dead', 'debilitated', 'devitalized', 'disabled', 'done', 'done up'],
    'fatigues': ['apparel', 'array', 'attire', 'bedizenment', 'clothes', 'clothing', 'costume', 'drapery', 'dress', 'dressing', 'duds', 'fashion'],
    'fatiguing': ['boresome', 'boring', 'devitalizing', 'draining', 'enervating', 'enfeebling', 'exhausting', 'fatiguesome', 'grueling', 'irksome', 'killing', 'punishing'],
    'fatten': ['acculturate', 'add to', 'advance', 'aggrandize', 'aliment', 'ameliorate', 'amend', 'amplify', 'augment', 'batten', 'become overweight', 'better'],
    'fatty': ['adipose', 'blimp', 'blubbery', 'buttery', 'butyraceous', 'chrismal', 'chrismatory', 'fat', 'greasy', 'heavy', 'heavyweight', 'hippo'],
    'fatuity': ['absurdity', 'aimlessness', 'asininity', 'battiness', 'blank mind', 'blankmindedness', 'blankness', 'bootlessness', 'brainlessness', 'buffoonery', 'calm of mind', 'clownishness'],
    'fatuous': ['absurd', 'air-built', 'airy', 'apish', 'asinine', 'barren', 'batty', 'befooled', 'beguiled', 'besotted', 'blank', 'blankminded'],
    'faucet': ['ball cock', 'ball valve', 'bung', 'bunghole', 'check valve', 'cock', 'cork', 'drain cock', 'draw cock', 'gate', 'hydrant', 'lid'],
    'fault': ['aberrancy', 'aberration', 'abysm', 'abyss', 'accountability', 'accountable', 'accuse', 'answerability', 'answerable', 'arroyo', 'at fault', 'atrocity'],
    'fault-finding': ['captious', 'captiousness', 'carping', 'cavilling', 'censorious', 'censure', 'contentious', 'critical', 'criticism', 'fussiness', 'fussy', 'hair-splitting'],
    'faultfinding': ['jeremianic', 'adverse criticism', 'animadversion', 'aspersion', 'bad notices', 'bad press', 'beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching'],
    'faultless': ['ok', 'absolute', 'accurate', 'all right', 'angelic', 'beyond all praise', 'blameless', 'chaste', 'childlike', 'clean', 'clear', 'correct'],
    'faulty': ['aberrant', 'abroad', 'absonant', 'adrift', 'adulterated', 'all abroad', 'all off', 'all wrong', 'amiss', 'arraignable', 'askew', 'astray'],
    'faun': ['cailleac', 'faunus', 'pan', 'priapus', 'vidar', 'vitharr', 'corn spirit', 'fertility god', 'field spirit', 'forest god', 'panisc', 'panisca'],
    'fauna': ['animalia', 'and fish', 'animal kingdom', 'animal life', 'animality', 'beasts', 'beasts of field', 'beasts of prey', 'big game', 'birds', 'brute creation', 'cattle'],
    'faux pas': ['blooper', 'blunder', 'boner', 'boo-boo', 'botch', 'break', 'bungle', 'gaffe', 'howler', 'impropriety', 'indecorum', 'indiscretion'],
    'favor': ['ok', 'abet', 'abetment', 'accept', 'acceptance', 'accommodate', 'accomplishment', 'accord respect to', 'account', 'acculturate', 'acknowledgment', 'act of courtesy'],
    'favor with': ['accommodate with', 'afford', 'bless with', 'dower', 'endow', 'endow with', 'furnish', 'grace with', 'heap upon', 'indulge with', 'invest', 'lavish upon'],
    'favorable': ['accommodating', 'accommodative', 'accordant', 'acquiescent', 'advantageous', 'advisable', 'advocating', 'affirmative', 'agreeable', 'agreeing', 'alacritous', 'amenable'],
    'favorably': ['accordantly', 'acquiescently', 'advantageously', 'affirmatively', 'agreeably', 'amelioratively', 'amiably', 'amicably', 'approvingly', 'ardently', 'arm in arm', 'as lief'],
    'favored': ['accepted', 'acclaimed', 'admired', 'admitted', 'advantaged', 'advocated', 'affluent', 'applauded', 'approved', 'auspicious', 'backed', 'better'],
    'favoring': ['advantageous', 'advocating', 'agential', 'agentival', 'agentive', 'alike', 'aped', 'approving', 'assisting', 'auspicious', 'backing', 'beneficial'],
    'favorite': ['accepted', 'acclaimed', 'admired', 'admitted', 'adored', 'advocated', 'applauded', 'approved', 'backed', 'beloved', 'cherished', 'choice'],
    'favoritism': ['bent', 'bias', 'discrimination', 'forejudgment', 'inclination', 'inequality', 'interest', 'involvement', 'jaundice', 'jaundiced eye', 'leaning', 'nepotism'],
    'fawn': ['cape elk', 'virginia deer', 'abase', 'antelope', 'apple-polish', 'be confined', 'bear', 'bear a child', 'bear young', 'beige', 'bend the knee', 'birdling'],
    'fawn upon': ['act up to', 'adulate', 'agree to anything', 'beslobber', 'beslubber', 'blandish', 'brown-nose', 'cajole', 'compliment', 'conceit', 'court', 'curry favor'],
    'fawning': ['abject', 'adulation', 'adulatory', 'apple-polishing', 'ass-kissing', 'backscratching', 'beggarly', 'bland', 'blandishing', 'blandishment', 'blarney', 'blarneying'],
    'fay': ['ariel', 'befind', 'corrigan', 'finnbeara', 'mab', 'oberon', 'titania', 'banshee', 'brownie', 'cluricaune', 'dwarf', 'elf'],
    'faze': ['abash', 'annoy', 'appall', 'awe', 'bother', 'confound', 'confuse', 'daunt', 'deter', 'discomfit', 'disconcert', 'discountenance'],
    'fbi': ['aec', 'atomic energy commission', 'bow street runner', 'cab', 'cia', 'central intelligence agency', 'cheka', 'civil aeronautics board', 'district of columbia', 'domestic council', 'eda', 'eeoc'],
    'fealty': ['acquiescence', 'adherence', 'adhesion', 'allegiance', 'ardor', 'assigned task', 'attachment', 'bona fides', 'bond', 'bonne foi', 'bounden duty', 'burden'],
    'fear': ['abulia', 'agitation', 'alarm', 'all-overs', 'angst', 'anticipate', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat'],
    'fear inspiring': ['abusive', 'alarming', 'awing', 'bludgeoning', 'blustering', 'browbeating', 'bulldozing', 'bullying', 'chilling', 'comminatory', 'daunting', 'denunciatory'],
    'fearful': ['aflutter', 'afraid', 'aghast', 'agitated', 'alarmed', 'alarming', 'all nerves', 'all-overish', 'anxious', 'anxioused up', 'appalling', 'apprehensive'],
    'fearless': ['assured', 'audacious', 'aweless', 'bold', 'brave', 'chivalrous', 'confident', 'courageous', 'daring', 'dauntless', 'dreadless', 'gallant'],
    'fearsome': ['alarming', 'appalling', 'awe-inspiring', 'awesome', 'awing', 'bashful', 'chilling', 'cowardly', 'daunting', 'deterrent', 'deterring', 'diffident'],
    'feasibility': ['achievability', 'actability', 'adaptability', 'advantage', 'advantageousness', 'advisability', 'applicability', 'appropriateness', 'attainability', 'beneficialness', 'compassability', 'convenience'],
    'feasible': ['achievable', 'actable', 'adaptable', 'advantageous', 'advisable', 'applicable', 'appropriate', 'attainable', 'banausic', 'becoming', 'befitting', 'beneficial'],
    'feast': ['high holiday', 'high holy day', 'lucullan feast', 'mardi gras', 'sabbath', 'saturnalia', 'sunday', 'allay', 'anniversary', 'appease', 'assuage', 'bank holiday'],
    'feat': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adventure', 'aristeia', 'attainment', 'blow', 'bold stroke', 'conquest'],
    'feather': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'air', 'bagatelle', 'bank', 'bauble', 'bead', 'bean', 'bejewel'],
    'feather bed': ['blubber', 'breeze', 'butter', 'clay', 'cushion', 'dough', 'down', 'eiderdown', 'feathers', 'fleece', 'floss', 'flue'],
    'featherbedding': ['bedizenment', 'duplication', 'duplication of effort', 'embellishment', 'expletive', 'extravagance', 'fat', 'filling', 'frill', 'frills', 'frippery', 'gingerbread'],
    'featherbrained': ['birdbrained', 'birdwitted', 'brainless', 'capricious', 'dizzy', 'empty-headed', 'featherheaded', 'fickle', 'flighty', 'fluffy', 'fluttery', 'frivolous'],
    'feathered': ['adorned', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'decked out', 'decorated', 'embellished', 'festooned'],
    'featheredge': ['bank', 'board', 'border', 'bordure', 'brim', 'brink', 'brow', 'coast', 'cutting edge', 'edge', 'edge tool', 'flange'],
    'feathers': ['apparel', 'array', 'attire', 'bedizenment', 'clothes', 'clothing', 'costume', 'covert', 'drapery', 'dress', 'dressing', 'duds'],
    'featherweight': ['chinese boxer', 'bantam', 'bantamweight', 'banty', 'black belt', 'boxer', 'brown belt', 'bruiser', 'button', 'catchweight', 'chit', 'cluck'],
    'feathery': ['airy', 'bubbly', 'downy', 'ethereal', 'fleecy', 'flossy', 'fluffy', 'foamy', 'frothy', 'furry', 'fuzzy', 'gossamery'],
    'featly': ['ably', 'adeptly', 'adroitly', 'agile', 'agilely', 'aptly', 'artfully', 'artistically', 'brilliantly', 'capably', 'cleverly', 'competently'],
    'feature': ['cinemascope', 'cinerama', 'technicolor', 'western', 'act', 'adjunct', 'advertise', 'affection', 'air', 'angle', 'animated cartoon', 'appurtenance'],
    'featureless': ['abstract', 'amorphic', 'amorphous', 'anarchic', 'articulated', 'baggy', 'bare', 'barren', 'bland', 'blank', 'bleached', 'blobby'],
    'features': ['air', 'appearance', 'bearing', 'brow', 'carriage', 'cast', 'cast of countenance', 'color', 'complexion', 'configuration', 'contour', 'countenance'],
    'febrile': ['ablaze', 'afire', 'ardent', 'at fever pitch', 'boiling', 'boiling over', 'breathless', 'burning', 'burning with excitement', 'cordial', 'delirious', 'drunk'],
    'fecal': ['bad', 'bad-smelling', 'barfy', 'crappy', 'disgusting', 'dungy', 'excremental', 'excrementary', 'feculent', 'fetid', 'filthy', 'flyblown'],
    'feces': ['bm', 'alluvion', 'alluvium', 'ash', 'bowel movement', 'buffalo chips', 'ca-ca', 'cinder', 'clinker', 'coprolite', 'coprolith', 'cow chips'],
    'feckless': ['aimless', 'barren', 'bootless', 'carefree', 'careless', 'counterproductive', 'easygoing', 'effete', 'empty', 'etiolated', 'fatuitous', 'fatuous'],
    'feculence': ['bm', 'beastliness', 'bowel movement', 'buffalo chips', 'ca-ca', 'coprolite', 'coprolith', 'cow chips', 'cow flops', 'cow pats', 'crap', 'defecation'],
    'fecund': ['abundant', 'blooming', 'bountiful', 'breeding', 'bursting', 'bursting out', 'conceptive', 'conceptual', 'copious', 'creative', 'diffuse', 'diffusive'],
    'fecundate': ['cross-fertilize', 'cross-pollen', 'cross-pollinate', 'cross-pollinize', 'dress', 'enrich', 'fatten', 'fecundify', 'fertilize', 'fructify', 'get with child', 'get with young'],
    'fed': ['bow street runner', 'fbi', 'fbi agent', 'federal', 'g-man', 'mp', 'secret service', 'sherlock holmes', 't-man', 'agent', 'amanuensis', 'baggage agent'],
    'fed up': ['allayed', 'blase', 'cloyed', 'crammed', 'disgusted', 'dispirited', 'engorged', 'full', 'full of', 'glutted', 'good and tired', 'gorged'],
    'federal': ['g-man', 'mp', 'absolute', 'aristocratic', 'associative', 'authoritarian', 'autocratic', 'autonomous', 'bailiff', 'beadle', 'beagle', 'blending'],
    'federalese': ['varietyese', 'wall streetese', 'washingtonese', 'bunkum', 'business english', 'businessese', 'cinemese', 'collegese', 'commercialism', 'computerese', 'economese', 'gobbledygook'],
    'federalism': ['nazism', 'centralism', 'collectivism', 'communism', 'constitutionalism', 'democratism', 'fascism', 'feudalism', 'feudality', 'governmentalism', 'imperialism', 'monarchism'],
    'federalist': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'civic', 'civil', 'constitutional', 'democratic', 'despotic', 'dictatorial'],
    'federalistic': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'civic', 'civil', 'constitutional', 'democratic', 'despotic', 'dictatorial'],
    'federalize': ['affiliate', 'ally', 'associate', 'band together', 'be in cahoots', 'bunch', 'bunch up', 'cabal', 'cement a union', 'centralize', 'club', 'club together'],
    'federate': ['act in concert', 'act together', 'affiliate', 'ally', 'amalgamate', 'associate', 'band', 'band together', 'be in cahoots', 'be in league', 'bunch', 'bunch up'],
    'federated': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'cabalistic', 'confederate', 'confederated', 'conspiratorial', 'corporate', 'coupled', 'enleagued'],
    'federation': ['anschluss', 'bund', 'rochdale cooperative', 'absolute monarchy', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alignment', 'alliance', 'amalgamation'],
    'fee': ['trinkgeld', 'account', 'admission', 'admission fee', 'allowance', 'anchorage', 'assessment', 'bill', 'blackmail', 'blood money', 'bonus', 'bounty'],
    'fee position': ['adverse possession', 'alodium', 'burgage', 'claim', 'colony', 'de facto', 'de jure', 'dependency', 'derivative title', 'fee fief', 'fee simple', 'fee simple absolute'],
    'fee simple': ['adverse possession', 'alodium', 'burgage', 'claim', 'colony', 'copyhold', 'de facto', 'de jure', 'dependency', 'derivative title', 'equitable estate', 'estate at sufferance'],
    'feeble': ['abulic', 'afraid', 'aged', 'ailing', 'anemic', 'anile', 'asthenic', 'backward', 'barely audible', 'blear', 'bleared', 'bleary'],
    'feeble-minded': ['boneheaded', 'deficient', 'dim-witted', 'dull-witted', 'dumb', 'empty-headed', 'exceptional', 'idiotic', 'imbecilic', 'mentally defective', 'moronic', 'retarded'],
    'feed': ['abet', 'aid and abet', 'allay', 'appease', 'ask for', 'assuage', 'bank', 'banquet', 'barley', 'bed', 'bed down', 'bird seed'],
    'feed on': ['batten on', 'batten upon', 'browse', 'consume', 'crop', 'devour', 'eat', 'fatten on', 'fatten upon', 'feast on', 'feast upon', 'graze'],
    'feedback': ['birdies', 'blooping', 'blurping', 'closed loop', 'closed sequence', 'current-control circuit', 'degeneration', 'distortion', 'flip-flop circuit', 'flutter', 'fluttering', 'hissing'],
    'feeder': ['brillat-savarin', 'lucullus', 'roscius', 'actor', 'actress', 'affluent', 'antagonist', 'antihero', 'bad guy', 'barnstormer', 'bayou', 'billabong'],
    'feel': ['abide', 'air', 'ambience', 'appear', 'appear like', 'appreciation', 'appreciation of differences', 'appreciativeness', 'apprehend', 'art', 'artistic judgment', 'assume'],
    'feel for': ['ache', 'be sorry for', 'beat about', 'bleed', 'bleed for', 'commiserate', 'compassionate', 'condole with', 'feel around', 'feel sorrow for', 'feel sorry for', 'fumble'],
    'feeler': ['advance', 'antenna', 'approach', 'asking price', 'barb', 'barbel', 'barbule', 'barometer', 'bid', 'bone of contention', 'cat whisker', 'catechism'],
    'feeling': ['action', 'affect', 'affection', 'affectional', 'affective', 'affectivity', 'air', 'ambiance', 'ambience', 'analog process', 'analytic', 'appreciation'],
    'feeling for': ['a thing for', 'affinity', 'aptitude', 'aptness', 'bent', 'bias', 'cast', 'conatus', 'conduciveness', 'delight', 'diathesis', 'disposition'],
    'feeling out': ['acid test', 'assay', 'blank determination', 'brouillon', 'criterion', 'crucial test', 'crucible', 'determination', 'docimasy', 'essay', 'first draft', 'kiteflying'],
    'feign': ['act', 'act a part', 'affect', 'assume', 'bluff', 'counterfeit', 'cover up', 'dissemble', 'dissimulate', 'do a bit', 'dramatize', 'fake'],
    'feigned': ['affected', 'apocryphal', 'artificial', 'assumed', 'bastard', 'bogus', 'brummagem', 'colorable', 'colored', 'counterfeit', 'counterfeited', 'distorted'],
    'feint': ['acting', 'aerial tactics', 'affectation', 'airborne tactics', 'alibi', 'apology', 'appearance', 'applied tactics', 'armored tactics', 'art', 'artful dodge', 'artifice'],
    'feisty': ['bearish', 'bitchy', 'cankered', 'cantankerous', 'churlish', 'crabbed', 'cranky', 'cross', 'cross-grained', 'crusty', 'cussed', 'disagreeable'],
    'felicitous': ['ciceronian', 'demosthenian', 'demosthenic', 'tullian', 'a propos', 'ad rem', 'adapted', 'advantageous', 'advisable', 'affable', 'agreeable', 'amiable'],
    'felicity': ['atticism', 'easy street', 'admissibility', 'affluence', 'an ear for', 'an eye for', 'applicability', 'appositeness', 'appropriateness', 'aptitude', 'aptness', 'articulateness'],
    'feline': ['cheshire cat', 'chinchilla cat', 'machiavellian', 'machiavellic', 'maltese cat', 'acute', 'alley cat', 'amphibian', 'aquatic', 'arch', 'artful', 'astute'],
    'fell': ['draconian', 'leatherette', 'leatheroid', 'tartarean', 'align', 'alkali flat', 'alluvial plain', 'animal', 'anthill', 'anthropophagous', 'appalling', 'astounding'],
    'fellow': ['adamite', 'casanova', 'don juan', 'greek', 'lothario', 'romeo', 'abecedarian', 'accessory', 'accompanier', 'accompanist', 'accompanying', 'accompanyist'],
    'fellow feeling': ['accord', 'accordance', 'affectionateness', 'affinity', 'agape', 'agreement', 'amity', 'an in', 'benignancy', 'benignity', 'bipartisanship', 'bonds of harmony'],
    'fellow traveler': ['bolshevik', 'bolshevist', 'castroite', 'communist', 'communist sympathizer', 'leninist', 'maoist', 'marxist', 'marxist-leninist', 'red', 'stalinist', 'titoist'],
    'fellowman': ['acquaintance', 'advocate', 'alter ego', 'backer', 'best friend', 'bosom friend', 'brother', 'casual acquaintance', 'close acquaintance', 'close friend', 'confidant', 'confidante'],
    'fellowship': ['accord', 'accordance', 'affability', 'affiliation', 'affinity', 'agape', 'agreement', 'aid', 'alignment', 'alimony', 'alliance', 'allotment'],
    'felon': ['judas', 'abscess', 'aposteme', 'bad person', 'bed sore', 'betrayer', 'blain', 'bleb', 'blister', 'boil', 'bubo', 'bulla'],
    'felonious': ['actionable', 'against the law', 'amoral', 'anarchic', 'anarchistic', 'anomic', 'black-market', 'bootleg', 'chargeable', 'conscienceless', 'contraband', 'contrary to law'],
    'felony': ['atrocity', 'breach', 'crime', 'crime against humanity', 'deadly sin', 'delict', 'delinquency', 'dereliction', 'enormity', 'error', 'evil', 'failure'],
    'felt': ['cloth', 'drapery', 'etoffe', 'fabric', 'goods', 'lace', 'material', 'napery', 'rag', 'silk', 'stuff', 'textile'],
    'female': ['distaff', 'female being', 'feminine', 'gentlewomanlike', 'girlish', 'gynecic', 'gynecoid', 'gynic', 'her', 'kittenish', 'ladylike', 'little-girlish'],
    'female organs': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'feminine': ['affected', 'amenable', 'animate', 'common gender', 'deferential', 'delicate', 'distaff', 'docile', 'effeminate', 'effete', 'female', 'gender'],
    'femininity': ['distaff side', 'fair sex', 'female sex', 'femaleness', 'gender', 'maleness', 'masculinity', 'second sex', 'sex', 'softer sex', 'weaker sex', 'weaker vessel'],
    'femme fatale': ['aspasia', 'circe', 'delilah', 'don juan', 'jezebel', 'lorelei', 'messalina', 'parthenope', 'phryne', 'siren', 'thais', 'adventuress'],
    'fence': ['abatis', 'about the bush', 'advanced work', 'arch dam', 'arm', 'armor', 'armor-plate', 'around the bush', 'avoid', 'backstop', 'baffle', 'balistraria'],
    'fence in': ['beleaguer', 'beset', 'besiege', 'blockade', 'bottle up', 'bound', 'box in', 'box up', 'cage', 'chamber', 'check', 'cloister'],
    'fencing': ['bickering', 'boggling', 'captiousness', 'caviling', 'chicane', 'chicanery', 'dodging', 'equivocation', 'evasion', 'hairsplitting', 'hedging', 'logic-chopping'],
    'fend': ['anticipate', 'arm', 'armor', 'avert', 'bar', 'beat off', 'bless', 'block', 'bulwark', 'champion', 'check', 'cloak'],
    'fend off': ['anticipate', 'avert', 'avoid', 'bar', 'beat back', 'beat off', 'block', 'brush off', 'chase', 'chase away', 'chase off', 'check'],
    'fender': ['aegis', 'arm guard', 'backstop', 'barrier', 'brattice', 'buffer', 'buffer state', 'bulkhead', 'bulwark', 'bumper', 'chimney', 'chimney corner'],
    'fenestra': ['aperture', 'broaching', 'cavity', 'chasm', 'check', 'clearing', 'cleft', 'crack', 'disclosure', 'fistula', 'fontanel', 'foramen'],
    'feral': ['draconian', 'tartarean', 'abandoned', 'amok', 'animal', 'anthropophagous', 'atrocious', 'baneful', 'barbaric', 'barbarous', 'beastly', 'bellowing'],
    'ferment': ['acetification', 'acetify', 'acidification', 'acidify', 'acidulate', 'acidulation', 'ado', 'agent', 'agitate', 'agitation', 'ailment', 'alkalify'],
    'fermentation': ['acescence', 'acetification', 'acidification', 'acidulation', 'ado', 'agitation', 'alkalization', 'bluster', 'bobbery', 'boil', 'boiling', 'brouhaha'],
    'fern': ['calamites', 'cycadofilicales', 'filicales', 'selaginellaceae', 'sigillaria', 'algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'calamite', 'climber'],
    'ferocious': ['draconian', 'tartarean', 'abandoned', 'aggressive', 'amok', 'animal', 'antagonistic', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'battling'],
    'ferociously': ['atrociously', 'barbarously', 'bec et ongles', 'bestially', 'brutally', 'brutishly', 'cruelly', 'devilishly', 'diabolically', 'ferally', 'fiendishly', 'fiercely'],
    'ferocity': ['aggression', 'aggressiveness', 'animality', 'antagonism', 'atrociousness', 'barbarity', 'barbarousness', 'beastliness', 'bellicism', 'bellicosity', 'belligerence', 'belligerency'],
    'ferret': ['argus', 'cape polecat', 'ape', 'bar', 'bear', 'cat', 'cavy', 'chimp', 'chimpanzee', 'coon', 'eagle', 'foumart'],
    'ferret out': ['ascertain', 'bring to light', 'cast about', 'chase', 'determine', 'dig out', 'dig up', 'disclose', 'discover', 'disinter', 'elicit', 'excavate'],
    'ferry': ['access', 'aeroplane', 'airlift', 'airplane', 'aisle', 'alley', 'almadia', 'ambulatory', 'aperture', 'arcade', 'ark', 'artery'],
    'ferryman': ['bargee', 'bargeman', 'barger', 'boat-handler', 'boater', 'boatman', 'boatsman', 'ferrier', 'galley slave', 'gondolier', 'lighterman', 'oar'],
    'fertile': ['abounding', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'blooming', 'bottomless', 'bounteous', 'bountiful', 'bursting', 'bursting out'],
    'fertility': ['abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bonanza', 'bountifulness', 'bountiousness', 'bumper crop', 'cloud of words', 'copiousness'],
    'fertility god': ['ashtoreth', 'astarte', 'baal', 'cailleac', 'ceres', 'cora', 'demeter', 'dionysos', 'dionysus', 'faunus', 'flora', 'frey'],
    'fertilize': ['backset', 'compost', 'cross-fertilize', 'cross-pollen', 'cross-pollinate', 'cross-pollinize', 'cultivate', 'culture', 'cut', 'delve', 'dig', 'dress'],
    'fervent': ['abandoned', 'ablaze', 'afire', 'animated', 'ardent', 'assiduous', 'blazing', 'boiling', 'boiling over', 'breathless', 'burning', 'burning with excitement'],
    'fervently': ['ardently', 'assiduously', 'breathlessly', 'cordially', 'devotedly', 'devoutly', 'diligently', 'earnestly', 'effectively', 'eloquently', 'energetically', 'enthusiastically'],
    'fervid': ['abandoned', 'ablaze', 'afire', 'ardent', 'athirst', 'blazing', 'boiling', 'boiling over', 'breathless', 'burning', 'burning with excitement', 'committed'],
    'fervidly': ['ardently', 'breathlessly', 'cordially', 'devotedly', 'devoutly', 'earnestly', 'enthusiastically', 'excitedly', 'exuberantly', 'fervently', 'feverishly', 'glowingly'],
    'fervor': ['amor', 'christian love', 'eros', 'platonic love', 'abandon', 'admiration', 'adoration', 'affection', 'agape', 'anger', 'animation', 'application'],
    'festal': ['comfortable', 'convivial', 'festive', 'gala', 'gay', 'gladsome', 'hilarious', 'holiday', 'jolly', 'jovial', 'joyful', 'joyous'],
    'fester': ['abscess', 'afflict', 'agonize', 'ail', 'aposteme', 'bed sore', 'bite', 'blain', 'bleb', 'blister', 'boil', 'break up'],
    'festering': ['abscess', 'adulteration', 'algesia', 'algetic', 'angry', 'aposteme', 'bad', 'bed sore', 'befouling', 'blain', 'bleb', 'blister'],
    'festival': ['mardi gras', 'saturnalia', 'anniversary', 'banquet', 'birthday', 'blowout', 'carnival', 'celebration', 'commemoration', 'do', 'entertainment', 'fair'],
    'festive': ['blithe', 'blithesome', 'boon', 'convivial', 'festal', 'free and easy', 'gala', 'gay', 'gladsome', 'gleeful', 'hail-fellow-well-met', 'hearty'],
    'festive occasion': ['mardi gras', 'saturnalia', 'banquet', 'blowout', 'carnival', 'do', 'fair', 'feast', 'festival', 'festivity', 'fete', 'field day'],
    'festivity': ['kaffeeklatsch', 'mardi gras', 'saturnalia', 'amusement', 'anniversaries', 'assemblee', 'assembly', 'assignation', 'at home', 'ball', 'banquet', 'blowout'],
    'festoon': ['arc', 'boughpot', 'bouquet', 'boutonniere', 'bow', 'bravery', 'buttonhole', 'catacaustic', 'catenary', 'caustic', 'chaplet', 'chiffon'],
    'festooned': ['adorned', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'colored', 'decked out', 'decorated', 'embellished'],
    'fetal': ['abecedarian', 'aboriginal', 'antenatal', 'autochthonous', 'beginning', 'budding', 'creative', 'elemental', 'elementary', 'embryonic', 'formative', 'foundational'],
    'fetch': ['doppelganger', 'accomplish', 'achieve', 'afford', 'amount to', 'appeal', 'approach', 'approach anchorage', 'arrive', 'arrive at', 'arrive in', 'art'],
    'fetch up': ['accomplish', 'achieve', 'apprentice', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be received', 'blow in', 'bob up'],
    'fetching': ['circean', 'alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching', 'charismatic'],
    'fete': ['mardi gras', 'saturnalia', 'assemblee', 'assembly', 'assignation', 'at home', 'ball', 'banquet', 'blowout', 'brawl', 'carnival', 'caucus'],
    'fetid': ['abhorrent', 'abominable', 'arrant', 'atrocious', 'awful', 'bad', 'bad-smelling', 'barfy', 'base', 'beastly', 'below contempt', 'beneath contempt'],
    'fetish': ['baal', 'juggernaut', 'amulet', 'bias', 'charm', 'compulsion', 'devil-god', 'fixation', 'fylfot', 'gammadion', 'golden calf', 'good-luck charm'],
    'fetishism': ['druidism', 'parsiism', 'sabaism', 'zoroastrianism', 'active algolagnia', 'alchemy', 'algolagnia', 'algolagny', 'amphierotism', 'animal worship', 'autoeroticism', 'bewitchery'],
    'fetlock': ['arch', 'bang', 'bangs', 'clubfoot', 'digit', 'dog', 'extremity', 'fleck', 'flock', 'foot', 'forefoot', 'forelock'],
    'fetter': ['oregon boat', 'anchor', 'arrest', 'bearing rein', 'bilbo', 'bind', 'bit', 'bond', 'bonds', 'brake', 'bridle', 'burden'],
    'feud': ['acrimony', 'adverse possession', 'alodium', 'altercate', 'altercation', 'animosity', 'animus', 'antagonism', 'argument', 'avengement', 'bad blood', 'battle'],
    'feudal': ['absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'authoritarian', 'authoritative', 'autocratic', 'bossy', 'client', 'dependent'],
    'feudal system': ['absolute monarchy', 'aristocracy', 'autarchy', 'autocracy', 'autonomy', 'coalition government', 'colonialism', 'commonwealth', 'constitutional government', 'constitutional monarchy', 'democracy', 'dictatorship'],
    'feudalism': ['nazism', 'absolutism', 'bond service', 'bondage', 'captivity', 'centralism', 'collectivism', 'communism', 'constitutionalism', 'control', 'debt slavery', 'democratism'],
    'fever': ['abscess', 'agitation', 'ague', 'amok', 'anemia', 'animal heat', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia'],
    'feverish': ['ablaze', 'afire', 'agitated', 'ardent', 'at fever pitch', 'baking', 'blistering', 'boiling', 'boiling over', 'breathless', 'broiling', 'burning'],
    'few': ['cursory', 'depthless', 'footling', 'handful', 'hardly any', 'inconsequential', 'inconsiderable', 'insignificant', 'least', 'little', 'littlest', 'low'],
    'fey': ['abnormal', 'anomalous', 'arcane', 'crank', 'crankish', 'cranky', 'crotchety', 'deviant', 'deviative', 'different', 'divergent', 'dotty'],
    'fiasco': ['abortion', 'bafflement', 'balk', 'betrayed hope', 'blasted expectation', 'blighted hope', 'blow', 'bollix', 'botch', 'buffet', 'bungle', 'comedown'],
    'fiat': ['appointment', 'authority', 'authorization', 'brevet', 'bull', 'certification', 'clearance', 'countenance', 'declaration', 'decree', 'decree-law', 'decreement'],
    'fib': ['be untruthful', 'blague', 'bouncer', 'canard', 'cock-and-bull story', 'concoct', 'deceive', 'draw the longbow', 'equivocate', 'equivocation', 'evasiveness', 'exaggerate'],
    'fiber': ['aralac', 'avisco', 'celanese', 'chemstrand', 'dacron', 'dynel', 'lastex', 'manila', 'orlon', 'terylene', 'velon', 'vicara'],
    'fibre': ['cast', 'character', 'composition', 'constitution', 'essence', 'fabric', 'filament', 'material', 'mould', 'nature', 'quality', 'strand'],
    'fibrillation': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'arrhythmia', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache'],
    'fibrous': ['capillary', 'cartilaginous', 'chewy', 'cirrose', 'cirrous', 'cohesive', 'coriaceous', 'durable', 'fibered', 'fibroid', 'flagelliform', 'flossy'],
    'fickle': ['adrift', 'afloat', 'agnostic', 'alternating', 'ambiguous', 'ambitendent', 'ambivalent', 'amorphous', 'at loose ends', 'brittle', 'capricious', 'chancy'],
    'fiction': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'anecdote', 'apologue', 'apparition', 'article', 'autograph', 'bedtime story'],
    'fictional': ['allegoric', 'chimerical', 'concocted', 'cooked-up', 'fabricated', 'fabulous', 'fancied', 'fanciful', 'fantasied', 'fantastic', 'fictitious', 'fictive'],
    'fictionalize': ['allegorize', 'coin', 'conceit', 'conceive', 'conceptualize', 'concoct', 'create', 'dream up', 'experience imaginatively', 'fable', 'fabricate', 'fabulize'],
    'fictitious': ['affected', 'apocryphal', 'artificial', 'assumed', 'bastard', 'bogus', 'brummagem', 'chimerical', 'colorable', 'colored', 'concocted', 'cooked-up'],
    'fiddle': ['a string', 'amati', 'cremona', 'd string', 'e string', 'g string', 'strad', 'stradivari', 'stradivarius', 'alter', 'bass', 'bass viol'],
    'fiddle faddle': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'blabber', 'blather', 'bombast', 'claptrap', 'coquet', 'dabble'],
    'fidelity': ['abandon', 'absoluteness', 'accuracy', 'adherence', 'adhesion', 'allegiance', 'application', 'ardency', 'ardor', 'assiduity', 'assiduousness', 'attachment'],
    'fidget': ['chafe', 'coquet', 'dabble', 'dally', 'dither', 'fiddle', 'fiddle with', 'fiddle-faddle', 'fidget with', 'fidgetiness', 'finger with', 'flip out'],
    'fidgets': ['agitation', 'apprehensiveness', 'attack of nerves', 'bluster', 'bobbery', 'boil', 'boiling', 'brouhaha', 'buck fever', 'bustle', 'case of nerves', 'churn'],
    'fidgety': ['agitated', 'all shook up', 'all-overish', 'bustling', 'convulsive', 'discomposed', 'disquieted', 'disturbed', 'eclamptic', 'excited', 'feverish', 'fidgeting'],
    'fiducial': ['balanced', 'convictional', 'cool', 'fast', 'fiduciary', 'firm', 'firm as gibraltar', 'imperturbable', 'in equilibrium', 'pistic', 'predictable', 'reliable'],
    'fiduciary': ['believable', 'colorable', 'conceivable', 'convictional', 'credible', 'depositary', 'depository', 'fiducial', 'held in pledge', 'held in trust', 'in escrow', 'in trust'],
    'fief': ['copyhold', 'equitable estate', 'estate at sufferance', 'estate for life', 'estate for years', 'estate in expectancy', 'estate in fee', 'estate in possession', 'estate tail', 'fee', 'fee simple', 'fee tail'],
    'fiefdom': ['adverse possession', 'alodium', 'burgage', 'claim', 'colony', 'de facto', 'de jure', 'dependency', 'derivative title', 'fee fief', 'fee position', 'fee simple'],
    'field': ['dmz', 'academic discipline', 'academic specialty', 'aceldama', 'achievement', 'acreage', 'aerodrome', 'agora', 'air base', 'airdrome', 'airfield', 'airport'],
    'field day': ['highland games', 'mardi gras', 'olympiad', 'olympic games', 'saturnalia', 'banquet', 'blowout', 'carnival', 'carousel', 'do', 'fair', 'feast'],
    'fiend': ['apollyon', 'baba yaga', 'beelzebub', 'lsd user', 'lilith', 'lucifer', 'mafioso', 'old nick', 'old scratch', 'satan', 'young turk', 'acidhead'],
    'fiendish': ['draconian', 'mephistophelian', 'tartarean', 'animal', 'anthropophagous', 'atrocious', 'bad', 'baleful', 'barbaric', 'barbarous', 'beastly', 'bestial'],
    'fierce': ['draconian', 'tartarean', 'abandoned', 'acid', 'acidulous', 'acrid', 'acrimonious', 'acute', 'aggressive', 'amok', 'angry', 'animal'],
    'fiery': ['titian', 'titian-red', 'abandoned', 'ablaze', 'accendible', 'afire', 'aflame', 'aglow', 'algetic', 'alight', 'angry', 'ardent'],
    'fiesta': ['mardi gras', 'saturnalia', 'banquet', 'blowout', 'carnival', 'do', 'fair', 'feast', 'festival', 'festive occasion', 'festivity', 'fete'],
    'fife': ['english horn', 'pandean pipe', 'aulos', 'bagpipe', 'basset horn', 'basset oboe', 'bassoon', 'blow', 'blow a horn', 'bombard', 'bugle', 'carillon'],
    'fifth': ['consecutive intervals', 'decimalization', 'decimation', 'degree', 'diapason', 'diatessaron', 'diatonic interval', 'diatonic semitone', 'enharmonic diesis', 'enharmonic interval', 'fivefold', 'fourth'],
    'fifth column': ['judas-like', 'trojan horse', 'trojan-horse', 'betraying', 'collaborationist', 'collaborator', 'crypto', 'double-crossing', 'fellow traveler', 'fifth columnist', 'fraternizer', 'quisling'],
    'fifth columnist': ['trojan horse', 'apostate', 'backslider', 'bolter', 'collaborationist', 'collaborator', 'convert', 'crypto', 'defector', 'deserter', 'fellow traveler', 'fifth column'],
    'fig': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'apparel', 'array', 'attire', 'bagatelle', 'bauble', 'bean', 'bedizenment'],
    'fig out': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'color', 'dandify', 'deck', 'deck out', 'decorate', 'dizen'],
    'fight': ['olympic games', 'olympics', 'a outrance', 'action', 'aerial combat', 'affray', 'against', 'aggression', 'aggressiveness', 'agonize', 'altercate', 'altercation'],
    'fight shy': ['avoid', 'blench', 'boggle', 'demur', 'falter', 'fight shy of', 'flinch', 'give place to', 'hang back', 'hang off', 'have qualms', 'hesitate'],
    'fighter': ['chinese boxer', 'bantamweight', 'battler', 'belligerent', 'belted knight', 'bickerer', 'black belt', 'blade', 'boxer', 'bravo', 'brawler', 'brown belt'],
    'fighting': ['chinese boxing', 'kilkenny cats', 'aggressive', 'all-out war', 'altercation', 'antagonistic', 'appeal to arms', 'argument', 'armed combat', 'armed conflict', 'attack', 'battle'],
    'fighting man': ['amazon', 'air serviceman', 'brave', 'cannon fodder', 'fighter', 'food for powder', 'halberdier', 'hoplite', 'legionary', 'man-at-arms', 'military man', 'navy man'],
    'figment': ['apparition', 'brainchild', 'bubble', 'canard', 'chimera', 'concoction', 'creation', 'daydream', 'delirium', 'dream', 'eidolon', 'extravaganza'],
    'figmental': ['concocted', 'cooked-up', 'fabricated', 'fabulous', 'fancied', 'fantasied', 'fantastic', 'fictional', 'fictitious', 'fictive', 'forged', 'hatched'],
    'figural': ['algorismic', 'algorithmic', 'aliquot', 'cardinal', 'connotative', 'decimal', 'demonstrative', 'denominative', 'denotative', 'designative', 'diagnostic', 'differential'],
    'figuration': ['platonic form', 'platonic idea', 'aesthetic form', 'alphabet', 'archetype', 'art', 'art form', 'blueprint', 'build', 'cast', 'charactering', 'characterization'],
    'figurative': ['adorned', 'algorismic', 'algorithmic', 'aliquot', 'allegoric', 'allegorical', 'allusive', 'anagogic', 'apish', 'associational', 'befrilled', 'cardinal'],
    'figure': ['aristotelian sorites', 'establishment', 'goclenian sorites', 'platonic body', 'platonic form', 'platonic idea', 'vip', 'accept', 'acclaim', 'acknowledge', 'act', 'acute-angled triangle'],
    'figure of speech': ['adornment', 'alliteration', 'allusion', 'anacoluthon', 'anadiplosis', 'analogy', 'anaphora', 'anastrophe', 'antiphrasis', 'antithesis', 'antonomasia', 'apophasis'],
    'figure out': ['add', 'algebraize', 'answer', 'bottom', 'calculate', 'cast', 'cipher', 'clear up', 'compute', 'crack', 'debug', 'decipher'],
    'figured': ['adorned', 'allusive', 'arranged', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'blueprinted', 'calculated'],
    'figurehead': ['charlie mccarthy', 'a nobody', 'a nothing', 'adherent', 'advocate', 'alter ego', 'alternate', 'amicus curiae', 'armory', 'attorney', 'backup', 'backup man'],
    'figurer': ['abacist', 'accountant', 'actuary', 'bookkeeper', 'calculator', 'carver', 'chaser', 'clay modeler', 'computer', 'earth artist', 'estimator', 'figuriste'],
    'figurine': ['bust', 'carving', 'doll', 'dolly', 'dummy', 'fantoccini', 'figure', 'figurehead', 'gingerbread man', 'lay figure', 'man of straw', 'manikin'],
    'filamentary': ['bristlelike', 'capillary', 'cirrose', 'cirrous', 'fibered', 'fibroid', 'fibrous', 'flagelliform', 'flossy', 'funicular', 'gossamery', 'hairlike'],
    'filch': ['abstract', 'and', 'annex', 'appropriate', 'bag', 'boost', 'borrow', 'cop', 'crib', 'defraud', 'embezzle', 'extort'],
    'file': ['indian file', 'kp', 'ablate', 'abrade', 'abrase', 'achievement', 'aculeate', 'acuminate', 'alerion', 'alphabetize', 'aluminum oxide', 'ammunition box'],
    'file away': ['abate', 'abrade', 'abstract', 'bank', 'bate', 'bundle away', 'cache', 'coffer', 'curtail', 'decrease', 'deduct', 'deposit'],
    'filed': ['assorted', 'booked', 'cadastral', 'cataloged', 'classified', 'documented', 'down', 'enrolled', 'entered', 'enumerated', 'graded', 'grouped'],
    'filial': ['adoring', 'affectionate', 'conjugal', 'daughterlike', 'daughterly', 'demonstrative', 'devoted', 'faithful', 'fond', 'husbandly', 'languishing', 'lovelorn'],
    'filiation': ['indian file', 'accord', 'addition', 'adjunct', 'affairs', 'affiliation', 'affinity', 'agnation', 'alliance', 'ancestry', 'apparentation', 'approximation'],
    'filibuster': ['address', 'after-dinner speech', 'allocution', 'be dilatory', 'chalk talk', 'cloture', 'committee consideration', 'constitute', 'debate', 'declamation', 'decree', 'deliberation'],
    'filigree': ['arabesque', 'basketry', 'basketwork', 'bead', 'bejewel', 'beribbon', 'bespangle', 'bonus', 'cancellation', 'cross-hatching', 'crossing-out', 'decoration'],
    'filing': ['ablation', 'abrasion', 'abrasive', 'analysis', 'arrangement', 'attrition', 'buffing', 'burnishing', 'cataloging', 'categorization', 'chafe', 'chafing'],
    'filing card': ['bulletin board', 'card', 'catalog card', 'disc', 'file', 'film', 'index card', 'library catalog', 'magnetic tape', 'microcard', 'microdot', 'microfiche'],
    'filing clerk': ['accountant', 'amanuensis', 'archivist', 'bookkeeper', 'clerk', 'documentalist', 'engraver', 'librarian', 'marker', 'notary', 'notary public', 'prothonotary'],
    'filings': ['afterglow', 'afterimage', 'air pollution', 'attritus', 'balance', 'bones', 'bran', 'butt', 'butt end', 'candle ends', 'chaff', 'cosmic dust'],
    'fill': ['abide by', 'accommodate', 'act up to', 'adhere to', 'admit', 'advise', 'afford', 'allay', 'answer', 'assimilate', 'attend to', 'bag'],
    'fill in': ['accomplish', 'acquaint', 'act for', 'admit', 'advise', 'alternate', 'apprise', 'assimilate', 'bring to completion', 'bring to fruition', 'change places with', 'clue'],
    'fill out': ['abide by', 'accomplish', 'add to', 'adhere to', 'administer', 'admit', 'aggrandize', 'amplify', 'assimilate', 'augment', 'balloon', 'bloat'],
    'fill the bill': ['advance', 'advantage', 'answer', 'avail', 'be ok', 'be equal to', 'be handy', 'be of use', 'be right', 'bear', 'befit', 'befitting'],
    'fill up': ['accommodate', 'afford', 'allay', 'atone', 'bar', 'bind', 'block', 'block up', 'blockade', 'brim', 'bung', 'bunker'],
    'filled': ['sro', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full', 'chuck-full', 'congested', 'cram-full', 'crammed', 'farci'],
    'filler': ['ic analysis', 'appositive', 'attribute', 'attributive', 'bidet', 'bush', 'bushing', 'carriage horse', 'cart horse', 'cavalry horse', 'complement', 'construction modifier'],
    'fillet': ['mystik tape', 'scotch tape', 'adhesive tape', 'anklet', 'armlet', 'band', 'bandage', 'bandeau', 'batten', 'belt', 'bracelet', 'cellophane tape'],
    'filling': ['battology', 'bedizenment', 'bonus', 'bush', 'bushing', 'cloying', 'cloysome', 'complemental', 'complementary', 'completing', 'completive', 'completory'],
    'fillip': ['animate', 'bait', 'beak', 'bonus', 'bribe', 'brush', 'bunt', 'carrot', 'chuck', 'dab', 'decoration', 'encouragement'],
    'filly': ['houyhnhnm', 'partlet', 'babe', 'baby', 'biddy', 'bitch', 'bossy', 'broad', 'brood mare', 'charger', 'chick', 'colleen'],
    'film': ['cinemascope', 'cinerama', 'london fog', 'london special', 'photostat', 'rabelaisianism', 'technicolor', 'western', 'x-rated movie', 'x-ray', 'xerox', 'actor-proof'],
    'filmy': ['attenuate', 'attenuated', 'beclouded', 'blear', 'bleared', 'bleary', 'blurred', 'blurry', 'clear', 'clear as crystal', 'clouded', 'cloudy'],
    'filter': ['bleed', 'bolt', 'butterfly', 'cheesecloth', 'clarifier', 'clarify', 'clean', 'clear', 'cloth', 'colander', 'condense', 'cradle'],
    'filter in': ['absorb', 'adsorb', 'assimilate', 'blot', 'blot up', 'chemisorb', 'chemosorb', 'digest', 'drink', 'drink in', 'drink up', 'engross'],
    'filtering': ['bolting', 'clarification', 'colature', 'destructive distillation', 'distillation', 'edulcoration', 'effusion', 'elution', 'elutriation', 'essentialization', 'excretion', 'exfiltration'],
    'filth': ['rabelaisianism', 'x-rated movie', 'abominableness', 'adulteration', 'atrociousness', 'awfulness', 'bad language', 'baseness', 'bawdiness', 'bawdry', 'beastliness', 'besmirchment'],
    'filthy': ['fescennine', 'rabelaisian', 'abominable', 'arrant', 'atrocious', 'awful', 'barfy', 'base', 'bawdy', 'beastly', 'bedraggled', 'beneath contempt'],
    'filtration': ['bolting', 'clarification', 'colature', 'destructive distillation', 'distillation', 'edulcoration', 'effusion', 'elution', 'elutriation', 'essentialization', 'excretion', 'exfiltration'],
    'fin': ['australian crawl', 'c-note', 'g-note', 'little phoebe', 'pentateuch', 'phoebe', 'aquaplaning', 'aquatics', 'backstroke', 'balneation', 'bathe', 'bathing'],
    'finagle': ['angle', 'beat', 'beguile of', 'bilk', 'brew', 'bunco', 'burn', 'cabal', 'cheat', 'chisel', 'chouse', 'chouse out of'],
    'finagler': ['machiavellian', 'behind-the-scenes operator', 'coconspirator', 'conniver', 'conspirator', 'conspirer', 'counterplotter', 'eminence grise', 'exploiter', 'gamesman', 'gray eminence', 'intrigant'],
    'final': ['absolute', 'adducible', 'admissible', 'admitting no exception', 'all-out', 'attestative', 'attestive', 'audition', 'authentic', 'based on', 'binding', 'blue book'],
    'final stroke': ['ko', 'capstone', 'climax', 'clincher', 'copestone', 'crown', 'crusher', 'death stroke', 'deathblow', 'end-all', 'ender', 'final touch'],
    'finale': ['act', 'afterpiece', 'apodosis', 'bit', 'bitter end', 'catastrophe', 'ceasing', 'cessation', 'chaser', 'climax', 'close', 'coda'],
    'finality': ['apodosis', 'catastrophe', 'ceasing', 'certainty', 'certitude', 'cessation', 'coda', 'conclusion', 'consummation', 'crack of doom', 'culmination', 'curtain'],
    'finalize': ['ko', 'button up', 'call off', 'cancel', 'cap', 'carry to completion', 'clean up', 'climax', 'clinch', 'close out', 'close up', 'complete'],
    'finally': ['absolutely', 'accordingly', 'and so', 'as a consequence', 'as a result', 'as things go', 'as times go', 'at last', 'at length', 'at long last', 'at the end', 'at the last'],
    'finance': ['accounting', 'acknowledge', 'afford support', 'aid', 'angel', 'assets', 'assist', 'back', 'bank', 'banking', 'bankroll', 'bear'],
    'financer': ['maecenas', 'santa claus', 'almoner', 'almsgiver', 'angel', 'assignor', 'awarder', 'backer', 'bestower', 'cheerful giver', 'conferrer', 'consignor'],
    'finances': ['lombard street', 'swiss bank account', 'wall street banking', 'assets', 'balance', 'bank account', 'bottom dollar', 'budget', 'cash reserves', 'checking account', 'command of money', 'economics'],
    'financier': ['wall streeter', 'angel', 'backer', 'banker', 'baron', 'big boss', 'big businessman', 'business leader', 'businessman', 'capitalist', 'captain of industry', 'director'],
    'financing': ['backing', 'borrowing', 'capitalization', 'debt', 'debtor', 'deficit financing', 'financial backing', 'financial support', 'funding', 'grubstake', 'hire purchase', 'hitting'],
    'find': ['accommodate', 'accomplish', 'achieve', 'acquire', 'act on', 'afford', 'allot', 'approach', 'arouse', 'arrive', 'arrive at', 'arrive in'],
    'find out': ['answer', 'ascertain', 'assure', 'be informed', 'become acquainted with', 'bottom', 'broaden the mind', 'catch on', 'certify', 'cinch', 'clear up', 'clinch'],
    'finding': ['accomplishment', 'accouterment', 'action', 'answer', 'armament', 'ascertainment', 'award', 'bonus', 'bringing to light', 'buried treasure', 'casual discovery', 'catching'],
    'fine': ['babylonian', 'corinthian', 'ok', 'roger', 'absolutely', 'abstruse', 'accomplished', 'accurate', 'acrid', 'acute', 'admirable', 'adulterated'],
    'fine and dandy': ['ok', 'ace-high', 'bad', 'bang-up', 'bonzer', 'boss', 'bully', 'but good', 'cool', 'corking', 'crackerjack', 'dandy'],
    'fine arts': ['abstract art', 'art', 'art form', 'artist', 'arts and crafts', 'arts of design', 'calligraphy', 'cave art', 'ceramics', 'decoration', 'design', 'designing'],
    'fine drawn': ['airy', 'attenuate', 'attenuated', 'boyish', 'dainty', 'delicate', 'diaphanous', 'diluted', 'downy', 'ethereal', 'filmy', 'fine'],
    'fine fettle': ['anality', 'apple-pie order', 'discipline', 'eupepsia', 'fine shape', 'fine whack', 'glowing health', 'good condition', 'good constitution', 'good digestion', 'good health', 'good shape'],
    'fine grained': ['attenuate', 'attenuated', 'dainty', 'delicate', 'downy', 'filmy', 'fine', 'fine-drawn', 'finespun', 'fluffy', 'fuzzy', 'gauzy'],
    'fine print': ['boundary condition', 'catch', 'clause', 'condition', 'donnee', 'escalator clause', 'escape clause', 'escape hatch', 'given', 'grounds', 'joker', 'kicker'],
    'fine spoken': ['adulatory', 'bland', 'blandishing', 'blarneying', 'buttery', 'cajoling', 'complimentary', 'courtierly', 'courtly', 'disarming', 'fair-spoken', 'fawning'],
    'fine writing': ['adornment', 'beauties', 'calligraphy', 'colors', 'colors of rhetoric', 'copybook hand', 'elegant penmanship', 'elegant variation', 'embellishment', 'embroidery', 'fair hand', 'figure'],
    'finer': ['a cut above', 'above', 'ahead', 'ascendant', 'better', 'capping', 'chosen', 'distinguished', 'eclipsing', 'eminent', 'exceeding', 'excellent'],
    'finery': ['sunday best', 'apparel', 'bravery', 'chiffon', 'clinquant', 'clothes', 'decorations', 'fancy dress', 'festoons', 'folderol', 'foofaraw', 'frill'],
    'finespun': ['airy', 'attenuate', 'attenuated', 'boyish', 'dainty', 'delicate', 'diaphanous', 'diluted', 'downy', 'ethereal', 'filmy', 'fine'],
    'finesse': ['italian hand', 'ability', 'acquired taste', 'acuteness', 'address', 'adeptness', 'adroitness', 'airmanship', 'angle', 'appreciation', 'appreciation of differences', 'appreciation of excellence'],
    'finger': ['accuse', 'acquire', 'advert to', 'allege', 'allude to', 'annulary', 'appoint', 'arraign', 'article', 'be master of', 'be taken as', 'bear witness'],
    'finger bowl': ['aquamanile', 'automatic dishwasher', 'basin', 'bath', 'bathtub', 'bidet', 'dishpan', 'dishwasher', 'ewer', 'kitchen sink', 'lavabo', 'lavatory'],
    'finger painting': ['acrylic painting', 'aquarelle', 'canvas', 'coloring', 'easel-picture', 'encaustic cerography', 'encaustic painting', 'flower painting', 'fresco painting', 'genre painting', 'gouache', 'grisaille'],
    'fingerboard': ['a string', 'amati', 'cremona', 'd string', 'e string', 'g string', 'strad', 'stradivari', 'stradivarius', 'bass', 'bass viol', 'bow'],
    'fingering': ['cantando', 'caressing', 'characterization', 'demilegato', 'denomination', 'denotation', 'designation', 'differentiation', 'disclosure', 'execution', 'expression', 'feeling'],
    'fingernails': ['claws', 'clutches', 'digits', 'fangs', 'fingers', 'hands', 'hooks', 'jaws', 'mandibles', 'maxillae', 'meathooks', 'mitts'],
    'fingerprint': ['boss', 'bump', 'colophon', 'concavity', 'convexity', 'dactylogram', 'dactylograph', 'dent', 'dint', 'embossment', 'excrescence', 'footmark'],
    'fini': ['sol', 'all bets off', 'all off', 'all over', 'all up', 'at an end', 'canceled', 'complete', 'concluded', 'dead', 'decided', 'defunct'],
    'finicky': ['accurate', 'advertent', 'agog', 'alert', 'all ears', 'all eyes', 'assiduous', 'attentive', 'aware', 'careful', 'choosy', 'close'],
    'finis': ['apodosis', 'catastrophe', 'ceasing', 'cessation', 'coda', 'conclusion', 'consummation', 'crack of doom', 'culmination', 'curtain', 'curtains', 'death'],
    'finish': ['atticism', 'ko', 'ablate', 'abort', 'absoluteness', 'absorb', 'accomplish', 'accomplishment', 'achieve', 'achievement', 'acquirement', 'acquisition'],
    'finished': ['attic', 'ciceronian', 'sol', 'ablated', 'accomplished', 'ago', 'all bets off', 'all off', 'all over', 'all up', 'antiquated', 'antique'],
    'finisher': ['ko', 'capstone', 'climax', 'clincher', 'conclusive argument', 'copestone', 'crown', 'crusher', 'cutter', 'death stroke', 'deathblow', 'end-all'],
    'finishing': ['ablation', 'absorption', 'assimilation', 'attrition', 'burning up', 'capping', 'close', 'closing', 'completing', 'completion', 'completive', 'completory'],
    'finite': ['adamite', 'adamitic', 'algorismic', 'algorithmic', 'aliquot', 'anthropocentric', 'anthropological', 'bound', 'bounded', 'cardinal', 'conditioned', 'confined'],
    'finitude': ['caducity', 'changeableness', 'corruptibility', 'death', 'ephemerality', 'ephemeralness', 'evanescence', 'fleetingness', 'fugacity', 'impermanence', 'impermanency', 'instability'],
    'fink': ['bear witness against', 'betray', 'betrayer', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'blackleg', 'blow the whistle', 'canary', 'delator', 'inform against'],
    'fiord': ['arm', 'armlet', 'bay', 'bayou', 'belt', 'bight', 'boca', 'cove', 'creek', 'estuary', 'euripus', 'fjord'],
    'fire': ['abandon', 'afflatus', 'afire', 'aflame', 'aggressiveness', 'agitate', 'aim at', 'air', 'air-dry', 'alight', 'anhydrate', 'animate'],
    'fire bell': ['klaxon', 'mayday', 'sos', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert', 'all clear', 'beacon'],
    'fire eater': ['mafioso', 'tartar', 'young turk', 'adventurer', 'adventuress', 'bear', 'beast', 'beldam', 'berserk', 'berserker', 'bomber', 'brazenface'],
    'fire escape': ['back stairs', 'bolt-hole', 'companion', 'companionway', 'ejection seat', 'emergency exit', 'escalier', 'escape hatch', 'flight of steps', 'incline', 'inflatable slide', 'landing'],
    'fire extinguisher': ['foamite', 'acid', 'automatic sprinkler', 'carbon tet', 'carbon tetrachloride', 'carbon-dioxide foam', 'deck gun', 'deluge set', 'extinguisher', 'fire apparatus', 'fire engine', 'fire hose'],
    'fire hydrant': ['foamite', 'acid', 'automatic sprinkler', 'carbon tet', 'carbon tetrachloride', 'carbon-dioxide foam', 'deck gun', 'deluge set', 'extinguisher', 'fire apparatus', 'fire engine', 'fire hose'],
    'fire tactics': ['aerial tactics', 'airborne tactics', 'applied tactics', 'armored tactics', 'barrier tactics', 'cavalry tactics', 'defensive strategy', 'diversion', 'encirclement', 'feint', 'infantry tactics', 'infiltration'],
    'fire worship': ['druidism', 'parsiism', 'sabaism', 'zoroastrianism', 'animal worship', 'arson', 'demonism', 'demonolatry', 'devil worship', 'fetishism', 'fire-raising', 'heathenism'],
    'firearm': ['automatic', 'blowgun', 'blowpipe', 'flamethrower', 'gat', 'gun', 'handgun', 'heater', 'musket', 'peashooter', 'piece', 'pistol'],
    'fireball': ['jupiter fulgur', 'thor', 'aerolite', 'alcohol', 'ball lightning', 'benzine', 'bolide', 'bolt', 'bolt of lightning', 'briquette', 'burnable', 'butane'],
    'firebrand': ['mafioso', 'young turk', 'agent provocateur', 'agitator', 'agitprop', 'beast', 'beldam', 'berserk', 'berserker', 'bomber', 'brand', 'brute'],
    'firebrick': ['adobe', 'ashlar', 'biscuit', 'bisque', 'bowl', 'brick', 'bricks and mortar', 'cement', 'ceramic ware', 'ceramics', 'china', 'clinker'],
    'firecracker': ['klaxon', 'roman candle', 'boiler factory', 'boiler room', 'bomb', 'bull-roarer', 'cap', 'catcall', 'cherry bomb', 'clack', 'clacker', 'clapper'],
    'fired': ['afire', 'agog', 'aquiver', 'aroused', 'atingle', 'atwitter', 'baked', 'boiled', 'braised', 'broiled', 'browned', 'bursting'],
    'firedamp': ['afterdamp', 'blackdamp', 'breath', 'chokedamp', 'cloud', 'coal gas', 'damp', 'effluvium', 'exhalation', 'exhaust', 'exhaust gas', 'fetid air'],
    'firefly': ['blink', 'blinking', 'candle fly', 'coruscation', 'fire beetle', 'fireworm', 'glimmer', 'glimmering', 'glisten', 'glister', 'glitter', 'glittering'],
    'fireguard': ['argus', 'charley', 'airplane spotter', 'chimney', 'chimney corner', 'fender', 'fire patrolman', 'fire screen', 'fire warden', 'fireboard', 'fireplace', 'fireside'],
    'fireman': ['baggage man', 'bakehead', 'black gang', 'boilerman', 'brakeman', 'brakie', 'bungs', 'butcher', 'cabin boy', 'chips', 'commissary steward', 'complement'],
    'fireplace': ['ancestral halls', 'chimney', 'chimney corner', 'family homestead', 'fender', 'fire screen', 'fireboard', 'fireguard', 'fireside', 'flue', 'foyer', 'hearth'],
    'fireplug': ['foamite', 'acid', 'automatic sprinkler', 'carbon tet', 'carbon tetrachloride', 'carbon-dioxide foam', 'deck gun', 'deluge set', 'extinguisher', 'fire apparatus', 'fire engine', 'fire hose'],
    'firepower': ['antiaircraft fire', 'cross fire', 'curtain fire', 'direct fire', 'dry fire', 'fighting force', 'file fire', 'fire', 'fire of demolition', 'fireworks', 'firing', 'flack'],
    'fireproof': ['airtight', 'ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'corrosionproof', 'dampproof', 'fire-resistant', 'fire-resisting', 'fire-retardant', 'fire-retarded', 'fireproofed'],
    'fireside': ['ancestral halls', 'chimney', 'chimney corner', 'family homestead', 'fender', 'fire screen', 'fireboard', 'fireguard', 'fireplace', 'flue', 'foyer', 'hearth'],
    'firewood': ['backlog', 'bavin', 'beam', 'billet', 'board', 'boarding', 'brush', 'brushwood', 'clapboard', 'cord', 'cordwood', 'deal'],
    'fireworks': ['roman candle', 'antiaircraft fire', 'bomb', 'cap', 'cherry bomb', 'cracker', 'cross fire', 'curtain fire', 'direct fire', 'dry fire', 'file fire', 'fire'],
    'firing': ['afflatus', 'agitation', 'alcohol', 'animating spirit', 'animation', 'animus', 'antiaircraft fire', 'archery', 'arousal', 'benzine', 'briquette', 'burnable'],
    'firing line': ['dmz', 'aceldama', 'battle line', 'battle site', 'battlefield', 'battleground', 'combat area', 'combat zone', 'enemy line', 'field', 'field of battle', 'field of blood'],
    'firm': ['aktiengesellschaft', 'cia', 'central intelligence agency', 'christian', 'abiding', 'accepted', 'adamant', 'adamantine', 'agency', 'airtight', 'aktiebolag', 'anchored'],
    'firmament': ['caelus', 'air', 'azure', 'blue sky', 'caelum', 'canopy', 'canopy of heaven', 'cerulean', 'cope', 'empyrean', 'ether', 'heaven'],
    'firmly': ['adamantly', 'bec et ongles', 'bona fide', 'close', 'closely', 'committedly', 'compactly', 'consistently', 'constantly', 'deafeningly', 'decidedly', 'decisively'],
    'first': ['ab initio', 'ab ovo', 'aborigine', 'ahead', 'alpha', 'antecedent', 'anterior', 'anticipatory', 'arch', 'at first', 'at the start', 'banner'],
    'first class': ['best', 'first-chop', 'first-rate', 'greatest', 'highest', 'maximal', 'maximum', 'most', 'superlative', 'supreme', 'tip-top', 'top'],
    'first draft': ['acid test', 'article', 'assay', 'autograph', 'blank determination', 'brainchild', 'brouillon', 'composition', 'computer printout', 'copy', 'criterion', 'crucial test'],
    'first impression': ['alpha', 'breaking-in', 'first', 'first blush', 'first glance', 'first inning', 'first lap', 'first move', 'first round', 'first sight', 'first stage', 'first step'],
    'first move': ['alpha', 'breaking-in', 'first', 'first blush', 'first glance', 'first impression', 'first inning', 'first lap', 'first round', 'first sight', 'first stage', 'first step'],
    'first place': ['acme', 'authority', 'authorization', 'be-all and end-all', 'blue ribbon', 'championship', 'command', 'control', 'directorship', 'dominion', 'effectiveness', 'first prize'],
    'first prize': ['academy award', 'nobel prize', 'oscar', 'acme', 'authority', 'authorization', 'award', 'be-all and end-all', 'blue ribbon', 'booby prize', 'championship', 'command'],
    'first rate': ['best', 'capital', 'dandy', 'fine', 'first-chop', 'first-class', 'greatest', 'highest', 'maximal', 'maximum', 'most', 'prime'],
    'first step': ['alpha', 'breaking-in', 'first', 'first blush', 'first glance', 'first impression', 'first inning', 'first lap', 'first move', 'first round', 'first sight', 'first stage'],
    'first string': ['capital', 'cast', 'class', 'company', 'complement', 'crew', 'eight', 'eleven', 'famous', 'first', 'first team', 'first-rate'],
    'first thing': ['ab initio', 'ab ovo', 'aborigine', 'at first', 'at the start', 'before everything', 'chiefly', 'first', 'first and foremost', 'firstly', 'from the beginning', 'in the beginning'],
    'first-rate': ['ace', 'admirable', 'crack', 'excellent', 'exceptional', 'extraordinary', 'fine', 'first-class', 'great', 'high-grade', 'matchless', 'outstanding'],
    'firsthand': ['absolute', 'adducible', 'admissible', 'attestative', 'attestive', 'authentic', 'avant-garde', 'based on', 'callow', 'certain', 'circumstantial', 'conclusive'],
    'firth': ['arm', 'armlet', 'bay', 'bayou', 'belt', 'bight', 'boca', 'cove', 'creek', 'estuary', 'euripus', 'fjord'],
    'fish': ['c-note', 'chinook salmon', 'g-note', 'loch ness monster', 'sunapee trout', 'aerial torpedo', 'albacore', 'alevin', 'alewife', 'alligator gar', 'amber jack', 'anchovy'],
    'fish for': ['address', 'angle for', 'ask for', 'beat about for', 'bid for', 'canvass', 'court', 'delve for', 'dig for', 'follow', 'go gunning for', 'gun for'],
    'fish fry': ['tv dinner', 'alfresco meal', 'barbecue', 'breakfast', 'brunch', 'buffet supper', 'clambake', 'coffee break', 'cookout', 'diner', 'dinner', 'elevenses'],
    'fish story': ['big talk', 'blague', 'bullshit', 'bunk', 'bunkum', 'cock-and-bull story', 'exaggeration', 'fairy tale', 'falsehood', 'falsity', 'fancy talk', 'farfetched story'],
    'fisherman': ['ab', 'ancient mariner', 'argonaut', 'dylan', 'flying dutchman', 'neptune', 'od', 'poseidon', 'varuna', 'able seaman', 'able-bodied seaman', 'angler'],
    'fishhook': ['bait', 'birdlime', 'bola', 'cobweb', 'dragnet', 'fly', 'gill net', 'ground bait', 'hook', 'jig', 'lariat', 'lasso'],
    'fishing': ['angling', 'casting', 'cynegetic', 'delving', 'digging', 'fishery', 'fly fishing', 'following', 'guddling', 'halieutic', 'harpooning', 'hunting'],
    'fishmonger': ['baker', 'bookdealer', 'bookseller', 'butcher', 'chandler', 'clothing merchant', 'confectioner', 'draper', 'drysalter', 'fishwife', 'florist', 'footwear merchant'],
    'fishpond': ['aquarium', 'artificial lake', 'bayou lake', 'cistern', 'dam', 'dead water', 'dike', 'etang', 'farm pond', 'freshwater lake', 'glacial lake', 'inland sea'],
    'fishwife': ['xanthippe', 'amazon', 'baker', 'battle-ax', 'beldam', 'bitch', 'bookdealer', 'bookseller', 'butcher', 'cat', 'chandler', 'clothing merchant'],
    'fishy': ['ambiguous', 'amoral', 'beguiling', 'blank', 'catchy', 'conscienceless', 'corrupt', 'corrupted', 'criminal', 'crooked', 'dark', 'deadpan'],
    'fissile': ['alienable', 'breakable', 'brittle', 'brittle as glass', 'crackable', 'crisp', 'crispy', 'crumbly', 'crushable', 'delicate', 'dissoluble', 'dissolvable'],
    'fission': ['ablate', 'abscission', 'accelerate', 'activate', 'alpha decay', 'amputation', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction', 'atomization', 'atomize'],
    'fissure': ['abysm', 'abyss', 'amputate', 'arachnoid', 'arbor vitae', 'archipallium', 'arroyo', 'ax', 'between brain', 'bisect', 'box canyon', 'brain stem'],
    'fist': ['arrow', 'autography', 'blaze', 'calligraphy', 'chirography', 'compass needle', 'direction', 'direction post', 'finger post', 'graphanalysis', 'graphology', 'graphometry'],
    'fit': ['jacksonian epilepsy', 'rolandic epilepsy', 'a propos', 'abdominal epilepsy', 'able', 'acceptable', 'access', 'accommodate', 'accommodate with', 'accord', 'according to hoyle', 'accouter'],
    'fit in': ['accord', 'be there', 'belong', 'conform', 'correspond', 'dovetail', 'fall in with', 'fall into line', 'fit', 'follow the crowd', 'follow the fashion', 'follow the rule'],
    'fitful': ['adrift', 'afloat', 'aimless', 'alternating', 'amorphous', 'broken', 'broken off', 'capricious', 'careening', 'casual', 'catchy', 'changeable'],
    'fitfully': ['at haphazard', 'at intervals', 'at irregular intervals', 'at random', 'brokenly', 'by catches', 'by chance', 'by fits', 'by jerks', 'by skips', 'by snatches', 'capriciously'],
    'fitness': ['hygeia', 'ability', 'ableness', 'acceptability', 'account', 'adequacy', 'admissibility', 'advantage', 'advantageousness', 'advisability', 'applicability', 'appositeness'],
    'fits and starts': ['ague', 'arrhythmia', 'brokenness', 'bumpiness', 'capriciousness', 'chattering', 'choppiness', 'chorea', 'cold shivers', 'desultoriness', 'disconnectedness', 'discontinuity'],
    'fitted': ['a propos', 'able', 'acceptable', 'accoutered', 'ad rem', 'adapted', 'adjusted', 'admissible', 'applicable', 'apposite', 'appropriate', 'apropos'],
    'fitting': ['a propos', 'about-face', 'accessories', 'accommodation', 'accordant', 'according to hoyle', 'accouterments', 'ad rem', 'adaptation', 'adapted', 'adjustment', 'advantageous'],
    'five': ['cast', 'company', 'complement', 'crew', 'eight', 'eleven', 'first string', 'first team', 'nine', 'platoon', 'reserves', 'rowing crew'],
    'five percenter': ['rasputin', 'svengali', 'vip', 'access', 'bad influence', 'big wheel', 'court', 'eminence grise', 'fixer', 'four-percenter', 'friend at court', 'good influence'],
    'five-and-ten': ['boutique', 'chain store', 'cheap as dirt', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dime store', 'dime-store', 'dirt cheap'],
    'fix': ['ko', 'acclimate', 'acclimatize', 'accommodate', 'accord', 'accustom', 'adapt', 'adjust', 'adjust to', 'affix', 'afford proof of', 'aim'],
    'fix on': ['account for', 'accredit with', 'accrete to', 'acknowledge', 'aim', 'aim at', 'apply to', 'ascribe to', 'assign to', 'attach to', 'attend to business', 'attribute to'],
    'fix up': ['accommodate', 'adjust', 'adorn', 'arrange', 'arrange matters', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'brew', 'bring to terms'],
    'fixable': ['ameliorable', 'amendable', 'approachable', 'bribable', 'buyable', 'correctable', 'corrigible', 'corrupt', 'corruptible', 'curable', 'emendable', 'improvable'],
    'fixation': ['freudian fixation', 'anchorage', 'arrest', 'arrestation', 'arrested development', 'arrestment', 'blockage', 'blocking', 'check', 'clogging', 'closing up', 'closure'],
    'fixative': ['air brush', 'ambergris', 'ambrosia', 'aromatic', 'aromatic gum', 'aromatic water', 'art paper', 'attar', 'attar of roses', 'balance', 'balance rudder', 'balance wheel'],
    'fixed': ['abiding', 'absolute', 'acknowledged', 'admitted', 'admitting no exception', 'agreed', 'aground', 'aligned', 'all up with', 'all-out', 'anchored', 'arranged'],
    'fixer': ['cobbler', 'developer', 'doctor', 'five-percenter', 'fixing bath', 'four-percenter', 'hypo', 'influence peddler', 'little miss fixit', 'logroller', 'maintenance man', 'mechanic'],
    'fixings': ['adjunct', 'appurtenance', 'aspect', 'circumstance', 'component', 'constituent', 'contents', 'detail', 'element', 'factor', 'feature', 'ingredient'],
    'fixture': ['accession', 'accessory', 'accompaniment', 'accouterments', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct'],
    'fizz': ['assibilate', 'assibilation', 'blubber', 'boil', 'boil over', 'boiling', 'bubble', 'bubble over', 'bubble up', 'bubbliness', 'bubbling', 'burble'],
    'fizzle': ['abort', 'assibilate', 'assibilation', 'bafflement', 'balk', 'be disappointing', 'betrayed hope', 'blasted expectation', 'blighted hope', 'blow', 'blow up', 'blubber'],
    'fizzle out': ['be disappointing', 'be unproductive', 'blow up', 'break', 'break down', 'burn out', 'cave in', 'collapse', 'come apart', 'come short', 'come to naught', 'come to nothing'],
    'fizzy': ['beaten', 'blebby', 'blistered', 'blistering', 'blistery', 'bubbling', 'bubbly', 'burbling', 'burbly', 'carbonated', 'chiffon', 'ebullient'],
    'fjord': ['arm', 'armlet', 'bay', 'bayou', 'belt', 'bight', 'boca', 'cove', 'creek', 'estuary', 'euripus', 'frith'],
    'flabbergast': ['amaze', 'astonish', 'astound', 'awe', 'awestrike', 'bedaze', 'bedazzle', 'bewilder', 'boggle', 'bowl down', 'bowl over', 'confound'],
    'flabbergasted': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled', 'bewildered'],
    'flabby': ['anemic', 'asthenic', 'baccate', 'baggy', 'bloodless', 'chicken', 'cowardly', 'debilitated', 'doughy', 'drooping', 'droopy', 'dull'],
    'flaccid': ['anemic', 'asthenic', 'bloodless', 'chicken', 'cowardly', 'debilitated', 'drooping', 'droopy', 'dull', 'effete', 'emasculated', 'etiolated'],
    'flack': ['advocacy', 'advocating', 'antiaircraft fire', 'bruiting', 'buildup', 'cross fire', 'curtain fire', 'direct fire', 'drumbeating', 'dry fire', 'file fire', 'fire'],
    'flag': ['dannebrog', 'jolly roger', 'old glory', 'star-spangled banner', 'stars and stripes', 'tarmac', 'tarvia', 'union flag', 'union jack', 'abate', 'adobe', 'and blue'],
    'flagellate': ['baste', 'bastinado', 'beat', 'belabor', 'belt', 'birch', 'buffet', 'cane', 'club', 'cowhide', 'cudgel', 'cut'],
    'flagellation': ['albigensianism', 'catharism', 'day of atonement', 'franciscanism', 'sabbatarianism', 'trappism', 'waldensianism', 'yoga', 'yom kippur', 'abstinence', 'anchoritic monasticism', 'anchoritism'],
    'flagellum': ['golgi apparatus', 'animal fiber', 'artificial fiber', 'aster', 'basal body', 'belt', 'bine', 'blacksnake', 'bough', 'branch', 'branchedness', 'branchiness'],
    'flagging': ['ambling', 'cautious', 'circumspect', 'claudicant', 'coming apart', 'cracking', 'crawling', 'creeping', 'creeping like snail', 'crumbling', 'debilitated', 'decadent'],
    'flagitious': ['corrupt', 'criminal', 'degenerate', 'depraved', 'disgraceful', 'flagrant', 'glaring', 'gross', 'infamous', 'miscreant', 'nefarious', 'perverse'],
    'flagrant': ['abject', 'ablaze', 'abominable', 'absolute', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'arrant', 'atrocious'],
    'flagrantly': ['abjectly', 'abominably', 'agonizingly', 'arrantly', 'atrociously', 'awfully', 'baldly', 'balefully', 'basely', 'bestially', 'bitterly', 'blatantly'],
    'flagstone': ['tarmac', 'tarvia', 'adobe', 'ashlar', 'asphalt', 'bitumen', 'bituminous macadam', 'blacktop', 'brick', 'bricks and mortar', 'cement', 'clinker'],
    'flail': ['bang', 'baste', 'bastinado', 'batter', 'beat', 'belabor', 'belt', 'birch', 'buffet', 'cane', 'club', 'cowhide'],
    'flair': ['ability', 'ableness', 'acuity', 'acumen', 'acuteness', 'adequacy', 'adroitness', 'an ear for', 'an eye for', 'aptitude', 'aptness', 'art'],
    'flak': ['abuse', 'adverse criticism', 'aggressiveness', 'animadversion', 'antiaircraft fire', 'artillery', 'aspersion', 'bad notices', 'bad press', 'battery', 'bellicosity', 'belligerence'],
    'flake': ['aliene', 'arrange in layers', 'avalanche', 'band', 'bar', 'bedlamite', 'bespangle', 'bespeckle', 'bespot', 'bit', 'blizzard', 'blotch'],
    'flake off': ['be off', 'beat it', 'begone', 'clear out', 'desquamate', 'exfoliate', 'flake', 'get', 'get going', 'get lost', 'get out', 'git'],
    'flaky': ['abnormal', 'anomalous', 'apish', 'arbitrary', 'asinine', 'asperous', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany'],
    'flam': ['ballot-box stuffing', 'balls', 'baloney', 'beat', 'beguile of', 'bilk', 'blague', 'bosh', 'bull', 'bullshit', 'bunco', 'bunk'],
    'flambeau': ['brand', 'butane lighter', 'cigarette lighter', 'cresset', 'firebrand', 'flaming torch', 'flare', 'flint', 'flint and steel', 'fusee', 'igniter', 'light'],
    'flamboyance': ['arabesque', 'baroque', 'baroqueness', 'blare', 'blatancy', 'blaze', 'blazing light', 'blinding light', 'brazenness', 'bright light', 'brightness', 'brilliance'],
    'flamboyant': ['gongoresque', 'johnsonian', 'affected', 'arabesque', 'baroque', 'bedazzling', 'bedizened', 'big-sounding', 'blinding', 'bright', 'bright and shining', 'brilliant'],
    'flame': ['amor', 'casanova', 'christian love', 'don juan', 'eros', 'lothario', 'platonic love', 'romeo', 'admiration', 'adoration', 'affection', 'agape'],
    'flame up': ['bake', 'be angry', 'be excitable', 'be in heat', 'bellow', 'blaze', 'blaze up', 'bloom', 'blow a gasket', 'blow up', 'boil', 'broil'],
    'flameproof': ['airtight', 'ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'corrosionproof', 'dampproof', 'fire-resistant', 'fire-resisting', 'fire-retardant', 'fire-retarded', 'fireproof'],
    'flamethrower': ['automatic', 'blowgun', 'blowpipe', 'firearm', 'gat', 'gun', 'handgun', 'heater', 'musket', 'peashooter', 'piece', 'pistol'],
    'flaming': ['gongoresque', 'johnsonian', 'titian', 'titian-red', 'abandoned', 'ablaze', 'affected', 'afire', 'aflame', 'aflicker', 'aglow', 'alight'],
    'flange': ['bank', 'bilge', 'blain', 'bleb', 'blister', 'blob', 'board', 'border', 'bordure', 'boss', 'bow', 'brim'],
    'flank': ['chateaubriand', 'advance against', 'advance upon', 'advocate', 'bank', 'beam', 'bear down upon', 'blade roast', 'border', 'breast', 'brisket', 'broadside'],
    'flannel': ['ballocks', 'blarney', 'bull', 'bullshit', 'bushwa', 'cock', 'crap', 'eyewash', 'flatter', 'flattery', 'hedge', 'hogwash'],
    'flap': ['bedlam let loose', 'ado', 'agitation', 'applique', 'argument', 'bag', 'bang', 'baste', 'batter', 'beat', 'beating', 'bedlam'],
    'flapper': ['australian crawl', 'aide-memoire', 'aquaplaning', 'aquatics', 'backstroke', 'balneation', 'bathe', 'bathing', 'breaststroke', 'butterfly', 'crawl', 'cue'],
    'flare': ['roman candle', 'addition', 'adjunct', 'aggrandizement', 'aid to navigation', 'alarm', 'amber light', 'ampliation', 'amplification', 'anger', 'augmentation', 'backfire'],
    'flare up': ['access', 'bake', 'be angry', 'be excitable', 'be in heat', 'belch', 'bellow', 'blaze', 'blaze of temper', 'blaze up', 'bloom', 'blow a gasket'],
    'flaring': ['ablaze', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'blatant', 'blazing', 'blinding', 'brazen', 'brazenfaced'],
    'flash': ['teletype', 'advertise', 'air', 'antelope', 'arrow', 'automatic response', 'backfire', 'bang', 'be bright', 'beacon', 'beam', 'beat the drum'],
    'flashback': ['commitment to memory', 'exercise of memory', 'hindsight', 'learning by heart', 'looking back', 'memoir', 'memorization', 'memorizing', 'recall', 'recalling', 'recollecting', 'recollection'],
    'flashing': ['ablaze', 'aflame', 'aflicker', 'bickering', 'blazing', 'blinking', 'brave', 'bravura', 'braw', 'brief', 'brisk', 'burning'],
    'flashy': ['gongoresque', 'johnsonian', 'ablaze', 'affected', 'aflame', 'bedizened', 'big-sounding', 'blatant', 'blazing', 'blinding', 'brave', 'bravura'],
    'flask': ['calabash', 'canteen', 'carafe', 'carboy', 'caster', 'cruet', 'cruse', 'decanter', 'demijohn', 'ewer', 'fifth', 'flacon'],
    'flat': ['pullman', 'pullman car', 'abeyant', 'absolute', 'absolutely', 'absonant', 'accented', 'accidental', 'accommodation', 'accordant', 'accumbent', 'achromatic'],
    'flat out': ['a outrance', 'a toute outrance', 'absolute', 'absolutely', 'admitting no exception', 'all hollow', 'all out', 'all the way', 'all-out', 'apace', 'at full blast', 'at full drive'],
    'flatfoot': ['dogberry', 'john law', 'beagle', 'bluecoat', 'bobby', 'bowlegs', 'bull', 'camelback', 'cleft palate', 'clubfoot', 'cop', 'copper'],
    'flatland': ['alkali flat', 'alluvial plain', 'basin', 'billiard table', 'bottomland', 'bowling green', 'bushveld', 'campo', 'champaign', 'champaign country', 'coastal plain', 'dead flat'],
    'flats': ['alkali flat', 'alluvial plain', 'apartment house', 'basin', 'bottomland', 'bushveld', 'campo', 'champaign', 'champaign country', 'coastal plain', 'condominium', 'cooperative apartment house'],
    'flatten': ['align', 'assimilate to', 'balance', 'beat down', 'bend', 'blow down', 'break', 'break down', 'bring down', 'bulldoze', 'burn down', 'cast down'],
    'flatter': ['adorn', 'adulate', 'apotheosize', 'beautify', 'become', 'beguile', 'belaud', 'bend the knee', 'bepraise', 'beslobber', 'beslubber', 'blandish'],
    'flatterer': ['adulator', 'apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'blarneyer', 'bootlick', 'bootlicker', 'brown-nose', 'brownie', 'cajoler', 'clawback'],
    'flattering': ['abject', 'acclamatory', 'admiring', 'adulatory', 'appreciative', 'approbatory', 'backscratching', 'becoming', 'beggarly', 'bland', 'blandishing', 'blarneying'],
    'flattery': ['accolade', 'adulation', 'apotheosis', 'ass-kissing', 'beguilement', 'bepraisement', 'blandishment', 'blarney', 'brown-nosing', 'cajolery', 'congratulation', 'deification'],
    'flatulence': ['barnumism', 'aeriness', 'affectation', 'bedizenment', 'big talk', 'bloat', 'bloatedness', 'bloating', 'blowing up', 'convolution', 'diastole', 'dilatation'],
    'flatulent': ['bloated', 'blown up', 'bombastic', 'dilated', 'distended', 'dropsical', 'edematous', 'ejaculative', 'ejective', 'empty', 'enchymatous', 'eructative'],
    'flatware': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'cutlery', 'dining utensils', 'dinnerware', 'durable goods', 'durables', 'earthenware', 'enamelware'],
    'flaunt': ['advertise', 'affect', 'air', 'betoken', 'blazon forth', 'boast', 'brag', 'brandish', 'breathe', 'bring forth', 'bring forward', 'bring into view'],
    'flaunting': ['gongoresque', 'johnsonian', 'affected', 'bedizened', 'big-sounding', 'blatant', 'blazon', 'blinding', 'brandish', 'brandishing', 'brave', 'bravura'],
    'flavor': ['aftertaste', 'air', 'ambiance', 'ambience', 'aroma', 'atmosphere', 'attribute', 'badge', 'besprinkle', 'bitter', 'brand', 'breath'],
    'flavorless': ['dead', 'dilute', 'diluted', 'distasteful', 'fade', 'flat', 'gruelly', 'ill-flavored', 'inane', 'indifferent', 'insipid', 'jejune'],
    'flavorsome': ['appetizing', 'delectable', 'delicious', 'flavorful', 'flavorous', 'flavory', 'fruity', 'full-bodied', 'full-flavored', 'good-tasting', 'juicy', 'luscious'],
    'flaw': ['aberrancy', 'aberration', 'abysm', 'abyss', 'arroyo', 'bad habit', 'besetting sin', 'birthmark', 'black mark', 'blackhead', 'blast', 'bleb'],
    'flawed': ['aberrant', 'abroad', 'absonant', 'actionable', 'adrift', 'against the law', 'all abroad', 'all off', 'all wrong', 'amiss', 'anarchic', 'anarchistic'],
    'flawless': ['ok', 'absolute', 'accurate', 'all right', 'beyond all praise', 'chaste', 'clean', 'correct', 'dead right', 'defectless', 'demonstrable', 'entire'],
    'flay': ['assail', 'attack', 'bark', 'berate', 'bleed', 'bleed white', 'blister', 'castigate', 'decorticate', 'defoliate', 'denude', 'deplume'],
    'flea': ['broad jumper', 'bucking bronco', 'buckjumper', 'cat flea', 'chigoe', 'cockroach', 'crab', 'dog flea', 'frog', 'gazelle', 'goat', 'grasshopper'],
    'flea bitten': ['bespangled', 'blotched', 'blotchy', 'dotted', 'dotty', 'flecked', 'fleckered', 'frecked', 'freckled', 'freckly', 'macular', 'maculate'],
    'flea market': ['auto show', 'bazaar', 'boat show', 'closing-out sale', 'commercial complex', 'distress sale', 'emporium', 'exposition', 'fair', 'flea fair', 'garage sale', 'going-out-of-business sale'],
    'fleabag': ['boardinghouse', 'dorm', 'dormitory', 'doss house', 'flophouse', 'guest house', 'hospice', 'hostel', 'hostelry', 'hotel', 'inn', 'lodging house'],
    'flection': ['s-curve', 'angle', 'angularity', 'angularness', 'bend', 'bending', 'bow', 'bowing', 'conflexure', 'crease', 'creasing', 'crimp'],
    'fledge': ['attain majority', 'bloom', 'come of age', 'come to maturity', 'develop', 'feather', 'flower', 'grow', 'grow up', 'leave the nest', 'mature', 'mellow'],
    'fledgling': ['young turk', 'abecedarian', 'adolescent', 'alphabetarian', 'apprentice', 'arriviste', 'articled clerk', 'at half cock', 'avifauna', 'baby', 'baby bird', 'beginner'],
    'flee': ['abscond', 'absquatulate', 'avoid', 'bail out', 'be annihilated', 'be consumed', 'be destroyed', 'be gone', 'be no more', 'be wiped out', 'beat a retreat', 'beat it'],
    'fleece': ['leatherette', 'leatheroid', 'alabaster', 'bare', 'beat', 'beguile of', 'bilk', 'bleed', 'bleed white', 'blubber', 'breeze', 'bristle'],
    'fleeced': ['beggared', 'beggarly', 'bereaved', 'bereft', 'deprived', 'disadvantaged', 'ghettoized', 'impoverished', 'in need', 'in rags', 'in want', 'indigent'],
    'fleecy': ['bristly', 'bushy', 'cirrose', 'downy', 'feathery', 'flocculent', 'flossy', 'fluffy', 'furry', 'fuzzy', 'hairy', 'hirsute'],
    'fleer': ['parthian shot', 'affront', 'back answer', 'barrack', 'be merry with', 'call names', 'caustic remark', 'chaff', 'comeback', 'crack', 'crack a joke', 'crack wise'],
    'fleet': ['naval construction battalion', 'rn', 'royal navy', 'seabees', 'usn', 'united states navy', 'age group', 'agile', 'alert', 'animated', 'argosy', 'armada'],
    'fleeting': ['abrupt', 'blunt', 'brief', 'brittle', 'brusque', 'capricious', 'changeable', 'compendious', 'corruptible', 'crusty', 'curt', 'deciduous'],
    'flesh': ['adam', 'hominidae', 'homo sapiens', 'leatherette', 'leatheroid', 'agnate', 'alive', 'all that lives', 'anatomy', 'ancestry', 'animalism', 'animality'],
    'flesh and blood': ['agnate', 'ancestry', 'blood', 'blood relation', 'blood relative', 'bodiliness', 'clansman', 'cognate', 'collateral', 'collateral relative', 'concreteness', 'connections'],
    'flesh eater': ['brillat-savarin', 'lucullus', 'board-and-roomer', 'boarder', 'bon vivant', 'cannibal', 'carnivore', 'connoisseur of food', 'consumer', 'diner', 'diner-out', 'eater'],
    'flesh eating': ['cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'dining', 'eating', 'feeding', 'fruitarian', 'gastronomic', 'gluttonous', 'grain-eating'],
    'fleshly': ['adamic', 'adamite', 'adamitic', 'circean', 'amorous', 'animal', 'animalistic', 'anthropocentric', 'anthropological', 'aphrodisiomaniacal', 'backsliding', 'bawdy'],
    'fleshpots': ['babylon', 'easy street', 'gomorrah', 'sodom', 'affluence', 'bed of roses', 'bordello', 'brothel', 'cathouse', 'clip joint', 'clover', 'comfort'],
    'fleshy': ['adipose', 'baccate', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky'],
    'fleur-de-lis': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'azure', 'badge', 'badge of office', 'badges'],
    'flex': ['s-curve', 'arch', 'bend', 'bend back', 'bending', 'bow', 'bowing', 'cable', 'conflexure', 'contract', 'cord', 'crook'],
    'flexibility': ['renaissance man', 'renaissance versatility', 'accommodation', 'accord', 'accordance', 'acquiescence', 'adaptability', 'adaptation', 'adaption', 'adjustability', 'adjustment', 'agreeability'],
    'flexible': ['able to adapt', 'acquiescent', 'adaptable', 'adaptive', 'adjustable', 'all-around', 'alterable', 'alterative', 'ambidextrous', 'amenable', 'amphibious', 'bendable'],
    'flexuous': ['adaptable', 'ambagious', 'anfractuous', 'bendable', 'bending', 'bendy', 'chevronwise', 'chevrony', 'circuitous', 'circumlocutory', 'compliant', 'convoluted'],
    'flexure': ['s-curve', 'angle', 'angularity', 'angularness', 'bend', 'bending', 'bow', 'bowing', 'conflexure', 'crease', 'creasing', 'crimp'],
    'flick': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'beak', 'beat', 'bicker', 'birthmark', 'black-and-white film', 'blaze', 'blemish'],
    'flicker': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'backfire', 'bake', 'balefire', 'be in heat', 'beacon', 'beacon fire', 'beat'],
    'flickering': ['ablaze', 'adrift', 'afire', 'aflame', 'aflicker', 'afloat', 'aglow', 'alight', 'alternating', 'amorphous', 'ardent', 'bickering'],
    'flier': ['amtrak', 'jehu', 'acrobat', 'aerialist', 'aeronaut', 'aeroplaner', 'aeroplanist', 'agiotage', 'air pilot', 'airman', 'airplanist', 'arbitrage'],
    'flight': ['awol', 'brownian movement', 'french leave', 'a mass of', 'a world of', 'abandonment', 'abscond', 'absence without leave', 'absquatulation', 'acciaccatura', 'advance', 'aeronautics'],
    'flight of fancy': ['autism', 'autistic thinking', 'conceit', 'dereism', 'dereistic thinking', 'dreamery', 'fancy', 'fantasticism', 'fantasy', 'fumes of fancy', 'ideal', 'idealism'],
    'flight path': ['air lane', 'amplitude', 'beat', 'camber', 'circuit', 'course', 'itinerary', 'line', 'orbit', 'path', 'primrose path', 'road'],
    'flighty': ['abnormal', 'adrift', 'afloat', 'alternating', 'amorphous', 'bereft of reason', 'birdbrained', 'birdwitted', 'brainsick', 'buoyant', 'capricious', 'changeable'],
    'flimflam': ['balderdash', 'ballot-box stuffing', 'balls', 'baloney', 'bamboozle', 'bamboozlement', 'beat', 'befool', 'befooling', 'beguile of', 'bilk', 'blague'],
    'flimsy': ['adulterated', 'airy', 'asinine', 'attenuate', 'attenuated', 'boyish', 'breakable', 'brittle', 'brittle as glass', 'catchpenny', 'cheap-jack', 'cobwebby'],
    'flinch': ['avoid', 'avoidance', 'be startled', 'blanch', 'blench', 'blink', 'boggle', 'cower', 'cringe', 'demur', 'dodge', 'draw back'],
    'fling': ['approach', 'assay', 'attempt', 'bash', 'bat', 'bender', 'bid', 'binge', 'boil', 'bolt', 'bout', 'bowl'],
    'fling off': ['articulate', 'breathe', 'cast off', 'chime', 'chorus', 'come out with', 'communicate', 'convey', 'deliver', 'disclose', 'dispel', 'do away with'],
    'flint': ['adamant', 'bone', 'brand', 'brick', 'butane lighter', 'cement', 'cigarette lighter', 'concrete', 'diamond', 'firebrand', 'flambeau', 'flint and steel'],
    'flinthearted': ['callous', 'calloused', 'cold', 'cold of heart', 'coldblooded', 'coldhearted', 'hard', 'hard of heart', 'hardened', 'hardhearted', 'heartless', 'insensitive'],
    'flinty': ['philistine', 'adamant', 'adamantine', 'bony', 'bowelless', 'callous', 'calloused', 'case-hardened', 'cast-iron', 'cement', 'cemental', 'concrete'],
    'flip': ['about-face', 'afterthoughts', 'all jaw', 'anger', 'be angry', 'be excitable', 'beak', 'beat', 'bellow', 'better thoughts', 'bicker', 'biggety'],
    'flip flop': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'afterthoughts', 'alchemy', 'alteration', 'amelioration', 'apostasy', 'assimilation', 'assumption', 'backing'],
    'flip out': ['anger', 'boil over', 'bridle', 'bridle up', 'bristle', 'bristle up', 'fidget', 'flutter', 'freak out on', 'get high on', 'get mad', 'get sore'],
    'flip side': ['antipode', 'antipodes', 'antipole', 'antithesis', 'antonym', 'contra', 'converse', 'counter', 'counterbalance', 'countercheck', 'counterpoint', 'counterpoise'],
    'flippancy': ['absentmindedness', 'banter', 'booing', 'brashness', 'brassiness', 'brazenfacedness', 'brazenness', 'carelessness', 'catcalling', 'chaffing', 'cheek', 'cheekiness'],
    'flippant': ['airy', 'bantering', 'belittling', 'biggety', 'bluff', 'booing', 'brash', 'brazen', 'careless', 'casual', 'catcalling', 'chaffing'],
    'flipped': ['balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bonkers', 'buggy', 'bughouse', 'bugs', 'crackers', 'cuckoo'],
    'flipper': ['australian crawl', 'act drop', 'aquaplaning', 'aquatics', 'asbestos', 'asbestos board', 'backdrop', 'backstroke', 'balneation', 'bathe', 'bathing', 'batten'],
    'flirt': ['circe', 'don juan', 'lorelei', 'parthenope', 'siren', 'sunday painter', 'allure', 'amateur', 'bait', 'bait the hook', 'beak', 'blandish'],
    'flirtation': ['adulterous affair', 'adultery', 'affair', 'agacerie', 'allure', 'allurement', 'amorous looks', 'amour', 'appeal', 'attraction', 'attractiveness', 'beguilement'],
    'flirtatious': ['alluring', 'amative', 'amatory', 'amorous', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating'],
    'flit': ['advance', 'aeroplane', 'air speed', 'airlift', 'airplane', 'auntie', 'ball the jack', 'balloon', 'barrel', 'bat around', 'be airborne', 'beat'],
    'flitter': ['beat', 'beating', 'bicker', 'dance', 'flap', 'flick', 'flicker', 'flip', 'flit', 'flop', 'flutter', 'go pitapat'],
    'flitting': ['adrift', 'afloat', 'airborne', 'alternating', 'amorphous', 'brittle', 'capricious', 'changeable', 'changeful', 'circumforaneous', 'corruptible', 'deciduous'],
    'float': ['carling float', 'arrange', 'ascend', 'aspire', 'balsa', 'balsa raft', 'barge', 'bathe', 'bear up', 'become airborne', 'boat', 'bob'],
    'floater': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'ballot-box stuffer', 'balloter', 'bird of passage'],
    'floating': ['australian crawl', 'hare system', 'pr', 'absentee voting', 'adrift', 'afloat', 'aquaplaning', 'aquatics', 'awash', 'backstroke', 'ballot-box stuffing', 'balneation'],
    'flocculent': ['asperous', 'bristly', 'bushy', 'cirrose', 'flaky', 'fleecy', 'furfuraceous', 'furry', 'fuzzy', 'hairy', 'hirsute', 'hispid'],
    'flock': ['a mass of', 'a world of', 'army', 'assemble', 'assembly', 'band', 'band together', 'bang', 'bangs', 'bevy', 'body', 'brethren'],
    'flock to': ['act with', 'align with', 'get together with', 'go along with', 'go in with', 'join', 'join hands with', 'join up with', 'join with', 'line up with', 'rally round', 'range with'],
    'flock together': ['accompany', 'assemble', 'associate', 'associate with', 'assort with', 'attend', 'band together', 'bunch', 'bunch up', 'chum', 'chum together', 'chum with'],
    'floe': ['dry ice', 'berg', 'calf', 'cryosphere', 'firn', 'frazil', 'frozen water', 'glaciation', 'glacier', 'glacieret', 'glaze', 'glazed frost'],
    'flog': ['baste', 'bastinado', 'beat', 'belabor', 'belt', 'birch', 'buffet', 'cane', 'castigate', 'chastise', 'club', 'cowhide'],
    'flood': ['niagara', 'abundance', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'acres', 'addition', 'advance', 'affluence'],
    'flood the market': ['be prodigal with', 'close out', 'convert into cash', 'cut under', 'deluge', 'dump', 'effect a sale', 'engulf', 'flood', 'inundate', 'job', 'make a sale'],
    'flood tide': ['amplitude', 'congestion', 'direct tide', 'ebb', 'ebb and flow', 'ebb tide', 'flood', 'flow', 'flux', 'flux and reflux', 'full', 'full tide'],
    'flooded': ['afloat', 'at flood', 'awash', 'bathed', 'buried', 'deluged', 'dipped', 'drenched', 'dribbling', 'dripping', 'dripping wet', 'drowned'],
    'floodgate': ['aboideau', 'air lock', 'avenue', 'blowhole', 'channel', 'chute', 'debouch', 'dock gate', 'door', 'egress', 'emunctory', 'escape'],
    'floodlight': ['arc', 'arc light', 'beacon', 'brighten', 'brighten up', 'color filter', 'dimmer', 'enlighten', 'floats', 'flood', 'flood with light', 'footlights'],
    'floor': ['addle', 'agora', 'amaze', 'amphitheater', 'answer', 'answer conclusively', 'arena', 'argue down', 'asphalt', 'astonish', 'astound', 'athletic field'],
    'floored': ['addled', 'all up with', 'armored', 'at a loss', 'baffled', 'bamboozled', 'beat', 'beaten', 'bested', 'buffaloed', 'cased', 'ceiled'],
    'floorer': ['chinese puzzle', 'baffling problem', 'brain twister', 'clincher', 'conclusive argument', 'crossword puzzle', 'crusher', 'crux', 'enigma', 'enigmatic question', 'finisher', 'jigsaw puzzle'],
    'flooring': ['adobe', 'ashlar', 'base', 'basement', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock', 'brick', 'bricks and mortar', 'carpet'],
    'floorwalker': ['big brother', 'agent', 'auditor', 'boatswain', 'boss', 'chief', 'clerk', 'comptroller', 'controller', 'floor manager', 'floorman', 'foreman'],
    'floozy': ['jezebel', 'bad woman', 'baggage', 'bitch', 'broad', 'chippy', 'clitoromaniac', 'cocotte', 'drab', 'easy lay', 'easy woman', 'frail sister'],
    'flop': ['grand guignol', 'passion play', 'tom show', 'also-ran', 'alter', 'ameliorate', 'antimasque', 'audience success', 'bag', 'ballet', 'bang', 'bankrupt'],
    'flophouse': ['boardinghouse', 'dorm', 'dormitory', 'doss house', 'fleabag', 'guest house', 'hospice', 'hostel', 'hostelry', 'hotel', 'inn', 'lodging house'],
    'floppy': ['anemic', 'asthenic', 'bagging', 'baggy', 'ballooning', 'bloodless', 'chicken', 'cowardly', 'debilitated', 'drooping', 'droopy', 'dull'],
    'flora': ['ceres', 'cora', 'demeter', 'dionysos', 'dionysus', 'frey', 'gaea', 'gaia', 'kore', 'persephassa', 'persephone', 'pomona'],
    'floral': ['blooming', 'bloomy', 'blossoming', 'efflorescent', 'floreate', 'florescent', 'floriate', 'floriated', 'floricultural', 'florid', 'flowered', 'flowering'],
    'florescence': ['anthesis', 'bloom', 'blooming', 'blossom', 'blossoming', 'blow', 'blowing', 'budtime', 'early years', 'efflorescence', 'flowerage', 'flowering'],
    'florescent': ['blooming', 'bloomy', 'blossoming', 'budding', 'burgeoning', 'crescent', 'developed', 'efflorescent', 'floral', 'floreate', 'floriate', 'floriated'],
    'floriculture': ['bloom', 'blossom', 'blow', 'citriculture', 'floret', 'floscule', 'flower', 'flower gardening', 'flower-growing', 'floweret', 'fruit-growing', 'gardening'],
    'florid': ['gothic', 'adorned', 'arabesque', 'aureate', 'baroque', 'befrilled', 'bizarre', 'blooming', 'bloomy', 'blossoming', 'blowzed', 'blowzy'],
    'florist': ['antique store', 'apothecary', 'automobile showroom', 'baker', 'bookdealer', 'bookseller', 'bookstore', 'bootery', 'butcher', 'candy store', 'chandler', 'chemist'],
    'floss': ['blubber', 'breeze', 'butter', 'clay', 'cushion', 'dough', 'down', 'eiderdown', 'feather bed', 'feathers', 'fleece', 'flue'],
    'flossy': ['ambitious', 'capillary', 'cirrose', 'cirrous', 'classy', 'downy', 'fancy', 'feathery', 'fibered', 'fibroid', 'fibrous', 'flagelliform'],
    'flotation': ['coming out', 'curtain raiser', 'debut', 'embarkation', 'embarkment', 'first appearance', 'floating', 'inaugural address', 'inauguration', 'induction', 'initiation', 'installation'],
    'flotilla': ['naval construction battalion', 'rn', 'royal navy', 'seabees', 'usn', 'united states navy', 'argosy', 'armada', 'bottoms', 'coast guard', 'division', 'escadrille'],
    'flotsam and jetsam': ['castaway', 'castoff', 'derelict', 'discard', 'dogie', 'flotsam', 'foundling', 'jetsam', 'junk', 'lagan', 'orphan', 'refuse'],
    'flounce': ['amble', 'antic', 'barge', 'bead', 'beading', 'bejewel', 'beribbon', 'bespangle', 'binding', 'blunder', 'bob', 'bordering'],
    'flounder': ['agonize over', 'alternate', 'back and fill', 'be all thumbs', 'be at sea', 'be hard put', 'be uncertain', 'beat about', 'blunder', 'blunder away', 'blunder into', 'blunder on'],
    'flour': ['abrade', 'air pollution', 'alabaster', 'atomize', 'attritus', 'beat', 'besprinkle', 'bran', 'bray', 'bread', 'brecciate', 'chalk'],
    'flourish': ['acciaccatura', 'adjunct', 'adorn', 'adornment', 'advertise', 'affect', 'air', 'amplify', 'appoggiatura', 'arabesque', 'arrangement', 'arrive'],
    'flourishing': ['abundant', 'balmy', 'blooming', 'blossoming', 'booming', 'bountiful', 'brandish', 'brandishing', 'budding', 'burgeoning', 'bursting', 'bursting out'],
    'flout': ['parthian shot', 'abase', 'affront', 'aspersion', 'atrocity', 'back answer', 'barrack', 'belittle', 'blaspheme', 'break', 'break the law', 'brickbat'],
    'flow': ['atticism', 'brownian movement', 'abound', 'abundance', 'accrue from', 'advance', 'affluence', 'afflux', 'affluxion', 'air flow', 'ample sufficiency', 'ampleness'],
    'flow on': ['advance', 'continue', 'deluge', 'dip', 'drift along', 'drown', 'duck', 'dunk', 'elapse', 'endure', 'expire', 'flit'],
    'flower': ['chinese lantern', 'christmas rose', 'eglantine', 'acacia', 'advance', 'androecium', 'anther', 'arrowhead', 'asiaticism', 'aster', 'attain majority', 'axiom'],
    'flower bed': ['japanese garden', 'alpine garden', 'arboretum', 'bed', 'bog garden', 'border', 'botanical garden', 'dry garden', 'flower garden', 'garden', 'garden spot', 'grape ranch'],
    'flower child': ['bohemian', 'beatnik', 'deviant', 'dissenter', 'dropout', 'freak', 'heretic', 'hippie', 'maverick', 'misfit', 'nonconformist', 'nonjuror'],
    'flower power': ['bomfog', 'benthamism', 'christian charity', 'christian love', 'agape', 'altruism', 'amperage', 'armipotence', 'authority', 'beef', 'beneficence', 'benevolence'],
    'flowered': ['adorned', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'blooming', 'bloomy', 'blossoming', 'decked out'],
    'flowering': ['accomplishment', 'advance', 'advancement', 'amplification', 'anthesis', 'balmy', 'bloom', 'blooming', 'bloomy', 'blossom', 'blossoming', 'blow'],
    'flowers': ['festschrift', 'album', 'ana', 'analects', 'anthology', 'beauties', 'canon', 'catamenia', 'catamenial discharge', 'chrestomathy', 'clippings', 'collectanea'],
    'flowery': ['gongoristic', 'adorned', 'affected', 'allusive', 'ambrosial', 'arabesque', 'aromatic', 'artificial', 'aureate', 'balmy', 'baroque', 'befrilled'],
    'flowing': ['affluent', 'ascending', 'autograph', 'autographic', 'axial', 'back', 'back-flowing', 'backward', 'balanced', 'calligraphic', 'cascading', 'chirographic'],
    'flu': ['african lethargy', 'asiatic cholera', 'asiatic flu', 'chagres fever', 'german measles', 'haverhill fever', 'hong kong flu', 'acute articular rheumatism', 'acute bronchitis', 'adenoiditis', 'ague', 'alkali disease'],
    'flub': ['bad job', 'bevue', 'bitch', 'bitch up', 'blow', 'blunder', 'bobble', 'boggle', 'bollix', 'bonehead into it', 'bonehead play', 'boner'],
    'fluctuate': ['alternate', 'back and fill', 'bob', 'bobble', 'careen', 'change', 'chop and change', 'coggle', 'dangle', 'dither', 'ebb and flow', 'equivocate'],
    'fluctuating': ['adrift', 'afloat', 'alternating', 'amorphous', 'broken', 'capricious', 'careening', 'catchy', 'changeable', 'changeful', 'choppy', 'desultory'],
    'fluctuation': ['alternation', 'arrhythmia', 'asking price', 'bearish prices', 'bid price', 'book value', 'brokenness', 'bullish prices', 'call price', 'capriciousness', 'choppiness', 'closing price'],
    'flue': ['air', 'blubber', 'breeze', 'bubble', 'butter', 'chaff', 'chimney', 'chimney corner', 'chip', 'clay', 'cobweb', 'cork'],
    'fluency': ['atticism', 'abundance', 'affluence', 'afflux', 'affluxion', 'amplitude', 'appropriateness', 'articulateness', 'big mouth', 'candor', 'chasteness', 'chastity'],
    'fluent': ['affluent', 'all jaw', 'apt', 'articulate', 'ascending', 'axial', 'back', 'back-flowing', 'backward', 'balanced', 'candid', 'chatty'],
    'fluently': ['ardently', 'effectively', 'effusively', 'eloquently', 'expressively', 'fervently', 'forcefully', 'glibly', 'glowingly', 'graphically', 'gushingly', 'impressively'],
    'fluff': ['irish bull', 'aerate', 'air', 'anacoluthon', 'bad job', 'ball up', 'bevue', 'bloomer', 'blooper', 'blow', 'blubber', 'blunder'],
    'fluffy': ['airy', 'attenuate', 'attenuated', 'birdbrained', 'birdwitted', 'bubbly', 'dainty', 'delicate', 'downy', 'ethereal', 'featherbrained', 'feathery'],
    'fluid': ['able to adapt', 'adaptable', 'adjustable', 'aerodynamics', 'afterdamp', 'air', 'alterable', 'alterative', 'aqueous', 'atmosphere', 'beverage', 'blackdamp'],
    'fluidity': ['adaptability', 'adjustability', 'aeriness', 'alterability', 'changeability', 'changeableness', 'changefulness', 'chylifaction', 'chylification', 'ethereality', 'flatulence', 'flatuosity'],
    'fluidize': ['aerate', 'aerify', 'atomize', 'carbonate', 'chlorinate', 'colliquate', 'cut', 'decoagulate', 'decoct', 'deliquesce', 'dissolve', 'distill'],
    'fluke': ['chilopoda', 'chordata', 'echiuroidea', 'ectoprocta', 'entoprocta', 'monoplacophora', 'nemertinea', 'phoronidea', 'accident', 'adventure', 'blessing', 'break'],
    'fluky': ['accidental', 'adventitious', 'aleatory', 'casual', 'causeless', 'chance', 'chancy', 'contingent', 'destinal', 'dicey', 'fatal', 'fatidic'],
    'flume': ['abysm', 'abyss', 'aqueduct', 'arroyo', 'avenue', 'bed', 'blowhole', 'box canyon', 'breach', 'break', 'canal', 'canyon'],
    'flummery': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'blabber', 'blather', 'bombast', 'claptrap', 'double-talk', 'drivel'],
    'flummox': ['abash', 'addle', 'addle the wits', 'baffle', 'balk', 'ball up', 'becloud', 'bedazzle', 'befuddle', 'bewilder', 'blast', 'bomb'],
    'flump': ['bump', 'cave', 'cave in', 'chink', 'click', 'clink', 'clop', 'clump', 'clunk', 'crump', 'decline', 'droop'],
    'flunk': ['be found wanting', 'be unsuccessful', 'bollix', 'botch', 'bungle', 'bust', 'come to grief', 'fail', 'fail of success', 'fiasco', 'flunk out', 'foozle'],
    'flunkey': ['apple-polisher', 'doormat', 'footman', 'gofer', 'hanger-on', 'hireling', 'inferior', 'jackal', 'lackey', 'lickspittle', 'menial', 'minion'],
    'flunky': ['adherent', 'appendage', 'apple-polisher', 'ass-licker', 'attendant', 'backscratcher', 'backslapper', 'blue-collar worker', 'bootlick', 'bootlicker', 'breadwinner', 'brown-nose'],
    'fluorescence': ['autoluminescence', 'bioluminescence', 'cathode luminescence', 'chemicoluminescence', 'chemiluminescence', 'corposant', 'crystalloluminescence', 'double corposant', 'electroluminescence', 'fata morgana', 'fox fire', 'ignis fatuus'],
    'fluoroscopy': ['x-ray photometry', 'x-ray spectrometry', 'atom-tagging', 'curiescopy', 'orthodiagraphy', 'photofluorography', 'radiation physics', 'radiobiology', 'radiochemistry', 'radiography', 'radiological physics', 'radiology'],
    'flurry': ['scotch mist', 'activity', 'addle', 'addle the wits', 'ado', 'agitate', 'agitation', 'air speed', 'asking price', 'avalanche', 'ball up', 'bearish prices'],
    'flush': ['hygeia', 'sro', 'ablution', 'abounding', 'abounding in riches', 'abundant', 'ace', 'adjacent', 'affluent', 'afterglow', 'air glow', 'align'],
    'flushed': ['ablaze', 'afire', 'ardent', 'baking', 'beaming', 'blistering', 'blithe', 'blithesome', 'bloated', 'bloated with pride', 'blooming', 'blowzed'],
    'fluster': ['addle', 'addle the wits', 'ado', 'agitate', 'agitation', 'baffle', 'bafflement', 'ball up', 'becloud', 'bedazzle', 'befuddle', 'befuddlement'],
    'flustered': ['addled', 'agitated', 'balled-up', 'beery', 'bemused', 'besotted', 'blind drunk', 'bothered', 'chaotic', 'confused', 'crapulent', 'crapulous'],
    'flute': ['english horn', 'pandean pipe', 'aulos', 'bagpipe', 'bark', 'basset horn', 'basset oboe', 'bassoon', 'bawl', 'bellow', 'bezel', 'blare'],
    'fluted': ['canaliculate', 'canaliculated', 'chamfered', 'channeled', 'corduroy', 'corduroyed', 'corrugate', 'corrugated', 'costate', 'creased', 'crimped', 'cut'],
    'flutter': ['bebung', 'addle', 'addle the wits', 'ado', 'agiotage', 'agitate', 'agitation', 'arbitrage', 'arrhythmia', 'asking price', 'ball up', 'barrage'],
    'fluttering': ['aflicker', 'agitated', 'airborne', 'beating', 'bickering', 'birdies', 'blinking', 'blooping', 'blurping', 'bustling', 'clicking', 'dance'],
    'fluttery': ['aflicker', 'agitated', 'all shook up', 'all-overish', 'bickering', 'blinking', 'brainless', 'bustling', 'dancing', 'desultory', 'dizzy', 'empty-headed'],
    'flux': ['asa scale', 'bm', 'british candle', 'brownian movement', 'hefner candle', 'scheiner scale', 'abscess', 'add', 'advance', 'affluence', 'afflux', 'affluxion'],
    'flux and reflux': ['lissajous figure', 'alternation', 'back-and-forth', 'coming and going', 'direct tide', 'ebb', 'ebb and flow', 'ebb tide', 'flood', 'flood tide', 'flow', 'flux'],
    'fluxional': ['affluent', 'confluent', 'coursing', 'decurrent', 'defluent', 'diffluent', 'flowing', 'fluent', 'fluid', 'fluidal', 'fluidic', 'fluxible'],
    'fly': ['abscond', 'absquatulate', 'advance', 'aeroplane', 'airlift', 'airplane', 'applique', 'arachnid', 'arise', 'arthropod', 'ascend', 'aspire'],
    'fly the coop': ['bail out', 'break away', 'break jail', 'break loose', 'cut loose', 'escape', 'escape prison', 'evade', 'flee', 'get away', 'get clear of', 'get free'],
    'fly-by-night': ['brittle', 'capricious', 'changeable', 'corruptible', 'deciduous', 'dying', 'ephemeral', 'evanescent', 'fading', 'fickle', 'fleeting', 'flitting'],
    'flyblown': ['barfy', 'blasted', 'blighted', 'blown', 'crappy', 'despoiled', 'disgusting', 'fecal', 'feculent', 'fetid', 'filthy', 'foul'],
    'flyer': ['amtrak', 'jehu', 'acrobat', 'aerialist', 'aeronaut', 'aeroplaner', 'aeroplanist', 'agiotage', 'air pilot', 'airplanist', 'arbitrage', 'astronaut'],
    'flying': ['aeronautics', 'agile', 'air service', 'airborne', 'airline', 'ascending', 'astronautics', 'aviation', 'axial', 'back', 'back-flowing', 'backward'],
    'flying dutchman': ['ab', 'ahasuerus', 'ancient mariner', 'argonaut', 'brocken specter', 'dylan', 'goliard', 'neptune', 'od', 'odysseus', 'oisin', 'ossian'],
    'flying start': ['advantage', 'alpha', 'beginning', 'blast-off', 'bulge', 'coign of vantage', 'commencement', 'creation', 'cutting edge', 'dawn', 'drop', 'edge'],
    'flyleaf': ['acknowledgments', 'back', 'back matter', 'bastard title', 'bibliography', 'catch line', 'catchword', 'colophon', 'contents', 'contents page', 'copyright page', 'dedication'],
    'flyover': ['bifrost', 'bascule bridge', 'bateau bridge', 'bridge', 'cantilever bridge', 'caravan', 'carrefour', 'catwalk', 'cavalcade', 'cloverleaf', 'column', 'cortege'],
    'flyspeck': ['ace', 'atom', 'bespeckle', 'bespot', 'bit', 'bloodstain', 'blot', 'blotch', 'blur', 'brand', 'crumb', 'dab'],
    'flyweight': ['chinese boxer', 'bantamweight', 'black belt', 'boxer', 'brown belt', 'bruiser', 'catchweight', 'featherweight', 'fighter', 'fisticuffer', 'heavyweight', 'karate expert'],
    'flywheel effect': ['indian file', 'array', 'articulation', 'bank', 'buzz', 'catena', 'catenation', 'chain', 'chain reaction', 'chaining', 'concatenation', 'connection'],
    'foal': ['houyhnhnm', 'be confined', 'bear', 'bear a child', 'bear young', 'birdling', 'brood mare', 'calf', 'calve', 'cast', 'catling', 'charger'],
    'foam': ['foamite', 'acid', 'aerate', 'air', 'alabaster', 'automatic sprinkler', 'beat', 'blubber', 'boil', 'breakers', 'breeze', 'bubble'],
    'foamy': ['airy', 'barmy', 'bubbly', 'downy', 'ethereal', 'feathery', 'fluffy', 'foam-flecked', 'frothy', 'gossamery', 'heady', 'imponderous'],
    'fob': ['anklet', 'armlet', 'bag', 'balloon', 'bangle', 'beads', 'bijou', 'bladder', 'bracelet', 'breastpin', 'brooch', 'chain'],
    'focal': ['approaching', 'arch', 'asymptotic', 'banner', 'basic', 'bedrock', 'capital', 'cardinal', 'central', 'centralized', 'centred', 'centripetal'],
    'focus': ['adductor', 'approach', 'asymptote', 'attractant', 'attrahent', 'axiom', 'blurred', 'blurry', 'bottleneck', 'bring into focus', 'center', 'center of attraction'],
    'focus on': ['act on', 'act upon', 'address to', 'affect', 'allude to', 'attend closely to', 'attend to business', 'be alert', 'be obsessed with', 'bring to attention', 'bring to notice', 'call attention to'],
    'fodder': ['barley', 'bed', 'bed down', 'bird seed', 'board', 'bran', 'bread', 'break', 'bridle', 'brush', 'cat food', 'chicken feed'],
    'foe': ['adversary', 'antagonist', 'archenemy', 'assailant', 'bitter enemy', 'combatant', 'devil', 'enemy', 'foeman', 'muddlement', 'open enemy', 'opponent'],
    'fog': ['cat', 'london fog', 'london special', 'addle', 'addle the wits', 'aerospace', 'aerosphere', 'aftergrass', 'air hole', 'air pocket', 'airspace', 'amorphousness'],
    'foggy': ['addlebrained', 'addled', 'addleheaded', 'addlepated', 'aleatoric', 'aleatory', 'amorphous', 'beclouded', 'befuddled', 'blear', 'blear-witted', 'bleared'],
    'foghorn': ['klaxon', 'mayday', 'roman candle', 'sos', 'aid to navigation', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert'],
    'fogy': ['methuselah', 'antediluvian', 'antique', 'back number', 'conservationist', 'conservatist', 'conservative', 'dad', 'diehard', 'dodo', 'dotard', 'elder'],
    'fogyish': ['backward', 'conservative', 'die-hard', 'fuddy-duddy', 'nonprogressive', 'old-fashioned', 'old-fogy', 'old-fogyish', 'old-line', 'opposed to change', 'preservative', 'ravaged with age'],
    'foible': ['bad habit', 'besetting sin', 'blemish', 'bug', 'catch', 'crack', 'crotchet', 'defect', 'defection', 'deficiency', 'drawback', 'eccentricity'],
    'foil': ['roscius', 'actor', 'actress', 'antagonist', 'antipode', 'antipodes', 'antipole', 'antithesis', 'antonym', 'background', 'background detail', 'bad guy'],
    'foiled': ['baffled', 'balked', 'betrayed', 'bilked', 'blasted', 'blighted', 'chapfallen', 'crestfallen', 'crossed', 'crushed', 'dashed', 'defeated'],
    'foist': ['bamboozle', 'barge in', 'beguile', 'break in', 'break in upon', 'burst in', 'butt in', 'charge in', 'cheat', 'come between', 'crash', 'crash in'],
    'fold': ['ko', 'alveolation', 'alveolus', 'antrum', 'arena', 'armpit', 'assembly', 'average', 'bang', 'bar', 'barricade', 'basin'],
    'folded': ['creased', 'crimped', 'dog-eared', 'doubled', 'flexible', 'flounced', 'fluted', 'foldable', 'folding', 'gathered', 'plaited', 'pleated'],
    'folder': ['book end', 'book support', 'book table', 'book tray', 'book truck', 'bookcase', 'bookholder', 'booklet', 'bookrack', 'bookrest', 'bookshelf', 'bookstack'],
    'folderol': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'absurdity', 'amphigory', 'anacrusis', 'babble', 'babblement', 'bagatelle', 'balderdash'],
    'foliated': ['bowery', 'branched', 'branching', 'branchy', 'filmy', 'foliaceous', 'foliaged', 'foliate', 'foliose', 'in layers', 'lamellar', 'lamellate'],
    'foliation': ['accounting', 'census', 'counting', 'dactylonomy', 'delamination', 'desquamation', 'enumeration', 'exfoliation', 'flakiness', 'foliage', 'frondage', 'furfuration'],
    'folie': ['aberration', 'abnormality', 'alienation', 'brain damage', 'brainsickness', 'clouded mind', 'craziness', 'daftness', 'dementedness', 'dementia', 'derangement', 'disorientation'],
    'folio': ['acknowledgments', 'article', 'back', 'back matter', 'bastard title', 'best seller', 'bibliography', 'book', 'book end', 'book support', 'book table', 'book tray'],
    'folk': ['everyman', 'john doe', 'public', 'acknowledged', 'admitted', 'animal kingdom', 'blood', 'body politic', 'breed', 'brood', 'citizenry', 'clan'],
    'folk hero': ['big name', 'celebrity', 'constellation', 'cynosure', 'figure', 'galaxy', 'great man', 'hero', 'heroine', 'idol', 'immortal', 'important person'],
    'folk singer': ['ballad singer', 'balladeer', 'bard', 'fili', 'folk-rock singer', 'gleeman', 'jongleur', 'minnesinger', 'minstrel', 'rhapsode', 'rhapsodist', 'scop'],
    'folklore': ['mishnah', 'spiritus mundi', 'sunna', 'talmud', 'ancient wisdom', 'archetypal myth', 'archetypal pattern', 'charm', 'common law', 'custom', 'fairy lore', 'fairyism'],
    'folks': ['agnate', 'ancestry', 'blood', 'blood relation', 'blood relative', 'brood', 'children', 'clansman', 'cognate', 'collateral', 'collateral relative', 'connections'],
    'folksiness': ['bohemianism', 'affability', 'casualness', 'common touch', 'cordiality', 'ease', 'easiness', 'easygoingness', 'familiarity', 'graciousness', 'homeliness', 'homeyness'],
    'folksy': ['bohemian', 'affable', 'casual', 'cordial', 'degage', 'easy', 'easygoing', 'familiar', 'free and easy', 'gracious', 'haymish', 'homely'],
    'folktale': ['marchen', 'mishnah', 'spiritus mundi', 'sunna', 'talmud', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'ancient wisdom', 'apologue'],
    'folkway': ['acculturation', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'bearing', 'behavior', 'behavior pattern', 'behavioral norm'],
    'follicle': ['alveolation', 'alveolus', 'antrum', 'armpit', 'basin', 'boll', 'bowl', 'burr', 'capsule', 'cavity', 'cod', 'concave'],
    'follow': ['abide by', 'absorb', 'accept', 'accept advice', 'accommodate', 'accommodate with', 'accompany', 'accord', 'act up to', 'adapt', 'adapt to', 'address'],
    'follow through': ['ps', 'parthian shot', 'addendum', 'afterthought', 'appendix', 'back matter', 'chorus', 'coda', 'codicil', 'colophon', 'conclusion', 'consequence'],
    'follow up': ['ps', 'parthian shot', 'addendum', 'afterthought', 'anamnesis', 'appendix', 'associative anamnesis', 'attend', 'back matter', 'carry through', 'case history', 'catamnesis'],
    'follower': ['christian', 'god-fearing man', 'accepter', 'addict', 'adherent', 'adherents', 'admirer', 'adorer', 'advocate', 'aficionado', 'amateur', 'amorist'],
    'following': ['adherent', 'after', 'afterlife', 'alike', 'aped', 'appendage', 'appendant', 'attendance', 'attendant', 'audience', 'behind', 'below'],
    'folly': ['absurdity', 'absurdness', 'act of folly', 'asininity', 'battiness', 'blunder', 'brainlessness', 'buffoonery', 'clownishness', 'crackpottedness', 'crankiness', 'craziness'],
    'foment': ['abate', 'abet', 'advance', 'agitate', 'agitation', 'allay', 'alleviate', 'anesthetize', 'annoy', 'appease', 'arouse', 'assuage'],
    'fomentation': ['aggravation', 'agitation', 'animation', 'arousal', 'arousing', 'bluster', 'brawl', 'broil', 'brouhaha', 'cacophony', 'chaos', 'commotion'],
    'fond': ['addicted to', 'adoring', 'affectionate', 'apish', 'asinine', 'aspiring', 'assured', 'attached to', 'batty', 'befooled', 'beguiled', 'besotted'],
    'fond of': ['aching for', 'attached to', 'bent on', 'crazy about', 'crazy to', 'desirous of', 'devoted to', 'dying for', 'dying to', 'enamored of', 'fain of', 'far gone on'],
    'fondle': ['bear', 'bosom', 'care for', 'caress', 'cherish', 'clasp', 'cling to', 'clip', 'cocker', 'coddle', 'cosset', 'cradle'],
    'fondling': ['amorous dalliance', 'billing and cooing', 'bundling', 'caressing', 'cosset', 'cuddling', 'dalliance', 'darling', 'favorite', 'hugging', 'idol', 'jewel'],
    'fondness': ['amor', 'christian love', 'eros', 'platonic love', 'admiration', 'adoration', 'affection', 'agape', 'ardency', 'ardor', 'attachment', 'blind faith'],
    'font': ['affusion', 'ascender', 'aspergation', 'aspersion', 'back', 'baptism', 'baptismal gown', 'baptismal regeneration', 'baptistery', 'baptizement', 'bastard type', 'beard'],
    'food': ['aliment', 'bread', 'chow', 'comestibles', 'commons', 'eatables', 'eats', 'edibles', 'feed', 'foodstuff', 'foodstuffs', 'grub'],
    'foofaraw': ['ado', 'agitation', 'bluster', 'bother', 'bravery', 'brawl', 'broil', 'brouhaha', 'cacophony', 'chaos', 'chiffon', 'clinquant'],
    'fool': ['columbine', 'hanswurst', 'harlequin', 'pantalone', 'pantaloon', 'polichinelle', 'pulcinella', 'punch', 'punchinello', 'scaramouch', 'ament', 'apish'],
    'fool around': ['antic', 'be foolish', 'be stupid', 'caper', 'caracole', 'carry on', 'cavort', 'clown', 'clown around', 'coquet', 'curvet', 'cut a dido'],
    'fool away': ['blow', 'blunder away', 'consume', 'dally away', 'diddle away', 'dissipate', 'dribble away', 'drivel away', 'fritter', 'fritter away', 'idle away', 'muddle away'],
    'fool notion': ['absurd idea', 'boutade', 'brainstorm', 'capriccio', 'caprice', 'conceit', 'crank', 'craze', 'crazy idea', 'crotchet', 'fad', 'fancy'],
    'foolable': ['artless', 'befoolable', 'cullible', 'deceivable', 'deludable', 'dupable', 'easy', 'exploitable', 'green', 'gullible', 'hoaxable', 'hoodwinkable'],
    'foolery': ['parthian shot', 'asininity', 'back answer', 'banter', 'battiness', 'brainlessness', 'buffoonery', 'caustic remark', 'clownishness', 'comeback', 'crack', 'crackpottedness'],
    'foolhardy': ['adventuresome', 'adventurous', 'audacious', 'bold', 'brash', 'careless', 'cheeky', 'daredevil', 'daring', 'death-defying', 'devil-may-care', 'enterprising'],
    'foolheaded': ['apish', 'asinine', 'batty', 'befooled', 'beguiled', 'besotted', 'brainless', 'buffoonish', 'cockeyed', 'crazy', 'credulous', 'daffy'],
    'fooling': ['badinage', 'bamboozlement', 'banter', 'bantering', 'befooling', 'bluffing', 'booing', 'buffoonery', 'calculated deception', 'catcalling', 'chaff', 'chaffing'],
    'foolish': ['pickwickian', 'absurd', 'airy', 'apish', 'arch', 'asinine', 'batty', 'befooled', 'beguiled', 'bemused', 'besotted', 'beyond belief'],
    'foolishness': ['urdummheit', 'absurdity', 'absurdness', 'big deal', 'blank mind', 'blankmindedness', 'blankness', 'brainlessness', 'bull', 'bunk', 'calm of mind', 'craziness'],
    'foolproof': ['adaptable', 'airtight', 'ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'certain', 'convenient', 'corrosionproof', 'dampproof', 'dependable', 'ductile'],
    'foot': ['alexandrine', 'accent', 'accentuation', 'add', 'amble', 'ambulate', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'ankle', 'antispast'],
    'foot candle': ['asa scale', 'british candle', 'hefner candle', 'scheiner scale', 'bougie decimale', 'candle', 'candle lumen', 'candle power', 'candle-foot', 'candle-hour', 'candle-meter', 'decimal candle'],
    'foot dragging': ['micawberish', 'ambling', 'antipathy', 'arrest', 'arrestation', 'arrestment', 'averseness', 'aversion', 'backward', 'backwardness', 'blockage', 'blocking'],
    'foot soldier': ['zouave', 'ambulator', 'backpacker', 'bersagliere', 'carabineer', 'chasseur', 'dogface', 'doughfoot', 'expert rifleman', 'foot passenger', 'foot traveler', 'footslogger'],
    'footage': ['distance', 'extension', 'extent', 'infinity', 'length', 'lengthiness', 'linear measures', 'long time', 'longitude', 'longness', 'measure', 'mileage'],
    'foothills': ['anthill', 'barrow', 'brae', 'butte', 'down', 'drumlin', 'dune', 'fell', 'hill', 'hillock', 'hummock', 'knob'],
    'foothold': ['advantage', 'bear hug', 'bite', 'clamp', 'clasp', 'clench', 'clinch', 'cling', 'clinging', 'clutch', 'death grip', 'embrace'],
    'footing': ['anschauung', 'account', 'adding', 'advantage', 'allowance', 'ambit', 'ambling', 'ambulation', 'angle', 'angle of vision', 'assessment', 'backpacking'],
    'footloose and fancy-free': ['afoot and lighthearted', 'at large', 'at liberty', 'circumforaneous', 'clear', 'detached', 'discursive', 'disengaged', 'divagatory', 'drifting', 'easygoing', 'emancipated'],
    'footnote': ['adversaria', 'aide-memoire', 'annotation', 'apparatus criticus', 'comment', 'commentary', 'commentation', 'docket', 'entry', 'exegesis', 'gloss', 'item'],
    'footprint': ['boss', 'bump', 'colophon', 'concavity', 'convexity', 'dactylogram', 'dactylograph', 'dent', 'dint', 'embossment', 'excrescence', 'fingerprint'],
    'footrest': ['doorstep', 'foothold', 'footing', 'footplate', 'footrail', 'footstep', 'hold', 'locus standi', 'perch', 'purchase', 'rest', 'riser'],
    'footslog': ['amble', 'backpack', 'barge', 'bowl along', 'bundle', 'clump', 'defile', 'drag', 'file', 'file off', 'flounce', 'foot'],
    'footsore': ['debilitated', 'drooping', 'droopy', 'enervated', 'enfeebled', 'fagged', 'faint', 'fainting', 'fatigued', 'feeling faint', 'flagging', 'frazzled'],
    'footstep': ['boss', 'bump', 'clop', 'colophon', 'concavity', 'convexity', 'dactylogram', 'dactylograph', 'dent', 'dint', 'doorstep', 'embossment'],
    'footstone': ['arch', 'barrow', 'boundary stone', 'brass', 'bust', 'cairn', 'cenotaph', 'column', 'cornerstone', 'cromlech', 'cross', 'cup'],
    'footwork': ['ambling', 'ambulation', 'backpacking', 'footing', 'footing it', 'going on foot', 'hiking', 'hitchhiking', 'hitching', 'hoofing', 'legwork', 'lumbering'],
    'foozle': ['bad job', 'bevue', 'bitch up', 'bloomer', 'blooper', 'blow', 'blunder', 'bobble', 'boggle', 'bollix', 'bonehead play', 'boner'],
    'fop': ['beau brummel', 'arbiter of fashion', 'beau', 'blade', 'blood', 'boulevardier', 'buck', 'clotheshorse', 'clubman', 'clubwoman', 'coxcomb', 'dandy'],
    'for': ['against', 'all for', 'as', 'as long as', 'as proxy for', 'as representing', 'as things go', 'because', 'being', 'being as how', 'cause', 'considering'],
    'for example': ['a propos', 'apropos', 'apropos of', 'as', 'as an example', 'as an instance', 'by the by', 'by the way', 'en passant', 'exempli gratia', 'for instance', 'in passing'],
    'for good': ['aye', 'ever', 'ever and again', 'ever and anon', 'evermore', 'for all time', 'for aye', 'for keeps', 'forever', 'forever and aye', 'forevermore', 'in all ages'],
    'for keeps': ['aye', 'ever', 'ever and again', 'ever and anon', 'evermore', 'for all time', 'for aye', 'for good', 'forever', 'forever and aye', 'forevermore', 'in all ages'],
    'for love': ['charitable', 'complimentary', 'costless', 'eleemosynary', 'expenseless', 'for free', 'for nothing', 'free', 'free as air', 'free for nothing', 'free gratis', 'free of charge'],
    'for nothing': ['charitable', 'complimentary', 'costless', 'eleemosynary', 'expenseless', 'for free', 'for love', 'free', 'free as air', 'free for nothing', 'free gratis', 'free of charge'],
    'for real': ['absolute', 'actively', 'actual', 'actually', 'assuredly', 'authentic', 'certainly', 'clearly', 'de facto', 'decidedly', 'demonstrably', 'down'],
    'forage': ['barley', 'beat', 'beat the bushes', 'bird seed', 'board', 'bran', 'bread', 'bunker', 'burrow', 'cat food', 'cater', 'chicken feed'],
    'foray': ['air attack', 'air raid', 'air strike', 'banditry', 'board', 'boarding', 'brigandage', 'brigandism', 'depredate', 'depredation', 'despoil', 'despoiling'],
    'forbear': ['abstain', 'abstain from', 'avoid', 'be patient', 'bear', 'bear with composure', 'bridle', 'carry on', 'carry through', 'cease', 'curb', 'desist'],
    'forbearance': ['abandonment', 'abeyance', 'abjuration', 'abjurement', 'abnegation', 'acceptance', 'avoidance', 'avoiding reaction', 'benevolence', 'cessation', 'charitableness', 'charity'],
    'forbearing': ['spartan', 'accepting', 'armed with patience', 'benevolent', 'charitable', 'clement', 'compassionate', 'conciliatory', 'disciplined', 'easy', 'easygoing', 'endurant'],
    'forbid': ['anticipate', 'avert', 'ban', 'bar', 'block', 'check', 'curb', 'debar', 'deflect', 'deny', 'deter', 'disallow'],
    'forbidden': ['banned', 'barred', 'contraband', 'forbade', 'forbid', 'illegal', 'illicit', 'nonpermissible', 'not permitted', 'off limits', 'out of bounds', 'outlawed'],
    'forbidden fruit': ['eighteenth amendment', 'prohibition party', 'volstead act', 'agacerie', 'allure', 'allurement', 'ambition', 'appeal', 'attraction', 'attractiveness', 'ban', 'beguilement'],
    'forbidding': ['olympian', 'abhorrent', 'abominable', 'aloof', 'awful', 'backward', 'bad', 'base', 'bashful', 'beastly', 'below contempt', 'beneath contempt'],
    'force': ['niagara', 'abuse', 'actuate', 'acuteness', 'administer', 'adventuresomeness', 'adventurousness', 'affective meaning', 'aggression', 'aggressiveness', 'ambitiousness', 'amount'],
    'force from': ['badger', 'blackmail', 'exact', 'extort', 'levy blackmail', 'pry loose from', 'rend', 'rend from', 'rip', 'rip from', 'screw', 'shake down'],
    'force majeure': ['act of god', 'amperage', 'armipotence', 'authority', 'beef', 'black power', 'brute force', 'certainty', 'charge', 'charisma', 'clout', 'cogence'],
    'force of habit': ['automatism', 'bad habit', 'characteristic', 'creature of habit', 'custom', 'habit', 'habit pattern', 'habitude', 'pattern', 'peculiarity', 'practice', 'praxis'],
    'force upon': ['administer', 'apply', 'bestow', 'dose', 'dose with', 'enforce upon', 'force', 'give', 'insist', 'lay on', 'mete out to', 'obtrude on'],
    'forced': ['herculean', 'latinate', 'affected', 'arduous', 'artificial', 'at odds', 'automatic', 'averse', 'awkward', 'backbreaking', 'blind', 'bombastic'],
    'forced march': ['acceleration', 'airing', 'amble', 'constitutional', 'double time', 'double-quick', 'double-quick time', 'festination', 'forwarding', 'hastening', 'hike', 'hurrying'],
    'forceful': ['accented', 'accentuated', 'acid', 'active', 'acute', 'adventuresome', 'adventurous', 'aggressive', 'ambitious', 'animated', 'armipotent', 'assertive'],
    'forcefully': ['actively', 'animatedly', 'ardently', 'briskly', 'cogently', 'con brio', 'deafeningly', 'dynamically', 'effectively', 'effectually', 'eloquently', 'energetically'],
    'forceless': ['emasculate', 'featherweight', 'feeble', 'flabby', 'impotent', 'inadequate', 'ineffective', 'ineffectual', 'inefficacious', 'invertebrate', 'lightweight', 'no-account'],
    'forcemeat': ['aspic', 'barbecue', 'boiled meat', 'bouilli', 'civet', 'dressing', 'farce', 'flesh', 'game', 'hachis', 'hash', 'jerky'],
    'forces': ['armed force', 'armed service', 'army', 'array', 'career soldiers', 'fighting force', 'fighting machine', 'firepower', 'ground forces', 'ground troops', 'hands', 'host'],
    'forcible': ['accented', 'accentuated', 'acid', 'active', 'acute', 'aggressive', 'animated', 'armipotent', 'assertive', 'authoritative', 'beefy', 'biting'],
    'ford': ['access', 'aisle', 'alley', 'ambulatory', 'aperture', 'arcade', 'artery', 'avenue', 'bank', 'bar', 'bestride', 'bypass'],
    'fore': ['ahead', 'ancient', 'ante', 'antecedent', 'anterior', 'anteriority', 'anticipatory', 'beforehand', 'bold front', 'brave face', 'brave front', 'chief'],
    'forearm': ['arm', 'arrange for', 'biceps', 'clear the decks', 'consider every angle', 'elbow', 'guard against', 'hedge', 'lay by', 'leave out nothing', 'look out for', 'make provision for'],
    'forearmed': ['agape', 'agog', 'all agog', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'awaiting', 'certain', 'confident', 'eager', 'expectant'],
    'forebears': ['ancestor', 'ancestors', 'announcer', 'antecedent', 'antecedents', 'ascendants', 'avant-garde', 'bellwether', 'buccinator', 'bushwhacker', 'elders', 'explorer'],
    'forebode': ['apprehend', 'be imminent', 'betoken', 'bludgeon', 'bode', 'bulldoze', 'cast a horoscope', 'cast a nativity', 'comminate', 'croak', 'denounce', 'divine'],
    'foreboding': ['abusive', 'actuarial prediction', 'advance notice', 'affect', 'affection', 'agitated', 'agitation', 'all-overish', 'all-overs', 'angst', 'anxiety', 'anxiety hysteria'],
    'forecast': ['accounting', 'actuarial prediction', 'adumbrate', 'analysis', 'anticipate', 'anticipation', 'apocalypse', 'arrange', 'augur', 'augury', 'braking', 'calculate'],
    'forecasting': ['actuarial prediction', 'aerography', 'aerology', 'anemology', 'apocalypse', 'barometry', 'climatography', 'climatology', 'foreboding', 'forecast', 'foreshowing', 'foresight'],
    'foreclose': ['anticipate', 'avert', 'bar', 'cut off', 'debar', 'deflect', 'deter', 'discourage', 'disendow', 'dishearten', 'disherison', 'disinherit'],
    'foreclosure': ['arrestation', 'debarment', 'determent', 'deterrence', 'discouragement', 'disendowment', 'disherison', 'disinheritance', 'disownment', 'dispossession', 'disseisin', 'estoppel'],
    'forefront': ['advance guard', 'airhead', 'anteriority', 'avant-garde', 'battle line', 'beachhead', 'bold front', 'brave face', 'brave front', 'bridgehead', 'display', 'facade'],
    'foreglimpse': ['anticipate', 'anticipation', 'contemplate', 'contemplation', 'discretion', 'envisage', 'envisagement', 'envision', 'envisionment', 'farseeingness', 'farsightedness', 'forecast'],
    'foregoing': ['above', 'aforegoing', 'aforementioned', 'aforenamed', 'aforesaid', 'antecedent', 'anterior', 'anticipatory', 'beforementioned', 'chief', 'ci-devant', 'earlier'],
    'foreground': ['anteriority', 'approach', 'approximation', 'bold front', 'brave face', 'brave front', 'closeness', 'confines', 'convergence', 'display', 'environs', 'facade'],
    'forehand': ['anterior', 'anticipative', 'anticipatory', 'beforetime', 'bright and early', 'chief', 'early', 'first', 'fore', 'forehanded', 'foremost', 'foresighted'],
    'forehanded': ['scotch', 'anticipant', 'anticipative', 'anticipatory', 'beforetime', 'bright and early', 'canny', 'careful', 'chary', 'cheeseparing', 'clairvoyant', 'conserving'],
    'foreign': ['accidental', 'adventitious', 'alien', 'apart', 'barbarian', 'barbaric', 'barbarous', 'curious', 'detached', 'disconnected', 'discrete', 'disjunct'],
    'foreign affairs': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'appeasement', 'balance of power', 'brinkmanship', 'coexistence', 'colonialism', 'compromise', 'containment', 'detente'],
    'foreign policy': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'appeasement', 'balance of power', 'brinkmanship', 'coexistence', 'colonialism', 'compromise', 'containment', 'detente'],
    'foreigner': ['uitlander', 'alien', 'barbarian', 'deracine', 'displaced person', 'emigre', 'exile', 'foreign devil', 'gringo', 'immigrant', 'new arrival', 'newcomer'],
    'foreknowledge': ['apprehension', 'clairvoyance', 'command', 'comprehension', 'conception', 'conceptualization', 'decree', 'foreboding', 'foredestiny', 'foregone conclusion', 'foreknowing', 'foreordination'],
    'foreman': ['big brother', 'auditor', 'boatswain', 'boss', 'chief', 'comptroller', 'controller', 'floor manager', 'floorman', 'floorwalker', 'gaffer', 'ganger'],
    'foremost': ['ahead', 'all-absorbing', 'antecedent', 'anterior', 'arch', 'banner', 'before', 'best', 'capital', 'cardinal', 'central', 'champion'],
    'forensics': ['debating', 'declamation', 'demagogism', 'elocution', 'eloquence', 'homiletics', 'lecturing', 'oratory', 'platform oratory', 'public speaking', 'pyrotechnics', 'rabble-rousing'],
    'forepaw': ['arch', 'clubfoot', 'digit', 'dog', 'extremity', 'fetlock', 'foot', 'forefoot', 'harefoot', 'heel', 'hoof', 'instep'],
    'forerun': ['announce', 'antecede', 'antedate', 'anticipate', 'be before', 'be early', 'blaze the trail', 'break the trail', 'come before', 'foreglimpse', 'foresee', 'foreshow'],
    'forerunner': ['gabriel', 'mahdi', 'advertisement', 'advertiser', 'ancestor', 'announcement', 'announcer', 'antecedent', 'augury', 'author', 'avant-garde', 'bell cow'],
    'foresee': ['anticipate', 'apprehend', 'approach', 'augur', 'await', 'be destined', 'be fated', 'be imminent', 'be to be', 'be to come', 'cast a horoscope', 'cast a nativity'],
    'foreseeable': ['anticipatable', 'apt', 'calculable', 'divinable', 'fair', 'foreknowable', 'foreseen', 'foretellable', 'hopeful', 'improbable', 'in the cards', 'liable'],
    'foreseeing': ['acute', 'anticipant', 'anticipatory', 'apocalyptic', 'apperceptive', 'appercipient', 'argute', 'astute', 'augural', 'auguring', 'clairvoyant', 'cogent'],
    'foreseen': ['anticipated', 'awaited', 'due', 'expected', 'forecast', 'foreknown', 'foreseeable', 'foreshown', 'foretold', 'hoped-for', 'imminent', 'in prospect'],
    'foreshadow': ['adumbrate', 'adumbration', 'augur', 'augury', 'auspicate', 'auspice', 'betoken', 'betokening', 'betokenment', 'bode', 'body forth', 'demonstrate'],
    'foreshorten': ['abbreviate', 'abridge', 'abstract', 'bob', 'boil down', 'capsulize', 'clip', 'compress', 'condense', 'contract', 'crop', 'curtail'],
    'foreshow': ['adumbrate', 'auspicate', 'betoken', 'bode', 'forebode', 'forerun', 'foreshadow', 'foretoken', 'harbinger', 'have a hunch', 'have an intimation', 'herald'],
    'foreshown': ['augured', 'forecast', 'foreknown', 'foreseen', 'foreshadowed', 'foretokened', 'foretold', 'indicated', 'predicted', 'prefigured', 'preindicated', 'presaged'],
    'foresight': ['esp', 'actuarial prediction', 'acuity', 'acumen', 'acuteness', 'aftertime', 'afteryears', 'anticipation', 'apocalypse', 'apperception', 'approach', 'arrangement'],
    'foresighted': ['acute', 'anticipant', 'anticipative', 'anticipatory', 'apperceptive', 'appercipient', 'argute', 'astute', 'beforetime', 'bright and early', 'clairvoyant', 'cogent'],
    'forest': ['afforestation', 'afforestational', 'arboreous', 'arboretum', 'back country', 'backwoods', 'bed', 'boondock', 'boondocks', 'borderland', 'bosky', 'braky'],
    'forest god': ['cailleac', 'ceres', 'cora', 'demeter', 'dionysos', 'dionysus', 'faunus', 'flora', 'frey', 'gaea', 'gaia', 'kore'],
    'forest ranger': ['audubon society', 'national wildlife service', 'sierra club', 'air warden', 'arboriculturist', 'attendant', 'caretaker', 'castellan', 'conservationist', 'conservator', 'curator', 'custodian'],
    'forestall': ['anticipate', 'avert', 'bamboozle', 'bar', 'beguile', 'betray', 'bluff', 'cajole', 'calculate on', 'cheat on', 'circumvent', 'conjure'],
    'forestalling': ['agape', 'agog', 'all agog', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'arrestation', 'avoidance', 'avoiding reaction', 'awaiting', 'certain'],
    'forested': ['afforestational', 'arboreous', 'bosky', 'braky', 'bushy', 'copsy', 'dendrologic', 'forest', 'forestal', 'reforestational', 'scrubby', 'shrubby'],
    'forester': ['arboriculturist', 'backwoodsman', 'briar-hopper', 'brush ape', 'bushman', 'clam digger', 'conservationist', 'cracker', 'desert rat', 'forest ranger', 'frontiersman', 'hillbilly'],
    'forestry': ['christmas tree farming', 'afforestation', 'arboretum', 'arboriculture', 'boondocks', 'bush', 'bushveld', 'chase', 'climax forest', 'cloud forest', 'dendrology', 'forest'],
    'foretaste': ['antepast', 'anticipate', 'antipasto', 'aperitif', 'appetizer', 'canape', 'contemplate', 'envisage', 'envision', 'foreglimpse', 'forerun', 'foresee'],
    'foretell': ['adumbrate', 'announce', 'anticipate', 'apprehend', 'approach', 'augur', 'await', 'be destined', 'be fated', 'be imminent', 'be to be', 'be to come'],
    'forethought': ['tlc', 'aforethought', 'anticipation', 'approach', 'arrangement', 'attack', 'attention', 'blueprint', 'blueprinting', 'calculatedness', 'calculation', 'canniness'],
    'forethoughted': ['acute', 'anticipant', 'anticipatory', 'apperceptive', 'appercipient', 'argute', 'astute', 'clairvoyant', 'cogent', 'discerning', 'divinatory', 'farseeing'],
    'foretoken': ['adumbration', 'augur', 'augury', 'auspice', 'badge', 'betoken', 'betokening', 'betokenment', 'bode', 'boding', 'divine', 'forebode'],
    'forever': ['ad infinitum', 'all-comprehensiveness', 'all-inclusiveness', 'always', 'an eternity', 'aye', 'boundlessly', 'boundlessness', 'countlessness', 'endless time', 'endlessly', 'endlessness'],
    'forewarn': ['apprehend', 'bode', 'caution', 'croak', 'forebode', 'give advance notice', 'have a premonition', 'have a presentiment', 'look black', 'lower', 'menace', 'portend'],
    'forewarned': ['agape', 'agog', 'all agog', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'awaiting', 'certain', 'confident', 'eager', 'expectant'],
    'forewarning': ['admonition', 'advance notice', 'apocalyptic', 'augural', 'auguring', 'caution', 'caveat', 'divinatory', 'fatidic', 'foreboding', 'forecasting', 'forerunning'],
    'foreword': ['acknowledgments', 'anteriority', 'avant-propos', 'back', 'back matter', 'bastard title', 'bibliography', 'bold front', 'brave face', 'brave front', 'breakthrough', 'catch line'],
    'forfeit': ['amercement', 'be bereaved of', 'bereavement', 'caution', 'caution money', 'charge', 'collateral', 'collateral security', 'cost', 'damage', 'damages', 'dead loss'],
    'forfeited': ['ablated', 'by the board', 'consumed', 'depleted', 'dissipated', 'eroded', 'expended', 'forfeit', 'gone', 'irretrievable', 'long-lost', 'lost'],
    'forfeiture': ['amercement', 'bereavement', 'cost', 'damage', 'damages', 'dead loss', 'debit', 'denial', 'denudation', 'deprivation', 'despoilment', 'destruction'],
    'forgather': ['assemble', 'bunch', 'bunch up', 'clot', 'cluster', 'collect', 'come together', 'congregate', 'congress', 'converge', 'copulate', 'couple'],
    'forge': ['act like', 'affect', 'assume', 'beat', 'blacksmith shop', 'block out', 'bloomery', 'borrow', 'build', 'carve', 'cast', 'chisel'],
    'forge ahead': ['be in front', 'be the front-runner', 'crowd', 'drive', 'drive on', 'go ahead', 'go all out', 'go slow', 'head', 'head up', 'hustle', 'inch forward'],
    'forged': ['assembled', 'built', 'cast', 'concocted', 'constructed', 'cooked-up', 'counterfeit', 'crafted', 'created', 'custom', 'custom-built', 'custom-made'],
    'forger': ['artful dodger', 'casanova', 'don juan', 'hephaestus', 'machiavel', 'machiavelli', 'machiavellian', 'vulcan', 'wayland', 'actor', 'ape', 'bamboozler'],
    'forgery': ['bad check', 'bad money', 'base coin', 'bogus money', 'canard', 'certified copy', 'cheat', 'clinquant', 'coinage', 'coining', 'concoction', 'copy'],
    'forget': ['abandon', 'blink at', 'blow up', 'brush aside', 'brush off', 'bury the hatchet', 'charge off', 'charge to experience', 'consign to oblivion', 'discount', 'dismiss', 'disregard'],
    'forget it': ['abandon', 'brush aside', 'brush off', 'dismiss', 'drop it', 'drop the subject', 'fat chance', 'forget', 'forget about it', 'ignore it', 'lay aside', 'let it go'],
    'forgetful': ['lethean', 'absent', 'absent-minded', 'absentminded', 'abstracted', 'airy', 'amnesiac', 'amnestic', 'bemused', 'blocked', 'careless', 'casual'],
    'forgetfulness': ['abandon', 'careless abandon', 'carelessness', 'casualness', 'cursoriness', 'disregardfulness', 'easiness', 'hastiness', 'heedlessness', 'inconsiderateness', 'inconsideration', 'indifference'],
    'forgivable': ['admissible', 'allowable', 'condonable', 'defensible', 'dispensable', 'excusable', 'exemptible', 'expiable', 'inoffensive', 'justifiable', 'legitimate', 'pardonable'],
    'forgive': ['abolish', 'absolve', 'acquit', 'allow', 'amnesty', 'cancel', 'clear', 'condone', 'consign to oblivion', 'decontaminate', 'delete', 'destigmatize'],
    'forgiven': ['absolved', 'acquitted', 'blotted', 'canceled', 'condoned', 'disregarded', 'exculpated', 'excused', 'exonerated', 'forgotten', 'indulged', 'overlooked'],
    'forgiveness': ['lethe', 'absentmindedness', 'absolution', 'acquittal', 'acquittance', 'allowance', 'amnesty', 'benevolence', 'clearance', 'clearing', 'clemency', 'commiseration'],
    'forgiving': ['accepting', 'benevolent', 'clement', 'compassionate', 'conciliatory', 'easy', 'easygoing', 'forbearant', 'forbearing', 'generous', 'gentle', 'humane'],
    'forgo': ['abandon', 'abdicate', 'abjure', 'abstain', 'abstain from', 'acknowledge defeat', 'avoid', 'cease', 'cede', 'cry quits', 'desist from', 'disgorge'],
    'forgone': ['abandoned', 'abjured', 'ceded', 'dispensed with', 'disposed of', 'foreordained', 'forsworn', 'predecided', 'predestinate', 'predestined', 'predetermined', 'preordained'],
    'forgotten': ['absolved', 'acquitted', 'ago', 'antiquated', 'antique', 'blotted', 'blown over', 'by', 'bygone', 'bypast', 'canceled', 'condoned'],
    'fork': ['affluent', 'angle', 'angle off', 'apex', 'bail', 'bayou', 'bend', 'bifurcate', 'bifurcation', 'bight', 'billabong', 'bine'],
    'fork out': ['accord', 'administer', 'afford', 'allot', 'allow', 'award', 'bestow', 'bestow on', 'budget', 'communicate', 'confer', 'cost'],
    'fork over': ['circulate', 'come across', 'come across with', 'come down with', 'come through with', 'cough up', 'deliver', 'deliver over', 'distribute', 'forward', 'give in', 'give out'],
    'forked': ['v-shaped', 'y-shaped', 'akimbo', 'angular', 'arboreal', 'arborescent', 'arboriform', 'bent', 'biforked', 'bifurcate', 'bifurcated', 'bisected'],
    'forlorn': ['abandoned', 'affording no hope', 'alone', 'apathetic', 'bereft', 'bleak', 'cheerless', 'comfortless', 'cynical', 'defenseless', 'dejected', 'depressed'],
    'form': ['berkeleianism', 'hegelianism', 'kantianism', 'mo', 'masan', 'neoplatonism', 'platonic form', 'platonic idea', 'platonism', 'procrustean law', 'sop', 'absolute idealism'],
    'formal': ['high-church', 'latinate', 'accepted', 'acknowledged', 'adjectival', 'admitted', 'adverbial', 'anatomic', 'approved', 'architectonic', 'architectural', 'arranged'],
    'formalist': ['babbitt', 'high-churchist', 'holy willie', 'joseph surface', 'mawworm', 'middle american', 'pecksniff', 'pharisee', 'philistine', 'sabbatarian', 'tartuffe', 'vicar of bray'],
    'formalistic': ['accordant', 'anal', 'bourgeois', 'compulsive', 'concordant', 'conformist', 'conventional', 'conventionalized', 'corresponding', 'elegant', 'euphemistic', 'euphuistic'],
    'formalities': ['amenities', 'ceremonies', 'civilities', 'civility', 'comity', 'convention', 'courtliness', 'decencies', 'decorum', 'dignities', 'diplomatic code', 'elegance'],
    'formality': ['procrustean law', 'act', 'baccalaureate service', 'bienseance', 'bill', 'bylaw', 'canon', 'celebration', 'ceremonial', 'ceremony', 'circumstance', 'civility'],
    'formalize': ['agree on terms', 'block out', 'carve', 'cast', 'celebrate', 'chisel', 'codify', 'conventionalize', 'create', 'cut', 'dignify', 'efform'],
    'format': ['platonic form', 'platonic idea', 'aesthetic form', 'anatomy', 'appearance', 'archetype', 'architectonics', 'architecture', 'arrangement', 'art form', 'aspect', 'build'],
    'formation': ['platonic form', 'platonic idea', 'accumulation', 'acronym', 'acrostic', 'aesthetic form', 'allocation', 'allotment', 'anatomy', 'appearance', 'apportionment', 'archetype'],
    'formative': ['ic analysis', 'abecedarian', 'aboriginal', 'accidence', 'adaptable', 'affix', 'affixation', 'allomorph', 'antenatal', 'autochthonous', 'beginning', 'behind the scenes'],
    'former': ['aforementioned', 'aforenamed', 'aforesaid', 'ancient', 'antecedent', 'antediluvian', 'anterior', 'anticipatory', 'beforementioned', 'bygone', 'ci-devant', 'departed'],
    'formidable': ['herculean', 'abstruse', 'alarming', 'appalling', 'arduous', 'astonishing', 'astounding', 'awe-inspiring', 'awesome', 'awful', 'brutal', 'burdensome'],
    'formless': ['aberrant', 'abnormal', 'abundant', 'aimless', 'amorphic', 'amorphous', 'anarchic', 'anomalistic', 'anomalous', 'baggy', 'blobby', 'blurred'],
    'formula': ['mo', 'procrustean law', 'a priori truth', 'act', 'addend', 'antilogarithm', 'argument', 'axiom', 'base', 'bill', 'binomial', 'blueprint'],
    'formulary': ['high-church', 'procrustean law', 'act', 'authoritative', 'baptismal', 'bill', 'binding', 'bylaw', 'canon', 'canonical', 'ceremonial', 'ceremonious'],
    'formulate': ['articulate', 'assemble', 'author', 'authorize', 'block out', 'breathe', 'build', 'cast', 'chime', 'chorus', 'coauthor', 'codify'],
    'formulation': ['allocation', 'allotment', 'apportionment', 'architecture', 'arrangement', 'array', 'arraying', 'assembly', 'building', 'casting', 'choice of words', 'collation'],
    'fornicate': ['ball', 'be intimate', 'be promiscuous', 'chase women', 'cohabit', 'come together', 'commit adultery', 'copulate', 'couple', 'cover', 'debauch', 'diddle'],
    'fornication': ['act of love', 'adultery', 'aphrodisia', 'ass', 'balling', 'carnal knowledge', 'climax', 'cohabitation', 'coition', 'coitus', 'coitus interruptus', 'commerce'],
    'forsake': ['abandon', 'abdicate', 'back out', 'be unfaithful', 'beg off', 'break faith', 'cast off', 'chuck', 'cry off', 'deny', 'depart', 'depart from'],
    'forsaken': ['abandoned', 'available', 'cast-off', 'castaway', 'defenseless', 'derelict', 'deserted', 'desolate', 'discarded', 'disowned', 'disused', 'fatherless'],
    'forsooth': ['absolutely', 'actually', 'and no mistake', 'assuredly', 'at all events', 'at any rate', 'by all means', 'certainly', 'clearly', 'decidedly', 'decisively', 'definitely'],
    'forswear': ['abandon', 'abdicate', 'abjure', 'acknowledge defeat', 'assert the contrary', 'back down', 'back out', 'backwater', 'belie', 'brush aside', 'cease', 'cede'],
    'forsworn': ['abandoned', 'abjured', 'artful', 'calculating', 'ceded', 'contemned', 'crafty', 'deceitful', 'declined', 'declined with thanks', 'denied', 'despised'],
    'fort': ['acropolis', 'bastion', 'beachhead', 'blockhouse', 'bridgehead', 'bunker', 'castle', 'citadel', 'donjon', 'fasthold', 'fastness', 'fortress'],
    'fort knox': ['bank', 'bursary', 'cash register', 'cashbox', 'chest', 'coffer', 'coin box', 'depository', 'exchequer', 'fisc', 'gold depository', 'locker'],
    'forte': ['a cappella', 'abbandono', 'ability', 'ableness', 'accrescendo', 'adagietto', 'adagio', 'affettuoso', 'agilmente', 'agitato', 'allegretto', 'allegro'],
    'forth': ['ahead', 'alee', 'along', 'away', 'en route to', 'for', 'forward', 'forwards', 'hence', 'off', 'on', 'onward'],
    'forthcoming': ['about to be', 'access', 'accessible', 'accession', 'advance', 'advancing', 'advent', 'affable', 'afflux', 'affluxion', 'already in sight', 'amiable'],
    'forthright': ['aboveboard', 'artless', 'bluff', 'blunt', 'broad', 'brusque', 'candid', 'dead', 'dead ahead', 'direct', 'directly', 'downright'],
    'forthwith': ['pdq', 'abruptly', 'all at once', 'all together', 'apace', 'at a blow', 'at a stroke', 'at once', 'at one blow', 'at one jump', 'at one stroke', 'at one swoop'],
    'fortification': ['abatis', 'advanced work', 'affirmation', 'attestation', 'authentication', 'backing', 'backing up', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican'],
    'fortify': ['add to', 'adulterate', 'affirm', 'animate', 'arm', 'armor', 'armor-plate', 'arouse', 'attest', 'augment', 'authenticate', 'back'],
    'fortissimo': ['a cappella', 'abbandono', 'accrescendo', 'adagietto', 'adagio', 'affettuoso', 'agilmente', 'agitato', 'allegretto', 'allegro', 'aloud', 'amabile'],
    'fortitude': ['acceptance', 'backbone', 'boldness', 'bottom', 'bravery', 'bulldog courage', 'cardinal virtues', 'charity', 'constancy', 'courage', 'courageousness', 'dauntlessness'],
    'fortnight': ['sexagesima', 'abundant year', 'academic year', 'annum', 'bissextile year', 'boxcar', 'boxcars', 'calendar month', 'calendar year', 'century', 'common year', 'day'],
    'fortnightly': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'daybook', 'decennial', 'diary'],
    'fortress': ['acropolis', 'bastion', 'beachhead', 'blockhouse', 'bridgehead', 'bunker', 'castle', 'citadel', 'donjon', 'fasthold', 'fastness', 'fort'],
    'fortuitous': ['accessory', 'accidental', 'additional', 'adscititious', 'adventitious', 'aleatory', 'appurtenant', 'ascititious', 'auxiliary', 'casual', 'causeless', 'chance'],
    'fortuity': ['accident', 'accidentality', 'actuarial calculation', 'adventitiousness', 'adventure', 'break', 'casualness', 'casualty', 'chance', 'chance hit', 'contingency', 'contingent'],
    'fortunate': ['advantageous', 'appropriate', 'assured of success', 'auspicious', 'befitting', 'benign', 'benignant', 'blessed', 'blessed with luck', 'bright', 'coming', 'convenient'],
    'fortune': ['clio', 'friday', 'friday the thirteenth', 'muse of history', 'accidentality', 'actuarial calculation', 'adventitiousness', 'adventures', 'affluence', 'annals', 'appointed lot', 'assets'],
    'fortune tell': ['cast a horoscope', 'cast a nativity', 'divine', 'dope', 'dope out', 'dowse for water', 'forebode', 'forecast', 'foresee', 'foretell', 'guess', 'hariolate'],
    'fortune teller': ['cassandra', 'druid', 'astrologer', 'augur', 'calamity howler', 'crystal gazer', 'divinator', 'diviner', 'divineress', 'forecaster', 'foreknower', 'foreseer'],
    'forum': ['areopagus', 'agora', 'airing', 'amphitheater', 'analysis', 'arena', 'assemblee', 'assembly', 'assignation', 'at home', 'athletic field', 'auditorium'],
    'forward': ['a bit previous', 'accelerate', 'acculturate', 'acquiescent', 'act for', 'actuate', 'address', 'advance', 'advanced', 'advancing', 'advantage', 'adventurous'],
    'forward looking': ['a la mode', 'advanced', 'advancing', 'avant-garde', 'contemporary', 'far out', 'fashionable', 'forward', 'go-ahead', 'in', 'mod', 'modern'],
    'forward motion': ['brownian movement', 'advance', 'advancement', 'advancing', 'angular motion', 'ascending', 'ascent', 'axial motion', 'backflowing', 'backing', 'backward motion', 'career'],
    'forward pass': ['bowl', 'cast', 'change of pace', 'change-up', 'chuck', 'chunk', 'curve', 'downcurve', 'fastball', 'fling', 'flip', 'heave'],
    'fosse': ['abri', 'approach trench', 'aqueduct', 'bunker', 'canal', 'canalization', 'channel', 'communication trench', 'countermine', 'coupure', 'crimp', 'cut'],
    'fossil': ['methuselah', 'afterglow', 'afterimage', 'ancient manuscript', 'antediluvian', 'antique', 'antiquity', 'archaism', 'artifact', 'back number', 'balance', 'butt'],
    'fossilize': ['age', 'anneal', 'antiquate', 'become extinct', 'become obsolete', 'calcify', 'callous', 'case harden', 'cornify', 'date', 'fade', 'firm'],
    'fossilized': ['gothic', 'victorian', 'anile', 'antediluvian', 'antiquated', 'antique', 'archaic', 'backed', 'calcified', 'callous', 'calloused', 'case-hardened'],
    'foster': ['abet', 'accommodate', 'acculturate', 'actuate', 'advance', 'affiliated', 'agnate', 'aid', 'aid and abet', 'akin', 'aliment', 'allied'],
    'fosterage': ['abetment', 'advocacy', 'aegis', 'auspices', 'backing', 'care', 'championship', 'charity', 'countenance', 'encouragement', 'favor', 'goodwill'],
    'fou': ['addled', 'aliene', 'bedlamite', 'beery', 'bemused', 'besotted', 'blind drunk', 'borderline case', 'crackbrain', 'crackpot', 'crapulent', 'crapulous'],
    'foul': ['fescennine', 'rabelaisian', 'abase', 'abeyant', 'abhorrent', 'abject', 'abominable', 'abuse', 'abusive', 'adulterate', 'adulterated', 'adverse'],
    'foul language': ['bad language', 'billingsgate', 'blue language', 'colorful language', 'cursing', 'cussing', 'dirty language', 'dirty talk', 'dysphemism', 'evil speaking', 'filth', 'filthy language'],
    'foul matter': ['carrion', 'corruption', 'dandruff', 'decay', 'excrement', 'filth', 'furfur', 'gangrene', 'mess', 'muck', 'mucus', 'obscenity'],
    'foul mouthed': ['fescennine', 'rabelaisian', 'bawdy', 'blue', 'dirty', 'filthy', 'foul', 'foul-spoken', 'foul-tongued', 'fulsome', 'impure', 'ithyphallic'],
    'foul play': ['artifice', 'assassination', 'blood', 'bloody murder', 'bumping-off', 'chicane', 'chicanery', 'collusion', 'connivance', 'connivery', 'conspiracy', 'covin'],
    'foul tongued': ['fescennine', 'rabelaisian', 'bawdy', 'blue', 'dirty', 'filthy', 'foul', 'foul-mouthed', 'foul-spoken', 'fulsome', 'impure', 'ithyphallic'],
    'foul up': ['anarchy', 'ball up', 'bitch', 'bitch up', 'bloomer', 'blooper', 'blow', 'bobble', 'bollix', 'bollix up', 'bonehead into it', 'bonehead play'],
    'fouled': ['bedraggled', 'befouled', 'besmirched', 'blocked', 'bound', 'choked', 'choked up', 'clogged', 'clogged up', 'congested', 'constipated', 'costive'],
    'found': ['assemble', 'author', 'base', 'bear', 'bed', 'beget', 'begin', 'blaze', 'blister', 'block out', 'bottom', 'brand'],
    'found wanting': ['adulterated', 'blemished', 'damaged', 'defective', 'deficient', 'erroneous', 'failing', 'fallible', 'faulty', 'immature', 'impaired', 'imperfect'],
    'foundation': ['a priori principle', 'affirmation', 'alpha', 'anchorage', 'appanage', 'apriorism', 'arrangement', 'assertion', 'assumed position', 'assumption', 'axiom', 'basal'],
    'foundation garment': ['advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'bearer', 'bra', 'brace', 'bracer'],
    'founded on': ['absolute', 'adducible', 'admissible', 'attestative', 'attestive', 'authentic', 'based on', 'bolstered', 'borne', 'braced', 'buttressed', 'certain'],
    'founder': ['abort', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'be clobbered', 'be destroyed', 'be felled', 'be lost', 'be poleaxed'],
    'foundering': ['collapsing', 'deciduous', 'declining', 'declivitous', 'decurrent', 'descendant', 'descending', 'down', 'down-reaching', 'downcoming', 'downfalling', 'downgoing'],
    'foundling': ['bonus', 'buried treasure', 'castaway', 'castoff', 'derelict', 'discard', 'discovery', 'dogie', 'find', 'finding', 'flotsam', 'flotsam and jetsam'],
    'fountain': ['anabasis', 'ascension', 'ascent', 'bob up', 'bonanza', 'break water', 'clamber', 'climb', 'climbing', 'cornucopia', 'elevation', 'escalade'],
    'fountainhead': ['font', 'fount', 'fountain', 'head', 'headspring', 'headstream', 'headwater', 'headwaters', 'inception', 'mainspring', 'mine', 'origin'],
    'four flush': ['act', 'act a part', 'affect', 'assume', 'bluff', 'counterfeit', 'cover up', 'dissemble', 'dissimulate', 'fake', 'feign', 'gammon'],
    'fourscore': ['sexagesima', 'boxcar', 'boxcars', 'dozen', 'duodecimo', 'eighty', 'eleven', 'fifteen', 'fifty', 'five and twenty', 'fortnight', 'forty'],
    'foursome': ['little joe', 'biquadrate', 'bout', 'contest', 'decathlon', 'double-header', 'doubles', 'event', 'four', 'four-part diaphony', 'game', 'games of chance'],
    'foursquare': ['aboveboard', 'authentic', 'biquadratic', 'bona fide', 'cube-shaped', 'cubed', 'cubic', 'cubiform', 'cuboid', 'diced', 'fair and square', 'four'],
    'fourth': ['consecutive intervals', 'degree', 'diapason', 'diatessaron', 'diatonic interval', 'diatonic semitone', 'enharmonic diesis', 'enharmonic interval', 'farthing', 'fifth', 'fourth part', 'half step'],
    'fourth class': ['mickey mouse', 'base', 'cheap', 'cheesy', 'coarse', 'common', 'inferior', 'irregular', 'low-class', 'low-grade', 'low-quality', 'low-test'],
    'fourth estate': ['ap', 'associated press', 'fleet street', 'reuters', 'upi', 'united press international', 'advice', 'book publishing', 'broadcast journalism', 'communications', 'communications industry', 'information'],
    'fowl': ['bantam', 'cornish hen', 'avifauna', 'baby bird', 'banty', 'barn-door fowl', 'barnyard fowl', 'beat', 'biddy', 'bird', 'bird of jove', 'bird of juno'],
    'fox': ['african hunting dog', 'artful dodger', 'cape hunting dog', 'philadelphia lawyer', 'yankee horse trader', 'brush wolf', 'charmer', 'coyote', 'crafty rascal', 'dingo', 'dodger', 'glib tongue'],
    'fox fire': ['autoluminescence', 'backfire', 'balefire', 'beacon', 'beacon fire', 'bioluminescence', 'blaze', 'bonfire', 'burning ghat', 'campfire', 'cathode luminescence', 'cheerful fire'],
    'fox trot': ['bound', 'canter', 'clog', 'dance', 'foot', 'gallop', 'get', 'git', 'hightail', 'hoof', 'hop', 'hop along'],
    'foxhole': ['abri', 'air-raid shelter', 'antre', 'approach trench', 'asylum', 'bolt-hole', 'bomb shelter', 'bombproof', 'bunker', 'burrow', 'cache', 'cave'],
    'foxy': ['byzantine', 'machiavellian', 'machiavellic', 'titian', 'acute', 'adust', 'alluring', 'arch', 'artful', 'astute', 'attractive', 'auburn'],
    'foyer': ['ancestral halls', 'chimney corner', 'entrance', 'entrance hall', 'entranceway', 'entry', 'entryway', 'family homestead', 'fireplace', 'fireside', 'galilee', 'hearth'],
    'fracas': ['bedlam let loose', 'ado', 'affray', 'altercation', 'argument', 'barney', 'bedlam', 'bicker', 'bickering', 'blast', 'blood feud', 'bobbery'],
    'fraction': ['gaussian integer', 'adjunct', 'algebraic number', 'arithmetical proportion', 'cardinal', 'cardinal number', 'complex number', 'component', 'contingent', 'continued fraction', 'cross section', 'defective number'],
    'fractionate': ['aerate', 'aerify', 'atomize', 'carbonate', 'chlorinate', 'distill', 'emit', 'etherify', 'etherize', 'evaporate', 'exhale', 'fluidize'],
    'fractious': ['adversary', 'adversative', 'adverse', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'at odds', 'averse', 'bearish', 'beyond control'],
    'fracture': ['abrade', 'abrasion', 'abysm', 'abyss', 'amuse', 'arroyo', 'bark', 'beguile', 'blemish', 'bloody', 'box canyon', 'breach'],
    'fragile': ['breakable', 'brittle', 'brittle as glass', 'capricious', 'changeable', 'cheap-jack', 'cobwebby', 'corruptible', 'crackable', 'crisp', 'crispy', 'crumbly'],
    'fragility': ['amiable weakness', 'breakability', 'breakableness', 'brittleness', 'cachexia', 'cachexy', 'changeableness', 'chronic ill health', 'collapse', 'crackability', 'crackableness', 'crispness'],
    'fragment': ['abrade', 'ace', 'ana', 'analects', 'anthology', 'atom', 'atomize', 'beat', 'bit', 'bray', 'break into pieces', 'break to pieces'],
    'fragrance': ['aroma', 'balm', 'bouquet', 'breath', 'definite odor', 'detectable odor', 'effluvium', 'emanation', 'essence', 'exhalation', 'flavor', 'fragrancy'],
    'fragrant': ['ambrosial', 'aromatic', 'balmy', 'delectable', 'delicious', 'delightful', 'effluvious', 'essenced', 'flowery', 'fruity', 'incense-breathing', 'malodorous'],
    'fraidy cat': ['milquetoast', 'baby', 'big baby', 'chicken', 'chicken liver', 'coward', 'fraid-cat', 'funk', 'funker', 'invertebrate', 'jellyfish', 'lily liver'],
    'frail': ['adamic', 'adamite', 'adamitic', 'abulic', 'afraid', 'ailing', 'airy', 'anthropocentric', 'anthropological', 'attenuate', 'attenuated', 'backsliding'],
    'frailty': ['abulia', 'airiness', 'airy texture', 'amiable weakness', 'attenuation', 'bad habit', 'besetting sin', 'blemish', 'breakability', 'breakableness', 'brittleness', 'bug'],
    'frame': ['platonic form', 'platonic idea', 'adjoin', 'aesthetic form', 'anatomy', 'angle', 'appendicular skeleton', 'archetype', 'architectonics', 'architecture', 'arrange', 'arrangement'],
    'frame of reference': ['anschauung', 'angle', 'angle of vision', 'basis', 'eye', 'footing', 'framework', 'light', 'mental outlook', 'outlook', 'place', 'point of view'],
    'frame up': ['artifice', 'cabal', 'cheat', 'clinquant', 'collusion', 'complicity', 'complot', 'confederacy', 'connivance', 'conspiracy', 'contrivance', 'contriving'],
    'framework': ['anschauung', 'angle', 'angle of vision', 'basis', 'cadre', 'case', 'casement', 'casing', 'chassis', 'configuration', 'contour', 'delineation'],
    'franc': ['deutschmark', 'mark', 'reichsmark', 'afghani', 'anna', 'baht', 'cent', 'centavo', 'centime', 'conto', 'dollar', 'dong'],
    'franchise': ['australian ballot', 'hare system', 'affranchise', 'authorize', 'aye', 'ballot', 'blank check', 'brevet', 'canvass', 'canvassing', 'carte blanche', 'casting vote'],
    'franciscan': ['albigensian', 'augustinian', 'augustinian hermit', 'austin friar', 'benedictine', 'bernardine', 'black friar', 'black monk', 'bonhomme', 'brigittine', 'capuchin', 'carmelite'],
    'frangible': ['breakable', 'brittle', 'brittle as glass', 'cheap-jack', 'cobwebby', 'crackable', 'crisp', 'crispy', 'crumbly', 'crushable', 'dainty', 'delicate'],
    'frank': ['pp', 'rd', 'rfd', 'spartan', 'vienna sausage', 'accessible', 'airmail', 'all jaw', 'approachable', 'artless', 'ascetic', 'austere'],
    'frankenstein': ['dracula', 'wolf-man', 'bogey', 'bogeyman', 'bugaboo', 'bugbear', 'fee-faw-fum', 'frightener', 'ghost', 'ghoul', 'hobgoblin', 'holy terror'],
    'frankfurter': ['vienna sausage', 'bangers', 'black pudding', 'blood pudding', 'bologna', 'braunschweiger', 'dog', 'frank', 'gooseliver', 'headcheese', 'hot dog', 'knockwurst'],
    'frankly': ['all joking aside', 'bluffly', 'bluntly', 'broadly', 'brusquely', 'candidly', 'directly', 'genuinely', 'in all conscience', 'in all seriousness', 'in plain english', 'in plain words'],
    'frankness': ['accessibility', 'approachability', 'artlessness', 'austerity', 'baldness', 'bareness', 'big mouth', 'bluffness', 'bluntness', 'broadness', 'brusqueness', 'candidness'],
    'frantic': ['dionysiac', 'abandoned', 'agitated', 'amok', 'anarchic', 'angry', 'at fever pitch', 'bacchic', 'bellowing', 'berserk', 'blustering', 'blusterous'],
    'frantically': ['angrily', 'deliriously', 'demonically', 'desperately', 'distractedly', 'fanatically', 'fiercely', 'frenetically', 'frenziedly', 'furiously', 'hotly', 'insensately'],
    'fraternal': ['christian', 'christlike', 'christly', 'affectionate', 'agreeable', 'amiable', 'amicable', 'benign', 'benignant', 'brotherly', 'compassionate', 'congenial'],
    'fraternity': ['affiliation', 'agnation', 'alignment', 'alliance', 'amalgamation', 'ancestry', 'association', 'blood', 'blood relationship', 'boon companionship', 'brotherhood', 'brotherliness'],
    'fraternization': ['affiliation', 'alignment', 'alliance', 'amalgamation', 'association', 'cahoots', 'coadunation', 'coalescence', 'coalition', 'collaboration', 'colleagueship', 'collegialism'],
    'fraternize': ['act the traitor', 'associate with', 'assort with', 'be acquainted with', 'be friends', 'be inseparable', 'chum', 'chum together', 'chum with', 'clique', 'clique with', 'club together'],
    'fratricide': ['aborticide', 'fungicide', 'genocide', 'germicide', 'herbicide', 'homicide', 'infanticide', 'insecticide', 'matricide', 'microbicide', 'parricide', 'patricide'],
    'frau': ['eve', 'fraulein', 'miss', 'mistress', 'mlle', 'mme', 'mmes', 'dame', 'daughter of eve', 'distaff', 'domina', 'dona'],
    'fraud': ['abstraction', 'acting', 'actor', 'affectation', 'affecter', 'annexation', 'appearance', 'appropriation', 'artfulness', 'artifice', 'attitudinizing', 'ballot-box stuffing'],
    'fraudulence': ['ballot-box stuffing', 'bunco', 'cardsharping', 'cheat', 'cheating', 'corruptedness', 'corruption', 'corruptness', 'cozenage', 'criminality', 'crookedness', 'deviousness'],
    'fraudulent': ['amoral', 'artful', 'bent', 'brigandish', 'burglarious', 'calculating', 'chiseling', 'collusive', 'conscienceless', 'corrupt', 'corrupted', 'counterfeit'],
    'fraught': ['anxious', 'attended by', 'burdened', 'charged', 'cumbered', 'distressful', 'distressing', 'encumbered', 'freighted', 'fretful', 'full-charged', 'full-fraught'],
    'fraulein': ['frau', 'miss', 'mistress', 'mlle', 'mme', 'mmes', 'dame', 'dona', 'donna', 'lady', 'madam', 'madame'],
    'fray': ['ablate', 'abrade', 'abrase', 'abrasion', 'action', 'aerial combat', 'affray', 'altercation', 'armored combat', 'bark', 'battle', 'battle royal'],
    'frayed': ['dowdy', 'down-at-heel', 'down-at-the-heels', 'frazzled', 'full of holes', 'holey', 'in rags', 'in shreds', 'in tatters', 'patchy', 'ragged', 'raggedy'],
    'frazzle': ['ablate', 'abrade', 'abrase', 'abrasion', 'agitate', 'bark', 'beat', 'blemish', 'bloody', 'bother', 'break', 'bugger'],
    'frazzled': ['ausgespielt', 'debilitated', 'done', 'done up', 'dowdy', 'down-at-heel', 'down-at-the-heels', 'drooping', 'emptied', 'enervated', 'enfeebled', 'exhausted'],
    'freak': ['bohemian', 'lsd user', 'aberration', 'abnormal', 'abnormality', 'abortion', 'acidhead', 'addict', 'aficionado', 'alcoholic', 'amateur', 'androgyne'],
    'freak out': ['adore', 'appreciate', 'bask in', 'be pleased with', 'becharm', 'bewitch', 'captivate', 'carry away', 'charm', 'daydream', 'delectate', 'delight'],
    'freakish': ['abnormal', 'adrift', 'afloat', 'alternating', 'amorphous', 'anomalous', 'arbitrary', 'baroque', 'bizarre', 'capricious', 'changeable', 'changeful'],
    'freckle': ['band', 'bar', 'bespangle', 'bespeckle', 'bespot', 'birthmark', 'blackhead', 'blaze', 'blaze a trail', 'bleb', 'blemish', 'blister'],
    'freckled': ['bespangled', 'bespeckled', 'blotched', 'blotchy', 'dotted', 'dotty', 'flea-bitten', 'flecked', 'fleckered', 'frecked', 'freckle-faced', 'freckly'],
    'free': ['abandoned', 'able', 'above', 'absolve', 'accessible', 'acquit', 'adrift', 'affranchise', 'afloat', 'afoot and lighthearted', 'allowed', 'amnesty'],
    'free and clear': ['above water', 'all clear', 'all straight', 'by one', 'clear', 'held', 'in fee', 'in fee simple', 'in hand', 'in seisin', 'in stock', 'in store'],
    'free and easy': ['bohemian', 'affable', 'afoot and lighthearted', 'airy', 'at large', 'at liberty', 'beat', 'blase', 'boon', 'breakaway', 'breezy', 'buoyant'],
    'free choice': ['alternativity', 'animus', 'appetence', 'appetency', 'appetite', 'choice', 'choosing', 'co-optation', 'co-option', 'command', 'conation', 'conatus'],
    'free enterprise': ['autarky', 'bimetallism', 'bourgeois', 'capitalism', 'capitalist', 'capitalistic system', 'economic self-sufficiency', 'finance capitalism', 'free competition', 'free economy', 'free trade', 'free-enterprise economy'],
    'free hand': ['ample scope', 'bigheartedness', 'blank check', 'bounteousness', 'bountifulness', 'bounty', 'carte blanche', 'clearance', 'easy purse strings', 'elbowroom', 'field', 'free course'],
    'free lance': ['adventurer', 'advertising writer', 'annalist', 'art critic', 'ask no favors', 'ask no quarter', 'author', 'authoress', 'belletrist', 'bibliographer', 'blue-collar worker', 'breadwinner'],
    'free love': ['amor', 'christian love', 'eros', 'platonic love', 'admiration', 'adoration', 'adultery', 'affection', 'agape', 'ardency', 'ardor', 'attachment'],
    'free spoken': ['accessible', 'approachable', 'articulate', 'artless', 'bluff', 'blunt', 'broad', 'brusque', 'candid', 'communicative', 'conversable', 'demonstrative'],
    'free will': ['alternativity', 'animus', 'appetence', 'appetency', 'appetite', 'autonomousness', 'autonomy', 'choice', 'choosing', 'co-optation', 'co-option', 'command'],
    'free-for-all': ['bedlam let loose', 'ado', 'affray', 'bedlam', 'blast', 'bobbery', 'bother', 'brawl', 'broil', 'brouhaha', 'charivari', 'chirm'],
    'freebie': ['charitable', 'complimentariness', 'complimentary', 'costless', 'costlessness', 'eleemosynary', 'expenseless', 'expenselessness', 'for free', 'for love', 'for nothing', 'free'],
    'freeboot': ['buccaneer', 'depredate', 'despoil', 'fleece', 'forage', 'foray', 'gut', 'loot', 'maraud', 'pillage', 'pirate', 'plunder'],
    'freeborn': ['afoot and lighthearted', 'at large', 'at liberty', 'clear', 'detached', 'disengaged', 'easygoing', 'emancipated', 'footloose', 'footloose and fancy-free', 'free', 'free and easy'],
    'freed': ['afoot and lighthearted', 'at large', 'at liberty', 'clear', 'delivered', 'detached', 'disengaged', 'easygoing', 'emancipated', 'extricated', 'footloose', 'footloose and fancy-free'],
    'freedom': ['arrogance', 'artlessness', 'audaciousness', 'audacity', 'authority', 'authorization', 'autonomy', 'bigheartedness', 'blank check', 'bluffness', 'bluntness', 'boldness'],
    'freehand': ['blunt', 'candid', 'direct', 'free hand', 'free-acting', 'free-going', 'free-moving', 'free-spoken', 'freehanded', 'graphic', 'monochrome', 'open'],
    'freehold': ['acres', 'adverse possession', 'alluvion', 'alluvium', 'alod', 'alodium', 'arable land', 'burgage', 'claim', 'clay', 'clod', 'colony'],
    'freeing': ['emancipation proclamation', 'affranchisement', 'break', 'breaking out', 'breakout', 'catharsis', 'cleansing', 'clearing', 'deliverance', 'delivery', 'disburdening', 'discharge'],
    'freeloader': ['barnacle', 'beat', 'beggar', 'bloodsucker', 'bummer', 'cadger', 'caller', 'company', 'coupon clippers', 'deadbeat', 'deadhead', 'drone'],
    'freely': ['abundantly', 'amply', 'bigheartedly', 'bounteously', 'bountifully', 'by choice', 'candidly', 'cleanly', 'easily', 'electively', 'frankly', 'free'],
    'freemasonry': ['affiliation', 'alignment', 'alliance', 'amalgamation', 'association', 'boon companionship', 'brotherhood', 'brotherliness', 'cahoots', 'chumship', 'coadunation', 'coalescence'],
    'freethinker': ['big person', 'broad-gauge person', 'ecumenicist', 'esprit fort', 'free lance', 'free spirit', 'free trader', 'humanist', 'independent', 'individualist', 'isolationist', 'latitudinarian'],
    'freethinking': ['broad-minded', 'broad-mindedness', 'catholicity', 'free thought', 'humanism', 'latitudinarian', 'latitudinarianism', 'liberal', 'liberalism', 'liberalistic', 'liberality', 'liberalness'],
    'freeway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'freewheeling': ['autarchic', 'autarkic', 'autonomous', 'free-spirited', 'independent', 'individualistic', 'inner-directed', 'neutral', 'nonaligned', 'nonpartisan', 'self-contained', 'self-dependent'],
    'freeze': ['ko', 'abide', 'anesthetize', 'anhydrate', 'appall', 'arrest', 'awe', 'balance', 'ballast', 'ban', 'be cold', 'be still'],
    'freeze dry': ['anhydrate', 'blast-freeze', 'brine', 'corn', 'cure', 'dehydrate', 'desiccate', 'dry', 'dry-cure', 'dry-salt', 'embalm', 'evaporate'],
    'freeze out': ['ban', 'bar', 'bar out', 'blockade', 'chase out', 'count out', 'cut off', 'debar', 'drive out', 'drum out', 'embargo', 'exclude'],
    'freeze to': ['adhere', 'adhere to', 'agglomerate', 'bite', 'bunch', 'clasp', 'cleave', 'cleave to', 'clench', 'clinch', 'cling', 'cling to'],
    'freezer': ['big house', 'bridewell', 'brig', 'calaboose', 'can', 'clink', 'cooler', 'coop', 'deep freeze', 'deep-freezer', 'freezing machine', 'hoosegow'],
    'freezing': ['siberian', 'adiabatic absorption', 'adiabatic demagnetization', 'adiabatic expansion', 'air conditioning', 'air cooling', 'algid', 'algific', 'anhydration', 'arctic', 'below zero', 'biting'],
    'freezing point': ['absolute zero', 'algidity', 'bitterness', 'bleakness', 'boiling point', 'briskness', 'chill', 'chilliness', 'cold', 'coldness', 'cool', 'coolness'],
    'freight': ['amtrak', 'air express', 'air-express', 'airfreight', 'airlift', 'airmail', 'asportation', 'bag', 'baggage', 'baggage train', 'bale', 'barrel'],
    'freighted': ['burdened', 'charged', 'cumbered', 'encumbered', 'fraught', 'full-charged', 'full-fraught', 'hampered', 'heavy-laden', 'laden', 'loaded', 'oppressed'],
    'freighter': ['amtrak', 'aquarius', 'ganymede', 'hebe', 'argosy', 'ark', 'baggage train', 'bathyscaphe', 'bearer', 'bheesty', 'busboy', 'cable railroad'],
    'french horn': ['alpenhorn', 'alphorn', 'althorn', 'alto horn', 'ballad horn', 'baritone', 'bass horn', 'brass choir', 'brass wind', 'brass-wind instrument', 'brasses', 'bugle'],
    'french leave': ['awol', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'absquatulation', 'bolt', 'cut', 'day off', 'decampment'],
    'frenetic': ['dionysiac', 'amok', 'at fever pitch', 'bacchic', 'berserk', 'corybantic', 'delirious', 'desperate', 'fanatical', 'febrile', 'feverish', 'frantic'],
    'frenzied': ['dionysiac', 'abandoned', 'amok', 'anarchic', 'angry', 'at fever pitch', 'bacchic', 'bellowing', 'berserk', 'blustering', 'blusterous', 'blustery'],
    'frenzy': ['jacksonian epilepsy', 'rolandic epilepsy', 'abandon', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'agitation', 'akinetic epilepsy', 'amok', 'annoy'],
    'frequency': ['af', 'cps', 'ehf', 'hf', 'hz', 'mf', 'rf', 'shf', 'uhf', 'vhf', 'vlf', 'amplitude'],
    'frequency band': ['amateur band', 'amplitude', 'antinode', 'band', 'channel', 'citizens band', 'crest', 'de broglie wave', 'diffraction', 'electromagnetic radiation', 'electromagnetic wave', 'fluctuation'],
    'frequent': ['affect', 'attend', 'automatic', 'beaten', 'common', 'constant', 'continual', 'continuing', 'continuous', 'countless', 'customary', 'cyclical'],
    'frequenter': ['aficionado', 'attender', 'audience', 'buff', 'caller', 'company', 'denizen', 'fan', 'freeloader', 'gate-crasher', 'guest', 'habitue'],
    'frequently': ['a lot', 'again and again', 'as a rule', 'chronically', 'commonly', 'continually', 'customarily', 'day after day', 'day by day', 'every so often', 'generally', 'habitually'],
    'fresco': ['abstract', 'abstraction', 'altarpiece', 'apply paint', 'bedaub', 'bedizen', 'begild', 'besmear', 'block print', 'brush on paint', 'calcimine', 'calcimining'],
    'fresh': ['niagara', 'a novice at', 'a stranger to', 'accessory', 'active', 'actual', 'additional', 'adolescent stream', 'aeolian', 'airish', 'airy', 'alert'],
    'fresh start': ['alpha', 'another shot', 'another try', 'beginning', 'blast-off', 'commencement', 'creation', 'cutting edge', 'dawn', 'edge', 'establishment', 'flying start'],
    'freshen': ['aerate', 'air', 'air out', 'air-condition', 'air-cool', 'airify', 'animate', 'blast', 'bleach', 'blow', 'blow a hurricane', 'blow great guns'],
    'freshman': ['abecedarian', 'alphabetarian', 'apprentice', 'articled clerk', 'baby', 'beginner', 'boot', 'cadet', 'catechumen', 'colt', 'deb', 'debutant'],
    'fret': ['ablate', 'abrade', 'abrase', 'ache', 'achievement', 'aching', 'afflict', 'aggravate', 'agitate', 'agonize', 'ail', 'air a grievance'],
    'fretful': ['jeremianic', 'abrupt', 'agitated', 'antsy', 'antsy-pantsy', 'anxious', 'bad-tempered', 'breathless', 'bustling', 'captious', 'carping', 'catty'],
    'fretfulness': ['anxiety', 'breathless impatience', 'chafing', 'disquietude', 'eagerness', 'excitement', 'fretting', 'haste', 'impatience', 'impatientness', 'impetuousness', 'lather'],
    'fretted': ['beset', 'braided', 'dogged', 'enlaced', 'entwined', 'handwoven', 'harassed', 'harried', 'haunted', 'hounded', 'interknit', 'interlaced'],
    'fretting': ['ablation', 'ablative', 'abradant', 'abrasion', 'abrasive', 'annoying', 'antsy', 'antsy-pantsy', 'anxiety', 'anxious', 'attrition', 'attritive'],
    'fretwork': ['arabesque', 'basketry', 'basketwork', 'cancellation', 'cross-hatching', 'crossing-out', 'filigree', 'fret', 'grate', 'grating', 'grid', 'gridiron'],
    'frey': ['aesir', 'ashtoreth', 'astarte', 'baal', 'balder', 'bor', 'bori', 'bragi', 'ceres', 'cora', 'demeter', 'dionysos'],
    'freya': ['adonis', 'aesir', 'amor', 'aphrodite', 'apollo', 'apollo belvedere', 'astarte', 'balder', 'bor', 'bori', 'bragi', 'cleopatra'],
    'friable': ['breakable', 'brittle', 'brittle as glass', 'crackable', 'crimp', 'crisp', 'crispy', 'crumbly', 'crump', 'crushable', 'delicate', 'fissile'],
    'friar': ['abbacomes', 'abbot', 'ascetic', 'beadsman', 'brother', 'caloyer', 'celibate', 'cenobite', 'conventual', 'conventual prior', 'grand prior', 'hermit'],
    'fribble': ['beau brummel', 'sunday painter', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'airy', 'amateur', 'asinine', 'bagatelle', 'bauble'],
    'fricassee': ['irish stew', 'bake', 'barbecue', 'baste', 'blanch', 'boil', 'bouillabaisse', 'braise', 'brew', 'broil', 'brown', 'chowder'],
    'friction': ['discordia', 'eris', 'abrading', 'abrasion', 'animosity', 'antagonism', 'antipathy', 'argument', 'attrition', 'backlash', 'bad blood', 'belligerence'],
    'frictionless': ['accordant', 'agreeable', 'agreeing', 'akin', 'amicable', 'at one', 'attuned', 'compatible', 'concordant', 'congenial', 'corresponding', 'easy-flowing'],
    'fried': ['afflicted', 'baked', 'bent', 'boiled', 'bombed', 'boozy', 'braised', 'broiled', 'browned', 'canned', 'cockeyed', 'cockeyed drunk'],
    'friend': ['maecenas', 'acquaintance', 'adherent', 'advocate', 'ally', 'alter ego', 'amigo', 'angel', 'associate', 'baby', 'backer', 'beau'],
    'friend at court': ['maecenas', 'rasputin', 'svengali', 'vip', 'abettor', 'access', 'admirer', 'advocate', 'aficionado', 'agent', 'amicus curiae', 'angel'],
    'friendless': ['abandoned', 'aidless', 'alienated', 'alone', 'aloof', 'apart', 'companionless', 'defenseless', 'deserted', 'desolate', 'detached', 'fatherless'],
    'friendly': ['accessible', 'acquainted', 'affable', 'affectionate', 'agreeable', 'agreeably', 'amiable', 'amiably', 'amicable', 'amicably', 'approachable', 'ardently'],
    'friendship': ['accord', 'affection', 'affinity', 'alliance', 'amiability', 'amicability', 'amity', 'attachment', 'attraction', 'benevolence', 'brotherhood', 'closeness'],
    'frieze': ['abacus', 'acanthus', 'annulet', 'apophyge', 'architrave', 'astragal', 'beading', 'beak', 'bell', 'billet', 'boss', 'capstone'],
    'frigg': ['aesir', 'balder', 'bor', 'bori', 'bragi', 'donar', 'forseti', 'frey', 'freya', 'freyja', 'freyr', 'frigga'],
    'fright': ['abject fear', 'affright', 'alarm', 'apprehension', 'awe', 'baboon', 'bag', 'blemish', 'blot', 'blue funk', 'consternation', 'cowardice'],
    'frighten': ['affright', 'agitate', 'alarm', 'alert', 'appall', 'arouse', 'astound', 'awe', 'bowl down', 'bowl over', 'browbeat', 'bulldoze'],
    'frightened': ['affrighted', 'aghast', 'alarmed', 'alerted', 'all nerves', 'anxious', 'apprehensive', 'aroused', 'consternated', 'daunted', 'dismayed', 'disquieted'],
    'frightening': ['alarming', 'appalling', 'awing', 'browbeating', 'bulldozing', 'bullying', 'chilling', 'cowing', 'daunting', 'demoralization', 'deterrent', 'deterring'],
    'frightful': ['abhorrent', 'abominable', 'alarming', 'appalling', 'atrocious', 'awful', 'awing', 'chilling', 'daunting', 'deadly', 'deterrent', 'deterring'],
    'frightfully': ['abominably', 'agonizingly', 'alarmingly', 'amazingly', 'appallingly', 'astoundingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly'],
    'frigid': ['olympian', 'siberian', 'affectless', 'algid', 'aloof', 'anesthetized', 'arctic', 'asexual', 'austere', 'autistic', 'backward', 'bashful'],
    'frigid zones': ['alaska', 'antarctic zone', 'antarctica', 'arctic circle', 'arctic zone', 'greenland', 'iceland', 'lower slobbovia', 'north pole', 'novaya zemlya', 'siberia', 'south pole'],
    'frill': ['addition', 'adornment', 'amenity', 'beading', 'beauties', 'bedizenment', 'binding', 'bonus', 'bordering', 'bordure', 'bravery', 'chiffon'],
    'frilly': ['arabesque', 'baroque', 'brave', 'bravura', 'braw', 'busy', 'chichi', 'daring', 'dashing', 'dressy', 'elaborate', 'elegant'],
    'fringe': ['adjoin', 'apparent', 'bang', 'bangs', 'bank', 'beading', 'befringe', 'bind', 'binding', 'board', 'border', 'bordering'],
    'frippery': ['sunday best', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'bagatelle', 'bauble', 'bean', 'bedizenment', 'bibelot', 'bit'],
    'frisk': ['amble', 'antic', 'beat the bushes', 'bob', 'bounce', 'burrow', 'canter', 'caper', 'capriole', 'caracole', 'carol', 'carry on'],
    'frisky': ['active', 'activist', 'activistic', 'alive', 'animated', 'antic', 'bouncing', 'bouncy', 'breezy', 'brisk', 'bubbly', 'capersome'],
    'frith': ['arm', 'armlet', 'bay', 'bayou', 'belt', 'bight', 'boca', 'boscage', 'bosket', 'brake', 'canebrake', 'ceja'],
    'fritter': ['apple fritter', 'beignet', 'beignet aux pommes', 'bismarck', 'blow', 'cast away', 'consume', 'cruller', 'dissipate', 'doughnut', 'fastnacht', 'fool away'],
    'frivolity': ['amusement', 'asininity', 'battiness', 'big deal', 'brainlessness', 'buffoonery', 'clownishness', 'crackpottedness', 'crankiness', 'craziness', 'daffiness', 'dallying'],
    'frivolous': ['aimless', 'airy', 'amorphous', 'asinine', 'birdbrained', 'birdwitted', 'brainless', 'buxom', 'capricious', 'casual', 'catchpenny', 'childish'],
    'frizzle': ['bake', 'barbecue', 'baste', 'blanch', 'boil', 'braise', 'brew', 'broil', 'brown', 'coddle', 'cook', 'crimp'],
    'fro': ['a rebours', 'a reculons', 'against the grain', 'anticlockwise', 'arear', 'ass-backwards', 'astern', 'away', 'back', 'backward', 'backwards', 'counterclockwise'],
    'frock': ['bib and tucker', 'cloak', 'costume', 'dress', 'duds', 'garment', 'gown', 'habit', 'jupe', 'mantle', 'rag', 'raiment'],
    'frog': ['aussie', 'boche', 'canuck', 'chink', 'guinea', 'hunk', 'hunkie', 'jerry', 'kraut', 'krauthead', 'mick', 'mickey'],
    'froggy': ['amphibian', 'anguine', 'batrachian', 'colubriform', 'crawling', 'creeping', 'crocodilian', 'lizardlike', 'ophidian', 'repent', 'reptant', 'reptile'],
    'frogman': ['naval reservist', 'royal marine', 'seabee', 'bather', 'bathing beauty', 'bathing girl', 'bluejacket', 'boot', 'cadet', 'deep-sea diver', 'diver', 'free diver'],
    'frolic': ['antic', 'beam', 'caper', 'caracole', 'carol', 'carouse', 'carry on', 'cavort', 'celebration', 'chirp', 'chirrup', 'clap hands'],
    'frolicsome': ['animated', 'antic', 'capersome', 'coltish', 'exuberant', 'frisky', 'full of beans', 'gamesome', 'gay', 'hearty', 'impish', 'lively'],
    'from': ['against', 'away from', 'barring', 'discounting', 'ex', 'except', 'excepting', 'exception taken of', 'excluding', 'exclusive of', 'for', 'leaving out'],
    'frond': ['bine', 'blade', 'bough', 'bract', 'bracteole', 'bractlet', 'branch', 'branchedness', 'branchiness', 'burgeon', 'cotyledon', 'deadwood'],
    'frondeur': ['agitator', 'anarch', 'anarchist', 'belittler', 'bellyacher', 'brawler', 'captious critic', 'carper', 'caviler', 'censor', 'censurer', 'common scold'],
    'front': ['cat', 'charlie mccarthy', 'dmz', 'accented', 'aceldama', 'act for', 'acting', 'advance', 'advance guard', 'aerospace', 'aerosphere', 'affectation'],
    'front line': ['dmz', 'aceldama', 'advance guard', 'airhead', 'avant-garde', 'battle line', 'battle site', 'battlefield', 'battleground', 'beachhead', 'bridgehead', 'combat area'],
    'front man': ['charlie mccarthy', 'agent', 'anteriority', 'bold front', 'brave face', 'brave front', 'connection', 'creature', 'deputy', 'display', 'dummy', 'facade'],
    'front matter': ['acknowledgments', 'anteriority', 'article', 'avant-propos', 'back', 'back matter', 'bastard title', 'bibliography', 'bold front', 'book', 'brave face', 'brave front'],
    'front position': ['antecedence', 'antecedency', 'anteposition', 'anteriority', 'dominion', 'precedence', 'precedency', 'preceding', 'precession', 'precursor', 'preference', 'prefixation'],
    'front runner': ['advance guard', 'airhead', 'ancestor', 'announcer', 'antecedent', 'avant-garde', 'battle line', 'beachhead', 'bellwether', 'bridgehead', 'buccinator', 'bushwhacker'],
    'frontage': ['anteriority', 'aspect', 'attitude', 'azimuth', 'bearing', 'bearings', 'bold front', 'brave face', 'brave front', 'celestial navigation', 'dead reckoning', 'display'],
    'frontal': ['communion table', 'altar', 'altar carpet', 'altar desk', 'altar facing', 'altar of prothesis', 'altar rail', 'altar side', 'altar slab', 'altar stair', 'altar stone', 'altarpiece'],
    'frontier': ['berlin wall', 'china', 'darkest africa', 'god knows where', 'greenland', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'siberia', 'south pole', 'thule'],
    'frontiersman': ['ancestor', 'announcer', 'antecedent', 'avant-garde', 'backwoodsman', 'bellwether', 'briar-hopper', 'brush ape', 'buccinator', 'bushman', 'bushwhacker', 'clam digger'],
    'frontispiece': ['anteriority', 'avant-propos', 'bold front', 'brave face', 'brave front', 'breakthrough', 'display', 'exordium', 'facade', 'face', 'facet', 'facia'],
    'frost': ['jack frost', 'benumb', 'besnow', 'bite', 'bitter weather', 'black frost', 'blanch', 'bleach', 'bleak weather', 'bomb', 'bust', 'cap'],
    'frostbite': ['minamata disease', 'ache', 'aching', 'altitude sickness', 'anoxemia', 'anoxia', 'anoxic anoxia', 'anthrax', 'benumb', 'bite', 'black lung', 'caisson disease'],
    'frosted': ['affectless', 'alcoholic drink', 'anesthetized', 'arctic', 'argent', 'argentine', 'autistic', 'beverage', 'blunt', 'canescent', 'catatonic', 'chalky'],
    'frosting': ['jell-o', 'albification', 'blanching', 'blancmange', 'bleaching', 'candy', 'comfit', 'compote', 'confiture', 'conserve', 'etiolation', 'gelatin'],
    'frosty': ['olympian', 'affectless', 'aloof', 'anesthetized', 'arctic', 'argent', 'argentine', 'autistic', 'backward', 'bashful', 'blank', 'blunt'],
    'froth': ['aerate', 'air', 'alluvion', 'alluvium', 'ash', 'babble', 'beat', 'breakers', 'bric-a-brac', 'bubble', 'bubbles', 'chaff'],
    'frothy': ['airy', 'asinine', 'barmy', 'birdbrained', 'birdwitted', 'brave', 'bravura', 'braw', 'bubbly', 'catchpenny', 'chichi', 'daring'],
    'froufrou': ['bravery', 'chiffon', 'clinquant', 'festoons', 'finery', 'folderol', 'foofaraw', 'frilliness', 'frilling', 'frills', 'frills and furbelows', 'frippery'],
    'froward': ['balky', 'cantankerous', 'contrary', 'cross-grained', 'difficult', 'disobedient', 'indisciplined', 'irascible', 'lawless', 'naughty', 'nonconforming', 'obstinate'],
    'frown': ['angry look', 'ban', 'black look', 'blackball', 'categorically reject', 'color', 'deprecate', 'dirty look', 'disallow', 'disapprove', 'disapprove of', 'discommend'],
    'frowning': ['beetle-browed', 'black', 'black-browed', 'dark', 'decorous', 'dejected', 'demure', 'dour', 'dumpish', 'earnest', 'formal', 'glowering'],
    'frowsty': ['bad', 'bad-smelling', 'blasted', 'blighted', 'blown', 'despoiled', 'fecal', 'fetid', 'flyblown', 'foul', 'frowsy', 'frowy'],
    'frowsy': ['blowsy', 'dowdy', 'draggletailed', 'funky', 'fusty', 'lax', 'musty', 'neglectful', 'negligent', 'noisome', 'rank', 'reeking'],
    'frowzy': ['bad', 'bad-smelling', 'beat-up', 'bedraggled', 'blasted', 'blighted', 'blown', 'blowzy', 'careless', 'chintzy', 'despoiled', 'dilapidated'],
    'frozen': ['abiding', 'adamant', 'adamantine', 'affectless', 'aghast', 'aguey', 'aguish', 'algid', 'amaranthine', 'anesthetized', 'appalled', 'arctic'],
    'fructify': ['be fruitful', 'be productive', 'bear', 'bear fruit', 'beget', 'bring forth', 'cross-fertilize', 'cross-pollen', 'cross-pollinate', 'cross-pollinize', 'dress', 'engender'],
    'fructuous': ['advantageous', 'advisable', 'appropriate', 'becoming', 'befitting', 'congruous', 'convenient', 'decent', 'desirable', 'expedient', 'favorable', 'feasible'],
    'frugal': ['lenten', 'scotch', 'spartan', 'abstemious', 'ascetic', 'austere', 'budget', 'canny', 'careful', 'chary', 'cheap', 'cheeseparing'],
    'frugality': ['abnegation', 'austerity', 'austerity program', 'canniness', 'care', 'carefulness', 'chariness', 'cheeseparing', 'constraint', 'denial', 'economic planning', 'economicalness'],
    'fruit': ['catawba', 'persian melon', 'valencia orange', 'acorn', 'advantages', 'aftermath', 'akee', 'alligator pear', 'ananas', 'apple', 'apricot', 'artifact'],
    'fruitarian': ['apostolici', 'brillat-savarin', 'encratite', 'lucullus', 'pythagorean', 'pythagorist', 'rechabite', 'shaker', 'abstainer', 'abstinent', 'ascetic', 'banian'],
    'fruitful': ['abundant', 'advantageous', 'beneficial', 'blooming', 'bounteous', 'bountiful', 'bursting', 'bursting out', 'copious', 'creative', 'effective', 'exuberant'],
    'fruition': ['accomplished fact', 'accomplishment', 'achievement', 'actualization', 'amusement', 'animal pleasure', 'attainment', 'bearing', 'bodily pleasure', 'carnal delight', 'carrying out', 'comfort'],
    'fruitless': ['abortive', 'acarpous', 'arid', 'barren', 'bootless', 'celibate', 'childless', 'counterproductive', 'desert', 'desolate', 'drained', 'dried-up'],
    'fruitlike': ['botanic', 'bulbous', 'cereal', 'farinaceous', 'fruity', 'herbaceous', 'herbal', 'herbose', 'herbous', 'herby', 'leguminose', 'leguminous'],
    'fruity': ['ambrosial', 'aromatic', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bonkers', 'botanic', 'buggy', 'bughouse'],
    'frump': ['beldam', 'crone', 'dame', 'dowager', 'drab', 'grandam', 'grandmother', 'granny', 'hag', 'litterbug', 'old battle-ax', 'old dame'],
    'frumpish': ['beat-up', 'bedraggled', 'blowzy', 'careless', 'chintzy', 'dilapidated', 'dowdy', 'drabbletailed', 'draggled', 'draggletailed', 'frowzy', 'frumpy'],
    'frustrate': ['annul', 'anticipate', 'arrest', 'baffle', 'balk', 'bar', 'beat', 'bilk', 'blast', 'block', 'brave', 'bring to nothing'],
    'frustrated': ['asexual', 'baffled', 'balked', 'betrayed', 'bilked', 'blasted', 'blighted', 'castrated', 'chapfallen', 'cold', 'crestfallen', 'crossed'],
    'frustration': ['ambivalence', 'ambivalence of impulse', 'annulment', 'bafflement', 'balk', 'balking', 'betrayed hope', 'blasted expectation', 'blighted hope', 'blow', 'buck-passing', 'buffet'],
    'fry': ['loch ness monster', 'alevin', 'bake', 'barbecue', 'baste', 'be in heat', 'benthon', 'benthos', 'blanch', 'blaze', 'bloom', 'boil'],
    'fryer': ['bantam', 'cornish hen', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'birdling', 'broiler', 'brooder', 'broody hen', 'caille', 'calf'],
    'fud': ['methuselah', 'antediluvian', 'antique', 'back number', 'conservative', 'dad', 'dodo', 'elder', 'fogy', 'fossil', 'fuddy-duddy', 'granny'],
    'fuddle': ['dutch courage', 'a high', 'addle', 'addle the wits', 'amaze', 'baffle', 'ball up', 'bamboozle', 'beat', 'becloud', 'bedazzle', 'befuddle'],
    'fuddled': ['addlebrained', 'addled', 'addleheaded', 'addlepated', 'afflicted', 'apish', 'asinine', 'at a loss', 'baffled', 'bamboozled', 'batty', 'beat'],
    'fuddy duddy': ['colonel blimp', 'methuselah', 'antediluvian', 'antique', 'back number', 'conservative', 'dad', 'dodo', 'dotard', 'elder', 'fogy', 'fogyish'],
    'fudge': ['life saver', 'scotch kisses', 'absurdity', 'amphigory', 'applesauce', 'babble', 'babblement', 'balderdash', 'baloney', 'beat', 'beguile of', 'belie'],
    'fuel': ['ammunition', 'bunker', 'cater', 'charge', 'coal', 'combustible', 'detonate', 'encourage', 'encouragement', 'exacerbate', 'excite', 'exhaust'],
    'fuel oil': ['barbados tar', 'anthracene oil', 'asphalt-base oil', 'benzine', 'coal oil', 'creosote', 'furnace oil', 'gas oil', 'jet fuel', 'kerosene', 'lamp oil', 'mineral oil'],
    'fugacious': ['brittle', 'capricious', 'changeable', 'corruptible', 'deciduous', 'dying', 'ephemeral', 'evanescent', 'fading', 'fickle', 'fleeting', 'flitting'],
    'fugacity': ['caducity', 'changeableness', 'corruptibility', 'death', 'ephemerality', 'ephemeralness', 'evanescence', 'finitude', 'fleetingness', 'impermanence', 'impermanency', 'instability'],
    'fugitive': ['dp', 'judas', 'absconder', 'at large', 'betrayer', 'bolter', 'brief', 'brittle', 'capricious', 'changeable', 'circumforaneous', 'convict'],
    'fugleman': ['a per se', 'mahdi', 'ace', 'ancestor', 'announcer', 'antecedent', 'antetype', 'antitype', 'archetype', 'avant-garde', 'bell cow', 'bell mare'],
    'fugue': ['agnosia', 'amnesia', 'blackout', 'canon', 'catalepsy', 'cataplexy', 'catatonic stupor', 'catch', 'daydreaming', 'daze', 'dream state', 'fugato'],
    'fuhrer': ['mahdi', 'simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'autocrat', 'bell cow', 'bell mare', 'bellwether', 'born leader'],
    'fulcrum': ['advocate', 'alpenstock', 'arbor', 'arm', 'athletic supporter', 'axis', 'axle', 'axle bar', 'axle shaft', 'axle spindle', 'axle-tree', 'back'],
    'fulfil': ['abide by', 'accomplish', 'achieve', 'answer', 'bring about', 'bring off', 'bring to completion', 'carry off', 'carry out', 'carry through', 'carry to completion', 'complete'],
    'fulfill': ['abide by', 'accomplish', 'achieve', 'act up to', 'adhere to', 'administer', 'answer', 'attain', 'attend to', 'avail', 'be equal to', 'be faithful to'],
    'fulfillment': ['acceptance', 'accomplished fact', 'accomplishment', 'accordance', 'achievement', 'acquittal', 'acquittance', 'adherence', 'adjustive reaction', 'adjustment', 'attainment', 'care'],
    'full': ['sro', 'a great deal', 'abounding', 'absolute', 'absorbed', 'abundant', 'addled', 'adipose', 'affluent', 'all-encompassing', 'all-inclusive', 'all-sufficing'],
    'full blast': ['amperage', 'armipotence', 'authority', 'beef', 'black power', 'brute force', 'charge', 'charisma', 'clout', 'cogence', 'cogency', 'compulsion'],
    'full blooded': ['beefy', 'blooming', 'blowzed', 'blowzy', 'blue-blooded', 'bouncing', 'burnt', 'doughty', 'florid', 'flush', 'flushed', 'forceful'],
    'full bloom': ['adulthood', 'adultness', 'age of consent', 'anthesis', 'bloom', 'blooming', 'blossom', 'blossoming', 'blow', 'blowing', 'driving age', 'efflorescence'],
    'full bodied': ['broad-bodied', 'bulky', 'bullnecked', 'coarse', 'corpulent', 'crass', 'dense', 'fat', 'flavorful', 'flavorous', 'flavorsome', 'flavory'],
    'full circle': ['ambit', 'angular momentum', 'angular motion', 'angular velocity', 'axial motion', 'beat', 'bowling', 'centrifugation', 'circle', 'circuit', 'circulation', 'circumgyration'],
    'full fledged': ['aged', 'blooming', 'blossoming', 'budding', 'burgeoning', 'complete', 'crescent', 'developed', 'entire', 'florescent', 'flourishing', 'flowering'],
    'full grown': ['aged', 'blooming', 'blossoming', 'budding', 'burgeoning', 'complete', 'crescent', 'developed', 'entire', 'florescent', 'flourishing', 'flowering'],
    'full house': ['ace', 'bellyful', 'best bower', 'bower', 'bumper', 'capacity', 'cards', 'charge', 'clubs', 'complement', 'cram', 'crush'],
    'full measure': ['abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bellyful', 'bonanza', 'bountifulness', 'bountiousness', 'bumper', 'bumper crop'],
    'full of beans': ['alive and kicking', 'animated', 'antic', 'bright-eyed and bushy-tailed', 'capersome', 'chipper', 'coltish', 'enjoying health', 'eupeptic', 'exuberant', 'fine', 'fit'],
    'full scale': ['all-out', 'complete', 'developed', 'entire', 'full', 'full-blown', 'full-fledged', 'full-formed', 'full-grown', 'global', 'intact', 'mature'],
    'full scope': ['ample scope', 'blank check', 'carte blanche', 'clearance', 'elbowroom', 'field', 'free course', 'free hand', 'free play', 'free scope', 'full swing', 'latitude'],
    'full stop': ['arrest', 'bell', 'cessation', 'check', 'checkmate', 'cutoff', 'dead set', 'dead stand', 'dead stop', 'deadlock', 'dying down', 'ebb'],
    'full swing': ['ample scope', 'blank check', 'carte blanche', 'clearance', 'elbowroom', 'field', 'free course', 'free hand', 'free play', 'free scope', 'full scope', 'latitude'],
    'full tilt': ['actively', 'all out', 'allegretto', 'allegro', 'animatedly', 'breezily', 'briskly', 'energetically', 'expeditiously', 'flat-out', 'hastily', 'in full swing'],
    'full time': ['anchor watch', 'bit', 'day shift', 'dogwatch', 'graveyard shift', 'half time', 'lobster trick', 'night shift', 'overtime', 'part time', 'relay', 'shift'],
    'fullback': ['amateur athlete', 'archer', 'athlete', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'blocking back', 'bowman', 'catcher', 'center'],
    'fullness': ['abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bassness', 'beam', 'bellyful', 'bonanza', 'boundlessness', 'bountifulness'],
    'fully': ['absolutely', 'abundantly', 'affluently', 'altogether', 'aplenty', 'at length', 'bottomlessly', 'bounteously', 'bountifully', 'completely', 'comprehensively', 'copiously'],
    'fulminate': ['backfire', 'bang', 'bark', 'blast', 'blow out', 'blow up', 'burst', 'bust', 'coal', 'crack', 'detonate', 'discharge'],
    'fulminate against': ['abuse', 'accurse', 'accuse', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'bark at', 'berate', 'betongue', 'blacken', 'blame'],
    'fulsome': ['fescennine', 'gongoresque', 'johnsonian', 'rabelaisian', 'abhorrent', 'abject', 'abominable', 'adulatory', 'affected', 'arrant', 'atrocious', 'awful'],
    'fumble': ['bad job', 'ball up', 'be all thumbs', 'beat about', 'bevue', 'blow', 'blunder', 'blunder away', 'blunder into', 'blunder on', 'blunder upon', 'bobble'],
    'fumbled': ['botched', 'bungled', 'butchered', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-done', 'ill-executed', 'ill-managed', 'impolitic', 'misconducted'],
    'fumbling': ['all thumbs', 'awkward', 'blunderheaded', 'blunderheadedness', 'blundering', 'boggling', 'boorish', 'botchery', 'botching', 'bumbling', 'bungling', 'butterfingered'],
    'fume': ['achromatize', 'ado', 'aerate', 'aerify', 'afterdamp', 'agitation', 'anhydrate', 'aroma', 'ash', 'ashes', 'atomize', 'be livid'],
    'fumigant': ['acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bactericide', 'bug bomb', 'carbamate insecticide', 'chemosterilant', 'contact poison', 'defoliant', 'deodorant', 'deodorizer'],
    'fumigate': ['aerate', 'aerify', 'antisepticize', 'aromatize', 'atomize', 'autoclave', 'boil', 'carbonate', 'cense', 'chlorinate', 'cleanse', 'decontaminate'],
    'fumigation': ['aeration', 'aerification', 'antisepsis', 'atomization', 'decontamination', 'deodorization', 'deodorizing', 'disinfection', 'disinfestation', 'distillation', 'etherealization', 'etherification'],
    'fuming': ['ablaze', 'aerial', 'aerodynamic', 'aerostatic', 'aery', 'afire', 'aflame', 'aflicker', 'aglow', 'airy', 'alight', 'ardent'],
    'fun': ['act', 'action', 'amusement', 'amusing', 'animal pleasure', 'ball', 'be merry with', 'beguiling', 'behave', 'belly laugh', 'big time', 'blitheness'],
    'fun fair': ['amusement park', 'ballroom', 'cabaret', 'cafe chantant', 'cafe dansant', 'casino', 'dance floor', 'dance hall', 'dancing pavilion', 'entertainment industry', 'juke joint', 'night spot'],
    'function': ['ic analysis', 'act', 'act as', 'acting', 'action', 'activism', 'activities', 'activity', 'affair', 'affairs', 'aim', 'ambition'],
    'functional': ['acting', 'active', 'adjectival', 'advantageous', 'adverbial', 'agential', 'agentival', 'agentive', 'appropriate', 'at work', 'attributive', 'banausic'],
    'functionary': ['federal', 'agent', 'amanuensis', 'baggage agent', 'bureaucrat', 'business agent', 'civil servant', 'claim agent', 'clerk', 'commercial agent', 'commission agent', 'commissioner'],
    'functioning': ['act', 'acting', 'action', 'active', 'activism', 'activity', 'agency', 'alive', 'at work', 'behavior', 'behavioral', 'conduct'],
    'fund': ['festschrift', 'swiss bank account', 'accommodate', 'acknowledge', 'afford', 'afford support', 'aid', 'ana', 'angel', 'anthology', 'aquarium', 'assets'],
    'fundament': ['backside', 'base', 'basement', 'basis', 'beam', 'bearing wall', 'bed', 'bedding', 'bedrock', 'behind', 'belly', 'bottom'],
    'fundamental': ['af', 'ab ovo', 'abecedarian', 'aboriginal', 'antenatal', 'audio frequency', 'austere', 'autochthonous', 'axiom', 'bare', 'basal', 'base'],
    'fundamentalism': ['sabbatarianism', 'bibliolatry', 'bigotry', 'dogmatism', 'evangelicalism', 'firmness', 'hardness', 'hideboundness', 'hyperorthodoxy', 'impliability', 'inexorability', 'inflexibility'],
    'fundamentalist': ['orthodox jew', 'sabbatarian', 'sunni muslim', 'bigoted', 'bitter-ender', 'canonist', 'conservative', 'creedbound', 'dogmatic', 'dour', 'evangelical', 'firm'],
    'fundamentally': ['a outrance', 'absolutely', 'all out', 'at bottom', 'at heart', 'at the core', 'au fond', 'basically', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure'],
    'funds': ['swiss bank account', 'ability', 'assessed valuation', 'assets', 'assets and liabilities', 'balance', 'bank account', 'bottom dollar', 'budget', 'capacity', 'capital', 'cash reserves'],
    'funebrial': ['black', 'bleak', 'cinerary', 'dark', 'dirgelike', 'dismal', 'drear', 'drearisome', 'dreary', 'epitaphic', 'exequial', 'feral'],
    'funeral': ['burial', 'burial at sea', 'burying', 'caravan', 'cavalcade', 'cinerary', 'column', 'cortege', 'cremation', 'dead march', 'deep six', 'dirge'],
    'funeral march': ['andante', 'claudication', 'coronach', 'crawl', 'creep', 'dead march', 'death knell', 'death song', 'dirge', 'dogtrot', 'elegy', 'epicedium'],
    'funereal': ['acheronian', 'acherontic', 'cimmerian', 'stygian', 'black', 'blackish', 'bleak', 'cinerary', 'clouded', 'cloudy', 'dark', 'dark and gloomy'],
    'fungicide': ['aborticide', 'acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bug bomb', 'carbamate insecticide', 'chemosterilant', 'contact poison', 'defoliant', 'disinfectant', 'eradicant'],
    'fungus': ['adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'amphibian', 'anaerobe', 'anaerobic bacteria', 'angiosperm', 'annual', 'aquatic plant', 'bacillus', 'bacteria'],
    'funicular': ['amtrak', 'baggage train', 'cable railroad', 'cable railway', 'cableway', 'capillary', 'choo-choo', 'cirrose', 'cirrous', 'cog railroad', 'cog railway', 'el'],
    'funk': ['milquetoast', 'abject fear', 'affright', 'alarm', 'awe', 'baby', 'back out', 'big baby', 'blench', 'blink', 'blue funk', 'boggle'],
    'funky': ['afraid', 'atrabiliar', 'atrabilious', 'bad', 'bad-smelling', 'blue', 'chicken', 'chickenhearted', 'coward', 'cowardly', 'cowed', 'daunted'],
    'funnel': ['adjutage', 'approach', 'asymptote', 'bottleneck', 'canalize', 'carry', 'catheter', 'center', 'centralize', 'channel', 'channelize', 'chimney'],
    'funnel shaped': ['boat-shaped', 'boatlike', 'bowl-shaped', 'bowllike', 'cavelike', 'cavernous', 'concave', 'concaved', 'cone-shaped', 'coned', 'conelike', 'conic'],
    'funny': ['attic', 'abnormal', 'absurd', 'amusing', 'anomalous', 'antic', 'biting', 'bizarre', 'brilliant', 'clever', 'comic', 'comical'],
    'funnyman': ['banana', 'burlesquer', 'caricaturist', 'clown', 'comedian', 'comedienne', 'comic', 'cutup', 'droll', 'epigrammatist', 'farcer', 'farceur'],
    'fur': ['australian seal', 'leatherette', 'leatheroid', 'achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'azure'],
    'furbelow': ['beading', 'binding', 'bordering', 'bordure', 'edging', 'fimbria', 'fimbriation', 'flounce', 'frill', 'frilling', 'fringe', 'galloon'],
    'furbish': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'brighten up', 'brush up', 'buff', 'burnish', 'color', 'dandify'],
    'furbished': ['buffed', 'burnished', 'finished', 'glace', 'glassy', 'glazed', 'gleaming', 'glossy', 'lacquered', 'polished', 'rubbed', 'satiny'],
    'furcate': ['v-shaped', 'y-shaped', 'akimbo', 'angle', 'angle off', 'angular', 'arboreal', 'arborescent', 'arboriform', 'bend', 'bent', 'biforked'],
    'furfuraceous': ['asperous', 'branny', 'chalklike', 'chalky', 'comminute', 'comminuted', 'crushed', 'detrital', 'detrited', 'disintegrated', 'dusty', 'efflorescent'],
    'furies': ['alecto', 'fury', 'megaera', 'nemesis', 'tisiphone', 'avenger', 'burning rage', 'furious rage', 'furor', 'fury', 'passion', 'rage'],
    'furious': ['dionysiac', 'abandoned', 'accident-prone', 'acute', 'amok', 'anarchic', 'angry', 'at fever pitch', 'bacchic', 'bellowing', 'berserk', 'bewildered'],
    'furiously': ['a corps perdu', 'all to pieces', 'amain', 'angrily', 'apace', 'at once', 'by forced marches', 'carelessly', 'cursorily', 'deliriously', 'demonically', 'desperately'],
    'furlough': ['awol', 'french leave', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'boot', 'bounce', 'break', 'bump'],
    'furnace': ['seger cone', 'torrid zone', 'acid kiln', 'atomic pile', 'blacksmith shop', 'blast furnace', 'bloomery', 'boiler', 'bottle-gas stove', 'breeder reactor', 'brickkiln', 'bricks'],
    'furnish': ['accommodate', 'accommodate with', 'accouter', 'adapt', 'adjust', 'afford', 'apparel', 'appoint', 'arm', 'array', 'attune', 'bear'],
    'furnishing': ['accouterment', 'adaptation', 'adjustment', 'armament', 'catering', 'chandlery', 'conditioning', 'enablement', 'endowment', 'equipment', 'finding', 'fit'],
    'furnishings': ['accouterments', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'caparison', 'conveniences', 'duffel', 'equipage', 'equipment', 'facilities'],
    'furniture': ['intertype', 'linotype', 'monotype', 'accessories', 'accouterments', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'belongings', 'chattels'],
    'furor': ['alecto', 'megaera', 'nemesis', 'tisiphone', 'abandon', 'aberration', 'abnormality', 'agitation', 'alienation', 'amok', 'ardency', 'ardor'],
    'furore': ['ado', 'brouhaha', 'bustle', 'chic', 'coil', 'commotion', 'craze', 'cry', 'disturbance', 'enthusiasm', 'excitement', 'fad'],
    'furrier': ['baker', 'bookdealer', 'bookseller', 'busheler', 'bushelman', 'butcher', 'chandler', 'clothier', 'clothing merchant', 'confectioner', 'costumer', 'costumier'],
    'furrow': ['abysm', 'abyss', 'alveolation', 'alveolus', 'arroyo', 'autolithograph', 'be a printmaker', 'bore', 'box canyon', 'breach', 'break', 'burrow'],
    'furrowed': ['canaliculate', 'canaliculated', 'carved', 'chamfered', 'channeled', 'cockled', 'cockly', 'corduroy', 'corduroyed', 'corrugate', 'corrugated', 'costate'],
    'furry': ['bristly', 'bushy', 'cirrose', 'cortical', 'cutaneous', 'dermal', 'dermic', 'downy', 'ecderonic', 'ectodermal', 'ectodermic', 'endermatic'],
    'further': ['above', 'accessory', 'added', 'additional', 'additionally', 'advance', 'advantage', 'again', 'aid', 'all included', 'also', 'altogether'],
    'furtherance': ['great leap forward', 'accomplishment', 'advance', 'advancement', 'advancing', 'advocacy', 'advocating', 'aid', 'amelioration', 'amendment', 'amplification', 'ascent'],
    'furthermore': ['above', 'additionally', 'again', 'all included', 'along', 'also', 'altogether', 'among other things', 'and all', 'and also', 'and so', 'as well'],
    'furthest': ['at the height', 'at the limit', 'extreme', 'far out', 'farthermost', 'farthest', 'farthest off', 'furthermost', 'greatest', 'most', 'most distant', 'outermost'],
    'furtive': ['artful', 'back-door', 'backstairs', 'calculating', 'chiseling', 'clandestine', 'collusive', 'conspiratorial', 'covert', 'covinous', 'crafty', 'cunning'],
    'furtiveness': ['artfulness', 'clandestine behavior', 'clandestinity', 'covertness', 'craft', 'cunning', 'deceit', 'deceitfulness', 'duplicity', 'falseheartedness', 'falseness', 'guile'],
    'furuncle': ['abscess', 'aposteme', 'bed sore', 'blain', 'bleb', 'blister', 'boil', 'bubo', 'bulla', 'bump', 'bunion', 'canker'],
    'fury': ['alecto', 'jezebel', 'mafioso', 'megaera', 'nemesis', 'tartar', 'tisiphone', 'young turk', 'abandon', 'acerbity', 'acrimony', 'agitation'],
    'fuse': ['act in concert', 'act together', 'add', 'admix', 'aegis', 'affiliate', 'agglutinate', 'alloy', 'ally', 'amalgamate', 'arm guard', 'assemble'],
    'fused': ['amalgamated', 'assimilated', 'blended', 'combinative', 'combinatory', 'combined', 'conjoint', 'conjugate', 'conjunctive', 'connective', 'consolidated', 'eclectic'],
    'fusillade': ['aim at', 'antiaircraft barrage', 'bang', 'bark', 'barrage', 'bash', 'bat', 'beating', 'beheading', 'belt', 'biff', 'blast'],
    'fusion': ['anschluss', 'addition', 'admixture', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alignment', 'alliance', 'alloy', 'alloyage', 'amalgam'],
    'fuss': ['addle', 'addle the wits', 'ado', 'agitate', 'agitation', 'air a grievance', 'altercation', 'argument', 'ball up', 'becloud', 'bedazzle', 'beef'],
    'fussy': ['byzantine', 'accurate', 'agitated', 'arabesque', 'attentive', 'baroque', 'bustling', 'busy', 'chichi', 'choosy', 'close', 'conscientious'],
    'fust': ['age', 'antiquate', 'become extinct', 'become obsolete', 'date', 'fade', 'fossilize', 'grow old', 'hang fire', 'idle', 'lose currency', 'molder'],
    'fustian': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'blabber', 'blather', 'bombast', 'bombastic', 'bombastry', 'claptrap'],
    'fustigate': ['assail', 'attack', 'baste', 'bastinado', 'beat', 'belabor', 'belt', 'birch', 'blister', 'buffet', 'cane', 'castigate'],
    'fusty': ['archaic', 'back-number', 'bad', 'bad-smelling', 'banal', 'bewhiskered', 'blasted', 'blighted', 'blown', 'bromidic', 'bygone', 'close'],
    'futile': ['abortive', 'absurd', 'airy', 'apish', 'asinine', 'bad', 'barren', 'batty', 'befooled', 'beguiled', 'besotted', 'bootless'],
    'futility': ['absurdity', 'aimlessness', 'bankruptcy', 'big deal', 'blank future', 'bleak outlook', 'bootlessness', 'counterproductiveness', 'counterproductivity', 'dead letter', 'defeat', 'emptiness'],
    'future': ['friday', 'friday the thirteenth', 'about to be', 'affianced', 'aftertime', 'afterward', 'already in sight', 'aorist', 'appointed lot', 'approaching', 'astral influences', 'astrology'],
    'futuristic': ['approaching', 'coming', 'desired', 'destinal', 'destined', 'determined', 'emergent', 'eventual', 'extrapolated', 'fatal', 'fated', 'fatidic'],
    'futurity': ['aftertime', 'afteryears', 'approach', 'by-and-by', 'coming', 'course ahead', 'crystal ball', 'determinism', 'distant future', 'eventuality', 'expectation', 'finality'],
    'fuzz': ['dogberry', 'john law', 'air', 'bluecoat', 'bobby', 'bubble', 'bull', 'chaff', 'chip', 'cobweb', 'confuse', 'cop'],
    'fuzzy': ['aleatoric', 'aleatory', 'amorphic', 'amorphous', 'anarchic', 'attenuate', 'attenuated', 'baggy', 'blear', 'bleared', 'bleary', 'blind'],
    'g man': ['bow street runner', 'fbi', 'fbi agent', 'federal', 'mp', 'secret service', 'sherlock holmes', 't-man', 'bailiff', 'beadle', 'beagle', 'bound bailiff'],
    'gab': ['accents', 'babble', 'babblement', 'balderdash', 'balls', 'bavardage', 'bazoo', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blarney'],
    'gabble': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bavardage', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather', 'blether'],
    'gabby': ['all jaw', 'candid', 'chatty', 'communicative', 'conversational', 'effusive', 'expansive', 'flip', 'fluent', 'frank', 'garrulous', 'gassy'],
    'gad': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'bat', 'bat around', 'bird of passage'],
    'gad about': ['bat around', 'bum', 'count ties', 'divagate', 'drift', 'flit', 'gad', 'gallivant', 'go about', 'go the rounds', 'hit the road', 'hit the trail'],
    'gadabout': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'bird of passage', 'drifter', 'floater'],
    'gadfly': ['abettor', 'actuator', 'animator', 'cajoler', 'coax', 'coaxer', 'encourager', 'energizer', 'firer', 'gad', 'galvanizer', 'goad'],
    'gadget': ['affair', 'apparatus', 'appliance', 'article', 'artifact', 'business', 'concern', 'contraption', 'contrivance', 'creation', 'device', 'dingus'],
    'gaea': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'gaffer': ['big brother', 'father time', 'methuselah', 'nestor', 'old paar', 'auditor', 'boatswain', 'boss', 'centenarian', 'chief', 'comptroller', 'controller'],
    'gag': ['oregon boat', 'acoustic tile', 'acting', 'antiknock', 'asphyxiate', 'baffler', 'balk', 'barf', 'be nauseated', 'be seasick', 'be sick', 'belly laugh'],
    'gaga': ['ape about', 'apish', 'asinine', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'befooled', 'beguiled', 'besotted'],
    'gage': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'bail', 'battle cry', 'bid to combat'],
    'gaggle': ['bevy', 'cackle', 'call', 'carol', 'caw', 'charm', 'chatter', 'cheep', 'chirk', 'chirp', 'chirr', 'chirrup'],
    'gaiety': ['technicolor', 'animal spirits', 'animation', 'beatification', 'beatitude', 'bewitchment', 'blatancy', 'blessedness', 'bliss', 'blissfulness', 'blitheness', 'bravery'],
    'gaily': ['airily', 'blithely', 'brightly', 'brilliantly', 'cheerfully', 'cheerily', 'colorfully', 'flamboyantly', 'flashily', 'garishly', 'gaudily', 'gleefully'],
    'gain': ['accept', 'access', 'accession', 'accomplish', 'accretion', 'accrual', 'accrue', 'accruement', 'accumulate', 'accumulation', 'achieve', 'achievement'],
    'gain the day': ['bear the palm', 'capture', 'carry', 'carry away', 'carry it', 'carry off', 'carry the day', 'come out first', 'finish in front', 'fluke', 'gain', 'make a killing'],
    'gain upon': ['accost', 'advance', 'approach', 'appropinquate', 'approximate', 'bear down on', 'bear down upon', 'bear up', 'catch up with', 'close', 'close in', 'close with'],
    'gainer': ['belly buster', 'belly flop', 'belly whopper', 'cannonball', 'crash dive', 'dive', 'drop', 'fall', 'header', 'jackknife', 'nose dive', 'parachute jump'],
    'gainful': ['advantageous', 'banausic', 'beneficial', 'breadwinning', 'fat', 'fruitful', 'generous', 'good', 'lucrative', 'lush', 'moneymaking', 'of value'],
    'gains': ['avails', 'box office', 'capital gains', 'cleanup', 'clear profit', 'commissions', 'credit', 'credits', 'disposable income', 'dividend', 'dividends', 'earned income'],
    'gainsay': ['abjure', 'assert the contrary', 'be contrary to', 'belie', 'call into question', 'challenge', 'combat', 'contest', 'contradict', 'contravene', 'controvert', 'counter'],
    'gait': ['amble', 'bat', 'career', 'celerity', 'clip', 'drag', 'droop', 'flounce', 'gallop', 'hitch', 'hobble', 'jog'],
    'gal': ['babe', 'baby', 'broad', 'chick', 'colleen', 'cutie', 'dame', 'damoiselle', 'damsel', 'demoiselle', 'doll', 'filly'],
    'gala': ['mardi gras', 'saturnalia', 'ball', 'banquet', 'blowout', 'carnival', 'celebration', 'celebratory', 'cheerful', 'cheery', 'convivial', 'do'],
    'galactic': ['cynthian', 'gargantuan', 'all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'allover'],
    'galaxy': ['milky way', 'via lactea', 'army', 'barred spiral', 'barred spiral galaxy', 'big name', 'celebrity', 'cluster', 'cohue', 'constellation', 'cosmic noise', 'crowd'],
    'gale': ['air', 'black squall', 'blast', 'blaze', 'blizzard', 'blow', 'breeze', 'burst', 'convulsion', 'cooling breeze', 'cyclone', 'equinoctial'],
    'gall': ['ablate', 'abrade', 'abrase', 'abrasion', 'acerbity', 'acid', 'acidity', 'acidulousness', 'acridity', 'acridness', 'acrimony', 'afflict'],
    'gallant': ['achilles', 'beau brummel', 'casanova', 'david', 'don juan', 'hector', 'lothario', 'roland', 'romeo', 'samson', 'a man', 'abandoned'],
    'gallantry': ['dutch courage', 'address', 'addresses', 'amenity', 'amorous pursuit', 'attention', 'backbone', 'boldness', 'braveness', 'bravery', 'chivalrousness', 'chivalry'],
    'galled': ['aggravated', 'algetic', 'angry', 'annoyed', 'bothered', 'browned-off', 'bugged', 'burning', 'burnt-up', 'chafed', 'disturbed', 'exasperated'],
    'galleon': ['bark', 'bawley', 'bilander', 'brig', 'brigantine', 'bully', 'buss', 'caravel', 'cat', 'catamaran', 'clipper', 'corsair'],
    'gallery': ['british museum', 'guggenheim museum', 'hermitage', 'louvre', 'metropolitan museum', 'national gallery', 'prado', 'rijksmuseum', 'tate gallery', 'texas tower', 'uffizi', 'abri'],
    'galley': ['bakehouse', 'bakery', 'bireme', 'blue', 'blueprint', 'caboose', 'camboose', 'cold-type proof', 'color proof', 'computer proof', 'cookery', 'cookhouse'],
    'galley slave': ['bargee', 'bargeman', 'barger', 'beast of burden', 'boat-handler', 'boater', 'boatman', 'boatsman', 'bondmaid', 'bondman', 'bondslave', 'bondsman'],
    'galling': ['ablative', 'abradant', 'abrasive', 'afflictive', 'aggravating', 'annoying', 'attritive', 'bothering', 'bothersome', 'chafing', 'distasteful', 'disturbing'],
    'gallivant': ['bat', 'bat around', 'bum', 'cast coquettish glances', 'coquet', 'count ties', 'divagate', 'drift', 'eye', 'flirt', 'flit', 'gad'],
    'gallop': ['amble', 'bound', 'burst', 'burst of speed', 'canter', 'caracole', 'curvet', 'dash', 'dead run', 'dogtrot', 'drag', 'droop'],
    'galloping': ['agile', 'breakneck', 'dashing', 'double-quick', 'eagle-winged', 'expeditious', 'express', 'fast', 'fleet', 'flying', 'hair-trigger', 'hasty'],
    'gallows': ['ax', 'beheading', 'block', 'burning', 'capital punishment', 'cross', 'crucifixion', 'death chair', 'death chamber', 'decapitation', 'decollation', 'defenestration'],
    'galoot': ['asshole', 'bloke', 'boob', 'booby', 'buck', 'chap', 'chump', 'cuss', 'ding-a-ling', 'dingbat', 'dingdong', 'fellow'],
    'galore': ['a deal', 'a great deal', 'a lot', 'abounding', 'abundant', 'abundantly', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'as all creation', 'as all get-out'],
    'galvanic': ['agitating', 'alluring', 'battery-powered', 'breathtaking', 'challenging', 'charged', 'cliff-hanging', 'disquieting', 'distracting', 'disturbing', 'dynamoelectric', 'electric'],
    'galvanize': ['activate', 'actuate', 'amplify', 'animate', 'arouse', 'charge', 'chromium-plate', 'compel', 'copperplate', 'dynamize', 'electrify', 'electrogalvanize'],
    'gam': ['ankle', 'army', 'bayonet legs', 'be closeted with', 'bowlegs', 'bunch', 'calf', 'causerie', 'chat', 'cnemis', 'colony', 'coze'],
    'gambit': ['alpha', 'approach', 'art', 'artful dodge', 'artifice', 'assay', 'attempt', 'bag of tricks', 'bid', 'blind', 'bluff', 'bosey'],
    'gamble': ['accidentality', 'actuarial calculation', 'admit of', 'adventitiousness', 'ante', 'ante up', 'back', 'be liable', 'be subjected to', 'bet', 'bet on', 'bid fair to'],
    'gamble on': ['aller sans dire', 'bank on', 'be axiomatic', 'be certain', 'be confident', 'bet on', 'calculate on', 'chance', 'chance it', 'count on', 'depend on', 'doubt not'],
    'gambler': ['adventurer', 'betting ring', 'bettor', 'boneshaker', 'cardshark', 'cardsharp', 'cardsharper', 'compulsive gambler', 'crap shooter', 'gamester', 'hazarder', 'petty gambler'],
    'gambling': ['cosa nostra', 'mafia', 'betting', 'black market', 'bootlegging', 'cardsharping', 'casting lots', 'gaming', 'gray market', 'hazarding', 'illegal commerce', 'illegal operations'],
    'gambling house': ['baths', 'betting house', 'betting parlor', 'casino', 'club', 'clubhouse', 'crib', 'flat', 'gambling den', 'gambling hall', 'gambling hell', 'gaming house'],
    'gambol': ['antic', 'beam', 'bob', 'bounce', 'bound', 'caper', 'capriole', 'caracole', 'carol', 'carry on', 'cavort', 'chirp'],
    'gambrel': ['ankle', 'bayonet legs', 'bowlegs', 'calf', 'cnemis', 'drumstick', 'foreleg', 'gamb', 'gigot', 'ham', 'hind leg', 'hock'],
    'game': ['animalia', 'boston', 'byzantine intrigues', 'earl of coventry', 'monopoly', 'olympic games', 'olympics', 'ping-pong', 'pit', 'polish bank', 'rugby', 'russian bank'],
    'game warden': ['audubon society', 'national wildlife service', 'sierra club', 'air warden', 'attendant', 'caretaker', 'castellan', 'conservationist', 'conservator', 'curator', 'custodian', 'deliverer'],
    'gamecock': ['achilles', 'david', 'hector', 'roland', 'samson', 'a man', 'battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'brave'],
    'gamely': ['audaciously', 'boldly', 'bravely', 'bulldoggishly', 'chivalrously', 'courageously', 'daringly', 'dauntlessly', 'doughtily', 'fearlessly', 'gallantly', 'gutsily'],
    'games': ['highland games', 'olympiad', 'olympic games', 'olympics', 'bout', 'carousel', 'concours', 'contest', 'derby', 'encounter', 'engagement', 'field day'],
    'gamesmanship': ['italian hand', 'acuteness', 'art', 'artfulness', 'artifice', 'astuteness', 'cageyness', 'callidity', 'canniness', 'cleverness', 'competition', 'craft'],
    'gamesome': ['animated', 'antic', 'capersome', 'coltish', 'exuberant', 'frisky', 'frolicsome', 'full of beans', 'gay', 'hearty', 'larkish', 'lively'],
    'gamic': ['amorous', 'carnal', 'erogenic', 'erogenous', 'erotic', 'erotogenic', 'fleshly', 'gametic', 'heterosexual', 'libidinal', 'nuptial', 'oversexed'],
    'gamin': ['arab', 'jd', 'beach bum', 'beachcomber', 'beggar', 'bo', 'brat', 'bum', 'bummer', 'dogie', 'elf', 'enfant terrible'],
    'gamma ray': ['becquerel ray', 'grenz ray', 'roentgen ray', 'x radiation', 'x ray', 'actinic ray', 'actinism', 'alpha radiation', 'alpha ray', 'anode ray', 'atomic beam', 'atomic ray'],
    'gammon': ['absurdity', 'act', 'act a part', 'affect', 'amphigory', 'assume', 'babble', 'babblement', 'bacon', 'balderdash', 'balls', 'baloney'],
    'gamut': ['indian file', 'array', 'articulation', 'bank', 'buzz', 'carry', 'catena', 'catenation', 'chain', 'chain reaction', 'chaining', 'chromatic scale'],
    'gamy': ['bad', 'bad-smelling', 'blown', 'bulldoggish', 'fecal', 'fetid', 'foul', 'frowsty', 'frowy', 'frowzy', 'fulsome', 'funky'],
    'gander': ['bantam', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'billy', 'billy goat', 'boar', 'broiler', 'brooder', 'broody hen', 'bubbly-jock'],
    'gang': ['bund', 'rochdale cooperative', 'affiliate', 'age group', 'alliance', 'ally', 'army', 'assemblage', 'associate', 'association', 'axis', 'band'],
    'gang around': ['assemble', 'bunch', 'bunch up', 'clot', 'cluster', 'collect', 'come together', 'congregate', 'converge', 'copulate', 'couple', 'crowd'],
    'gang up on': ['ambush', 'assail', 'assault', 'attack', 'blitz', 'bushwhack', 'come at', 'come down on', 'crack down on', 'descend on', 'descend upon', 'fall on'],
    'gangling': ['bony', 'colossal', 'flat', 'flat-chested', 'fleshless', 'gangly', 'gaunt', 'gawky', 'giant', 'gigantic', 'lank', 'lanky'],
    'ganglion': ['afferent neuron', 'autonomic nervous system', 'axon', 'brain', 'center of activity', 'central nervous system', 'cerebral cortex', 'craniosacral nervous system', 'dendrite', 'effector organ', 'efferent neuron', 'gray matter'],
    'gangplank': ['bifrost', 'access', 'adit', 'air lock', 'approach', 'bascule bridge', 'bateau bridge', 'bridge', 'cantilever bridge', 'catwalk', 'corridor', 'drawbridge'],
    'gangrene': ['break up', 'canker', 'caries', 'carrion', 'corrupt', 'corruption', 'crumble', 'crumble into dust', 'dandruff', 'decay', 'decompose', 'decomposition'],
    'gangrened': ['bad', 'cankered', 'carious', 'contaminated', 'corrupt', 'decayed', 'decomposed', 'diseased', 'festering', 'foul', 'gangrenous', 'gone bad'],
    'gangster': ['judas', 'mafioso', 'bad person', 'bandit', 'betrayer', 'brigand', 'convict', 'criminal', 'crook', 'dacoit', 'deceiver', 'delinquent'],
    'gangway': ['bifrost', 'access', 'adit', 'air lock', 'approach', 'bascule bridge', 'bateau bridge', 'bridge', 'cantilever bridge', 'catwalk', 'corridor', 'drawbridge'],
    'ganja': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'diethyltryptamine', 'dimethyltryptamine', 'gage'],
    'gantlet': ['battle cry', 'bid to combat', 'brass knuckles', 'cesta', 'cestus', 'challenge', 'confinement', 'dare', 'defi', 'defy', 'dismemberment', 'double dare'],
    'gaol': ['pow camp', 'bastille', 'beleaguer', 'beset', 'besiege', 'black hole', 'blockade', 'bolt in', 'borstal', 'borstal institution', 'bound', 'box in'],
    'gap': ['abysm', 'abyss', 'aperture', 'arrearage', 'arroyo', 'bottom', 'bottom glade', 'bottoms', 'box canyon', 'breach', 'break', 'breakage'],
    'gape': ['abysm', 'abyss', 'aperture', 'arroyo', 'attend', 'be amazed', 'be astonished', 'be curious', 'bedroom eyes', 'bore', 'box canyon', 'breach'],
    'gaping': ['abysmal', 'abyssal', 'agape', 'aghast', 'agog', 'ajar', 'all agog', 'amazed', 'anticipant', 'anticipating', 'anticipative', 'anticipatory'],
    'garb': ['air', 'apparel', 'array', 'attire', 'bearing', 'bedeck', 'bedizenment', 'bedrape', 'brow', 'bundle up', 'carriage', 'cast'],
    'garbage': ['bilge', 'bilgewater', 'bones', 'carrion', 'chaff', 'crap', 'culm', 'deadwood', 'debris', 'detritus', 'dishwater', 'ditchwater'],
    'garbage dump': ['bog', 'cesspool', 'cloaca', 'cloaca maxima', 'colluvies', 'compost heap', 'drain', 'dump', 'dunghill', 'kitchen midden', 'manure pile', 'marsh'],
    'garble': ['aesopian language', 'babel', 'greek', 'adulterate', 'argot', 'babble', 'ball up', 'becloud', 'belie', 'bias', 'bollix up', 'burlesque'],
    'garbled': ['affected', 'aimless', 'apocryphal', 'artificial', 'assumed', 'bastard', 'beyond one', 'biased', 'bogus', 'brummagem', 'butchered', 'castrated'],
    'garcon': ['boy', 'bub', 'bubba', 'buck', 'bud', 'buddy', 'butler', 'chauffeur', 'coachman', 'colt', 'cub', 'driver'],
    'garden': ['attic', 'festschrift', 'japanese garden', 'album', 'alpine garden', 'ana', 'analects', 'anthology', 'arboretum', 'average', 'beauties', 'bed'],
    'garden of eden': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'goshen', 'happy valley', 'land of youth'],
    'garden variety': ['attic', 'average', 'averageness', 'bourgeois', 'chaste', 'classic', 'classical', 'common', 'commonness', 'commonplace', 'commonplaceness', 'conventional'],
    'gardener': ['boy', 'butler', 'chauffeur', 'coachman', 'driver', 'equerry', 'floriculturist', 'florist', 'fruit-grower', 'gentleman', 'gillie', 'horticulturist'],
    'gardening': ['bloom', 'blossom', 'blow', 'citriculture', 'floret', 'floriculture', 'floscule', 'flower', 'flower gardening', 'flower-growing', 'floweret', 'fruit-growing'],
    'gargantuan': ['atlantean', 'brobdingnagian', 'cyclopean', 'herculean', 'homeric', 'abysmal', 'amplitudinous', 'astronomic', 'astronomical', 'awesome', 'boundless', 'bulky'],
    'gargle': ['baptize', 'bath', 'bathe', 'bib', 'dentifrice', 'douche', 'draft', 'drain the cup', 'dram', 'drench', 'drink', 'drink bottoms-up'],
    'gargoyle': ['baboon', 'bag', 'beak', 'blemish', 'blot', 'dog', 'downspout', 'eyesore', 'fright', 'hag', 'harridan', 'mess'],
    'garish': ['gongoresque', 'johnsonian', 'affected', 'bedazzling', 'bedizened', 'big-sounding', 'blatant', 'blinding', 'brazen', 'brazenfaced', 'bright', 'bright and shining'],
    'garland': ['festschrift', 'old mug', 'achievement', 'album', 'alerion', 'ana', 'analects', 'animal charge', 'annular muscle', 'annulet', 'annulus', 'anthology'],
    'garment': ['roman collar', 'salvation army bonnet', 'apparel', 'apron', 'arm', 'armhole', 'armlet', 'array', 'attire', 'bands', 'bedizenment', 'bosom'],
    'garments': ['apparel', 'attire', 'clothes', 'clothing', 'costume', 'dress', 'duds', 'garb', 'gear', 'habiliment', 'habit', 'livery'],
    'garner': ['accumulate', 'amass', 'assemble', 'backlog', 'cache', 'collect', 'crib', 'cull', 'cumulate', 'elevator', 'extract', 'garner up'],
    'garnish': ['adjunct', 'adorn', 'adornment', 'annex', 'arrangement', 'array', 'attach', 'beautify', 'bedeck', 'bedizen', 'blazon', 'collectivize'],
    'garnished': ['adorned', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'decked out', 'decorated', 'embellished', 'feathered'],
    'garnishment': ['adjunct', 'adornment', 'angary', 'annexation', 'annexure', 'arrangement', 'attachment', 'certiorari', 'citation', 'collectivization', 'color', 'color patterns'],
    'garrison': ['kp', 'acropolis', 'advance guard', 'arm', 'armed guard', 'armor', 'armor-plate', 'army', 'army group', 'bank', 'bank guard', 'barricade'],
    'garrison state': ['absolute monarchy', 'activation', 'aristocracy', 'arms race', 'autarchy', 'autocracy', 'autonomy', 'coalition government', 'colonialism', 'commonwealth', 'constitutional government', 'constitutional monarchy'],
    'garrote': ['asphyxia', 'asphyxiate', 'asphyxiation', 'behead', 'beheading', 'bowstring', 'burke', 'burking', 'burn', 'burning', 'capital punishment', 'choke'],
    'garrulous': ['all jaw', 'blabbing', 'candid', 'chatty', 'communicative', 'conversational', 'effusive', 'expansive', 'flip', 'fluent', 'frank', 'gabby'],
    'gas': ['acetylene', 'advance against', 'advance upon', 'aerodynamics', 'air', 'alcohol', 'ammonia', 'argon', 'asphyxiating gas', 'atmosphere', 'avgas', 'babble'],
    'gas chamber': ['belsen', 'abattoir', 'aceldama', 'ax', 'beheading', 'block', 'burning', 'butchery', 'capital punishment', 'concentration camp', 'cross', 'crucifixion'],
    'gasbag': ['captain bobadil', 'gascon', 'graf zeppelin', 'texan', 'aerostat', 'agreeable rattle', 'airship', 'babbler', 'ballonet', 'balloon', 'big mouth', 'big talker'],
    'gasconade': ['blow', 'bluff', 'bluster', 'bluster and bluff', 'boast', 'bounce', 'brag', 'bully', 'cock-a-doodle-doo', 'crow', 'draw the longbow', 'flourish'],
    'gaseous': ['adulterated', 'aerial', 'aerodynamic', 'aerostatic', 'aery', 'air-built', 'airy', 'attenuate', 'attenuated', 'chimerical', 'cloud-built', 'cut'],
    'gash': ['vandyke', 'abrade', 'abrasion', 'abysm', 'abyss', 'amputate', 'arroyo', 'ax', 'bark', 'bezel', 'birthmark', 'bisect'],
    'gasify': ['aerate', 'aerify', 'atomize', 'carbonate', 'chlorinate', 'distill', 'emit', 'etherify', 'etherize', 'evaporate', 'exhale', 'fluidize'],
    'gasket': ['air hole', 'armhole', 'blowhole', 'bullet-hole', 'bunghole', 'cringle', 'deadeye', 'eye', 'eyelet', 'gland', 'grommet', 'guide'],
    'gaslike': ['aerial', 'aerodynamic', 'aerostatic', 'aery', 'airy', 'ethereal', 'fuming', 'fumy', 'gaseous', 'gasified', 'gasiform', 'gassy'],
    'gaslit': ['ablaze', 'aglow', 'alight', 'bathed with light', 'bespangled', 'brightened', 'candlelit', 'enlightened', 'firelit', 'illuminated', 'in a blaze', 'irradiate'],
    'gasoline': ['alcohol', 'avgas', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coal oil', 'coke', 'combustible'],
    'gasp': ['aqua-lung', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'bake', 'bark', 'bawl', 'be in heat', 'bellow', 'blare', 'blat', 'blaze'],
    'gasser': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'best seller', 'big hit', 'bomb', 'brilliant success', 'broadcast drama', 'burlesque show'],
    'gassy': ['aerial', 'aerodynamic', 'aerostatic', 'aery', 'airy', 'all jaw', 'big', 'bloated', 'blown up', 'bombastic', 'candid', 'chatty'],
    'gastric': ['abdominal', 'anal', 'appendical', 'big-bellied', 'cardiac', 'cecal', 'celiac', 'colic', 'colonic', 'coronary', 'duodenal', 'enteric'],
    'gastric juice': ['absorption', 'assimilation', 'autacoid', 'bile', 'chalone', 'digestion', 'digestive secretion', 'digestive system', 'endocrine', 'gall', 'gastrointestinal tract', 'hormone'],
    'gastritis': ['abdominal hernia', 'adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever'],
    'gastronome': ['brillat-savarin', 'lucullus', 'aesthete', 'board-and-roomer', 'boarder', 'bon vivant', 'cannibal', 'carnivore', 'connoisseur', 'connoisseur of food', 'consumer', 'dilettante'],
    'gat': ['aperture', 'automatic', 'blowgun', 'blowpipe', 'broaching', 'cavity', 'chasm', 'check', 'clearing', 'cleft', 'crack', 'disclosure'],
    'gate': ['french door', 'aboideau', 'access', 'admissions', 'air lock', 'arch dam', 'archway', 'assemblage', 'attendance', 'audience', 'avails', 'back door'],
    'gate crasher': ['arriviste', 'buttinsky', 'caller', 'company', 'crasher', 'emigrant', 'encroacher', 'freeloader', 'frequenter', 'greenhorn', 'guest', 'habitue'],
    'gateau': ['boston cream pie', 'angel cake', 'angel food cake', 'baked alaska', 'cake', 'cheesecake', 'chocolate cake', 'coffee cake', 'cupcake', 'fruitcake', 'genoise', 'gingerbread'],
    'gatehouse': ['nissen hut', 'quonset hut', 'booth', 'crib', 'hut', 'hutch', 'kiosk', 'lean-to', 'outbuilding', 'outhouse', 'pavilion', 'sentry box'],
    'gatepost': ['french door', 'samson post', 'archway', 'back door', 'baluster', 'balustrade', 'banister', 'barway', 'bulkhead', 'carriage entrance', 'cellar door', 'cellarway'],
    'gateway': ['french door', 'archway', 'back door', 'barway', 'bulkhead', 'carriage entrance', 'cellar door', 'cellarway', 'door', 'doorjamb', 'doorpost', 'doorway'],
    'gather': ['accouple', 'accumulate', 'affiliate', 'agglomerate', 'agglutinate', 'aggregate', 'aggroup', 'ally', 'amass', 'approach', 'articulate', 'assemble'],
    'gather around': ['assemble', 'bunch', 'bunch up', 'clot', 'cluster', 'collect', 'come together', 'congregate', 'converge', 'copulate', 'couple', 'crowd'],
    'gathered': ['accumulated', 'agglomerate', 'aggregate', 'allied', 'amassed', 'assembled', 'associated', 'backlogged', 'banded together', 'bound', 'bracketed', 'built'],
    'gathering': ['smyth sewing', 'abscess', 'accumulation', 'acervation', 'affair', 'agglomerate', 'agglomeration', 'agglutination', 'aggregate', 'aggregation', 'amassment', 'aposteme'],
    'gathering clouds': ['angry clouds', 'black cat', 'black clouds', 'blackening', 'blocking the light', 'breakers ahead', 'broken mirror', 'cardhouse', 'cause for alarm', 'clouding', 'crisis', 'danger'],
    'gauche': ['all thumbs', 'awkward', 'blankminded', 'blunderheaded', 'blundering', 'boorish', 'bumbling', 'bungling', 'butterfingered', 'callow', 'careless', 'clownish'],
    'gaucherie': ['bad job', 'bevue', 'blunder', 'bobble', 'boggle', 'bonehead play', 'boner', 'boo-boo', 'botch', 'bungle', 'clumsy performance', 'error'],
    'gaucho': ['broncobuster', 'buckaroo', 'caballero', 'cattleman', 'cavalier', 'cavalryman', 'chevalier', 'circus rider', 'cowboy', 'cowgirl', 'cowhand', 'cowherd'],
    'gaudiness': ['barnumism', 'affectation', 'apparent character', 'appearances', 'arsenic green', 'bedizenment', 'beggarliness', 'big talk', 'blatancy', 'brazenness', 'cheapness', 'clashing colors'],
    'gaudy': ['gongoresque', 'johnsonian', 'affected', 'bedizened', 'beggarly', 'beneath contempt', 'big-sounding', 'blatant', 'blinding', 'brazen', 'brazenfaced', 'brummagem'],
    'gauge': ['johansson block', 't square', 'adjust', 'amount', 'amplitude', 'appraise', 'appreciate', 'area', 'assay', 'assess', 'barometer', 'basis'],
    'gauging': ['analyzing', 'appraisal', 'appraisement', 'appraising', 'appreciation', 'approximation', 'assessing', 'assessment', 'assize', 'assizement', 'calculation', 'categorization'],
    'gaunt': ['acarpous', 'angular', 'arid', 'bare', 'barren', 'bleak', 'bony', 'cadaverous', 'celibate', 'childless', 'desert', 'deserted'],
    'gauntlet': ['battle cry', 'bid to combat', 'brass knuckles', 'cesta', 'cestus', 'challenge', 'confinement', 'dare', 'defi', 'defy', 'dismemberment', 'double dare'],
    'gauze': ['ace bandage', 'band-aid', 'london fog', 'london special', 'adhesive tape', 'application', 'band', 'bandage', 'bandaging', 'binder', 'brace', 'cast'],
    'gauzy': ['airy', 'attenuate', 'attenuated', 'boyish', 'clear', 'clear as crystal', 'crystal', 'crystal-clear', 'crystalline', 'dainty', 'delicate', 'diaphane'],
    'gawk': ['ass', 'be amazed', 'be astonished', 'be curious', 'blockhead', 'blunderer', 'blunderhead', 'boor', 'bore', 'botcher', 'bumbler', 'bumpkin'],
    'gawky': ['all thumbs', 'awkward', 'blunderheaded', 'blundering', 'bony', 'boorish', 'bumbling', 'bungling', 'butterfingered', 'careless', 'clownish', 'clumsy'],
    'gay': ['ac-dc', 'abandoned', 'addled', 'alert', 'amphierotic', 'animate', 'animated', 'antic', 'autoerotic', 'beaming', 'beatific', 'beatified'],
    'gay deceiver': ['artful dodger', 'casanova', 'don juan', 'lothario', 'machiavel', 'machiavelli', 'machiavellian', 'actor', 'bamboozler', 'befuddler', 'beguiler', 'charmer'],
    'gay dog': ['casanova', 'don juan', 'lothario', 'debauchee', 'gallant', 'gay deceiver', 'lady-killer', 'libertine', 'lover-boy', 'philanderer', 'profligate', 'rake'],
    'gaze': ['admire', 'be amazed', 'be astonished', 'be vigilant', 'be watchful', 'bedroom eyes', 'bore', 'come-hither look', 'contemplate', 'crane', 'crane the neck', 'evil eye'],
    'gazebo': ['texas tower', 'alcove', 'arbor', 'beacon', 'belvedere', 'bleachers', 'bower', 'bridge', 'conning tower', 'conservatory', 'gallery', 'garden'],
    'gazelle': ['cape elk', 'virginia deer', 'antelope', 'arrow', 'blue darter', 'blue streak', 'broad jumper', 'buck', 'bucking bronco', 'buckjumper', 'camel', 'camelopard'],
    'gazette': ['congressional record', 'hansard', 'red book', 'annual', 'bimonthly', 'biweekly', 'blue book', 'daily', 'daily newspaper', 'daybook', 'diary', 'ephemeris'],
    'gazetteer': ['atlas', 'biographical dictionary', 'calendar', 'casebook', 'catalog', 'catalogue raisonne', 'chemical dictionary', 'city directory', 'city editor', 'classified catalog', 'columnist', 'concordance'],
    'gazpacho': ['bisque', 'borscht', 'bouillabaisse', 'bouillon', 'broth', 'burgoo', 'chicken soup', 'chowder', 'clam chowder', 'clear soup', 'consomme', 'egg drop soup'],
    'ge': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'gear': ['hydromatic', 'accessories', 'accommodate', 'accouter', 'accouterments', 'action', 'adapt', 'adjust', 'apparatus', 'apparel', 'appendages', 'appliances'],
    'gear to': ['accommodate', 'accommodate with', 'accord', 'adapt', 'adapt to', 'adjust', 'adjust to', 'agree with', 'assimilate', 'assimilate to', 'attune', 'be guided by'],
    'geared': ['a propos', 'ad rem', 'adapted', 'applicable', 'apposite', 'appropriate', 'apropos', 'apt', 'becoming', 'befitting', 'dovetailing', 'felicitous'],
    'gee': ['accord', 'bloke', 'boy', 'buck', 'chap', 'conform', 'correspond', 'dovetail', 'fellow', 'gent', 'gentleman', 'go'],
    'geezer': ['father time', 'methuselah', 'nestor', 'old paar', 'centenarian', 'dotard', 'elder', 'gaffer', 'golden-ager', 'gramps', 'grandfather', 'grandsire'],
    'geiger counter': ['wilson chamber', 'alpha pulse analyzer', 'atom counter', 'boron counter', 'cloud chamber', 'cosmic ray counter', 'counting tube', 'electronic counter', 'electrophotometer', 'expansion chamber', 'gamma ray counter', 'heavy particle counter'],
    'geisha': ['artist', 'artiste', 'ballerina', 'ballet dancer', 'ballet girl', 'ballroom dancer', 'belly dancer', 'burlesque queen', 'choral dancer', 'chorine', 'chorus boy', 'chorus girl'],
    'gel': ['albumen', 'batter', 'bonnyclabber', 'butter', 'cake', 'clabber', 'clot', 'clump', 'cluster', 'coagulate', 'concrete', 'congeal'],
    'gelatin': ['jell-o', 'albumen', 'arc', 'arc light', 'batter', 'blancmange', 'bonnyclabber', 'butter', 'candy', 'clabber', 'color filter', 'comfit'],
    'gelatinous': ['adhesive', 'amylaceous', 'clabbered', 'clammy', 'clotted', 'coagulated', 'curdled', 'doughy', 'gaumy', 'glairy', 'gluelike', 'gluey'],
    'geld': ['alter', 'castrate', 'change', 'demasculinize', 'desexualize', 'effeminate', 'effeminatize', 'effeminize', 'emasculate', 'eunuchize', 'fix', 'mutilate'],
    'gelded': ['acarpous', 'arid', 'barren', 'castrated', 'celibate', 'childless', 'debilitated', 'demasculinized', 'desert', 'desolate', 'devitalized', 'drained'],
    'gelding': ['houyhnhnm', 'altering', 'blank cartridge', 'brood mare', 'castration', 'castrato', 'charger', 'colt', 'courser', 'critter', 'dobbin', 'dud'],
    'gelid': ['siberian', 'algid', 'arctic', 'below zero', 'biting', 'bitter', 'bitterly cold', 'blast-frozen', 'bleak', 'boreal', 'brisk', 'brumal'],
    'gelt': ['blunt', 'boodle', 'brass', 'bread', 'bucks', 'cabbage', 'chips', 'dinero', 'dough', 'filthy lucre', 'gilt', 'grease'],
    'gem': ['danish', 'danish pastry', 'english muffin', 'parker house roll', 'yorkshire pudding', 'acceptable person', 'anklet', 'armlet', 'bagel', 'bangle', 'bead', 'beads'],
    'geminate': ['janus-like', 'ambidextrous', 'bifacial', 'bifold', 'biform', 'bilateral', 'binary', 'binate', 'biparous', 'bivalent', 'conduplicate', 'copy'],
    'gemini': ['atda', 'ats', 'alouette', 'anna', 'apollo', 'ariel', 'atlas-score', 'biosatellite', 'castor and pollux', 'comsat', 'cosmos', 'courier'],
    'gendarme': ['dogberry', 'g-man', 'john law', 'mp', 'bailiff', 'beadle', 'beagle', 'bluecoat', 'bobby', 'bound bailiff', 'bull', 'captain'],
    'gene': ['altmann theory', 'dna', 'dna double helix', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory'],
    'general': ['adc', 'babbittish', 'co', 'od', 'philistine', 'abstract', 'accepted', 'accustomed', 'across the board', 'aide', 'aide-de-camp', 'aleatoric'],
    'general public': ['everyman', 'john doe', 'public', 'body politic', 'citizenry', 'common man', 'commonwealth', 'community', 'community at large', 'constituency', 'cultural community', 'demos'],
    'general store': ['boutique', 'chain store', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dime store', 'discount house', 'discount store', 'emporium'],
    'generality': ['everyman', 'public', 'abstract', 'abstraction', 'abstractions', 'amorphousness', 'average', 'average man', 'averageness', 'balance', 'best part', 'better part'],
    'generalization': ['baconian method', 'a fortiori reasoning', 'a posteriori reasoning', 'a priori reasoning', 'abstraction', 'analysis', 'bromide', 'catholicity', 'cliche', 'commonplace', 'cosmopolitanism', 'deduction'],
    'generalize': ['analyze', 'apply reason', 'broaden', 'deal in generalities', 'deduce', 'ecumenicize', 'expand', 'extend', 'globalize', 'hypothesize', 'infer', 'intellectualize'],
    'generally': ['about', 'all in all', 'all things considered', 'altogether', 'approximately', 'approximatively', 'as a rule', 'as a whole', 'as an approximation', 'as per usual', 'as things go', 'as usual'],
    'generalship': ['arms', 'art of war', 'captainship', 'chairmanship', 'chivalry', 'convenership', 'custody', 'dictatorship', 'directorate', 'directorship', 'foremanship', 'governorship'],
    'generate': ['accomplish', 'achieve', 'amplify', 'author', 'bear', 'beget', 'breed', 'breed true', 'bring about', 'bring forth', 'bring into being', 'bring to effect'],
    'generation': ['platonic year', 'abiogenesis', 'aeon', 'age', 'age group', 'annus magnus', 'archigenesis', 'authorship', 'begetting', 'beginning', 'biogenesis', 'birth'],
    'generative': ['abiogenetic', 'aboriginal', 'basal', 'basic', 'biogenetic', 'blastogenetic', 'causative', 'central', 'constructive', 'creative', 'crucial', 'demiurgic'],
    'generator': ['ac motor', 'corliss engine', 'otto engine', 'pcv valve', 'wankel engine', 'accelerator', 'actuator', 'aeromotor', 'agent', 'air engine', 'alternator', 'ammeter'],
    'generic': ['abstract', 'bland', 'broad', 'collective', 'common', 'featureless', 'general', 'generalized', 'indefinite', 'indeterminate', 'nebulous', 'neutral'],
    'generosity': ['bomfog', 'benthamism', 'christian charity', 'christian love', 'abundance', 'affluence', 'agape', 'altruism', 'amiability', 'ample sufficiency', 'ampleness', 'amplitude'],
    'generous': ['abounding', 'abundant', 'accommodating', 'affable', 'affluent', 'agreeable', 'all-sufficing', 'almsgiving', 'altruistic', 'amiable', 'ample', 'aplenty'],
    'generously': ['abundantly', 'acutely', 'affluently', 'amazingly', 'amply', 'aplenty', 'astonishingly', 'awesomely', 'bigheartedly', 'bottomlessly', 'bounteously', 'bountifully'],
    'genesis': ['abiogenesis', 'accouchement', 'adaptation', 'alpha', 'archigenesis', 'babyhood', 'beginning', 'beginnings', 'biogenesis', 'biological evolution', 'birth', 'birth throes'],
    'genetic': ['abiogenetic', 'aboriginal', 'advancing', 'atavistic', 'basal', 'basic', 'biogenetic', 'blastogenetic', 'bodily', 'born', 'bradytelic', 'central'],
    'genetic disease': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'cardiovascular disease'],
    'genetics': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory', 'aerobiology'],
    'genial': ['abiogenetic', 'aestival', 'affable', 'agreeable', 'amiable', 'amicable', 'ardent', 'beaming', 'biogenetic', 'blastogenetic', 'blissful', 'blithe'],
    'geniality': ['affability', 'agreeability', 'agreeableness', 'amenity', 'amiability', 'amicability', 'ardency', 'bliss', 'blissfulness', 'blitheness', 'blithesomeness', 'bonhomie'],
    'genie': ['baba yaga', 'lilith', 'afreet', 'barghest', 'cacodemon', 'daeva', 'demon', 'devil', 'dybbuk', 'evil genius', 'evil spirit', 'fiend'],
    'genital': ['abiogenetic', 'biogenetic', 'blastogenetic', 'cervical', 'clitoral', 'epigenetic', 'eumerogenetic', 'gametic', 'generative', 'genetic', 'genial', 'genitive'],
    'genitals': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'genitor': ['abba', 'dad', 'daddy', 'father', 'foster father', 'governor', 'pa', 'pap', 'papa', 'pappy', 'pater', 'paterfamilias'],
    'genius': ['a per se', 'baba yaga', 'calliope', 'clio', 'erato', 'euterpe', 'geist', 'lilith', 'melpomene', 'muse', 'polyhymnia', 'terpsichore'],
    'genocide': ['aborticide', 'atrocity', 'bloodbath', 'breach', 'carnage', 'crime', 'crime against humanity', 'deadly sin', 'decimation', 'delinquency', 'dereliction', 'enormity'],
    'genotype': ['dna', 'dna double helix', 'rna', 'allele', 'antetype', 'anticodon', 'antitype', 'archetype', 'biotype', 'branch', 'class', 'classic example'],
    'genre': ['platonic form', 'platonic idea', 'aesthetic form', 'archetype', 'art form', 'blood', 'brand', 'breed', 'build', 'cast', 'category', 'character'],
    'gens': ['animal kingdom', 'ashram', 'blood', 'body', 'breed', 'brood', 'caste', 'clan', 'class', 'colony', 'commonwealth', 'commune'],
    'genteel': ['victorian', 'affected', 'appropriate', 'aristocratic', 'artificial', 'becoming', 'blue-blooded', 'braw', 'cavalier', 'chic', 'chivalrous', 'civil'],
    'gentile': ['atheist', 'atheistic', 'clannish', 'disbeliever', 'ethnic', 'family', 'genetic', 'gentilic', 'giaour', 'goy', 'goyish', 'heathen'],
    'gentility': ['ancestry', 'appropriateness', 'aristocracy', 'aristocraticalness', 'becomingness', 'birth', 'blood', 'blue blood', 'breeding', 'civility', 'cultivation', 'culture'],
    'gentle': ['accepting', 'acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'affable', 'agreeable', 'ambling', 'amiable', 'appease'],
    'gentleman': ['brahman', 'brahmin', 'acceptable person', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'bloke', 'blue blood', 'boy', 'buck'],
    'gentlemanly': ['andric', 'aristocratic', 'bull', 'chivalrous', 'cultivated', 'cultured', 'ducal', 'exalted', 'genteel', 'gentle', 'gentlemanlike', 'high'],
    'gentleness': ['abnegation', 'abstinence', 'acceptance', 'affability', 'airiness', 'amiability', 'ascent', 'bleeding heart', 'bonhomie', 'bowels of compassion', 'breeding', 'bubbliness'],
    'gentlewoman': ['eve', 'frau', 'abigail', 'amah', 'archduchess', 'au pair girl', 'ayah', 'baroness', 'betweenmaid', 'biddy', 'chambermaid', 'chaperon'],
    'gently': ['a la sourdine', 'cautiously', 'circumspectly', 'compliantly', 'crawlingly', 'creepingly', 'deliberately', 'delicately', 'dilatorily', 'dimly', 'easily', 'faintly'],
    'gentry': ['everyman', 'john doe', 'public', 'absolute', 'aristocracy', 'better sort', 'body politic', 'bona fide', 'citizenry', 'common man', 'commonwealth', 'community'],
    'genuflect': ['bend', 'bend the knee', 'bend the neck', 'bend to', 'bob', 'bob a curtsy', 'bob down', 'bow', 'bow and scrape', 'bow down', 'bow the head', 'bow to'],
    'genuflection': ['bend', 'bending the knee', 'bob', 'bow', 'bowing and scraping', 'crouch', 'curtsy', 'dipping the colors', 'duck', 'homage', 'inclination', 'kneeling'],
    'genuine': ['aboveboard', 'absolute', 'actual', 'arcadian', 'artless', 'authentic', 'bluff', 'blunt', 'bona fide', 'broad', 'brusque', 'bucolic'],
    'genuinely': ['absolutely', 'actually', 'all joking aside', 'artlessly', 'authentically', 'bluffly', 'bluntly', 'broadly', 'brusquely', 'candidly', 'de facto', 'directly'],
    'genus': ['antonomasia', 'binomial nomenclature', 'biosystematics', 'biosystematy', 'biotype', 'blood', 'branch', 'brand', 'breed', 'cast', 'character', 'clan'],
    'geodetic': ['approximative', 'cartographic', 'chorographic', 'estimative', 'geodesic', 'geographic', 'geological', 'geophysical', 'hypsographic', 'locational', 'measuring', 'mensural'],
    'geodetics': ['altimetry', 'bathymetry', 'biometrics', 'biometry', 'cadastration', 'cartography', 'chorography', 'cosmical geology', 'craniometry', 'dynamic geology', 'geodesy', 'geodynamics'],
    'geographic': ['areal', 'cartographic', 'chorographic', 'geodesic', 'geodetic', 'geographical', 'geological', 'geophysical', 'locational', 'navigational', 'physiographic', 'positional'],
    'geographical': ['areal', 'cartographic', 'chorographic', 'geodesic', 'geodetic', 'geographic', 'geological', 'geophysical', 'locational', 'navigational', 'physiographic', 'positional'],
    'geography': ['earth', 'gaea', 'ge', 'tellus', 'terra', 'biosphere', 'cartography', 'chorography', 'cosmical geology', 'dynamic geology', 'geodesy', 'geodetic satellite'],
    'geology': ['cosmical geology', 'crystallography', 'dynamic geology', 'geodesy', 'geodetics', 'geodynamics', 'geognosy', 'geographics', 'geography', 'geological chemistry', 'geological engineering', 'geomorphogeny'],
    'geophysics': ['newtonian physics', 'acoustics', 'aerophysics', 'applied physics', 'astrophysics', 'basic conductor physics', 'biophysics', 'chemical physics', 'cosmical geology', 'cryogenics', 'crystallography', 'cytophysics'],
    'geoponics': ['agrarianism', 'agricultural geology', 'agriculture', 'agrology', 'agronomics', 'agronomy', 'contour farming', 'cultivation', 'culture', 'dirt farming', 'dry farming', 'dryland farming'],
    'germ': ['anlage', 'euglena', 'adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'animalcule', 'bacillus', 'bacteria', 'bacterium'],
    'germ cell': ['act of love', 'adultery', 'animal cell', 'aphrodisia', 'ass', 'balling', 'bioplast', 'carnal knowledge', 'cell', 'cellular tissue', 'cellule', 'chromatoplasm'],
    'german measles': ['african lethargy', 'asiatic cholera', 'chagres fever', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery', 'bastard measles'],
    'germane': ['a propos', 'ad rem', 'admissible', 'affiliated', 'agnate', 'akin', 'allied', 'appertaining', 'applicable', 'applying', 'apposite', 'appropriate'],
    'germicide': ['aborticide', 'acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bactericide', 'bug bomb', 'carbamate insecticide', 'chemosterilant', 'contact poison', 'defoliant', 'disinfectant'],
    'germinal': ['aboriginal', 'atomic', 'basal', 'basic', 'central', 'conceptive', 'conceptual', 'corpuscular', 'creative', 'crucial', 'elemental', 'elementary'],
    'germinate': ['blossom', 'brew', 'bud', 'burgeon', 'burst forth', 'develop', 'flourish', 'gather', 'gemmate', 'grow', 'grow rank', 'grow up'],
    'germinate from': ['accrue from', 'arise from', 'be contingent on', 'be due to', 'bud from', 'come from', 'come out of', 'depend on', 'derive from', 'descend from', 'emanate from', 'emerge from'],
    'geronimo': ['bugle call', 'call to arms', 'call-up', 'catchword', 'clarion', 'clarion call', 'conscription', 'exhortation', 'go for broke', 'gung ho', 'levy', 'mobilization'],
    'gerontic': ['anile', 'crabbed', 'debilitated', 'decrepit', 'doddered', 'doddering', 'doddery', 'feeble', 'fossilized', 'gerontal', 'infirm', 'mossbacked'],
    'gerrymander': ['angle', 'borough', 'caucus', 'close borough', 'congressional district', 'contrive', 'election district', 'engineer', 'finagle', 'gerrymandered district', 'intrigue', 'jockey'],
    'gerrymandering': ['ballot-box stuffing', 'bunco', 'cardsharping', 'cheat', 'cheating', 'cozenage', 'diddle', 'diddling', 'dishonesty', 'dodge', 'fishy transaction', 'flam'],
    'gest': ['marchen', 'western', 'western story', 'westerner', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adventure', 'adventure story'],
    'gestalt': ['alentours', 'ambience', 'ambit', 'angle', 'aspect', 'borderlands', 'circle', 'circuit', 'circumambiencies', 'circumjacencies', 'circumstances', 'compass'],
    'gestapo': ['cheka', 'fbi', 'interpol', 'mp', 'mvd', 'mounties', 'nkvd', 'ogpu', 'rcmp', 'sp', 'scotland yard', 'constabulary'],
    'gestate': ['author', 'be gravid', 'be knocked up', 'be pregnant', 'be with child', 'bear', 'beget', 'breed', 'bring about', 'bring forth', 'bring to effect', 'bring to pass'],
    'gesticulation': ['bearing', 'beck', 'beckon', 'body language', 'carriage', 'charade', 'chironomy', 'dactylology', 'deaf-and-dumb alphabet', 'dumb show', 'gesture', 'gesture language'],
    'gesture': ['action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'bearing', 'beck', 'beckon', 'behavior', 'behavior pattern'],
    'get': ['od', 'absorb', 'accede to', 'accept', 'access', 'accumulate', 'acquire', 'addle', 'admit', 'advance', 'affect', 'age'],
    'get across': ['assail the ear', 'be glimpsed', 'be heard', 'broadcast', 'caress the ear', 'clarify', 'come through', 'communicate', 'contact', 'convey', 'dawn on', 'disseminate'],
    'get ahead': ['accrue', 'accumulate', 'achieve success', 'advance', 'ameliorate', 'amend', 'appreciate', 'arrive', 'balloon', 'be a success', 'bloat', 'boom'],
    'get along': ['accord', 'advance', 'age', 'agree', 'agree with', 'ameliorate', 'amend', 'be getting along', 'be so', 'be such', 'buzz off', 'cheat the undertaker'],
    'get around': ['bamboozle', 'become public', 'beg', 'beguile', 'betray', 'blarney', 'bluff', 'break', 'butter', 'butter up', 'buzz about', 'cajole'],
    'get at': ['annex', 'approach', 'arrive at', 'arrive upon', 'ascertain', 'assure', 'bribe', 'buy', 'buy off', 'certify', 'cinch', 'clear up'],
    'get away': ['bail out', 'be getting along', 'beg', 'blow', 'break away', 'break jail', 'break loose', 'buzz off', 'circumvent', 'come away', 'cut loose', 'depart'],
    'get away with': ['accomplish', 'achieve', 'bring off', 'bring through', 'carry off', 'compass', 'consume', 'cop a plea', 'cop out', 'crown with success', 'devour', 'dispatch'],
    'get back': ['ransom', 'recapture', 'reclaim', 'recoup', 'recover', 'recruit', 'recuperate', 'redeem', 'regain', 'renovate', 'reoccupy', 'replevin'],
    'get back at': ['alternate', 'bandy', 'be quits with', 'change', 'come back at', 'commute', 'compensate', 'cooperate', 'counter', 'counterchange', 'exchange', 'get even with'],
    'get by': ['accomplish', 'achieve', 'answer', 'avail', 'be equal to', 'be missed', 'be so', 'be such', 'bear', 'bring off', 'bring through', 'carry off'],
    'get cracking': ['attack', 'dive into', 'enter on', 'enter upon', 'fall to', 'get busy', 'get going', 'get with it', 'go to it', 'hop to it', 'hotfoot', 'hump'],
    'get even with': ['account with', 'alternate', 'avenge', 'bandy', 'be quits', 'be quits with', 'change', 'clear the board', 'commute', 'compensate', 'cooperate', 'counterchange'],
    'get going': ['attack', 'be off', 'beat it', 'begone', 'break in', 'bundle', 'bustle', 'chase', 'clear out', 'crowd', 'dash', 'dash off'],
    'get hold of': ['abduct', 'absorb', 'annex', 'appreciate', 'apprehend', 'ascertain', 'assimilate', 'be informed', 'be with one', 'become acquainted with', 'broaden the mind', 'carry off'],
    'get in': ['accomplish', 'accumulate', 'achieve', 'admit', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'approach', 'arrive', 'arrive at', 'arrive in'],
    'get it over': ['ko', 'button up', 'call off', 'cancel', 'cap', 'carry to completion', 'clean up', 'climax', 'close out', 'close up', 'complete', 'conclude'],
    'get off': ['achieve satisfaction', 'advance', 'alight', 'be getting along', 'be off', 'blow', 'break in', 'bring out', 'buzz off', 'climax', 'climb down', 'come'],
    'get on': ['achieve success', 'advance', 'age', 'arrive', 'assume', 'back', 'be a success', 'be getting along', 'be so', 'be such', 'bestraddle', 'bestride'],
    'get out': ['appear', 'avulse', 'bail out', 'be off', 'be revealed', 'beat it', 'become known', 'begone', 'bow out', 'break away', 'break forth', 'break jail'],
    'get out of': ['arouse', 'bail out', 'beg', 'break away', 'break jail', 'break loose', 'bring forth', 'bring out', 'bring to light', 'call forth', 'call out', 'call up'],
    'get over': ['advance', 'ascend', 'back', 'back up', 'be glimpsed', 'bounce back', 'broadcast', 'budge', 'change', 'change place', 'circle', 'clarify'],
    'get rid of': ['abandon', 'abjure', 'abstract', 'assassinate', 'cast', 'cast aside', 'cast away', 'cast off', 'cast out', 'cede', 'chuck', 'clear'],
    'get the picture': ['absorb', 'appreciate', 'apprehend', 'assimilate', 'be with one', 'catch', 'catch on', 'comprehend', 'conceive', 'dig', 'digest', 'fathom'],
    'get through': ['ko', 'assail the ear', 'be heard', 'bring about', 'bring off', 'bring to effect', 'bring to pass', 'button up', 'call off', 'cancel', 'cap', 'caress the ear'],
    'get to': ['accomplish', 'achieve', 'answer', 'approach', 'arrive', 'arrive at', 'arrive in', 'assail the ear', 'attain', 'attain to', 'be heard', 'be received'],
    'get to be': ['arise', 'be born', 'be changed', 'be converted into', 'become', 'break out', 'burst forth', 'come forth', 'come out', 'come to be', 'crop up', 'erupt'],
    'get together': ['accumulate', 'act in concert', 'act together', 'act with', 'affair', 'affiliate', 'agglomerate', 'aggregate', 'aggroup', 'agree', 'agree on', 'agree with'],
    'get up': ['arise', 'assemble', 'awake', 'awaken', 'bedizen', 'bone up', 'brew', 'bristle', 'brush up', 'build', 'cast', 'cock up'],
    'get well': ['bounce back', 'come around', 'come back', 'come round', 'come to', 'come up smiling', 'get about', 'get over', 'make a comeback', 'mend', 'pull round', 'pull through'],
    'get with it': ['act on', 'act upon', 'attack', 'bear a hand', 'dive into', 'do something', 'do something about', 'enter on', 'enter upon', 'fall to', 'get busy', 'get cracking'],
    'get-up-and-go': ['adventuresomeness', 'adventurousness', 'aggression', 'aggressiveness', 'ambitiousness', 'bang', 'dash', 'drive', 'dynamism', 'enterprise', 'enterprisingness', 'fire'],
    'getaway': ['abandonment', 'acceleration', 'break', 'breakout', 'decampment', 'deliverance', 'delivery', 'departure', 'drive', 'egress', 'emergence', 'escape'],
    'getup': ['accouterments', 'adventuresomeness', 'adventurousness', 'aggression', 'aggressiveness', 'ambitiousness', 'anatomy', 'architectonics', 'architecture', 'arrangement', 'assemblage', 'assembly'],
    'gewgaw': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'agate', 'bagatelle', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble'],
    'geyser': ['old faithful', 'boiling water', 'flush', 'font', 'fount', 'fountain', 'gush', 'hot spring', 'hot water', 'jet', 'rush', 'spew'],
    'ghastly': ['achromatic', 'achromic', 'ailing', 'anemic', 'appalling', 'ashen', 'ashy', 'astounding', 'awe-inspiring', 'awesome', 'awful', 'bad'],
    'ghetto': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'barrio', 'black ghetto', 'blighted area', 'business district'],
    'ghetto dwellers': ['chronic poor', 'chronic poverty area', 'depressed class', 'depressed population', 'outcasts', 'poverty subculture', 'slum-dwellers', 'the disadvantaged', 'the dispossessed', 'the distressed', 'the down-and-out', 'the forgotten man'],
    'ghettoize': ['bolt', 'cordon', 'cordon off', 'cull out', 'divide', 'gin', 'insulate', 'isolate', 'keep apart', 'keep aside', 'lay aside', 'pick out'],
    'ghost': ['doppelganger', 'dracula', 'frankenstein', 'masan', 'wolf-man', 'act for', 'advertising writer', 'agent', 'alternate', 'alternative', 'analogy', 'annalist'],
    'ghost story': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'apologue', 'bedtime story', 'blague', 'cock-and-bull story', 'detective story', 'exaggeration'],
    'ghostly': ['airy', 'asomatous', 'astral', 'blue', 'bodiless', 'cadaverous', 'corpselike', 'creepy', 'deadly', 'deathlike', 'deathly', 'deathly pale'],
    'ghostwrite': ['act for', 'author', 'change places with', 'coauthor', 'collaborate', 'compose', 'crowd out', 'cut out', 'dash off', 'displace', 'double for', 'editorialize'],
    'ghoul': ['baba yaga', 'dracula', 'frankenstein', 'lilith', 'wolf-man', 'afreet', 'ape-man', 'barghest', 'body snatcher', 'bogey', 'bogeyman', 'booster'],
    'ghoulish': ['mephistophelian', 'abominable', 'agape', 'agog', 'all agog', 'appalling', 'astounding', 'awe-inspiring', 'awesome', 'awful', 'barbaric', 'bloodthirsty'],
    'gi': ['anzac', 'aussie', 'boche', 'fritz', 'heinie', 'hun', 'jerry', 'johnny', 'kraut', 'tommy', 'tommy atkins', 'yank'],
    'giant': ['amazon', 'antaeus', 'atlantean', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclopean', 'cyclops', 'gargantua', 'gargantuan', 'goliath'],
    'gibber': ['absurdity', 'amphigory', 'babble', 'babblement', 'baffle', 'balderdash', 'bavardage', 'be greek to', 'be beyond one', 'be too deep', 'beat one', 'bibble-babble'],
    'gibbering': ['blabbering', 'blabbing', 'blathering', 'chattering', 'drone', 'droning', 'gabble', 'gabbling', 'gibber', 'jabber', 'jabbering', 'jibber'],
    'gibberish': ['aesopian language', 'babel', 'gongorism', 'greek', 'abracadabra', 'absurdity', 'amphigory', 'argot', 'babble', 'babblement', 'balderdash', 'balls'],
    'gibbous': ['arched', 'arciform', 'arclike', 'arcual', 'bandy', 'bowed', 'bowlike', 'bunchbacked', 'camelback', 'concave', 'convex', 'convexed'],
    'gibe': ['parthian shot', 'affront', 'aphorism', 'apothegm', 'aspersion', 'atrocity', 'back answer', 'barrack', 'be merry with', 'bon mot', 'boutade', 'brickbat'],
    'giblets': ['abatis', 'abdomen', 'anus', 'appendix', 'blind gut', 'bowels', 'brain', 'brains', 'breast', 'cecum', 'chicken foot', 'chitterlings'],
    'giddy': ['addled', 'adrift', 'afloat', 'alternating', 'amorphous', 'babbling', 'beery', 'bemused', 'besotted', 'blind drunk', 'brainless', 'capricious'],
    'gift': ['christmas present', 'ability', 'accomplishment', 'accord', 'acquirement', 'acuity', 'acuteness', 'administer', 'adroitness', 'afford', 'allot', 'allow'],
    'gift of gab': ['articulateness', 'big mouth', 'candor', 'command of language', 'command of words', 'communicativeness', 'conversableness', 'effective style', 'effusion', 'effusiveness', 'eloquence', 'eloquent tongue'],
    'gifted': ['able', 'ace', 'adroit', 'apt', 'born for', 'brainy', 'bright', 'brilliant', 'capable', 'clever', 'crack', 'crackerjack'],
    'gig': ['angle', 'appointment', 'bait the hook', 'berth', 'billet', 'bob', 'clam', 'dap', 'dib', 'dibble', 'drive', 'employment'],
    'gigantic': ['antaean', 'atlantean', 'briarean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'a bit much', 'abandoned', 'abysmal', 'amplitudinous'],
    'giggle': ['homeric laughter', 'be in stitches', 'belly laugh', 'boff', 'boffola', 'break up', 'burst into laughter', 'burst of laughter', 'burst out', 'burst out laughing', 'burst with laughter', 'bust a gut'],
    'gigolo': ['casanova', 'don juan', 'lothario', 'romeo', 'amoroso', 'bawd', 'beau', 'boyfriend', 'caballero', 'cavalier', 'cavaliere servente', 'esquire'],
    'gild': ['adorn', 'apply paint', 'aurify', 'bedaub', 'belie', 'besmear', 'brighten', 'brush on paint', 'butter', 'calcimine', 'camouflage', 'coat'],
    'gilded': ['apparent', 'aureate', 'auric', 'beige', 'buff', 'buff-yellow', 'canary', 'canary-yellow', 'citron', 'citron-yellow', 'colorable', 'colored'],
    'gill': ['dulcinea', 'adolescent stream', 'arroyo', 'beck', 'bellows', 'best girl', 'bottom', 'bottom glade', 'bottoms', 'bourn', 'braided stream', 'branch'],
    'gilt': ['acting', 'affectation', 'appearance', 'attitudinizing', 'aureate', 'auric', 'barrow', 'beige', 'bluff', 'bluffing', 'blunt', 'boar'],
    'gilt edged': ['divine', 'exquisite', 'glorious', 'golden', 'heavenly', 'immense', 'magnificent', 'marvelous', 'sensational', 'splendid', 'splendiferous', 'sterling'],
    'gimcrack': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'agate', 'apparatus', 'bagatelle', 'ball', 'baseball bat', 'bat', 'battledore'],
    'gimmick': ['action', 'ad hoc measure', 'affair', 'anagnorisis', 'angle', 'answer', 'apparatus', 'architectonics', 'architecture', 'argument', 'art', 'artful dodge'],
    'gin': ['angostura bitters', 'canadian', 'canadian whiskey', 'cognac', 'dionaea', 'grand champagne', 'irish', 'irish whiskey', 'kirsch', 'scotch', 'scotch whiskey', 'absinthe'],
    'gin mill': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'boozer', 'cabaret', 'cafe', 'cocktail'],
    'ginger': ['aggressiveness', 'bang', 'bite', 'briskness', 'dash', 'drive', 'enterprise', 'fire', 'get-up-and-go', 'guts', 'hotness', 'initiative'],
    'gingerbread': ['boston cream pie', 'angel cake', 'angel food cake', 'baked alaska', 'bedizenment', 'bravery', 'cake', 'cheesecake', 'chiffon', 'chocolate cake', 'clinquant', 'coffee cake'],
    'gingerly': ['calculating', 'cannily', 'canny', 'careful', 'carefully', 'cautious', 'cautiously', 'charily', 'chary', 'circumspect', 'circumspectly', 'considerate'],
    'gingivitis': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis'],
    'giraffe': ['cape elk', 'virginia deer', 'antelope', 'buck', 'camel', 'camelopard', 'caribou', 'deer', 'deerlet', 'doe', 'dromedary', 'eland'],
    'gird': ['band', 'bandage', 'beef up', 'begird', 'belt', 'belt in', 'bend', 'beset', 'bind', 'bind up', 'bolster', 'brace'],
    'girdle': ['mystik tape', 'scotch tape', 'adhesive tape', 'advocate', 'alpenstock', 'anklet', 'arm', 'armlet', 'athletic supporter', 'back', 'backbone', 'backing'],
    'girl': ['dulcinea', 'eve', 'frau', 'fraulein', 'abigail', 'amah', 'au pair girl', 'ayah', 'babe', 'baby', 'best girl', 'betrothed'],
    'girl friend': ['dulcinea', 'ace', 'amigo', 'associate', 'baby', 'bedfellow', 'bedmate', 'beloved', 'best girl', 'bosom buddy', 'buddy', 'bunkie'],
    'girl watcher': ['tv-viewer', 'beholder', 'bird-watcher', 'bystander', 'drugstore cowboy', 'eyewitness', 'gaper', 'gazer', 'gazer-on', 'goggler', 'kibitzer', 'looker'],
    'girlish': ['airy', 'attenuate', 'attenuated', 'beardless', 'boyish', 'boylike', 'calflike', 'childish', 'childlike', 'coltish', 'delicate', 'diaphanous'],
    'girth': ['ambit', 'amplitude', 'anchor', 'anklet', 'area', 'armlet', 'back band', 'backstrap', 'band', 'bandage', 'bar', 'barrette'],
    'gist': ['affective meaning', 'axiom', 'basis', 'bearing', 'bench mark', 'best part', 'better part', 'body', 'bulk', 'burden', 'cardinal point', 'case'],
    'give': ['abalienate', 'abandon', 'abstain from', 'accommodate', 'accord', 'act', 'adaptability', 'administer', 'afford', 'agreeability', 'aid', 'air'],
    'give a hand': ['abet', 'acclaim', 'aid', 'applaud', 'assist', 'avail', 'bail out', 'bear a hand', 'befriend', 'benefit', 'cheer', 'cheer on'],
    'give a lift': ['abet', 'aid', 'animate', 'assist', 'avail', 'bail out', 'bear a hand', 'befriend', 'benefit', 'boost', 'brighten', 'buoy up'],
    'give away': ['abandon', 'abjure', 'arrange a match', 'babble', 'be indiscreet', 'be unguarded', 'bestow', 'betray', 'betray a confidence', 'blab', 'blabber', 'blurt'],
    'give back': ['back out', 'backtrack', 'backwater', 'bring back', 'crumble', 'extradite', 'fail', 'fall back', 'falter', 'place in', 'put back', 'reactivate'],
    'give birth': ['animate', 'be confined', 'bear', 'bear a child', 'bear young', 'breathe life into', 'bring into being', 'bring into existence', 'bring to life', 'call into being', 'call into existence', 'calve'],
    'give birth to': ['author', 'bear', 'beget', 'birth', 'breed', 'bring about', 'bring forth', 'bring to birth', 'bring to effect', 'bring to pass', 'cause', 'conceive'],
    'give ground': ['back down', 'back out', 'beat a retreat', 'break off combat', 'cave in', 'cease resistance', 'disengage', 'draw back', 'draw off', 'fall back', 'give in', 'give place'],
    'give in': ['back down', 'bow to', 'break off combat', 'cave in', 'cease resistance', 'circulate', 'come across with', 'deliver', 'deliver over', 'distribute', 'fork over', 'forward'],
    'give notice': ['acquaint', 'admonish', 'advertise', 'advertise of', 'advise', 'affirm', 'alert', 'announce', 'annunciate', 'apprise', 'brief', 'bring word'],
    'give off': ['aerate', 'aerify', 'atomize', 'bleed', 'blow', 'breathe out', 'carbonate', 'chlorinate', 'discharge', 'distill', 'effuse', 'egest'],
    'give out': ['accord', 'administer', 'afford', 'air', 'allot', 'allow', 'award', 'be consumed', 'be used up', 'bestow', 'bestow on', 'blow'],
    'give over': ['abandon', 'abdicate', 'abjure', 'abort', 'acknowledge defeat', 'beg a truce', 'belay', 'cancel', 'capitulate', 'cease', 'cede', 'circulate'],
    'give thanks': ['acknowledge', 'beseech', 'bless', 'commune with god', 'credit', 'give credit', 'implore', 'invoke', 'make acknowledgments of', 'make supplication', 'offer a prayer', 'offer thanks'],
    'give the gate': ['boot', 'bounce', 'bow out', 'break', 'bump', 'bundle', 'bundle off', 'bust', 'can', 'cashier', 'deconsecrate', 'defrock'],
    'give the word': ['ok', 'accord', 'admit', 'allow', 'bid', 'call on', 'call the signals', 'call upon', 'charge', 'command', 'commission', 'consent'],
    'give up': ['abandon', 'abandon hope', 'abdicate', 'abjure', 'acknowledge defeat', 'back down', 'be at sea', 'be innocent of', 'be lost', 'be pensioned', 'be superannuated', 'break off combat'],
    'give way': ['abandon hope', 'accommodate', 'adjust', 'aye', 'back down', 'beat down', 'become suicidal', 'bend', 'break', 'break off combat', 'break open', 'break up'],
    'give way to': ['bow to', 'cater to', 'coddle', 'cosset', 'cut loose', 'defer to', 'favor', 'go all out', 'go flat out', 'go unrestrained', 'gratify', 'humor'],
    'give-and-take': ['abatement of differences', 'accommodation', 'adjustment', 'agency', 'alternation', 'arrangement', 'badinage', 'balance', 'ballast', 'banter', 'bargain', 'barter'],
    'giveaway': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'babbling', 'ballet', 'best', 'betrayal', 'blabbering', 'blabbing', 'bomb'],
    'given': ['god-given', 'accepted', 'accorded', 'accounted as', 'accustomed', 'acknowledged', 'actuality', 'addicted', 'affirmed', 'alleged', 'allowed', 'apt'],
    'giver': ['maecenas', 'santa claus', 'almoner', 'almsgiver', 'angel', 'assignor', 'awarder', 'backer', 'bestower', 'cheerful giver', 'conferrer', 'consignor'],
    'giving': ['bomfog', 'benthamism', 'christian charity', 'christian love', 'abalienation', 'adaptable', 'administration', 'agape', 'alienation', 'altruism', 'amortization', 'amortizement'],
    'gizmo': ['affair', 'apparatus', 'article', 'artifact', 'concern', 'contraption', 'contrivance', 'device', 'dingus', 'dofunny', 'dohickey', 'dojigger'],
    'gizzard': ['abatis', 'abdomen', 'abomasum', 'anus', 'appendix', 'bay window', 'beerbelly', 'belly', 'blind gut', 'bowels', 'brain', 'brains'],
    'glabrous': ['acomous', 'bald', 'bald-headed', 'beardless', 'clean-shaven', 'depilous', 'downy', 'even', 'flat', 'glabrate', 'glabrescent', 'hairless'],
    'glace': ['buffed', 'burnished', 'finished', 'furbished', 'glassy', 'glazed', 'gleaming', 'glossy', 'lacquered', 'lustrous', 'polished', 'rubbed'],
    'glacial': ['siberian', 'algid', 'aloof', 'arctic', 'below zero', 'biting', 'bitter', 'bitterly cold', 'blast-frozen', 'bleak', 'boreal', 'brisk'],
    'glacier': ['dry ice', 'berg', 'calf', 'cryosphere', 'firn', 'floe', 'frazil', 'frozen water', 'glaciation', 'glacieret', 'glaze', 'glazed frost'],
    'glacis': ['abatis', 'advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'bastion', 'battlement'],
    'glad': ['animating', 'beaming', 'beatific', 'beatified', 'beautiful', 'blessed', 'blissful', 'blithe', 'blithesome', 'bright', 'bright and sunny', 'capering'],
    'gladden': ['animate', 'beatify', 'bless', 'boost', 'brighten', 'buoy up', 'cheer', 'comfort', 'console', 'delectate', 'delight', 'elate'],
    'glade': ['lebensraum', 'air space', 'back country', 'baygall', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'clear space', 'clearance', 'clearing'],
    'gladiator': ['battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'combatant', 'competitor', 'contender'],
    'gladly': ['airily', 'blessedly', 'blissfully', 'blithely', 'cheerfully', 'cheerily', 'delightedly', 'ecstatically', 'elatedly', 'exultantly', 'genially', 'happily'],
    'gladness': ['beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'blitheness', 'blithesomeness', 'brightness', 'cheer', 'cheerfulness', 'cheeriness'],
    'gladsome': ['beaming', 'blithe', 'blithesome', 'bright', 'bright and sunny', 'charmed', 'cheerful', 'cheery', 'comfortable', 'content', 'contented', 'convivial'],
    'glair': ['albumen', 'batter', 'bonnyclabber', 'butter', 'caviar', 'clabber', 'cornstarch', 'cream', 'curd', 'dough', 'egg', 'egg white'],
    'glamorize': ['adorn', 'aggrandize', 'apotheose', 'apotheosize', 'beatify', 'beautify', 'become one', 'canonize', 'crown', 'decorate', 'deify', 'doll up'],
    'glamorous': ['circean', 'alluring', 'appealing', 'appetizing', 'attractive', 'beaming', 'beguiling', 'bewitching', 'blandishing', 'blooming', 'bright', 'brilliant'],
    'glamour': ['agacerie', 'alchemy', 'allure', 'allurement', 'appeal', 'appealingness', 'attraction', 'attractiveness', 'aura', 'beguilement', 'beguiling', 'bewitchery'],
    'glance': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'attouchement', 'avert', 'balefire', 'be bright', 'beacon', 'beacon fire', 'beam', 'bear off'],
    'glance at': ['adumbrate', 'allude to', 'cast a glance', 'dip into', 'drop a hint', 'examine cursorily', 'flip', 'give a hint', 'give the cue', 'give the once-over', 'glance', 'glimpse'],
    'glancing': ['brushing', 'contacting', 'contingent', 'flanking', 'grazing', 'impingent', 'impinging', 'in contact', 'lateral', 'lee', 'leeward', 'meeting'],
    'gland': ['acromegaly', 'adrenal', 'breast', 'choriocarcinoma', 'cretinism', 'diabetes', 'diabetes insipidus', 'diabetes mellitus', 'dwarfism', 'gasket', 'giantism', 'hyperglycemia'],
    'glandular': ['adrenal', 'affectional', 'affective', 'demonstrative', 'eccrine', 'emotiometabolic', 'emotiomotor', 'emotional', 'emotiovascular', 'emotive', 'endocrine', 'exocrine'],
    'glare': ['pr', 'aller sans dire', 'angry look', 'appear', 'ballyhoo', 'bandage', 'be bright', 'be evident', 'be manifest', 'be no secret', 'be noticeable', 'be revealed'],
    'glaring': ['absolute', 'arrant', 'atrocious', 'bedazzling', 'blatant', 'blazing', 'blinding', 'bold', 'brazen', 'brazenfaced', 'bright', 'bright and shining'],
    'glass': ['cm-glass', 'cr-glass', 'achromatic lens', 'adobe', 'aerological instrument', 'agate glass', 'alabaster', 'aneroid barometer', 'aneroidograph', 'astigmatic lens', 'barograph', 'barometer'],
    'glass cutting': ['burr', 'chiseling', 'cross-hatching', 'demitint', 'engravement', 'engraving', 'etch', 'etching', 'gem-engraving', 'glyptic', 'graving', 'half tint'],
    'glasses': ['polaroid glasses', 'bifocals', 'blinkers', 'cheaters', 'colored glasses', 'contact lens', 'dark glasses', 'divided spectacles', 'eyeglass', 'eyeglasses', 'goggles', 'granny glasses'],
    'glasshouse': ['alcove', 'arbor', 'bower', 'cloche', 'cold frame', 'conservatory', 'coolhouse', 'forcing bed', 'forcing house', 'forcing pit', 'gazebo', 'greenhouse'],
    'glassware': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'diaphane', 'dinnerware', 'display case', 'durable goods', 'durables', 'earthenware', 'enamelware'],
    'glassy': ['blank', 'buffed', 'burnished', 'clear as glass', 'cold', 'dazed', 'deadpan', 'dull', 'empty', 'expressionless', 'finished', 'fishy'],
    'glaucoma': ['ablepsia', 'amaurosis', 'benightedness', 'blepharitis', 'blind side', 'blind spot', 'blindfolding', 'blinding', 'blindness', 'blurring the eyes', 'cataract', 'cecity'],
    'glaucous': ['quaker-colored', 'acier', 'aestival', 'alabaster', 'alabastrine', 'albescent', 'ashen', 'ashy', 'beryl-green', 'berylline', 'blue-green', 'bluish-green'],
    'glaze': ['dry ice', 'jell-o', 'apply paint', 'bake', 'bedaub', 'bedizen', 'begild', 'berg', 'besmear', 'blancmange', 'board', 'brick'],
    'glazed': ['buffed', 'burnished', 'finished', 'furbished', 'glace', 'glassy', 'gleaming', 'glossy', 'lacquered', 'polished', 'rubbed', 'satiny'],
    'gleam': ['beam', 'burn', 'coruscation', 'flare', 'flash', 'flicker', 'glance', 'glare', 'glimmer', 'glint', 'glisten', 'glitter'],
    'gleaming': ['aglow', 'beaming', 'beamy', 'blushing', 'bright and sunny', 'buffed', 'burning', 'burnished', 'candescent', 'finished', 'flushing', 'furbished'],
    'glean': ['accumulate', 'amass', 'ascertain', 'assemble', 'bring in', 'bring together', 'choose out', 'collect', 'conclude', 'crop', 'crop herbs', 'cull'],
    'gleaning': ['accumulation', 'amassment', 'ana', 'analects', 'anthology', 'assembling', 'bringing together', 'capital gains', 'cleanup', 'clear profit', 'clippings', 'collectanea'],
    'glee': ['schadenfreude', 'amusement', 'beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'blitheness', 'cantata', 'cheer', 'cheerfulness'],
    'gleeful': ['blithe', 'blithesome', 'boon', 'buxom', 'cheerful', 'delighted', 'ecstatic', 'elated', 'exhilarated', 'exuberant', 'exultant', 'frivolous'],
    'gleet': ['chyle', 'colostrum', 'discharge', 'festering', 'humor', 'ichor', 'lachryma', 'lactation', 'leukorrhea', 'lymph', 'matter', 'mattering'],
    'glen': ['bottom', 'bottom glade', 'bottoms', 'combe', 'dale', 'dell', 'dingle', 'gap', 'gill', 'grove', 'intervale', 'lunar rill'],
    'glib': ['ciceronian', 'demosthenian', 'demosthenic', 'mickey mouse', 'tullian', 'all jaw', 'articulate', 'bland', 'buttery', 'candid', 'casual', 'chatty'],
    'glibness': ['articulateness', 'big mouth', 'blandness', 'butter', 'candor', 'command of language', 'command of words', 'communicativeness', 'conversableness', 'effective style', 'effusion', 'effusiveness'],
    'glide': ['accented', 'acrobatics', 'advance', 'aerobatics', 'aeroplane', 'airlift', 'airplane', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental'],
    'glim': ['candle', 'electric light bulb', 'fire', 'flame', 'illuminant', 'illuminator', 'incandescent body', 'lamp', 'lantern', 'light', 'light bulb', 'light source'],
    'glimmer': ['blink', 'blinking', 'broad hint', 'clue', 'coruscate', 'coruscation', 'cue', 'firefly', 'gentle hint', 'gesture', 'glance', 'gleam'],
    'glimmering': ['a little learning', 'amateurism', 'blink', 'blinking', 'blinky', 'broad hint', 'clue', 'coruscant', 'coruscating', 'coruscation', 'cue', 'dilettantism'],
    'glimpse': ['a little learning', 'amateurism', 'behold', 'blink', 'cast', 'cast a glance', 'catch sight of', 'clap eyes on', 'descry', 'dilettantism', 'dilettantship', 'discern'],
    'glint': ['afterglow', 'air glow', 'be bright', 'beacon', 'beam', 'bedazzle', 'blaze', 'blaze of light', 'blind', 'burn', 'candescence', 'cast a glance'],
    'glissade': ['avalanche', 'coast', 'flit', 'float', 'flow', 'fly', 'glide', 'glissando', 'ice-skate', 'landslide', 'landslip', 'roller-skate'],
    'glissando': ['avalanche', 'cantando', 'coast', 'demilegato', 'execution', 'expression', 'fingering', 'glide', 'glissade', 'intonation', 'landslide', 'landslip'],
    'glisten': ['blink', 'blinking', 'coruscate', 'coruscation', 'firefly', 'glance', 'gleam', 'glimmer', 'glimmering', 'glint', 'glisk', 'glister'],
    'glistening': ['blinking', 'blinky', 'burnished', 'coruscant', 'coruscating', 'gleaming', 'glimmering', 'glimmerous', 'glimmery', 'glistering', 'glittering', 'glittery'],
    'glitter': ['be somebody', 'be something', 'bespangle', 'blatancy', 'blink', 'blinking', 'brazenness', 'brilliance', 'colorfulness', 'coruscate', 'coruscation', 'crudeness'],
    'glittering': ['blinking', 'blinky', 'brave', 'bravura', 'braw', 'chichi', 'coruscant', 'coruscating', 'daring', 'dashing', 'dressy', 'exhibitionistic'],
    'gloaming': ['bad light', 'brown of dusk', 'brownness', 'candlelight', 'candlelighting', 'cocklight', 'crepuscule', 'darkishness', 'darksomeness', 'deadness', 'dim', 'dim light'],
    'gloat': ['bore', 'crane', 'crane the neck', 'crow', 'crow over', 'delight', 'delight in', 'exult', 'exult in', 'eye', 'gape', 'gaup'],
    'gloat over': ['adore', 'appreciate', 'bask in', 'be pleased with', 'crow', 'crow over', 'delight', 'delight in', 'derive pleasure from', 'devour', 'eat up', 'enjoy'],
    'global': ['absolute', 'across-the-board', 'admitting no exception', 'all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-out'],
    'globate': ['bulblike', 'bulbous', 'ellipsoid', 'global', 'globe-shaped', 'globed', 'globelike', 'globoid', 'globose', 'globular', 'hemispheric', 'obovoid'],
    'globe': ['earth', 'gaea', 'ge', 'lambert conformal projection', 'mercator projection', 'miller projection', 'tellus', 'terra', 'aeronautical chart', 'astronomical chart', 'atlas', 'azimuthal projection'],
    'globe trot': ['campaign', 'cruise', 'fare', 'go abroad', 'go on safari', 'go overseas', 'hit the trail', 'jaunt', 'journey', 'make a journey', 'make a pilgrimage', 'make a trip'],
    'globe trotter': ['adventurer', 'alpinist', 'astronaut', 'camper', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser', 'excursionist', 'explorer', 'fare'],
    'globular': ['bulblike', 'bulbous', 'ellipsoid', 'global', 'globate', 'globe-shaped', 'globed', 'globelike', 'globoid', 'globose', 'hemispheric', 'obovoid'],
    'globule': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'air bubble', 'antibody', 'antigen', 'arterial blood', 'ball', 'balloon', 'bladder'],
    'glockenspiel': ['battery', 'bells', 'bones', 'castanets', 'celesta', 'chime', 'chimes', 'clappers', 'crash cymbal', 'cymbals', 'finger cymbals', 'gamelan'],
    'gloom': ['adumbrate', 'becloud', 'bedarken', 'bedim', 'begloom', 'black', 'black out', 'blacken', 'blackness', 'bleakness', 'block the light', 'blot out'],
    'gloominess': ['bleakness', 'cynicism', 'darkness', 'defeatism', 'dismalness', 'dreariness', 'gloom', 'gloomy outlook', 'gravity', 'grimness', 'lower', 'lowering'],
    'gloomy': ['acheronian', 'acherontic', 'cassandra-like', 'cassandran', 'cassandrian', 'cimmerian', 'stygian', 'acheronian', 'acherontic', 'apocalyptic', 'bad', 'baleful'],
    'glop': ['albumen', 'batter', 'bonnyclabber', 'butter', 'clabber', 'cornstarch', 'cream', 'curd', 'dough', 'egg white', 'gaum', 'gel'],
    'gloppy': ['barfy', 'crappy', 'disgusting', 'fecal', 'feculent', 'fetid', 'filthy', 'flyblown', 'foul', 'gunky', 'icky', 'maggoty'],
    'gloria': ['agnus dei', 'alleluia', 'anamnesis', 'benedicite', 'blessing', 'canon', 'collect', 'communion', 'consecration', 'credo', 'dismissal', 'epistle'],
    'glorification': ['accolade', 'adulation', 'aggrandizement', 'apotheosis', 'beatification', 'beatitude', 'bepraisement', 'blessedness', 'blessing', 'canonization', 'congratulation', 'consecration'],
    'glorified': ['elysian', 'olympian', 'affected', 'aggrandized', 'angelic', 'apotheosized', 'archangelic', 'awesome', 'beatific', 'beatified', 'big', 'blessed'],
    'glorify': ['acclaim', 'adore', 'adulate', 'advance', 'aggrandize', 'apotheose', 'apotheosize', 'applaud', 'beatify', 'belaud', 'bepraise', 'bless'],
    'glorious': ['babylonian', 'corinthian', 'addled', 'admirable', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'august', 'awe-inspiring', 'awful'],
    'glory': ['babylonian splendor', 'beulah', 'beulah land', 'heaven', 'land of beulah', 'paradise', 'a better place', 'acclaim', 'accolade', 'adoration', 'adulation', 'annular muscle'],
    'gloss': ['abuse of terms', 'acting', 'affectation', 'afterglow', 'air glow', 'alibi', 'allowance', 'amplification', 'analysis', 'annotate', 'annotation', 'apology'],
    'gloss over': ['account', 'allow for', 'be caught napping', 'be neglectful', 'be negligent', 'becloud', 'befog', 'belie', 'blanket', 'blind', 'camouflage', 'cloak'],
    'glossal': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'glossary': ['amplification', 'bilingual text', 'biographical dictionary', 'chemical dictionary', 'clavis', 'crib', 'decipherment', 'decoding', 'desk dictionary', 'dialect dictionary', 'dictionary', 'dictionary of quotations'],
    'glossematics': ['bowwow theory', 'comparative linguistics', 'derivation', 'descriptive grammar', 'descriptive linguistics', 'dialectology', 'dingdong theory', 'etymology', 'generative grammar', 'glossology', 'glottochronology', 'glottology'],
    'glossy': ['photostat', 'xerox', 'xerox copy', 'artificial', 'blowup', 'blueprint', 'bogus', 'buffed', 'burnished', 'contact printing', 'contrived', 'counterfeit'],
    'glottal': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation', 'back'],
    'glove': ['battle cry', 'bid to combat', 'brass knuckles', 'cesta', 'cestus', 'challenge', 'dare', 'defi', 'defy', 'double dare', 'gage', 'gage of battle'],
    'glow': ['hygeia', 'ablate', 'activity', 'afterglow', 'air glow', 'alpenglow', 'animation', 'ardency', 'ardor', 'attractiveness', 'aurora', 'bake'],
    'glower': ['angry look', 'bedroom eyes', 'color', 'come-hither look', 'dirty look', 'evil eye', 'flush', 'frown', 'gape', 'gaze', 'glad eye', 'glare'],
    'glowering': ['beetle-browed', 'black', 'black-browed', 'dark', 'dejected', 'dour', 'dumpish', 'frowning', 'glum', 'grim', 'grum', 'lowering'],
    'glowing': ['titian', 'titian-red', 'ablaze', 'adhesive', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'avid', 'beaming'],
    'glowworm': ['blink', 'blinking', 'candle fly', 'coruscation', 'fire beetle', 'firefly', 'fireworm', 'glimmer', 'glimmering', 'glisten', 'glister', 'glitter'],
    'glue': ['accouple', 'accumulate', 'adherent', 'adhesive', 'affix', 'agglutinate', 'albumen', 'amass', 'articulate', 'assemble', 'associate', 'band'],
    'gluey': ['adherent', 'adhesive', 'amylaceous', 'bulldogged', 'bulldoggish', 'bulldoggy', 'bullheaded', 'clabbered', 'clammy', 'clingy', 'close', 'close-knit'],
    'glum': ['beetle-browed', 'black', 'black-browed', 'brooding', 'broody', 'chapfallen', 'close-lipped', 'crabbed', 'crestfallen', 'dark', 'dejected', 'depressed'],
    'glut': ['allay', 'batten', 'be infinitely repetitive', 'be tedious', 'bellyful', 'bolt', 'bolt down', 'choke', 'clog', 'cloy', 'congest', 'congestion'],
    'gluten': ['albumen', 'batter', 'bonnyclabber', 'butter', 'clabber', 'cornstarch', 'cream', 'curd', 'dough', 'egg white', 'gaum', 'gel'],
    'glutinous': ['adherent', 'adhesive', 'amylaceous', 'bulldogged', 'bulldoggish', 'bulldoggy', 'bullheaded', 'clabbered', 'clammy', 'clingy', 'clotted', 'coagulated'],
    'glutted': ['allayed', 'bloated', 'bursting', 'choked', 'cloyed', 'congested', 'crammed', 'crowded', 'disgusted', 'distended', 'drenched', 'engorged'],
    'glutton': ['brillat-savarin', 'cape polecat', 'lucullus', 'ape', 'bar', 'bear', 'belly-god', 'board-and-roomer', 'boarder', 'bon vivant', 'cannibal', 'carnivore'],
    'gluttonous': ['apician', 'a bit much', 'abandoned', 'all-devouring', 'bibulous', 'bolting', 'boundless', 'cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'cramming'],
    'gluttony': ['abandon', 'acedia', 'acquisitiveness', 'anger', 'appetite', 'avarice', 'avariciousness', 'avaritia', 'avidity', 'avidness', 'boundlessness', 'cannibalism'],
    'glyph': ['anaglyph', 'bas-relief', 'boss', 'cameo', 'cameo glass', 'cavo-rilievo', 'cut glass', 'embossment', 'glyptograph', 'high relief', 'intaglio', 'intaglio rilevato'],
    'glyphic': ['anaglyphic', 'anaglyptic', 'anastatic', 'carved', 'ceroplastic', 'chased', 'creased', 'cut', 'embossed', 'enchased', 'engraved', 'engraven'],
    'glyptic': ['cysp sculpture', 'anaglyptics', 'anaglyptography', 'architectural sculpture', 'bone-carving', 'burr', 'casting', 'ceroplastics', 'chasing', 'chiseling', 'clay sculpture', 'cross-hatching'],
    'gnarl': ['anamorphism', 'anamorphosis', 'asymmetry', 'bend', 'bilge', 'blain', 'bleb', 'blister', 'blob', 'boss', 'bow', 'bubble'],
    'gnarled': ['arthritic', 'bent', 'bumpy', 'burled', 'contorted', 'crooked', 'distorted', 'gnarly', 'knobbed', 'knobbly', 'knobby', 'knoblike'],
    'gnash': ['bite', 'bolus', 'champ', 'chaw', 'chew', 'chew the cud', 'chew up', 'chomp', 'cud', 'gnaw', 'gob', 'grind'],
    'gnat': ['crumb', 'dot', 'drop', 'droplet', 'fleck', 'flyspeck', 'grain', 'iota', 'jot', 'microbe', 'microorganism', 'midge'],
    'gnaw': ['ablate', 'abrade', 'abrase', 'afflict', 'agonize', 'ail', 'annoy', 'badger', 'bark', 'bedevil', 'beleaguer', 'bite'],
    'gnawing': ['ablative', 'abradant', 'abrasive', 'ache', 'aching', 'acute', 'acute pain', 'afflictive', 'agonizing', 'angina', 'atrocious', 'attritive'],
    'gneiss': ['aa', 'abyssal rock', 'basalt', 'bedrock', 'block lava', 'brash', 'breccia', 'conglomerate', 'crag', 'druid stone', 'festooned pahoehoe', 'granite'],
    'gnome': ['ariel', 'befind', 'corrigan', 'finnbeara', 'lilliputian', 'mab', 'oberon', 'titania', 'tom thumb', 'adage', 'ana', 'analects'],
    'gnomic': ['spartan', 'abbreviated', 'abridged', 'aphoristic', 'aposiopestic', 'axiomatic', 'brief', 'brusque', 'clipped', 'close', 'compact', 'compendious'],
    'gnominious': ['illegal', 'illogical', 'illusory', 'improper', 'improved', 'inappropriate', 'incorrect', 'indecorous', 'indirect', 'infamous', 'irregular', 'kinky'],
    'gnu': ['cape elk', 'virginia deer', 'antelope', 'buck', 'camel', 'camelopard', 'caribou', 'deer', 'deerlet', 'doe', 'dromedary', 'eland'],
    'go': ['olympic games', 'olympics', 'abstain from', 'accompany', 'accomplished fact', 'accomplishment', 'accord', 'achievement', 'act', 'act on', 'act upon', 'acta'],
    'go about': ['about ship', 'accept', 'assume', 'attack', 'attempt', 'back and fill', 'bat around', 'bear away', 'bear off', 'bear to starboard', 'beat', 'beat about'],
    'go after': ['attend', 'bedog', 'bring', 'bring back', 'call for', 'chase', 'chase after', 'chivy', 'come after', 'come behind', 'come on', 'displace'],
    'go against': ['antagonize', 'be antipathetic', 'be at cross-purposes', 'be inimical', 'beat against', 'clash', 'collide', 'conflict', 'conflict with', 'confute', 'contradict', 'contrapose'],
    'go ahead': ['john hancock', 'ok', 'acceptance', 'admission', 'advance', 'advancement', 'advancing', 'adventuresome', 'adventuresomeness', 'adventurous', 'adventurousness', 'affirmance'],
    'go all out': ['buckle down', 'carry through', 'cut loose', 'do to perfection', 'do up brown', 'drive', 'drive on', 'endeavor', 'exhaust every move', 'follow out', 'follow through', 'follow up'],
    'go along': ['abide', 'advance', 'be getting along', 'be so', 'be such', 'bide', 'buzz off', 'carry on', 'cease not', 'come along', 'come away', 'come on'],
    'go along with': ['ok', 'accede', 'accede to', 'accept', 'accompany', 'accord', 'accord to', 'acknowledge', 'acquiesce', 'act with', 'admit', 'agree'],
    'go around': ['advance', 'answer', 'ascend', 'avail', 'back', 'back up', 'be equal to', 'bear', 'budge', 'bypass', 'change', 'change place'],
    'go astray': ['abort', 'backslide', 'be in error', 'be mistaken', 'be wrong', 'degenerate', 'depart', 'deviate', 'digress', 'divagate', 'drift', 'err'],
    'go at': ['accept', 'ambush', 'assail', 'assault', 'assume', 'attack', 'attempt', 'blitz', 'buckle to', 'bushwhack', 'clip off', 'come at'],
    'go away': ['aberrate', 'be consumed', 'be getting along', 'be gone', 'buzz off', 'cease', 'cease to be', 'cease to exist', 'come away', 'decline', 'dematerialize', 'depart'],
    'go back': ['back', 'back down', 'back out', 'back up', 'beat a retreat', 'break back', 'bring back', 'bring to mind', 'call back', 'call to mind', 'call up', 'change back'],
    'go back on': ['abandon', 'back out', 'be unfaithful', 'beg off', 'break faith', 'cry off', 'depart from', 'desert', 'discard', 'drop out', 'evacuate', 'fail'],
    'go back over': ['bring back', 'bring to mind', 'call back', 'call to mind', 'call up', 'conjure up', 'evoke', 'go back', 'hark back', 'look back', 'mind', 're-examine'],
    'go before': ['announce', 'antecede', 'antedate', 'anticipate', 'be before', 'be early', 'be the bellwether', 'beacon', 'blaze the trail', 'break the trail', 'come before', 'come first'],
    'go between': ['charlie mccarthy', 'hermes', 'iris', 'mercury', 'paul revere', 'pheidippides', 'agent', 'allegorist', 'ancilla', 'annotator', 'appliance', 'arbitrator'],
    'go beyond': ['exaggerate', 'exceed', 'overdo', 'overgo', 'overjump', 'overleap', 'overpass', 'overreach', 'overrun', 'overshoot', 'overshoot the field', 'overshoot the mark'],
    'go down': ['be believed', 'be lost', 'be received', 'be swallowed', 'bite the dust', 'bow', 'capsize', 'carry conviction', 'cascade', 'cataract', 'cave', 'cave in'],
    'go far': ['achieve success', 'advance', 'arrive', 'be a success', 'break through', 'come on', 'come through', 'cut a swath', 'get ahead', 'get on', 'get there', 'go places'],
    'go for': ['abet', 'accept', 'advocate', 'aid and abet', 'aim', 'aim at', 'ambush', 'and sinker', 'answer for', 'aspire after', 'aspire to', 'assail'],
    'go for broke': ['be determined', 'be in earnest', 'be resolved', 'bell the cat', 'buckle down', 'buckle to', 'carry through', 'court danger', 'cross the rubicon', 'defy danger', 'die fighting', 'die hard'],
    'go getter': ['activist', 'ball of fire', 'beaver', 'big-time operator', 'bustler', 'busy bee', 'doer', 'dynamo', 'eager beaver', 'enthusiast', 'human dynamo', 'hustler'],
    'go go': ['abandoned', 'active', 'acute', 'aggressive', 'animated', 'brisk', 'dynamic', 'energetic', 'enterprising', 'enthusiastic', 'forceful', 'forcible'],
    'go in for': ['accept', 'adopt', 'affiliate', 'approve', 'assume', 'attack', 'attempt', 'be into', 'be strong in', 'buckle to', 'carry', 'carry on'],
    'go in with': ['act with', 'align with', 'flock to', 'get together with', 'go along with', 'join', 'join hands with', 'join up with', 'join with', 'line up with', 'rally round', 'range with'],
    'go into': ['accept', 'admit', 'affiliate', 'affiliate with', 'air', 'amplify', 'analyze', 'assemble', 'associate', 'assume', 'attack', 'attempt'],
    'go off': ['aberrate', 'avert', 'backfire', 'bang', 'bark', 'be blooded', 'be found', 'be getting along', 'be met with', 'be realized', 'be successful', 'bear off'],
    'go on': ['abide', 'acquit', 'act', 'advance', 'assault', 'attack', 'babble', 'barbarize', 'batter', 'be getting along', 'be livid', 'be pissed'],
    'go one better': ['best', 'better', 'cap', 'circumvent', 'deceive', 'elude', 'evade', 'exceed', 'excel', 'foil', 'frustrate', 'get around'],
    'go out': ['be all over', 'be lost', 'be no more', 'be superseded', 'become extinct', 'become void', 'blow over', 'bow out', 'boycott', 'burn out', 'carry', 'carry out'],
    'go over': ['apostacize', 'apostatize', 'autopsy', 'battologize', 'be blooded', 'be successful', 'bolt', 'bone', 'break away', 'canvass', 'catch on', 'change sides'],
    'go over big': ['be blooded', 'be successful', 'catch on', 'click', 'come off', 'connect', 'farewell', 'give pleasure', 'go', 'go great guns', 'go off', 'go over'],
    'go overboard': ['carry too far', 'exaggerate', 'exhaust', 'go to extremes', 'go too far', 'know no bounds', 'overact', 'overcarry', 'overdevelop', 'overdo', 'overdrive', 'overelaborate'],
    'go places': ['achieve success', 'advance', 'arrive', 'be a success', 'break through', 'come on', 'come through', 'cut a swath', 'get ahead', 'get on', 'get there', 'go far'],
    'go slow': ['amble', 'claudicate', 'crawl', 'creep', 'crowd', 'dogtrot', 'drag', 'drag along', 'drag out', 'drive on', 'forge ahead', 'go dead slow'],
    'go straight': ['acculturate', 'advance', 'ameliorate', 'amend', 'arrow', 'arrow for', 'be straight', 'better', 'boost', 'bring forward', 'civilize', 'edify'],
    'go the limit': ['carry through', 'carry to excess', 'carry too far', 'do to perfection', 'do up brown', 'exhaust every move', 'follow out', 'follow through', 'follow up', 'go all lengths', 'go all out', 'go for broke'],
    'go through': ['battologize', 'be exposed to', 'be subjected to', 'beat the bushes', 'benumb', 'bite', 'blow', 'bring off', 'budget', 'burrow', 'carry into effect', 'carry into execution'],
    'go to': ['appear', 'assister', 'attend', 'be at', 'be present at', 'carry to', 'catch', 'come to', 'do', 'extend to', 'get to', 'hie to'],
    'go to bed': ['bed', 'bed down', 'couch', 'curl up', 'go beddy-bye', 'go night-night', 'go to rest', 'lie down', 'loll', 'lounge', 'recline', 'repose'],
    'go to extremes': ['aggrandize', 'amplify', 'ballyhoo', 'build up', 'burlesque', 'caricature', 'carry too far', 'draw the longbow', 'exaggerate', 'exhaust', 'go overboard', 'go too far'],
    'go to it': ['attack', 'dive into', 'enter on', 'enter upon', 'fall to', 'get busy', 'get cracking', 'get going', 'get with it', 'hop to it', 'jump to it', 'launch into'],
    'go to pieces': ['bite the dust', 'break', 'break up', 'canker', 'carry away', 'cave in', 'collapse', 'come apart', 'come off', 'come undone', 'come unstuck', 'conk out'],
    'go to pot': ['be ruined', 'become insolvent', 'break', 'bust', 'collapse', 'come down', 'come to naught', 'come to nothing', 'crash', 'decline', 'degenerate', 'deteriorate'],
    'go to town': ['be blooded', 'be successful', 'catch on', 'click', 'come off', 'connect', 'farewell', 'get cutting', 'go', 'go great guns', 'go off', 'go over'],
    'go together': ['accord', 'agree', 'answer to', 'assent', 'assort with', 'be consistent', 'be of one', 'be uniform with', 'check', 'chime', 'cohere', 'coincide'],
    'go too far': ['advance upon', 'ask for it', 'be rash', 'be reckless', 'break bounds', 'carry too far', 'catch at straws', 'encroach', 'exaggerate', 'exhaust', 'go overboard', 'go to extremes'],
    'go under': ['be ruined', 'become insolvent', 'bite the dust', 'bow', 'break', 'bust', 'collapse', 'crash', 'fail', 'fall', 'fold', 'fold up'],
    'go up': ['accrue', 'accumulate', 'advance', 'appreciate', 'arise', 'ascend', 'balloon', 'be ruined', 'become insolvent', 'bloat', 'boom', 'break'],
    'go with': ['accompany', 'accord', 'agree', 'agree in opinion', 'agree with', 'answer to', 'around', 'assent', 'associate', 'associate with', 'assort with', 'attend'],
    'go without saying': ['aller sans dire', 'be axiomatic', 'be certain', 'be confident', 'be manifest', 'be no secret', 'bet on', 'come across', 'doubt not', 'feel sure', 'gamble on', 'glare'],
    'go wrong': ['abort', 'backslide', 'be disappointing', 'be in error', 'be mistaken', 'be wrong', 'break down', 'come short', 'conk out', 'degenerate', 'deviate', 'err'],
    'goad': ['actuate', 'animate', 'assault', 'bear', 'bear upon', 'boost', 'buck', 'bull', 'bulldoze', 'bump', 'bump against', 'bunt'],
    'goal': ['aim', 'ambition', 'anchorage', 'apodosis', 'aspiration', 'basis', 'bourn', 'butt', 'by-end', 'by-purpose', 'calling', 'catastrophe'],
    'goalie': ['advance guard', 'armed guard', 'bank guard', 'coast guard', 'cordon', 'cordon sanitaire', 'garrison', 'goalkeeper', 'goaltender', 'guard', 'guarder', 'guardsman'],
    'goaltender': ['advance guard', 'armed guard', 'bank guard', 'coast guard', 'cordon', 'cordon sanitaire', 'garrison', 'goalie', 'goalkeeper', 'guard', 'guarder', 'guardsman'],
    'goat': ['priapus', 'aphrodisiomaniac', 'balker', 'balky horse', 'billy', 'billy goat', 'broad jumper', 'buck', 'bucking bronco', 'buckjumper', 'butt', 'byword'],
    'goatherd': ['gyropilot', 'automatic pilot', 'boatheader', 'boatsteerer', 'cattleman', 'cicerone', 'courier', 'cowboy', 'cowgirl', 'cowhand', 'cowherd', 'cowman'],
    'goatish': ['animal', 'aphrodisiomaniacal', 'asinine', 'bawdy', 'bovid', 'bovine', 'caprid', 'caprine', 'carnal', 'clitoromaniacal', 'concupiscent', 'cowish'],
    'gob': ['naval reservist', 'royal marine', 'seabee', 'accumulation', 'acervation', 'agglomerate', 'agglomeration', 'aggregate', 'aggregation', 'amassment', 'amount', 'ball'],
    'gobbet': ['ace', 'atom', 'ball', 'balloon', 'bit', 'bladder', 'blob', 'boll', 'bolus', 'bubble', 'bulb', 'bulbil'],
    'gobble': ['ablate', 'absorb', 'assimilate', 'batten', 'bleed white', 'bolt', 'bolt down', 'bring to ruin', 'burn up', 'cackle', 'call', 'carol'],
    'gobbledegook': ['balderdash', 'bosh', 'bull', 'bullshit', 'bunk', 'circumlocution', 'crap', 'deception', 'deceptiveness', 'double-talk', 'drivel', 'equivocation'],
    'gobbledygook': ['aesopian language', 'babel', 'greek', 'washingtonese', 'absurdity', 'amphigory', 'argot', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'blabber'],
    'gobbler': ['bantam', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'billy', 'billy goat', 'boar', 'broiler', 'brooder', 'broody hen', 'bubbly-jock'],
    'gobbling': ['apician', 'a hog for', 'acquisitive', 'all-devouring', 'avaricious', 'avid', 'bolting', 'bottomless', 'coveting', 'covetous', 'cramming', 'crapulent'],
    'goblet': ['beaker', 'blackjack', 'bowl', 'chalice', 'coffee cup', 'eggcup', 'glass', 'highball glass', 'horn', 'jigger', 'loving cup', 'mug'],
    'goblin': ['ariel', 'befind', 'corrigan', 'finnbeara', 'mab', 'oberon', 'titania', 'banshee', 'brownie', 'cluricaune', 'demon', 'dwarf'],
    'god': ['aides', 'aidoneus', 'amen-ra', 'amor', 'aphrodite', 'apollo', 'apollo musagetes', 'ares', 'artemis', 'ashtoreth', 'astarte', 'astraea'],
    'god fearing': ['christlike', 'christly', 'angelic', 'godlike', 'godly', 'godly-minded', 'good', 'heavenly', 'holy', 'holy-minded', 'otherworldly', 'pure'],
    'god the son': ['christ', 'christ jesus', 'emmanuel', 'god-man', 'immanuel', 'jesu', 'jesus', 'jesus christ', 'jesus of nazareth', 'king of glory', 'king of heaven', 'king of kings'],
    'godawful': ['barfy', 'bum', 'cheesy', 'crappy', 'creepy', 'crummy', 'dirty', 'goshawful', 'grim', 'hairy', 'icky', 'punk'],
    'goddamn': ['absolute', 'accursed', 'blankety-blank', 'blasted', 'blessed', 'blooming', 'complete', 'consummate', 'cursed', 'damn', 'damnable', 'damned'],
    'goddess': ['aides', 'aidoneus', 'amen-ra', 'amor', 'aphrodite', 'apollo', 'apollo musagetes', 'ares', 'artemis', 'ashtoreth', 'astarte', 'astraea'],
    'goddess like': ['junoesque', 'agreeable', 'amply endowed', 'becoming', 'bonny', 'braw', 'built', 'built for comfort', 'buxom', 'callipygian', 'callipygous', 'comely'],
    'godforsaken': ['abandoned', 'antipodean', 'available', 'back of beyond', 'defenseless', 'deserted', 'desolate', 'fatherless', 'forlorn', 'forsaken', 'free', 'friendless'],
    'godless': ['agnostic', 'atheistic', 'blasphemous', 'damned', 'evil', 'graceless', 'hellish', 'impious', 'infidel', 'iniquitous', 'irreligious', 'lost'],
    'godlike': ['christlike', 'christly', 'god-fearing', 'angelic', 'august', 'beatific', 'blessed', 'blissful', 'celestial', 'distinguished', 'divine', 'ecstatic'],
    'godliness': ['christianity', 'christlikeness', 'christliness', 'fatherhood', 'angelicalness', 'awesomeness', 'awfulness', 'beauty of holiness', 'blessedness', 'deity', 'divineness', 'divinity'],
    'godly': ['christlike', 'christly', 'god-fearing', 'angelic', 'celestial', 'devoted', 'devout', 'divine', 'empyrean', 'faithful', 'godlike', 'godly-minded'],
    'godsend': ['advantage', 'benediction', 'benefit', 'blessing', 'boast', 'bonanza', 'boon', 'catch', 'diamond', 'find', 'gem', 'gift'],
    'goer': ['jehu', 'adventurer', 'alpinist', 'astronaut', 'camper', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser', 'departer', 'emigrant'],
    'gofer': ['ganymede', 'hebe', 'airline hostess', 'airline stewardess', 'attendant', 'batman', 'bellboy', 'bellhop', 'bellman', 'bootblack', 'boots', 'cabin boy'],
    'goffer': ['aqueduct', 'canal', 'canalization', 'canalize', 'carve', 'chamfer', 'channel', 'chisel', 'corrugate', 'crack', 'crimp', 'cut'],
    'goggle': ['bag', 'balloon', 'bedroom eyes', 'bellied', 'belly', 'belly out', 'bilge', 'billow', 'bore', 'bouge', 'bug', 'bug-eyed'],
    'goggle eyes': ['baby blues', 'banjo eyes', 'bright eyes', 'bug-eyes', 'clear eyes', 'cockeyes', 'cornea', 'cross-eyes', 'eye', 'eyeball', 'eyelid', 'iris'],
    'goggled': ['bellied', 'bespectacled', 'bug-eyed', 'bulged', 'exophthalmic', 'four-eyed', 'goggle', 'monocled', 'popeyed', 'pouched', 'spectacled', 'swollen'],
    'goggles': ['polaroid glasses', 'aegis', 'arm guard', 'backstop', 'bifocals', 'blinkers', 'buffer', 'bulwark', 'bumper', 'cheaters', 'colored glasses', 'contact lens'],
    'going': ['abandonment', 'accepted', 'acting', 'active', 'activity', 'actuation', 'affluent', 'ambulant', 'ambulative', 'ambulatory', 'annihilation', 'ascending'],
    'going on': ['accidental', 'accompanying', 'acting', 'active', 'ado', 'afloat', 'afoot', 'at work', 'brewing', 'circumstantial', 'current', 'doing'],
    'going strong': ['balmy', 'blooming', 'blossoming', 'booming', 'clear', 'exuberant', 'fair', 'fat', 'flourishing', 'flowering', 'fruiting', 'halcyon'],
    'goings on': ['action', 'actions', 'activeness', 'activism', 'activity', 'acts', 'address', 'affairs', 'affectation', 'air', 'bearing', 'behavior'],
    'goiter': ['lombardy leprosy', 'anemia', 'ariboflavinosis', 'beriberi', 'cachexia', 'chlorosis', 'deficiency anemia', 'dermatitis', 'greensickness', 'keratomalacia', 'kwashiorkor', 'maidism'],
    'gold': ['affluence', 'aluminum', 'americium', 'and pence', 'assets', 'aureate', 'aureateness', 'auric', 'bar', 'barium', 'beige', 'beryllium'],
    'gold filled': ['aureate', 'brass', 'brassy', 'brazen', 'bronze', 'bronzy', 'copper', 'coppery', 'cupreous', 'cuprous', 'ferrous', 'ferruginous'],
    'gold mine': ['eldorado', 'golconda', 'bank', 'bonanza', 'coal mine', 'colliery', 'cornucopia', 'diggings', 'eldorado', 'font', 'fount', 'fountain'],
    'gold piece': ['coin', 'crown', 'double eagle', 'doubloon', 'ducat', 'eagle', 'five-dollar gold piece', 'guinea', 'half crown', 'half eagle', 'hard money', 'moidore'],
    'goldbrick': ['abandon', 'boiler room', 'bucket shop', 'bum', 'bunco game', 'bungler', 'clock watcher', 'con game', 'confidence game', 'cut', 'dallier', 'dawdle'],
    'golden': ['achingly sweet', 'advantageous', 'agreeable', 'agreeable-sounding', 'appealing', 'ariose', 'arioso', 'aureate', 'auric', 'auriferous', 'aurous', 'auspicious'],
    'golden age': ['saturnia regna', 'saturnian age', 'age of aquarius', 'era of prosperity', 'fair weather', 'golden era', 'golden time', 'good times', 'halcyon days', 'heaven', 'heyday', 'millennium'],
    'golden rule': ['christian ethics', 'stoicism', 'a priori truth', 'altruistic ethics', 'aretaics', 'axiom', 'brocard', 'canon', 'casuistry', 'categorical imperative', 'code', 'commandment'],
    'golem': ['ament', 'automaton', 'born fool', 'clot', 'congenital idiot', 'cretin', 'defective', 'half-wit', 'idiot', 'imbecile', 'juggins', 'machine'],
    'goliath': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'gargantua', 'hercules', 'orion', 'polyphemus', 'samson', 'superman'],
    'gonads': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'gondolier': ['bargee', 'bargeman', 'barger', 'boat-handler', 'boater', 'boatman', 'boatsman', 'ferrier', 'ferryman', 'galley slave', 'lighterman', 'oar'],
    'gone': ['ablated', 'absconded', 'absent', 'ago', 'all gone', 'all in', 'anemic', 'annihilated', 'antiquated', 'antique', 'asleep', 'asleep in jesus'],
    'gone by': ['ago', 'antiquated', 'antique', 'back', 'back when', 'backward', 'blown over', 'by', 'bygone', 'bypast', 'dated', 'dead'],
    'gone on': ['ape about', 'attached to', 'bugs on', 'cracked on', 'crazy about', 'devoted to', 'enamored of', 'far gone on', 'fond of', 'freaked-out', 'gaga over', 'hepped up over'],
    'gone to seed': ['crumbling', 'dense', 'dilapidated', 'dusty', 'exuberant', 'flourishing', 'fusty', 'gross', 'heavy', 'impenetrable', 'jungled', 'jungly'],
    'gong': ['battery', 'bell', 'bells', 'bones', 'castanets', 'celesta', 'chime', 'chimes', 'chink', 'church bell', 'clang', 'clangor'],
    'gongorism': ['affectation', 'affectedness', 'artfulness', 'artifice', 'artificiality', 'euphemism', 'euphuism', 'hyperelegance', 'manneredness', 'mannerism', 'overelaboration', 'overelegance'],
    'gonorrhea': ['french disease', 'spanish pox', 'vd', 'acquired syphilis', 'balanitis gangrenosa', 'cerebral tabes', 'chancre', 'chancroid', 'clap', 'claps', 'climatic bubo', 'congenital syphilis'],
    'goo': ['albumen', 'bathos', 'batter', 'bleeding heart', 'bonnyclabber', 'butter', 'cab', 'clabber', 'cloyingness', 'cornstarch', 'cream', 'curd'],
    'goober': ['brazil nut', 'almond', 'almond paste', 'amande', 'amande douce', 'amandes mondees', 'bitter almond', 'blanched almonds', 'burnt almond', 'goober pea', 'ground-pea', 'groundnut'],
    'good': ['christian', 'christlike', 'christly', 'daedalian', 'god-fearing', 'ok', 'roger', 'sunday', 'able to pay', 'absolutely', 'acceptable', 'accomplished'],
    'good bye': ['godspeed', 'adieu', 'aloha', 'conge', 'departing', 'doch-an-dorrach', 'farewell', 'leave', 'leave-taking', 'leavetaking', 'parting', 'parting words'],
    'good chance': ['aptitude', 'bare possibility', 'best bet', 'chance', 'conceivability', 'conceivableness', 'contingency', 'due season', 'equivalent odds', 'even break', 'even chance', 'eventuality'],
    'good deal': ['batch', 'considerable', 'deal', 'gobs', 'great deal', 'heap', 'heaps', 'lashings', 'loads', 'lot', 'lots', 'mess'],
    'good deed': ['act of grace', 'act of kindness', 'benefaction', 'benefit', 'benevolence', 'benignity', 'blessing', 'courtesy', 'favor', 'good offices', 'good turn', 'grace'],
    'good enough': ['ok', 'roger', 'absolutely', 'acceptable', 'adequate', 'admissible', 'agreeable', 'all right', 'alright', 'alrighty', 'amen', 'ample'],
    'good fellow': ['acceptable person', 'bon vivant', 'boon companion', 'capital fellow', 'diamond', 'gem', 'gentleman', 'good lot', 'good man', 'good person', 'good sort', 'good woman'],
    'good for': ['able to pay', 'ad valorem', 'advantageous', 'aidful', 'appraised', 'appropriate', 'assessed', 'banausic', 'beneficial', 'benign', 'bracing', 'commodious'],
    'good form': ['amenities', 'bienseance', 'civilities', 'civility', 'comity', 'conformity', 'convenance', 'convention', 'conventional usage', 'conventionalism', 'conventionality', 'correctness'],
    'good friday': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas'],
    'good humor': ['affability', 'amiability', 'bonhomie', 'cordiality', 'exhilaration', 'geniality', 'gentleness', 'good disposition', 'good nature', 'good spirits', 'good temper', 'goodnaturedness'],
    'good humored': ['affable', 'agreeable', 'amiable', 'bonhomous', 'buoyant', 'cheerful', 'cheery', 'complaisant', 'cordial', 'easy', 'easy-natured', 'genial'],
    'good looking': ['junoesque', 'agreeable', 'amply endowed', 'becoming', 'bonny', 'braw', 'built', 'built for comfort', 'buxom', 'callipygian', 'callipygous', 'comely'],
    'good looks': ['aesthetic proportions', 'beauties', 'belle tournure', 'bodily charm', 'bodily grace', 'charms', 'curvaceousness', 'curves', 'good appearance', 'good effect', 'good figure', 'good points'],
    'good luck': ['accidentality', 'actuarial calculation', 'adventitiousness', 'blessing', 'break', 'casualness', 'chance', 'destiny', 'fate', 'felicity', 'flukiness', 'fortuitousness'],
    'good manners': ['amenities', 'bienseance', 'civilities', 'civility', 'comity', 'convention', 'correct deportment', 'correctitude', 'correctness', 'courtesy', 'courtliness', 'decencies'],
    'good person': ['samaritan', 'aid', 'aider', 'assister', 'backer', 'befriender', 'benefactor', 'benefactress', 'benefiter', 'good samaritan', 'help', 'helper'],
    'good samaritan': ['samaritan', 'aid', 'aider', 'assister', 'backer', 'befriender', 'benefactor', 'benefactress', 'benefiter', 'good person', 'help', 'helper'],
    'good shape': ['aesthetic proportions', 'anality', 'apple-pie order', 'beauties', 'belle tournure', 'bodily charm', 'bodily grace', 'charms', 'curvaceousness', 'curves', 'discipline', 'eupepsia'],
    'good taste': ['atticism', 'acquired taste', 'appreciation of excellence', 'appropriateness', 'chasteness', 'chastity', 'choiceness', 'civilized taste', 'civilizedness', 'clarity', 'classicalism', 'classicism'],
    'good time': ['action', 'ball', 'big time', 'due season', 'favorable opportunity', 'fun', 'fun and games', 'funmaking', 'game', 'golden opportunity', 'good chance', 'good opportunity'],
    'good times': ['saturnia regna', 'saturnian age', 'age of aquarius', 'era of prosperity', 'fair weather', 'golden age', 'golden era', 'golden time', 'halcyon days', 'heaven', 'heyday', 'millennium'],
    'good turn': ['act of grace', 'act of kindness', 'benefaction', 'benefit', 'benevolence', 'benignity', 'blessing', 'courtesy', 'favor', 'good deed', 'good offices', 'grace'],
    'good vibrations': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'amity', 'bonds of harmony', 'brotherly love', 'caritas', 'cement of friendship', 'charity', 'communion'],
    'good-for-nothing': ['bowery bum', 'ng', 'bad lot', 'beachcomber', 'beggar', 'beggarly fellow', 'blighter', 'bone-lazy', 'budmash', 'bum', 'bummer', 'cadging'],
    'good-natured': ['acquiescent', 'affable', 'agreeable', 'altruistic', 'amiable', 'amicable', 'benevolent', 'bonhomous', 'charitable', 'cheerful', 'complaisant', 'compliant'],
    'goodly': ['junoesque', 'advantageous', 'affable', 'agreeable', 'amiable', 'amicable', 'ample', 'amply endowed', 'auspicious', 'becoming', 'beneficial', 'benevolent'],
    'goodness': ['christianity', 'christlikeness', 'christliness', 'affability', 'affectionateness', 'agreeability', 'agreeableness', 'amenity', 'amiability', 'amicability', 'angelicalness', 'appropriateness'],
    'goods': ['ability', 'ableness', 'account', 'acquaintance', 'acquest', 'adequacy', 'announcement', 'baggage', 'blue book', 'briefing', 'bulletin', 'bump'],
    'goodwill': ['bomfog', 'benthamism', 'christian charity', 'christian love', 'abetment', 'acquiescence', 'advocacy', 'aegis', 'agreeableness', 'alacrity', 'altruism', 'amenability'],
    'goody': ['tartuffian', 'tartuffish', 'affected', 'ambrosia', 'better half', 'bonne bouche', 'canting', 'cate', 'choice morsel', 'common-law wife', 'concubine', 'dainty'],
    'goody goody': ['lord fauntleroy', 'pecksniffian', 'percy', 'tartuffian', 'tartuffish', 'victorian', 'affected', 'bluenose', 'canting', 'chicken', 'cream puff', 'effeminate'],
    'gooey': ['adhesive', 'amylaceous', 'bathetic', 'beery', 'clabbered', 'clammy', 'clotted', 'cloying', 'coagulated', 'curdled', 'doughy', 'drippy'],
    'goof': ['asshole', 'bitch', 'bitch up', 'bloomer', 'blooper', 'blow', 'blunder', 'bobble', 'bonehead into it', 'bonehead play', 'boner', 'boo-boo'],
    'goof off': ['abandon', 'bum', 'bum around', 'bungler', 'clock watcher', 'cut', 'dallier', 'dally', 'dawdle', 'dawdler', 'delay', 'diddler'],
    'goofball': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'goofy': ['apish', 'asinine', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'befooled', 'beguiled', 'besotted', 'bonkers'],
    'googol': ['astronomical number', 'billion', 'decillion', 'duodecillion', 'googolplex', 'infinitude', 'infinity', 'jillion', 'large number', 'nonillion', 'novemdecillion', 'octillion'],
    'gook': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'goon': ['mafioso', 'young turk', 'adherent', 'battler', 'beast', 'beldam', 'belligerent', 'belted knight', 'berserk', 'berserker', 'bickerer', 'blade'],
    'goop': ['albumen', 'batter', 'bonnyclabber', 'butter', 'clabber', 'cornstarch', 'cream', 'curd', 'dough', 'egg white', 'gaum', 'gel'],
    'goose': ['bantam', 'cornish hen', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'broiler', 'brooder', 'broody hen', 'caille', 'canard', 'caneton'],
    'goose bumps': ['ache', 'aching', 'agitation', 'broken ground', 'broken water', 'chilblains', 'chill', 'chilliness', 'chilling', 'chills of fear', 'chop', 'cold creeps'],
    'goose grass': ['bramble', 'brier', 'bristle', 'burr', 'cactus', 'catchweed', 'cleavers', 'needle', 'nettle', 'pine needle', 'prickle', 'quill'],
    'goose step': ['backpack', 'defile', 'double march', 'double time', 'double-quick', 'file', 'file off', 'footslog', 'go on parade', 'half step', 'hike', 'march'],
    'goosy': ['allergic', 'altricial', 'anaphylactic', 'anserine', 'anserous', 'aquiline', 'avian', 'avicular', 'bashful', 'birdlike', 'birdy', 'columbine'],
    'gop': ['american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party', 'greenback party'],
    'gordian knot': ['chinese puzzle', 'rube goldberg contraption', 'can of worms', 'complex', 'crux', 'dilemma', 'enigma', 'jungle', 'knot', 'knotty point', 'labyrinth', 'maze'],
    'gore': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'antibody', 'antigen', 'arterial blood', 'auger', 'bane', 'bite', 'blood'],
    'gorge': ['abysm', 'abyss', 'allay', 'arroyo', 'bar', 'barrier', 'batten', 'blank wall', 'blind alley', 'blind gut', 'block', 'blockade'],
    'gorged': ['allayed', 'bloated', 'bursting', 'choked', 'cloyed', 'congested', 'crammed', 'crowded', 'disgusted', 'distended', 'drenched', 'engorged'],
    'gorgeous': ['beaming', 'beautiful', 'blatant', 'blooming', 'brazen', 'brazenfaced', 'breathtaking', 'bright', 'bright-hued', 'brilliant', 'burning', 'colorful'],
    'gorilla': ['antaeus', 'atlas', 'barbary ape', 'briareus', 'brobdingnagian', 'cain', 'charles atlas', 'cyclops', 'goliath', 'hercules', 'mafioso', 'polyphemus'],
    'gormandize': ['batten', 'bolt', 'bolt down', 'cram', 'devour', 'engorge', 'glut', 'gluttonize', 'gobble', 'gorge', 'gulp', 'gulp down'],
    'gory': ['blood-colored', 'blood-spattered', 'bloodstained', 'bloodthirsty', 'bloody', 'bloody-minded', 'bloody-red', 'cruel', 'cutthroat', 'ensanguined', 'grisly', 'gruesome'],
    'goshen': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'happy valley', 'land of youth'],
    'gosling': ['bantam', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'birdling', 'broiler', 'brooder', 'broody hen', 'calf', 'capon', 'catling'],
    'gospel': ['bible truth', 'biblical', 'mosaic', 'negro spiritual', 'new-testament', 'old-testament', 'weltanschauung', 'anthem', 'apocalyptic', 'apostolic', 'articles of religion', 'bad news'],
    'gossamer': ['air', 'airy', 'animal fiber', 'artificial fiber', 'attenuate', 'attenuated', 'boyish', 'bubble', 'cambric tea', 'capillament', 'chaff', 'chip'],
    'gossamery': ['air-built', 'airy', 'attenuate', 'attenuated', 'breakable', 'brittle', 'bubbly', 'capillary', 'cheap-jack', 'chimerical', 'cirrose', 'cirrous'],
    'gossip': ['paul pry', 'peeping tom', 'a tale-bearing animal', 'account', 'ace', 'amigo', 'associate', 'babble', 'babblement', 'back-fence gossip', 'banter', 'bavardage'],
    'gothic': ['neanderthal', 'philistine', 'victorian', 'animal', 'antediluvian', 'antiquated', 'antique', 'archaic', 'barbarian', 'barbaric', 'barbarous', 'baroque'],
    'gouge': ['alveolation', 'alveolus', 'auger', 'avulse', 'bandage', 'beat', 'bedazzle', 'beguile of', 'benight', 'bezel', 'bilk', 'bite'],
    'gourmet': ['brillat-savarin', 'cyrenaic', 'heliogabalus', 'lucullus', 'sardanapalus', 'amateur', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'authority', 'board-and-roomer', 'boarder'],
    'gout': ['pku', 'acidosis', 'adenoiditis', 'adrenitis', 'alkalosis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation'],
    'govern': ['administer', 'administrate', 'arrest', 'be master', 'be responsible for', 'boss', 'bridle', 'call the shots', 'call the signals', 'captain', 'carry authority', 'carry on'],
    'governess': ['abbess', 'chaperon', 'chatelaine', 'dame', 'dowager', 'duenna', 'educatress', 'first lady', 'goodwife', 'great lady', 'homemaker', 'housewife'],
    'governing': ['absolute', 'ascendant', 'at the head', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'boss', 'chief', 'clothed with authority', 'commanding', 'competent'],
    'government': ['geopolitik', 'john bull', 'kreis', 'uncle sam', 'washington', 'whitehall', 'administration', 'archbishopric', 'archdiocese', 'arrondissement', 'auspices', 'authority'],
    'governmental': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'civic', 'civil', 'constitutional', 'democratic', 'despotic', 'dictatorial'],
    'governor': ['abba', 'administrator', 'aegis', 'agent', 'air warden', 'arm guard', 'attendant', 'backstop', 'beg', 'beglerbeg', 'bey', 'buffer'],
    'gown': ['bonnet', 'boot', 'breech', 'cap', 'cloak', 'coat', 'coif', 'dress', 'duds', 'frock', 'garment', 'hat'],
    'gp': ['doctor of medicine', 'md', 'allopath', 'allopathist', 'attending physician', 'coroner', 'country doctor', 'croaker', 'doc', 'doctor', 'family doctor', 'general practitioner'],
    'grab': ['abduct', 'abduction', 'absorb', 'absorb the attention', 'annex', 'apprehend', 'apprehension', 'appropriate', 'arrest', 'arrest the thoughts', 'arrestation', 'arrogate'],
    'grabble': ['beat about', 'bring in', 'crop', 'crop herbs', 'cut', 'dig', 'feel', 'feel around', 'feel for', 'fumble', 'gather', 'gather in'],
    'grabby': ['a hog for', 'acquiring', 'acquisitive', 'all-devouring', 'all-engulfing', 'avaricious', 'avid', 'bloodsucking', 'bottomless', 'coveting', 'covetous', 'desirous'],
    'grace': ['angelus', 'atticism', 'ave', 'ave maria', 'bomfog', 'benthamism', 'christian charity', 'christian love', 'hail mary', 'kyrie eleison', 'paternoster', 'ability'],
    'graceful': ['attic', 'ciceronian', 'daedalian', 'accommodating', 'adept', 'adroit', 'aesthetic', 'aesthetically appealing', 'affable', 'agile', 'agreeable', 'apt'],
    'gracefully': ['accommodatingly', 'aesthetically', 'artistically', 'attentively', 'becomingly', 'chivalrously', 'civilly', 'complacently', 'complaisantly', 'courteously', 'courtly', 'decently'],
    'graceless': ['doric', 'all thumbs', 'awkward', 'barbarian', 'barbaric', 'barbarous', 'blunderheaded', 'blundering', 'boorish', 'bumbling', 'bungling', 'butterfingered'],
    'gracile': ['attic', 'ciceronian', 'aesthetic', 'aesthetically appealing', 'airy', 'attenuate', 'attenuated', 'attractive', 'beauteous', 'beautiful', 'boyish', 'chaste'],
    'gracious': ['bohemian', 'christian', 'christlike', 'christly', 'accommodating', 'affable', 'affectionate', 'agreeable', 'amiable', 'amicable', 'approachable', 'attentive'],
    'gracious living': ['easy street', 'affluence', 'bed of roses', 'clover', 'comfort', 'ease', 'easy circumstances', 'felicity', 'fleshpots', 'gracious life', 'happiness', 'lap of luxury'],
    'graciously': ['accommodatingly', 'affably', 'agreeably', 'amiably', 'amicably', 'attentively', 'bigheartedly', 'blissfully', 'bonhomously', 'bounteously', 'bountifully', 'cheerfully'],
    'gradation': ['indian file', 'ablaut', 'acoustic phonetics', 'array', 'articulation', 'articulatory phonetics', 'assortment', 'bank', 'betacism', 'buzz', 'categorization', 'catena'],
    'grade': ['acclivity', 'adjust', 'align', 'alphabetize', 'amount', 'analyze', 'arrange', 'array', 'ascend', 'ascent', 'assort', 'bank'],
    'graded': ['aligned', 'arranged', 'arrayed', 'assorted', 'cataloged', 'categorized', 'classified', 'composed', 'constituted', 'disposed', 'filed', 'fixed'],
    'gradient': ['bank', 'bevel', 'bezel', 'chute', 'easy slope', 'fleam', 'gentle slope', 'glacis', 'grade', 'hanging gardens', 'helicline', 'hillside'],
    'grading': ['analysis', 'arrangement', 'cataloging', 'categorization', 'classification', 'codification', 'division', 'filing', 'gradation', 'graduation', 'grouping', 'indexing'],
    'gradual': ['ambling', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'deliberate', 'dilatory', 'easy', 'even', 'faltering'],
    'graduate': ['admirable crichton', 'academic', 'adept', 'adjust', 'advance', 'aggrandize', 'alumna', 'alumnae', 'alumni', 'alumnus', 'ameliorate', 'amend'],
    'graduate school': ['academe', 'academia', 'alma mater', 'college', 'college of engineering', 'community college', 'degree-granting institution', 'four-year college', 'institute of technology', 'ivied halls', 'journalism school', 'junior college'],
    'graduation': ['advance', 'advancement', 'aggrandizement', 'baccalaureate service', 'boost', 'celebration', 'ceremonial', 'ceremony', 'commencement', 'convocation', 'elevation', 'empty formality'],
    'graft': ['abstraction', 'affix', 'anchor', 'annex', 'annexation', 'appropriation', 'attach', 'ballot-box stuffing', 'belay', 'blackmail', 'boodle', 'boodling'],
    'grafter': ['body snatcher', 'boodler', 'booster', 'chicken thief', 'con man', 'crook', 'crooked politician', 'den of thieves', 'embezzler', 'filcher', 'ganef', 'ghoul'],
    'grafting': ['embedment', 'entrance', 'graft', 'impaction', 'impactment', 'implantation', 'infixion', 'infusion', 'injection', 'inoculation', 'insertion', 'insinuation'],
    'grain': ['abrade', 'ace', 'acorn', 'aftergrass', 'animus', 'apply paint', 'aptitude', 'atom', 'atomize', 'bamboo', 'barley', 'beat'],
    'grainy': ['arenaceous', 'arenarious', 'breccial', 'brecciated', 'broken', 'bumpy', 'choppy', 'coarse', 'coarse-grained', 'corrugated', 'cross-grained', 'grained'],
    'grammar': ['abecedarium', 'abecedary', 'alphabet', 'alphabet book', 'basics', 'battledore', 'bowwow theory', 'casebook', 'choice of words', 'comparative linguistics', 'composition', 'derivation'],
    'grammar school': ['gymnasium', 'latin school', 'realgymnasium', 'realschule', 'academy', 'elementary school', 'grade school', 'graded school', 'high', 'high school', 'intermediate school', 'junior high'],
    'grammarian': ['dialectician', 'etymologer', 'etymologist', 'glossarist', 'glossographer', 'grammaticaster', 'grammatist', 'lexicographer', 'lexicologist', 'linguist', 'linguistic scholar', 'linguistic scientist'],
    'grammatic': ['adjectival', 'adverbial', 'attributive', 'conjunctive', 'copulative', 'correct', 'descriptive', 'formal', 'functional', 'glossematic', 'glottochronological', 'graphemic'],
    'grammatical': ['adjectival', 'adverbial', 'attributive', 'conjunctive', 'copulative', 'correct', 'descriptive', 'formal', 'functional', 'glossematic', 'glottochronological', 'grammatic'],
    'gramophone': ['pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer', 'crystal pickup'],
    'grand': ['babylonian', 'c-note', 'corinthian', 'g-note', 'klavier', 'steinway', 'admirable', 'advantageous', 'aggrandized', 'all-inclusive', 'apotheosized', 'aristocratic'],
    'grand mal': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'akinetic epilepsy', 'apoplexy', 'arrest', 'attack', 'autonomic epilepsy'],
    'grand slam': ['cadmean victory', 'ko', 'pyrrhic victory', 'ascendancy', 'championship', 'conquest', 'easy victory', 'goal', 'hit', 'hole', 'hole in one', 'home run'],
    'grand tour': ['aerospace medicine', 'aerospace research', 'aerospace science', 'aerospace technology', 'astronautics', 'bioastronautics', 'campaign', 'circuit', 'course', 'escape velocity', 'excursion', 'expedition'],
    'grandee': ['brahman', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'blue blood', 'count', 'daimio', 'duke', 'earl', 'esquire'],
    'grandeur': ['babylonian splendor', 'ampleness', 'amplitude', 'augustness', 'bigness', 'broadness', 'bulk', 'capaciousness', 'comprehensiveness', 'consequence', 'conspicuousness', 'copiousness'],
    'grandfather': ['father time', 'methuselah', 'nestor', 'old paar', 'centenarian', 'dotard', 'elder', 'gaffer', 'geezer', 'golden-ager', 'grampa', 'gramps'],
    'grandiloquence': ['affectation', 'aggrandizement', 'amplification', 'ballyhoo', 'big talk', 'blowing up', 'burlesque', 'caricature', 'command of language', 'dilatation', 'dilation', 'enhancement'],
    'grandiloquent': ['gongoresque', 'johnsonian', 'affected', 'aggrandized', 'amplified', 'aureate', 'ballyhooed', 'bedizened', 'big-sounding', 'bloated', 'bombastic', 'convoluted'],
    'grandiose': ['babylonian', 'corinthian', 'gongoresque', 'johnsonian', 'affected', 'ambitious', 'august', 'awe-inspiring', 'awful', 'barbaric', 'bedizened', 'big-sounding'],
    'grandly': ['consequentially', 'conspicuously', 'elaborately', 'elegantly', 'eminently', 'extravagantly', 'gloriously', 'grandiosely', 'gravely', 'greatly', 'importantly', 'imposingly'],
    'grandmother': ['beldam', 'crone', 'dame', 'dowager', 'frump', 'gammer', 'grandam', 'grandma', 'grannam', 'granny', 'great-grandmother', 'hag'],
    'grandstand': ['texas tower', 'beacon', 'belvedere', 'bleachers', 'bridge', 'conning tower', 'gallery', 'gazebo', 'hot dog', 'lighthouse', 'lookout', 'loophole'],
    'grange': ['arable land', 'barnyard', 'barton', 'cattle ranch', 'chicken farm', 'collective farm', 'cotton plantation', 'croft', 'dairy farm', 'demesne', 'demesne farm', 'dry farm'],
    'granite': ['aa', 'abyssal rock', 'adamant', 'basalt', 'bedrock', 'block lava', 'bone', 'brash', 'breccia', 'brick', 'cement', 'concrete'],
    'granny': ['methuselah', 'antediluvian', 'antique', 'back number', 'beldam', 'conservative', 'crone', 'dad', 'dame', 'dodo', 'dowager', 'elder'],
    'grant': ['ok', 'accede to', 'accept', 'accommodation', 'accord', 'accord to', 'accordance', 'acknowledge', 'administer', 'admit', 'admit everything', 'admit exceptions'],
    'granted': ['god-given', 'accepted', 'accorded', 'accounted as', 'acknowledged', 'admitted', 'affirmed', 'alleged', 'allowed', 'approved', 'assumed', 'assumptive'],
    'granting': ['accommodation', 'accordance', 'admitting', 'admitting that', 'allowing', 'allowing that', 'award', 'awarding', 'bestowal', 'bestowment', 'communication', 'concession'],
    'grantor': ['maecenas', 'santa claus', 'almoner', 'almsgiver', 'angel', 'assignor', 'awarder', 'backer', 'bestower', 'cheerful giver', 'conferrer', 'consignor'],
    'granular': ['arenaceous', 'arenarious', 'atomic', 'breccial', 'brecciated', 'coarse', 'coarse-grained', 'comminuted', 'corpuscular', 'cross-grained', 'embryonic', 'evanescent'],
    'granulate': ['abrade', 'atomize', 'beat', 'boss', 'bray', 'break up', 'brecciate', 'cake', 'candy', 'cicatrize', 'close up', 'coarsen'],
    'granulated': ['arenaceous', 'arenarious', 'backed', 'breccial', 'brecciated', 'broken', 'bumpy', 'calcified', 'callous', 'calloused', 'case-hardened', 'choppy'],
    'granule': ['ace', 'atom', 'bit', 'breccia', 'dab', 'debris', 'detritus', 'dole', 'dot', 'dram', 'dribble', 'driblet'],
    'grapeshot': ['ball', 'bar shot', 'bird shot', 'buckshot', 'bullet', 'cannon shot', 'cannonball', 'case shot', 'crossbar shot', 'duck shot', 'dumdum bullet', 'expanding bullet'],
    'grapevine': ['adviser', 'algae', 'announcer', 'annunciator', 'authority', 'autophyte', 'bean', 'bracken', 'brown algae', 'bruit', 'bush telegraph', 'buzz'],
    'graph': ['alphabetic character', 'black and white', 'blueprint', 'brouillon', 'cartoon', 'catalog', 'catalogue raisonne', 'character', 'charcoal', 'charcoal drawing', 'chart', 'chiaroscuro'],
    'graphemic': ['abecedarian', 'allographic', 'alphabetic', 'capital', 'descriptive', 'glottochronological', 'grammatic', 'ideographic', 'lettered', 'lexicographic', 'lexicological', 'lexicostatistical'],
    'graphic': ['accurate', 'apish', 'autograph', 'autographic', 'calligraphic', 'chirographic', 'clear', 'clear-cut', 'cogent', 'compelling', 'convincing', 'cursive'],
    'graphic arts': ['abstract art', 'albertype', 'art', 'art form', 'artist', 'arts and crafts', 'arts of design', 'book printing', 'calligraphy', 'cave art', 'ceramics', 'chromotypography'],
    'graphically': ['ardently', 'descriptively', 'effectively', 'eloquently', 'expressively', 'faithfully', 'fervently', 'fluently', 'forcefully', 'glibly', 'glowingly', 'impressively'],
    'grapple': ['abduct', 'adhere to', 'affix', 'anchor', 'annex', 'attach', 'battle', 'bear hug', 'belay', 'bite', 'box', 'brawl'],
    'grapple with': ['a outrance', 'antagonize', 'bandy with', 'battle', 'battle it out', 'beat against', 'beat up against', 'box', 'brawl', 'breast the wave', 'broil', 'buck'],
    'grasp': ['abduct', 'absorb', 'accept', 'adhere', 'adhere to', 'agglomerate', 'appreciate', 'apprehend', 'apprehension', 'assimilate', 'awareness', 'be acquainted with'],
    'grasping': ['a hog for', 'acquiring', 'acquisitive', 'acquisitiveness', 'all-devouring', 'all-engulfing', 'ambitious for self', 'autistic', 'avarice', 'avaricious', 'avariciousness', 'avid'],
    'grass': ['bengal grass', 'det', 'dmt', 'english rye grass', 'italian rye grass', 'kentucky bluegrass', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'aftergrass'],
    'grass roots': ['agricultural region', 'arable land', 'beginning', 'black belt', 'citrus belt', 'commencement', 'conception', 'corn belt', 'cotton belt', 'countryside', 'derivation', 'dust bowl'],
    'grasshopper': ['broad jumper', 'bucking bronco', 'buckjumper', 'cicada', 'cicala', 'cricket', 'dog-day cicada', 'feckless', 'flea', 'frog', 'gazelle', 'goat'],
    'grassland': ['acres', 'agricultural region', 'alkali flat', 'alluvial plain', 'alluvion', 'alluvium', 'arable land', 'barnyard', 'barton', 'basin', 'black belt', 'bottomland'],
    'grassy': ['aestival', 'beryl-green', 'berylline', 'blue-green', 'bluish-green', 'caespitose', 'chartreuse', 'chloranemic', 'chlorine', 'chlorotic', 'citrine', 'citrinous'],
    'grate': ['ablate', 'abrade', 'abrase', 'afflict', 'aggravate', 'agonize', 'ail', 'andiron', 'annoy', 'arabesque', 'atomize', 'bark'],
    'grate on': ['chafe', 'exacerbate', 'fret', 'gall', 'grate', 'gravel', 'grit', 'irritate', 'jangle the nerves', 'jar on', 'lacerate the ear', 'offend the ear'],
    'grated': ['barred', 'branny', 'cancellated', 'chalklike', 'chalky', 'comminute', 'comminuted', 'crossbarred', 'crushed', 'detrital', 'detrited', 'disintegrated'],
    'grateful': ['acceptable', 'acknowledging', 'affable', 'agreeable', 'amiable', 'amicable', 'appreciative', 'beholden', 'blissful', 'cheerful', 'cognizant of', 'comforting'],
    'grater': ['cheese grater', 'comminutor', 'crusher', 'granulator', 'grinder', 'kominuter', 'levigator', 'masher', 'mill', 'millstone', 'mortar and pestle', 'nutmeg grater'],
    'gratification': ['amusement', 'animal pleasure', 'bodily pleasure', 'boodle', 'bribe', 'bribe money', 'carnal delight', 'coddling', 'comfort', 'compensation', 'content', 'contentment'],
    'gratify': ['achieve inner harmony', 'allay', 'appease', 'assuage', 'baby', 'board', 'bread', 'cater to', 'cheer', 'coddle', 'compensate', 'content'],
    'gratifying': ['acceptable', 'affable', 'agreeable', 'amiable', 'amicable', 'blissful', 'cheerful', 'compatible', 'complaisant', 'congenial', 'cordial', 'delighting'],
    'grating': ['abrasion', 'absonant', 'ajar', 'andiron', 'annoying', 'antagonistic', 'antipathetic', 'arabesque', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance'],
    'gratis': ['as a gift', 'as our guest', 'charitable', 'complimentary', 'costless', 'eleemosynary', 'expenseless', 'for free', 'for love', 'for nothing', 'for the asking', 'free'],
    'gratuitous': ['god-given', 'accorded', 'aimless', 'allowed', 'amorphous', 'arbitrary', 'autonomous', 'baseless', 'bestowed', 'biggety', 'bluff', 'bottomless'],
    'gratuity': ['trinkgeld', 'balance', 'bonus', 'boodle', 'bounty', 'bribe', 'bribe money', 'complimentariness', 'consideration', 'costlessness', 'dividend', 'donative'],
    'gravamen': ['axiom', 'bench mark', 'best part', 'better part', 'body', 'bulk', 'cardinal point', 'center', 'chief thing', 'climax', 'core', 'cornerstone'],
    'grave': ['abject', 'abominable', 'acute', 'afflictive', 'agonizing', 'annihilation', 'arch', 'aristocratic', 'arrant', 'assemble', 'atrocious', 'august'],
    'grave robber': ['body snatcher', 'booster', 'chicken thief', 'con man', 'crook', 'den of thieves', 'embezzler', 'filcher', 'ganef', 'ghoul', 'grafter', 'jewel thief'],
    'gravel': ['tarmac', 'tarvia', 'asphalt', 'bitumen', 'bituminous macadam', 'blacktop', 'breccia', 'brick', 'cement', 'chafe', 'cobble', 'cobblestone'],
    'gravelly': ['arenaceous', 'arenarious', 'breccial', 'brecciated', 'corrugated', 'cragged', 'craggy', 'crinkled', 'crumpled', 'crystal', 'crystalline', 'grainy'],
    'gravely': ['bleakly', 'decorously', 'demurely', 'dismally', 'drearily', 'earnestly', 'formally', 'funereally', 'gloomily', 'grandly', 'grimly', 'heavily'],
    'graven': ['anaglyphic', 'anaglyptic', 'anastatic', 'carved', 'ceroplastic', 'chased', 'confirmed', 'creased', 'cut', 'deep-dyed', 'deep-engraven', 'deep-fixed'],
    'gravestone': ['arch', 'barrow', 'boundary stone', 'brass', 'bust', 'cairn', 'cenotaph', 'column', 'cromlech', 'cross', 'cup', 'cyclolith'],
    'gravid': ['anticipating', 'big', 'big with child', 'big-laden', 'breeding', 'carrying', 'carrying a fetus', 'expectant', 'expecting', 'gestating', 'gone', 'great'],
    'gravitate': ['bend to', 'bias', 'cascade', 'cataract', 'collapse', 'come down', 'conduce', 'contribute', 'crash', 'descend', 'dip down', 'dispose'],
    'gravitation': ['g suit', 'adduction', 'affinity', 'allurement', 'apogeotropism', 'attractance', 'attraction', 'attractiveness', 'attractivity', 'capillarity', 'capillary attraction', 'cascade'],
    'gravity': ['g suit', 'acuteness', 'adduction', 'affinity', 'allurement', 'apogeotropism', 'attractance', 'attraction', 'attractiveness', 'attractivity', 'augustness', 'avoirdupois'],
    'gravure': ['albertype', 'book printing', 'chromotypography', 'chromotypy', 'chromoxylography', 'collotype', 'color printing', 'electronography', 'electrostatic printing', 'graphic arts', 'halftone engraving', 'history of printing'],
    'gravy': ['colbert', 'smitane', 'soubise', 'trinkgeld', 'allemande', 'bonus', 'bonus system', 'bounty', 'bourguignonne', 'bribe', 'brown sauce', 'buried treasure'],
    'gray': ['quaker-colored', 'achromatic', 'achromic', 'acier', 'advanced', 'advanced in life', 'advanced in years', 'aged', 'along in years', 'ancient', 'anemic', 'ashen'],
    'gray eminence': ['machiavellian', 'rasputin', 'svengali', 'vip', 'access', 'bad influence', 'behind-the-scenes operator', 'big wheel', 'court', 'eminence grise', 'finagler', 'five-percenter'],
    'gray matter': ['vernunft', 'afferent neuron', 'arachnoid', 'arbor vitae', 'archipallium', 'autonomic nervous system', 'axon', 'bean', 'between brain', 'brain', 'brain stem', 'brains'],
    'graybeard': ['father time', 'methuselah', 'nestor', 'old paar', 'centenarian', 'dotard', 'elder', 'gaffer', 'geezer', 'golden-ager', 'gramps', 'grandfather'],
    'graze': ['ablate', 'abrade', 'abrase', 'attouchement', 'bark', 'batten upon', 'beak', 'board', 'bread', 'breath', 'browse', 'bruise'],
    'grazing': ['ablation', 'abrasion', 'abrasive', 'animal husbandry', 'animal rearing', 'appetite', 'attrition', 'bee culture', 'beekeeping', 'breeding', 'brushing', 'buffing'],
    'grease': ['trinkgeld', 'adulation', 'aid', 'animal oil', 'anoint', 'approach', 'beeswax', 'blandishment', 'blarney', 'blunt', 'bonus', 'boodle'],
    'grease the palm': ['approach', 'bribe', 'buy', 'buy off', 'come across', 'come across with', 'come down with', 'come through with', 'corrupt', 'cough up', 'fix', 'fork over'],
    'grease the wheels': ['aid', 'anoint', 'beeswax', 'clear the way', 'daub', 'dress', 'ease', 'embrocate', 'expedite', 'explain', 'facilitate', 'glycerolate'],
    'greasepaint': ['base', 'blackface', 'clown white', 'cold cream', 'compact', 'cosmetics', 'costume', 'drugstore complexion', 'eye shadow', 'eyebrow pencil', 'foundation', 'foundation cream'],
    'greasiness': ['downiness', 'evenness', 'fatness', 'fattiness', 'flatness', 'frictionlessness', 'glabriety', 'glabrousness', 'glossiness', 'levelness', 'lubricity', 'oiliness'],
    'greasy': ['adipose', 'blubbery', 'buttery', 'butyraceous', 'chrismal', 'chrismatory', 'fat', 'fatty', 'fawning', 'glib', 'greased', 'lardaceous'],
    'great': ['brobdingnagian', 'cyclopean', 'establishment', 'ok', 'vip', 'able', 'absolute', 'abundant', 'accomplished', 'ace', 'ace-high', 'active'],
    'great circle': ['anklet', 'aphelion', 'apogee', 'armlet', 'astronomical longitude', 'autumnal equinox', 'band', 'belt', 'bracelet', 'celestial equator', 'celestial longitude', 'celestial meridian'],
    'great deal': ['a deal', 'a great deal', 'a lot', 'abundantly', 'as all creation', 'as all get-out', 'batch', 'beaucoup', 'considerable', 'considerably', 'deal', 'ever so'],
    'great man': ['establishment', 'vip', 'baron', 'big gun', 'big man', 'big name', 'bigwig', 'brass', 'brass hat', 'celebrity', 'constellation', 'cynosure'],
    'great mother': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'greater': ['a cut above', 'above', 'ahead', 'ascendant', 'better', 'capping', 'chosen', 'distinguished', 'eclipsing', 'eminent', 'exceeding', 'excellent'],
    'greatest': ['at the height', 'at the limit', 'best', 'champion', 'choice', 'elect', 'elite', 'extreme', 'far out', 'first-class', 'first-rate', 'for the best'],
    'greathearted': ['almsgiving', 'altruistic', 'beneficent', 'benevolent', 'big', 'bighearted', 'bold', 'bold-spirited', 'bounteous', 'bountiful', 'brave', 'charitable'],
    'greatly': ['a deal', 'a great deal', 'a lot', 'abundantly', 'as all creation', 'as all get-out', 'beaucoup', 'consequentially', 'considerable', 'considerably', 'conspicuously', 'eminently'],
    'greatness': ['accomplishment', 'ampleness', 'amplitude', 'area', 'ascendancy', 'authority', 'bigheartedness', 'bigness', 'body', 'breadth', 'broadness', 'brooding'],
    'greed': ['acedia', 'acquisitiveness', 'anger', 'autism', 'avarice', 'avariciousness', 'avaritia', 'avidity', 'avidness', 'careerism', 'covetousness', 'crapulence'],
    'greedy': ['apician', 'a hog for', 'acquiring', 'acquisitive', 'all-devouring', 'ambitious for self', 'autistic', 'avaricious', 'avid', 'bolting', 'bottomless', 'careerist'],
    'greek': ['aesopian language', 'babel', 'affiliate', 'argot', 'associate', 'babble', 'belonger', 'brother', 'cant', 'card-carrier', 'card-carrying member', 'cardholder'],
    'green': ['astroturf', 'a novice at', 'a stranger to', 'acerb', 'acerbate', 'acerbic', 'acescent', 'adolescent', 'aestival', 'alive', 'amateur', 'amateurish'],
    'green light': ['john hancock', 'ok', 'roman candle', 'acceptance', 'admission', 'affirmance', 'affirmation', 'aid to navigation', 'alarm', 'allowance', 'amber light', 'approbation'],
    'greengrocer': ['baker', 'bookdealer', 'bookseller', 'butcher', 'chandler', 'clothing merchant', 'confectioner', 'draper', 'drysalter', 'fishmonger', 'fishwife', 'florist'],
    'greenhorn': ['abecedarian', 'alphabetarian', 'apprentice', 'arriviste', 'articled clerk', 'babe', 'baby', 'beginner', 'boob', 'boot', 'catechumen', 'chump'],
    'greenhouse': ['alcove', 'arbor', 'bower', 'cloche', 'cold frame', 'conservatory', 'coolhouse', 'forcing bed', 'forcing house', 'forcing pit', 'gazebo', 'glasshouse'],
    'greenness': ['acerbity', 'acescency', 'acidity', 'acidulousness', 'adolescence', 'agnosticism', 'amateurishness', 'amateurism', 'blankmindedness', 'brand-newness', 'callowness', 'coarseness'],
    'greenroom': ['acting area', 'antechamber', 'anteroom', 'apron', 'apron stage', 'audience chamber', 'backstage', 'band shell', 'bandstand', 'board', 'bridge', 'coulisse'],
    'greens': ['irish potato', 'kraut', 'aubergine', 'beans', 'botany', 'cabbage', 'eggplant', 'flora', 'flowerage', 'greenery', 'herbage', 'legumes'],
    'greeny': ['apprentice', 'babe', 'baby', 'beginner', 'boob', 'catechumen', 'chump', 'cinch', 'credulous person', 'cull', 'dabbler', 'deb'],
    'greet': ['accost', 'address', 'apostrophize', 'appeal to', 'approach', 'bawl', 'bespeak', 'bid good day', 'bid good morning', 'blubber', 'boohoo', 'bow to'],
    'greeting': ['parthian shot', 'accost', 'address', 'affirmation', 'allegation', 'answer', 'apostrophe', 'assertion', 'averment', 'best wishes', 'bob', 'bow'],
    'gregarious': ['affable', 'all jaw', 'amiable', 'candid', 'chatty', 'civil', 'clubbable', 'clubbish', 'clubby', 'communicative', 'companionable', 'companionate'],
    'gremlin': ['ariel', 'befind', 'corrigan', 'dingbelle', 'fifinella', 'finnbeara', 'hob', 'hobgoblin', 'mab', 'oberon', 'puck', 'titania'],
    'grenade': ['aerial bomb', 'antipersonnel bomb', 'bomb', 'bombshell', 'carcass', 'concussion grenade', 'depth bomb', 'depth charge', 'fire bomb', 'gas grenade', 'hand grenade', 'incendiary bomb'],
    'grenadier': ['zouave', 'bean pole', 'bersagliere', 'carabineer', 'chasseur', 'dogface', 'doughfoot', 'expert rifleman', 'foot soldier', 'footslogger', 'fusileer', 'giant'],
    'grey': ['quaker-colored', 'achromatic', 'achromic', 'acier', 'advanced', 'advanced in life', 'advanced in years', 'aged', 'along in years', 'ancient', 'anemic', 'ashen'],
    'greyhound': ['antelope', 'arrow', 'blue darter', 'blue streak', 'cannonball', 'courser', 'dart', 'eagle', 'electricity', 'express train', 'flash', 'gazelle'],
    'grid': ['acting area', 'andiron', 'apron', 'apron stage', 'arabesque', 'backstage', 'band shell', 'bandstand', 'basketry', 'basketwork', 'black spot', 'bloom'],
    'griddle': ['andiron', 'bake', 'barbecue', 'baste', 'blanch', 'boil', 'braise', 'brew', 'broil', 'brown', 'chain', 'coal tongs'],
    'gridiron': ['acting area', 'andiron', 'apron', 'apron stage', 'arabesque', 'archery ground', 'athletic field', 'backstage', 'badminton court', 'band shell', 'bandstand', 'baseball field'],
    'grief': ['accident', 'ache', 'aching', 'aching heart', 'adversity', 'affliction', 'agony', 'agony of mind', 'anguish', 'apologies', 'attrition', 'ayenbite of inwit'],
    'grief stricken': ['aggrieved', 'anguished', 'careworn', 'doleful', 'dolorous', 'dumb with grief', 'griefful', 'grieved', 'grievous', 'in grief', 'lamentable', 'lugubrious'],
    'grievance': ['abomination', 'affliction', 'affront', 'allegation', 'atrocity', 'bad', 'bane', 'beef', 'beefing', 'befoulment', 'bellyache', 'bellyaching'],
    'grieve': ['ache', 'affect', 'afflict', 'affront', 'aggrieve', 'agonize', 'anguish', 'barb the dart', 'bear', 'bemoan', 'bewail', 'bleed'],
    'grieved': ['aching', 'aggrieved', 'anguished', 'bleeding', 'bruised', 'careworn', 'cut', 'doleful', 'dolorous', 'dumb with grief', 'grief-stricken', 'griefful'],
    'grievous': ['abominable', 'acute', 'affecting', 'afflictive', 'aggrieved', 'anguished', 'appalling', 'arrant', 'atrocious', 'awful', 'base', 'beastly'],
    'grievously': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'brokenheartedly', 'calamitously', 'cataclysmically', 'catastrophically'],
    'grill': ['andiron', 'automat', 'bake', 'barbecue', 'baste', 'beanery', 'bistro', 'blanch', 'boil', 'braise', 'brew', 'broil'],
    'grille': ['arabesque', 'basketry', 'basketwork', 'bay', 'bay window', 'bow window', 'cancellation', 'casement', 'casement window', 'cross-hatching', 'crossing-out', 'fan window'],
    'grilling': ['ardent', 'baking', 'barbecuing', 'basting', 'blistering', 'boiling', 'braising', 'brewing', 'broil', 'broiling', 'burning', 'burning hot'],
    'grim': ['spartan', 'spartanic', 'adamant', 'adamantine', 'affording no hope', 'alarming', 'anguished', 'anxious', 'apathetic', 'appalling', 'astounding', 'astringent'],
    'grimace': ['ache', 'agonize', 'ail', 'anguish', 'blanch', 'blench', 'bob', 'bobble', 'bounce', 'bump', 'contort', 'declaim'],
    'grimalkin': ['cheshire cat', 'chinchilla cat', 'jezebel', 'maltese cat', 'alley cat', 'beldam', 'bitch-kitty', 'blue cat', 'calico cat', 'cat', 'feline', 'fury'],
    'grime': ['begrime', 'bemire', 'bemud', 'besmoke', 'besoil', 'dirt', 'dirty', 'dirty up', 'dust', 'filth', 'foul', 'mire'],
    'grimly': ['adamantly', 'appallingly', 'austerely', 'banefully', 'bleakly', 'decorously', 'demurely', 'direly', 'dismally', 'dourly', 'dreadfully', 'drearily'],
    'grimy': ['besmirched', 'blotchy', 'dingy', 'dirty', 'dusty', 'fuliginous', 'grubby', 'grungy', 'messy', 'miry', 'muddy', 'murky'],
    'grin': ['beam', 'bright smile', 'broad grin', 'crack a smile', 'ear-to-ear grin', 'gleaming smile', 'glowing smile', 'grinning', 'idiotic grin', 'sardonic grin', 'simper', 'smile'],
    'grind': ['ablate', 'abrade', 'abrase', 'aculeate', 'acuminate', 'afflict', 'agonize', 'ail', 'application', 'atomize', 'badger', 'barb'],
    'grinder': ['blt', 'dagwood sandwich', 'sloppy joe', 'swiss cheese sandwich', 'baby tooth', 'bacon-lettuce-tomato sandwich', 'bicuspid', 'bucktooth', 'canape', 'canine', 'cheese grater', 'cheeseburger'],
    'grinding': ['ablation', 'ablative', 'abradant', 'abrasion', 'abrasive', 'absolute', 'absolutist', 'absolutistic', 'application', 'arbitrary', 'aristocratic', 'arrogant'],
    'gringo': ['uitlander', 'alien', 'barbarian', 'deracine', 'displaced person', 'emigre', 'exile', 'foreign devil', 'foreigner', 'outlander', 'outlaw', 'outsider'],
    'grinning': ['banter', 'bantering', 'beam', 'booing', 'bright smile', 'broad grin', 'catcalling', 'chaffing', 'derision', 'derisive', 'derisory', 'ear-to-ear grin'],
    'grip': ['abduct', 'ability', 'absorb', 'absorb the attention', 'access', 'acerbity', 'acidity', 'acridity', 'acrimony', 'address', 'adeptness', 'adhere to'],
    'gripe': ['abduct', 'ache', 'aching', 'adhere to', 'afflict', 'aggravate', 'agonize', 'ail', 'air a grievance', 'angina', 'annoy', 'backache'],
    'grippe': ['african lethargy', 'asiatic cholera', 'asiatic flu', 'chagres fever', 'german measles', 'haverhill fever', 'hong kong flu', 'acute articular rheumatism', 'acute bronchitis', 'adenoiditis', 'ague', 'alkali disease'],
    'gripped': ['arrested', 'besotted', 'caught', 'charmed', 'enchanted', 'enthralled', 'fascinated', 'fixated', 'fixed', 'held', 'hung-up', 'hypnotized'],
    'gripping': ['absorbing', 'arresting', 'attractive', 'clinging', 'compelling', 'compulsive', 'consuming', 'driving', 'enchanting', 'engaging', 'engrossing', 'enthralling'],
    'grisly': ['abhorrent', 'abominable', 'appalling', 'astounding', 'awe-inspiring', 'awesome', 'awful', 'blue', 'cadaverous', 'corpselike', 'deadly', 'deathlike'],
    'grit': ['air pollution', 'attritus', 'backbone', 'bottle', 'bottom', 'bran', 'bravery', 'breccia', 'chafe', 'chutzpah', 'cosmic dust', 'courage'],
    'gritty': ['abrasive', 'arenaceous', 'arenarious', 'arenose', 'brave', 'breccial', 'brecciated', 'bulldoggish', 'coarse', 'coarse-grained', 'courageous', 'craggy'],
    'grizzle': ['quaker-colored', 'acier', 'ashen', 'ashy', 'bay', 'bayard', 'besnow', 'blanch', 'bleach', 'buckskin', 'calico pony', 'canescent'],
    'grizzled': ['quaker-colored', 'acier', 'argent', 'argentine', 'ashen', 'ashy', 'canescent', 'chalky', 'cinereous', 'cinerous', 'cretaceous', 'dapple'],
    'grizzly': ['quaker-colored', 'acier', 'argent', 'argentine', 'ashen', 'ashy', 'canescent', 'chalky', 'cinereous', 'cinerous', 'cretaceous', 'dapple'],
    'groan': ['air a grievance', 'bawl', 'beef', 'beefing', 'belch', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'blare', 'blat', 'bray'],
    'groat': ['ace', 'air pollution', 'atom', 'attritus', 'bawbee', 'bit', 'bran', 'cosmic dust', 'crown', 'crumb', 'crumble', 'dab'],
    'grocer': ['baker', 'bookdealer', 'bookseller', 'butcher', 'chandler', 'clothing merchant', 'confectioner', 'draper', 'drysalter', 'fishmonger', 'fishwife', 'florist'],
    'groceries': ['baked goods', 'canned foods', 'canned goods', 'commissariat', 'commissary', 'dehydrated foods', 'food items', 'food supply', 'fresh foods', 'frozen foods', 'green goods', 'grocery'],
    'grocery': ['appetizing store', 'bakery', 'bakeshop', 'bodega', 'butcher shop', 'creamery', 'dairy', 'deli', 'delicatessen', 'food shop', 'food store', 'fruit stand'],
    'grog': ['john barleycorn', 'alcohol', 'alcoholic beverage', 'alcoholic drink', 'aqua vitae', 'ardent spirits', 'beverage', 'booze', 'brew', 'drink', 'firewater', 'hard liquor'],
    'groggy': ['abeyant', 'addled', 'apathetic', 'baffled', 'bedazzled', 'befuddled', 'benumbed', 'bewildered', 'cataleptic', 'catatonic', 'confounded', 'confused'],
    'grogshop': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'boozer', 'bucket shop', 'cabaret', 'cafe'],
    'groin': ['abutment', 'anchorage', 'anchorage ground', 'arc-boutant', 'arch dam', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier', 'basin'],
    'grommet': ['air hole', 'annulet', 'armhole', 'blowhole', 'bullet-hole', 'bunghole', 'circlet', 'cringle', 'deadeye', 'eye', 'eyelet', 'gasket'],
    'groom': ['adapt', 'apprentice', 'bed', 'bed down', 'blushing bride', 'break', 'break in', 'breaker', 'breed', 'breeder', 'bride', 'bridegroom'],
    'groomed': ['all ready', 'all set', 'armed', 'armed and ready', 'booted and spurred', 'briefed', 'coached', 'cocked', 'equipped', 'familiarized', 'good and ready', 'in arms'],
    'grooming': ['apprenticeship', 'basic training', 'breaking', 'breeding', 'conditioning', 'cultivation', 'development', 'discipline', 'drill', 'drilling', 'exercise', 'fetching-up'],
    'groove': ['abysm', 'abyss', 'alameda', 'arroyo', 'ascender', 'autolithograph', 'back', 'bastard type', 'be a printmaker', 'beard', 'beat', 'beaten path'],
    'groove on': ['adore', 'appreciate', 'bask in', 'be pleased with', 'delight in', 'derive pleasure from', 'devour', 'eat up', 'enjoy', 'feast on', 'freak out on', 'get high on'],
    'grooved': ['canaliculate', 'canaliculated', 'carved', 'chamfered', 'channeled', 'corduroy', 'corduroyed', 'corrugate', 'corrugated', 'costate', 'creased', 'crimped'],
    'groovy': ['ok', 'ace-high', 'bad', 'bang-up', 'bonzer', 'boss', 'bully', 'but good', 'cool', 'corking', 'crackerjack', 'dandy'],
    'grope': ['agonize over', 'be at sea', 'be uncertain', 'beat about', 'doubt', 'examine', 'explore', 'feel', 'feel around', 'feel for', 'feel unsure', 'fish'],
    'groping': ['analytic', 'awkward', 'blankminded', 'callow', 'dumb', 'empty', 'empty-headed', 'examinational', 'examinatorial', 'examining', 'explorational', 'explorative'],
    'gross': ['adamic', 'boeotian', 'circean', 'doric', 'rabelaisian', 'abhorrent', 'abject', 'abominable', 'absolute', 'adipose', 'afford', 'aggregate'],
    'gross income': ['avails', 'base pay', 'box office', 'commissions', 'compensation', 'credit', 'credits', 'dismissal wage', 'disposable income', 'dividend', 'dividends', 'earned income'],
    'gross national product': ['gnp', 'barter economy', 'capitalistic economy', 'collectivized economy', 'consumer economy', 'diversified economy', 'economic system', 'economy', 'farm economy', 'free-enterprise economy', 'handicraft economy', 'hot economy'],
    'grossly': ['abjectly', 'abominably', 'arrantly', 'atrociously', 'awfully', 'basely', 'bestially', 'brutally', 'coarsely', 'contemptibly', 'crassly', 'crudely'],
    'grotesque': ['gothic', 'aberrant', 'abnormal', 'absurd', 'anomalous', 'antic', 'art object', 'bandy', 'bandy-legged', 'baroque', 'beyond belief', 'bizarre'],
    'grotto': ['abri', 'antre', 'bunker', 'burrow', 'cave', 'cavern', 'cove', 'dugout', 'foxhole', 'grot', 'hole', 'lair'],
    'grouch': ['tartar', 'air a grievance', 'bear', 'beef', 'bellyache', 'bellyacher', 'bitch', 'clamor', 'complain', 'complainant', 'complainer', 'crab'],
    'grouchy': ['beefing', 'bellyaching', 'bitching', 'complaining', 'complaintful', 'crabbing', 'crabby', 'cranky', 'croaking', 'disappointed', 'discontented', 'disgruntled'],
    'ground': ['bassalia', 'a priori principle', 'abyss', 'abyssal zone', 'acres', 'affirmation', 'agora', 'air brush', 'airspace', 'alluvion', 'alluvium', 'ambition'],
    'ground floor': ['anticipation', 'beginnings', 'clerestory', 'earliness', 'early hour', 'early stage', 'entresol', 'first crack', 'first floor', 'first stage', 'flat', 'floor'],
    'ground swell': ['billow', 'bore', 'breakers', 'chop', 'choppiness', 'chopping sea', 'coalition', 'comb', 'comber', 'communist front', 'dirty water', 'eagre'],
    'groundbreaker': ['ancestor', 'announcer', 'antecedent', 'avant-garde', 'bellwether', 'buccinator', 'bushwhacker', 'explorer', 'forebear', 'foregoer', 'forerunner', 'front runner'],
    'grounded': ['aground', 'anchored', 'beached', 'castaway', 'caught', 'chained', 'fast', 'fastened', 'fixed', 'foundered', 'held', 'high and dry'],
    'grounded on': ['absolute', 'adducible', 'admissible', 'attestative', 'attestive', 'authentic', 'based on', 'bolstered', 'borne', 'braced', 'buttressed', 'certain'],
    'groundhog': ['cape polecat', 'ape', 'bar', 'bear', 'cavy', 'chimp', 'chimpanzee', 'coon', 'digger', 'dredge', 'dredger', 'driller'],
    'groundless': ['baseless', 'bottomless', 'built on sand', 'chimerical', 'empty', 'flimsy', 'gratuitous', 'hypothetical', 'idle', 'ill-founded', 'illusory', 'imaginary'],
    'groundling': ['adamite', 'babbitt', 'philistine', 'arriviste', 'attender', 'audience', 'auditory', 'being', 'body', 'boor', 'bounder', 'bourgeois'],
    'grounds': ['astroturf', 'acres', 'alluvion', 'alluvium', 'antecedents', 'artificial turf', 'ash', 'base', 'basement', 'basis', 'basis for belief', 'bearing wall'],
    'groundwork': ['arrangement', 'base', 'basement', 'basic training', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock', 'bottom', 'briefing', 'clearing the decks'],
    'group': ['american', 'art nouveau', 'ashcan school', 'barbizon', 'bauhaus', 'bolognese', 'british', 'bund', 'cobra', 'dutch', 'flemish', 'fontainebleau'],
    'group therapy': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'assertiveness training', 'behavior modification', 'behavior therapy', 'bioenergetics', 'biofeedback', 'confrontation therapy'],
    'grouped': ['aligned', 'arranged', 'arrayed', 'assorted', 'cataloged', 'categorized', 'classified', 'composed', 'constituted', 'disposed', 'filed', 'fixed'],
    'grouping': ['bund', 'rochdale cooperative', 'age group', 'alliance', 'analysis', 'appraisal', 'arrangement', 'assemblage', 'assessment', 'association', 'assortment', 'atmosphere'],
    'grouse': ['cornish hen', 'air a grievance', 'beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'broiler', 'caille', 'canard', 'caneton'],
    'grousing': ['beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'complaining', 'complaint', 'complaintful', 'crabbing', 'crabby', 'cranky'],
    'grove': ['batch', 'bocage', 'bosk', 'bottom', 'bottom glade', 'bottoms', 'bunch', 'clump', 'cluster', 'coppice', 'copse', 'crop'],
    'grovel': ['apple-polish', 'be promiscuous', 'bend', 'bend the knee', 'bend the neck', 'bend to', 'bootlick', 'bow', 'bow and scrape', 'bow down', 'bow to', 'chase women'],
    'groveler': ['apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bootlick', 'bootlicker', 'brown-nose', 'brownie', 'clawback', 'courtier', 'creature', 'cringer'],
    'groveling': ['abject', 'accumbent', 'apple-polishing', 'ass-kissing', 'backscratching', 'beggarly', 'bootlicking', 'brown-nosing', 'couchant', 'couche', 'cowering', 'crawling'],
    'grovelling': ['abject', 'apple-polishing', 'ass-kissing', 'base', 'brown-nosing', 'cowering', 'crawling', 'cringing', 'fawning', 'kowtowing', 'low', 'mean'],
    'grow': ['accrue', 'accumulate', 'advance', 'age', 'appreciate', 'arise', 'attain majority', 'balloon', 'be changed', 'be converted into', 'bear fruit', 'become'],
    'grow from': ['accrue from', 'arise from', 'be contingent on', 'be due to', 'bud from', 'come from', 'come out of', 'depend on', 'derive from', 'descend from', 'emanate from', 'emerge from'],
    'grow old': ['age', 'antiquate', 'become extinct', 'become obsolete', 'cheat the undertaker', 'date', 'decline', 'dodder', 'fade', 'fail', 'fossilize', 'fust'],
    'grow together': ['adhere', 'agglomerate', 'bunch', 'clasp', 'cleave', 'clinch', 'cling', 'cling to', 'clot', 'cluster', 'coagulate', 'cohere'],
    'grow up': ['age', 'arise', 'ascend', 'attain majority', 'bear fruit', 'bloom', 'blossom', 'blow', 'brew', 'bring to maturity', 'burgeon', 'come of age'],
    'grower': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter'],
    'growing': ['architecture', 'assembly', 'blooming', 'blossoming', 'budding', 'building', 'burgeoning', 'callow', 'casting', 'composition', 'construction', 'conversion'],
    'growl': ['air a grievance', 'bark', 'bawl', 'beef', 'belch', 'bellow', 'bellyache', 'bitch', 'blare', 'blat', 'blubber', 'boom'],
    'grown': ['adult', 'assembled', 'big', 'blooming', 'blossoming', 'brought about', 'budding', 'built', 'burgeoning', 'cast', 'caused', 'constructed'],
    'grown up': ['adult', 'big', 'blooming', 'blossoming', 'budding', 'burgeoning', 'crescent', 'developed', 'florescent', 'flourishing', 'flowering', 'full-fledged'],
    'growth': ['about-face', 'abscess', 'access', 'accession', 'accomplishment', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'advancement'],
    'grub': ['accumulate', 'amass', 'assemble', 'aurelia', 'beast of burden', 'beat', 'bore', 'bring together', 'burrow', 'caterpillar', 'chow', 'chrysalis'],
    'grub up': ['accumulate', 'amass', 'assemble', 'avulse', 'bring together', 'collect', 'cull', 'cut out', 'deracinate', 'dig out', 'dig up', 'disentangle'],
    'grubby': ['beat-up', 'bedraggled', 'beset', 'black', 'blowzy', 'careless', 'chintzy', 'dilapidated', 'dingy', 'dirty', 'drabbletailed', 'draggled'],
    'grubstake': ['angel', 'back', 'backing', 'bankroll', 'capitalization', 'capitalize', 'deficit financing', 'finance', 'financial backing', 'financial support', 'financing', 'fund'],
    'grudge': ['animosity', 'animus', 'antipathy', 'aversion', 'balk at', 'be unwilling', 'begrudge', 'bitterness', 'bone to pick', 'cast envious eyes', 'close the hand', 'covet'],
    'grudging': ['apathetic', 'backward', 'balking', 'balky', 'begrudging', 'covetous', 'desirous of', 'dilatory', 'envious', 'envying', 'green with envy', 'indifferent'],
    'gruel': ['albumen', 'batter', 'bonnyclabber', 'breakfast food', 'butter', 'cambric tea', 'cereal', 'clabber', 'cobweb', 'cornflakes', 'cornstarch', 'cream'],
    'grueling': ['herculean', 'annoying', 'arduous', 'backbreaking', 'besetting', 'bothersome', 'burdensome', 'castigatory', 'chastening', 'chastising', 'corrective', 'crushing'],
    'gruesome': ['abominable', 'appalling', 'astounding', 'awe-inspiring', 'awesome', 'awful', 'baleful', 'blue', 'cadaverous', 'corpselike', 'daunting', 'deadly'],
    'gruff': ['abrupt', 'acerb', 'acid', 'acrimonious', 'aggressive', 'bad-tempered', 'bearish', 'beastly', 'biting', 'bluff', 'blunt', 'boorish'],
    'grum': ['beetle-browed', 'black', 'black-browed', 'brooding', 'broody', 'chapfallen', 'crestfallen', 'dark', 'dejected', 'dour', 'dumpish', 'frowning'],
    'grumble': ['air a grievance', 'beef', 'belch', 'bellyache', 'bitch', 'blare', 'blat', 'boom', 'booming', 'brawl', 'bray', 'burr'],
    'grumbler': ['bellyacher', 'complainant', 'complainer', 'crab', 'crank', 'croaker', 'crosspatch', 'faultfinder', 'frondeur', 'griper', 'grouch', 'grouser'],
    'grumbling': ['beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'boom', 'booming', 'complaining', 'complaint', 'complaintful', 'crabbing'],
    'grume': ['devonshire cream', 'rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'antibody', 'antigen', 'arterial blood', 'blood', 'blood bank', 'blood cell'],
    'grungy': ['dingy', 'dirty', 'dusty', 'grimy', 'grubby', 'messy', 'miry', 'muddy', 'scruffy', 'slovenly', 'smirchy', 'smoky'],
    'grunt': ['zouave', 'air a grievance', 'animal noise', 'bark', 'barking', 'bawl', 'beef', 'bellow', 'bellyache', 'bersagliere', 'birdcall', 'bitch'],
    'guarantee': ['bible oath', 'and candle', 'arm', 'armor', 'assert under oath', 'assurance', 'assure', 'attest', 'avouch', 'avouchment', 'avow', 'back'],
    'guaranteed': ['affianced', 'ascertained', 'assured', 'attested', 'betrothed', 'bound', 'certain', 'certified', 'committed', 'compromised', 'contracted', 'covered'],
    'guaranteed annual income': ['adc', 'medicaid', 'medicare', 'aid', 'alimony', 'allotment', 'allowance', 'annuity', 'assistance', 'bounty', 'cradle-to-grave security', 'depletion allowance'],
    'guarantor': ['angel', 'approver', 'backer', 'bailsman', 'bondsman', 'certifier', 'confirmer', 'cosignatory', 'cosigner', 'endorser', 'godfather', 'godparent'],
    'guaranty': ['assurance', 'assure', 'attest', 'back', 'bail', 'bailsman', 'bargain', 'be sponsor for', 'bond', 'bondsman', 'certify', 'confirm'],
    'guard': ['coldstream guards', 'foot guards', 'grenadier guards', 'life guards', 'scots guards', 'accompany', 'advance guard', 'advocate', 'aegis', 'amateur athlete', 'apologist', 'archer'],
    'guard against': ['advocate', 'champion', 'clear the decks', 'consider every angle', 'defend', 'flank', 'forearm', 'guard', 'hedge', 'leave out nothing', 'make sure', 'make sure against'],
    'guarded': ['argus-eyed', 'olympian', 'all ears', 'all eyes', 'aloof', 'apprehensive', 'armed', 'arrested', 'aux aguets', 'backward', 'bashful', 'blank'],
    'guardhouse': ['pow camp', 'bastille', 'black hole', 'borstal', 'borstal institution', 'bridewell', 'brig', 'cell', 'concentration camp', 'condemned cell', 'death cell', 'death house'],
    'guardian': ['mc', 'air warden', 'ancestral spirits', 'angel', 'attendant', 'attendant godling', 'attorney', 'bailiff', 'bull', 'butler', 'caretaker', 'castellan'],
    'guardian angel': ['air warden', 'ancestral spirits', 'angel', 'attendant', 'attendant godling', 'caretaker', 'castellan', 'conservator', 'control', 'curator', 'custodian', 'daemon'],
    'guardianship': ['administration', 'auspices', 'captainship', 'care', 'chairmanship', 'charge', 'cold storage', 'conservation', 'convenership', 'cure', 'custodianship', 'custody'],
    'guarding': ['care', 'charge', 'covering', 'custodial', 'custodianship', 'custody', 'defending', 'defensive', 'fostering', 'guardian', 'hold', 'immunizing'],
    'guardrail': ['aegis', 'arm guard', 'backstop', 'buffer', 'bulwark', 'bumper', 'contraceptive', 'copyright', 'crash helmet', 'cushion', 'dashboard', 'dodger'],
    'gubernatorial': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'civic', 'civil', 'constitutional', 'democratic', 'despotic', 'dictatorial'],
    'gudgeon': ['arbor', 'axis', 'axle', 'axle bar', 'axle shaft', 'axle spindle', 'axle-tree', 'babe', 'boob', 'chump', 'cinch', 'credulous person'],
    'guerrilla': ['charley', 'vc', 'vietcong', 'bushfighter', 'bushwhacker', 'casual', 'guerilla', 'insurgent', 'irregular', 'maquis', 'maquisard', 'partisan'],
    'guess': ['account as', 'answer', 'appraise', 'appreciate', 'assess', 'assume', 'assumption', 'be afraid', 'believe', 'blind bargain', 'blind guess', 'bold conjecture'],
    'guessing': ['abashed', 'abroad', 'adrift', 'astray', 'at sea', 'bewildered', 'bothered', 'clueless', 'confused', 'discomposed', 'disconcerted', 'dismayed'],
    'guesswork': ['actuarial prediction', 'apocalypse', 'assumption', 'axiom', 'conjecture', 'foreboding', 'forecast', 'forecasting', 'foreshowing', 'foresight', 'foretelling', 'hypothesis'],
    'guest house': ['boardinghouse', 'dorm', 'dormitory', 'doss house', 'fleabag', 'flophouse', 'hospice', 'hostel', 'hostelry', 'hotel', 'inn', 'lodging house'],
    'guff': ['babble', 'babblement', 'balderdash', 'baloney', 'bavardage', 'bibble-babble', 'bilge', 'blab', 'blabber', 'blah', 'blah-blah', 'blather'],
    'guffaw': ['homeric laughter', 'be in stitches', 'belly laugh', 'boff', 'boffola', 'break up', 'burst into laughter', 'burst of laughter', 'burst out', 'burst out laughing', 'burst with laughter', 'bust a gut'],
    'guidance': ['abetment', 'administration', 'admonition', 'advice', 'advisement', 'advising', 'advocacy', 'aegis', 'auspices', 'authority', 'backing', 'briefing'],
    'guide': ['baedeker', 'dutch uncle', 'gyropilot', 'masan', 'polonius', 'abecedarian', 'accompany', 'admonisher', 'advise', 'adviser', 'advisor', 'advocate'],
    'guidebook': ['baedeker', 'yellow pages', 'account', 'acquaintance', 'announcement', 'bibliography', 'blue book', 'briefing', 'bulletin', 'business directory', 'catalog', 'checklist'],
    'guideline': ['procrustean law', 'approach', 'arrangement', 'attack', 'blueprint', 'blueprinting', 'calculation', 'canon', 'charting', 'code', 'commandment', 'conception'],
    'guidepost': ['arrow', 'blaze', 'compass needle', 'direction', 'direction post', 'finger post', 'fist', 'guide', 'guideboard', 'hand', 'hour hand', 'index'],
    'guiding light': ['ambition', 'aspiration', 'basis', 'calling', 'cause', 'consideration', 'goal', 'ground', 'guiding star', 'ideal', 'inspiration', 'intention'],
    'guiding principle': ['big idea', 'canon', 'code', 'commandment', 'convention', 'course', 'creed', 'dictum', 'form', 'formula', 'fundamental idea', 'general principle'],
    'guiding star': ['north star', 'polaris', 'ambition', 'aspiration', 'basis', 'calling', 'cause', 'consideration', 'cynosure', 'goal', 'ground', 'guiding light'],
    'guile': ['italian hand', 'acuteness', 'art', 'artfulness', 'artifice', 'astuteness', 'cageyness', 'callidity', 'canniness', 'cleverness', 'craft', 'craftiness'],
    'guileful': ['byzantine', 'machiavellian', 'machiavellic', 'acute', 'arch', 'artful', 'astute', 'cagey', 'calculating', 'canny', 'chiseling', 'clever'],
    'guilefully': ['artfully', 'astutely', 'cagily', 'cannily', 'cleverly', 'cunningly', 'deceitfully', 'foxily', 'fraudulently', 'furtively', 'indirectly', 'insidiously'],
    'guileless': ['artless', 'bluff', 'blunt', 'born yesterday', 'candid', 'childlike', 'confiding', 'credulous', 'dependent', 'depending', 'direct', 'frank'],
    'guillotine': ['ax', 'behead', 'beheading', 'block', 'bowstring', 'burn', 'burning', 'capital punishment', 'cloture', 'cloture by compartment', 'cross', 'crucifixion'],
    'guilt': ['blame', 'blameworthiness', 'contriteness', 'contrition', 'crime', 'criminality', 'culpability', 'fault', 'feloniousness', 'guiltiness', 'misconduct', 'offense'],
    'guiltless': ['angelic', 'blameless', 'chaste', 'childlike', 'clean', 'clear', 'dovelike', 'exemplary', 'faultless', 'immaculate', 'in the clear', 'incorrupt'],
    'guilty': ['accountable', 'amiss', 'answerable', 'apologetic', 'arraignable', 'ashamed', 'at fault', 'blamable', 'blameful', 'blameworthy', 'censurable', 'conscience-stricken'],
    'guinea': ['bawbee', 'coin', 'crown', 'dollar', 'double eagle', 'doubloon', 'ducat', 'eagle', 'farthing', 'five-dollar gold piece', 'fiver', 'florin'],
    'guinea pig': ['cape polecat', 'ape', 'bar', 'bear', 'cavy', 'chimp', 'chimpanzee', 'coon', 'ferret', 'foumart', 'glutton', 'groundhog'],
    'guise': ['mo', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'algorithm', 'alibi', 'angle', 'apology'],
    'guitar': ['dobro guitar', 'f-hole guitar', 'spanish guitar', 'archlute', 'balalaika', 'banjo', 'banjo-uke', 'banjo-ukulele', 'banjo-zither', 'banjorine', 'banjuke', 'bass guitar'],
    'gulch': ['abysm', 'abyss', 'aqueduct', 'arroyo', 'bed', 'box canyon', 'breach', 'break', 'canal', 'canyon', 'cavity', 'chap'],
    'gulf': ['charybdis', 'maelstrom', 'abysm', 'abyss', 'aperture', 'arm', 'armlet', 'arroyo', 'back stream', 'backflow', 'backwash', 'backwater'],
    'gull': ['babe', 'bamboozle', 'beat', 'befool', 'beguile', 'beguile of', 'betray', 'bilk', 'bluff', 'boob', 'bunco', 'burn'],
    'gullet': ['abdomen', 'abomasum', 'bay window', 'beerbelly', 'belly', 'breadbasket', 'craw', 'crop', 'diaphragm', 'embonpoint', 'esophagus', 'fauces'],
    'gullible': ['artless', 'befoolable', 'born yesterday', 'credulous', 'cullible', 'deceivable', 'deludable', 'dupable', 'easy', 'exploitable', 'foolable', 'green'],
    'gully': ['abysm', 'abyss', 'aqueduct', 'arroyo', 'bed', 'box canyon', 'breach', 'break', 'canal', 'canalize', 'canyon', 'carve'],
    'gulp': ['aqua-lung', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'batten', 'beverage', 'blow', 'bolt', 'bolt down', 'breath', 'breath of air', 'breathe'],
    'gum': ['lastex', 'acaroid resins', 'agglutinate', 'alveolar ridge', 'amber', 'baleen', 'battledore', 'bind', 'bite', 'bollix', 'braze', 'bridgework'],
    'gum up': ['ball up', 'bitch', 'bitch up', 'blow', 'bobble', 'bollix', 'bollix up', 'bonehead into it', 'bugger', 'bugger up', 'bungle', 'cook'],
    'gumbo': ['adhesive', 'adobe', 'albumen', 'amylaceous', 'batter', 'bisque', 'bonnyclabber', 'borscht', 'bouillabaisse', 'bouillon', 'broth', 'burgoo'],
    'gummed up': ['ass-backwards', 'balled up', 'bitched', 'bitched up', 'bollixed up', 'buggered', 'buggered up', 'cooked', 'fouled up', 'hashed up', 'loused up', 'messed up'],
    'gummy': ['adherent', 'adhesive', 'amylaceous', 'bulldogged', 'bulldoggish', 'bulldoggy', 'bullheaded', 'clabbered', 'clammy', 'clingy', 'clotted', 'coagulated'],
    'gumption': ['adventuresomeness', 'adventurousness', 'aggression', 'aggressiveness', 'ambitiousness', 'astuteness', 'audacity', 'backbone', 'balls', 'boldness', 'bottle', 'brains'],
    'gumshoe': ['dogberry', 'john law', 'sherlock', 'sherlock holmes', 'beagle', 'bluecoat', 'bobby', 'bull', 'cop', 'copper', 'couch', 'crawl'],
    'gun': ['aa gun', 'armstrong', 'bar', 'bb gun', 'benet-mercie', 'beretta', 'big bertha', 'bren', 'bren gun', 'browning', 'cain', 'colt'],
    'gun down': ['blast', 'blot out', 'blow to pieces', 'blow up', 'brain', 'bring down', 'bump off', 'burn to death', 'croak', 'cut down', 'cut to pieces', 'deal a deathblow'],
    'gun for': ['angle for', 'ask for', 'beat about for', 'charge', 'cock', 'delve for', 'detonate', 'dig for', 'discharge', 'drop', 'eject', 'fell'],
    'gunfight': ['antiaircraft fire', 'cross fire', 'curtain fire', 'direct fire', 'dry fire', 'file fire', 'fire', 'fire of demolition', 'firepower', 'fireworks', 'firing', 'flack'],
    'gunfire': ['antiaircraft fire', 'bowshot', 'bullet', 'cannon', 'cross fire', 'curtain fire', 'detonation', 'direct fire', 'discharge', 'dry fire', 'ejection', 'file fire'],
    'gung ho': ['buggy', 'bugle call', 'bugs', 'call to arms', 'call-up', 'catchword', 'clarion', 'clarion call', 'conscription', 'enthused', 'enthusiastic', 'enthusiastic about'],
    'gunk': ['adherent', 'adhesive', 'albumen', 'barnacle', 'batter', 'bonnyclabber', 'bramble', 'brier', 'bulldog', 'burr', 'butter', 'cab'],
    'gunman': ['cain', 'nimrod', 'adventurer', 'apache', 'archer', 'artilleryman', 'assassin', 'assassinator', 'bloodletter', 'bloodshedder', 'bowman', 'bravo'],
    'gunner': ['nimrod', 'aerial photographer', 'aircrew', 'aircrewman', 'archer', 'artillerist', 'artilleryman', 'avigator', 'bakehead', 'belly gunner', 'black gang', 'boilerman'],
    'gunnery': ['archery', 'artillery', 'ballistics', 'casting', 'chucking', 'firing', 'flinging', 'heaving', 'hurling', 'jaculation', 'lobbing', 'missilery'],
    'gunsel': ['cain', 'mafioso', 'young turk', 'apache', 'assassin', 'assassinator', 'auntie', 'beast', 'beldam', 'berserk', 'berserker', 'bi-guy'],
    'gunshot': ['ace', 'bang', 'bark', 'bit', 'blast', 'bowshot', 'brief span', 'bullet', 'burst', 'cannon', 'close quarters', 'close range'],
    'gurge': ['charybdis', 'maelstrom', 'back stream', 'backflow', 'backwash', 'backwater', 'centrifugate', 'centrifuge', 'countercurrent', 'counterflow', 'counterflux', 'dizzy round'],
    'gurgle': ['babble', 'babbling', 'blubber', 'boil', 'boil over', 'bubble', 'bubble over', 'bubble up', 'bubbling', 'burble', 'burbling', 'condense'],
    'guru': ['brahman', 'ramwat', 'abecedarian', 'angel', 'authority', 'bairagi', 'bashara', 'bhikhari', 'bhikshu', 'boss', 'bwana', 'certified teacher'],
    'gush': ['abound', 'abundance', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'affluence', 'afflux'],
    'gushing': ['abundance', 'abundant', 'adulatory', 'affluent', 'amplitude', 'bathetic', 'beery', 'bland', 'blandishing', 'blarneying', 'buttery', 'cajoling'],
    'gussy up': ['adorn', 'array', 'beautify', 'become one', 'bedeck', 'bedizen', 'blazon', 'color', 'dandify', 'deck', 'deck out', 'decorate'],
    'gust': ['access', 'affection', 'aftertaste', 'alacrity', 'animation', 'anxiety', 'anxiousness', 'appetite', 'aroma', 'attribute', 'avidity', 'avidness'],
    'gusto': ['activity', 'affection', 'alacrity', 'amusement', 'animal pleasure', 'animal spirits', 'animation', 'anxiety', 'anxiousness', 'appetite', 'appreciation', 'ardency'],
    'gusty': ['aeolian', 'agreeable', 'airish', 'airy', 'ambrosial', 'appetizing', 'blasty', 'blowy', 'blustering', 'blusterous', 'blustery', 'boreal'],
    'gut': ['ab ovo', 'abdomen', 'abomasum', 'affectional', 'affective', 'arm', 'armlet', 'audacity', 'automatic', 'backbone', 'balls', 'basal'],
    'gut reaction': ['affect', 'affection', 'emotion', 'emotional charge', 'emotional shade', 'experience', 'feeling', 'feeling tone', 'foreboding', 'heartthrob', 'impression', 'passion'],
    'gutless': ['anemic', 'asthenic', 'bloodless', 'chicken', 'coward', 'cowardly', 'craven', 'debilitated', 'drooping', 'droopy', 'dull', 'effete'],
    'guts': ['abdomen', 'anus', 'appendix', 'backbone', 'being', 'bite', 'bitingness', 'blind gut', 'bones', 'bosom', 'bottom', 'bowels'],
    'gutsy': ['acid', 'beefy', 'biting', 'bold', 'bouncing', 'bulldoggish', 'corrosive', 'courageous', 'cutting', 'dauntless', 'doughty', 'driving'],
    'gutter': ['aqueduct', 'beat', 'beneath one', 'bicker', 'broad', 'canal', 'canalization', 'channel', 'cheap', 'chute', 'cloaca', 'cloaca maxima'],
    'guttersnipe': ['arab', 'babbitt', 'philistine', 'arriviste', 'beach bum', 'beachcomber', 'beggar', 'bo', 'boor', 'bounder', 'bourgeois', 'brat'],
    'guttural': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation', 'back'],
    'guy': ['adamite', 'advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'bastard', 'bearer', 'being'],
    'guywire': ['advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'bearer', 'bra', 'brace', 'bracer'],
    'guzzle': ['bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'batten', 'bender', 'beverage', 'bib', 'binge', 'bolt', 'bolt down', 'booze'],
    'gym': ['agora', 'amphitheater', 'archery ground', 'arena', 'athletic field', 'auditorium', 'background', 'badminton court', 'baseball field', 'basketball court', 'bear garden', 'billiard parlor'],
    'gymkhana': ['highland games', 'olympiad', 'olympic games', 'olympics', 'bout', 'carousel', 'concours', 'contest', 'derby', 'encounter', 'engagement', 'field day'],
    'gymnasium': ['agora', 'amphitheater', 'archery ground', 'arena', 'athletic field', 'auditorium', 'background', 'badminton court', 'baseball field', 'basketball court', 'bear garden', 'billiard parlor'],
    'gymnastics': ['rugby', 'acrobatics', 'agonistics', 'association football', 'athletics', 'bathing', 'breather', 'calisthenics', 'constitutional', 'daily dozen', 'drill', 'eurythmics'],
    'gynecologist': ['anesthesiologist', 'cardiologist', 'chiropodist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'immunologist', 'internist', 'neurologist', 'obstetrician', 'oculist'],
    'gyp': ['partlet', 'seeing eye dog', 'ballot-box stuffing', 'bandog', 'beat', 'beguile of', 'biddy', 'bilk', 'bitch', 'bossy', 'bowwow', 'brood mare'],
    'gyp joint': ['ballot-box stuffing', 'bordello', 'brothel', 'bunco', 'cardsharping', 'cathouse', 'cheat', 'cheating', 'clip joint', 'cozenage', 'den', 'den of thieves'],
    'gypper': ['blackleg', 'cheat', 'cheater', 'chiseler', 'con man', 'cozener', 'crook', 'defrauder', 'diddler', 'double-dealer', 'flimflam man', 'flimflammer'],
    'gyrate': ['advance', 'ascend', 'back', 'back up', 'budge', 'change', 'change place', 'circle', 'circulate', 'circumrotate', 'circumvolute', 'climb'],
    'gyration': ['angular momentum', 'angular motion', 'angular velocity', 'axial motion', 'bowling', 'centrifugation', 'circuit', 'circulation', 'circumgyration', 'circumrotation', 'circumvolution', 'full circle'],
    'gyrational': ['ascending', 'axial', 'back', 'back-flowing', 'backward', 'circumgyratory', 'circumvolutory', 'cyclonic', 'descending', 'down-trending', 'downward', 'drifting'],
    'gyre': ['baba yaga', 'charybdis', 'lilith', 'afreet', 'barghest', 'cacodemon', 'circle', 'circling', 'circuit', 'circuiteer', 'circuition', 'circuitousness'],
    'gyrene': ['marine corps', 'naval reservist', 'royal marine', 'royal marines', 'seabee', 'bluejacket', 'boot', 'cadet', 'devil dogs', 'frogman', 'gob', 'horse marine'],
    'gyroscope': ['balance', 'balance rudder', 'balance wheel', 'ballast', 'centrifuge', 'chuck', 'counterbalance', 'counterweight', 'drill', 'extractor', 'fan', 'fin'],
    'h bomb': ['a-bomb', 'atomic bomb', 'atomic warhead', 'clean bomb', 'cobalt bomb', 'dirty bomb', 'fusion bomb', 'hell bomb', 'hydrogen bomb', 'limited nuclear weapons', 'nuclear artillery', 'nuclear explosive'],
    'ha ha': ['homeric laughter', 'aqueduct', 'be in stitches', 'belly laugh', 'boff', 'boffola', 'break up', 'burst into laughter', 'burst of laughter', 'burst out', 'burst out laughing', 'burst with laughter'],
    'haberdasher': ['baker', 'bookdealer', 'bookseller', 'butcher', 'chandler', 'clothier', 'clothing merchant', 'confectioner', 'costumer', 'costumier', 'draper', 'dry goods dealer'],
    'haberdashery': ['antique store', 'apothecary', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'chemist', 'cigar store', 'clothiers', 'clothing store', 'confectionery', 'dress shop'],
    'habit': ['a habit', 'accouter', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'addiction', 'alcoholism', 'apparel', 'array', 'attire', 'attitude', 'automatism'],
    'habitat': ['abode', 'alentours', 'ambience', 'ambit', 'bailiwick', 'borderlands', 'circle', 'circuit', 'circumambiencies', 'circumjacencies', 'circumstances', 'compass'],
    'habitation': ['abiding place', 'abode', 'address', 'apartment', 'cantonment', 'colonization', 'commorancy', 'crash pad', 'crib', 'digs', 'domicile', 'domiciliation'],
    'habitual': ['accepted', 'accustomed', 'addicted', 'arranged', 'automatic', 'average', 'beaten', 'businesslike', 'chronic', 'common', 'commonplace', 'confirmed'],
    'habitually': ['again and again', 'as a rule', 'as per usual', 'as things go', 'as usual', 'chiefly', 'chronically', 'commonly', 'consistently', 'customarily', 'frequently', 'generally'],
    'habituate': ['acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'addict', 'adjust', 'bear', 'break', 'break in', 'case harden', 'condition'],
    'habituation': ['a habit', 'acclimation', 'acclimatization', 'accommodation', 'accustoming', 'acquired tolerance', 'acute alcoholism', 'adaption', 'addictedness', 'addiction', 'adjustment', 'alcoholism'],
    'habitue': ['aficionado', 'attender', 'audience', 'buff', 'caller', 'company', 'customer', 'denizen', 'devotee', 'employer', 'fan', 'freeloader'],
    'hachure': ['lambert conformal projection', 'mercator projection', 'miller projection', 'aeronautical chart', 'arabesque', 'astronomical chart', 'atlas', 'azimuthal projection', 'band', 'bar', 'basketry', 'basketwork'],
    'hacienda': ['arable land', 'barnyard', 'barton', 'cattle ranch', 'chicken farm', 'collective farm', 'cotton plantation', 'croft', 'dairy farm', 'demesne', 'demesne farm', 'dry farm'],
    'hack': ['aqua-lung', 'jehu', 'sunday driver', 'amble', 'amputate', 'antiquated', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'autobus', 'ax', 'backseat driver'],
    'hack it': ['answer', 'avail', 'be able', 'be equal to', 'be up to', 'bear', 'can', 'can do', 'clear', 'clear the hurdle', 'come along', 'come on'],
    'hackle': ['card', 'comb', 'covert', 'crest', 'curry', 'feather', 'feathers', 'hack', 'haggle', 'hatchel', 'heckle', 'mail'],
    'hackneyed': ['antediluvian', 'antiquated', 'archaic', 'automatic', 'back-number', 'banal', 'bathetic', 'beaten', 'bewhiskered', 'bromidic', 'cliched', 'common'],
    'hades': ['abaddon', 'acheron', 'agdistis', 'aides', 'aidoneus', 'amenti', 'amor', 'aphrodite', 'apollo', 'apollon', 'aralu', 'ares'],
    'hag': ['jezebel', 'weird sisters', 'baboon', 'bag', 'bat', 'battle-ax', 'beldam', 'biddy', 'bitch-kitty', 'blemish', 'blot', 'coven'],
    'haggard': ['abandoned', 'achromatic', 'achromic', 'amok', 'anemic', 'angular', 'ashen', 'ashy', 'attenuated', 'bellowing', 'berserk', 'bigoted'],
    'haggle': ['bargain', 'bargaining', 'barter', 'beat down', 'bicker', 'bid', 'bid for', 'cavil', 'chaffer', 'chaffering', 'cheapen', 'collective bargaining'],
    'hagiography': ['buddhology', 'clio', 'mariolatry', 'mariology', 'mercersburg theology', 'muse of history', 'adventures', 'annals', 'apologetics', 'autobiography', 'biographical sketch', 'biography'],
    'haiku': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'hail': ['a mass of', 'a world of', 'abide by', 'accede', 'accept', 'acclaim', 'accost', 'acknowledge', 'acquiesce', 'acquiesce in', 'address', 'agree'],
    'hail mary': ['angelus', 'ave', 'ave maria', 'kyrie eleison', 'paternoster', 'aid prayer', 'appeal', 'beadroll', 'beads', 'beseechment', 'bidding prayer', 'breviary'],
    'hair': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'ace', 'animal fiber', 'artificial fiber', 'atom', 'bagatelle', 'bauble', 'bean'],
    'hair trigger': ['agile', 'breakneck', 'dashing', 'double-quick', 'eagle-winged', 'expeditious', 'express', 'fast', 'fleet', 'flying', 'galloping', 'hasty'],
    'hairbreadth': ['ace', 'bit', 'bowshot', 'brief span', 'close quarters', 'close range', 'closeness', 'confinement', 'crack', 'crowdedness', 'earreach', 'earshot'],
    'hairdo': ['afro', 'french knot', 'bangs', 'bob', 'coif', 'coiffure', 'cold wave', 'conk', 'cut', 'haircut', 'hairstyle', 'headdress'],
    'hairiness': ['abstruseness', 'arduousness', 'bothersomeness', 'burdensomeness', 'complexity', 'complication', 'difficultness', 'difficulty', 'hardness', 'intricacy', 'laboriousness', 'onerousness'],
    'hairlike': ['bristlelike', 'capillary', 'cirrose', 'cirrous', 'fibered', 'fibroid', 'fibrous', 'flagelliform', 'flossy', 'funicular', 'gossamery', 'hairy'],
    'hairline': ['band', 'bar', 'cross-hatching', 'dash', 'delicacy', 'delicate', 'delicate distinction', 'delineation', 'diagonal', 'differentia', 'differential', 'distinction'],
    'hairpin': ['aberrancy', 'aberration', 'bend', 'bendy', 'bias', 'branching off', 'chevron', 'chevronwise', 'chevrony', 'circuitousness', 'corner', 'crankiness'],
    'hairsplitting': ['adverse criticism', 'animadversion', 'aspersion', 'bad notices', 'bad press', 'bickering', 'boggling', 'captious', 'captiousness', 'carping', 'cavil', 'caviling'],
    'hairy': ['herculean', 'abstruse', 'arduous', 'asperous', 'barbellate', 'barfy', 'bearded', 'bewhiskered', 'bristled', 'bristling', 'bristly', 'brutal'],
    'halcyon': ['saturnian', 'at peace', 'at rest', 'balmy', 'bloodless', 'blooming', 'blossoming', 'booming', 'bright', 'calm', 'clear', 'cloistered'],
    'hale': ['able-bodied', 'beefy', 'bouncing', 'bunkum', 'doughty', 'drag', 'draggle', 'draw', 'fit', 'flourishing', 'flush', 'forceful'],
    'half': ['allotment', 'allowance', 'big end', 'bigger half', 'bisection', 'bit', 'bite', 'budget', 'chunk', 'commission', 'contingent', 'cut'],
    'half assed': ['amateur', 'amateurish', 'artless', 'botched', 'bungling', 'clumsy', 'dabbling', 'defective', 'deficient', 'dilettante', 'dilettantish', 'half-baked'],
    'half baked': ['a bit previous', 'adolescent', 'advanced', 'amateur', 'amateurish', 'arrested', 'at half cock', 'babbling', 'backward', 'blithering', 'burbling', 'callow'],
    'half breed': ['cape colored', 'eurasian', 'bastard', 'cattalo', 'citrange', 'cross', 'crossbred', 'crossbreed', 'crossed', 'griffe', 'half blood', 'half-bred'],
    'half cocked': ['a bit previous', 'adolescent', 'advanced', 'amateur', 'amateurish', 'at half cock', 'callow', 'dabbling', 'dilettante', 'dilettantish', 'far ahead', 'fledgling'],
    'half life': ['activity', 'artificial radioactivity', 'contamination', 'curiage', 'decontamination', 'fallout', 'natural radioactivity', 'nuclear radiation', 'radiant energy', 'radiation', 'radioactive radiation', 'radioactivity'],
    'half moon': ['artificial satellite', 'crescent', 'crescent moon', 'decrescent', 'decrescent moon', 'demilune', 'full moon', 'gibbous moon', 'harvest moon', 'horseshoe', 'increscent', 'increscent moon'],
    'half pint': ['cramped', 'dinky', 'exiguous', 'knee-high', 'limited', 'little', 'one-horse', 'petite', 'piddling', 'pindling', 'pint-sized', 'poky'],
    'half time': ['anchor watch', 'bit', 'break', 'coffee break', 'day shift', 'dogwatch', 'downtime', 'full time', 'graveyard shift', 'half-time intermission', 'holiday', 'interim'],
    'half truth': ['blague', 'cock-and-bull story', 'exaggeration', 'fairy tale', 'falsehood', 'falsity', 'farfetched story', 'farrago', 'fib', 'fiction', 'fish story', 'flam'],
    'halfhearted': ['laodicean', 'bland', 'changeable', 'cold', 'cool', 'fervorless', 'indecisive', 'indifferent', 'infirm of purpose', 'infirm of will', 'insipid', 'irresolute'],
    'halftone': ['maxwell triangle', 'munsell scale', 'chromatic circle', 'chromatic spectrum', 'chromaticity diagram', 'color circle', 'color cycle', 'color index', 'color mixture curve', 'color solid', 'color spectrum', 'color system'],
    'halftone engraving': ['albertype', 'book printing', 'chromotypography', 'chromotypy', 'chromoxylography', 'collotype', 'color printing', 'electronography', 'electrostatic printing', 'graphic arts', 'gravure', 'history of printing'],
    'halfway': ['amidships', 'average', 'betwixt and between', 'center', 'centermost', 'central', 'core', 'equatorial', 'equidistant', 'half', 'half-and-half', 'in medias res'],
    'halfway house': ['almshouse', 'asylum', 'bisection', 'equidistance', 'foster home', 'half', 'home', 'hospice', 'hospitium', 'mediety', 'mid-distance', 'midcourse'],
    'halfwit': ['ass', 'birdbrain', 'dolt', 'dullard', 'dunce', 'dunderhead', 'dunderpate', 'fool', 'idiot', 'imbecile', 'moron', 'nincompoop'],
    'halitosis': ['bo', 'bad breath', 'bad smell', 'body odor', 'fetidity', 'fetidness', 'fetor', 'foul breath', 'foul odor', 'frowst', 'graveolence', 'malodor'],
    'hall': ['dymaxion house', 'elizabethan theater', 'globe theatre', 'greek theater', 'white house', 'access', 'adit', 'adobe house', 'agora', 'air lock', 'amphitheater', 'approach'],
    'hallelujah': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'nunc dimittis', 'te deum', 'trisagion', 'vedic hymn'],
    'hallmark': ['aroma', 'attribute', 'authentication', 'badge', 'banner', 'billhead', 'book stamp', 'bookplate', 'brand', 'broad arrow', 'cachet', 'cast'],
    'hallow': ['beat the drum', 'beatify', 'bless', 'blow the trumpet', 'canonize', 'celebrate', 'cleanse', 'commemorate', 'consecrate', 'dedicate', 'devote', 'dress ship'],
    'hallowed': ['acknowledged', 'admitted', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'beatified', 'blessed', 'boundless', 'canonized', 'changeless'],
    'hallucination': ['aberration', 'agnosia', 'apparition', 'bamboozlement', 'befooling', 'block', 'blocking', 'bluffing', 'brainchild', 'bubble', 'calculated deception', 'chimera'],
    'hallucinatory': ['beguiling', 'catchy', 'consciousness-expanding', 'deceiving', 'deceptive', 'delusive', 'delusory', 'dubious', 'fallacious', 'false', 'fishy', 'hallucinational'],
    'hallucinogen': ['det', 'dmt', 'indian hemp', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'belladonna', 'bhang'],
    'halo': ['annular muscle', 'annulation', 'annulus', 'anthelion', 'antisun', 'areola', 'aura', 'aureola', 'aureole', 'blaze of glory', 'brilliance', 'brilliancy'],
    'halt': ['abandon', 'abort', 'afterthought', 'amble', 'arrest', 'arrestation', 'bad', 'barge', 'belay', 'bell', 'bind', 'blind alley'],
    'halter': ['oregon boat', 'ax', 'back band', 'backstrap', 'bearing rein', 'bellyband', 'bilbo', 'bit', 'blinders', 'blinds', 'block', 'bond'],
    'halting': ['latinate', 'ambidextrous', 'ambling', 'awkward', 'bad', 'balbutient', 'bombastic', 'broken', 'build up', 'bumbling', 'capricious', 'careening'],
    'haltingly': ['at irregular intervals', 'at random', 'brokenly', 'by catches', 'by fits', 'by jerks', 'by snatches', 'capriciously', 'cautiously', 'circumspectly', 'crawlingly', 'creepingly'],
    'halve': ['amputate', 'apportion', 'ax', 'be partners in', 'bifurcate', 'bisect', 'branch', 'butcher', 'by two', 'carve', 'chop', 'cleave'],
    'halving': ['janus', 'ambiguity', 'ambivalence', 'bifidity', 'biformity', 'bifurcation', 'bipartition', 'bisection', 'branching', 'by two', 'conjugation', 'cutting in two'],
    'ham': ['arrl', 'acting', 'actor-proof', 'all-star', 'amateur radio operator', 'ankle', 'bacon', 'ballet', 'balletic', 'bayonet legs', 'be theatrical', 'bowlegs'],
    'hamburger': ['blt', 'dagwood sandwich', 'london broil', 'salisbury steak', 'sloppy joe', 'swiss cheese sandwich', 't-bone steak', 'bacon-lettuce-tomato sandwich', 'beef', 'beef extract', 'beef tea', 'beefsteak'],
    'hamlet': ['kreis', 'archbishopric', 'archdiocese', 'arrondissement', 'bailiwick', 'bishopric', 'borough', 'canton', 'city', 'commune', 'congressional district', 'constablewick'],
    'hammer': ['eustachian tube', 'air hammer', 'anvil', 'assault', 'attack', 'auditory apparatus', 'auditory canal', 'auditory meatus', 'auditory nerve', 'auditory ossicles', 'auditory tube', 'auricle'],
    'hammer and sickle': ['armory', 'badge', 'badge of office', 'badges', 'baton', 'blazonry', 'brassard', 'button', 'cap and gown', 'chain', 'chain of office', 'class ring'],
    'hammer and tongs': ['arduously', 'bec et ongles', 'committedly', 'decidedly', 'decisively', 'determinedly', 'devotedly', 'earnestly', 'effortfully', 'firmly', 'fixedly', 'hard'],
    'hammer away at': ['always trot out', 'apply the mind', 'belabor', 'dig', 'drudge', 'dwell on', 'dwell upon', 'fag', 'grind', 'grub', 'hammer', 'hammer at'],
    'hammy': ['actor-proof', 'all-star', 'ballet', 'balletic', 'cinematic', 'cinematographic', 'dramatic', 'dramatical', 'dramaturgic', 'emotionalistic', 'emotive', 'film'],
    'hamper': ['oregon boat', 'anchor', 'bag', 'balk', 'bar', 'barrel', 'barricade', 'basket', 'bear hard upon', 'bilbo', 'bind', 'block'],
    'hampered': ['bound', 'burdened', 'charged', 'cumbered', 'encumbered', 'fettered', 'fraught', 'freighted', 'handcuffed', 'in bonds', 'in chains', 'in irons'],
    'hampering': ['arrest', 'arrestation', 'arrestment', 'blockage', 'blocking', 'burdensome', 'check', 'clogging', 'closing up', 'closure', 'constriction', 'cramp'],
    'hamstring': ['bugger', 'burden', 'castrate', 'cramp', 'cripple', 'cumber', 'de-energize', 'debilitate', 'deflate', 'disable', 'disarm', 'disenable'],
    'hand': ['adamite', 'john hancock', 'abalienate', 'accessible', 'acclaim', 'acclamation', 'accomplished fact', 'accomplishment', 'ace', 'achievement', 'act', 'acta'],
    'hand clasp': ['accost', 'address', 'bob', 'bow', 'curtsy', 'embrace', 'greeting', 'hail', 'handshake', 'hello', 'how-do-you-do', 'hug'],
    'hand down': ['abalienate', 'add a codicil', 'alien', 'alienate', 'amortize', 'assign', 'barter', 'bequeath', 'cede', 'confer', 'consign', 'convey'],
    'hand grenade': ['aerial bomb', 'antipersonnel bomb', 'bomb', 'bombshell', 'carcass', 'concussion grenade', 'depth bomb', 'depth charge', 'fire bomb', 'gas grenade', 'grenade', 'incendiary bomb'],
    'hand in': ['circulate', 'come across with', 'deliver', 'deliver over', 'distribute', 'fork over', 'forward', 'give in', 'give out', 'give over', 'hand', 'hand out'],
    'hand in hand': ['affably', 'agreeably', 'amiably', 'amicably', 'ardently', 'arm in arm', 'as one', 'as one man', 'back to back', 'cheek by jowl', 'coactively', 'coefficiently'],
    'hand on': ['abalienate', 'add a codicil', 'alien', 'alienate', 'amortize', 'assign', 'barter', 'bequeath', 'broadcast', 'carry over', 'cede', 'communicate'],
    'hand out': ['accord', 'administer', 'afford', 'allot', 'allow', 'award', 'bestow', 'bestow on', 'circulate', 'come across with', 'communicate', 'confer'],
    'hand over': ['abalienate', 'abandon', 'abdicate', 'abjure', 'acknowledge defeat', 'alien', 'alienate', 'amortize', 'ante', 'ante up', 'assign', 'barter'],
    'hand over fist': ['amain', 'apace', 'at flank speed', 'at once', 'by forced marches', 'cursorily', 'double-quick', 'expeditiously', 'fast', 'feverishly', 'furiously', 'hand over hand'],
    'hand-in-hand': ['allied', 'approaching', 'approximate', 'approximating', 'arm-in-arm', 'assembled', 'associated', 'banded together', 'bound', 'bracketed', 'burning', 'cheek-by-jowl'],
    'handbook': ['baedeker', 'yellow pages', 'ante', 'bet', 'bibliography', 'book', 'business directory', 'catalog', 'checklist', 'chunk', 'city directory', 'classified directory'],
    'handcuff': ['oregon boat', 'anchor', 'bilbo', 'bind', 'bond', 'bonds', 'bridle', 'camisole', 'chain', 'chains', 'collar', 'cuffs'],
    'handed down': ['acknowledged', 'admitted', 'conventional', 'customary', 'established', 'fixed', 'folk', 'hallowed', 'heroic', 'hoary', 'immemorial', 'inveterate'],
    'handful': ['augean task', 'herculean task', 'a few', 'ace', 'atom', 'backbreaker', 'ballbuster', 'bit', 'bitch', 'bother', 'chore', 'couple'],
    'handicap': ['derby', 'kentucky derby', 'preakness stakes', 'abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'allowance', 'atrophy'],
    'handicapped': ['amputee', 'bad', 'castrated', 'cripple', 'crippled', 'defective', 'deformity', 'disabled', 'emasculated', 'game', 'halt', 'halting'],
    'handicraft': ['architecture', 'art', 'artisan work', 'artisanship', 'assembly', 'building', 'business', 'calling', 'career', 'career building', 'careerism', 'casting'],
    'handily': ['ably', 'adeptly', 'adroitly', 'advantageously', 'agilely', 'aptly', 'artfully', 'artistically', 'brilliantly', 'capably', 'cleverly', 'comfortably'],
    'handiwork': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adventure', 'architecture', 'artifact', 'assembly', 'blow', 'brainchild'],
    'handle': ['accomplish', 'act toward', 'administer', 'aim', 'air', 'alibi', 'analyze', 'apology', 'appellation', 'appellative', 'apply', 'be in'],
    'handler': ['agent', 'athletic coach', 'coach', 'conductor', 'driller', 'drillmaster', 'driver', 'engineer', 'functionary', 'groomer', 'manipulator', 'operant'],
    'handling': ['accomplishment', 'achievement', 'action', 'administration', 'agency', 'authority', 'care', 'caressing', 'charge', 'command', 'commission', 'completion'],
    'handmade': ['assembled', 'built', 'cast', 'constructed', 'crafted', 'created', 'custom', 'custom-built', 'custom-made', 'extracted', 'fabricated', 'fashioned'],
    'handmaid': ['charlie mccarthy', 'abigail', 'agent', 'amah', 'ancilla', 'appliance', 'au pair girl', 'ayah', 'betweenmaid', 'biddy', 'chambermaid', 'chaperon'],
    'handout': ['account', 'acquaintance', 'alms', 'alms fee', 'announcement', 'blue book', 'briefing', 'bulletin', 'charity', 'collection', 'communication', 'communique'],
    'handpicked': ['accepted', 'adopted', 'appointed', 'approved', 'best', 'carried', 'champion', 'choice', 'chosen', 'designated', 'elect', 'elected'],
    'hands': ['administration', 'authority', 'claws', 'clutches', 'command', 'control', 'disposition', 'domination', 'dominion', 'empery', 'empire', 'fighting force'],
    'handshake': ['accost', 'act up to', 'address', 'agree to anything', 'bob', 'bow', 'brown-nose', 'court', 'curry favor', 'curtsy', 'dance attendance on', 'embrace'],
    'handsome': ['abundant', 'aesthetic', 'aesthetically appealing', 'ample', 'attractive', 'august', 'beauteous', 'beautiful', 'big', 'bighearted', 'bonny', 'bounteous'],
    'handsomely': ['attractively', 'beauteously', 'beautifully', 'becomingly', 'bigheartedly', 'bounteously', 'bountifully', 'chivalrously', 'comelily', 'elegantly', 'exquisitely', 'freehandedly'],
    'handwriting': ['autography', 'calligraphy', 'chirography', 'fist', 'graphanalysis', 'graphology', 'graphometry', 'hand', 'longhand', 'manuscript', 'paleography', 'pencraft'],
    'handy': ['daedalian', 'accessible', 'adaptable', 'adept', 'adjacent', 'adroit', 'agential', 'agentival', 'agentive', 'all-around', 'apt', 'artistic'],
    'handy man': ['admirable crichton', 'adept', 'artisan', 'artist', 'attache', 'authority', 'connaisseur', 'connoisseur', 'consultant', 'cordon bleu', 'crack shot', 'craftsman'],
    'hang': ['act in concert', 'adhere', 'all depend', 'and quarter', 'art', 'aspire', 'associate with', 'attach', 'bag', 'be based on', 'be consistent', 'be contingent on'],
    'hang about': ['around', 'clasp', 'cling to', 'dangle', 'follow', 'follow at heel', 'follow close upon', 'follow the crowd', 'go with', 'hover over', 'huddle', 'hug'],
    'hang around': ['abide', 'affect', 'await', 'bide', 'bide the issue', 'bum around', 'dally', 'dawdle', 'delay', 'dillydally', 'do nothing', 'frequent'],
    'hang around with': ['accompany', 'associate', 'associate with', 'assort with', 'attend', 'band together', 'chum', 'chum together', 'chum with', 'clique', 'clique with', 'club together'],
    'hang back': ['avoid', 'back down', 'balance', 'be dilatory', 'blench', 'blink', 'boggle', 'cringe', 'dawdle', 'debate', 'deliberate', 'demur'],
    'hang fire': ['adjourn', 'be a sideliner', 'be dilatory', 'be still', 'be unproductive', 'bring up', 'bring up short', 'cease fire', 'coast', 'come to naught', 'come to nothing', 'come up short'],
    'hang in': ['abide', 'abide with', 'bear', 'bear up', 'bear with', 'bide', 'brave', 'brook', 'come up fighting', 'dig in', 'endure', 'get along'],
    'hang in effigy': ['attaint', 'bespatter', 'blacken', 'blot', 'blow upon', 'brand', 'censure', 'defame', 'defile', 'disapprove', 'disparage', 'expose'],
    'hang off': ['blench', 'boggle', 'demur', 'falter', 'fight shy of', 'flinch', 'hang back', 'have qualms', 'hesitate', 'hold off', 'make bones about', 'pause'],
    'hang on': ['account for', 'accredit with', 'accrete to', 'accrue from', 'acknowledge', 'adhere', 'adhere to', 'agglomerate', 'all depend', 'apply to', 'arise from', 'ascribe to'],
    'hang out': ['abide', 'affect', 'aller sans dire', 'be conspicuous', 'be exposed', 'be found', 'be manifest', 'be no secret', 'beetle', 'berth', 'betray itself', 'bide'],
    'hang over': ['approach', 'arch over', 'await', 'be imminent', 'be in store', 'beetle', 'bestraddle', 'bestride', 'brew', 'bridge', 'come on', 'confront'],
    'hang together': ['accord', 'act in concert', 'act together', 'adhere', 'affiliate', 'agglomerate', 'agree', 'ally', 'amalgamate', 'answer to', 'assent', 'associate'],
    'hang up': ['adjourn', 'afterthought', 'bind', 'block', 'blockade', 'blockage', 'blow up', 'bog down', 'bottleneck', 'bureaucratic delay', 'buzz', 'call'],
    'hangdog': ['abashed', 'abject', 'ashamed', 'backscratching', 'beggarly', 'blushing', 'bootlicking', 'chagrined', 'chapfallen', 'cowering', 'crawling', 'crestfallen'],
    'hanger': ['afforestation', 'arboretum', 'banner', 'banner head', 'bar', 'belt', 'boom', 'boondocks', 'braces', 'bush', 'bushveld', 'button'],
    'hanger on': ['adherent', 'appendage', 'attendant', 'barnacle', 'bloodsucker', 'buff', 'bystander', 'cavaliere servente', 'courtier', 'creature', 'dangler', 'dependent'],
    'hanging': ['act drop', 'asbestos', 'asbestos board', 'backdrop', 'bagging', 'baggy', 'batten', 'beheading', 'blanket', 'border', 'burning', 'capital punishment'],
    'hangout': ['baths', 'casino', 'club', 'clubhouse', 'gambling house', 'gathering place', 'haunt', 'health resort', 'honky-tonk', 'joint', 'meeting place', 'purlieu'],
    'hangover': ['dutch courage', 'a high', 'afterlife', 'befuddlement', 'besottedness', 'drunkenness', 'following', 'fuddle', 'fuddledness', 'fuddlement', 'future time', 'inebriation'],
    'hank': ['animal fiber', 'artificial fiber', 'capillament', 'cilium', 'cirrus', 'cobweb', 'denier', 'fiber', 'fibrilla', 'filament', 'filamentule', 'flagellum'],
    'hanker': ['ache', 'covet', 'crave', 'desire', 'fancy', 'hunger', 'hunger after', 'hunger for', 'itch for', 'long for', 'lust', 'lust after'],
    'hankering': ['heimweh', 'aching', 'desiderium', 'homesick', 'homesickness', 'honing', 'languishing', 'languishment', 'longing', 'mal du pays', 'maladie du pays', 'nostalgia'],
    'hanky panky': ['adulterous affair', 'adultery', 'affair', 'amour', 'conjuration', 'cuckoldry', 'entanglement', 'escamotage', 'eternal triangle', 'flirtation', 'forbidden love', 'hocus-pocus'],
    'hap': ['accident', 'accidentality', 'actuarial calculation', 'adventitiousness', 'adventure', 'be found', 'be met with', 'be realized', 'bechance', 'befall', 'betide', 'break'],
    'haphazard': ['accidental', 'accidentally', 'ad-lib', 'aimless', 'aimlessly', 'amorphous', 'any which way', 'anyhow', 'anywise', 'around', 'at random', 'botched'],
    'haphazardly': ['about', 'aimlessly', 'airily', 'any old way', 'any which way', 'anyhow', 'at haphazard', 'at hazard', 'at intervals', 'at random', 'brokenly', 'bunglingly'],
    'hapless': ['badly off', 'depressed', 'dire', 'donsie', 'doomful', 'evil-starred', 'fatal', 'fortuneless', 'funest', 'ill off', 'ill-fated', 'ill-starred'],
    'happen': ['be found', 'be met with', 'be realized', 'bechance', 'become of', 'befall', 'betide', 'break', 'bump', 'chance', 'come', 'come about'],
    'happen upon': ['alight upon', 'blunder upon', 'bump into', 'chance upon', 'come across', 'come on', 'come up against', 'come upon', 'discover serendipitously', 'encounter', 'fall in with', 'hit upon'],
    'happening': ['grand guignol', 'passion play', 'tom show', 'accident', 'accidental', 'accompanying', 'ado', 'adventure', 'afloat', 'afoot', 'antimasque', 'audience success'],
    'happenstance': ['accessory', 'accident', 'accidental', 'accidentality', 'actuarial calculation', 'addendum', 'addition', 'adjunct', 'adventitiousness', 'adventure', 'appendage', 'appurtenance'],
    'happily': ['agreeably', 'airily', 'blessedly', 'blissfully', 'blithely', 'cheerfully', 'cheerily', 'delightedly', 'ecstatically', 'elatedly', 'enthusiastically', 'exultantly'],
    'happiness': ['easy street', 'acceptance', 'affluence', 'appropriateness', 'beatification', 'beatitude', 'becomingness', 'bed of roses', 'bewitchment', 'blessedness', 'bliss', 'blissfulness'],
    'happy': ['a propos', 'accepting', 'accidental', 'ad rem', 'adapted', 'addled', 'advantageous', 'advisable', 'applicable', 'apposite', 'appropriate', 'apropos'],
    'happy hour': ['break', 'breath', 'breather', 'breathing place', 'breathing space', 'breathing spell', 'breathing time', 'cigarette break', 'cocktail hour', 'coffee break', 'downtime', 'enforced respite'],
    'happy medium': ['abnegation', 'abstinence', 'average', 'balance', 'calm', 'calmness', 'center', 'compromise', 'conservatism', 'constraint', 'continence', 'control'],
    'harangue': ['address', 'after-dinner speech', 'allocution', 'assignment', 'chalk talk', 'debate', 'declaim', 'declamation', 'demagogue', 'diatribe', 'discourse', 'disquisition'],
    'harass': ['abuse', 'afflict', 'aggravate', 'aggrieve', 'ail', 'annoy', 'badger', 'bait', 'be at', 'be the matter', 'beat', 'bedevil'],
    'harassed': ['annoyed', 'anxious', 'badgered', 'baited', 'bedeviled', 'beset', 'bothered', 'bugged', 'bullyragged', 'chivied', 'deviled', 'distracted'],
    'harassing': ['aggravating', 'annoying', 'bothering', 'bothersome', 'chafing', 'disquieting', 'distressful', 'distressing', 'disturbing', 'exasperating', 'fretting', 'galling'],
    'harassment': ['mccarthyism', 'aggravation', 'annoyance', 'annoyingness', 'bad news', 'bedevilment', 'bore', 'bother', 'botheration', 'bothering', 'bothersomeness', 'crashing bore'],
    'harbinger': ['gabriel', 'ancestor', 'announce', 'announcer', 'antecedent', 'augury', 'avant-garde', 'bellwether', 'buccinator', 'buccinator novi temporis', 'bushwhacker', 'evangel'],
    'harbor': ['accommodate', 'anchorage', 'anchorage ground', 'arm', 'armlet', 'armor', 'asylum', 'basin', 'bay', 'bayou', 'bear', 'bed'],
    'hard': ['herculean', 'philistine', 'about', 'absolute', 'abstruse', 'accented', 'acerb', 'acerbic', 'acrid', 'acrimonious', 'actively', 'acute'],
    'hard and fast': ['absolute', 'aground', 'authoritative', 'binding', 'canonical', 'compulsory', 'conclusive', 'decisive', 'decretory', 'dictated', 'didactic', 'entailed'],
    'hard core': ['adamant', 'adamantine', 'ardent', 'cast-iron', 'dour', 'fanatic', 'fiery', 'firm', 'flaming', 'flinty', 'grim', 'hard'],
    'hard earned': ['herculean', 'abstruse', 'arduous', 'backbreaking', 'brutal', 'burdensome', 'complex', 'critical', 'crushing', 'delicate', 'demanding', 'difficile'],
    'hard feelings': ['acerbity', 'acid', 'acidity', 'acidulousness', 'acrimony', 'animosity', 'animus', 'asperity', 'bad blood', 'bad feeling', 'bile', 'bitter feeling'],
    'hard fought': ['herculean', 'abstruse', 'arduous', 'backbreaking', 'brutal', 'burdensome', 'complex', 'critical', 'crushing', 'delicate', 'demanding', 'difficile'],
    'hard goods': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'dinnerware', 'durable goods', 'durables', 'earthenware', 'enamelware', 'fixtures', 'flatware'],
    'hard hat': ['bircher', 'bourbon', 'tory', 'aegis', 'arm guard', 'backstop', 'buffer', 'bulwark', 'bumper', 'chauvin', 'chauvinist', 'conservatist'],
    'hard job': ['augean task', 'herculean task', 'arduousness', 'backbreaker', 'backbreaking work', 'ballbuster', 'bitch', 'burdensomeness', 'chore', 'dead lift', 'effortfulness', 'handful'],
    'hard labor': ['arduousness', 'backbreaking work', 'burdensomeness', 'confinement', 'dismemberment', 'effortfulness', 'estrapade', 'galleys', 'hard job', 'hard work', 'impalement', 'imprisonment'],
    'hard life': ['adverse circumstances', 'adversity', 'affliction', 'aggravation', 'annoyance', 'blight', 'bummer', 'care', 'cross', 'curse', 'difficulties', 'difficulty'],
    'hard pressed': ['at the double', 'crowded', 'desperate', 'double-quick', 'double-time', 'hard up', 'hard-pressed', 'hard-pushed', 'hard-run', 'hurried', 'in desperate straits', 'in extremis'],
    'hard rock': ['acid rock', 'avant-garde jazz', 'ballroom music', 'bebop', 'boogie-woogie', 'bop', 'country rock', 'dance music', 'dances', 'folk rock', 'hot jazz', 'jazz'],
    'hard stuff': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'hard up': ['badly off', 'desperate', 'distressed', 'down to bedrock', 'embarrassed', 'feeling the pinch', 'hard pressed', 'ill off', 'impecunious', 'in queer street', 'in desperate straits', 'in extremis'],
    'hardcase': ['adverse circumstances', 'adversity', 'affliction', 'aggravation', 'almsman', 'almswoman', 'annoyance', 'bankrupt', 'beggar', 'blight', 'bummer', 'care'],
    'harden': ['acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'anneal', 'be tough', 'beef up', 'brace', 'brace up', 'break'],
    'hardened': ['philistine', 'acclimated', 'acclimatized', 'accommodated', 'accustomed', 'adapted', 'adjusted', 'annealed', 'backed', 'brazen', 'calcified', 'callous'],
    'hardening': ['abidingness', 'acclimation', 'acclimatization', 'accommodation', 'accustoming', 'adaption', 'adjustment', 'agglutination', 'arteriosclerosis', 'atherosclerosis', 'breaking', 'breaking-in'],
    'hardheaded': ['balking', 'balky', 'bigoted', 'bulldogged', 'bulletheaded', 'bullheaded', 'case-hardened', 'dogged', 'dogmatic', 'down-to-earth', 'earthy', 'fanatic'],
    'hardhearted': ['philistine', 'brazen', 'callous', 'calloused', 'case-hardened', 'cold', 'cold of heart', 'coldblooded', 'coldhearted', 'conscienceless', 'flinthearted', 'flinty'],
    'hardihood': ['assurance', 'audacity', 'birr', 'boldness', 'brashness', 'brazenness', 'cockiness', 'disrespect', 'fortitude', 'go', 'grit', 'guts'],
    'hardiness': ['assurance', 'audacity', 'brashness', 'bulldog courage', 'cohesiveness', 'decisiveness', 'durability', 'endurance', 'energy', 'force', 'fortitude', 'gameness'],
    'hardly': ['a bit', 'a little', 'abnormally', 'arduously', 'at infrequent intervals', 'badly', 'barely', 'bitterly', 'burdensomely', 'by a hair', 'by an ace', 'by no means'],
    'hardness': ['philistinism', 'abstruseness', 'arduousness', 'armor', 'asperity', 'astringency', 'austerity', 'bothersomeness', 'burdensomeness', 'callosity', 'callousness', 'callus'],
    'hardnose': ['mafioso', 'young turk', 'ass', 'beast', 'beldam', 'berserk', 'berserker', 'bigot', 'bitter-ender', 'bomber', 'brute', 'bullethead'],
    'hardship': ['adverse circumstances', 'adversity', 'affliction', 'aggravation', 'annoyance', 'asperity', 'austerity', 'bad luck', 'blight', 'broken fortune', 'bummer', 'care'],
    'hardware': ['appliances', 'armaments', 'arms', 'brassware', 'chinaware', 'clayware', 'components', 'computer', 'computer hardware', 'computer unit', 'copperware', 'devices'],
    'hardworking': ['ardent', 'assiduous', 'diligent', 'drudging', 'energetic', 'fervent', 'grinding', 'grubbing', 'hard', 'indefatigable', 'industrious', 'laboring'],
    'hardy': ['abiding', 'able-bodied', 'age-long', 'aged', 'ancient', 'antique', 'beefy', 'bold', 'bold-spirited', 'bouncing', 'brave', 'cartilaginous'],
    'hare': ['angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'indian buffalo', 'kodiak bear', 'virginia deer', 'aardvark', 'aardwolf', 'alpaca', 'anteater', 'antelope'],
    'hare-brained': ['airy', 'asinine', 'brainless', 'crackpot', 'fanciful', 'flighty', 'foolhardy', 'foolish', 'frivolous', 'giddy', 'heedless', 'improvident'],
    'harebrain': ['birdbrain', 'crackbrain', 'crank', 'cuckoo', 'ding-a-ling', 'featherbrain', 'featherhead', 'flibbertigibbet', 'giddybrain', 'giddyhead', 'kook', 'lunatic'],
    'harebrained': ['absurd', 'adventurous', 'arbitrary', 'audacious', 'balmy', 'bold', 'brainless', 'capricious', 'cranky', 'crazy', 'crotchety', 'daredevil'],
    'harelip': ['bowlegs', 'camelback', 'cleft palate', 'clubfoot', 'crookback', 'defacement', 'deformation', 'deformity', 'disfigurement', 'flatfoot', 'freakishness', 'humpback'],
    'hark': ['nb', 'attend', 'attend to', 'auscultate', 'be all ears', 'bend an ear', 'bug', 'cock the ears', 'eavesdrop', 'examine by ear', 'give attention', 'give audience to'],
    'hark back': ['break back', 'bring back', 'bring to mind', 'call back', 'call to mind', 'call up', 'change back', 'conjure up', 'cry back', 'cry back to', 'do a flip-flop', 'do an about-face'],
    'harlequin': ['columbine', 'dalmatian', 'hanswurst', 'pantalone', 'pantaloon', 'polichinelle', 'pulcinella', 'punch', 'punchinello', 'scaramouch', 'antigorite', 'bicolor'],
    'harlot': ['b-girl', 'cyprian', 'paphian', 'bawd', 'call girl', 'courtesan', 'daughter of joy', 'demimondaine', 'demimonde', 'demirep', 'drab', 'erring sister'],
    'harm': ['abomination', 'abuse', 'afflict', 'affliction', 'aggravate', 'aggrieve', 'atrocity', 'bad', 'badness', 'bane', 'banefulness', 'bankruptcy'],
    'harmed': ['aggravated', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped', 'cracked', 'crazed', 'cut', 'damaged', 'deteriorated'],
    'harmful': ['adverse', 'antagonistic', 'bad', 'bad for', 'baleful', 'baneful', 'bitchy', 'conflicting', 'contaminated', 'contrary', 'corroding', 'corrosive'],
    'harmfully': ['balefully', 'banefully', 'corrodingly', 'corrosively', 'counterproductively', 'damagingly', 'deleteriously', 'detrimentally', 'disadvantageously', 'disserviceably', 'hatefully', 'hurtfully'],
    'harmfulness': ['air', 'badness', 'balefulness', 'banefulness', 'bitchiness', 'contamination', 'cussedness', 'deadliness', 'detrimentalness', 'devilment', 'devilry', 'deviltry'],
    'harmless': ['benign', 'bright', 'dependable', 'fail-safe', 'firm', 'fresh', 'gentle', 'guaranteed', 'guiltless', 'innocent', 'innocuous', 'inoffensive'],
    'harmlessness': ['assurance', 'benignancy', 'benignity', 'clear sailing', 'hurtlessness', 'immunity', 'innocence', 'innocuousness', 'inoffensiveness', 'invulnerability', 'protection', 'risklessness'],
    'harmonic': ['af', 'accordant', 'according', 'assonant', 'assonantal', 'attuned', 'audio frequency', 'blended', 'blending', 'chiming', 'concordant', 'consonant'],
    'harmonics': ['accord', 'accordance', 'attune', 'attunement', 'chime', 'chiming', 'concentus', 'concert', 'concord', 'concordance', 'consonance', 'consonancy'],
    'harmonious': ['accompanying', 'accordant', 'according', 'affable', 'affirmative', 'agreeable', 'agreeing', 'akin', 'amiable', 'amicable', 'anal', 'answerable'],
    'harmoniously': ['agreeably', 'as one', 'as one man', 'back to back', 'by consensus', 'coactively', 'coefficiently', 'collectively', 'combinedly', 'communally', 'compatibly', 'concertedly'],
    'harmonium': ['hammond organ', 'baroque organ', 'calliope', 'calliophone', 'choralcelo', 'electric organ', 'electro-pneumatic organ', 'hydraulic organ', 'melodeon', 'melodica', 'orchestrelle', 'organ'],
    'harmonization': ['nachtmusik', 'absolute music', 'accommodation', 'adaptation', 'adjustment', 'air varie', 'aleatory', 'aleatory music', 'arrangement', 'assimilation', 'attunement', 'balancing'],
    'harmonize': ['accommodate', 'accommodate with', 'accord', 'act in concert', 'act together', 'adapt', 'adapt to', 'adjust', 'adjust to', 'affiliate', 'agree', 'agree with'],
    'harmony': ['acclamation', 'accommodation', 'accord', 'accordance', 'acquiescence', 'adaptation', 'adaption', 'adjustment', 'affinity', 'agape', 'agreement', 'agreement of all'],
    'harness': ['accouterments', 'armature', 'armor', 'armor plate', 'back band', 'backstrap', 'bearing rein', 'bed', 'bed down', 'bellyband', 'bit', 'blinders'],
    'harp': ['french harp', 'irish harp', 'aeolian harp', 'cithara', 'clarsach', 'dulcimer', 'harmonica', 'harmonicon', 'heptachord', 'hexachord', 'kazoo', 'langspiel'],
    'harp on': ['accent', 'accentuate', 'always trot out', 'belabor', 'dwell on', 'dwell upon', 'emphasize', 'give emphasis to', 'hammer away at', 'highlight', 'insist upon', 'italicize'],
    'harpoon': ['bag', 'catch', 'enmesh', 'ensnare', 'entangle', 'entrap', 'foul', 'hook', 'land', 'lasso', 'mesh', 'nail'],
    'harpsichord': ['klavier', 'steinway', 'baby grand', 'cembalo', 'clarichord', 'clavicembalo', 'clavichord', 'clavicittern', 'clavicymbal', 'clavicytherium', 'clavier', 'concert grand'],
    'harpy': ['argus', 'briareus', 'cerberus', 'charybdis', 'cyclops', 'echidna', 'gorgon', 'hydra', 'loch ness monster', 'medusa', 'minotaur', 'pegasus'],
    'harridan': ['jezebel', 'baboon', 'bad woman', 'bag', 'baggage', 'bitch', 'blemish', 'blot', 'broad', 'chippy', 'clitoromaniac', 'cocotte'],
    'harried': ['badgered', 'baited', 'bedeviled', 'beset', 'bugged', 'bullyragged', 'chivied', 'deviled', 'dogged', 'fretted', 'harassed', 'haunted'],
    'harrow': ['afflict', 'agonize', 'ail', 'backset', 'badger', 'bait', 'bedevil', 'bite', 'bloody', 'burn', 'chafe', 'claw'],
    'harrowed': ['afflicted', 'agonized', 'clawed', 'convulsed', 'crucified', 'distressed', 'hurt', 'hurting', 'in distress', 'in pain', 'lacerated', 'lancinated'],
    'harrowing': ['acute', 'afflictive', 'agonizing', 'alarming', 'atrocious', 'biting', 'chilling', 'consuming', 'cramping', 'cruel', 'daunting', 'desolating'],
    'harry': ['aggravate', 'ambush', 'annoy', 'assail', 'assault', 'attack', 'badger', 'bait', 'be at', 'bedevil', 'beleaguer', 'beset'],
    'harsh': ['doric', 'draconian', 'spartan', 'spartanic', 'abrupt', 'absonant', 'abusive', 'acerb', 'acerbic', 'acid', 'acidulous', 'acrid'],
    'harshly': ['abruptly', 'austerely', 'badly', 'bearishly', 'bluffly', 'bluntly', 'boorishly', 'brashly', 'brusquely', 'cavalierly', 'churlishly', 'cruelly'],
    'harshness': ['babel', 'gothicism', 'spartanism', 'abominability', 'abruptness', 'acerbity', 'acidity', 'acidulousness', 'acridity', 'acrimony', 'acuteness', 'aggressiveness'],
    'harum scarum': ['accident-prone', 'all over', 'all over hell', 'boisterous', 'breakneck', 'careless', 'desperate', 'devil-may-care', 'every which way', 'furious', 'hasty', 'headlong'],
    'harvest': ['accumulate', 'acquire', 'aftermath', 'amass', 'assemble', 'autumn', 'bag', 'be seized of', 'bearing', 'bin', 'bring in', 'bumper crop'],
    'harvesting': ['architecture', 'assembly', 'building', 'casting', 'composition', 'construction', 'conversion', 'crafting', 'craftsmanship', 'creation', 'crop', 'cropping'],
    'has been': ['methuselah', 'ago', 'antediluvian', 'antiquated', 'antique', 'back number', 'back-number', 'behind the times', 'blown over', 'by', 'bygone', 'bypast'],
    'hash': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'admix', 'all sorts', 'alloy', 'amalgamate', 'antidepressant'],
    'hash mark': ['hershey bar', 'aviation badge', 'badge', 'bar', 'chevron', 'chicken', 'eagle', 'epaulet', 'insignia of branch', 'oak leaf', 'organization insignia', 'overseas bar'],
    'hash up': ['ball up', 'bitch', 'bitch up', 'bobble', 'bollix', 'bollix up', 'bonehead into it', 'bugger', 'bugger up', 'cook', 'drop a brick', 'flub'],
    'hashish': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'diethyltryptamine', 'dimethyltryptamine', 'gage'],
    'hasp': ['articulate', 'batten', 'batten down', 'bolt', 'buckle', 'butt', 'button', 'clasp', 'cleat', 'clip', 'dovetail', 'hinge'],
    'hassle': ['ado', 'agonize', 'altercation', 'anarchy', 'apologetics', 'apologia', 'apology', 'argue', 'argufy', 'argument', 'argumentation', 'bandy words'],
    'hassock': ['eames chair', 'hitchcock chair', 'tv chair', 'armchair', 'armless chair', 'back seat', 'banquette', 'bar stool', 'barber chair', 'barrel chair', 'basket chair', 'batch'],
    'haste': ['air speed', 'alacrity', 'anxiety', 'barrel', 'beeline', 'breathless impatience', 'briskness', 'bucket', 'bustle', 'carelessness', 'celerity', 'chafing'],
    'hasten': ['accelerate', 'advance', 'advantage', 'aid', 'barrel', 'bolt', 'boost', 'bundle', 'burn to', 'bustle', 'career', 'chafe'],
    'hastily': ['a corps perdu', 'abruptly', 'agilely', 'amain', 'apace', 'at flank speed', 'at half cock', 'at once', 'bang', 'by forced marches', 'carelessly', 'cursorily'],
    'hastiness': ['abandon', 'abruptness', 'alacrity', 'careless abandon', 'carelessness', 'casualness', 'cursoriness', 'desperateness', 'devil-may-careness', 'disregardfulness', 'easiness', 'expeditiousness'],
    'hasty': ['a bit previous', 'abrupt', 'accident-prone', 'ad-lib', 'advanced', 'agile', 'antsy', 'antsy-pantsy', 'anxious', 'bearish', 'brash', 'breakneck'],
    'hat': ['balmoral', 'dutch cap', 'panama', 'panama hat', 'salvation army bonnet', 'stetson', 'astrakhan', 'balaclava helmet', 'baseball cap', 'beany', 'bearskin', 'beaver'],
    'hatch': ['french door', 'angle', 'archway', 'autolithograph', 'back door', 'barway', 'be a printmaker', 'be born', 'be gravid', 'be illegitimate', 'be knocked up', 'be pregnant'],
    'hatched': ['bearing', 'born', 'calved', 'cast', 'concocted', 'cooked-up', 'dropped', 'fabricated', 'fabulous', 'fancied', 'fantasied', 'fantastic'],
    'hatchet': ['adz', 'ax', 'battle-ax', 'bread knife', 'bushwhacker', 'butcher knife', 'carving knife', 'chaser', 'chisel', 'cleaver', 'clipper', 'clippers'],
    'hatchet man': ['cain', 'thersites', 'apache', 'assassin', 'assassinator', 'backbiter', 'battler', 'belittler', 'belligerent', 'belted knight', 'bickerer', 'blade'],
    'hatching': ['accouchement', 'arabesque', 'authorship', 'band', 'bar', 'basketry', 'basketwork', 'beginning', 'birth', 'birth throes', 'birthing', 'blessed event'],
    'hate': ['abhor', 'abhorrence', 'abhorrent', 'abominable', 'abominate', 'abomination', 'accursed', 'acrimonious', 'allergy', 'anathema', 'animosity', 'animus'],
    'hateful': ['abhorrent', 'abominable', 'acrid', 'antagonistic', 'antipathetic', 'arrant', 'atrocious', 'awful', 'baleful', 'base', 'beastly', 'belligerent'],
    'hatred': ['anglophobia', 'russophobia', 'abhorrence', 'abomination', 'allergy', 'animosity', 'antagonism', 'anti-semitism', 'antipathy', 'aversion', 'belligerence', 'bigotry'],
    'haughty': ['olympian', 'aerial', 'airy', 'aloof', 'altitudinous', 'arrogant', 'ascending', 'aspiring', 'belittling', 'big', 'boastful', 'cavalier'],
    'haul': ['attraction', 'bag', 'barge', 'blackmail', 'board', 'boat', 'boodle', 'boom', 'boost', 'booty', 'bring to', 'burden'],
    'hauling': ['air express', 'airfreight', 'airlift', 'asportation', 'attraction', 'bearing', 'carriage', 'carry', 'carrying', 'cartage', 'conveyance', 'draft'],
    'haunch': ['bank', 'beam', 'border', 'broadside', 'cheek', 'chop', 'coast', 'flank', 'hand', 'handedness', 'hip', 'jowl'],
    'haunt': ['masan', 'affect', 'apparition', 'appearance', 'astral', 'astral spirit', 'banshee', 'baths', 'beset', 'burden', 'casino', 'club'],
    'haunted': ['beset', 'dogged', 'fretted', 'ghost-haunted', 'ghost-ridden', 'harassed', 'harried', 'hounded', 'mindful', 'nagged', 'obsessed', 'persecuted'],
    'haunting': ['continuous', 'cyclical', 'ever-recurring', 'frequent', 'incessant', 'indelible', 'nagging', 'obsessive', 'periodic', 'persistent', 'reappearing', 'recurrent'],
    'haut monde': ['ffvs', 'vanity fair', 'ancienne noblesse', 'aristocracy', 'baronage', 'baronetage', 'beau monde', 'beautiful people', 'best people', 'blue blood', 'cafe society', 'carriage'],
    'hauteur': ['olympian detachment', 'olympian loftiness', 'airs', 'altitude', 'arrogance', 'arrogantness', 'assumption of superiority', 'ceiling', 'clannishness', 'cliquishness', 'condescendence', 'condescension'],
    'havana': ['burley', 'cuban', 'havana seed', 'latakia', 'maryland', 'russian', 'turkish', 'virginia', 'belvedere', 'box of cigars', 'bright', 'canaster'],
    'have': ['absorb', 'accept', 'acquire', 'admit', 'affirm', 'allege', 'allow', 'annex', 'announce', 'annunciate', 'appreciate', 'apprehend'],
    'have a baby': ['be confined', 'bear', 'bear a child', 'bear young', 'calve', 'cast', 'drop', 'farrow', 'fawn', 'foal', 'give birth', 'have'],
    'have at': ['accept', 'ambush', 'assail', 'assault', 'assume', 'attack', 'attempt', 'blitz', 'buckle to', 'bushwhack', 'come at', 'come down on'],
    'have in hand': ['be enfeoffed of', 'be possessed of', 'be seized of', 'boast', 'claim', 'command', 'control', 'enjoy', 'fill', 'have', 'have and hold', 'have control of'],
    'have in mind': ['anticipate', 'bear in mind', 'brood over', 'cherish', 'consider', 'contemplate', 'dread', 'dwell on', 'dwell upon', 'entertain thoughts of', 'envisage', 'envision'],
    'have it made': ['achieve success', 'advance', 'arrive', 'be a success', 'break through', 'come on', 'come through', 'cut a swath', 'get ahead', 'get on', 'get there', 'go far'],
    'haven': ['anchorage', 'anchorage ground', 'arm', 'armor', 'asylum', 'basin', 'berth', 'bird sanctuary', 'bless', 'bourn', 'breakwater', 'bulkhead'],
    'havoc': ['abomination', 'atrocity', 'bad', 'bane', 'befoulment', 'blight', 'bloodbath', 'blue ruin', 'breakup', 'calamity', 'carnage', 'cataclysm'],
    'haw': ['avert', 'bear off', 'draw aside', 'ease off', 'edge off', 'falter', 'fly off', 'gee', 'glance', 'glance off', 'go off', 'halt'],
    'hawk': ['argus', 'beat', 'cat', 'chase', 'chauvinist', 'course', 'dispense', 'dog', 'dribble', 'drive', 'drivel', 'drool'],
    'hawk eyed': ['argus-eyed', 'all ears', 'all eyes', 'aux aguets', 'cat-eyed', 'clear-eyed', 'clear-sighted', 'custodial', 'eagle-eyed', 'eye-minded', 'farseeing', 'farsighted'],
    'hawking': ['blurred', 'breathy', 'chase', 'chevy', 'chivy', 'choked', 'choking', 'consumer preference study', 'consumer research', 'consumer survey', 'coursing', 'croaking'],
    'hay': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'barley', 'bird seed', 'bran'],
    'hay fever': ['asiatic flu', 'hong kong flu', 'acute bronchitis', 'adenoiditis', 'allergen', 'allergic disorder', 'allergy', 'aluminosis', 'amygdalitis', 'anthracosilicosis', 'anthracosis', 'asbestosis'],
    'hayloft': ['attic', 'attic room', 'cockloft', 'crib', 'elevator', 'garner', 'garret', 'grain bin', 'grain elevator', 'granary', 'haymow', 'hayrick'],
    'haymaker': ['bauer', 'long melford', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'backhand', 'backhander', 'backstroke', 'bolo punch', 'box', 'buffet'],
    'hayseed': ['acorn', 'berry', 'bird seed', 'boor', 'boorish', 'bucolic', 'bumpkin', 'churlish', 'clod', 'cloddish', 'clodhopper', 'clodhopping'],
    'haystack': ['anthill', 'bank', 'cock', 'drift', 'dune', 'embankment', 'haycock', 'haymow', 'hayrick', 'heap', 'hill', 'molehill'],
    'haywire': ['amiss', 'askew', 'awry', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bonkers', 'broken', 'buggy'],
    'hazard': ['accident', 'adventure', 'ante', 'ante up', 'assume', 'attempt', 'back', 'bechance', 'befall', 'bet', 'bet on', 'betide'],
    'hazardous': ['adventurous', 'aleatory', 'chancy', 'dangerous', 'desultory', 'dicey', 'dickey', 'fraught with danger', 'full of risk', 'hairy', 'infirm', 'insecure'],
    'haze': ['london fog', 'london special', 'absentmindedness', 'abstraction', 'banter', 'becloud', 'befog', 'befuddlement', 'bemist', 'bemusement', 'bewilderment', 'bother'],
    'hazel': ['beige', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'chocolate', 'cinnamon', 'cocoa', 'cocoa-brown', 'coffee', 'coffee-brown', 'drab'],
    'haziness': ['amorphia', 'amorphism', 'amorphousness', 'anarchy', 'bleariness', 'blobbiness', 'blur', 'blurriness', 'broadness', 'chaos', 'cloudiness', 'confusion'],
    'hazy': ['addlebrained', 'addled', 'addleheaded', 'addlepated', 'aleatoric', 'aleatory', 'amorphic', 'amorphous', 'anarchic', 'baggy', 'beclouded', 'befuddled'],
    'he': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'bloke', 'boy', 'buck', 'chap', 'ego', 'ethical self', 'fellow'],
    'head': ['a per se', 'adamite', 'big brother', 'lsd user', 'md', 'vernunft', 'wc', 'abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract'],
    'head count': ['account', 'accounts', 'agenda', 'beadroll', 'body count', 'cadastre', 'calendar', 'capitulation', 'census', 'census report', 'checklist', 'checkroll'],
    'head hunter': ['cain', 'apache', 'assassin', 'assassinator', 'bloodletter', 'bloodshedder', 'bravo', 'burker', 'butcher', 'button man', 'cannibal', 'cutthroat'],
    'head off': ['avert', 'bear off', 'draw aside', 'ease off', 'edge off', 'fly off', 'gee', 'glance', 'glance off', 'go off', 'haw', 'jib'],
    'head over heels': ['a corps perdu', 'abruptly', 'anticlockwise', 'around', 'arsy-varsy', 'ass over elbows', 'back-to-front', 'backwards', 'bottom side up', 'bottom up', 'capsized', 'carelessly'],
    'head start': ['advantage', 'allowance', 'anticipation', 'beginnings', 'bulge', 'coign of vantage', 'deadwood', 'draw', 'drop', 'earliness', 'early hour', 'early stage'],
    'head up': ['antecede', 'be in front', 'be responsible for', 'be the front-runner', 'break ground', 'break the ice', 'call the signals', 'captain', 'caption', 'carry on', 'come before', 'come first'],
    'head wind': ['cat', 'aerospace', 'aerosphere', 'air current', 'air hole', 'air pocket', 'airspace', 'backing wind', 'beam wind', 'bucking', 'bump', 'ceiling'],
    'headache': ['ms', 'ache', 'aching', 'ado', 'aggravation', 'amyotrophic lateral sclerosis', 'angina', 'annoyance', 'anxiety', 'backache', 'bad news', 'bane'],
    'headdress': ['afro', 'cap', 'chapeau', 'coif', 'coiffure', 'cold wave', 'conk', 'coverchief', 'haircut', 'hairdo', 'hairstyle', 'handkerchief'],
    'header': ['belly buster', 'belly flop', 'belly whopper', 'cannonball', 'crash dive', 'cropper', 'culbute', 'dive', 'drop', 'fall', 'flop', 'forced landing'],
    'headfirst': ['a corps perdu', 'abruptly', 'carelessly', 'desperately', 'furiously', 'happen what may', 'hastily', 'head over heels', 'headforemost', 'headlong', 'heedlessly', 'heels over head'],
    'headgear': ['back band', 'backstrap', 'bearing rein', 'bellyband', 'bit', 'blinders', 'blinds', 'breeching', 'bridle', 'cap', 'caparison', 'cavesson'],
    'heading': ['aim', 'antecedent', 'anteposition', 'anteriority', 'azimuth', 'banner', 'banner head', 'basis', 'bearing', 'bent', 'blood', 'bold front'],
    'headland': ['beak', 'bill', 'breakwater', 'cape', 'chersonese', 'coral reef', 'delta', 'foreland', 'head', 'hook', 'mull', 'naze'],
    'headless': ['brainless', 'crownless', 'foolish', 'ignorant', 'inept', 'insensate', 'irrational', 'lackbrained', 'lean-minded', 'lean-witted', 'mindless', 'not bright'],
    'headline': ['banner', 'banner head', 'be a gas', 'be a hit', 'bill', 'bomb', 'caption', 'dramatize', 'drop head', 'dropline', 'epigraph', 'fail'],
    'headliner': ['danseur noble', 'diva', 'feature attraction', 'first tragedian', 'heavy lead', 'hero', 'heroine', 'jeune premier', 'lead', 'leading lady', 'leading man', 'prima ballerina'],
    'headlong': ['a corps perdu', 'abrupt', 'abruptly', 'accident-prone', 'agile', 'bluff', 'bold', 'breakneck', 'breathless', 'careless', 'carelessly', 'daredevil'],
    'headman': ['big brother', 'alderman', 'archon', 'auditor', 'bailie', 'boatswain', 'boss', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor'],
    'headmost': ['acmatic', 'ahead', 'antecedent', 'anterior', 'apical', 'arch', 'banner', 'before', 'capital', 'cardinal', 'central', 'champion'],
    'headphone': ['acoustical network', 'capacitor speaker', 'coaxial speaker', 'cone', 'crossover network', 'diaphragm', 'dynamic speaker', 'earphone', 'electrodynamic speaker', 'electromagnetic speaker', 'electrostatic speaker', 'excited-field speaker'],
    'headpiece': ['vernunft', 'bean', 'brain', 'brains', 'brow', 'cap', 'capsheaf', 'caput', 'chapeau', 'conception', 'conk', 'coverchief'],
    'headquarters': ['cp', 'ghq', 'hq', 'base', 'base of operations', 'booking office', 'box office', 'branch', 'branch office', 'cabinet', 'center of authority', 'central administration'],
    'headset': ['acoustical network', 'capacitor speaker', 'coaxial speaker', 'cone', 'crossover network', 'diaphragm', 'dynamic speaker', 'earphone', 'electrodynamic speaker', 'electromagnetic speaker', 'electrostatic speaker', 'excited-field speaker'],
    'headstone': ['arch', 'barrow', 'boundary stone', 'brass', 'bust', 'cairn', 'cenotaph', 'column', 'cornerstone', 'cromlech', 'cross', 'cup'],
    'headstrong': ['balking', 'balky', 'bigoted', 'bulldogged', 'bulletheaded', 'bullheaded', 'case-hardened', 'disobedient', 'dogged', 'dogmatic', 'fanatic', 'hardheaded'],
    'headwater': ['font', 'fount', 'fountain', 'fountainhead', 'head', 'headspring', 'headstream', 'headwaters', 'mainspring', 'mine', 'quarry', 'riverhead'],
    'headway': ['great leap forward', 'advance', 'advancement', 'advancing', 'amelioration', 'amendment', 'anabasis', 'ascent', 'bettering', 'betterment', 'boost', 'career'],
    'headwork': ['abstract thought', 'act of thought', 'application', 'boning', 'brainwork', 'cerebration', 'cogitation', 'conceit', 'conception', 'conceptualization', 'conning', 'contemplation'],
    'heady': ['agitating', 'astute', 'barmy', 'breathtaking', 'cagey', 'charged', 'cliff-hanging', 'disobedient', 'disquieting', 'distracting', 'disturbing', 'electric'],
    'heal': ['bandage', 'bathe', 'bring around', 'bring round', 'care for', 'cicatrize', 'close up', 'cure', 'diagnose', 'doctor', 'flux', 'give care to'],
    'healing': ['adjuvant', 'alterative', 'analeptic', 'corrective', 'curative', 'cure', 'curing', 'divine healing', 'faith healing', 'iatric', 'medicative', 'medicinal'],
    'health': ['condition', 'constitution', 'euphoria', 'fettle', 'fitness', 'form', 'haleness', 'healthfulness', 'healthiness', 'naturalism', 'naturalness', 'naturism'],
    'health food': ['board', 'bread', 'bread and butter', 'caudle', 'cheer', 'comestibles', 'cottonseed flour', 'creature comfort', 'cuisine', 'daily bread', 'eatables', 'edibles'],
    'health resort': ['baths', 'casino', 'club', 'clubhouse', 'gambling house', 'gathering place', 'hangout', 'haunt', 'hot spring', 'meeting place', 'mineral spring', 'pump house'],
    'healthful': ['advantageous', 'aiding', 'alive and kicking', 'alleviative', 'beneficial', 'benign', 'bracing', 'bright-eyed and bushy-tailed', 'chipper', 'constitutional', 'corrective', 'curative'],
    'healthiness': ['advantageousness', 'agreeableness', 'auspiciousness', 'beneficialness', 'benevolence', 'benignity', 'class', 'cogency', 'desert', 'eupepsia', 'excellence', 'expedience'],
    'healthy': ['advantageous', 'alive and kicking', 'auspicious', 'beneficial', 'benevolent', 'benign', 'big', 'bon', 'bonny', 'bracing', 'braw', 'bright-eyed and bushy-tailed'],
    'heap': ['abundance', 'accord', 'accumulate', 'accumulation', 'administer', 'afford', 'agglomeration', 'aggregate', 'aggregation', 'allot', 'allow', 'amass'],
    'hear': ['apprehend', 'approve of', 'arbitrate', 'ascertain', 'attend', 'attend to', 'auscultate', 'be all ears', 'be aware of', 'be conscious of', 'be informed', 'be sensible of'],
    'hearer': ['accepter', 'acquirer', 'addressee', 'audience', 'audient', 'auditor', 'beholder', 'consignee', 'eavesdropper', 'getter', 'hearkener', 'holder'],
    'hearing': ['gedankenexperiment', 'acoustic', 'amassing evidence', 'assize', 'attention', 'audible', 'audience', 'audile', 'audio', 'audition', 'auditory', 'auditory range'],
    'hearken': ['attend', 'attend to', 'auscultate', 'be all ears', 'bend an ear', 'bug', 'cock the ears', 'eavesdrop', 'examine by ear', 'give attention', 'give audience to', 'give ear'],
    'hearken to': ['attend to orders', 'be all ears', 'comply', 'conform', 'defer to', 'follow the book', 'give ear to', 'hark', 'harken to', 'hear', 'heed', 'keep'],
    'hearsay': ['absolute', 'adducible', 'admissible', 'attestative', 'attestive', 'authentic', 'based on', 'bruit', 'buzz', 'canard', 'certain', 'circumstantial'],
    'heart': ['amor', 'benzedrine', 'benzedrine pill', 'christian love', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'eros', 'methedrine', 'abatis', 'abdomen'],
    'heart and soul': ['ad infinitum', 'all over', 'ardently', 'arduously', 'at all points', 'at full length', 'bec et ongles', 'breathlessly', 'committedly', 'cordially', 'decidedly', 'decisively'],
    'heart attack': ['angina', 'angina pectoris', 'aortic insufficiency', 'aortic stenosis', 'apoplectic stroke', 'apoplexy', 'arrhythmia', 'arteriosclerosis', 'atherosclerosis', 'atrial fibrillation', 'auricular fibrillation', 'beriberi heart'],
    'heart disease': ['angina', 'angina pectoris', 'aortic insufficiency', 'aortic stenosis', 'apoplectic stroke', 'apoplexy', 'arrhythmia', 'arteriosclerosis', 'atherosclerosis', 'atrial fibrillation', 'auricular fibrillation', 'beriberi heart'],
    'heart failure': ['angina', 'angina pectoris', 'aortic insufficiency', 'aortic stenosis', 'apoplectic stroke', 'apoplexy', 'arrhythmia', 'arteriosclerosis', 'atherosclerosis', 'atrial fibrillation', 'auricular fibrillation', 'beriberi heart'],
    'heart of gold': ['affectionateness', 'benignancy', 'benignity', 'brotherhood', 'compassion', 'feeling of kinship', 'fellow feeling', 'fraternal feeling', 'goodness', 'goodness of heart', 'graciousness', 'humaneness'],
    'heart warming': ['affable', 'agreeable', 'amiable', 'amicable', 'animating', 'blissful', 'cheerful', 'cheering', 'cheery', 'compatible', 'complaisant', 'congenial'],
    'heartache': ['aching heart', 'affliction', 'agony', 'agony of mind', 'anguish', 'bale', 'bitterness', 'bleeding heart', 'broken heart', 'brokenheartedness', 'care', 'crushing'],
    'heartbeat': ['anima', 'animating force', 'arrhythmia', 'atman', 'bathmism', 'beat', 'beating', 'beating heart', 'biological clock', 'biorhythm', 'blood', 'breath'],
    'heartbreak': ['aching heart', 'affliction', 'agonizingness', 'agony', 'anguish', 'bale', 'bleeding heart', 'broken heart', 'brokenheartedness', 'care', 'desolateness', 'desolation'],
    'heartbreaking': ['afflictive', 'agonizing', 'calamitous', 'consuming', 'desolating', 'dire', 'distressing', 'excruciating', 'grievous', 'harrowing', 'heartrending', 'heartsickening'],
    'heartbroken': ['broken-down', 'brokenhearted', 'crestfallen', 'crushed', 'cut up', 'dejected', 'depressed', 'desolated', 'despondent', 'disappointed', 'disconsolate', 'disheartened'],
    'heartburn': ['ache', 'aching', 'angina', 'backache', 'bellyache', 'cardialgia', 'cephalalgia', 'cholera morbus', 'colic', 'collywobbles', 'constipation', 'costiveness'],
    'hearten': ['abet', 'advocate', 'aid and abet', 'animate', 'arouse', 'assure', 'bear up', 'bolster', 'boost', 'brace up', 'brighten', 'buck up'],
    'heartening': ['animating', 'assurance', 'assuring', 'cheerful', 'cheering', 'cheery', 'comforting', 'condolatory', 'condolent', 'condoling', 'consolatory', 'consoling'],
    'heartfelt': ['absorbing', 'acute', 'ardent', 'bona fide', 'committed', 'dedicated', 'deep', 'deep-felt', 'deepgoing', 'devoted', 'earnest', 'fervent'],
    'hearth': ['ancestral halls', 'brood', 'children', 'chimney', 'chimney corner', 'family', 'family homestead', 'fender', 'fire screen', 'fireboard', 'fireguard', 'fireplace'],
    'heartily': ['actively', 'agreeably', 'amiably', 'amicably', 'animatedly', 'ardently', 'arm in arm', 'breathlessly', 'briskly', 'con brio', 'congenially', 'cordially'],
    'heartland': ['airspace', 'area', 'belt', 'confines', 'continental shelf', 'corridor', 'country', 'department', 'district', 'division', 'environs', 'ground'],
    'heartless': ['laodicean', 'olympian', 'affectless', 'aloof', 'anesthetized', 'apathetic', 'arctic', 'autistic', 'benumbed', 'blah', 'blase', 'blunt'],
    'heartlessly': ['apathetically', 'chickenheartedly', 'cold-bloodedly', 'coldheartedly', 'coldly', 'cravenly', 'cruelly', 'deadpan', 'dejectedly', 'despairingly', 'despondently', 'discouragedly'],
    'heartrending': ['affecting', 'afflictive', 'agonizing', 'calamitous', 'consuming', 'desolating', 'dire', 'distressing', 'doleful', 'excruciating', 'grievous', 'harrowing'],
    'hearts-and-flowers': ['bathos', 'bleeding heart', 'cloyingness', 'goo', 'maudlinness', 'mawkishness', 'mush', 'mushiness', 'namby-pamby', 'namby-pambyism', 'namby-pambyness', 'nostalgia'],
    'heartsick': ['blue', 'cast down', 'comfortless', 'crushed', 'cut up', 'deep-troubled', 'dejected', 'depressed', 'desolate', 'desole', 'disconsolate', 'dispirited'],
    'heartthrob': ['affect', 'affection', 'arrhythmia', 'beat', 'beating', 'beloved', 'darling', 'drumming', 'emotion', 'emotional charge', 'emotional shade', 'experience'],
    'hearty': ['ab', 'ancient mariner', 'argonaut', 'dylan', 'flying dutchman', 'neptune', 'od', 'poseidon', 'varuna', 'abandoned', 'ablaze', 'able seaman'],
    'heat': ['john law', 'le mans', 'a transient madness', 'abandon', 'activate', 'agitate', 'agitation', 'air race', 'anger', 'angriness', 'animate', 'annoy'],
    'heat up': ['accelerate', 'agent provocateur', 'aggravate', 'agitate', 'alienate', 'amplify', 'annoy', 'antagonize', 'arouse', 'augment', 'beef up', 'blow the coals'],
    'heated': ['abandoned', 'ablaze', 'acrimonious', 'afire', 'angry', 'ardent', 'aroused', 'baked', 'baking', 'bitter', 'blistering', 'boiled'],
    'heater': ['bunsen burner', 'dutch oven', 'automatic', 'bedpan', 'bloom heater', 'blowgun', 'blowpipe', 'brazier', 'brick oven', 'burner', 'calefactory', 'caliduct'],
    'heath': ['arabia deserta', 'death valley', 'sahara', 'alkali flat', 'alluvial plain', 'barren', 'barren land', 'barrens', 'basin', 'bottomland', 'brush', 'bush'],
    'heathen': ['gothic', 'philistine', 'agnostic', 'allotheist', 'allotheistic', 'animist', 'animistic', 'atheist', 'atheistic', 'barbarian', 'barbaric', 'barbarous'],
    'heathenism': ['druidism', 'gothicism', 'parsiism', 'sabaism', 'zoroastrianism', 'age of ignorance', 'allotheism', 'animal worship', 'animatism', 'animism', 'barbarism', 'benightedness'],
    'heating': ['animal heat', 'blood heat', 'body heat', 'burning', 'calefacient', 'calefactive', 'calefactory', 'calidity', 'caloric', 'cauterant', 'chafing', 'coal heat'],
    'heave': ['a leg up', 'aye', 'barf', 'be nauseated', 'be poised', 'be seasick', 'be sick', 'billow', 'blow', 'board', 'boom', 'boost'],
    'heaven': ['agapemone', 'arcadia', 'avalon', 'big rock-candy mountain', 'caelus', 'canaan', 'civitas dei', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon'],
    'heavenly': ['arcadian', 'christlike', 'christly', 'cynthian', 'edenic', 'elysian', 'god-fearing', 'olympian', 'adorable', 'ambrosial', 'anagalactic', 'angelic'],
    'heavily': ['apathetically', 'aridly', 'barrenly', 'bleakly', 'bloodlessly', 'burdensomely', 'close', 'closely', 'coldly', 'colorlessly', 'compactly', 'cumbersomely'],
    'heavy': ['herculean', 'latinate', 'ok', 'roscius', 'abeyant', 'abstruse', 'abundant', 'accented', 'ace-high', 'actor', 'actress', 'acute'],
    'heavy hand': ['argumentum baculinum', 'big stick', 'despotism', 'domination', 'domineering', 'fascism', 'firm hand', 'high hand', 'iron boot', 'iron hand', 'iron heel', 'oppression'],
    'heavy handed': ['all thumbs', 'awkward', 'blunderheaded', 'blundering', 'boorish', 'bumbling', 'bungling', 'butterfingered', 'careless', 'clownish', 'clumsy', 'clumsy-fisted'],
    'heavy heart': ['aching heart', 'agony', 'agony of mind', 'anguish', 'bale', 'bathos', 'bitterness', 'bleeding heart', 'broken heart', 'crushing', 'depression', 'depth of misery'],
    'heavy-handed': ['autocratic', 'awkward', 'bungling', 'clumsy', 'despotic', 'dictatorial', 'domineering', 'graceless', 'harsh', 'imperious', 'inept', 'magisterial'],
    'heavyset': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'broad-bodied', 'bulky', 'bullnecked', 'burly', 'buxom'],
    'heavyweight': ['chinese boxer', 'rasputin', 'svengali', 'vip', 'access', 'bad influence', 'bantamweight', 'big', 'big boy', 'big cheese', 'big wheel', 'big-league'],
    'hebetude': ['acedia', 'aloofness', 'apathy', 'asininity', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'blockishness', 'boobishness', 'boorishness'],
    'heckle': ['aggravate', 'annoy', 'badger', 'bait', 'barrack', 'be at', 'bedevil', 'beset', 'bother', 'bristle', 'brown off', 'bug'],
    'heckled': ['badgered', 'baited', 'bedeviled', 'beset', 'bugged', 'bullyragged', 'chivied', 'deviled', 'dogged', 'harassed', 'harried', 'hectored'],
    'hectic': ['agitated', 'at fever pitch', 'bloom', 'blooming', 'blowzed', 'blowzy', 'blush', 'blushing', 'boiling', 'boiling over', 'burning', 'burning with excitement'],
    'hector': ['captain bobadil', 'gascon', 'herod', 'texan', 'aggravate', 'annoy', 'badger', 'bait', 'be at', 'bedevil', 'beset', 'big mouth'],
    'hedge': ['abate', 'about the bush', 'adjust to', 'allowance', 'alter', 'around the bush', 'assuage', 'bar', 'beat about', 'beat around', 'beg the question', 'bicker'],
    'hedging': ['allowance', 'bickering', 'boggling', 'calculation', 'canniness', 'captious', 'captiousness', 'care', 'careful consideration', 'carefulness', 'caution', 'cautiousness'],
    'hedonism': ['christian ethics', 'cyrenaic hedonism', 'cyrenaicism', 'stoicism', 'altruistic ethics', 'appetite', 'appetitiveness', 'aretaics', 'casuistry', 'categorical imperative', 'comparative ethics', 'deontology'],
    'hedonist': ['cyrenaic', 'heliogabalus', 'sardanapalus', 'bon vivant', 'carpet knight', 'debauchee', 'epicure', 'epicurean', 'gourmand', 'gourmet', 'libertine', 'man-about-town'],
    'hedonistic': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'animist', 'animistic', 'appetitive', 'atomistic', 'bent on pleasure', 'cosmotheistic', 'eclectic'],
    'heebie jeebies': ['all-overs', 'blue johnnies', 'blue devils', 'cold shivers', 'cold sweat', 'dither', 'dithers', 'jimjams', 'jitters', 'jumps', 'pink elephants', 'pink spiders'],
    'heed': ['tlc', 'abide by', 'accept', 'accordance', 'acquittal', 'acquittance', 'act up to', 'adhere to', 'adherence', 'advertence', 'advertency', 'alertness'],
    'heedful': ['accommodating', 'accommodative', 'advertent', 'agog', 'agreeable', 'alert', 'all ears', 'all eyes', 'assiduous', 'attentive', 'aware', 'canny'],
    'heeding': ['accordance', 'acquittal', 'acquittance', 'adherence', 'attention', 'audibility', 'audition', 'aural examination', 'aural sense', 'auscultation', 'care', 'carrying out'],
    'heedless': ['lethean', 'absentminded', 'airy', 'aloof', 'amnestic', 'apathetic', 'arbitrary', 'ataractic', 'blase', 'blind', 'blocked', 'bored'],
    'heedlessly': ['a corps perdu', 'airily', 'any old way', 'any which way', 'anyhow', 'apathetically', 'bunglingly', 'carelessly', 'casually', 'clumsily', 'cursorily', 'desperately'],
    'heel': ['sob', 'accouter', 'afterpart', 'afterpiece', 'appoint', 'arch', 'arm', 'back', 'back door', 'back seat', 'back side', 'balance'],
    'heeler': ['conservative', 'democrat', 'labourite', 'republican', 'tory', 'whig', 'adherent', 'appendage', 'dangler', 'dependent', 'follower', 'hanger-on'],
    'heft': ['avoirdupois', 'balance', 'be heavy', 'beef', 'beefiness', 'boost', 'buoy up', 'carry weight', 'cast up', 'counterbalance', 'deadweight', 'elevate'],
    'hefty': ['herculean', 'adipose', 'annoying', 'arduous', 'awkward', 'backbreaking', 'beefy', 'besetting', 'big', 'big-bellied', 'bloated', 'blowzy'],
    'hegira': ['awol', 'french leave', 'abandonment', 'absence without leave', 'absquatulation', 'bolt', 'decampment', 'departure', 'desertion', 'disappearance', 'disappearing act', 'egress'],
    'heifer': ['brahman', 'indian buffalo', 'partlet', 'aurochs', 'babe', 'baby', 'beef', 'beef cattle', 'beeves', 'biddy', 'bison', 'bitch'],
    'height': ['french pitch', 'olympian heights', 'acme', 'acme of perfection', 'aerial heights', 'altitude', 'amount', 'amplitude', 'apex', 'apogee', 'apotheosis', 'area'],
    'heighten': ['accelerate', 'add to', 'agent provocateur', 'aggrandize', 'aggravate', 'amplify', 'annoy', 'augment', 'beef up', 'better', 'blow up', 'boost'],
    'heightened': ['accelerated', 'aggrandized', 'aggravated', 'amplified', 'annoyed', 'augmented', 'beefed-up', 'bloated', 'boosted', 'broadened', 'deepened', 'deliberately provoked'],
    'heightening': ['accelerando', 'acceleration', 'aggrandizement', 'aggravation', 'amplification', 'annoyance', 'augmentation', 'ballyhoo', 'beefing-up', 'big talk', 'blowing up', 'blowup'],
    'heinous': ['abhorrent', 'abject', 'abominable', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beggarly', 'below contempt', 'beneath contempt'],
    'heir': ['aftermath', 'apparent heir', 'backup man', 'beneficiary', 'beneficiary heir', 'breed', 'brood', 'children', 'conclusion', 'consequence', 'coparcener', 'descendant'],
    'heir apparent': ['muslim rulers', 'prinz', 'apparent heir', 'atheling', 'beneficiary heir', 'coparcener', 'crown prince', 'emir', 'fideicommissary heir', 'fiduciary heir', 'heir', 'heir expectant'],
    'heiress': ['apparent heir', 'beneficiary heir', 'child', 'coparcener', 'daughter', 'descendant', 'fideicommissary heir', 'fiduciary heir', 'foster child', 'grandchild', 'granddaughter', 'grandson'],
    'heirloom': ['bequeathal', 'bequest', 'birthright', 'borough-english', 'coheirship', 'coparcenary', 'entail', 'gavelkind', 'heirship', 'hereditament', 'heritable', 'heritage'],
    'heist': ['armed robbery', 'asportation', 'assault and robbery', 'banditry', 'bank robbery', 'boost', 'buoy up', 'burglary', 'caper', 'cast up', 'cattle lifting', 'cattle stealing'],
    'held': ['aground', 'anchored', 'arrested', 'based on', 'besotted', 'bolstered', 'borne', 'braced', 'buttressed', 'by one', 'caught', 'chained'],
    'held up': ['arrested', 'back', 'backward', 'behindhand', 'belated', 'blocked', 'delayed', 'delayed-action', 'detained', 'hung up', 'in a bind', 'in abeyance'],
    'helical': ['o-shaped', 'ambagious', 'anfractuous', 'backhanded', 'circuitous', 'circular', 'cochlear', 'cochleate', 'corkscrew', 'corkscrewy', 'deviating', 'deviative'],
    'helios': ['agdistis', 'amen-ra', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres'],
    'heliport': ['aerodrome', 'air base', 'airdrome', 'airfield', 'airport', 'balcony', 'catafalque', 'dais', 'emplacement', 'estrade', 'field', 'floor'],
    'helix': ['cirrus', 'coil', 'corkscrew', 'curl', 'curlicue', 'evolute', 'gyre', 'involute', 'kink', 'ringlet', 'roll', 'screw'],
    'hell': ['abaddon', 'acheron', 'babel', 'dis', 'erebus', 'gehenna', 'hades', 'pandemonium', 'sheol', 'styx', 'tartarus', 'tophet'],
    'hell bent': ['amain', 'apace', 'at flank speed', 'bent on', 'dead set on', 'decided upon', 'determined upon', 'double-quick', 'expeditiously', 'fast', 'fixed upon', 'hand over fist'],
    'hell raiser': ['mafioso', 'young turk', 'beast', 'beldam', 'berserk', 'berserker', 'bomber', 'bravo', 'brute', 'bucko', 'bully', 'bullyboy'],
    'hell to pay': ['bind', 'clutch', 'complication', 'crunch', 'embarrassing position', 'embarrassment', 'fine how-do-you-do', 'hobble', 'hot water', 'how-do-you-do', 'imbroglio', 'jam'],
    'hellcat': ['jezebel', 'mafioso', 'young turk', 'adventurer', 'adventuress', 'beast', 'beldam', 'berserk', 'berserker', 'bitch-kitty', 'bomber', 'bravo'],
    'hellion': ['baba yaga', 'lilith', 'mafioso', 'young turk', 'afreet', 'barghest', 'beast', 'beldam', 'berserk', 'berserker', 'bomber', 'bruiser'],
    'hellish': ['acherontic', 'draconian', 'lethean', 'mephistophelian', 'plutonian', 'plutonic', 'stygian', 'tartarean', 'anarchic', 'angry', 'animal', 'anthropophagous'],
    'hello': ['accost', 'address', 'bob', 'bow', 'curtsy', 'embrace', 'greeting', 'hail', 'hand-clasp', 'handshake', 'how-do-you-do', 'hug'],
    'helm': ['automatic pilot', 'bench', 'chair', 'chairmanship', 'chart a course', 'claws', 'clutches', 'command', 'cond', 'conn', 'control', 'coxswain'],
    'helmet': ['achievement', 'aegis', 'alerion', 'animal charge', 'annulet', 'argent', 'arm guard', 'armorial bearings', 'armory', 'arms', 'azure', 'backstop'],
    'helmsman': ['gyropilot', 'automatic pilot', 'boatheader', 'boatsteerer', 'cicerone', 'conner', 'courier', 'cowherd', 'cox', 'coxswain', 'docking pilot', 'dragoman'],
    'helot': ['apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'bootlick', 'bootlicker', 'brown-nose'],
    'help': ['samaritan', 'abet', 'acolyte', 'adjutant', 'administer to', 'advance', 'advantage', 'advise', 'agent', 'aid', 'aide', 'aide-de-camp'],
    'helper': ['samaritan', 'acolyte', 'adjutant', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider', 'ancilla', 'assistant', 'assister', 'associate'],
    'helpful': ['accommodating', 'accommodative', 'advantageous', 'agential', 'agentival', 'agentive', 'agreeable', 'aidful', 'aiding', 'appropriate', 'assisting', 'attentive'],
    'helping': ['accessory', 'adjuvant', 'allotment', 'allowance', 'ancillary', 'antepast', 'assistant', 'assisting', 'attendant', 'attending', 'auxiliary', 'big end'],
    'helping hand': ['samaritan', 'aid', 'aider', 'assist', 'assister', 'backer', 'befriender', 'benefactor', 'benefactress', 'benefiter', 'boost', 'good samaritan'],
    'helpless': ['abandoned', 'aidless', 'at sea', 'baffled', 'bare-handed', 'bewildered', 'blind', 'blind drunk', 'blotto', 'confounded', 'confused', 'crippled'],
    'helpmate': ['acolyte', 'adjutant', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider', 'assistant', 'attendant', 'auxiliary', 'best man', 'better half'],
    'helter skelter': ['a corps perdu', 'ado', 'airily', 'all over', 'all over hell', 'amain', 'anarchic', 'any old way', 'any which way', 'anyhow', 'apace', 'arsy-varsiness'],
    'hem': ['adjoin', 'bank', 'bar', 'beading', 'befringe', 'begird', 'beset', 'bind', 'binding', 'board', 'border', 'bordering'],
    'hem and haw': ['about the bush', 'back and fill', 'back down', 'balance', 'beat around', 'beg the question', 'debate', 'deliberate', 'demur', 'dodge', 'duck', 'equivocate'],
    'hem in': ['beleaguer', 'beset', 'besiege', 'blockade', 'bottle up', 'bound', 'box', 'box in', 'box up', 'cage', 'chamber', 'check'],
    'hemisphere': ['ambit', 'arena', 'bailiwick', 'beat', 'border', 'borderland', 'circle', 'circuit', 'demesne', 'department', 'domain', 'dominion'],
    'hemlock': ['beheading', 'belladonna', 'burning', 'capital punishment', 'castor-oil plant', 'crucifixion', 'deadly nightshade', 'death camas', 'decapitation', 'decollation', 'defenestration', 'electrocution'],
    'hemmed in': ['barred', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'boxed in', 'cabined', 'caged', 'circumscribed', 'cloistered', 'closed-in'],
    'hemoglobin': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'albumin', 'albuminoid', 'antibody', 'antigen', 'arterial blood', 'blood', 'blood bank'],
    'hemophilia': ['christmas disease', 'hartnup disease', 'letterer-siwe syndrome', 'werdnig-hoffmann disease', 'achromatic vision', 'acute leukemia', 'albinism', 'anemia', 'angiohemophilia', 'aplastic anemia', 'chronic leukemia', 'color blindness'],
    'hemorrhage': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'bleed'],
    'hemp': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'ax', 'block', 'cross'],
    'hen': ['bantam', 'jane', 'partlet', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'bird', 'bitch', 'bossy', 'broad', 'broiler'],
    'hence': ['accordingly', 'as a result', 'away', 'because of that', 'because of this', 'consequently', 'ergo', 'for that', 'for that cause', 'for that reason', 'for this cause', 'for this reason'],
    'henchman': ['adherent', 'appendage', 'associate', 'attendant', 'bodyguard', 'buddy', 'buff', 'cavaliere servente', 'cohort', 'confidant', 'courtier', 'creature'],
    'henna': ['titian', 'adust', 'auburn', 'bay', 'bay-colored', 'bayard', 'brazen', 'bronze', 'bronze-colored', 'bronzed', 'brownish-red', 'castaneous'],
    'henpeck': ['beat down', 'break', 'browbeat', 'bug', 'bulldoze', 'bully', 'carp', 'carp at', 'castrate', 'cavil', 'clamp down on', 'coerce'],
    'henpecked': ['abused', 'browbeaten', 'downtrod', 'downtrodden', 'ground down', 'in leading strings', 'misused', 'on a leash', 'on a string', 'oppressed', 'ordered around', 'overborne'],
    'hep': ['alive to', 'appreciative of', 'apprised of', 'awake to', 'aware of', 'behind the curtain', 'behind the scenes', 'canny', 'cognizant of', 'conscious of', 'hep to', 'in the know'],
    'hepatitis': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'adenoiditis', 'adrenitis', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery'],
    'hephaestus': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'her': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'ego', 'ethical self', 'female', 'female being', 'he', 'herself', 'him'],
    'hera': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'herald': ['clarenceux', 'college of arms', 'gabriel', 'garter', 'lyon', 'norroy', 'norroy and ulster', 'ancestor', 'announce', 'announcer', 'antecede', 'antecedent'],
    'heraldry': ['armory', 'badge', 'badge of office', 'badges', 'baton', 'blazonry', 'brassard', 'button', 'cap and gown', 'chain', 'chain of office', 'circumstance'],
    'herb': ['cretan dittany', 'algae', 'angelica', 'autophyte', 'balm', 'balsam', 'basil', 'bean', 'belladonna', 'boneset', 'borage', 'bracken'],
    'herbaceous': ['botanic', 'bulbous', 'cereal', 'farinaceous', 'fruitlike', 'fruity', 'herbal', 'herbose', 'herbous', 'herby', 'leguminose', 'leguminous'],
    'herbarium': ['japanese garden', 'alpine garden', 'arboretum', 'bed', 'bog garden', 'border', 'botanical garden', 'dry garden', 'flower bed', 'flower garden', 'garden', 'garden spot'],
    'herbicide': ['aborticide', 'acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bug bomb', 'carbamate insecticide', 'chemosterilant', 'contact poison', 'defoliant', 'disinfectant', 'eradicant'],
    'herbivore': ['brillat-savarin', 'lucullus', 'amphibian', 'aquatic', 'biped', 'board-and-roomer', 'boarder', 'bon vivant', 'canine', 'cannibal', 'carnivore', 'connoisseur of food'],
    'herbivorous': ['cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'dining', 'eating', 'feeding', 'flesh-eating', 'fruitarian', 'gastronomic', 'gluttonous'],
    'herculean': ['antaean', 'atlantean', 'briarean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'homeric', 'abstruse', 'abysmal', 'arduous', 'astronomic', 'backbreaking'],
    'hercules': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'gargantua', 'goliath', 'orion', 'polyphemus', 'samson', 'superman'],
    'herd': ['gyropilot', 'army', 'assemblage', 'assemble', 'automatic pilot', 'boatheader', 'boatsteerer', 'bunch', 'cage', 'cicerone', 'cluster', 'collect'],
    'herd together': ['accompany', 'assemble', 'associate', 'associate with', 'assort with', 'attend', 'band together', 'bunch', 'bunch up', 'chum', 'chum together', 'chum with'],
    'herder': ['cattleman', 'cowboy', 'cowgirl', 'cowhand', 'cowherd', 'cowman', 'cowpuncher', 'drover', 'gaucho', 'goatherd', 'gooseboy', 'gooseherd'],
    'herdsman': ['gyropilot', 'automatic pilot', 'boatheader', 'boatsteerer', 'cattleman', 'cicerone', 'courier', 'cowboy', 'cowgirl', 'cowhand', 'cowherd', 'cowman'],
    'here': ['aboard', 'among us', 'as of now', 'as things are', 'at present', 'at this juncture', 'at this moment', 'at this point', 'at this time', 'but now', 'even now', 'for the nonce'],
    'here and there': ['at intervals', 'at large', 'at times', 'betimes', 'brokenly', 'by catches', 'by fits', 'by jerks', 'by skips', 'by snatches', 'diffusely', 'disconnectedly'],
    'hereafter': ['heaven', 'paradise', 'a better place', 'afterlife', 'afterworld', 'approaching', 'coming', 'desired', 'destinal', 'destined', 'destiny', 'determined'],
    'hereby': ['by', 'by dint of', 'by means of', 'by use of', 'by virtue of', 'by way of', 'herewith', 'in virtue of', 'on', 'per', 'thanks to', 'thereby'],
    'hereditary': ['ancestral', 'atavistic', 'bequeathed', 'bodily', 'born', 'coeval', 'congenital', 'connatal', 'connate', 'connatural', 'constitutional', 'genetic'],
    'heredity': ['altmann theory', 'dna', 'dna double helix', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory'],
    'heresy': ['albigensianism', 'arianism', 'bohemianism', 'catharism', 'ebionitism', 'erastianism', 'gnosticism', 'jovinianism', 'lollardy', 'manichaeanism', 'manichaeism', 'monophysism'],
    'heretic': ['albigensian', 'arian', 'bohemian', 'cathar', 'donatist', 'ebionite', 'erastian', 'gnostic', 'jansenist', 'lollard', 'manichaean', 'monophysite'],
    'heretical': ['albigensian', 'arian', 'bohemian', 'catharist', 'donatist', 'ebionitist', 'erastian', 'gnostic', 'jansenist', 'jansenistic', 'jovinianist', 'jovinianistic'],
    'heretofore': ['aforetime', 'already', 'as yet', 'before', 'before all', 'before now', 'beforetime', 'by this time', 'earlier', 'early', 'ere', 'ere then'],
    'herewith': ['arm in arm', 'by', 'by dint of', 'by means of', 'by use of', 'by virtue of', 'by way of', 'cheek by jowl', 'hand in glove', 'hand in hand', 'hereby', 'in virtue of'],
    'heritage': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory', 'allele'],
    'hermes': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'hermetic': ['abstruse', 'airtight', 'arcane', 'ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'cabalistic', 'censored', 'classified', 'cloistered', 'close'],
    'hermit': ['albigensian', 'catharist', 'diogenes', 'franciscan', 'hieronymian', 'hieronymite', 'sabbatarian', 'timon of athens', 'trappist', 'waldensian', 'abbacomes', 'abbot'],
    'hermitage': ['adytum', 'ashram', 'cell', 'cloister', 'den', 'hideaway', 'hideout', 'hiding place', 'holy of holies', 'ivory tower', 'lair', 'mew'],
    'hero': ['achilles', 'david', 'hector', 'roland', 'samson', 'a man', 'acme', 'actor', 'antagonist', 'antihero', 'apotheosis', 'beau ideal'],
    'hero worship': ['amor', 'christian love', 'druidism', 'eros', 'parsiism', 'platonic love', 'sabaism', 'zoroastrianism', 'accolade', 'accord respect to', 'admiration', 'admire'],
    'heroic': ['alcaic', 'anacreontic', 'atlantean', 'brobdingnagian', 'castalian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'hudibrastic', 'pierian', 'pindaric'],
    'heroically': ['audaciously', 'boldly', 'bravely', 'bulldoggishly', 'chivalrously', 'courageously', 'daringly', 'dauntlessly', 'doughtily', 'fearlessly', 'gallantly', 'gamely'],
    'heroics': ['bluster', 'boast', 'boastfulness', 'boasting', 'bombast', 'brag', 'braggadocio', 'braggartism', 'bragging', 'brashness', 'brass', 'bravado'],
    'heroin': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'heroine': ['achilles', 'david', 'hector', 'roland', 'samson', 'a man', 'actor', 'antagonist', 'antihero', 'big name', 'bit', 'bit part'],
    'heroism': ['dutch courage', 'bigheartedness', 'bigness', 'boldness', 'braveness', 'bravery', 'chivalrousness', 'chivalry', 'consequence', 'conspicuous gallantry', 'courage', 'courageousness'],
    'herpes': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acne', 'acne vulgaris', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery'],
    'herpetology': ['anatomy', 'animal physiology', 'anthropology', 'biology', 'comparative anatomy', 'conchology', 'ecology', 'entomology', 'ethology', 'helminthology', 'ichthyology', 'malacology'],
    'hesitant': ['afraid', 'agnostic', 'ambiguous', 'ambivalent', 'averse', 'backward', 'bashful', 'boggling', 'canny', 'capricious', 'careful', 'cautious'],
    'hesitate': ['alternate', 'back down', 'balance', 'balk', 'be dilatory', 'blench', 'boggle', 'call a recess', 'debate', 'delay', 'deliberate', 'demur'],
    'hesitating': ['agnostic', 'ambiguous', 'balbutient', 'bashful', 'boggling', 'capricious', 'cautious', 'chancy', 'changeable', 'demurring', 'dicey', 'diffident'],
    'hesitation': ['fabian policy', 'micawberism', 'abeyance', 'averseness', 'backwardness', 'balbuties', 'bashfulness', 'boggle', 'boggling', 'break', 'caesura', 'calculation'],
    'heterodox': ['albigensian', 'arian', 'bohemian', 'catharist', 'donatist', 'ebionitist', 'erastian', 'gnostic', 'jansenist', 'jansenistic', 'jovinianist', 'jovinianistic'],
    'heterogeneous': ['amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'assorted', 'at odds', 'at variance', 'blended', 'combined', 'complex', 'composite', 'compound'],
    'heteronomous': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'civic', 'civil', 'constitutional', 'democratic', 'despotic', 'dictatorial'],
    'heterosexual': ['amorous', 'carnal', 'erogenic', 'erogenous', 'erotic', 'erotogenic', 'fleshly', 'gamic', 'libidinal', 'nuptial', 'oversexed', 'potent'],
    'heuristic': ['analytic', 'cut-and-try', 'empirical', 'examinational', 'examinatorial', 'examining', 'experimental', 'explorational', 'explorative', 'exploratory', 'fact-finding', 'feeling'],
    'hew': ['amputate', 'ax', 'bisect', 'block out', 'blow down', 'blow over', 'bowl down', 'bowl over', 'bring down', 'bulldog', 'butcher', 'carve'],
    'hex': ['jonah', 'weird sisters', 'abuse', 'accurse', 'afflict', 'aggrieve', 'anathema', 'anathematize', 'bad influence', 'ban', 'bedevil', 'befoul'],
    'hi fi': ['gramophone', 'pa', 'pa system', 'victrola', 'articulate', 'audible', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge'],
    'hiatus': ['aperture', 'arrearage', 'breach', 'break', 'broaching', 'caesura', 'cavity', 'cessation', 'chasm', 'check', 'clearance', 'clearing'],
    'hibernal': ['siberian', 'aestival', 'algid', 'arctic', 'autumn', 'autumnal', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'boreal'],
    'hibernate': ['aestivate', 'be a sideliner', 'be latent', 'be still', 'coast', 'delay', 'do nothing', 'drift', 'escape notice', 'hang fire', 'have nothing on', 'idle'],
    'hibernation': ['beauty sleep', 'beddy-bye', 'bedtime', 'blanket drill', 'bye-bye', 'dormancy', 'doze', 'dreamland', 'drowse', 'fitful sleep', 'immobility', 'inaction'],
    'hiccup': ['aqua-lung', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'belch', 'blow', 'breath', 'breath of air', 'breathe', 'breathe hard', 'breathe in', 'breathe out'],
    'hick': ['babe', 'boor', 'boorish', 'bucolic', 'bumpkin', 'butterfingers', 'child', 'child of nature', 'churlish', 'clod', 'cloddish', 'clodhopper'],
    'hickey': ['affair', 'article', 'artifact', 'birthmark', 'blackhead', 'bleb', 'blemish', 'blister', 'bulla', 'check', 'cicatrix', 'comedo'],
    'hidden': ['abstract', 'abstruse', 'arcane', 'beclouded', 'behind the curtain', 'behind the scenes', 'between the lines', 'blind', 'buried', 'cabalistic', 'camouflaged', 'censored'],
    'hide': ['australian seal', 'leatherette', 'leatheroid', 'accumulate', 'amass', 'backlog', 'be consumed', 'be gone', 'be incognito', 'bearskin', 'beat', 'beat all hollow'],
    'hideaway': ['adytum', 'ashram', 'asylum', 'bolt-hole', 'cache', 'cell', 'cloister', 'concealment', 'corner', 'cover', 'covert', 'coverture'],
    'hidebound': ['quakerish', 'sabbatarian', 'victorian', 'authoritarian', 'bigot', 'bigoted', 'borne', 'censorious', 'closed', 'conservative', 'constricted', 'conventional'],
    'hideous': ['abhorrent', 'abominable', 'appalling', 'astounding', 'atrocious', 'awe-inspiring', 'awesome', 'awful', 'baneful', 'beastly', 'contemptible', 'damnable'],
    'hideously': ['appallingly', 'awfully', 'banefully', 'direly', 'dreadfully', 'forbiddingly', 'frightfully', 'ghastly', 'grimly', 'gruesomely', 'horribly', 'horridly'],
    'hideout': ['adytum', 'ashram', 'asylum', 'bolt-hole', 'cache', 'cell', 'cloister', 'concealment', 'corner', 'cover', 'covert', 'coverture'],
    'hiding': ['waterloo', 'asylum', 'beating', 'blanketing', 'blocking', 'blotting out', 'bolt-hole', 'burial', 'burying', 'cache', 'cementwork', 'cloaking'],
    'hiding place': ['adytum', 'ashram', 'asylum', 'bolt-hole', 'cache', 'cell', 'cloister', 'concealment', 'corner', 'cover', 'covert', 'coverture'],
    'hie': ['accelerate', 'bolt', 'bundle', 'bustle', 'career', 'cheer on', 'commute', 'course', 'cover ground', 'crowd', 'dart', 'dash'],
    'hiemal': ['siberian', 'aestival', 'algid', 'arctic', 'autumn', 'autumnal', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'boreal'],
    'hierarchic': ['assorted', 'cataloged', 'classified', 'filed', 'graded', 'grouped', 'hierarchal', 'indexed', 'on file', 'pigeonholed', 'placed', 'pyramidal'],
    'hierarchy': ['absolute monarchy', 'aedileship', 'animal kingdom', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'autarchy', 'autocracy', 'autonomy', 'bishopric', 'bureaucracy'],
    'hieroglyphic': ['alphabet', 'arrowhead', 'art', 'blueprint', 'character', 'charactering', 'characterization', 'chart', 'choreography', 'conventional representation', 'cuneiform', 'dance notation'],
    'higgledy piggledy': ['all over', 'all over hell', 'anarchic', 'arsy-varsy', 'ass-backwards', 'balled up', 'bollixed up', 'capriciously', 'chaotic', 'chaotically', 'confused', 'erratically'],
    'high': ['dutch courage', 'gymnasium', 'hydromatic', 'latin school', 'olympian', 'realgymnasium', 'realschule', 'a bit much', 'a high', 'abandoned', 'above', 'abovestairs'],
    'high and dry': ['saharan', 'above water', 'aground', 'anchored', 'anhydrous', 'arid', 'at anchor', 'athirst', 'bone-dry', 'castaway', 'caught', 'chained'],
    'high and mighty': ['aggrandized', 'apotheosized', 'aristocratic', 'awesome', 'beatified', 'big', 'canonized', 'deified', 'dictatorial', 'elevated', 'elitist', 'eminent'],
    'high camp': ['babbittry', 'thalia', 'arlequinade', 'bad taste', 'black comedy', 'bourgeois taste', 'broad comedy', 'burlesque', 'burletta', 'camp', 'campiness', 'comedie bouffe'],
    'high church': ['anglicanism', 'anglo-catholicism', 'broad church', 'church of england', 'established church', 'free church', 'high-churchism', 'low church', 'baptismal', 'ceremonial', 'ceremonious', 'eucharistic'],
    'high flown': ['gongoresque', 'johnsonian', 'absurd', 'affected', 'aggrandized', 'ambitious', 'amplified', 'arrogant', 'ballyhooed', 'bedizened', 'beyond belief', 'big'],
    'high flying': ['gongoresque', 'johnsonian', 'affected', 'ambitious', 'aspiring', 'bedizened', 'big-sounding', 'careerist', 'careeristic', 'classy', 'convoluted', 'declamatory'],
    'high handed': ['absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'authoritarian', 'authoritative', 'autocratic', 'bossy', 'despotic', 'dictatorial'],
    'high horse': ['olympian detachment', 'olympian loftiness', 'arrogance', 'arrogantness', 'assumption of superiority', 'condescendence', 'condescension', 'domineering', 'domineeringness', 'haughtiness', 'haughty airs', 'hauteur'],
    'high jinks': ['mardi gras', 'saturnalia', 'banquet', 'blowout', 'carnival', 'do', 'fair', 'feast', 'festival', 'festive occasion', 'festivity', 'fete'],
    'high life': ['ffvs', 'vanity fair', 'ancienne noblesse', 'aristocracy', 'baronage', 'baronetage', 'beau monde', 'beautiful people', 'best people', 'cafe society', 'carriage trade', 'chivalry'],
    'high liver': ['brillat-savarin', 'lucullus', 'board-and-roomer', 'boarder', 'bon vivant', 'cannibal', 'carnivore', 'connoisseur of food', 'consumer', 'diner', 'diner-out', 'dissipater'],
    'high noon': ['acme', 'apex', 'apogee', 'brow', 'cap', 'climax', 'cloud nine', 'crest', 'crown', 'culmen', 'culmination', 'edge'],
    'high pitched': ['olympian', 'aerial', 'airy', 'altitudinous', 'alto', 'ascending', 'aspiring', 'colossal', 'dominating', 'elevated', 'eminent', 'ethereal'],
    'high powered': ['armipotent', 'authoritative', 'big', 'big-league', 'big-name', 'big-time', 'bigwig', 'bigwigged', 'cogent', 'consequential', 'considerable', 'double-barreled'],
    'high principled': ['christian', 'blameless', 'clean', 'creditable', 'decent', 'erect', 'estimable', 'ethical', 'fair', 'full of integrity', 'good', 'high-minded'],
    'high school': ['gymnasium', 'latin school', 'realgymnasium', 'realschule', 'academy', 'grammar school', 'high', 'intermediate school', 'junior high', 'junior high school', 'middle school', 'prep school'],
    'high seas': ['big drink', 'blue water', 'drink', 'high sea', 'hydrosphere', 'main', 'main sea', 'ocean', 'ocean depths', 'ocean main', 'ocean sea', 'salt sea'],
    'high sign': ['roman candle', 'sos', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'beacon', 'beacon fire', 'bell', 'bell buoy', 'blinker', 'blue peter'],
    'high society': ['ffvs', 'vanity fair', 'ancienne noblesse', 'aristocracy', 'baronage', 'baronetage', 'beau monde', 'beautiful people', 'best people', 'cafe society', 'cafe-society', 'carriage trade'],
    'high sounding': ['gongoresque', 'johnsonian', 'affected', 'alto', 'bedizened', 'big-sounding', 'convoluted', 'declamatory', 'elevated', 'euphuistic', 'falsetto', 'flamboyant'],
    'high spirited': ['agitable', 'arch', 'beany', 'brash', 'devilish', 'ebullient', 'edgy', 'effervescent', 'elfish', 'elvish', 'emotional', 'emotionally unstable'],
    'high spirits': ['beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'cheer', 'cheerfulness', 'cloud nine', 'delectation', 'delight', 'devilishness'],
    'high strung': ['agitable', 'all nerves', 'apprehensive', 'edgy', 'emotional', 'emotionally unstable', 'eruptive', 'excitable', 'explosive', 'fearful', 'fidgety', 'frightened'],
    'high test': ['avgas', 'crude', 'crude oil', 'ethyl', 'ethyl gas', 'fossil oil', 'gas', 'gasoline', 'high-octane gas', 'kerosene', 'lead-free gas', 'low-lead gas'],
    'high tide': ['amplitude', 'congestion', 'direct tide', 'ebb', 'ebb and flow', 'ebb tide', 'flood', 'flood tide', 'flow', 'flux', 'flux and reflux', 'full'],
    'high time': ['action', 'ball', 'belatedness', 'big time', 'due season', 'eleventh hour', 'favorable opportunity', 'fun', 'fun and games', 'funmaking', 'game', 'golden opportunity'],
    'high water mark': ['plimsoll line', 'plimsoll mark', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bourn', 'break boundary', 'breakoff point', 'ceiling', 'circumscription'],
    'high-minded': ['christian', 'big', 'bighearted', 'blameless', 'chivalrous', 'clean', 'creditable', 'decent', 'elevated', 'erect', 'estimable', 'ethical'],
    'highball': ['mickey', 'mickey finn', 'aperitif', 'ball the jack', 'barrel', 'boom', 'bowl along', 'breeze', 'breeze along', 'brush', 'chaser', 'clip'],
    'highbrow': ['brahmin', 'aesthete', 'aesthetic', 'bookish', 'brain', 'brainworker', 'brainy', 'cerebral', 'connoisseur', 'cultivated', 'cultured', 'deep'],
    'higher': ['a cut above', 'above', 'ahead', 'ascendant', 'better', 'capping', 'chosen', 'distinguished', 'eclipsing', 'eminent', 'exceeding', 'excellent'],
    'higher up': ['a per se', 'ace', 'boss', 'bureaucracy', 'champion', 'chief', 'commander', 'dean', 'directorate', 'fugleman', 'genius', 'head'],
    'highest': ['above', 'acmatic', 'acme', 'all-absorbing', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'apical', 'astral', 'authority'],
    'highfalutin': ['gongoresque', 'johnsonian', 'affected', 'ambitious', 'arrogant', 'aureate', 'bedizened', 'big', 'big-sounding', 'bombastic', 'classy', 'condescending'],
    'highlands': ['agricultural region', 'arable land', 'black belt', 'citrus belt', 'corn belt', 'cotton belt', 'countryside', 'downs', 'dust bowl', 'farm belt', 'farm country', 'farmland'],
    'highlight': ['accent', 'accentuate', 'affect', 'arc lighting', 'argue', 'be indicative of', 'be significant of', 'be symptomatic of', 'beacon', 'belabor', 'bespeak', 'betoken'],
    'highly': ['a deal', 'a great deal', 'a lot', 'abundantly', 'approvingly', 'as all creation', 'as all get-out', 'authoritatively', 'beaucoup', 'considerable', 'considerably', 'decidedly'],
    'highness': ['eminence', 'grace', 'her excellency', 'her highness', 'her ladyship', 'her majesty', 'his lordship', 'his majesty', 'honor', 'imperial highness', 'imperial majesty', 'lady'],
    'highroad': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'hightail': ['begone', 'bound', 'canter', 'clear out', 'cut and run', 'cut out', 'decamp', 'flee', 'fly', 'fox-trot', 'gallop', 'get'],
    'highway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'highway robbery': ['armed robbery', 'asportation', 'assault and robbery', 'banditry', 'bank robbery', 'cattle lifting', 'cattle stealing', 'exploitation', 'extortion', 'heist', 'hijacking', 'holdup'],
    'hijack': ['blackjack', 'bludgeon', 'bulldoze', 'bully', 'coerce', 'commit robbery', 'dragoon', 'heist', 'hold up', 'intimidate', 'knock over', 'mug'],
    'hijacking': ['armed robbery', 'asportation', 'assault and robbery', 'banditry', 'bank robbery', 'cattle lifting', 'cattle stealing', 'extortion', 'heist', 'highway robbery', 'holdup', 'mugging'],
    'hike': ['access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'add to', 'addition', 'advance', 'aggrandize', 'aggrandizement', 'airing'],
    'hiker': ['ambulator', 'backpacker', 'foot passenger', 'foot soldier', 'foot traveler', 'footslogger', 'hitchhiker', 'hoofer', 'infantryman', 'jaywalker', 'marcher', 'paddlefoot'],
    'hiking': ['addition', 'adjunct', 'aggrandizement', 'ambling', 'ambulation', 'ampliation', 'amplification', 'augmentation', 'backpacking', 'broadening', 'crescendo', 'deployment'],
    'hilarious': ['absurd', 'amusing', 'bizarre', 'buxom', 'cheerful', 'cheery', 'comical', 'convivial', 'droll', 'eccentric', 'entertaining', 'festal'],
    'hilarity': ['homeric laughter', 'absurdity', 'absurdness', 'amusement', 'belly laugh', 'bizarreness', 'bizarrerie', 'boff', 'boffola', 'boisterousness', 'burst of laughter', 'cachinnation'],
    'hill': ['acclivity', 'anthill', 'bank', 'bank up', 'barrow', 'bilge', 'blain', 'bleb', 'blister', 'blob', 'boss', 'bow'],
    'hill of beans': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'bagatelle', 'bauble', 'bean', 'bibelot', 'bit', 'brass farthing', 'button'],
    'hillbilly': ['backwoodsman', 'boor', 'briar-hopper', 'brush ape', 'bucolic', 'bumpkin', 'bushman', 'clam digger', 'clod', 'clodhopper', 'clown', 'country bumpkin'],
    'hillock': ['anthill', 'barrow', 'brae', 'butte', 'down', 'drumlin', 'dune', 'fell', 'foothills', 'hill', 'hummock', 'knob'],
    'hillocky': ['bagging', 'baggy', 'ballooning', 'bellying', 'billowing', 'billowy', 'bloated', 'bosomy', 'bulbose', 'bulbous', 'bulging', 'bumped'],
    'him': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'ego', 'ethical self', 'gentleman', 'he', 'her', 'herself', 'himself'],
    'hind': ['cape elk', 'partlet', 'virginia deer', 'aft', 'after', 'aftermost', 'antelope', 'back', 'backward', 'biddy', 'bitch', 'bossy'],
    'hind end': ['afterpart', 'afterpiece', 'back', 'back door', 'back seat', 'back side', 'backside', 'beam', 'behind', 'breech', 'butt', 'buttocks'],
    'hinder': ['arrest', 'arse', 'back', 'backside', 'baffle', 'balk', 'bar', 'beat off', 'behind', 'block', 'bog down', 'bottle up'],
    'hindmost': ['aft', 'after', 'aftermost', 'back', 'backward', 'closing', 'concluding', 'eventual', 'final', 'hind', 'hinder', 'hindermost'],
    'hindrance': ['afterthought', 'arrest', 'arrestation', 'barrier', 'bind', 'block', 'blockage', 'bureaucratic delay', 'check', 'clog', 'constraint', 'control'],
    'hindsight': ['commitment to memory', 'exercise of memory', 'flashback', 'learning by heart', 'looking back', 'memoir', 'memorization', 'memorizing', 'recall', 'recalling', 'recollecting', 'recollection'],
    'hinge': ['accrue from', 'ankle', 'arbor', 'arise from', 'articulate', 'articulation', 'axis', 'axle', 'axle bar', 'axle shaft', 'axle spindle', 'axle-tree'],
    'hint': ['admonishment', 'admonition', 'adumbrate', 'adumbration', 'advert', 'advice', 'aide-memoire', 'alarm', 'allegorize', 'allegory', 'allude', 'allude to'],
    'hinterland': ['airspace', 'area', 'arena', 'back', 'back country', 'backcountry', 'backdrop', 'background', 'backwash', 'backwater', 'backwoods', 'belt'],
    'hip': ['all the rage', 'all the thing', 'ankle', 'articulation', 'backside', 'bank', 'beam', 'behind', 'border', 'boundary', 'broadside', 'butt'],
    'hipped on': ['ape about', 'attached to', 'bugs on', 'cracked on', 'crazy about', 'devoted to', 'enamored of', 'far gone on', 'fond of', 'freaked-out', 'gaga over', 'gone on'],
    'hippie': ['bohemian', 'beat', 'beatnik', 'bohemian', 'breakaway', 'deviant', 'dissenter', 'dropout', 'far out', 'flower child', 'freak', 'free and easy'],
    'hippo': ['jumbo', 'blimp', 'dinosaur', 'elephant', 'fatty', 'hathi', 'heavy', 'heavyweight', 'hippopotamus', 'jumbo', 'leviathan', 'lump'],
    'hippodrome': ['agora', 'amphitheater', 'arena', 'athletic field', 'auditorium', 'background', 'bear garden', 'bowl', 'boxing ring', 'bull ring', 'campus', 'canvas'],
    'hippy': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky', 'corpulent'],
    'hire': ['admission', 'admission fee', 'anchorage', 'appoint', 'bareboat charter', 'base pay', 'bespeak', 'book', 'brief', 'brokerage', 'carfare', 'cellarage'],
    'hire purchase': ['acquitment', 'acquittal', 'acquittance', 'amortization', 'amortizement', 'binder', 'borrowing', 'buy', 'buying', 'buying power', 'buying up', 'cash'],
    'hired': ['acquitted', 'chartered', 'discharged', 'employed', 'expended', 'hireling', 'leased', 'let', 'liquidated', 'mercenary', 'paid', 'paid in full'],
    'hireling': ['adventurer', 'assistant', 'condottiere', 'drudge', 'employee', 'free lance', 'girl friday', 'grub', 'grubber', 'gun', 'gunman', 'hack'],
    'hirsute': ['barbellate', 'bristled', 'bristling', 'bristly', 'bushy', 'cirrose', 'downy', 'feathery', 'fleecy', 'flocculent', 'flossy', 'fluffy'],
    'hiss': ['bronx cheer', 'aphonia', 'artificial voice', 'assibilate', 'assibilation', 'bark', 'bawl', 'bellow', 'bird', 'blare', 'blat', 'blubber'],
    'hissing': ['bronx cheer', 'assibilation', 'banter', 'bantering', 'birdies', 'blooping', 'blurping', 'boo', 'booing', 'buzz', 'catcall', 'catcalling'],
    'histology': ['anatomist', 'anatomy', 'angiography', 'angiology', 'anthropotomy', 'geomorphology', 'histologist', 'morphologist', 'morphology', 'myography', 'myology', 'organography'],
    'historical': ['absolute', 'actual', 'admitting no question', 'ascertained', 'attested', 'authentic', 'authenticated', 'autobiographical', 'biographical', 'categorically true', 'certain', 'certified'],
    'historically': ['actually', 'aforetime', 'before', 'before now', 'beforetime', 'certainly', 'earlier', 'erenow', 'erewhile', 'erst', 'factually', 'formerly'],
    'historicity': ['accomplished fact', 'actuality', 'authenticity', 'eternal verities', 'fact', 'factuality', 'fait accompli', 'good sooth', 'grim reality', 'historical truth', 'not a dream', 'objective existence'],
    'history': ['clio', 'muse of history', 'account', 'adventures', 'ancient history', 'annals', 'antiquity', 'autobiography', 'background', 'biographical sketch', 'biography', 'bygone days'],
    'histrionic': ['actor-proof', 'affected', 'all-star', 'artificial', 'ballet', 'balletic', 'cinematic', 'cinematographic', 'dramatic', 'dramatical', 'dramaturgic', 'emotionalistic'],
    'histrionics': ['thespian art', 'amateur theatricals', 'blazon', 'blood and thunder', 'bravura', 'brilliancy', 'daring', 'dash', 'demonstration', 'demonstrativeness', 'display', 'dramatic art'],
    'hit': ['grand guignol', 'passion play', 'tom show', 'accomplish', 'accord', 'achieve', 'adverse criticism', 'affect', 'agree', 'ambush', 'animadversion', 'answer to'],
    'hit it': ['answer', 'bottom', 'break the bank', 'clear up', 'crack', 'debug', 'decipher', 'decode', 'disentangle', 'divine', 'do', 'dope'],
    'hit it off': ['accord', 'agree', 'agree with', 'associate with', 'be acquainted with', 'be friends', 'be inseparable', 'chime in with', 'correspond', 'cotton to', 'empathize', 'fall in with'],
    'hit man': ['cain', 'apache', 'assassin', 'assassinator', 'bloodletter', 'bloodshedder', 'bravo', 'burker', 'butcher', 'button man', 'cannibal', 'cutthroat'],
    'hit or miss': ['airily', 'any old way', 'any which way', 'anyhow', 'at haphazard', 'at intervals', 'at random', 'bunglingly', 'by chance', 'by fits', 'by snatches', 'capriciously'],
    'hit the ceiling': ['be angry', 'be excitable', 'bellow', 'blow a fuse', 'blow a gasket', 'blow up', 'catch fire', 'catch the infection', 'come apart', 'excite easily', 'explode', 'fire up'],
    'hit the road': ['bat around', 'be off', 'beat it', 'begone', 'bum', 'clear out', 'count ties', 'divagate', 'drift', 'flake off', 'flit', 'gad'],
    'hit up': ['beg', 'borrow', 'bum', 'cadge', 'float a loan', 'get a loan', 'get on credit', 'hit', 'hit one for', 'mooch', 'negotiate a loan', 'panhandle'],
    'hit upon': ['alight upon', 'arrive at', 'arrive upon', 'blunder upon', 'bump into', 'chance upon', 'come across', 'come at', 'come down on', 'come on', 'come up against', 'come upon'],
    'hitch': ['acute pain', 'amble', 'arrange a match', 'articulate', 'attach', 'barge', 'batten', 'batten down', 'bed', 'bed down', 'bite', 'block'],
    'hitchhiker': ['ambulator', 'backpacker', 'foot passenger', 'foot soldier', 'foot traveler', 'footslogger', 'hiker', 'hoofer', 'infantryman', 'jaywalker', 'marcher', 'paddlefoot'],
    'hither': ['aboard', 'among us', 'here', 'hereabout', 'hereabouts', 'hereat', 'hereinto', 'hereto', 'hereunto', 'hitherward', 'hitherwards', 'in this place'],
    'hitherto': ['aforetime', 'already', 'as yet', 'before', 'before all', 'before now', 'beforetime', 'earlier', 'early', 'ere', 'ere then', 'erenow'],
    'hive': ['a mass of', 'a world of', 'aerie', 'amass', 'anchor', 'apiary', 'army', 'assemble', 'bee tree', 'beehive', 'bevy', 'billet at'],
    'hives': ['acne', 'acne vulgaris', 'allergen', 'allergic disorder', 'allergy', 'asthma', 'breaking out', 'conjunctivitis', 'cosmetic dermatitis', 'dermamycosis', 'dermatitis', 'dermatosis'],
    'ho ho': ['homeric laughter', 'be in stitches', 'belly laugh', 'boff', 'boffola', 'break up', 'burst into laughter', 'burst of laughter', 'burst out', 'burst out laughing', 'burst with laughter', 'bust a gut'],
    'ho hum': ['arid', 'barren', 'blah', 'blank', 'bloodless', 'characterless', 'cold', 'colorless', 'dead', 'dismal', 'draggy', 'drearisome'],
    'hoagy': ['blt', 'dagwood sandwich', 'sloppy joe', 'swiss cheese sandwich', 'bacon-lettuce-tomato sandwich', 'canape', 'cheeseburger', 'corned beef sandwich', 'double-decker sandwich', 'egg salad sandwich', 'grilled cheese sandwich', 'grinder'],
    'hoar': ['jack frost', 'advanced', 'advanced in life', 'advanced in years', 'aged', 'along in years', 'ancient', 'argent', 'argentine', 'black frost', 'canescent', 'chalky'],
    'hoard': ['abundance', 'accumulate', 'accumulation', 'agglomeration', 'amass', 'amassment', 'assemble', 'backlog', 'budget', 'cache', 'capital gains', 'cleanup'],
    'hoarse': ['blurred', 'brassy', 'brazen', 'breathy', 'choked', 'choking', 'coarse', 'cracked', 'croaking', 'croaky', 'drawling', 'drawly'],
    'hoary': ['acknowledged', 'admitted', 'advanced', 'advanced in life', 'advanced in years', 'age-old', 'aged', 'ageless', 'along in years', 'ancient', 'antediluvian', 'antique'],
    'hoax': ['bamboozle', 'befool', 'beguile', 'betray', 'bluff', 'cajole', 'cheat', 'cheat on', 'chicane', 'circumvent', 'clinquant', 'con'],
    'hoaxer': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'actor', 'bamboozler', 'befuddler', 'beguiler', 'charmer', 'counterfeiter'],
    'hob': ['ariel', 'befind', 'corrigan', 'finnbeara', 'mab', 'oberon', 'titania', 'banshee', 'beam-end', 'brownie', 'chimney', 'chimney corner'],
    'hobble': ['amble', 'anchor', 'andante', 'barge', 'bind', 'bowl along', 'bridle', 'bundle', 'burden', 'castrate', 'chain', 'claudicate'],
    'hobbyhorse': ['agate', 'avocation', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble', 'blocks', 'by-line', 'checkerboard', 'chessboard', 'club'],
    'hobbyist': ['addict', 'bug', 'collector', 'demon', 'eager beaver', 'energumen', 'enthusiast', 'faddist', 'fanatic', 'fiend', 'freak', 'great one for'],
    'hobgoblin': ['dracula', 'frankenstein', 'wolf-man', 'bogey', 'bogeyman', 'bugaboo', 'bugbear', 'fee-faw-fum', 'frightener', 'ghost', 'ghoul', 'goblin'],
    'hobnob with': ['associate with', 'assort with', 'be acquainted with', 'be friends', 'be inseparable', 'chum', 'chum together', 'chum with', 'clique', 'clique with', 'club together', 'consort with'],
    'hobo': ['arab', 'bowery bum', 'alien', 'beach bum', 'beachcomber', 'beggar', 'beggarly fellow', 'blighter', 'bo', 'budmash', 'bum', 'bummer'],
    'hock': ['ankle', 'bail', 'bayonet legs', 'bond', 'bottomry', 'bowlegs', 'calf', 'cnemis', 'deposit', 'drumstick', 'earnest', 'earnest money'],
    'hocus pocus': ['abracadabra', 'absurdity', 'amphigory', 'anagoge', 'anagogics', 'anthroposophy', 'artful dodge', 'artifice', 'babble', 'babblement', 'bag of tricks', 'balderdash'],
    'hocus-pocus': ['abracadabra', 'artifice', 'cheat', 'chicanery', 'con game', 'conjuring', 'deceit', 'deception', 'duplicity', 'flimflam', 'gibberish', 'hanky-panky'],
    'hodgepodge': ['all sorts', 'arsy-varsiness', 'assemblage', 'assortment', 'broad spectrum', 'clutter', 'collectanea', 'conglomerate', 'conglomeration', 'farrago', 'gallimaufry', 'hash'],
    'hoe': ['backset', 'cultivate', 'culture', 'cut', 'delve', 'dig', 'dress', 'fallow', 'fertilize', 'force', 'harrow', 'list'],
    'hog': ['adopt', 'appropriate', 'arrogate', 'assume', 'barrow', 'belly-god', 'boar', 'careerist', 'colonize', 'conquer', 'cormorant', 'corner'],
    'hog tie': ['anchor', 'bind', 'bridle', 'chain', 'clog', 'curb', 'deflate', 'disarm', 'enchain', 'entrammel', 'fasten', 'fetter'],
    'hog wallow': ['baygall', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'chuckhole', 'everglade', 'fen', 'fenland', 'glade', 'holm'],
    'hog wild': ['abandoned', 'amok', 'bellowing', 'berserk', 'carried away', 'delirious', 'demoniac', 'distracted', 'ecstatic', 'enraptured', 'feral', 'ferocious'],
    'hoggish': ['apician', 'a hog for', 'acquisitive', 'all-devouring', 'asinine', 'avaricious', 'avid', 'beastly', 'bolting', 'bottomless', 'bovid', 'bovine'],
    'hogwash': ['balls', 'baloney', 'bilge', 'blague', 'blah', 'blah-blah', 'bones', 'bop', 'bosh', 'bull', 'bullshit', 'bunk'],
    'hoi polloi': ['cog', 'commonality', 'commonalty', 'creature', 'demos', 'flunky', 'follower', 'ignobile vulgus', 'inferior', 'junior', 'lightweight', 'lower class'],
    'hoist': ['a leg up', 'boost', 'buoy up', 'cast up', 'crab', 'crane', 'davit', 'derrick', 'elevate', 'elevator', 'erect', 'erector'],
    'hoity toity': ['olympian detachment', 'olympian loftiness', 'arrogance', 'arrogant', 'arrogantness', 'assumption of superiority', 'big', 'condescendence', 'condescending', 'condescension', 'dizzy', 'domineering'],
    'hoke': ['acting', 'balls', 'baloney', 'blague', 'bosh', 'buffoonery', 'bull', 'bullshit', 'bunk', 'bunkum', 'business', 'characterization'],
    'hoke up': ['act like', 'affect', 'assume', 'borrow', 'chorus', 'concoct', 'cook up', 'copy', 'counterfeit', 'crib', 'ditto', 'do'],
    'hokum': ['acting', 'balls', 'baloney', 'bilge', 'blague', 'blah', 'blah-blah', 'bop', 'bosh', 'buffoonery', 'bull', 'bullshit'],
    'hold': ['abandon', 'abduction', 'abide', 'abort', 'absorb', 'absorb the attention', 'abstain', 'accent', 'accent mark', 'accommodate', 'account', 'account as'],
    'hold back': ['abstain', 'abstain from', 'arrest', 'avoid', 'avoid excess', 'backpedal', 'backwater', 'begrudge', 'bit', 'block', 'bottle up', 'brake'],
    'hold by': ['abide by', 'act up to', 'adhere to', 'attend to', 'be faithful to', 'comply with', 'conform to', 'do justice to', 'fill', 'follow', 'fulfill', 'heed'],
    'hold cheap': ['be above', 'be contemptuous of', 'care nothing for', 'contemn', 'deride', 'despise', 'disdain', 'disparage', 'disprize', 'dump on', 'feel contempt for', 'feel superior to'],
    'hold down': ['asphyxiate', 'bit', 'bottle up', 'bridle', 'censor', 'check', 'choke off', 'clamp down on', 'constrain', 'cork', 'cork up', 'crack down on'],
    'hold everything': ['abide', 'await', 'bide', 'bide the issue', 'dally', 'dawdle', 'delay', 'dillydally', 'hang about', 'hang around', 'hold on', 'hold your horses'],
    'hold fast': ['adhere to', 'arrest', 'be unflappable', 'bear up', 'bite', 'bridle', 'check', 'clasp', 'cleave to', 'clench', 'clinch', 'cling'],
    'hold forth': ['debate', 'declaim', 'demagogue', 'discourse', 'elocute', 'explain', 'exposit', 'expound', 'extend', 'harangue', 'hold out', 'lecture'],
    'hold good': ['afford proof of', 'ascertain', 'be consistent', 'be demonstrable', 'be irrefutable', 'be logical', 'be reasonable', 'be the case', 'be true', 'be truthful', 'bring home to', 'cinch'],
    'hold in contempt': ['be above', 'be contemptuous of', 'belittle', 'bring down', 'bring into discredit', 'bring low', 'care nothing for', 'contemn', 'cry down', 'dare', 'debase', 'decry'],
    'hold off': ['abstain', 'adjourn', 'be dilatory', 'beat back', 'beat off', 'blench', 'block', 'boggle', 'brush off', 'chase', 'chase away', 'chase off'],
    'hold office': ['alternate', 'be in office', 'be the incumbent', 'cover', 'do a hitch', 'do a stint', 'do a tour', 'do time', 'enlist', 'fill an office', 'fill in for', 'have a go'],
    'hold on': ['abide', 'adhere', 'adhere to', 'agglomerate', 'aim', 'aim at', 'await', 'be caught short', 'be short', 'bear up', 'belong', 'bend'],
    'hold out': ['abide', 'balk', 'be proof against', 'be unflappable', 'be unmoved', 'be unwilling', 'bear up', 'bear up against', 'beg off', 'bide', 'boycott', 'carry on'],
    'hold out on': ['bosom', 'classify', 'conceal', 'file and forget', 'hold back', 'in petto', 'keep', 'keep back', 'keep between us', 'keep buttoned up', 'keep close', 'keep dark'],
    'hold over': ['adjourn', 'continue', 'defer', 'delay', 'drag out', 'extend', 'hang fire', 'hang up', 'hold off', 'hold up', 'lay aside', 'lay by'],
    'hold together': ['accord', 'act in concert', 'act together', 'adhere', 'affiliate', 'agglomerate', 'agree', 'ally', 'amalgamate', 'answer to', 'assent', 'associate'],
    'hold true': ['be consistent', 'be the case', 'be true', 'be truthful', 'conform to fact', 'hold', 'hold good', 'hold together', 'hold up', 'hold water', 'prove out', 'prove to be'],
    'hold up': ['adjourn', 'advertise', 'afford support', 'air', 'arrest', 'back', 'back up', 'backpedal', 'backwater', 'be consistent', 'be proof against', 'be the case'],
    'hold water': ['afford proof of', 'ascertain', 'be consistent', 'be demonstrable', 'be irrefutable', 'be logical', 'be reasonable', 'be the case', 'be true', 'be truthful', 'bring home to', 'cinch'],
    'hold with': ['ok', 'abide by', 'accede', 'accede to', 'accept', 'acclaim', 'accord to', 'acquiesce', 'acquiesce in', 'admire', 'agree', 'agree to'],
    'hold your horses': ['abide', 'await', 'bide', 'bide the issue', 'dally', 'dawdle', 'delay', 'dillydally', 'hang about', 'hang around', 'hold everything', 'hold on'],
    'holdback': ['arrest', 'arrestation', 'arrestment', 'bearing rein', 'bit', 'blockage', 'blocking', 'brake', 'chain', 'check', 'checkrein', 'chock'],
    'holder': ['accepter', 'acquirer', 'addressee', 'audience', 'auditor', 'beholder', 'bracket', 'candelabrum', 'candlestand', 'candlestick', 'chandelier', 'consignee'],
    'holding': ['absolute interest', 'absorbing', 'adverse possession', 'alodium', 'arresting', 'attractive', 'bearing', 'benefit', 'blessed with', 'block', 'board lot', 'bolstering'],
    'holding company': ['aktiengesellschaft', 'aktiebolag', 'body corporate', 'business', 'business establishment', 'cartel', 'chamber of commerce', 'closed-end investment company', 'combine', 'commercial enterprise', 'compagnie', 'company'],
    'holdings': ['festschrift', 'acquest', 'ana', 'anthology', 'aquarium', 'assets', 'available means', 'balance', 'block', 'board lot', 'body', 'capital'],
    'holdover': ['afterglow', 'afterimage', 'balance', 'butt', 'butt end', 'candle ends', 'chaff', 'debris', 'detritus', 'end', 'fag end', 'filings'],
    'holdup': ['afterthought', 'armed robbery', 'arrest', 'arrestation', 'arrestment', 'asportation', 'assault and robbery', 'banditry', 'bank robbery', 'bind', 'block', 'blockage'],
    'hole': ['augean stables', 'babylon', 'cat', 'gomorrah', 'sodom', 'abode', 'abri', 'abysm', 'abyss', 'aerospace', 'aerosphere', 'air hole'],
    'hole up': ['be incognito', 'burrow', 'disappear', 'drop from sight', 'go into hiding', 'go to ground', 'go underground', 'hide', 'hide away', 'hide out', 'lie', 'lie close'],
    'holey': ['apertured', 'crible', 'dowdy', 'down-at-heel', 'down-at-the-heels', 'fenestrated', 'frayed', 'frazzled', 'full of holes', 'honeycombed', 'in rags', 'in shreds'],
    'holiday': ['awol', 'admission day', 'arbor day', 'armed forces day', 'armistice day', 'army day', 'bastille day', 'christmas', 'colorado day', 'constitution day', 'decoration day', 'dewali'],
    'holier-than-thou': ['pecksniffian', 'tartuffian', 'tartuffish', 'affected', 'canting', 'false', 'goody', 'goody-goody', 'hypocritic', 'hypocritical', 'insincere', 'mealymouthed'],
    'holiness': ['christianity', 'christlikeness', 'christliness', 'angelicalness', 'awesomeness', 'awfulness', 'beauty of holiness', 'blessedness', 'consecration', 'devotion', 'devoutness', 'divineness'],
    'holler': ['air a grievance', 'bark', 'battle cry', 'bawl', 'beef', 'beefing', 'bellow', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'boggle'],
    'hollow': ['absurd', 'abysm', 'abyss', 'alveolation', 'alveolus', 'antrum', 'aperture', 'apparently sound', 'arid', 'armpit', 'artificial', 'bare'],
    'hollow eyed': ['attenuated', 'cadaverous', 'corpselike', 'drawn', 'emacerated', 'emaciate', 'emaciated', 'haggard', 'jejune', 'marantic', 'marasmic', 'peaked'],
    'hollow man': ['actor', 'affecter', 'cipher', 'deceiver', 'dud', 'dummy', 'fake', 'fraud', 'jackstraw', 'lay figure', 'man of straw', 'mannerist'],
    'hollow ware': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'cutlery', 'dining utensils', 'dinnerware', 'durable goods', 'durables', 'earthenware', 'enamelware'],
    'holocaust': ['annihilation', 'bloodbath', 'blue ruin', 'breakup', 'burnt offering', 'butchery', 'carnage', 'clawing', 'collection', 'conflagration', 'consumption', 'cruciation'],
    'hologram': ['photostat', 'xerox', 'xerox copy', 'blowup', 'blueprint', 'contact printing', 'cyanotype', 'enlargement', 'glossy', 'lantern slide', 'matte', 'microcopy'],
    'holograph': ['article', 'autograph', 'blank', 'brainchild', 'chirograph', 'composition', 'computer printout', 'copy', 'docket', 'document', 'dossier', 'draft'],
    'holus bolus': ['a corps perdu', 'carelessly', 'desperately', 'furiously', 'happen what may', 'hastily', 'head over heels', 'headfirst', 'headforemost', 'headlong', 'heedlessly', 'heels over head'],
    'holy': ['christlike', 'christly', 'god-fearing', 'adored', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'angelic', 'awesome', 'awful'],
    'holy communion': ['communion', 'eucharist', 'host', 'last supper', 'sacrament sunday', 'altar bread', 'bread', 'bread and wine', 'consecrated bread', 'consecrated elements', 'consubstantiation', 'elements'],
    'holy day': ['high holiday', 'high holy day', 'sabbath', 'sunday', 'bank holiday', 'church calendar', 'church feast', 'day of festivities', 'day off', 'ecclesiastical calendar', 'fast', 'feast'],
    'holy father': ['god the father', 'grand penitentiary', 'our father', 'abuna', 'antipope', 'archbishop', 'archdeacon', 'archpriest', 'bishop', 'bishop coadjutor', 'canon', 'cardinal'],
    'holy grail': ['agnus dei', 'host', 'pieta', 'sanctus bell', 'sangraal', 'ark', 'asperger', 'asperges', 'aspergillum', 'bambino', 'beadroll', 'beads'],
    'holy of holies': ['adytum', 'ashram', 'cabinet', 'cell', 'cloister', 'closet', 'den', 'hermitage', 'hideaway', 'hideout', 'hiding place', 'ivory tower'],
    'holy orders': ['acolyte', 'acolytus', 'apostleship', 'apostolic orders', 'appointment', 'baptism', 'call', 'calling', 'canonization', 'care of souls', 'conferment', 'confirmation'],
    'holy sacrament': ['communion', 'eucharist', 'holy communion', 'host', 'last supper', 'sacrament sunday', 'altar bread', 'bread', 'bread and wine', 'consecrated bread', 'consecrated elements', 'consubstantiation'],
    'holy terror': ['dracula', 'frankenstein', 'jd', 'mafioso', 'wolf-man', 'young turk', 'beast', 'beldam', 'berserk', 'berserker', 'bogey', 'bogeyman'],
    'holy war': ['armageddon', 'brushfire war', 'campaign', 'civil war', 'crusade', 'drive', 'expedition', 'general war', 'global war', 'jihad', 'limited war', 'police action'],
    'holystone': ['abstergent', 'baptize', 'bath', 'bathe', 'cathartic', 'cleaner', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing cream', 'cold cream', 'cream'],
    'homage': ['acceptance', 'accolade', 'acquiescence', 'adherence', 'adhesion', 'admiration', 'adoration', 'adulation', 'allegiance', 'apotheosis', 'appreciation', 'approbation'],
    'home': ['heaven', 'paradise', 'va hospital', 'vaterland', 'a better place', 'abode', 'accessible', 'adept in', 'afterlife', 'afterworld', 'almshouse', 'ancestral halls'],
    'home economics': ['baking', 'barbecuing', 'basting', 'boiling', 'braising', 'brewing', 'broil', 'broiling', 'catering', 'cookery', 'cooking', 'cuisine'],
    'home in on': ['allocate', 'assign', 'collocate', 'deploy', 'dispose', 'emplace', 'fix', 'get a fix', 'home on', 'identify', 'install', 'localize'],
    'home rule': ['declaration of independence', 'absolute monarchy', 'aristocracy', 'autarchy', 'autarky', 'autocracy', 'autonomy', 'coalition government', 'colonialism', 'commonwealth', 'constitutional government', 'constitutional monarchy'],
    'homebody': ['diogenes', 'hieronymian', 'hieronymite', 'timon of athens', 'anchoress', 'anchorite', 'ascetic', 'bedridden invalid', 'cloistered monk', 'closet cynic', 'desert fathers', 'desert saints'],
    'homeless': ['abandoned', 'alienated', 'alone', 'aloof', 'apart', 'bankrupt', 'bums', 'companionless', 'defenseless', 'derelict', 'deserted', 'desolate'],
    'homelike': ['cheerful', 'comfortable', 'comfy', 'commodious', 'contented', 'convenient', 'cozy', 'cushioned', 'cushiony', 'cushy', 'easeful', 'easy'],
    'homely': ['attic', 'babbittish', 'bohemian', 'philistine', 'spartan', 'affable', 'amiable', 'ascetic', 'austere', 'bald', 'bare', 'baseborn'],
    'homemade': ['assembled', 'built', 'cast', 'constructed', 'crafted', 'created', 'custom', 'custom-built', 'custom-made', 'extracted', 'fabricated', 'fashioned'],
    'homeostasis': ['aplomb', 'balance', 'balanced personality', 'constancy', 'cool', 'equilibrium', 'fastness', 'firmness', 'imperturbability', 'invariability', 'nerve', 'reliability'],
    'homer': ['carrier', 'carrier pigeon', 'goal', 'grand slam', 'hit', 'hole', 'hole in one', 'home run', 'homing pigeon', 'mail car', 'mail coach', 'mail packet'],
    'homeric': ['alcaic', 'anacreontic', 'atlantean', 'brobdingnagian', 'castalian', 'cyclopean', 'gargantuan', 'herculean', 'hudibrastic', 'pierian', 'pindaric', 'theocritean'],
    'homespun': ['attic', 'babbittish', 'philistine', 'spartan', 'amateur', 'amateurish', 'arcadian', 'ascetic', 'assembled', 'austere', 'bald', 'bare'],
    'homestead': ['ancestral halls', 'arable land', 'barnyard', 'barton', 'cattle ranch', 'chicken farm', 'chimney corner', 'collective farm', 'cotton plantation', 'croft', 'dairy farm', 'demesne'],
    'homesteader': ['colonial', 'colonist', 'colonizer', 'hirer', 'immigrant', 'incumbent', 'leaseholder', 'lessee', 'lodger', 'nester', 'occupant', 'occupier'],
    'homeward': ['anticlockwise', 'approaching', 'arriving', 'clockwise', 'coming', 'counterclockwise', 'earthward', 'entering', 'heavenward', 'homeward-bound', 'inbound', 'incoming'],
    'homeward bound': ['approaching', 'arriving', 'at sea', 'coming', 'entering', 'homeward', 'homeward-bound', 'in blue water', 'in soundings', 'inbound', 'incoming', 'inward-bound'],
    'homework': ['assignment', 'busywork', 'chalk talk', 'chare', 'charge', 'chore', 'commission', 'discourse', 'disquisition', 'duty', 'errand', 'exercise'],
    'homey': ['bohemian', 'affable', 'casual', 'cheerful', 'comfortable', 'comfy', 'commodious', 'contented', 'convenient', 'cordial', 'cozy', 'cushioned'],
    'homicidal': ['amok', 'berserk', 'bloodthirsty', 'bloody', 'bloody-minded', 'cruel', 'cutthroat', 'deadly', 'ferocious', 'gory', 'insane', 'lethal'],
    'homicide': ['cain', 'aborticide', 'apache', 'assassin', 'assassination', 'assassinator', 'blood', 'bloodletter', 'bloodshedder', 'bloody murder', 'bravo', 'bumping-off'],
    'homily': ['article', 'assignment', 'causerie', 'chalk talk', 'descant', 'discourse', 'discussion', 'disquisition', 'dissertation', 'essay', 'etude', 'examination'],
    'homing pigeon': ['aquarius', 'ganymede', 'hebe', 'bearer', 'bheesty', 'busboy', 'caddie', 'cargo handler', 'carrier', 'carrier pigeon', 'carter', 'common carrier'],
    'hominid': ['adam', 'bronze age man', 'hominidae', 'homo sapiens', 'iron age man', 'stone age man', 'aboriginal', 'aborigine', 'ancient', 'antediluvian', 'anthropoid', 'ape-man'],
    'hominy grits': ['breakfast food', 'cereal', 'cornflakes', 'dry cereal', 'farina', 'frumenty', 'grits', 'gruel', 'hasty pudding', 'hot cereal', 'kasha', 'loblolly'],
    'hommage': ['accolade', 'adulation', 'apotheosis', 'bepraisement', 'congratulation', 'deification', 'eloge', 'encomium', 'eulogium', 'eulogy', 'exaltation', 'excessive praise'],
    'homo': ['adam', 'adamite', 'hominidae', 'homo sapiens', 'auntie', 'being', 'bi-guy', 'bisexual', 'body', 'bull dyke', 'butch', 'cat'],
    'homo sapiens': ['adam', 'hominidae', 'clay', 'fallen humanity', 'flesh', 'generation of man', 'genus homo', 'hominid', 'homo', 'human family', 'human nature', 'human race'],
    'homoerotic': ['ac-dc', 'amphierotic', 'autoerotic', 'bisexed', 'bisexual', 'butch', 'deviant', 'effeminate', 'gay', 'homophile', 'homosexual', 'inverted'],
    'homogeneity': ['accordance', 'agreement', 'calm', 'coequality', 'coincidence', 'congruence', 'consistency', 'consonance', 'constancy', 'continuity', 'correspondence', 'elementarity'],
    'homogeneous': ['accordant', 'akin', 'alike', 'aped', 'austere', 'automatic', 'balanced', 'bare', 'basic', 'chaste', 'comparable', 'consimilar'],
    'homogenize': ['admix', 'alloy', 'amalgamate', 'assimilate to', 'balance', 'bemingle', 'blend', 'coalesce', 'combine', 'commingle', 'commix', 'compose'],
    'homologous': ['analogous', 'answering', 'approximate', 'approximating', 'approximative', 'close', 'coequal', 'comparable', 'complemental', 'complementary', 'correspondent', 'corresponding'],
    'homology': ['accord', 'addition', 'adjunct', 'affairs', 'affiliation', 'affinity', 'alliance', 'approximation', 'assemblage', 'association', 'bond', 'closeness'],
    'homonym': ['doppelganger', 'actual thing', 'antonym', 'articulation', 'carbon copy', 'copy', 'dead ringer', 'ditto', 'double', 'duplicate', 'equivalent', 'exact counterpart'],
    'homosexual': ['ac-dc', 'amphierotic', 'androgynous', 'auntie', 'autoerotic', 'bent', 'bi-guy', 'bisexed', 'bisexual', 'bull dyke', 'butch', 'camp'],
    'homosexuality': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'bisexuality', 'coprophilia', 'exhibitionism', 'fetishism', 'heterosexuality', 'homoeroticism', 'homosexualism'],
    'honcho': ['boss', 'chief', 'chieftain', 'cock', 'electronics king', 'head', 'headman', 'hierarch', 'king', 'lead', 'leader', 'leading light'],
    'honest': ['christian', 'angelic', 'authentic', 'blameless', 'bona fide', 'candid', 'card-carrying', 'clean', 'conscientious', 'creditable', 'decent', 'dependable'],
    'honest man': ['acceptable person', 'capital fellow', 'diamond', 'faithful', 'galantuomo', 'gem', 'gentilhomme', 'gentleman', 'good fellow', 'good lot', 'good man', 'good person'],
    'honest-to-god': ['absolute', 'actual', 'authentic', 'bona fide', 'candid', 'card-carrying', 'de facto', 'dinkum', 'factual', 'following the letter', 'for real', 'genuine'],
    'honestly': ['authentically', 'blamelessly', 'bluntly', 'candidly', 'conscientiously', 'creditably', 'decently', 'dependably', 'disinterestedly', 'equitably', 'erectly', 'ethically'],
    'honesty': ['absolute realism', 'artlessness', 'assured probity', 'authenticity', 'blamelessness', 'bluntness', 'bona fideness', 'candor', 'character', 'cleanness', 'conscientiousness', 'decency'],
    'honey': ['jell-o', 'ace', 'ambrosia', 'angel', 'artificial sweetener', 'babe', 'baby', 'baby-doll', 'beaut', 'beloved', 'blackstrap', 'blancmange'],
    'honeycomb': ['alveolation', 'alveolus', 'ambrosia', 'artificial sweetener', 'auger', 'bespread', 'bite', 'blackstrap', 'bore', 'broach', 'calcium cyclamate', 'cane syrup'],
    'honeycombed': ['alveolar', 'alveolate', 'apertured', 'crawling', 'creeping', 'crible', 'dented', 'depressed', 'dimpled', 'engraved', 'faveolate', 'fenestrated'],
    'honeyed': ['achingly sweet', 'adulatory', 'affable', 'agreeable', 'agreeable-sounding', 'ambrosial', 'amiable', 'amicable', 'appealing', 'ariose', 'arioso', 'bittersweet'],
    'honeymoon': ['gretna green wedding', 'banns', 'bridal', 'bridal suite', 'bridechamber', 'chuppah', 'church wedding', 'civil ceremony', 'civil wedding', 'elopement', 'epithalamium', 'espousals'],
    'honk': ['bay', 'beep', 'bell', 'blare', 'blast', 'blat', 'blow', 'blow the horn', 'bray', 'bugle', 'cackle', 'call'],
    'honky': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'honky tonk': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'cabaret', 'cafe', 'cocktail lounge', 'dive'],
    'honor': ['abide by', 'accept', 'acclaim', 'accolade', 'accord respect to', 'account', 'accounting for', 'acknowledgment', 'acres', 'adhere to', 'administer', 'admiration'],
    'honor roll': ['agenda', 'beadroll', 'cadastre', 'calendar', 'census', 'census report', 'checklist', 'checkroll', 'docket', 'dramatis personae', 'head count', 'jury list'],
    'honorable': ['christian', 'acclaimed', 'appropriate', 'artless', 'august', 'awe-inspiring', 'awesome', 'awful', 'blameless', 'celebrated', 'clean', 'conscientious'],
    'honorable mention': ['accolade', 'acknowledgment', 'appreciation', 'blurb', 'boost', 'buildup', 'citation', 'commendation', 'eulogy', 'good word', 'hype', 'kudos'],
    'honorably': ['blamelessly', 'conscientiously', 'creditably', 'decently', 'erectly', 'estimably', 'fastidiously', 'high-mindedly', 'honestly', 'immaculately', 'irreproachably', 'meticulously'],
    'honorarium': ['trinkgeld', 'amends', 'atonement', 'blood money', 'bonus', 'bounty', 'bribe', 'compensation', 'consideration', 'damages', 'donative', 'double time'],
    'honored': ['acclaimed', 'admired', 'adored', 'appreciated', 'celebrated', 'creditable', 'crowned with laurel', 'distinguished', 'esteemed', 'estimable', 'fabled', 'famed'],
    'honorific': ['appellation', 'appellative', 'attentive', 'binomen', 'binomial name', 'byname', 'byword', 'cap in hand', 'ceremonious', 'cognomen', 'cognominal', 'courteous'],
    'hooch': ['alcohol', 'aqua vitae', 'bathtub gin', 'blockade', 'bootleg', 'booze', 'corpse reviver', 'drink', 'firewater', 'grog', 'juice', 'likker'],
    'hood': ['mafioso', 'sob', 'young turk', 'apply to', 'bad boy', 'bastard', 'battler', 'beast', 'beldam', 'belligerent', 'belted knight', 'berserk'],
    'hooded': ['appareled', 'armored', 'arrayed', 'attired', 'bedecked', 'breeched', 'capped', 'cased', 'ceiled', 'chausse', 'clad', 'cloaked'],
    'hoodlum': ['mafioso', 'young turk', 'apache', 'bad boy', 'bandit', 'battler', 'beast', 'beldam', 'belligerent', 'belted knight', 'berserk', 'berserker'],
    'hoodoo': ['jonah', 'alchemy', 'amulet', 'bad influence', 'bedevil', 'bewitch', 'bewitchery', 'bring bad luck', 'charm', 'curse', 'demonize', 'diabolize'],
    'hoodwink': ['bamboozle', 'bandage', 'bedazzle', 'befool', 'benight', 'blind', 'blind the eyes', 'blindfold', 'chicane', 'con', 'darken', 'daze'],
    'hoodwinked': ['gothic', 'philistine', 'barbarous', 'bedazzled', 'blindfold', 'blindfolded', 'bookless', 'darkened', 'dazed', 'dazzled', 'deceived', 'excecate'],
    'hooey': ['balls', 'baloney', 'bilge', 'blague', 'blah', 'blah-blah', 'bop', 'bosh', 'bull', 'bullshit', 'bunk', 'bunkum'],
    'hoof': ['ambulate', 'ankle', 'arch', 'circumambulate', 'clog', 'clubfoot', 'dance', 'digit', 'dog', 'extremity', 'fetlock', 'foot'],
    'hoof-and-mouth disease': ['texas fever', 'anthrax', 'aphthous fever', 'bighead', 'black quarter', 'blackleg', 'blackwater', 'blind staggers', 'bloody flux', 'broken wind', 'cattle plague', 'charbon'],
    'hoofed': ['asinine', 'bovid', 'bovine', 'caprid', 'caprine', 'clawed', 'cowish', 'cowlike', 'deerlike', 'equestrian', 'equine', 'footed'],
    'hoofer': ['ambulator', 'artist', 'artiste', 'backpacker', 'ballerina', 'ballet dancer', 'ballet girl', 'ballroom dancer', 'belly dancer', 'burlesque queen', 'choral dancer', 'chorine'],
    'hoofing': ['ambling', 'ambulation', 'backpacking', 'ballet', 'ballroom dancing', 'choreodrama', 'choreography', 'classical ballet', 'comedy ballet', 'dance', 'dance drama', 'dancing'],
    'hook': ['long melford', 'abstract', 'acquitted', 'all the way', 'allure', 'anchor', 'anchorage', 'and', 'and sinker', 'angle', 'angle off', 'annex'],
    'hook up': ['act in concert', 'act together', 'affiliate', 'ally', 'amalgamate', 'associate', 'band', 'band together', 'be in cahoots', 'be in league', 'bridle', 'bunch'],
    'hook-and-ladder': ['foamite', 'acid', 'automatic sprinkler', 'carbon tet', 'carbon tetrachloride', 'carbon-dioxide foam', 'deck gun', 'deluge set', 'extinguisher', 'fire apparatus', 'fire engine', 'fire hose'],
    'hookah': ['missouri meerschaum', 'briar', 'briar pipe', 'calean', 'calumet', 'churchwarden', 'clay', 'corncob', 'corncob pipe', 'hubble-bubble', 'meerschaum', 'nargileh'],
    'hooked': ['roman-nosed', 'v-shaped', 'y-shaped', 'absorbed in', 'addicted', 'addicted to', 'akimbo', 'angular', 'aquiline', 'aquiline-nosed', 'beak-nosed', 'beak-shaped'],
    'hooker': ['b-girl', 'cyprian', 'paphian', 'argosy', 'bark', 'bawd', 'boat', 'bottom', 'bucket', 'call girl', 'craft', 'daughter of joy'],
    'hookup': ['anschluss', 'addition', 'affiliation', 'agglomeration', 'agglutination', 'aggregation', 'agreement', 'alignment', 'alliance', 'amalgamation', 'articulation', 'assimilation'],
    'hookworm': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'hooky': ['awol', 'french leave', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'cut', 'day off', 'default', 'departure'],
    'hooligan': ['babbitt', 'philistine', 'sob', 'arriviste', 'bad boy', 'bastard', 'battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'booger'],
    'hoop': ['anklet', 'armlet', 'band', 'belt', 'bracelet', 'cincture', 'cingulum', 'collar', 'collarband', 'earring', 'ecliptic', 'equator'],
    'hoopla': ['pr', 'ballyhoo', 'blurb', 'bright light', 'celebration', 'celebrity', 'common knowledge', 'conviviality', 'cry', 'currency', 'daylight', 'eclat'],
    'hooray': ['alleluia', 'applaud', 'applause', 'cheer', 'chorus of cheers', 'cry', 'cry for joy', 'give a cheer', 'hallelujah', 'hosanna', 'hurrah', 'hurray'],
    'hoot': ['bronx', 'bronx cheer', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'bagatelle', 'bark', 'battle cry', 'bauble', 'bawl'],
    'hootenanny': ['affair', 'article', 'artifact', 'choral service', 'dingus', 'dofunny', 'dohickey', 'dojigger', 'dojiggy', 'domajig', 'domajigger', 'doodad'],
    'hop': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'highland fling', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill'],
    'hop to it': ['attack', 'dive into', 'enter on', 'enter upon', 'fall to', 'get busy', 'get cracking', 'get going', 'get with it', 'go to it', 'hotfoot', 'hump'],
    'hope': ['acceptation', 'acception', 'ache for', 'acquiescence', 'ambition', 'anticipate', 'anticipation', 'approach', 'ardor', 'aspire', 'aspire to', 'assumption'],
    'hoped for': ['anticipated', 'approaching', 'awaited', 'coming', 'coveted', 'desired', 'destinal', 'destined', 'determined', 'due', 'emergent', 'eventual'],
    'hopeful': ['leibnizian optimist', 'pollyanna', 'addict', 'adolescent', 'advantageous', 'agape', 'agog', 'all agog', 'also-ran', 'anticipant', 'anticipating', 'anticipative'],
    'hopefully': ['after a time', 'after a while', 'afterward', 'afterwards', 'airily', 'anon', 'anticipatingly', 'anticipatively', 'anticipatorily', 'before long', 'blithely', 'by and by'],
    'hopeless': ['laodicean', 'olympian', 'pollyanna', 'absurd', 'affording no hope', 'aloof', 'apathetic', 'bad', 'barred', 'benumbed', 'blah', 'blase'],
    'hopelessness': ['schmerz', 'slough of despond', 'absurdity', 'acedia', 'aloofness', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'blank despondency'],
    'hophead': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser'],
    'hoping': ['appetitive', 'aspiring', 'assured', 'confident', 'desiderative', 'desireful', 'desiring', 'desirous', 'eager', 'expectant', 'fond', 'full of hope'],
    'hopped up': ['agog', 'antsy', 'antsy-pantsy', 'anxious', 'aquiver', 'aroused', 'atingle', 'atwitter', 'breathless', 'bursting', 'carried away', 'chafing'],
    'hopper': ['broad jumper', 'bucking bronco', 'buckjumper', 'cicada', 'cicala', 'cricket', 'dog-day cicada', 'flea', 'frog', 'gazelle', 'goat', 'grasshopper'],
    'horde': ['army', 'assemble', 'bunch', 'bunch up', 'clot', 'cluster', 'cohue', 'collect', 'come together', 'congregate', 'converge', 'copulate'],
    'horizon': ['azimuth', 'background', 'clear sight', 'color vision', 'command', 'compass', 'cone vision', 'day vision', 'daylight vision', 'discernment', 'domination', 'eye'],
    'horizontal': ['arrowlike', 'billiard table', 'bowling green', 'dead flat', 'dead level', 'dead straight', 'direct', 'earth', 'esplanade', 'even', 'flat', 'flatland'],
    'hormone': ['allen-doisy hormone', 'adjuvant', 'adrenosterone', 'androgen', 'androsterone', 'autacoid', 'bile', 'carminative', 'chalone', 'cholecystokinin', 'chondrotrophic hormone', 'corticosterone'],
    'horn': ['klaxon', 'mayday', 'sos', 'acoustical network', 'aerophone', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert'],
    'horn in': ['barge in', 'break in', 'break in upon', 'burst in', 'busybody', 'butt in', 'charge in', 'chisel', 'come between', 'crash', 'crash in', 'crash the gates'],
    'hornbook': ['abecedarium', 'abecedary', 'alphabet', 'alphabet book', 'and arithmetic', 'basics', 'battledore', 'casebook', 'elementary education', 'elements', 'exercise book', 'first principles'],
    'horned': ['cynthian', 's-shaped', 'acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'barbed', 'bicorn'],
    'hornswaggle': ['bamboozle', 'beguile', 'betray', 'bluff', 'cajole', 'cheat on', 'circumvent', 'conjure', 'deceive', 'delude', 'diddle', 'double-cross'],
    'horny': ['acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'animal', 'aphrodisiomaniacal', 'barbed', 'bawdy'],
    'horoscope': ['aspect', 'astrodiagnosis', 'astrology', 'astromancy', 'genethliac astrology', 'genethliacism', 'genethliacs', 'genethlialogy', 'horoscopy', 'house', 'mansion', 'mundane astrology'],
    'horrendous': ['appalling', 'astounding', 'atrocious', 'awe-inspiring', 'awesome', 'awful', 'baneful', 'beastly', 'dire', 'direful', 'dread', 'dreaded'],
    'horrible': ['abhorrent', 'abominable', 'appalling', 'arrant', 'astounding', 'atrocious', 'awe-inspiring', 'awesome', 'awful', 'baneful', 'base', 'beastly'],
    'horribly': ['abominably', 'agonizingly', 'alarmingly', 'appallingly', 'astoundingly', 'atrociously', 'awfully', 'baldly', 'balefully', 'banefully', 'basely', 'bestially'],
    'horrid': ['abhorrent', 'abominable', 'appalling', 'arrant', 'astounding', 'atrocious', 'awe-inspiring', 'awesome', 'awful', 'baneful', 'base', 'beastly'],
    'horridly': ['abominably', 'alarmingly', 'appallingly', 'astoundingly', 'atrociously', 'awfully', 'banefully', 'basely', 'bestially', 'brutally', 'contemptibly', 'despicably'],
    'horrified': ['aghast', 'appalled', 'ashen', 'astounded', 'awed', 'awestricken', 'awestruck', 'blanched', 'cowed', 'deadly pale', 'frozen', 'gray with fear'],
    'horrify': ['alarm', 'appall', 'awe', 'daunt', 'disconcert', 'discountenance', 'disgust', 'dismay', 'distress', 'freeze', 'frighten', 'give offense'],
    'horrifying': ['appalling', 'astounding', 'atrocious', 'awe-inspiring', 'awesome', 'awful', 'baneful', 'beastly', 'dire', 'direful', 'dread', 'dreaded'],
    'horripilate': ['affright', 'alarm', 'be cold', 'boss', 'chatter', 'chill', 'coarsen', 'curdle the blood', 'didder', 'disquiet', 'dither', 'freeze'],
    'horripilation': ['ache', 'aching', 'agitation', 'broken ground', 'broken water', 'chilblains', 'chill', 'chilliness', 'chilling', 'chills of fear', 'chop', 'cold creeps'],
    'horror': ['dracula', 'frankenstein', 'wolf-man', 'abhorrence', 'abject fear', 'abomination', 'affright', 'alarm', 'allergy', 'angst', 'animosity', 'animus'],
    'hors de combat': ['all up with', 'beat', 'beaten', 'bested', 'confounded', 'defeated', 'discomfited', 'done for', 'done in', 'down', 'fallen', 'fixed'],
    'horse': ['al borak', 'american trotter', 'amytal', 'amytal pill', 'angora goat', 'appaloosa', 'arabian', 'arctic fox', 'barb', 'barbary horse', 'belgian', 'belgian hare'],
    'horse around': ['act up', 'antic', 'be foolish', 'be stupid', 'behave ill', 'caper', 'caracole', 'carry on', 'cavort', 'clown', 'clown around', 'coquet'],
    'horse latitudes': ['antarctic zone', 'arctic circle', 'arctic zone', 'frigid zones', 'torrid zone', 'tropic of cancer', 'tropic of capricorn', 'variable zones', 'anticyclone', 'antitrades', 'calm', 'climate'],
    'horse opera': ['cinemascope', 'cinerama', 'marchen', 'technicolor', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'animated cartoon', 'apologue', 'bedtime story'],
    'horse racing': ['automobile racing', 'bingo', 'card games', 'chuck and toss', 'chuck farthing', 'chuck-a-luck', 'crack-loo', 'crap game', 'crap shooting', 'craps', 'dog racing', 'fan-tan'],
    'horse sense': ['balance', 'common sense', 'cool head', 'coolheadedness', 'coolness', 'due sense of', 'good sense', 'gumption', 'judgment', 'level head', 'levelheadedness', 'plain sense'],
    'horse trader': ['artful dodger', 'philadelphia lawyer', 'yankee horse trader', 'bunco artist', 'bunco steerer', 'cardsharp', 'cardsharper', 'carpetbagger', 'charmer', 'con artist', 'con man', 'confidence man'],
    'horse trading': ['agency', 'barter', 'bartering', 'brokerage', 'buying and selling', 'dealing', 'doing business', 'exchange', 'give-and-take', 'interchange', 'jobbing', 'merchandising'],
    'horseback': ['across', 'astraddle', 'astride', 'by horse', 'chine', 'col', 'comb', 'esker', 'hogback', 'kame', 'mounted', 'on'],
    'horsehair': ['bristle', 'capillament', 'catgut', 'chord', 'cilium', 'coat', 'fiddlestring', 'fleece', 'fur', 'hair', 'mane', 'nylon string'],
    'horselaugh': ['homeric laughter', 'belly laugh', 'boff', 'boffola', 'burst of laughter', 'cachinnation', 'cackle', 'chortle', 'chuckle', 'convulsion', 'crow', 'fit of laughter'],
    'horseman': ['broncobuster', 'buckaroo', 'caballero', 'cavalier', 'cavalryman', 'chevalier', 'circus rider', 'cowboy', 'cowgirl', 'cowpuncher', 'equestrian', 'equestrienne'],
    'horsemanship': ['ability', 'address', 'adeptness', 'adroitness', 'airmanship', 'animal husbandry', 'animal rearing', 'artfulness', 'artisanship', 'artistry', 'automobiling', 'bee culture'],
    'horseplay': ['badness', 'banter', 'buffoonery', 'clownishness', 'discourtesy', 'disorder', 'disorderliness', 'disorderly conduct', 'disruption', 'disruptiveness', 'foolery', 'fooling'],
    'horsewhip': ['baste', 'bastinado', 'beat', 'belabor', 'belt', 'birch', 'blacksnake', 'buffet', 'bullwhack', 'bullwhip', 'cane', 'cat'],
    'horsy': ['asinine', 'bovid', 'bovine', 'caprid', 'caprine', 'cowish', 'cowlike', 'deerlike', 'equestrian', 'equine', 'goatish', 'goatlike'],
    'hortatory': ['admonitory', 'advisory', 'autodidactic', 'cajoling', 'cautionary', 'coeducational', 'consultative', 'consultatory', 'cultural', 'didactic', 'directive', 'disciplinary'],
    'horticultural': ['arboricultural', 'blooming', 'bloomy', 'blossoming', 'efflorescent', 'floral', 'floreate', 'florescent', 'floriate', 'floriated', 'floricultural', 'florid'],
    'horticulture': ['bloom', 'blossom', 'blow', 'citriculture', 'floret', 'floriculture', 'floscule', 'flower', 'flower gardening', 'flower-growing', 'floweret', 'fruit-growing'],
    'hosanna': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'nunc dimittis', 'te deum', 'trisagion', 'vedic hymn'],
    'hose': ['adjutage', 'asperge', 'bedew', 'bespatter', 'besprinkle', 'catheter', 'dabble', 'damp', 'dampen', 'dash', 'dew', 'douche'],
    'hospice': ['almshouse', 'asylum', 'boardinghouse', 'dorm', 'dormitory', 'doss house', 'fleabag', 'flophouse', 'foster home', 'guest house', 'halfway house', 'home'],
    'hospitable': ['admissible', 'admissive', 'admissory', 'affable', 'agreeable', 'amenable', 'amiable', 'amicable', 'approachable', 'ardent', 'assuring', 'bighearted'],
    'hospital': ['va hospital', 'asylum', 'base hospital', 'clinic', 'community hospital', 'convalescent home', 'convalescent hospital', 'dispensary', 'evacuation hospital', 'field hospital', 'general hospital', 'home'],
    'hospital room': ['x ray', 'blood bank', 'charity ward', 'clinic', 'consultation room', 'delivery room', 'dispensary', 'emergency', 'examining room', 'fever ward', 'intensive care', 'isolation'],
    'hospitality': ['admissibility', 'affability', 'amiability', 'amicability', 'ardency', 'assembly-line housing', 'bigheartedness', 'billeting', 'bonhomie', 'bounteousness', 'bountifulness', 'bounty'],
    'host': ['mc', 'a mass of', 'a world of', 'announcer', 'armed force', 'armed service', 'army', 'array', 'assemblage', 'assembly', 'bevy', 'body'],
    'hostage': ['bail', 'bond', 'captive', 'earnest', 'earnest money', 'escrow', 'gage', 'guaranty', 'handsel', 'hock', 'mainprise', 'pawn'],
    'hostel': ['boardinghouse', 'dorm', 'dormitory', 'doss house', 'fleabag', 'flophouse', 'guest house', 'hospice', 'hostelry', 'hotel', 'inn', 'lodge'],
    'hostile': ['acrid', 'adversary', 'adversative', 'adverse', 'adversive', 'against', 'aggressive', 'alien', 'allergic', 'antagonistic', 'anti', 'antipathetic'],
    'hostilities': ['all-out war', 'appeal to arms', 'armed combat', 'armed conflict', 'attack', 'battle', 'belligerence', 'belligerency', 'bloodshed', 'combat', 'fighting', 'hot war'],
    'hostility': ['kilkenny cats', 'abhorrence', 'abomination', 'action', 'aggression', 'aggressiveness', 'allergy', 'altercation', 'animosity', 'animus', 'antagonism', 'anteposition'],
    'hostler': ['breaker', 'breeder', 'broncobuster', 'buckaroo', 'cattleman', 'cow keeper', 'cowman', 'dairy farmer', 'dairyman', 'equerry', 'farrier', 'grazier'],
    'hot': ['ok', 'titian', 'titian-red', 'abandoned', 'ablaze', 'ace-high', 'activated', 'afire', 'animal', 'ape about', 'aphrodisiomaniacal', 'approaching'],
    'hot air': ['babble', 'babblement', 'balderdash', 'baloney', 'bavardage', 'bibble-babble', 'big talk', 'bilge', 'blab', 'blabber', 'blah', 'blah-blah'],
    'hot blood': ['andromania', 'aphrodisia', 'biological urge', 'bodily appetite', 'carnal desire', 'concupiscence', 'desire', 'eromania', 'eroticism', 'eroticomaniac', 'erotism', 'erotomania'],
    'hot blooded': ['abandoned', 'afire', 'ardent', 'burning', 'committed', 'concupiscent', 'dedicated', 'devoted', 'devout', 'earnest', 'ejaculatory', 'faithful'],
    'hot dog': ['blt', 'dagwood sandwich', 'sloppy joe', 'swiss cheese sandwich', 'vienna sausage', 'bacon-lettuce-tomato sandwich', 'bangers', 'black pudding', 'blood pudding', 'bologna', 'braunschweiger', 'canape'],
    'hot pants': ['andromania', 'aphrodisia', 'biological urge', 'bodily appetite', 'carnal desire', 'concupiscence', 'desire', 'eromania', 'eroticism', 'eroticomaniac', 'erotism', 'erotomania'],
    'hot seat': ['ax', 'beheading', 'block', 'burning', 'capital punishment', 'cross', 'crucifixion', 'death chair', 'death chamber', 'decapitation', 'decollation', 'defenestration'],
    'hot up': ['accelerate', 'agent provocateur', 'aggravate', 'amplify', 'annoy', 'augment', 'beef up', 'blow up', 'build up', 'chafe', 'complicate', 'concentrate'],
    'hot water': ['dutch', 'old faithful', 'bind', 'boiling water', 'box', 'clutch', 'complication', 'corner', 'crunch', 'deep', 'embarrassing position', 'embarrassment'],
    'hotbed': ['hydra', 'birthplace', 'breeding place', 'brooder', 'cloche', 'cold frame', 'conservatory', 'coolhouse', 'cradle', 'forcing', 'forcing bed', 'forcing house'],
    'hotchpotch': ['agglomeration', 'conglomeration', 'farrago', 'gallimaufry', 'hash', 'hodgepodge', 'jumble', 'medley', 'melange', 'mess', 'miscellany', 'mishmash'],
    'hotel': ['boardinghouse', 'dorm', 'dormitory', 'doss house', 'fleabag', 'flophouse', 'guest house', 'hospice', 'hostel', 'hostelry', 'inn', 'lodge'],
    'hotfoot': ['amain', 'apace', 'at once', 'bound', 'by forced marches', 'canter', 'cursorily', 'expeditiously', 'feverishly', 'fox-trot', 'furiously', 'gallop'],
    'hothead': ['mafioso', 'tartar', 'young turk', 'bear', 'beast', 'beldam', 'berserk', 'berserker', 'bomber', 'brute', 'crank', 'crosspatch'],
    'hotheaded': ['accident-prone', 'ardent', 'brash', 'breakneck', 'careless', 'combustible', 'daredevil', 'desperate', 'devil-may-care', 'explosive', 'fanatic', 'fierce'],
    'hothouse': ['babied', 'cloche', 'coddled', 'cold frame', 'conservatory', 'coolhouse', 'dainty', 'delicate', 'forcing bed', 'forcing house', 'forcing pit', 'fragile'],
    'hotly': ['ardently', 'demonically', 'desperately', 'doggedly', 'energetically', 'enthusiastically', 'fanatically', 'fervently', 'fervidly', 'feverishly', 'fiercely', 'frantically'],
    'hound': ['afghan hound', 'alaskan malamute', 'bedlington terrier', 'border terrier', 'boston bull', 'cairn terrier', 'chihuahua', 'dalmatian', 'doberman pinscher', 'english toy spaniel', 'eskimo dog', 'gordon setter'],
    'hounded': ['badgered', 'baited', 'bedeviled', 'beset', 'bugged', 'bullyragged', 'chivied', 'deviled', 'dogged', 'fretted', 'harassed', 'harried'],
    'hour': ['abundant year', 'academic year', 'annum', 'bell', 'bissextile year', 'calendar month', 'calendar year', 'century', 'common year', 'day', 'decade', 'decennary'],
    'hourglass': ['abbreviation', 'astriction', 'astringency', 'bottleneck', 'cervix', 'circumscription', 'coarctation', 'compactedness', 'compaction', 'compression', 'compressure', 'concentration'],
    'houri': ['adonis', 'aphrodite', 'apollo', 'apollo belvedere', 'aspasia', 'astarte', 'balder', 'cleopatra', 'delilah', 'freya', 'hebe', 'hyperion'],
    'hourly': ['always', 'annual', 'at all times', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'ceaselessly', 'centenary', 'centennial', 'constantly'],
    'house': ['aktiengesellschaft', 'dymaxion house', 'elizabethan theater', 'globe theatre', 'greek theater', 'white house', 'abbey', 'abode', 'accommodate', 'adobe house', 'affiliation', 'agency'],
    'house of cards': ['breakers ahead', 'bubble', 'cambric tea', 'cardhouse', 'cause for alarm', 'china', 'cobweb', 'crisis', 'danger', 'dangerous ground', 'dishwater', 'eggshell'],
    'house of god': ['abbey', 'basilica', 'bethel', 'cathedral', 'chantry', 'chapel', 'church', 'conventicle', 'fane', 'house of prayer', 'kirk', 'masjid'],
    'housebreak': ['acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'apprentice', 'break', 'break in', 'break to harness', 'breed', 'bring up'],
    'housebroken': ['broken', 'brought low', 'chastened', 'crushed', 'domesticated', 'dovelike', 'gentle', 'housebroke', 'humble', 'humbled', 'humiliated', 'lamblike'],
    'housed': ['armored', 'billeted', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'coped', 'covered', 'covert', 'cowled', 'curtained'],
    'household': ['attic', 'accustomed', 'ancestral halls', 'average', 'brood', 'chaste', 'children', 'chimney corner', 'classic', 'classical', 'common', 'commonly known'],
    'household words': ['austerity', 'baldness', 'bareness', 'candor', 'common speech', 'directness', 'frankness', 'homespun', 'leanness', 'matter-of-factness', 'naturalness', 'openness'],
    'householder': ['beneficiary', 'cestui', 'cestui que trust', 'cestui que use', 'cottager', 'cotter', 'cottier', 'crofter', 'deedholder', 'feoffee', 'feudatory', 'freeholder'],
    'housekeeper': ['mc', 'attorney', 'bailiff', 'butler', 'chamberlain', 'croupier', 'curator', 'custodian', 'emcee', 'factor', 'guardian', 'house steward'],
    'housetop': ['ceiling', 'eaves', 'lantern', 'overhead', 'penthouse', 'plafond', 'ridgepole', 'roof', 'roof garden', 'roof-deck', 'roofage', 'roofing'],
    'housewares': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'dinnerware', 'durable goods', 'durables', 'earthenware', 'enamelware', 'fixtures', 'flatware'],
    'housewarming': ['kaffeeklatsch', 'assemblee', 'assembly', 'assignation', 'at home', 'ball', 'blowout', 'brawl', 'caucus', 'cocktail party', 'coffee klatch', 'colloquium'],
    'housing': ['accommodation', 'accommodations', 'architectonic', 'architectural', 'assembly-line housing', 'berth', 'billeting', 'blanket', 'box', 'building', 'cabinet', 'caparison'],
    'hovel': ['augean stables', 'burrow', 'coop', 'crib', 'dump', 'hole', 'hut', 'hutch', 'pesthole', 'pigpen', 'pigsty', 'plague spot'],
    'hover': ['aeroplane', 'airlift', 'airplane', 'approach', 'around', 'ascend', 'aspire', 'await', 'back down', 'balance', 'balloon', 'be airborne'],
    'however': ['after all', 'again', 'albeit', 'all the same', 'although', 'anyhow', 'anyway', 'anywise', 'at all', 'at all events', 'at any rate', 'but'],
    'howl': ['bedlam let loose', 'air a grievance', 'animal noise', 'bark', 'barking', 'battle cry', 'bawl', 'bay', 'bedlam', 'beef', 'beefing', 'bell'],
    'howler': ['irish bull', 'belly laugh', 'bloomer', 'blooper', 'blue story', 'blunder', 'bobble', 'bonehead play', 'boner', 'boo-boo', 'boob stunt', 'boot'],
    'howling': ['jeremianic', 'abandoned', 'acute', 'amok', 'animal noise', 'argute', 'awful', 'bark', 'barking', 'bawling', 'bellowing', 'bemoaning'],
    'hoyden': ['amazon', 'androgyne', 'babe', 'baby', 'broad', 'butch', 'chick', 'colleen', 'cutie', 'dame', 'damoiselle', 'damsel'],
    'hub': ['approach', 'arbor', 'asymptote', 'axis', 'axle', 'axle bar', 'axle shaft', 'axle spindle', 'axle-tree', 'bottleneck', 'center', 'center of action'],
    'hubbub': ['bedlam let loose', 'ado', 'agitation', 'apologetics', 'apologia', 'apology', 'argument', 'argumentation', 'babel', 'bedlam', 'bicker', 'bickering'],
    'hubris': ['arrogance', 'assumption', 'assurance', 'assuredness', 'audacity', 'belief', 'boldness', 'brashness', 'brass', 'brazen boldness', 'bumptiousness', 'certitude'],
    'huckster': ['arab', 'bargain', 'beat down', 'bid', 'bid for', 'cadger', 'chaffer', 'chapman', 'cheap-jack', 'cheap-john', 'cheapen', 'cheapjack'],
    'huckstering': ['aggrandizement', 'amplification', 'ballyhoo', 'big talk', 'blowing up', 'burlesque', 'caricature', 'consumer preference study', 'consumer research', 'consumer survey', 'dilatation', 'dilation'],
    'huddle': ['around', 'assemble', 'ataxia', 'audience', 'bargaining', 'bargaining session', 'bunch', 'bunch up', 'chaos', 'clasp', 'cling to', 'clot'],
    'hue': ['munsell chroma', 'achromatism', 'apply paint', 'bedaub', 'bedizen', 'begild', 'besmear', 'body-build', 'brand', 'brightness', 'brush on paint', 'calcimine'],
    'hue and cry': ['bedlam let loose', 'klaxon', 'mayday', 'pr', 'sos', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert'],
    'huff': ['add to', 'aggrandize', 'aggravate', 'amplify', 'angered', 'annoy', 'annoyed', 'arouse', 'augment', 'blast', 'bloat', 'blow'],
    'huffy': ['aggravated', 'annoyed', 'arrogant', 'bearish', 'bitchy', 'cankered', 'cantankerous', 'cavalier', 'churlish', 'crabbed', 'cranky', 'cross'],
    'hug': ['abduct', 'accost', 'accueil', 'address', 'adhere', 'adhere to', 'agglomerate', 'around', 'bear', 'bear hug', 'bite', 'bob'],
    'huge': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'amplitudinous', 'astronomic', 'astronomical', 'awesome', 'boundless'],
    'hugeness': ['ampleness', 'amplitude', 'boundlessness', 'bulk', 'enormity', 'enormousness', 'expanse', 'formidableness', 'fullness', 'gigantism', 'grandeur', 'grandness'],
    'hugger mugger': ['airtight secrecy', 'all over', 'all over hell', 'anarchic', 'arsy-varsy', 'ass-backwards', 'back-door', 'backstairs', 'balled up', 'black out', 'bollixed up', 'by stealth'],
    'hulk': ['anatomy', 'argosy', 'bark', 'boat', 'body', 'bones', 'bottom', 'bucket', 'carcass', 'clay', 'clod', 'corpus'],
    'hulking': ['all thumbs', 'awkward', 'blunderheaded', 'blundering', 'boorish', 'bulky', 'bumbling', 'bungling', 'butterfingered', 'careless', 'clownish', 'clumsy'],
    'hull': ['argosy', 'bark', 'boat', 'body', 'boll', 'bottom', 'bran', 'bucket', 'burr', 'capsule', 'case', 'chaff'],
    'hullabaloo': ['bedlam let loose', 'ado', 'agitation', 'babel', 'bedlam', 'blast', 'bobbery', 'bother', 'botheration', 'brawl', 'brouhaha', 'burst'],
    'hum': ['indian file', 'anthem', 'array', 'articulation', 'ballad', 'bank', 'bel canto', 'birdies', 'birr', 'blooping', 'blurping', 'bombilate'],
    'human': ['adamite', 'adamitic', 'christian', 'christlike', 'christly', 'accommodating', 'affectionate', 'android', 'anthropocentric', 'anthropoid', 'anthropological', 'being'],
    'human factor': ['differentiation', 'differentness', 'distinctiveness', 'egohood', 'identity', 'individualism', 'individuality', 'integrity', 'nominalism', 'nonconformity', 'oneness', 'particularism'],
    'human interest': ['blood and thunder', 'demonstrativeness', 'emotional appeal', 'emotionalism', 'emotionality', 'emotionalization', 'emotionalizing', 'emotiveness', 'emotivity', 'histrionics', 'love interest', 'making scenes'],
    'human nature': ['adam', 'hominidae', 'homo sapiens', 'clay', 'fallen humanity', 'flesh', 'frailty', 'generation of man', 'genus homo', 'hominid', 'homo', 'human equation'],
    'human race': ['adam', 'hominidae', 'homo sapiens', 'clay', 'fallen humanity', 'flesh', 'generation of man', 'genus homo', 'hominid', 'homo', 'human family', 'human nature'],
    'humane': ['christian', 'christlike', 'christly', 'accepting', 'affectionate', 'altruistic', 'benevolent', 'benign', 'benignant', 'bleeding', 'brotherly', 'charitable'],
    'humanism': ['christian humanism', 'religious humanism', 'anthroposophy', 'bibliolatry', 'bibliomania', 'bluestockingism', 'book learning', 'book madness', 'bookiness', 'bookishness', 'booklore', 'classical scholarship'],
    'humanist': ['academician', 'bookman', 'classicist', 'clerk', 'colossus of knowledge', 'esprit fort', 'freethinker', 'genius', 'giant of learning', 'latitudinarian', 'learned clerk', 'learned man'],
    'humanitarian': ['robin hood', 'almoner', 'almsgiver', 'almsgiving', 'altruistic', 'benefactor', 'beneficent', 'benevolent', 'benevolist', 'bighearted', 'charitable', 'do-gooder'],
    'humanitarianism': ['bomfog', 'benthamism', 'christian charity', 'christian love', 'agape', 'altruism', 'beneficence', 'benevolence', 'benevolent disposition', 'benevolentness', 'bigheartedness', 'brotherly love'],
    'humanities': ['academic specialty', 'area', 'classical education', 'core curriculum', 'course', 'course of study', 'curriculum', 'discipline', 'elective', 'field', 'general education', 'general studies'],
    'humanity': ['adam', 'hominidae', 'homo sapiens', 'acceptance', 'affectionateness', 'beneficence', 'benevolence', 'benignancy', 'benignity', 'brotherhood', 'charitableness', 'clay'],
    'humanoid': ['bronze age man', 'hominidae', 'iron age man', 'stone age man', 'aboriginal', 'aborigine', 'ancestral', 'ancient', 'antediluvian', 'antepatriarchal', 'anthropoid', 'anthropomorphic'],
    'humble': ['abase', 'abash', 'abject', 'accommodating', 'acquiescent', 'adapting', 'adaptive', 'adjusting', 'altruistic', 'amenable', 'apologetic', 'base'],
    'humbled': ['abashed', 'abject', 'apologetic', 'ashamed', 'blushing', 'bowed down', 'broken', 'brought down', 'brought low', 'chagrined', 'chapfallen', 'conquered'],
    'humbly': ['abjectly', 'apologetically', 'contritely', 'meekly', 'modestly', 'on all fours', 'on bended knee', 'penitentially', 'penitently', 'quietly', 'repentantly', 'sheepishly'],
    'humbug': ['absurdity', 'acting', 'affectation', 'amphigory', 'appearance', 'attitudinizing', 'babble', 'babblement', 'balderdash', 'balls', 'baloney', 'bamboozle'],
    'humdinger': ['ace', 'beaut', 'corker', 'crackerjack', 'daisy', 'dandy', 'darb', 'dilly', 'dream', 'honey', 'killer-diller', 'knockout'],
    'humdrum': ['alliterating', 'alliteration', 'alliterative', 'assonance', 'assonant', 'banal', 'banausic', 'belabored', 'blah', 'bore', 'boring', 'broken record'],
    'humid': ['boggy', 'clammy', 'close', 'damp', 'dampish', 'dank', 'dewy', 'fenny', 'marshy', 'moist', 'mucky', 'muggy'],
    'humidify': ['asperge', 'bedew', 'bespatter', 'besprinkle', 'dabble', 'damp', 'dampen', 'dash', 'dew', 'douche', 'hose', 'hose down'],
    'humidor': ['havana', 'belvedere', 'box of cigars', 'cheroot', 'cigar', 'cigar box', 'cigar case', 'cigar cutter', 'cigarillo', 'colorado', 'corona', 'hair hygrometer'],
    'humiliate': ['abase', 'affront', 'beat down', 'bend', 'break', 'break down', 'bring into discredit', 'bring low', 'bring shame upon', 'bring to terms', 'call names', 'cast down'],
    'humiliated': ['abashed', 'ashamed', 'blushing', 'broken', 'brought low', 'chagrined', 'chapfallen', 'crestfallen', 'crushed', 'domesticated', 'embarrassed', 'hangdog'],
    'humiliating': ['abusive', 'atrocious', 'awkward', 'backhand', 'backhanded', 'beneath one', 'calumnious', 'chastening', 'cheap', 'contumelious', 'crushing', 'debasing'],
    'humiliation': ['abasement', 'affront', 'aspersion', 'atrocity', 'awkwardness', 'belittlement', 'breaking', 'brickbat', 'burning shame', 'byword', 'byword of reproach', 'comedown'],
    'humility': ['quakerism', 'acquiescence', 'altruism', 'amenability', 'back seat', 'bashfulness', 'commitment', 'compliance', 'consecration', 'dedication', 'devotion', 'diffidence'],
    'humming': ['bel canto', 'birring', 'bombilation', 'bombinating', 'bombination', 'booming', 'bravura', 'burring', 'busy', 'buzzing', 'choral singing', 'coloratura'],
    'hummock': ['anthill', 'barrow', 'brae', 'butte', 'down', 'drumlin', 'dune', 'fell', 'foothills', 'hill', 'hillock', 'knob'],
    'humor': ['atticism', 'rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'agile wit', 'ambiversion', 'antibody', 'antigen', 'appease', 'arterial blood'],
    'humoral': ['adrenal', 'bloody', 'chylifactive', 'chylifactory', 'chylific', 'eccrine', 'endocrine', 'exocrine', 'glandular', 'glandulous', 'gonadal', 'holocrine'],
    'humorist': ['advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'banana', 'banterer', 'belletrist', 'bibliographer', 'buffoon', 'burlesquer', 'card'],
    'humorless': ['cheerless', 'discontented', 'grim', 'in bad humor', 'infestive', 'joyless', 'mirthless', 'miserable', 'out of humor', 'out of sorts', 'pleasureless', 'sorry'],
    'humorous': ['attic', 'absurd', 'amusing', 'beguiling', 'biting', 'bizarre', 'brilliant', 'clever', 'comical', 'delightful', 'diverting', 'droll'],
    'humorously': ['absurdly', 'amusingly', 'bizarrely', 'broadly', 'comically', 'drolly', 'eccentrically', 'facetiously', 'farcically', 'funnily', 'incongruously', 'jocosely'],
    'hump': ['everest', 'olympus', 'alp', 'arch', 'barrow', 'bear', 'bend', 'bend back', 'bilge', 'blain', 'bleb', 'blister'],
    'humpbacked': ['arched', 'arciform', 'arclike', 'arcual', 'bandy', 'bowed', 'bowlike', 'bunchbacked', 'camelback', 'concave', 'convex', 'crookbacked'],
    'humped': ['arched', 'arciform', 'arclike', 'arcual', 'bandy', 'bowed', 'bowlike', 'bunchbacked', 'camelback', 'concave', 'convex', 'convexed'],
    'hun': ['anzac', 'aussie', 'boche', 'fritz', 'gi', 'heinie', 'jerry', 'johnny', 'kraut', 'tommy', 'tommy atkins', 'yank'],
    'hunch': ['arch', 'bend', 'bend back', 'bilge', 'blain', 'bleb', 'blind guess', 'blister', 'blob', 'bold conjecture', 'boss', 'bow'],
    'hunchback': ['bowlegs', 'camelback', 'cleft palate', 'clubfoot', 'crookback', 'defacement', 'deformation', 'deformity', 'disfigurement', 'flatfoot', 'freakishness', 'harelip'],
    'hunched': ['arched', 'arciform', 'arclike', 'arcual', 'bandy', 'bowed', 'bowlike', 'concave', 'convex', 'embowed', 'gibbose', 'gibbous'],
    'hundred': ['kreis', 'archbishopric', 'archdiocese', 'arrondissement', 'bailiwick', 'bicentenary', 'bicentennial', 'bishopric', 'borough', 'canton', 'cental', 'centare'],
    'hung': ['cascading', 'dangling', 'dependent', 'depending', 'falling', 'falling loosely', 'flowing', 'hanging', 'pendent', 'pending', 'pendulant', 'pendular'],
    'hung up': ['abashed', 'afflicted', 'agitated', 'arrested', 'back', 'backward', 'behindhand', 'belated', 'beset', 'besotted', 'blocked', 'bothered'],
    'hunger': ['ache', 'an universal wolf', 'appetence', 'appetency', 'appetite', 'appetition', 'aspire after', 'be ravenous', 'break bread', 'canine appetite', 'cannibalism', 'carnivorism'],
    'hungering': ['athirst', 'consumed with desire', 'coveting', 'craving', 'devoured by desire', 'dog-hungry', 'empty', 'famished', 'famishing', 'fasting', 'fervid', 'half-famished'],
    'hungry': ['acquisitive', 'athirst', 'avid', 'consumed with desire', 'coveting', 'covetous', 'craving', 'deprived', 'desirous', 'devoured by desire', 'dog-hungry', 'dying'],
    'hunk': ['accumulation', 'acervation', 'agglomerate', 'agglomeration', 'aggregate', 'aggregation', 'amassment', 'amount', 'batch', 'bit', 'block', 'budget'],
    'hunky dory': ['ok', 'ace-high', 'bad', 'bang-up', 'bonzer', 'boss', 'bully', 'but good', 'cool', 'corking', 'crackerjack', 'dandy'],
    'hunt': ['angle for', 'ask for', 'beat', 'beat about for', 'beat the bushes', 'beset', 'burrow', 'capture', 'cast about', 'chase', 'chase out', 'check out'],
    'hunt down': ['beat', 'chase', 'course', 'determine', 'dig out', 'discover', 'dog', 'drive', 'falcon', 'find', 'find out', 'flush'],
    'hunter': ['nimrod', 'orion', 'archer', 'artilleryman', 'beater', 'bidet', 'big game hunter', 'bird dog', 'bowman', 'cannoneer', 'carabineer', 'carriage horse'],
    'hunting': ['analog process', 'angling', 'behavior pattern', 'chase', 'chevy', 'chivy', 'coursing', 'cynegetic', 'cynegetics', 'digital process', 'dogging', 'domiciliary visit'],
    'hurdle': ['highland fling', 'and jump', 'bar', 'barrier', 'block', 'blockade', 'bottleneck', 'bounce', 'bound', 'broad jump', 'buck', 'buckjump'],
    'hurl': ['bowl', 'bung', 'cast', 'cast at', 'catapult', 'change of pace', 'change-up', 'chuck', 'chuck at', 'chunk', 'clap', 'curve'],
    'hurl a brickbat': ['affront', 'call names', 'dishonor', 'disoblige', 'dump on', 'fleer at', 'flout', 'gibe at', 'give offense to', 'humiliate', 'insult', 'jeer at'],
    'hurly burly': ['ado', 'agitation', 'bluster', 'bobbery', 'boil', 'boiling', 'brouhaha', 'bustle', 'churn', 'clamor', 'commotion', 'conturbation'],
    'hurrah': ['alleluia', 'applaud', 'applause', 'ardor', 'bark', 'battle cry', 'bawl', 'bellow', 'calenture', 'call', 'caterwaul', 'cheer'],
    'hurricane': ['black squall', 'blaze', 'blizzard', 'blow', 'burst', 'convulsion', 'cyclone', 'dirty weather', 'equinoctial', 'eruption', 'explosion', 'fit'],
    'hurried': ['abrupt', 'accident-prone', 'at the double', 'breakneck', 'brief', 'careless', 'crowded', 'cursory', 'desperate', 'devil-may-care', 'double-quick', 'double-time'],
    'hurriedness': ['barrel', 'beeline', 'bowl along', 'breeze', 'bucket', 'bullet', 'bustle', 'dig in', 'dust', 'fleet', 'flit', 'fly'],
    'hurry': ['accelerate', 'ado', 'agitation', 'air speed', 'bolt', 'brouhaha', 'bundle', 'bustle', 'buzz about', 'career', 'celerity', 'chase'],
    'hurry scurry': ['a corps perdu', 'ado', 'agitation', 'amain', 'apace', 'at once', 'brouhaha', 'bundle', 'bustle', 'by forced marches', 'carelessly', 'chase'],
    'hurry up': ['accelerate', 'bundle', 'bustle', 'chase', 'crack on', 'crowd', 'dash', 'dash off', 'dash on', 'dispatch', 'double-time', 'drive on'],
    'hurt': ['schmerz', 'abomination', 'abrade', 'abrasion', 'abuse', 'ache', 'aches and pains', 'aching', 'affect', 'afflict', 'afflicted', 'affront'],
    'hurtful': ['acute', 'afflictive', 'agonizing', 'atrocious', 'baleful', 'baneful', 'biting', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'counterproductive'],
    'hurting': ['schmerz', 'aches and pains', 'aching', 'acute', 'afflicted', 'afflictive', 'agonized', 'agonizing', 'algetic', 'atrocious', 'bankruptcy', 'biting'],
    'hurtle': ['assault', 'bang', 'bang into', 'bear', 'bear upon', 'bolt', 'boost', 'bowl', 'buck', 'bull', 'bulldoze', 'bump'],
    'husband': ['benedict', 'boss', 'bridegroom', 'budget', 'bwana', 'chef', 'chief', 'church dignitary', 'conserve', 'consort', 'ecclesiarch', 'economize'],
    'husbandly': ['adoring', 'affectionate', 'bridal', 'cannily', 'carefully', 'charily', 'conjugal', 'connubial', 'demonstrative', 'devoted', 'economically', 'epithalamic'],
    'husbandry': ['agrarianism', 'agricultural geology', 'agriculture', 'agrology', 'agronomics', 'agronomy', 'austerity', 'austerity program', 'authority', 'canniness', 'care', 'carefulness'],
    'hush': ['allay', 'appease', 'assibilate', 'assibilation', 'awful silence', 'black out', 'buzz', 'calm', 'calm down', 'censor', 'choke', 'choke off'],
    'hush hush': ['arcane', 'cabalistic', 'censored', 'clandestine', 'classified', 'close', 'closed', 'concealed', 'covert', 'cryptic', 'dark', 'enigmatic'],
    'hush money': ['account', 'allowance', 'assessment', 'bill', 'blackmail', 'blood money', 'boodle', 'bribe', 'bribe money', 'emolument', 'fee', 'footing'],
    'hushed': ['at rest', 'calm', 'chastened', 'cloistered', 'closet', 'confidential', 'constrained', 'controlled', 'cool', 'dwindling', 'ebbing', 'echoless'],
    'husk': ['afterglow', 'afterimage', 'balance', 'bark', 'boll', 'bones', 'bran', 'burr', 'butt', 'butt end', 'candle ends', 'capsule'],
    'husky': ['herculean', 'siberian husky', 'ass', 'beast of burden', 'beefy', 'big', 'bouncing', 'brassy', 'brawny', 'brazen', 'bull', 'burly'],
    'hussy': ['jezebel', 'bad woman', 'baggage', 'bitch', 'boldface', 'brazenface', 'broad', 'chippy', 'chutzpanik', 'clitoromaniac', 'cocotte', 'drab'],
    'hustle': ['charleston', 'highland fling', 'lambeth walk', 'mexican hat dance', 'portland fancy', 'virginia reel', 'watusi', 'accelerate', 'action', 'activity', 'adventuresomeness', 'adventurousness'],
    'hustler': ['b-girl', 'cyprian', 'jehu', 'paphian', 'activist', 'ball of fire', 'beaver', 'big-time operator', 'bustler', 'busy bee', 'call girl', 'daughter of joy'],
    'hut': ['nissen hut', 'quonset hut', 'bestow', 'billet', 'board', 'booth', 'box', 'camp', 'chalet', 'cot', 'cottage', 'crib'],
    'hutch': ['nissen hut', 'quonset hut', 'archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase'],
    'huzzah': ['alleluia', 'applaud', 'applause', 'cheer', 'chorus of cheers', 'cry', 'cry for joy', 'give a cheer', 'hallelujah', 'hooray', 'hosanna', 'hurrah'],
    'hyades': ['atlantides', 'beehive', 'cepheid variable', 'hertzsprung-russell diagram', 'messier catalog', 'ngc', 'napaea', 'pleiades', 'seven sisters', 'absolute magnitude', 'binary star', 'black hole'],
    'hyaline': ['caelus', 'air', 'azure', 'blue sky', 'caelum', 'canopy', 'canopy of heaven', 'cerulean', 'clear as glass', 'cope', 'empyrean', 'ether'],
    'hybrid': ['cape colored', 'eurasian', 'bastard', 'blend', 'cattalo', 'citrange', 'combination', 'composite', 'compound', 'contamination', 'cross', 'crossbred'],
    'hydrant': ['foamite', 'acid', 'automatic sprinkler', 'carbon tet', 'carbon tetrachloride', 'carbon-dioxide foam', 'cock', 'deck gun', 'deluge set', 'extinguisher', 'fire apparatus', 'fire engine'],
    'hydrate': ['acetify', 'acidify', 'acidulate', 'alkalify', 'alkalize', 'borate', 'carbonate', 'catalyze', 'chemical', 'chlorinate', 'electrolyze', 'ferment'],
    'hydraulics': ['beverage', 'blood', 'drink', 'fluid', 'fluid extract', 'fluid mechanics', 'fluidics', 'hydrodynamics', 'hydrogeology', 'hydrography', 'hydrology', 'hydromechanics'],
    'hydrodynamics': ['aerodynamics', 'barodynamics', 'biodynamics', 'dynamics', 'fluid dynamics', 'fluidics', 'geodynamics', 'hydraulics', 'hydrography', 'hydrology', 'hydromechanics', 'hydrometry'],
    'hydroelectric': ['battery-powered', 'dynamoelectric', 'electric', 'electric-powered', 'electrified', 'electrifying', 'electrochemical', 'electrodynamic', 'electrokinetic', 'electromechanical', 'electrometric', 'electromotive'],
    'hydrogen bomb': ['a-bomb', 'h-bomb', 'atomic bomb', 'atomic warhead', 'clean bomb', 'cobalt bomb', 'dirty bomb', 'fusion bomb', 'hell bomb', 'limited nuclear weapons', 'nuclear artillery', 'nuclear explosive'],
    'hydrogenate': ['acetify', 'acidify', 'acidulate', 'aerate', 'aerify', 'alkalify', 'alkalize', 'atomize', 'borate', 'carbonate', 'catalyze', 'chemical'],
    'hydromechanics': ['aeromechanics', 'animal mechanics', 'biomechanics', 'celestial mechanics', 'electromechanics', 'fluid mechanics', 'fluidics', 'hydraulics', 'hydrodynamics', 'hydrography', 'hydrology', 'hydrometry'],
    'hydrophobia': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'texas fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amathophobia', 'amebiasis', 'amebic dysentery'],
    'hydroplane': ['aeroboat', 'aeroplane', 'airlift', 'airplane', 'amphibian', 'balloon', 'be airborne', 'boat seaplane', 'clipper', 'cruise', 'drift', 'ferry'],
    'hydroponics': ['agrarianism', 'agricultural geology', 'agriculture', 'agrology', 'agronomics', 'agronomy', 'algology', 'aquiculture', 'botany', 'bryology', 'contour farming', 'cultivation'],
    'hydrosphere': ['agua', 'aqua', 'big drink', 'blue water', 'drink', 'drinking water', 'eau', 'ground water', 'hard water', 'head', 'heavy water', 'high sea'],
    'hydrostatics': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics'],
    'hyena': ['african hunting dog', 'cape hunting dog', 'animal', 'anthropophagite', 'barbarian', 'beast', 'brush wolf', 'brute', 'cannibal', 'coyote', 'cur', 'destroyer'],
    'hygiene': ['antisepsis', 'decontamination', 'disinfection', 'disinfestation', 'epidemiology', 'flash pasteurization', 'fumigation', 'health physics', 'hygenics', 'hygienics', 'mental hygiene', 'pasteurization'],
    'hygienic': ['antiseptic', 'aseptic', 'beneficial', 'benign', 'boiled', 'bracing', 'clean', 'constitutional', 'decontaminated', 'disinfected', 'good', 'good for'],
    'hygrometer': ['aerological instrument', 'aneroid barometer', 'aneroidograph', 'barograph', 'barometer', 'barometrograph', 'glass', 'hair hygrometer', 'humidor', 'hurricane-hunter aircraft', 'hygrodeik', 'hygrograph'],
    'hymen': ['gretna green wedding', 'allantoic membrane', 'amnion', 'amniotic sac', 'arachnoid membrane', 'banns', 'basement membrane', 'bridal', 'bridal suite', 'bridechamber', 'chuppah', 'church wedding'],
    'hymn': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'negro spiritual', 'nunc dimittis', 'te deum', 'trisagion'],
    'hymnal': ['alto', 'arrangement', 'baritone', 'bass', 'bravura', 'choral', 'choric', 'coloratura', 'copy', 'draft', 'dramatic', 'edition'],
    'hymnist': ['arranger', 'ballad maker', 'balladeer', 'balladist', 'balladmonger', 'composer', 'contrapuntist', 'ethnomusicologist', 'harmonist', 'harmonizer', 'hymnographer', 'hymnologist'],
    'hype': ['lsd user', 'acidhead', 'acknowledgment', 'addict', 'advocate', 'alcoholic', 'appreciation', 'back', 'blurb', 'boost', 'buildup', 'chain smoker'],
    'hyperbola': ['arc', 'bow', 'catacaustic', 'catenary', 'caustic', 'circle', 'conchoid', 'crook', 'curl', 'curve', 'diacaustic', 'ellipse'],
    'hyperbole': ['abandon', 'abstractionism', 'aggrandizement', 'amplification', 'ballyhoo', 'big talk', 'blowing up', 'boundlessness', 'burlesque', 'caricature', 'coloring', 'deformation'],
    'hyperborean': ['siberian', 'algid', 'antarctic', 'antipodean', 'arctic', 'austral', 'back of beyond', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak'],
    'hypercritical': ['captious', 'carping', 'caviling', 'censorious', 'critic', 'critical', 'cynical', 'faultfinding', 'hairsplitting', 'hypersensitive', 'morbidly sensitive', 'nagging'],
    'hyperion': ['adonis', 'agdistis', 'amen-ra', 'amor', 'aphrodite', 'apollo', 'apollo belvedere', 'apollon', 'ares', 'artemis', 'astarte', 'ate'],
    'hypersensitive': ['allergic', 'anaphylactic', 'delicate', 'empathetic', 'empathic', 'goosy', 'hairsplitting', 'high-strung', 'hypercritical', 'hyperesthetic', 'hyperpathic', 'irritable'],
    'hypersensitivity': ['allergy', 'anaphylaxis', 'considerateness', 'delicacy', 'empathy', 'exquisiteness', 'fineness', 'hairsplitting', 'hypercriticism', 'hyperesthesia', 'hyperpathia', 'hypersensitiveness'],
    'hypertension': ['abscess', 'ague', 'anemia', 'angina', 'angina pectoris', 'ankylosis', 'anoxia', 'aortic insufficiency', 'aortic stenosis', 'apnea', 'apoplectic stroke', 'apoplexy'],
    'hypertensive': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'cancerous', 'chlorotic', 'colicky', 'consumptive', 'dropsical', 'dyspeptic', 'edematous'],
    'hypertrophy': ['abandon', 'blossom', 'boundlessness', 'brew', 'burgeon', 'develop', 'egregiousness', 'enormousness', 'exaggeration', 'excess', 'excessiveness', 'exorbitance'],
    'hyphenate': ['analyze', 'bracket', 'citizen', 'citizen by adoption', 'conjugate', 'cosmopolitan', 'cosmopolite', 'decline', 'hyphenated american', 'immigrant', 'inflect', 'mark'],
    'hypnosis': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'animal hypnosis', 'assertiveness training', 'autohypnosis', 'autosuggestion', 'behavior modification', 'behavior therapy'],
    'hypnotic': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'hypnotism': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'animal magnetism', 'assertiveness training', 'autosuggestion', 'behavior modification', 'behavior therapy', 'bioenergetics'],
    'hypnotize': ['absorb', 'absorb the attention', 'anesthetize', 'arrest', 'becharm', 'beguile', 'bewitch', 'captivate', 'carry away', 'cast a spell', 'catch', 'charm'],
    'hypnotized': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'arrested', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'becharmed'],
    'hypochondria': ['abstraction', 'abulia', 'accident neurosis', 'alienation', 'anxiety', 'anxiety equivalent', 'anxiety hysteria', 'anxiety neurosis', 'anxiety state', 'apathy', 'association neurosis', 'battle fatigue'],
    'hypochondriac': ['alcoholic', 'alternating personality', 'antisocial personality', 'bowed-down', 'cast down', 'dashed', 'dejected', 'depressed', 'despairing', 'despondent', 'desponding', 'discouraged'],
    'hypocrisy': ['pecksniffery', 'pharisaism', 'tartuffery', 'tartuffism', 'affectation', 'affectedness', 'airs', 'airs and graces', 'artfulness', 'artificiality', 'cant', 'casuistry'],
    'hypocrite': ['holy willie', 'joseph surface', 'mawworm', 'pecksniff', 'pharisee', 'tartuffe', 'actor', 'affecter', 'ape', 'attitudinizer', 'bluffer', 'canter'],
    'hypocritical': ['pecksniffian', 'tartuffian', 'tartuffish', 'affected', 'alleged', 'ambidextrous', 'assumed', 'avowed', 'bland', 'canting', 'casuistic', 'claimed'],
    'hypodermic': ['antitoxin', 'bang', 'booster', 'booster shot', 'cortical', 'cutaneous', 'dermal', 'dermic', 'ecderonic', 'ectodermal', 'ectodermic', 'endermatic'],
    'hypostasis': ['abstract noun', 'adherent noun', 'air', 'atom', 'atomic particles', 'axiom', 'brute matter', 'building block', 'center', 'chemical element', 'collective noun', 'common noun'],
    'hypotension': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'bleeding'],
    'hypothesis': ['a priori principle', 'affirmation', 'apriorism', 'assertion', 'assumed position', 'assumption', 'axiom', 'basis', 'categorical proposition', 'conjecture', 'data', 'first principles'],
    'hypothesize': ['analyze', 'apply reason', 'deduce', 'entertain a theory', 'espouse a theory', 'generalize', 'have a theory', 'infer', 'intellectualize', 'logicalize', 'logicize', 'philosophize'],
    'hypothetical': ['a fortiori', 'a posteriori', 'a priori', 'abstract', 'academic', 'analytic', 'armchair', 'assumed', 'categorical', 'conditional', 'conjectural', 'conjectured'],
    'hysterectomy': ['adenoidectomy', 'appendectomy', 'arteriectomy', 'castration', 'cholecystectomy', 'craniectomy', 'cricoidectomy', 'cystectomy', 'enterectomy', 'gastrectomy', 'hemorrhoidectomy', 'mammectomy'],
    'hysteresis': ['dead time', 'diamagnetism', 'electromagnetism', 'ferromagnetism', 'gain', 'gilbert', 'holdup', 'hysteresis curve', 'lag', 'magnetic circuit', 'magnetic conductivity', 'magnetic creeping'],
    'hysteria': ['abandon', 'abstraction', 'abulia', 'accident neurosis', 'alienation', 'anxiety', 'anxiety equivalent', 'anxiety hysteria', 'anxiety neurosis', 'anxiety state', 'apathy', 'association neurosis'],
    'hysterical': ['abandoned', 'amok', 'at fever pitch', 'bellowing', 'berserk', 'carried away', 'comical', 'crazed', 'delirious', 'demoniac', 'disordered', 'distracted'],
    'hysteron proteron': ['anastrophe', 'argument', 'argument by analogy', 'argumentum ad baculum', 'argumentum ad captandum', 'argumentum ad hominem', 'arsy-varsiness', 'bad case', 'begging the question', 'chiasmus', 'circular argument', 'claptrap'],
    'iambic': ['alexandrine', 'accent', 'accentuation', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antispast', 'antispastic', 'arsis', 'bacchius', 'beat'],
    'ice': ['dry ice', 'french ice cream', 'freon', 'italian ice', 'air-condition', 'air-cool', 'alabaster', 'ammonia', 'berg', 'bijouterie', 'billiard table', 'blast'],
    'ice cold': ['siberian', 'algid', 'arctic', 'below zero', 'biting', 'bitter', 'bitterly cold', 'blast-frozen', 'bleak', 'boreal', 'brisk', 'brumal'],
    'ice pack': ['dry ice', 'air cooler', 'berg', 'calf', 'chiller', 'cold pack', 'cooler', 'cryosphere', 'fan', 'firn', 'floe', 'frazil'],
    'ice skate': ['coast', 'flit', 'flow', 'fly', 'glide', 'glissade', 'roller-skate', 'sail', 'sideslip', 'skate', 'skateboard', 'ski'],
    'iceberg': ['dry ice', 'berg', 'calf', 'cryosphere', 'firn', 'floe', 'frazil', 'frozen water', 'glaciation', 'glacier', 'glacieret', 'glaze'],
    'ichor': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'antibody', 'antigen', 'arterial blood', 'blood', 'blood bank', 'blood cell', 'blood count'],
    'ichthyologist': ['animal physiologist', 'anthropologist', 'biologist', 'conchologist', 'ecologist', 'entomologist', 'ethologist', 'helminthologist', 'herpetologist', 'malacologist', 'mammalogist', 'ophiologist'],
    'ichthyology': ['anatomy', 'animal physiology', 'anthropology', 'biology', 'comparative anatomy', 'conchology', 'ecology', 'entomology', 'ethology', 'helminthology', 'herpetology', 'malacology'],
    'icicle': ['dry ice', 'berg', 'calf', 'cryosphere', 'firn', 'floe', 'frazil', 'frozen water', 'glaciation', 'glacier', 'glacieret', 'glaze'],
    'icing': ['jell-o', 'blancmange', 'bonus', 'candy', 'coating', 'comfit', 'compote', 'confection', 'confectionery', 'confiture', 'conserve', 'dividend'],
    'icky': ['bad', 'barfy', 'brackish', 'bum', 'cheesy', 'cloying', 'crappy', 'creepy', 'crummy', 'dirty', 'disgusting', 'fecal'],
    'icon': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'abstract', 'abstraction', 'altarpiece', 'ark', 'asperger', 'asperges'],
    'iconoclast': ['annihilator', 'antichristian', 'arsonist', 'biblioclast', 'bomber', 'breaker', 'burner', 'demolisher', 'destroyer', 'dynamitard', 'dynamiter', 'earthling'],
    'iconography': ['alphabet', 'art', 'blueprint', 'charactering', 'characterization', 'chart', 'choreography', 'conventional representation', 'dance notation', 'delineation', 'demonstration', 'depiction'],
    'iconology': ['allegory', 'charactery', 'cipher', 'conventional symbol', 'emblem', 'ideogram', 'logogram', 'logotype', 'love knot', 'pictogram', 'symbol', 'symbolic system'],
    'icterus': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'bleeding'],
    'ictus': ['alexandrine', 'jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'accent', 'accentuation', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'akinetic epilepsy', 'amphibrach'],
    'icy': ['olympian', 'siberian', 'affectless', 'algid', 'aloof', 'anesthetized', 'arctic', 'autistic', 'backward', 'bashful', 'below zero', 'biting'],
    'id': ['anima', 'archetypal pattern', 'archetype', 'blind impulse', 'coconscious', 'collective unconscious', 'conscience', 'conscious self', 'death instinct', 'ego', 'ego ideal', 'ego-id conflict'],
    'id card': ['badge', 'calligram', 'calling card', 'card', 'countermark', 'countersign', 'credentials', 'dog tag', 'identification', 'identification badge', 'identification tag', 'initials'],
    'idea': ['abstract thought', 'act of thought', 'admonition', 'advice', 'advising', 'advocacy', 'affective meaning', 'aim', 'ambition', 'animus', 'apprehension', 'approach'],
    'ideal': ['arcadian', 'edenic', 'geistesgeschichte', 'hegelian idea', 'kantian idea', 'platonic form', 'platonic idea', 'utopian', 'absolute', 'abstract', 'academic', 'acme'],
    'idealism': ['berkeleianism', 'geistesgeschichte', 'hegelian idea', 'hegelianism', 'kantian idea', 'kantianism', 'neoplatonism', 'platonic form', 'platonic idea', 'platonism', 'absolute idealism', 'animatism'],
    'idealist': ['berkeleian', 'don quixote', 'hegelian', 'kantian', 'neoplatonic', 'neoplatonist', 'neoplatonistic', 'platonic', 'platonist', 'platonistic', 'quixote', 'animist'],
    'idealistic': ['berkeleian', 'cyrenaic', 'eleatic', 'epicurean', 'hegelian', 'kantian', 'megarian', 'neoplatonic', 'neoplatonistic', 'platonic', 'platonistic', 'stoic'],
    'idealization': ['prospero', 'airiness', 'appearance', 'autism', 'autistic thinking', 'delusiveness', 'dematerialization', 'dereism', 'dereistic thinking', 'disembodiment', 'dreamery', 'etherealization'],
    'idealize': ['apotheosize', 'deify', 'dematerialize', 'disembody', 'disincarnate', 'elevate', 'ennoble', 'etherealize', 'exaggerate', 'exalt', 'glorify', 'immaterialize'],
    'ideally': ['absolutely', 'at best', 'completely', 'entirely', 'faultlessly', 'flawlessly', 'fully', 'hypothetically', 'immaculately', 'impeccably', 'in idea', 'in the abstract'],
    'ideation': ['iq', 'abstract thought', 'act of thought', 'apprehension', 'brainwork', 'caliber', 'capacity', 'cerebration', 'clairvoyance', 'cogitation', 'command', 'comprehension'],
    'ideational': ['bright', 'conceptive', 'conceptual', 'creative', 'discursive', 'esemplastic', 'fanciful', 'fecund', 'fertile', 'germinal', 'ideal', 'ideative'],
    'identical': ['alike', 'all one', 'all the same', 'aped', 'biform', 'bifurcated', 'bilateral', 'bipartisan', 'bipartite', 'coequal', 'comparable', 'consimilar'],
    'identically': ['ad eundem', 'alike', 'as', 'as is', 'as well', 'ceteris paribus', 'coequally', 'coextensively', 'coincidentally', 'congruently', 'correspondently', 'correspondingly'],
    'identification': ['id card', 'affiliation', 'allergy', 'anaphylaxis', 'appellation', 'apperception', 'appraisal', 'assessment', 'assimilation', 'association', 'association by contiguity', 'association of ideas'],
    'identify': ['ally', 'apply', 'appraise', 'argue', 'assess', 'associate', 'baptize', 'be indicative of', 'be significant of', 'be symptomatic of', 'bespeak', 'betoken'],
    'identify with': ['accord', 'agree', 'agree in opinion', 'agree with', 'be affected', 'be in tune', 'be inspired', 'be involved', 'be moved', 'care about', 'catch the flame', 'catch the infection'],
    'identity': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'alikeness', 'alliance', 'amity', 'analogy', 'aping', 'approach', 'approximation'],
    'ideogram': ['allegory', 'alphabet', 'arrowhead', 'art', 'blueprint', 'character', 'charactering', 'characterization', 'charactery', 'chart', 'choreography', 'cipher'],
    'ideographic': ['abecedarian', 'allographic', 'alphabetic', 'apish', 'capital', 'connotative', 'delineatory', 'demonstrative', 'denominative', 'denotative', 'depictive', 'designative'],
    'ideology': ['weltanschauung', 'articles of religion', 'body of ideas', 'catechism', 'climate', 'climate of opinion', 'credenda', 'credo', 'creed', 'cult', 'doctrinal statement', 'doctrine'],
    'ides of march': ['friday', 'friday the thirteenth', 'appointed lot', 'astral influences', 'astrology', 'book of fate', 'constellation', 'cup', 'destination', 'destiny', 'dies funestis', 'doom'],
    'idiocy': ['amentia', 'arrested development', 'asininity', 'backwardness', 'battiness', 'blithering idiocy', 'brainlessness', 'buffoonery', 'clownishness', 'crackpottedness', 'crankiness', 'craziness'],
    'idiom': ['acadian', 'anglo-indian', 'brooklynese', 'cajun', 'canadian french', 'cockney', 'french canadian', 'gullah', 'midland', 'midland dialect', 'new england dialect', 'pennsylvania dutch'],
    'idiosyncrasy': ['aberration', 'abnormality', 'animus', 'anomaly', 'aptitude', 'aroma', 'attribute', 'badge', 'banner', 'bent', 'bias', 'brand'],
    'idiosyncratic': ['abnormal', 'anomalous', 'appropriate', 'characteristic', 'characterizing', 'connotative', 'contrastive', 'crank', 'crankish', 'cranky', 'crotchety', 'demonstrative'],
    'idiot': ['alcoholic', 'aliene', 'alternating personality', 'ament', 'antisocial personality', 'ass', 'bedlamite', 'borderline case', 'born fool', 'clot', 'congenital idiot', 'crackbrain'],
    'idiotic': ['apish', 'arrested', 'asinine', 'babbling', 'backward', 'batty', 'befooled', 'beguiled', 'besotted', 'blithering', 'brainless', 'buffoonish'],
    'idle': ['abortive', 'absurd', 'airy', 'amble', 'ambling', 'asinine', 'asleep', 'at a standstill', 'at anchor', 'at leisure', 'at liberty', 'at loose ends'],
    'idle rich': ['beggar', 'bummer', 'cadger', 'coupon clippers', 'drone', 'freeloader', 'leisure class', 'lounge lizard', 'lumpen proletariat', 'mendicant', 'moocher', 'nonworker'],
    'idle talk': ['babble', 'babblement', 'back-fence gossip', 'bavardage', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather', 'blether', 'blethers', 'cackle'],
    'idleness': ['a wise passiveness', 'big deal', 'cautiousness', 'circumspection', 'contemplation', 'contemplative life', 'creeping', 'dawdling', 'deliberateness', 'deliberation', 'do-nothing policy', 'do-nothingism'],
    'idler': ['arab', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'bungler', 'clock watcher', 'dallier', 'dawdle', 'dawdler'],
    'idol': ['baal', 'juggernaut', 'big name', 'celebrity', 'companion', 'constellation', 'copy', 'cosset', 'cynosure', 'darling', 'dea', 'dead ringer'],
    'idol worship': ['druidism', 'parsiism', 'sabaism', 'zoroastrianism', 'animal worship', 'demonism', 'demonolatry', 'devil worship', 'fetishism', 'fire worship', 'heathenism', 'hero worship'],
    'idolater': ['druid', 'parsi', 'sabaist', 'zoroastrian', 'admirer', 'adorer', 'allotheist', 'amateur', 'animal worshiper', 'animist', 'anthropolater', 'arborolater'],
    'idolatry': ['amor', 'christian love', 'eros', 'platonic love', 'accolade', 'admiration', 'adoration', 'adulation', 'affection', 'agape', 'allotheism', 'animatism'],
    'idolization': ['amor', 'christian love', 'eros', 'platonic love', 'admiration', 'adoration', 'affection', 'agape', 'anthropolatry', 'apotheosis', 'appreciation', 'approbation'],
    'idolize': ['accord respect to', 'admire', 'adore', 'adulate', 'apotheosize', 'appreciate', 'belaud', 'bepraise', 'bless', 'blow up', 'boast of', 'brag about'],
    'idyll': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'idyllic': ['alcaic', 'anacreontic', 'arcadian', 'castalian', 'edenic', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'at peace', 'bardic'],
    'iffy': ['accidental', 'adventitious', 'aleatory', 'arguable', 'at issue', 'capricious', 'casual', 'causeless', 'chance', 'chancy', 'confutable', 'conjectural'],
    'igloo': ['apse', 'arcade', 'arcature', 'arch', 'arched roof', 'archway', 'avalanche', 'blizzard', 'camber', 'ceilinged roof', 'concameration', 'concha'],
    'ignis fatuus': ['airy nothing', 'autism', 'autoluminescence', 'backfire', 'balefire', 'beacon', 'beacon fire', 'bioluminescence', 'blaze', 'bonfire', 'bubble', 'burning ghat'],
    'ignite': ['bank', 'blaze up', 'burn', 'conflagrate', 'enkindle', 'fan the flame', 'feed', 'feed the fire', 'fire', 'fire up', 'flame up', 'flare up'],
    'ignited': ['ablaze', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'blazing', 'burning', 'candent', 'candescent', 'comburent'],
    'ignition': ['altitude peak', 'automatic control', 'backfire', 'balefire', 'beacon', 'beacon fire', 'blast-off', 'blaze', 'bonfire', 'burn', 'burning ghat', 'burnout'],
    'ignobility': ['abominability', 'baseness', 'beastliness', 'commonness', 'commonplaceness', 'contemptibility', 'contrariety', 'crudeness', 'degradation', 'demotion', 'depluming', 'despicability'],
    'ignoble': ['abhorrent', 'abject', 'abominable', 'base', 'base-minded', 'baseborn', 'beastly', 'beggarly', 'below contempt', 'beneath contempt', 'coarse', 'common'],
    'ignominious': ['aberrant', 'abnormal', 'abominable', 'atrocious', 'criminal', 'delinquent', 'derogatory', 'deviant', 'discreditable', 'disgraceful', 'dishonorable', 'disreputable'],
    'ignominy': ['abomination', 'atrocity', 'chagrin', 'contempt', 'degradation', 'demotion', 'depluming', 'desecration', 'despite', 'discredit', 'disdain', 'disesteem'],
    'ignoramus': ['abecedarian', 'alphabetarian', 'apprentice', 'articled clerk', 'ass', 'beginner', 'boot', 'born fool', 'buffoon', 'catechumen', 'clown', 'dabbler'],
    'ignorance': ['urdummheit', 'amateurishness', 'amateurism', 'benightedness', 'brainlessness', 'callowness', 'disaccustomedness', 'empty-headedness', 'foolishness', 'greenness', 'illiteracy', 'immaturity'],
    'ignorant': ['a novice at', 'a stranger to', 'awkward', 'benighted', 'blankminded', 'boorish', 'brainless', 'callow', 'crude', 'disaccustomed', 'discourteous', 'dumb'],
    'ignore': ['abide with', 'abjure', 'accept', 'allow for', 'avoid', 'ban', 'bar', 'bar out', 'be big', 'be blind to', 'be caught napping', 'be caught out'],
    'ignored': ['abandoned', 'contemned', 'declined', 'declined with thanks', 'denied', 'deserted', 'despised', 'disapproved', 'discarded', 'discounted', 'disdained', 'dismissed'],
    'ileac': ['abdominal', 'anal', 'appendical', 'cardiac', 'cecal', 'colic', 'colonic', 'coronary', 'duodenal', 'enteric', 'gastric', 'intestinal'],
    'ilk': ['blood', 'body-build', 'brand', 'breed', 'cast', 'character', 'characteristic', 'characteristics', 'clan', 'color', 'complexion', 'composition'],
    'ill': ['abomination', 'affection', 'ailing', 'ailment', 'amiss', 'apocalyptic', 'atrocity', 'bad', 'badly', 'baleful', 'bane', 'baneful'],
    'ill-advised': ['a bit previous', 'advanced', 'automatic', 'bad', 'botched', 'brash', 'bungled', 'butchered', 'casual', 'far ahead', 'forward', 'fumbled'],
    'ill-at-ease': ['abashed', 'afflicted', 'agitated', 'beset', 'bothered', 'cast down', 'chagrined', 'chapfallen', 'confused', 'discomfited', 'discomforted', 'discomposed'],
    'ill-bred': ['gothic', 'neanderthal', 'animal', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'boorish', 'brutal', 'brutish', 'caddish', 'coarse'],
    'ill-considered': ['a bit previous', 'advanced', 'automatic', 'bad', 'botched', 'bungled', 'butchered', 'casual', 'far ahead', 'forward', 'fumbled', 'futile'],
    'ill-equipped': ['bare-handed', 'beggarly', 'disqualified', 'empty-handed', 'famished', 'half-starved', 'ill off', 'ill-fitted', 'ill-furnished', 'ill-provided', 'impoverished', 'incapable'],
    'ill-fated': ['apocalyptic', 'bad', 'baleful', 'baneful', 'black', 'bodeful', 'boding', 'dark', 'dire', 'doomful', 'dreary', 'evil'],
    'ill-favored': ['evil-eyed', 'evil-faced', 'evil-fashioned', 'evil-favored', 'evil-gotten', 'evil-looking', 'evil-minded', 'grim', 'grim-faced', 'grim-visaged', 'hard-favored', 'hard-featured'],
    'ill-gotten': ['amoral', 'conscienceless', 'corrupt', 'corrupted', 'criminal', 'crooked', 'dark', 'devious', 'dishonest', 'dishonorable', 'doubtful', 'dubious'],
    'ill-health': ['cachexia', 'cachexy', 'chronic ill health', 'debilitation', 'debility', 'decrepitude', 'delicacy', 'delicate health', 'enervation', 'exhaustion', 'feebleness', 'fragility'],
    'ill-humor': ['faustianism', 'argumentativeness', 'cold comfort', 'combativeness', 'contentiousness', 'disappointment', 'discontent', 'discontentedness', 'discontentment', 'disgruntlement', 'disputatiousness', 'dissatisfaction'],
    'ill-humored': ['argumental', 'argumentative', 'bad-tempered', 'combative', 'contentious', 'controversial', 'dialectic', 'disputatious', 'eristic', 'evil-tempered', 'ill-affected', 'ill-disposed'],
    'ill-nature': ['anger', 'asperity', 'bad blood', 'bad humor', 'bad temper', 'bad will', 'bile', 'biliousness', 'blighting glance', 'causticity', 'choler', 'corrosiveness'],
    'ill-natured': ['bad-tempered', 'bitter', 'crabbed', 'cranky', 'cross', 'crusty', 'dour', 'evil-disposed', 'evil-tempered', 'gloomy', 'ill-affected', 'ill-conditioned'],
    'ill-off': ['badly off', 'bare-handed', 'beggarly', 'depressed', 'dire', 'distressed', 'donsie', 'doomful', 'down to bedrock', 'embarrassed', 'empty-handed', 'evil-starred'],
    'ill-repute': ['bad character', 'bad name', 'bad odor', 'bad report', 'bad reputation', 'bad repute', 'disapprobation', 'discredit', 'disesteem', 'disfavor', 'dishonor', 'evil repute'],
    'ill-starred': ['baleful', 'bodeful', 'fateful', 'foreboding', 'hapless', 'ill-fated', 'luckless', 'malefic', 'malign', 'ominous', 'portentous', 'sinister'],
    'ill-suited': ['bad', 'futile', 'ill-adapted', 'ill-advised', 'ill-assorted', 'ill-chosen', 'ill-considered', 'ill-fitted', 'ill-matched', 'ill-sorted', 'ill-timed', 'impolitic'],
    'ill-tempered': ['bad-tempered', 'crabbed', 'dyspeptic', 'fractious', 'hot-tempered', 'huffy', 'ill-humored', 'ill-natured', 'irritable', 'peevish', 'petulant', 'querulous'],
    'ill-timed': ['bad', 'futile', 'ill-adapted', 'ill-advised', 'ill-assorted', 'ill-chosen', 'ill-considered', 'ill-fitted', 'ill-matched', 'ill-seasoned', 'ill-sorted', 'ill-suited'],
    'ill-use': ['abuse', 'active use', 'appliance', 'application', 'atrocity', 'batter', 'bleed', 'bleed white', 'bruise', 'buffet', 'consumption', 'do violence to'],
    'ill-will': ['acrimony', 'animosity', 'animus', 'bad blood', 'bad temper', 'bad will', 'bitter feeling', 'bitterness', 'blighting glance', 'despite', 'evil disposition', 'evil eye'],
    'ill-wind': ['jonah', 'bad fortune', 'bad influence', 'bad luck', 'black squall', 'blizzard', 'blow', 'curse', 'enchantment', 'equinoctial', 'evil dispensation', 'evil eye'],
    'illegal': ['aberrant', 'abnormal', 'abominable', 'actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'atrocious', 'banned', 'barred', 'black-market'],
    'illegality': ['aberrance', 'aberrancy', 'abnormality', 'crime', 'criminality', 'delict', 'delinquency', 'deviance', 'deviancy', 'felony', 'improperness', 'impropriety'],
    'illegitimate': ['actionable', 'affected', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'apocryphal', 'artificial', 'assumed', 'bantling', 'bar sinister', 'baseborn'],
    'illiberal': ['authoritarian', 'avaricious', 'biased', 'bigot', 'bigoted', 'borne', 'chauvinist', 'cheap', 'close', 'closed', 'closefisted', 'constricted'],
    'illicit': ['actionable', 'adulterous', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'back-door', 'banned', 'barred', 'black-market', 'bootleg', 'chargeable'],
    'illicit business': ['anarchy', 'anomie', 'ballot-box stuffing', 'bunco', 'cardsharping', 'cheat', 'cheating', 'cozenage', 'criminalism', 'criminality', 'diddle', 'diddling'],
    'illiterate': ['gothic', 'philistine', 'barbarous', 'benighted', 'bookless', 'dabbler', 'deceived', 'dilettante', 'dunce', 'empty-headed', 'fool', 'functionally illiterate'],
    'illness': ['abnormality', 'acute disease', 'addiction', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight'],
    'illogical': ['aberrant', 'abroad', 'absonant', 'adrift', 'all abroad', 'all off', 'all wrong', 'amiss', 'askew', 'astray', 'at fault', 'awry'],
    'illuminant': ['aglow', 'beaming', 'beamy', 'benzine', 'blushing', 'bright and sunny', 'burning', 'candescent', 'candle', 'coal oil', 'electric light bulb', 'electricity'],
    'illuminate': ['account for', 'adorn', 'affect', 'allegorize', 'apply paint', 'beacon', 'bead', 'bedaub', 'bedizen', 'begild', 'bejewel', 'beribbon'],
    'illuminated': ['ablaze', 'afflicted', 'aglow', 'alight', 'bathed with light', 'bent', 'bespangled', 'boiled', 'bombed', 'boozy', 'brightened', 'candlelit'],
    'illuminating': ['allegorizing', 'annotative', 'autodidactic', 'brightening', 'clarifying', 'coeducational', 'critical', 'cultural', 'demonstrative', 'demythologizing', 'didactic', 'disciplinary'],
    'illumination': ['abstract', 'abstraction', 'accomplishments', 'acquisition of knowledge', 'acquisitions', 'acrylic painting', 'adjunct', 'adornment', 'allegorization', 'altarpiece', 'arc lighting', 'arrangement'],
    'illusion': ['aberrancy', 'aberration', 'air', 'airy nothing', 'apparition', 'appearance', 'bamboozlement', 'bedevilment', 'befooling', 'bewitchery', 'bewitchment', 'bluffing'],
    'illusionist': ['merlin', 'prospero', 'airiness', 'appearance', 'conjurer', 'delusiveness', 'escamoteur', 'fallaciousness', 'false appearance', 'false light', 'false show', 'falseness'],
    'illusive': ['barmecidal', 'barmecide', 'circean', 'airy', 'apparent', 'apparently sound', 'apparitional', 'autistic', 'beguiling', 'bewitching', 'casuistic', 'catchy'],
    'illusory': ['barmecidal', 'barmecide', 'circean', 'aberrant', 'abroad', 'adrift', 'air-built', 'airy', 'all abroad', 'all off', 'all wrong', 'amiss'],
    'illustrate': ['account for', 'adorn', 'adumbrate', 'allegorize', 'approve', 'argue', 'attest', 'bespeak', 'betoken', 'body forth', 'breathe', 'call to mind'],
    'illustration': ['abstract', 'abstraction', 'acrylic painting', 'allegorization', 'alphabet', 'altarpiece', 'art', 'block print', 'blueprint', 'case', 'case history', 'case in point'],
    'illustrative': ['allegorizing', 'annotative', 'apish', 'clarifying', 'critical', 'delineatory', 'demonstrative', 'demythologizing', 'depictive', 'echoic', 'editorial', 'elucidative'],
    'illustrious': ['acclaimed', 'bright', 'brilliant', 'celebrated', 'charismatic', 'conspicuous', 'distinguished', 'eminent', 'esteemed', 'famed', 'famous', 'glamorous'],
    'image': ['doppelganger', 'vorstellung', 'abstract', 'abstraction', 'adumbrate', 'affectation', 'affectedness', 'airs', 'airs and graces', 'allusion', 'ally', 'altarpiece'],
    'imagery': ['vorstellung', 'allusion', 'alphabet', 'apparition', 'art', 'asiaticism', 'blueprint', 'brainchild', 'bubble', 'cameo', 'catalog', 'cataloging'],
    'imaginable': ['assumable', 'cogitable', 'conceivable', 'conceivably possible', 'conjecturable', 'contingent', 'fanciable', 'humanly possible', 'likely', 'plausible', 'possible', 'potential'],
    'imaginary': ['barmecidal', 'barmecide', 'abstract', 'air-built', 'airy', 'algorismic', 'algorithmic', 'aliquot', 'apparent', 'apparitional', 'autistic', 'cardinal'],
    'imaginary invalid': ['alcoholic', 'alternating personality', 'antisocial personality', 'disordered personality', 'disturbed personality', 'double personality', 'drug user', 'dual personality', 'escapist', 'hostile personality', 'hypochondriac', 'hypochondriast'],
    'imagination': ['apparition', 'brainchild', 'bubble', 'chimera', 'creativity', 'delirium', 'eidolon', 'fancy', 'fantasque', 'fantasy', 'fiction', 'figment'],
    'imaginative': ['authentic', 'avant-garde', 'clever', 'conceptive', 'conceptual', 'contrived', 'creative', 'enterprising', 'esemplastic', 'expressive', 'fanciful', 'fantastic'],
    'imagine': ['account as', 'assume', 'be afraid', 'believe', 'coin', 'conceit', 'conceive', 'conceptualize', 'conclude', 'concoct', 'conjecture', 'consider'],
    'imbalance': ['anamorphism', 'anamorphosis', 'asymmetry', 'buckle', 'contortion', 'contrariety', 'crookedness', 'detorsion', 'deviation', 'difference', 'disequilibrium', 'disparity'],
    'imbecile': ['ament', 'amputee', 'anemic', 'apish', 'arrested', 'asinine', 'ass', 'asthenic', 'babbling', 'backward', 'batty', 'befooled'],
    'imbecility': ['amentia', 'arrested development', 'asininity', 'backwardness', 'battiness', 'blithering idiocy', 'brainlessness', 'buffoonery', 'clownishness', 'crackpottedness', 'crankiness', 'craziness'],
    'imbed': ['bed', 'bed in', 'comprise', 'confirm', 'contain', 'deep-dye', 'define', 'embed', 'enclose', 'enfold', 'engraft', 'engrave'],
    'imbibe': ['absorb', 'adsorb', 'assimilate', 'bib', 'blot', 'blot up', 'booze', 'chemisorb', 'chemosorb', 'devour', 'digest', 'drain the cup'],
    'imbroglio': ['altercation', 'argument', 'bicker', 'bickering', 'bind', 'blood feud', 'brawl', 'broil', 'clutch', 'complication', 'contention', 'controversy'],
    'imbrue': ['bathe', 'besprinkle', 'breathe', 'brew', 'color', 'decoct', 'douche', 'dredge', 'drench', 'drouk', 'dye', 'entincture'],
    'imbue': ['animate', 'apply paint', 'bathe', 'beat into', 'bedaub', 'bedizen', 'begild', 'besmear', 'bespread', 'besprinkle', 'brainwash', 'breathe'],
    'imbued': ['affected', 'agonized', 'colored', 'deep', 'deep-colored', 'devoured by', 'dyed', 'full', 'full-colored', 'hued', 'imbued with', 'impressed'],
    'imitate': ['act like', 'adopt', 'affect', 'ape', 'appear like', 'approach', 'appropriate', 'approximate', 'assume', 'be like', 'be redolent of', 'bear resemblance'],
    'imitated': ['alike', 'aped', 'consimilar', 'copied', 'counterfeit', 'ersatz', 'fake', 'favoring', 'following', 'homogeneous', 'identical', 'imitation'],
    'imitation': ['accordance', 'acting', 'adoption', 'affected', 'agent', 'agreement', 'alike', 'alikeness', 'alliance', 'alternate', 'alternative', 'analogy'],
    'imitative': ['apish', 'battological', 'delineatory', 'depictive', 'duplicative', 'echoic', 'echoing', 'embodying', 'emulative', 'figurative', 'graphic', 'ideographic'],
    'imitator': ['ape', 'conformist', 'copier', 'copycat', 'copyist', 'counterfeiter', 'cuckoo', 'dissembler', 'dissimulator', 'echo', 'echoer', 'echoist'],
    'immaculate': ['christian', 'absolute', 'beyond all praise', 'blameless', 'bleached', 'blotless', 'bright', 'chaste', 'clean', 'cleanly', 'creditable', 'dainty'],
    'immaculate conception': ['dei mater', 'deipara', 'holy mary', 'mariolatry', 'mariology', 'mother of god', 'notre dame', 'our lady', 'queen of angels', 'queen of heaven', 'regina angelorum', 'regina coeli'],
    'immaculately': ['absolutely', 'blamelessly', 'clean', 'cleanly', 'completely', 'conscientiously', 'decently', 'entirely', 'erectly', 'fastidiously', 'faultlessly', 'flawlessly'],
    'immanence': ['accessibility', 'actual presence', 'availability', 'being here', 'being there', 'essentiality', 'existence', 'fundamentality', 'hereness', 'immediacy', 'inbeing', 'indigenousness'],
    'immanent': ['accessible', 'actual', 'as is', 'at hand', 'attendant', 'available', 'being', 'contemporaneous', 'contemporary', 'current', 'deep-seated', 'esoteric'],
    'immaterial': ['adrift', 'aerial', 'airy', 'apparitional', 'asomatous', 'astral', 'back-burner', 'beside the mark', 'beside the point', 'beside the question', 'bodiless', 'celestial'],
    'immateriality': ['masan', 'prospero', 'airiness', 'airy nothing', 'apparition', 'appearance', 'astral', 'astral spirit', 'banshee', 'bodilessness', 'concealment', 'control'],
    'immature': ['a novice at', 'a stranger to', 'adolescent', 'adulterated', 'amateur', 'amateurish', 'arrested', 'at half cock', 'babish', 'babyish', 'blemished', 'budding'],
    'immaturity': ['adulteration', 'amateurishness', 'amateurism', 'arrestment', 'babyishness', 'brand-newness', 'callowness', 'childishness', 'coarseness', 'crudeness', 'crudity', 'defectibility'],
    'immeasurable': ['gargantuan', 'all-comprehensive', 'all-inclusive', 'amplitudinous', 'astronomical', 'awesome', 'boundless', 'bulky', 'colossal', 'cosmic', 'countless', 'endless'],
    'immeasurably': ['a outrance', 'absolutely', 'abundantly', 'acervatim', 'ad infinitum', 'all out', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure', 'boundlessly', 'completely'],
    'immediacy': ['accessibility', 'actual presence', 'alacrity', 'approach', 'approximation', 'availability', 'being here', 'being there', 'case of need', 'closeness', 'confines', 'contiguity'],
    'immediate': ['about to be', 'abrupt', 'accessible', 'actual', 'adjacent', 'adjoining', 'alert', 'already in sight', 'approaching', 'apt', 'articulated', 'as is'],
    'immediately': ['pdq', 'amain', 'anon', 'apace', 'at once', 'away', 'by forced marches', 'closely', 'contiguously', 'cursorily', 'decisively', 'directly'],
    'immemorial': ['acknowledged', 'admitted', 'age-old', 'ageless', 'ancient', 'antique', 'auld', 'ceaseless', 'coeternal', 'constant', 'continual', 'continuous'],
    'immense': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'all-comprehensive', 'all-inclusive', 'amplitudinous', 'astronomic', 'astronomical'],
    'immensely': ['ad infinitum', 'boundlessly', 'colossally', 'divinely', 'endlessly', 'enormously', 'eternally', 'ever', 'excessively', 'exquisitely', 'extremely', 'forever'],
    'immensity': ['all-comprehensiveness', 'all-inclusiveness', 'ampleness', 'amplitude', 'boundlessness', 'bulk', 'countlessness', 'endlessness', 'enormity', 'enormousness', 'eternity', 'exhaustlessness'],
    'immerge': ['baptize', 'bury', 'deluge', 'dip', 'douse', 'drown', 'duck', 'dunk', 'engulf', 'immerse', 'inundate', 'merge'],
    'immerse': ['absorb', 'absorb the attention', 'arrest', 'asperge', 'asperse', 'baptize', 'bury', 'busy', 'catch', 'charm', 'christen', 'deluge'],
    'immersed': ['absorbed', 'absorbed in', 'awash', 'bathed', 'buried', 'buried in', 'caught up in', 'contemplating', 'contemplative', 'deep', 'deluged', 'devoted'],
    'immersion': ['absorbed attention', 'absorption', 'affusion', 'application', 'aspergation', 'aspersion', 'baptism', 'baptismal gown', 'baptismal regeneration', 'baptistery', 'baptizement', 'bath'],
    'immigrant': ['dp', 'alien', 'arrival', 'arriviste', 'citizen', 'citizen by adoption', 'colonial', 'colonist', 'colonizer', 'comer', 'cosmopolitan', 'cosmopolite'],
    'imminence': ['access', 'accession', 'advance', 'advent', 'afflux', 'affluxion', 'aftertime', 'afteryears', 'anticipation', 'approach', 'approaching', 'appropinquation'],
    'imminent': ['about to be', 'abusive', 'advancing', 'alarming', 'already in sight', 'anticipated', 'approaching', 'approximate', 'approximative', 'at hand', 'attracted to', 'awaited'],
    'immobile': ['abiding', 'adamant', 'adamantine', 'at a standstill', 'at anchor', 'changeless', 'constant', 'contemplative', 'continuing', 'dead-still', 'do-nothing', 'dormant'],
    'immobility': ['a wise passiveness', 'abidingness', 'changelessness', 'constancy', 'contemplation', 'contemplative life', 'do-nothing policy', 'do-nothingism', 'do-nothingness', 'dormancy', 'durability', 'durableness'],
    'immobilize': ['balance', 'ballast', 'counterbalance', 'cripple', 'disable', 'disarm', 'firm', 'firm up', 'freeze', 'hold', 'incapacitate', 'keep'],
    'immoderate': ['a bit much', 'abandoned', 'acute', 'bibulous', 'boundless', 'crapulent', 'crapulous', 'cutthroat', 'cutting', 'dizzy', 'drastic', 'egregious'],
    'immodest': ['aggressively self-confident', 'arrogant', 'bawdy', 'biggety', 'bold', 'brash', 'brazen', 'brazenfaced', 'bumptious', 'cheeky', 'chesty', 'coarse'],
    'immodesty': ['aggressive self-confidence', 'boldness', 'brazenness', 'bumptiousness', 'chestiness', 'cockiness', 'conceit', 'conceitedness', 'exhibitionism', 'flagrancy', 'forwardness', 'impudicity'],
    'immolate': ['annihilate', 'appease', 'bereave of life', 'carry away', 'carry off', 'chloroform', 'cut down', 'cut off', 'deprive of life', 'destroy', 'dispatch', 'dispose of'],
    'immolation': ['bane', 'blood', 'bloodletting', 'bloodshed', 'braining', 'burnt offering', 'collection', 'dealing death', 'destruction', 'destruction of life', 'dispatch', 'drink offering'],
    'immoral': ['abandoned', 'amoral', 'bad', 'base', 'carnal', 'concupiscent', 'conscienceless', 'corrupt', 'corrupted', 'criminal', 'crooked', 'dark'],
    'immorality': ['amorality', 'backsliding', 'carnality', 'corruption', 'criminality', 'delinquency', 'depravity', 'evil', 'evil nature', 'impurity', 'moral delinquency', 'peccability'],
    'immortal': ['olympian', 'aggrandized', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'amaranthine', 'apotheosized', 'awesome', 'beatified', 'beyond compare'],
    'immortality': ['afterlife', 'animal spirits', 'animate existence', 'animation', 'athanasia', 'athanasy', 'being alive', 'birth', 'deathlessness', 'eternal life', 'eternal youth', 'everlastingness'],
    'immortalize': ['aggrandize', 'apotheose', 'apotheosize', 'beatify', 'canonize', 'celebrate', 'commemorate', 'crown', 'deify', 'elevate', 'embalm', 'ennoble'],
    'immortalized': ['aggrandized', 'apotheosized', 'awesome', 'beatified', 'big', 'canonized', 'deified', 'elevated', 'eminent', 'ennobled', 'enshrined', 'enthroned'],
    'immovable': ['adamant', 'adamantine', 'affectless', 'anchored', 'anesthetized', 'arctic', 'at a standstill', 'autistic', 'blunt', 'cast-iron', 'catatonic', 'chill'],
    'immune': ['chartered', 'excepted', 'excused', 'exempt', 'exempted', 'favored', 'immunized', 'inoculated', 'insured', 'insusceptible', 'intact', 'invulnerable'],
    'immunity': ['absolution', 'acquired immunity', 'active immunity', 'amnesty', 'antibody', 'antigen', 'artificial immunity', 'assurance', 'blank check', 'carte blanche', 'charter', 'clear sailing'],
    'immunization': ['acquired immunity', 'active immunity', 'antibody', 'antigen', 'artificial immunity', 'congenital immunity', 'familial immunity', 'immunity', 'immunity theory', 'immunization therapy', 'immunochemistry', 'immunology'],
    'immure': ['bastille', 'bolt in', 'bottle up', 'box in', 'box up', 'cabin', 'cage', 'casket', 'cast in prison', 'check', 'clap in jail', 'clap up'],
    'immured': ['barred', 'behind bars', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'cabined', 'caged', 'cloistered', 'closed-in', 'confined'],
    'immutable': ['abiding', 'accordant', 'adamant', 'adamantine', 'age-long', 'aged', 'alike', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty'],
    'imp': ['ariel', 'befind', 'corrigan', 'dingbelle', 'fifinella', 'finnbeara', 'hob', 'hobgoblin', 'jd', 'mab', 'oberon', 'puck'],
    'impact': ['affect', 'affective meaning', 'altitude peak', 'appulse', 'automatic control', 'backlash', 'backwash', 'bearing', 'bed', 'blast-off', 'blow', 'bounce'],
    'impair': ['abate', 'abrade', 'abstract', 'abuse', 'afflict', 'aggravate', 'aggrieve', 'bate', 'befoul', 'bewitch', 'blemish', 'blight'],
    'impaired': ['adulterated', 'aggravated', 'blemished', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped', 'cracked', 'crazed', 'cut'],
    'impairment': ['adulteration', 'attrition', 'curtailment', 'cut', 'cutting', 'damage', 'debilitation', 'decrease', 'decrement', 'defectibility', 'defectiveness', 'deficiency'],
    'impale': ['agonize', 'auger', 'bayonet', 'bite', 'bloody', 'bore', 'broach', 'claw', 'convulse', 'countersink', 'crucify', 'dagger'],
    'impalpable': ['airy', 'asomatous', 'astral', 'atomic', 'bodiless', 'branny', 'chalklike', 'chalky', 'comminute', 'comminuted', 'corpuscular', 'crushed'],
    'impanel': ['book', 'calendar', 'carve', 'catalog', 'chalk', 'chalk up', 'check in', 'chronicle', 'cut', 'docket', 'engrave', 'enroll'],
    'impanelment': ['booking', 'cataloging', 'chronicling', 'enlistment', 'enrollment', 'entering', 'entry', 'indexing', 'inscribing', 'inscription', 'insertion', 'inventorying'],
    'impart': ['accord', 'administer', 'afford', 'allot', 'allow', 'articulate', 'assign', 'award', 'bare', 'bestow', 'bestow on', 'break'],
    'impartable': ['allowable', 'assignable', 'bequeathable', 'bestowable', 'communicable', 'conductive', 'consignable', 'contagious', 'conveyable', 'devisable', 'expressable', 'giveable'],
    'impartial': ['laodicean', 'olympian', 'apathetic', 'candid', 'centrist', 'detached', 'disinterested', 'dispassionate', 'equal', 'equitable', 'even', 'evenhanded'],
    'impartiality': ['olympian detachment', 'abnegation', 'abstention', 'abstinence', 'anythingarianism', 'calm', 'calmness', 'conservatism', 'constraint', 'continence', 'control', 'cool'],
    'impasse': ['bar', 'barrier', 'blank wall', 'blind alley', 'blind gut', 'block', 'blockade', 'blockage', 'bottleneck', 'box', 'cecum', 'choking'],
    'impassion': ['agitate', 'annoy', 'arouse', 'awake', 'awaken', 'blow the coals', 'blow up', 'call forth', 'call up', 'enkindle', 'enrage', 'excite'],
    'impassioned': ['abandoned', 'ablaze', 'afire', 'agog', 'amative', 'amatory', 'amorous', 'animated', 'aquiver', 'ardent', 'aroused', 'atingle'],
    'impassive': ['olympian', 'affectless', 'aloof', 'anesthetized', 'apathetic', 'arctic', 'at rest', 'autistic', 'backward', 'bashful', 'blank', 'blunt'],
    'impatience': ['alacrity', 'animation', 'anxiety', 'anxiousness', 'appetite', 'avidity', 'avidness', 'breathless impatience', 'cheerful readiness', 'eagerness', 'elan', 'forwardness'],
    'impatient': ['abrupt', 'agitated', 'agog', 'alacritous', 'all agog', 'animated', 'antsy', 'antsy-pantsy', 'anxious', 'athirst', 'avid', 'breathless'],
    'impatiently': ['animatedly', 'anxiously', 'avidly', 'breathlessly', 'eagerly', 'enthusiastically', 'fretfully', 'intolerantly', 'keenly', 'promptly', 'quickly', 'readily'],
    'impeach': ['accuse', 'allege', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'article', 'asperse', 'attack', 'belittle', 'blame', 'book'],
    'impeachable': ['accusable', 'arraignable', 'at fault', 'blamable', 'blameworthy', 'censurable', 'chargeable', 'criminal', 'culpable', 'faulty', 'guilty', 'implicated'],
    'impeached': ['accused', 'arraigned', 'blamed', 'charged', 'cited', 'denounced', 'implicated', 'impugned', 'in complicity', 'incriminated', 'inculpated', 'indicted'],
    'impeccable': ['absolute', 'accurate', 'beyond all praise', 'blameless', 'chaste', 'clean', 'correct', 'defectless', 'destitute', 'errorless', 'exact', 'exquisite'],
    'impecunious': ['badly off', 'destitute', 'distressed', 'down to bedrock', 'embarrassed', 'feeling the pinch', 'hard up', 'ill off', 'in queer street', 'in narrow circumstances', 'in reduced circumstances', 'in straitened circumstances'],
    'impedance': ['capacitive reactance', 'clog', 'cumbrance', 'electric resistance', 'hindrance', 'impediment', 'inductive reactance', 'magnetic reluctance', 'ohm', 'ohmage', 'reactance', 'reluctance'],
    'impede': ['arrest', 'backpedal', 'backwater', 'bar', 'block', 'bottle up', 'brake', 'burden', 'check', 'clip the wings', 'confine', 'confound'],
    'impediment': ['arrest', 'arrestation', 'arrestment', 'bar', 'barrier', 'blank wall', 'blind alley', 'blind gut', 'block', 'blockade', 'blockage', 'blocking'],
    'impedimenta': ['accouterments', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'bag and baggage', 'baggage', 'burden', 'burthen', 'cargo', 'charge'],
    'impel': ['actuate', 'advance', 'animate', 'beset', 'bind', 'bowl', 'bunt', 'butt', 'cause', 'cause to', 'compel', 'constrain'],
    'impelling': ['active', 'actuating', 'animating', 'causal', 'causative', 'compelling', 'compulsive', 'directive', 'driving', 'gripping', 'holding', 'impellent'],
    'impend': ['approach', 'await', 'be as expected', 'be imminent', 'be in store', 'beetle', 'brew', 'come on', 'confront', 'draw near', 'draw nigh', 'draw on'],
    'impending': ['about to be', 'already in sight', 'approaching', 'at hand', 'beetle', 'beetle-browed', 'beetling', 'brewing', 'close', 'close at hand', 'coming', 'forthcoming'],
    'impenetrable': ['greek to one', 'ambiguous', 'arcane', 'beyond reach', 'beyond understanding', 'cabalistic', 'close', 'close-knit', 'close-textured', 'close-woven', 'closed forever to', 'closed to'],
    'imperative': ['absolute', 'absolutist', 'absolutistic', 'acid', 'acute', 'allegiance', 'arbitrary', 'aristocratic', 'arrogant', 'ascendant', 'assigned task', 'authoritarian'],
    'imperceptible': ['atomic', 'behind the curtain', 'behind the scenes', 'camouflaged', 'concealed', 'corpuscular', 'disguised', 'embryonic', 'ephemeral', 'evanescent', 'faint', 'fugitive'],
    'imperfect': ['adulterated', 'aggravated', 'amiss', 'aorist', 'base', 'blemished', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped'],
    'imperfection': ['absence', 'arrear', 'arrearage', 'arrears', 'bad habit', 'baseness', 'beggary', 'besetting sin', 'blemish', 'bug', 'catch', 'crack'],
    'imperfectly': ['a bit', 'a little', 'barely', 'by a hair', 'by an ace', 'defectively', 'deficiently', 'ever so little', 'exiguously', 'faintly', 'faultily', 'feebly'],
    'imperial': ['vandyke', 'absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'august', 'authoritarian', 'authoritative', 'autocratic', 'beard'],
    'imperialism': ['eisenhower doctrine', 'monroe doctrine', 'nazism', 'nixon doctrine', 'truman doctrine', 'appeasement', 'balance of power', 'brinkmanship', 'caliphate', 'centralism', 'coexistence', 'collectivism'],
    'imperialist': ['bircher', 'bourbon', 'tory', 'conservatist', 'conservative', 'diehard', 'extreme right-winger', 'hard hat', 'monarchist', 'radical right', 'reactionarist', 'reactionary'],
    'imperilment': ['breakers ahead', 'cardhouse', 'cause for alarm', 'crisis', 'danger', 'dangerous ground', 'emergency', 'endangerment', 'gaping chasm', 'gathering clouds', 'hazard', 'house of cards'],
    'imperious': ['absolute', 'absolutist', 'absolutistic', 'acute', 'arbitrary', 'aristocratic', 'arrogant', 'authoritarian', 'authoritative', 'autocratic', 'binding', 'bossy'],
    'imperishable': ['amaranthine', 'deathless', 'embalmed', 'ever-fresh', 'everlasting', 'fadeless', 'frozen', 'immortal', 'impregnable', 'incorruptible', 'indelible', 'indestructible'],
    'impermanence': ['adaptability', 'adjustability', 'alterability', 'caducity', 'changeability', 'changeableness', 'changefulness', 'corruptibility', 'death', 'ephemerality', 'ephemeralness', 'evanescence'],
    'impermanent': ['able to adapt', 'adaptable', 'adjustable', 'alterable', 'alterative', 'brittle', 'capricious', 'changeable', 'checkered', 'corruptible', 'deciduous', 'dying'],
    'impermeable': ['close', 'close-knit', 'close-textured', 'close-woven', 'closed', 'compact', 'compacted', 'compressed', 'concentrated', 'concrete', 'condensed', 'congested'],
    'impersonal': ['olympian', 'abstract', 'aloof', 'backward', 'bashful', 'blank', 'candid', 'chilled', 'chilly', 'cold', 'cold-blooded', 'colorless'],
    'impersonate': ['act', 'act a part', 'act as', 'act out', 'adumbrate', 'ape', 'body forth', 'copy', 'copycat', 'create a role', 'demonstrate', 'depict'],
    'impersonation': ['acting', 'aping', 'buffoonery', 'business', 'characterization', 'copying', 'counterfeiting', 'dumb show', 'embodiment', 'emulation', 'enacting', 'enactment'],
    'impersonator': ['ape', 'artist', 'artiste', 'belly dancer', 'blagueur', 'bluff', 'bluffer', 'burlesque queen', 'charlatan', 'chorine', 'chorus boy', 'chorus girl'],
    'impertinence': ['arrogance', 'audacity', 'bold front', 'boldness', 'brash bearing', 'brashness', 'brass', 'brassiness', 'bravado', 'brazenfacedness', 'brazenness', 'bumptiousness'],
    'impertinent': ['adrift', 'arrogant', 'audacious', 'beside the mark', 'beside the point', 'beside the question', 'biggety', 'bluff', 'bold', 'brash', 'brassy', 'brazen'],
    'imperturbable': ['balanced', 'bovine', 'collected', 'complacent', 'composed', 'cool', 'dispassionate', 'dull', 'even-tempered', 'fast', 'fiducial', 'firm'],
    'impervious': ['philistine', 'airtight', 'ballproof', 'beyond reach', 'bombproof', 'bulletproof', 'burglarproof', 'callous', 'calloused', 'case-hardened', 'closed forever to', 'closed to'],
    'impetigo': ['acne', 'acne vulgaris', 'dermamycosis', 'dermatitis', 'dermatosis', 'eczema', 'elephantiasis', 'epithelioma', 'erysipelas', 'erythema', 'exanthem', 'heat rash'],
    'impetration': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'address', 'aid prayer', 'appeal', 'application', 'asking', 'beadroll'],
    'impetuous': ['abrupt', 'accident-prone', 'active', 'acute', 'adrift', 'afloat', 'aggressive', 'alternating', 'amorphous', 'animated', 'antsy', 'antsy-pantsy'],
    'impetuously': ['a corps perdu', 'abruptly', 'bang', 'carelessly', 'dash', 'desperately', 'furiously', 'happen what may', 'hastily', 'head over heels', 'headfirst', 'headforemost'],
    'impetus': ['acceleration', 'activity', 'animation', 'ardor', 'brio', 'briskness', 'catalyst', 'clout', 'compulsion', 'drive', 'driving force', 'elan'],
    'impiety': ['blasphemousness', 'blasphemy', 'desecration', 'godlessness', 'irreligion', 'profanation', 'profaneness', 'profanity', 'sacrilege', 'sacrilegiousness', 'sinfulness', 'un-christliness'],
    'impinge': ['bang', 'bang into', 'barge in', 'break in', 'break in upon', 'brush', 'brush by', 'bump', 'bump into', 'burst in', 'butt in', 'cannon'],
    'impingement': ['appulse', 'attouchement', 'brunt', 'brush', 'bulldozing', 'bulling', 'bump', 'cannon', 'carambole', 'caress', 'carom', 'clash'],
    'impious': ['apostate', 'arch', 'atheistic', 'backsliding', 'blasphemous', 'casual', 'coltish', 'contrary', 'devil-may-care', 'disobedient', 'elvish', 'fallen'],
    'impish': ['arch', 'devilish', 'elfish', 'elvish', 'foolish', 'full of mischief', 'high-spirited', 'knavish', 'mischief-loving', 'mischievous', 'playful', 'prankish'],
    'implacable': ['adamant', 'adamantine', 'avenging', 'cast-iron', 'cruel', 'dour', 'firm', 'flinty', 'grim', 'grudgeful', 'hard', 'hard-core'],
    'implant': ['beat into', 'bed', 'brainwash', 'broadcast', 'bud', 'catechize', 'condition', 'confirm', 'deep-dye', 'define', 'dibble', 'disseminate'],
    'implantation': ['absorption and regurgitation', 'brainwashing', 'catechization', 'conditioning', 'confirmation', 'deep-rootedness', 'deep-seatedness', 'dictation', 'embedment', 'entrance', 'entrenchment', 'establishment'],
    'implanted': ['chronic', 'confirmed', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid', 'deep-rooted', 'deep-seated', 'deep-set', 'deep-settled', 'dyed-in-the-wool'],
    'implausibility': ['bare possibility', 'credibility gap', 'doubtfulness', 'dubiousness', 'faint likelihood', 'improbability', 'inconceivability', 'incredibility', 'little expectation', 'poor possibility', 'poor prospect', 'questionableness'],
    'implausible': ['a bit thick', 'a bit thin', 'absurd', 'beyond belief', 'debatable', 'doubtable', 'doubtful', 'dubious', 'dubitable', 'fishy', 'flimsy', 'hard of belief'],
    'implement': ['charlie mccarthy', 'federal', 'abide by', 'accomplish', 'achieve', 'actualize', 'adhere to', 'administer', 'agent', 'amanuensis', 'ancilla', 'apparatus'],
    'implementation': ['accomplished fact', 'accomplishment', 'achievement', 'administration', 'attainment', 'carrying out', 'commission', 'completion', 'conduct', 'consummation', 'discharge', 'dispatch'],
    'implicate': ['absorb', 'affect', 'allegorize', 'allude to', 'assail', 'associate', 'assume', 'attack', 'ball up', 'bring', 'bring to mind', 'call for'],
    'implicated': ['byzantine', 'a party to', 'accessory', 'accused', 'affected', 'affiliate', 'affiliated', 'allied', 'arraignable', 'arraigned', 'associate', 'associated'],
    'implication': ['absorption', 'accusal', 'accusation', 'accusing', 'affective meaning', 'allegation', 'allegement', 'allegory', 'allusion', 'arcane meaning', 'arraignability', 'arraignableness'],
    'implicative': ['allusive', 'allusory', 'connotative', 'demonstrative', 'denominative', 'denotative', 'designative', 'diagnostic', 'emblematic', 'evidential', 'exhibitive', 'expressive'],
    'implicit': ['absolute', 'adducible', 'admissible', 'admitting no exception', 'all-out', 'attestative', 'attestive', 'authentic', 'based on', 'categorical', 'certain', 'circumstantial'],
    'implore': ['adjure', 'appeal', 'appeal to', 'beg', 'beseech', 'call for help', 'call on', 'call upon', 'clamor for', 'commune with god', 'conjure', 'crave'],
    'imploring': ['adjuration', 'adjuratory', 'adorant', 'adoring', 'appeal', 'appealing', 'begging', 'beseeching', 'beseechment', 'bid', 'call', 'clamor'],
    'imply': ['accuse', 'adumbrate', 'advert to', 'affect', 'allege', 'allegorize', 'allude to', 'approve', 'argue', 'arraign', 'article', 'assume'],
    'impolite': ['gothic', 'neanderthal', 'animal', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'boorish', 'brutal', 'brutish', 'churlish', 'coarse'],
    'impoliteness': ['bad manners', 'caddishness', 'coarseness', 'crudeness', 'discourteousness', 'discourtesy', 'gross behavior', 'grossness', 'ill breeding', 'ill manners', 'incivility', 'inconsiderateness'],
    'impolitic': ['bad', 'botched', 'brash', 'bungled', 'butchered', 'fumbled', 'futile', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-done'],
    'imponderable': ['airy', 'asomatous', 'astral', 'atomic', 'bodiless', 'corpuscular', 'decarnate', 'decarnated', 'discarnate', 'disembodied', 'embryonic', 'ethereal'],
    'import': ['accent', 'acceptation', 'access', 'add up to', 'admission', 'affective meaning', 'allegorize', 'allegory', 'allude to', 'allusion', 'amount to something', 'arcane meaning'],
    'importance': ['account', 'ascendancy', 'authority', 'charisma', 'charm', 'clout', 'concern', 'consequence', 'conspicuousness', 'control', 'credit', 'distinction'],
    'important': ['absolute', 'arrogant', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'big', 'big-league', 'big-name', 'big-time', 'bigwig'],
    'important person': ['establishment', 'vip', 'baron', 'big gun', 'big man', 'big name', 'bigwig', 'brass', 'brass hat', 'celebrity', 'chief', 'constellation'],
    'importunate': ['aggravating', 'annoying', 'bothering', 'bothersome', 'cajoling', 'choiceless', 'clamant', 'clamorous', 'coaxing', 'compulsory', 'controlled', 'crying'],
    'importune': ['advocate', 'aggravating', 'annoying', 'appeal', 'apply pressure', 'approach', 'beg', 'beseech', 'beset', 'besiege', 'blandish', 'bothering'],
    'importunity': ['blandishment', 'buttonholing', 'cajolement', 'cajolery', 'coaxing', 'demandingness', 'dunning', 'exigency', 'importunacy', 'importunateness', 'insistence', 'nagging'],
    'impose': ['abuse', 'administer the eucharist', 'anoint', 'appoint', 'ask', 'ask for', 'assess', 'authorize', 'barge in', 'blackmail', 'break in', 'break in upon'],
    'impose upon': ['abuse', 'abuse a privilege', 'barge in', 'bleed', 'bleed white', 'bother', 'break in', 'break in upon', 'burden with', 'burst in', 'butt in', 'charge'],
    'imposed': ['absolute', 'binding', 'compulsory', 'conclusive', 'decisive', 'decretory', 'dictated', 'entailed', 'final', 'hard-and-fast', 'imperative', 'irrevocable'],
    'imposing': ['babylonian', 'corinthian', 'adipose', 'aristocratic', 'arty', 'august', 'awe-inspiring', 'awful', 'barbaric', 'baronial', 'beefy', 'big'],
    'imposition': ['intertype', 'linotype', 'monotype', 'application', 'applying', 'assessment', 'assumption', 'atrocity', 'ballot-box stuffing', 'blackmail', 'bunco', 'burden'],
    'impossible': ['i refuse', 'i will not', 'absurd', 'algorismic', 'algorithmic', 'aliquot', 'antic', 'barred', 'by no means', 'cardinal', 'closed-out', 'contrary to reason'],
    'impost': ['assessment', 'blackmail', 'call', 'call for', 'cess', 'claim', 'conscience money', 'contribution', 'demand', 'demand for', 'direct tax', 'draft'],
    'impostor': ['ape', 'beguiler', 'blagueur', 'bluff', 'bluffer', 'charlatan', 'cheat', 'clinquant', 'con man', 'confidence man', 'conformist', 'copier'],
    'imposture': ['acting', 'affectation', 'appearance', 'artifice', 'attitudinizing', 'ballot-box stuffing', 'bluff', 'bluffing', 'bunco', 'cardsharping', 'charlatanism', 'charlatanry'],
    'impotence': ['absurdity', 'adynamia', 'aimlessness', 'anemia', 'aridity', 'atony', 'barrenness', 'birth control', 'blah feeling', 'bloodlessness', 'bootlessness', 'cachexia'],
    'impotent': ['acarpous', 'aimless', 'anemic', 'arid', 'asexual', 'asthenic', 'barren', 'blank cartridge', 'bloodless', 'careless', 'castrated', 'castrato'],
    'impound': ['annex', 'attach', 'beleaguer', 'beset', 'besiege', 'blockade', 'bottle up', 'bound', 'box in', 'box up', 'cage', 'chamber'],
    'impoverish': ['ablate', 'absorb', 'assimilate', 'bankrupt', 'beggar', 'bleed', 'bleed white', 'break', 'burn up', 'bust', 'consume', 'denude'],
    'impoverished': ['lenten', 'spartan', 'ablated', 'abstemious', 'ascetic', 'austere', 'badly off', 'bankrupt', 'bare-handed', 'barren', 'beggared', 'beggarly'],
    'impracticable': ['awkward', 'disadvantageous', 'impossible', 'impractical', 'inapplicable', 'inconvenient', 'infeasible', 'nonfunctional', 'troublesome', 'unacceptable', 'unachievable', 'unattainable'],
    'impractical': ['abstract', 'academic', 'airy', 'armchair', 'autistic', 'awkward', 'beyond one', 'bulky', 'clumsy', 'conjectural', 'contrary', 'crosswise'],
    'impracticality': ['autism', 'autistic thinking', 'awkwardness', 'bulkiness', 'clumsiness', 'cumbersomeness', 'dereism', 'dereistic thinking', 'dreamery', 'flight of fancy', 'hulkiness', 'ideal'],
    'imprecation': ['adjuration', 'anathema', 'appeal', 'application', 'ban', 'beseechment', 'bid', 'blasphemy', 'call', 'clamor', 'commination', 'cry'],
    'imprecatory': ['rabelaisian', 'abusive', 'blasphemous', 'calumniatory', 'calumnious', 'comminatory', 'contumelious', 'cursing', 'damnatory', 'denunciatory', 'dirty', 'dysphemistic'],
    'imprecise': ['adulterated', 'aleatoric', 'aleatory', 'ambiguous', 'amorphous', 'approximate', 'approximative', 'barbarous', 'blemished', 'blobby', 'blurred', 'blurry'],
    'impregnable': ['deathless', 'defended', 'guarded', 'immortal', 'impenetrable', 'imperishable', 'incontestable', 'incorruptible', 'indelible', 'indestructible', 'indomitable', 'ineffaceable'],
    'impregnate': ['bathe', 'beat into', 'besprinkle', 'brainwash', 'breathe', 'brew', 'catechize', 'charge', 'color', 'condition', 'cross-fertilize', 'cross-pollen'],
    'impregnation': ['absorption and regurgitation', 'artificial insemination', 'brainwashing', 'brewing', 'catechization', 'conditioning', 'conjugation', 'cross-fertilization', 'cross-pollination', 'decoction', 'dictation', 'drench'],
    'impresario': ['mc', 'administrator', 'agent', 'auteur', 'ballyhoo man', 'barker', 'callboy', 'conductor', 'costume designer', 'costumer', 'costumier', 'deputy'],
    'impress': ['ditto copy', 'photostat', 'xerox', 'xerox copy', 'abduce', 'abduct', 'affect', 'alveolation', 'alveolus', 'annex', 'aquatint', 'aroma'],
    'impressed': ['affected', 'agonized', 'carved', 'confirmed', 'creased', 'cut', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid', 'deep-rooted'],
    'impression': ['ditto copy', 'photostat', 'platonic form', 'platonic idea', 'xerox', 'xerox copy', 'absorption and regurgitation', 'aesthetic form', 'affect', 'affection', 'alveolation', 'alveolus'],
    'impressionability': ['accessibility', 'adaptability', 'affectibility', 'affectivity', 'agreeability', 'amenability', 'amenableness', 'aptitude', 'aptness', 'bendability', 'brightness', 'cleverness'],
    'impressionable': ['accessible', 'adaptable', 'alive to', 'amenable', 'apt', 'aware', 'bendable', 'bending', 'bright', 'clever', 'cognizant', 'compliant'],
    'impressive': ['babylonian', 'corinthian', 'absolute', 'acid', 'affecting', 'agitating', 'alive to', 'arousing', 'arresting', 'assuring', 'august', 'authoritative'],
    'impressively': ['abundantly', 'acutely', 'amazingly', 'amply', 'ardently', 'astonishingly', 'awesomely', 'conspicuously', 'copiously', 'effectively', 'elaborately', 'elegantly'],
    'impressment': ['abduction', 'angary', 'annexation', 'annexure', 'attachment', 'call', 'call-up', 'collectivization', 'commandeering', 'communalization', 'communization', 'compulsory military service'],
    'imprimatur': ['john hancock', 'ok', 'acceptance', 'affirmance', 'affirmation', 'approbation', 'approval', 'authentication', 'authorization', 'building permit', 'certification', 'confirmation'],
    'imprint': ['acknowledgments', 'alveolation', 'alveolus', 'aquatint', 'autolithograph', 'back', 'back matter', 'backlash', 'backwash', 'bastard title', 'bed', 'bibliography'],
    'imprinted': ['carved', 'confirmed', 'creased', 'cut', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid', 'deep-rooted', 'deep-seated', 'deep-set'],
    'imprison': ['bastille', 'beleaguer', 'beset', 'besiege', 'blockade', 'bolt in', 'bound', 'box in', 'cage', 'cast in prison', 'chamber', 'check'],
    'imprisoned': ['barred', 'behind bars', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'cabined', 'caged', 'cloistered', 'closed-in', 'confined'],
    'imprisonment': ['beleaguerment', 'besetment', 'blockade', 'blockading', 'captivity', 'circumscription', 'close arrest', 'confinement', 'cordoning', 'custody', 'detention', 'dismemberment'],
    'improbability': ['abnormality', 'anomaly', 'bare possibility', 'conversation piece', 'curio', 'curiosity', 'dark horse', 'exception', 'fighting chance', 'gambling chance', 'hardly a chance', 'hundred-to-one shot'],
    'improbable': ['absurd', 'crazy', 'distant', 'doubtable', 'doubtful', 'dubious', 'dubitable', 'extraordinary', 'fanciful', 'farfetched', 'fishy', 'flimsy'],
    'improbity': ['machiavellianism', 'ambidexterity', 'artifice', 'bad faith', 'cunning', 'deceitfulness', 'dishonesty', 'double-dealing', 'doubleness', 'doubleness of heart', 'duplicity', 'faithlessness'],
    'impromptu': ['ad lib', 'ad libitum', 'ad-lib', 'ad-libbing', 'arrangement', 'at short notice', 'at sight', 'by ear', 'cadenza', 'caught napping', 'caught off balance', 'caught short'],
    'improper': ['doric', 'aberrant', 'abnormal', 'abominable', 'amiss', 'arrant', 'atrocious', 'bad', 'barbaric', 'barbarous', 'base', 'black'],
    'improperly': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'coarsely', 'confoundedly', 'crassly', 'crudely'],
    'impropriety': ['babbittry', 'gothicism', 'aberrance', 'aberrancy', 'abnormality', 'anomaly', 'atrocity', 'bad taste', 'badness', 'barbarism', 'barbarousness', 'blunder'],
    'improvable': ['ameliorable', 'amendable', 'correctable', 'corrigible', 'curable', 'emendable', 'fixable', 'medicable', 'mendable', 'perfectible', 'reclaimable', 'recoverable'],
    'improve': ['accommodate', 'acculturate', 'adapt', 'adjust', 'advance', 'alter', 'ameliorate', 'amend', 'apprentice', 'be changed', 'be converted into', 'be renewed'],
    'improved': ['advanced', 'altered', 'ameliorated', 'beautified', 'better', 'bettered', 'changeable', 'changed', 'civilized', 'converted', 'cultivated', 'cultured'],
    'improvement': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'advance', 'alteration', 'amelioration', 'amendment', 'apostasy', 'apprenticeship', 'basic training', 'betterment'],
    'improvidence': ['brashness', 'brass', 'brazen boldness', 'cheek', 'chutzpah', 'fecklessness', 'gall', 'hastiness', 'heedlessness', 'heroics', 'hubris', 'imprudence'],
    'improvident': ['brash', 'brazen', 'brazenfaced', 'careless', 'extravagant', 'feckless', 'grasshopper', 'happy-go-lucky', 'headlong', 'heedless', 'hubristic', 'impetuous'],
    'improvisation': ['action', 'ad hoc measure', 'ad lib', 'ad-libbing', 'answer', 'arrangement', 'artifice', 'authorship', 'beginning', 'cadenza', 'coinage', 'conception'],
    'improvisational drama': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger', 'closet drama'],
    'improvise': ['ad lib', 'ad-lib', 'be caught napping', 'be surprised', 'be taken unawares', 'be unprepared', 'beget', 'breed', 'bring forth', 'bring into being', 'call into being', 'coin'],
    'improvised': ['ad hoc', 'ad libitum', 'ad-lib', 'band-aid', 'caught napping', 'caught off balance', 'caught short', 'extemporaneous', 'extemporary', 'extempore', 'extemporized', 'haphazard'],
    'imprudence': ['absurdity', 'act of folly', 'blunder', 'brashness', 'brass', 'brazen boldness', 'callowness', 'casualness', 'cheek', 'childishness', 'chutzpah', 'crudity of intellect'],
    'imprudent': ['blanket', 'brash', 'brazen', 'brazenfaced', 'careless', 'casual', 'crazy', 'foolhardy', 'foolish', 'general', 'hasty', 'heedless'],
    'impudence': ['arrogance', 'audacity', 'back talk', 'backchat', 'bold front', 'boldness', 'brash bearing', 'brashness', 'brass', 'brassiness', 'bravado', 'brazen boldness'],
    'impudent': ['arrant', 'arrogant', 'audacious', 'aweless', 'barefaced', 'biggety', 'blatant', 'bluff', 'bold', 'brash', 'brassy', 'brazen'],
    'impugn': ['abjure', 'accuse', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'assail', 'assert the contrary', 'attack', 'belie', 'blame', 'call in question'],
    'impugned': ['accused', 'arraigned', 'belied', 'blamed', 'charged', 'cited', 'confounded', 'confuted', 'deflated', 'denied', 'denounced', 'discarded'],
    'impulse': ['actuation', 'archetypal pattern', 'archetype', 'atomic power', 'automatic writing', 'automatism', 'blind impulse', 'catalyst', 'collective unconscious', 'compulsion', 'compulsiveness', 'conditioning'],
    'impulsive': ['a bit previous', 'abrupt', 'actuating', 'adrift', 'advanced', 'afloat', 'alternating', 'amorphous', 'animating', 'automatic', 'blind', 'breakneck'],
    'impulsively': ['a corps perdu', 'abruptly', 'at half cock', 'bang', 'capriciously', 'chaotically', 'dash', 'erratically', 'every which way', 'hastily', 'head over heels', 'headfirst'],
    'impulsiveness': ['abruptness', 'alacrity', 'capriciousness', 'desultoriness', 'deviability', 'eccentricity', 'erraticism', 'expeditiousness', 'feverishness', 'fickleness', 'flightiness', 'forwardness'],
    'impure': ['adamic', 'doric', 'fescennine', 'rabelaisian', 'adulterated', 'alloyed', 'backsliding', 'barbaric', 'barbarous', 'bawdy', 'belowstairs', 'besmirched'],
    'impurity': ['gothicism', 'adulteration', 'amorality', 'backsliding', 'bad taste', 'barbarism', 'barbarousness', 'black sheep', 'blemish', 'bombasticness', 'cacology', 'cacophony'],
    'imputable': ['accountable', 'accusable', 'alleged', 'arraignable', 'ascribable', 'assignable', 'attributable', 'attributed', 'blamable', 'blameworthy', 'censurable', 'chargeable'],
    'imputation': ['accounting for', 'accusal', 'accusation', 'accusing', 'adverse criticism', 'allegation', 'allegement', 'animadversion', 'answerability', 'application', 'arraignment', 'arrogation'],
    'impute': ['accredit', 'accuse', 'adduce', 'allege', 'apply', 'arraign', 'article', 'ascribe', 'assign', 'attach', 'attribute', 'book'],
    'in': ['a la mode', 'access', 'adit', 'advanced', 'air lock', 'among', 'an in', 'approach', 'at', 'avant-garde', 'by', 'chic'],
    'in a bind': ['arrested', 'back', 'backward', 'behindhand', 'belated', 'blocked', 'delayed', 'delayed-action', 'detained', 'held up', 'hung up', 'in dutch'],
    'in a rut': ['addicted', 'addicted to', 'dependent', 'dependent on', 'dully', 'equably', 'evenly', 'habituated', 'habitue', 'hooked', 'hooked on', 'monotonously'],
    'in a stew': ['abashed', 'abroad', 'adrift', 'agitated', 'all-overish', 'antsy', 'antsy-pantsy', 'anxious', 'anxioused up', 'apprehensive', 'astray', 'at sea'],
    'in a way': ['a bit', 'a little', 'after a fashion', 'appreciably', 'as it were', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside'],
    'in action': ['acting', 'active', 'at work', 'behavioral', 'functional', 'functioning', 'going', 'going on', 'in exercise', 'in force', 'in hand', 'in operation'],
    'in advance': ['ahead', 'ahead of time', 'ante', 'before', 'beforehand', 'beforetime', 'betimes', 'early', 'first', 'fore', 'foremost', 'foresightedly'],
    'in all conscience': ['actually', 'all joking aside', 'analytically', 'appropriately', 'as is proper', 'as is right', 'assuredly', 'bluffly', 'bluntly', 'broadly', 'brusquely', 'by right'],
    'in all respects': ['absolutely', 'across the board', 'ad infinitum', 'all', 'all over', 'all put together', 'altogether', 'as a body', 'as a whole', 'at all points', 'at full length', 'at large'],
    'in any case': ['after all', 'again', 'albeit', 'all the same', 'although', 'anyhow', 'anyway', 'anywise', 'at all', 'at all events', 'at any rate', 'but'],
    'in cahoots': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'cabalistic', 'confederate', 'confederated', 'conspiratorial', 'corporate', 'coupled', 'enleagued'],
    'in charge': ['ascendant', 'at the head', 'at the helm', 'at the reins', 'boss', 'chief', 'commanding', 'controlling', 'dominant', 'general', 'governing', 'head'],
    'in clover': ['affluent', 'charmed', 'comfortable', 'comfortably situated', 'content', 'contented', 'cozy', 'delighted', 'easy', 'eupeptic', 'euphoric', 'exhilarated'],
    'in cold blood': ['advisedly', 'by design', 'calculatedly', 'cold-bloodedly', 'coldheartedly', 'coldly', 'consciously', 'contemplatedly', 'deadpan', 'deliberately', 'designedly', 'dispassionately'],
    'in condition': ['alive and kicking', 'bright-eyed and bushy-tailed', 'chipper', 'enjoying health', 'eupeptic', 'fine', 'fit', 'fit and fine', 'fixed', 'full of beans', 'healthful', 'healthy'],
    'in detail': ['accurately', 'at large', 'at length', 'bit by bit', 'by degrees', 'by inches', 'by inchmeal', 'by snatches', 'completely', 'concretely', 'conscientiously', 'definitely'],
    'in due course': ['after a while', 'anon', 'auspiciously', 'before long', 'betimes', 'by and by', 'directly', 'ere long', 'eventually', 'in a moment', 'in a while', 'in due season'],
    'in extremis': ['bad', 'between two fires', 'cornered', 'despaired of', 'desperate', 'done for', 'dying', 'endangered', 'expiring', 'facing death', 'given up', 'going'],
    'in fact': ['absolutely', 'actually', 'certainly', 'de facto', 'factually', 'forsooth', 'genuinely', 'historically', 'in actuality', 'in effect', 'in reality', 'in truth'],
    'in favor': ['creditable', 'esteemed', 'estimable', 'held in esteem', 'highly esteemed', 'highly regarded', 'highly reputed', 'highly respectable', 'honorable', 'honored', 'in', 'in good odor'],
    'in favor of': ['advocating', 'all for', 'approving', 'backing', 'favorable', 'favoring', 'for', 'in aid of', 'in behalf of', 'in furtherance of', 'on account of', 'on behalf of'],
    'in force': ['acting', 'active', 'armipotent', 'at work', 'authoritative', 'being', 'cogent', 'current', 'dynamic', 'effective', 'energetic', 'existent'],
    'in full': ['altogether', 'at large', 'at length', 'completely', 'comprehensively', 'entirely', 'exhaustively', 'fully', 'globally', 'hundred per cent', 'in detail', 'in extenso'],
    'in full swing': ['actively', 'afoot', 'all out', 'allegretto', 'allegro', 'animatedly', 'astir', 'balmy', 'blooming', 'blossoming', 'booming', 'breezily'],
    'in full view': ['apparent', 'beholdable', 'detectable', 'discernible', 'disclosed', 'evident', 'exposed', 'exposed to view', 'hanging out', 'in evidence', 'in plain sight', 'in view'],
    'in fun': ['as a joke', 'devilishly', 'elfishly', 'for amusement', 'for fun', 'for kicks', 'for laughs', 'for sport', 'impishly', 'in jest', 'in joke', 'in play'],
    'in general': ['all in all', 'all things considered', 'altogether', 'as a rule', 'as a whole', 'as an approximation', 'at large', 'broadly', 'broadly speaking', 'by and large', 'chiefly', 'commonly'],
    'in hand': ['accepted', 'accidental', 'accompanying', 'acting', 'active', 'ado', 'afloat', 'afoot', 'arranged', 'assumed', 'at work', 'brewing'],
    'in harmony': ['accommodated to', 'accordant', 'according to', 'adapted to', 'adjusted to', 'affirmative', 'after', 'agreeable', 'agreeable to', 'agreeably to', 'agreeing', 'akin'],
    'in keeping': ['accordant', 'agreeably', 'anal', 'bourgeois', 'by consensus', 'compatibly', 'compulsive', 'concordant', 'concordantly', 'conformist', 'congenially', 'consonantly'],
    'in keeping with': ['accommodated to', 'according to', 'adapted to', 'adjusted to', 'after', 'agreeable to', 'agreeably to', 'answerable to', 'by', 'conformable to', 'congruent with', 'consistent with'],
    'in league': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'cabalistic', 'confederate', 'confederated', 'conspiratorial', 'corporate', 'coupled', 'enleagued'],
    'in line': ['accordant', 'agreeably', 'anal', 'bourgeois', 'by consensus', 'compatibly', 'compulsive', 'concordant', 'concordantly', 'conformist', 'congenially', 'consonantly'],
    'in line with': ['accommodated to', 'according to', 'adapted to', 'adjusted to', 'after', 'agreeable to', 'agreeably to', 'answerable to', 'by', 'conformable to', 'congruent with', 'consistent with'],
    'in motion': ['active', 'astir', 'driving', 'impelling', 'mobile', 'motile', 'motivational', 'motive', 'motor', 'moving', 'on the go', 'on the move'],
    'in name only': ['alleged', 'apparently', 'artificially', 'avowed', 'byname', 'claimed', 'cognominal', 'diminutive', 'epithetic', 'erroneously', 'factitiously', 'falsely'],
    'in no time': ['pdq', 'apace', 'at once', 'decisively', 'directly', 'expeditiously', 'forthwith', 'immediately', 'in a bit', 'in a flash', 'in a jiff', 'in a jiffy'],
    'in operation': ['acting', 'active', 'at work', 'functional', 'functioning', 'going', 'going on', 'in commission', 'in effect', 'in exercise', 'in force', 'in hand'],
    'in opposition': ['adverse', 'against the grain', 'against the tide', 'against the wind', 'alienated', 'antagonistic', 'antagonistically', 'antiestablishment', 'at cross-purposes', 'at daggers', 'at daggers drawn', 'at issue'],
    'in opposition to': ['across', 'adverse to', 'against', 'at cross-purposes with', 'athwart', 'con', 'confronting', 'contra', 'contrary to', 'counter to', 'dead against', 'facing'],
    'in order': ['by stages', 'fixed', 'hierarchically', 'in apple-pie order', 'in commission', 'in condition', 'in fine fettle', 'in good condition', 'in good form', 'in good shape', 'in good trim', 'in kilter'],
    'in particular': ['at length', 'completely', 'concretely', 'definitely', 'distinctly', 'especially', 'exactly', 'expressly', 'fully', 'in detail', 'in extenso', 'in full'],
    'in passing': ['a propos', 'along the way', 'amain', 'apace', 'apropos', 'apropos of', 'as one goes', 'at once', 'by forced marches', 'by the by', 'by the way', 'cursorily'],
    'in plain sight': ['aboveboard', 'apparent', 'before one', 'beholdable', 'detectable', 'discernible', 'disclosed', 'evident', 'exposed', 'exposed to view', 'face to face', 'hanging out'],
    'in power': ['armipotent', 'at the head', 'at the helm', 'at the reins', 'authoritative', 'cogent', 'dynamic', 'effective', 'energetic', 'forceful', 'forcible', 'high-potency'],
    'in practice': ['acting', 'active', 'at work', 'functional', 'functioning', 'going', 'going on', 'in commission', 'in effect', 'in exercise', 'in force', 'in hand'],
    'in process': ['accepted', 'acting', 'active', 'assumed', 'at work', 'brewing', 'chanced', 'forthcoming', 'functional', 'functioning', 'going', 'going on'],
    'in production': ['brewing', 'forthcoming', 'going on', 'in embryo', 'in hand', 'in preparation', 'in process', 'in progress', 'in the oven', 'in the works', 'on foot', 'on stream'],
    'in progress': ['accepted', 'assumed', 'brewing', 'chanced', 'forthcoming', 'going on', 'in embryo', 'in hand', 'in mid-progress', 'in preparation', 'in process', 'in production'],
    'in question': ['arguable', 'at issue', 'before the house', 'conditional', 'conditioned', 'confutable', 'conjectural', 'contestable', 'contingent', 'controversial', 'controvertible', 'debatable'],
    'in re': ['about', 'anent', 'apropos of', 'as', 'as for', 'as regards', 'as respects', 'as to', 'concerning', 'in connection with', 'in point of', 'in reference to'],
    'in reality': ['absolutely', 'actually', 'certainly', 'de facto', 'factually', 'forsooth', 'genuinely', 'historically', 'in actuality', 'in effect', 'in fact', 'in truth'],
    'in relation to': ['about', 'anent', 'apropos of', 'as for', 'as regards', 'as respects', 'as to', 'concerning', 'in connection with', 'in point of', 'in re', 'in reference to'],
    'in reserve': ['about to be', 'already in sight', 'approaching', 'aside', 'at hand', 'back', 'brewing', 'by', 'close', 'close at hand', 'coming', 'forthcoming'],
    'in return': ['au pair', 'back', 'by turns', 'en revanche', 'even', 'exchangeably', 'for a consideration', 'in amends', 'in answer', 'in compensation', 'in consideration', 'in exchange'],
    'in session': ['accumulated', 'agglomerate', 'aggregate', 'amassed', 'assembled', 'bunched', 'bundled', 'clumped', 'clustered', 'collected', 'combined', 'conglomerate'],
    'in shape': ['alive and kicking', 'bright-eyed and bushy-tailed', 'chipper', 'enjoying health', 'eupeptic', 'fine', 'fit', 'fit and fine', 'fixed', 'full of beans', 'healthful', 'healthy'],
    'in short supply': ['arrested', 'at a premium', 'callow', 'defective', 'deficient', 'embryonic', 'failing', 'hypoplastic', 'immature', 'in arrear', 'in arrears', 'in default'],
    'in sight': ['apparent', 'beholdable', 'detectable', 'discernible', 'disclosed', 'evident', 'exposed', 'exposed to view', 'hanging out', 'in evidence', 'in full view', 'in plain sight'],
    'in step': ['accordant', 'agreeably', 'anal', 'bourgeois', 'by consensus', 'compatibly', 'compulsive', 'concordant', 'concordantly', 'conformist', 'congenially', 'consonantly'],
    'in step with': ['accommodated to', 'according to', 'adapted to', 'adjusted to', 'after', 'agreeable to', 'agreeably to', 'answerable to', 'by', 'conformable to', 'congruent with', 'consistent with'],
    'in store': ['about to be', 'already in sight', 'appointed', 'approaching', 'at hand', 'brewing', 'by one', 'close', 'close at hand', 'coming', 'destined', 'devoted'],
    'in succession': ['by stages', 'consecutively', 'hand running', 'hierarchically', 'in indian file', 'in a chain', 'in a line', 'in a row', 'in a series', 'in column', 'in file', 'in order'],
    'in suspense': ['abeyant', 'addled', 'anxious', 'apathetic', 'apprehensive', 'at a loss', 'at issue', 'baffled', 'bamboozled', 'beat', 'buffaloed', 'cataleptic'],
    'in the air': ['above', 'abovestairs', 'afloat', 'airward', 'aloft', 'aloof', 'bandied about', 'bruited about', 'current', 'going about', 'going around', 'high'],
    'in the bag': ['ascertained', 'assured', 'attested', 'certified', 'cooked-up', 'cut out', 'cut-and-dried', 'cut-and-dry', 'decided', 'determinate', 'determined', 'established'],
    'in the blood': ['atavistic', 'bodily', 'born', 'coeval', 'congenital', 'connatal', 'connate', 'connatural', 'constitutional', 'genetic', 'hereditary', 'inborn'],
    'in the cards': ['about to be', 'already in sight', 'appointed', 'approaching', 'apt', 'at hand', 'brewing', 'close', 'close at hand', 'coming', 'destined', 'devoted'],
    'in the clear': ['above water', 'afoot and lighthearted', 'angelic', 'at anchor', 'at large', 'at liberty', 'blameless', 'childlike', 'clear', 'decipherable', 'detached', 'disengaged'],
    'in the dark': ['at night', 'behind the curtain', 'behind the scenes', 'behind the veil', 'benighted', 'by night', 'covertly', 'dark', 'darkling', 'in a corner', 'in a whisper', 'in darkness'],
    'in the know': ['alive to', 'appreciative of', 'apprised of', 'awake to', 'aware of', 'behind the curtain', 'behind the scenes', 'cognizant of', 'conscious of', 'hep to', 'in the secret', 'informed'],
    'in the pink': ['alive and kicking', 'bright-eyed and bushy-tailed', 'chipper', 'enjoying health', 'eupeptic', 'fine', 'fit', 'fit and fine', 'fixed', 'full of beans', 'healthful', 'healthy'],
    'in the red': ['at a loss', 'bankrupt', 'burdened with debt', 'deep in debt', 'destitute', 'down-and-out', 'embarrassed', 'encumbered', 'fortuneless', 'homeless', 'in debt', 'in difficulties'],
    'in the wind': ['about to be', 'accidental', 'accompanying', 'ado', 'afloat', 'afoot', 'against the wind', 'already in sight', 'approaching', 'at hand', 'brewing', 'by the wind'],
    'in the works': ['accepted', 'acting', 'active', 'arranged', 'assumed', 'at work', 'blueprinted', 'brewing', 'calculated', 'chanced', 'charted', 'contrived'],
    'in time': ['a tempo', 'cyclically', 'daily', 'day by day', 'early enough', 'epochally', 'eventually', 'every day', 'every hour', 'hour by hour', 'hourly', 'in due course'],
    'in tune': ['accordant', 'according', 'agreeable', 'agreeing', 'akin', 'amicable', 'assonant', 'assonantal', 'at one', 'attuned', 'blended', 'blending'],
    'in turn': ['alternately', 'au pair', 'by stages', 'by turns', 'consecutively', 'even', 'every other', 'exchangeably', 'hand running', 'hierarchically', 'in indian file', 'in a chain'],
    'in unison': ['accordant', 'according', 'agreeably', 'all agreeing', 'all together', 'as one', 'as one man', 'assonant', 'assonantal', 'at a clip', 'at once', 'at one time'],
    'in view': ['about to be', 'accessible', 'already in sight', 'anticipated', 'apparent', 'approaching', 'at hand', 'attendant', 'available', 'awaited', 'beholdable', 'brewing'],
    'in vogue': ['all the rage', 'all the thing', 'current', 'fashionable', 'hip', 'in fashion', 'in style', 'mod', 'modern', 'new', 'newfashioned', 'popular'],
    'in with': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'cabalistic', 'confederate', 'confederated', 'conspiratorial', 'corporate', 'coupled', 'enleagued'],
    'in writing': ['autograph', 'autographic', 'calligraphic', 'chirographic', 'cursive', 'engrossed', 'flowing', 'graphic', 'graphoanalytic', 'graphologic', 'graphometric', 'holograph'],
    'inability': ['disability', 'disablement', 'disqualification', 'imbecility', 'inadeptness', 'inadequacy', 'inaptitude', 'inaptness', 'inattentiveness', 'incapability', 'incapacitation', 'incapacity'],
    'inaccessible': ['olympian', 'aloof', 'antipodean', 'back of beyond', 'backward', 'bashful', 'beyond reach', 'blank', 'chilled', 'chilly', 'closed forever to', 'closed to'],
    'inaccordant': ['antagonistic', 'antipathetic', 'assorted', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'clashing', 'contradictory', 'contrary', 'contrasted'],
    'inaccuracy': ['abstractionism', 'adulteration', 'allowance', 'amorphousness', 'approximation', 'blobbiness', 'blurriness', 'broadness', 'coloring', 'defectibility', 'defectiveness', 'deficiency'],
    'inaccurate': ['adulterated', 'aleatoric', 'aleatory', 'all wet', 'amiss', 'amorphous', 'approximate', 'approximative', 'awry', 'blemished', 'blobby', 'blurred'],
    'inaction': ['dormancy', 'drift', 'fixation', 'fixity', 'hibernation', 'idleness', 'immobility', 'inactiveness', 'inactivity', 'indolence', 'inertia', 'inertness'],
    'inactivate': ['bugger', 'cripple', 'de-energize', 'debilitate', 'disable', 'disenable', 'drain', 'enfeeble', 'hamstring', 'hors de combat', 'incapacitate', 'kibosh'],
    'inactive': ['abeyant', 'apathetic', 'asleep', 'at a standstill', 'cataleptic', 'catatonic', 'contemplative', 'dead', 'deliberate', 'disengaged', 'do-nothing', 'dopey'],
    'inactivity': ['a wise passiveness', 'comfort', 'contemplation', 'contemplative life', 'deliberateness', 'deliberation', 'do-nothing policy', 'do-nothingism', 'do-nothingness', 'dolce far niente', 'dormancy', 'ease'],
    'inadequacy': ['adulteration', 'arrear', 'arrearage', 'arrears', 'arrestment', 'asymmetry', 'baseness', 'blemish', 'bug', 'callowness', 'catch', 'contrariety'],
    'inadequate': ['adulterated', 'arrested', 'asymmetric', 'barren', 'base', 'blemished', 'bootless', 'callow', 'counterproductive', 'damaged', 'defective', 'deficient'],
    'inadequately': ['by halves', 'defectively', 'deficiently', 'dissatisfactorily', 'faultily', 'imperfectly', 'in half measures', 'in installments', 'inadeptly', 'inadmissibly', 'inaptly', 'incapably'],
    'inadmissible': ['adrift', 'beside the mark', 'beside the point', 'beside the question', 'ethnocentric', 'exceptionable', 'exceptional', 'excluding', 'exclusive', 'exclusory', 'extraneous', 'extrinsic'],
    'inadvertence': ['absentmindedness', 'balk', 'bevue', 'carelessness', 'culpa', 'culpable negligence', 'default', 'dereliction', 'disregard', 'disregardfulness', 'distraction', 'failure'],
    'inadvertent': ['arbitrary', 'automatic', 'capricious', 'careless', 'casual', 'culpably negligent', 'derelict', 'disregardant', 'disregardful', 'distracted', 'distrait', 'feckless'],
    'inadvertently': ['carelessly', 'heedlessly', 'inconsiderately', 'indeliberately', 'involuntarily', 'lightly', 'negligently', 'permissively', 'remissly', 'scampingly', 'skimpingly', 'slightingly'],
    'inadvisable': ['bad', 'careless', 'foolhardy', 'foolish', 'futile', 'harebrained', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-gauged', 'ill-judged'],
    'inalienable': ['bound up in', 'bound up with', 'deep-seated', 'esoteric', 'immanent', 'impartible', 'implanted', 'implicit', 'incommunicable', 'indefeasible', 'indissoluble', 'indivisible'],
    'inalterable': ['assiduous', 'constant', 'continuing', 'diligent', 'dogged', 'enduring', 'faithful', 'fixed', 'immovable', 'immutable', 'indefatigable', 'indomitable'],
    'inamorata': ['dulcinea', 'beloved', 'best girl', 'doxy', 'dream girl', 'flame', 'gill', 'girl', 'girl friend', 'honey', 'jill', 'jo'],
    'inamorato': ['casanova', 'don juan', 'lothario', 'romeo', 'amoroso', 'beau', 'beloved', 'boyfriend', 'caballero', 'cavalier', 'cavaliere servente', 'esquire'],
    'inane': ['absurd', 'aimless', 'airy', 'apish', 'arid', 'asinine', 'awkward', 'bare', 'barren', 'batty', 'befooled', 'beguiled'],
    'inanimate': ['abiotic', 'animate', 'apathetic', 'asleep', 'asleep in jesus', 'at rest', 'azoic', 'benumbed', 'bereft of life', 'blase', 'bored', 'breathless'],
    'inanity': ['absence of mind', 'absurdity', 'agnosticism', 'aimlessness', 'aridity', 'asininity', 'barrenness', 'battiness', 'big deal', 'blank', 'blank mind', 'blankmindedness'],
    'inappetence': ['acedia', 'aloofness', 'anorexia', 'anorexia nervosa', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'comatoseness', 'desirelessness'],
    'inapplicable': ['adrift', 'beside the mark', 'beside the point', 'beside the question', 'extraneous', 'extrinsic', 'foreign', 'functionless', 'ill-adapted', 'ill-assorted', 'ill-chosen', 'ill-fitted'],
    'inapposite': ['adrift', 'beside the mark', 'beside the point', 'beside the question', 'extraneous', 'extrinsic', 'foreign', 'ill-adapted', 'ill-assorted', 'ill-chosen', 'ill-fitted', 'ill-matched'],
    'inappreciable': ['atomic', 'back-burner', 'corpuscular', 'dinky', 'dispensable', 'embryonic', 'evanescent', 'germinal', 'granular', 'immaterial', 'impalpable', 'imperceptible'],
    'inappropriate': ['aberrant', 'abnormal', 'abominable', 'adrift', 'atrocious', 'bad', 'beside the mark', 'beside the point', 'beside the question', 'chintzy', 'criminal', 'delinquent'],
    'inappropriateness': ['babbittry', 'aberrance', 'aberrancy', 'abnormality', 'anomaly', 'bad taste', 'bourgeois taste', 'camp', 'campiness', 'criminality', 'delinquency', 'deviance'],
    'inapt': ['artless', 'awkward', 'bad', 'banal', 'clumsy', 'flat', 'futile', 'gauche', 'half-assed', 'ill-adapted', 'ill-advised', 'ill-assorted'],
    'inaptitude': ['abnormality', 'anomaly', 'futility', 'impoliticalness', 'impoliticness', 'impropriety', 'inability', 'inadeptness', 'inadequacy', 'inadmissibility', 'inadvisability', 'inapplicability'],
    'inarticulate': ['greek to one', 'ambiguous', 'anaudic', 'aphasic', 'aphonic', 'bashful', 'beyond understanding', 'blurred', 'breathless', 'breathy', 'choked', 'choking'],
    'inartificial': ['arcadian', 'artless', 'authentic', 'bona fide', 'bucolic', 'candid', 'card-carrying', 'dinkum', 'direct', 'following the letter', 'genuine', 'good'],
    'inasmuch as': ['as', 'as long as', 'as things go', 'because', 'being', 'being as how', 'cause', 'considering', 'for', 'forasmuch as', 'in that', 'insofar as'],
    'inattention': ['accidia', 'acedia', 'apathy', 'ataraxia', 'ataraxy', 'callowness', 'carelessness', 'casualness', 'childishness', 'culpa', 'culpable negligence', 'default'],
    'inattentive': ['apathetic', 'artless', 'ataractic', 'blase', 'careless', 'casual', 'culpably negligent', 'derelict', 'devil-may-care', 'disinterested', 'dispassionate', 'disregardant'],
    'inaudible': ['echoless', 'hush as death', 'hushed', 'mousy', 'noiseless', 'quiescent', 'quiet', 'silent', 'soundless', 'still', 'still as death', 'stilly'],
    'inaugural': ['abecedarian', 'aboriginal', 'address', 'advanced', 'after-dinner speech', 'allocution', 'antecedent', 'antenatal', 'anterior', 'autochthonous', 'avant-garde', 'baccalaureate service'],
    'inaugurate': ['anoint', 'author', 'bear', 'beget', 'breed', 'bring about', 'bring forth', 'bring to effect', 'bring to pass', 'bring up', 'broach', 'cause'],
    'inauguration': ['accedence', 'acceptance', 'accession', 'admission', 'admittance', 'anchorage', 'baccalaureate service', 'baptism', 'celebration', 'ceremonial', 'ceremony', 'colonization'],
    'inauspicious': ['apocalyptic', 'bad', 'badly off', 'baleful', 'baneful', 'black', 'bodeful', 'boding', 'criminal', 'dark', 'depressed', 'dire'],
    'inauthentic': ['absonant', 'contradictory', 'contrary to reason', 'fallacious', 'faulty', 'flawed', 'garbled', 'illogical', 'inconclusive', 'incongruous', 'inconsequent', 'inconsequential'],
    'inborn': ['atavistic', 'bodily', 'born', 'coeval', 'congenital', 'connatal', 'connate', 'connatural', 'constitutional', 'deep-rooted', 'deep-seated', 'genetic'],
    'inbred': ['atavistic', 'bodily', 'born', 'coeval', 'congenital', 'connatal', 'connate', 'connatural', 'constitutional', 'crossbred', 'endogamic', 'endogamous'],
    'inbreed': ['beget', 'breed', 'breed true', 'copulate', 'crossbreed', 'engender', 'father', 'generate', 'get', 'make love', 'mother', 'multiply'],
    'incalculable': ['able', 'agnostic', 'all-comprehensive', 'all-inclusive', 'ambiguous', 'boundless', 'capricious', 'chancy', 'changeable', 'countless', 'dicey', 'doubting'],
    'incandesce': ['bake', 'be bright', 'be in heat', 'beacon', 'beam', 'bedazzle', 'blaze', 'blind', 'bloom', 'boil', 'broil', 'burn'],
    'incandescence': ['afterglow', 'air glow', 'bloom', 'blush', 'candescence', 'fieriness', 'flush', 'gleam', 'glint', 'gloss', 'glow', 'hectic'],
    'incandescent': ['ablaze', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'beaming', 'beamy', 'blazing', 'blushing', 'bright'],
    'incantation': ['abracadabra', 'bewitchment', 'conjuration', 'conjurement', 'devil', 'enchantment', 'evocation', 'exorcisation', 'exorcism', 'exsufflation', 'hocus-pocus', 'invocation'],
    'incapability': ['ad lib', 'disability', 'disablement', 'disqualification', 'extemporaneousness', 'imbecility', 'improvisation', 'inability', 'inadeptness', 'inadequacy', 'inaptitude', 'inaptness'],
    'incapable': ['amputee', 'cripple', 'defective', 'deformity', 'disqualified', 'dull tool', 'greenhorn', 'handicapped person', 'idiot', 'ill-equipped', 'ill-fitted', 'ill-furnished'],
    'incapacitate': ['afflict', 'bugger', 'castrate', 'cripple', 'de-energize', 'deactivate', 'debilitate', 'derange', 'devitalize', 'disable', 'disarm', 'disenable'],
    'incapacitated': ['ausgespielt', 'bad', 'burned-out', 'castrated', 'crippled', 'devitalized', 'disabled', 'disarmed', 'disqualified', 'drained', 'effete', 'emasculated'],
    'incapacity': ['urdummheit', 'brainlessness', 'caducity', 'decrepitude', 'disability', 'disablement', 'disqualification', 'foolishness', 'ignorance', 'imbecility', 'inability', 'inadeptness'],
    'incarcerate': ['bastille', 'beleaguer', 'beset', 'besiege', 'blockade', 'bolt in', 'bound', 'box in', 'cage', 'cast in prison', 'chamber', 'clap in jail'],
    'incarcerated': ['barred', 'behind bars', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'cabined', 'caged', 'cloistered', 'closed-in', 'confined'],
    'incarceration': ['beleaguerment', 'besetment', 'blockade', 'blockading', 'captivity', 'circumscription', 'close arrest', 'confinement', 'cordoning', 'detention', 'dismemberment', 'durance'],
    'incarnate': ['christlike', 'christly', 'adumbrate', 'affect', 'atavistic', 'betoken', 'bodily', 'body', 'body forth', 'born', 'brandish', 'breathe'],
    'incarnation': ['christophany', 'satanophany', 'acting', 'angelophany', 'aping', 'apparition', 'appearance', 'appearing', 'arising', 'avatar', 'characterization', 'coming'],
    'incautious': ['asleep', 'brash', 'brazen', 'brazenfaced', 'goofing off', 'hubristic', 'improvident', 'imprudent', 'impudent', 'indiscreet', 'injudicious', 'insolent'],
    'incendiary': ['mafioso', 'young turk', 'agent provocateur', 'agitational', 'agitative', 'agitator', 'agitprop', 'arsonist', 'beast', 'beldam', 'berserk', 'berserker'],
    'incense': ['adulation', 'agalloch', 'agape', 'aggravate', 'agitate', 'aloeswood', 'annoy', 'aroma', 'aromatize', 'arouse', 'asperges', 'aspersion'],
    'incensed': ['angered', 'angry', 'browned-off', 'cross', 'indignant', 'irate', 'ireful', 'livid', 'mad', 'pissed', 'pissed-off', 'riled up'],
    'incensory': ['atomizer', 'censer', 'fumigator', 'incense burner', 'odorator', 'odorizer', 'parfumoir', 'perfumer', 'pomander', 'potpourri', 'pouncet-box', 'purse atomizer'],
    'incentive': ['agitational', 'agitative', 'bait', 'bribe', 'carrot', 'catalyst', 'clout', 'compulsion', 'drive', 'driving force', 'encouragement', 'enticement'],
    'inception': ['babyhood', 'beginning', 'beginnings', 'birth', 'childhood', 'commencement', 'conception', 'constitution', 'cradle', 'derivation', 'effectuation', 'establishment'],
    'inceptive': ['abecedarian', 'aboriginal', 'antenatal', 'autochthonous', 'beginning', 'budding', 'creative', 'elemental', 'elementary', 'embryonic', 'fetal', 'formative'],
    'incertitude': ['capriciousness', 'chance', 'chanciness', 'changeableness', 'erraticism', 'erraticness', 'fickleness', 'hesitancy', 'hesitation', 'incalculability', 'indecision', 'indecisiveness'],
    'incessancy': ['ceaselessness', 'chattering', 'coeternity', 'consecutiveness', 'constancy', 'constant flow', 'continualness', 'continuance', 'continuity', 'continuousness', 'durability', 'endlessness'],
    'incessant': ['ageless', 'articulated', 'catenated', 'ceaseless', 'chattering', 'coeternal', 'concatenated', 'connected', 'constant', 'continual', 'continued', 'continuing'],
    'incessantly': ['ad infinitum', 'again and again', 'always', 'at a stretch', 'at all times', 'ceaselessly', 'connectedly', 'constantly', 'continually', 'continuously', 'cumulatively', 'cyclically'],
    'incest': ['active algolagnia', 'adultery', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'bisexuality', 'concubinage', 'coprophilia', 'criminal conversation', 'cuckoldry', 'exhibitionism'],
    'inch': ['ace', 'amble', 'bit', 'bowshot', 'brief span', 'claudicate', 'close quarters', 'close range', 'crack', 'crawl', 'creep', 'crowd'],
    'inchmeal': ['bit by bit', 'by degrees', 'by inches', 'by inchmeal', 'by slow degrees', 'by snatches', 'degreewise', 'drop by drop', 'foot by foot', 'gradatim', 'grade by grade', 'gradually'],
    'inchoate': ['abecedarian', 'aboriginal', 'aimless', 'aleatoric', 'aleatory', 'amorphic', 'amorphous', 'anarchic', 'antenatal', 'autochthonous', 'baggy', 'beginning'],
    'incidence': ['accident', 'amount', 'coming to be', 'common occurrence', 'commonness', 'contingency', 'contingent', 'degree', 'event', 'eventuality', 'eventuation', 'extent'],
    'incident': ['action', 'adventure', 'affair', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'argument', 'atmosphere', 'background', 'catastrophe', 'characterization'],
    'incidental': ['accessory', 'acciaccatura', 'accident', 'accidental', 'accompanying', 'addendum', 'addition', 'additional', 'adjunct', 'ado', 'adrift', 'adscititious'],
    'incidentally': ['a propos', 'accidentally', 'apropos', 'apropos of', 'as it chanced', 'by a fluke', 'by accident', 'by chance', 'by good fortune', 'by hazard', 'by the by', 'by the way'],
    'incinerate': ['blow to pieces', 'blow up', 'brain', 'bring down', 'bring to ruin', 'burn', 'burn down', 'burn to death', 'burn up', 'condemn', 'confound', 'consume'],
    'incineration': ['blazing', 'blistering', 'branding', 'burning', 'calcination', 'carbonization', 'cauterization', 'cautery', 'cineration', 'combustion', 'concremation', 'cracking'],
    'incipiency': ['babyhood', 'beginnings', 'birth', 'childhood', 'cradle', 'freshman year', 'genesis', 'inception', 'inchoation', 'incipience', 'incunabula', 'infancy'],
    'incipient': ['lilliputian', 'tom thumb', 'abecedarian', 'aboriginal', 'antenatal', 'autochthonous', 'beginning', 'budding', 'creative', 'dumpy', 'dwarf', 'dwarfed'],
    'incise': ['vandyke', 'abrade', 'amputate', 'autolithograph', 'ax', 'bark', 'be a printmaker', 'bisect', 'blaze', 'blemish', 'bloody', 'book'],
    'incised': ['battlemented', 'canaliculate', 'canaliculated', 'carved', 'chamfered', 'channeled', 'chopped', 'corduroy', 'corduroyed', 'corrugate', 'corrugated', 'costate'],
    'incision': ['abrasion', 'abysm', 'abyss', 'arroyo', 'bezel', 'blaze', 'blemish', 'box canyon', 'breach', 'break', 'burn', 'burr'],
    'incisive': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'active', 'acute', 'aggressive'],
    'incisor': ['baby tooth', 'bicuspid', 'bucktooth', 'canine', 'crown', 'cuspid', 'cutter', 'deciduous tooth', 'dent', 'denticle', 'denticulation', 'dentil'],
    'incite': ['abet', 'actuate', 'admonish', 'agitate', 'animate', 'annoy', 'arouse', 'awake', 'awaken', 'bestir', 'blow the coals', 'blow up'],
    'incitement': ['aggravation', 'agitating', 'agitation', 'animation', 'arousal', 'arousing', 'awakening', 'bait', 'bribe', 'carrot', 'clout', 'compulsion'],
    'incivility': ['gothicism', 'neanderthalism', 'animality', 'bad manners', 'barbarism', 'barbarity', 'barbarousness', 'bestiality', 'boorishness', 'brutality', 'brutishness', 'caddishness'],
    'inclemency': ['absolute zero', 'acuteness', 'algidity', 'animality', 'astringency', 'atrocity', 'austerity', 'barbarity', 'bitterness', 'bleakness', 'bloodlust', 'briskness'],
    'inclement': ['siberian', 'algid', 'arctic', 'astringent', 'austere', 'bad', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'blustery'],
    'inclination': ['a thing for', 'affection', 'affinity', 'aim', 'an ear for', 'an eye for', 'angle', 'angularity', 'animus', 'appetence', 'appetency', 'appetite'],
    'incline': ['acclivity', 'acquiesce', 'address', 'affect', 'agree', 'aim', 'angle', 'ascend', 'ascent', 'back stairs', 'bank', 'be agreeable to'],
    'inclined': ['aching for', 'acquiescent', 'actuated', 'agreeable', 'alacritous', 'amenable', 'animated', 'apt', 'apt to', 'ardent', 'aslant', 'aslope'],
    'inclining': ['aslant', 'aslope', 'atilt', 'bent', 'bevel', 'beveled', 'bias', 'biased', 'canting', 'careening', 'comprehend', 'contain'],
    'include': ['accouple', 'accumulate', 'add', 'admit', 'agglutinate', 'allow for', 'amalgamate', 'amass', 'articulate', 'assemble', 'assimilate', 'associate'],
    'including': ['added to', 'along with', 'as well as', 'assimilating', 'attended by', 'compact of', 'composed of', 'composing', 'comprising', 'consisting of', 'constituting', 'contained in'],
    'inclusion': ['anschluss', 'absorption', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alignment', 'alliance', 'amalgamation', 'assimilation', 'association'],
    'inclusive': ['across the board', 'aggregate', 'all', 'all-embracing', 'all-encompassing', 'all-inclusive', 'assimilating', 'blanket', 'broad', 'coincident', 'compact', 'comprehensive'],
    'inclusive of': ['added to', 'along with', 'as well as', 'attended by', 'compact of', 'composed of', 'composing', 'comprising', 'consisting of', 'constituting', 'contained in', 'containing'],
    'incognito': ['anonym', 'anonymity', 'anonymous', 'anonymousness', 'camouflage', 'camouflaged', 'closed meeting', 'closet', 'concealed', 'confidentiality', 'confidentialness', 'cryptonymic'],
    'incognizant': ['a stranger to', 'asleep', 'blind to', 'caught napping', 'dead to', 'deaf to', 'impercipient', 'in ignorance of', 'insensible', 'insensible to', 'mindless', 'napping'],
    'incoherent': ['greek to one', 'abnormal', 'absurd', 'aleatoric', 'aleatory', 'aloof', 'ambiguous', 'amorphous', 'anomalous', 'apart', 'asunder', 'babbling'],
    'income': ['access', 'admission', 'avails', 'base pay', 'box office', 'capital gains', 'cleanup', 'clear profit', 'commissions', 'compensation', 'credit', 'credits'],
    'income tax': ['vat', 'ad valorem duty', 'alcohol tax', 'amusement tax', 'assessment on default', 'capital gains tax', 'capitation', 'capitation tax', 'corporation tax', 'customs', 'customs duty', 'death duty'],
    'incoming': ['access', 'admission', 'approaching', 'arriving', 'coming', 'entering', 'entrance', 'entree', 'entry', 'homeward', 'homeward-bound', 'import'],
    'incommensurable': ['abnormal', 'absurd', 'alien', 'anomalous', 'apart', 'detached', 'disconnected', 'discrete', 'disjunct', 'disproportionate', 'disrelated', 'dissimilar'],
    'incommensurate': ['abnormal', 'absurd', 'anomalous', 'disappointing', 'disheartening', 'displeasing', 'disproportionate', 'dissatisfactory', 'inadequate', 'incoherent', 'incommensurable', 'incomparable'],
    'incommodious': ['angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'awkward', 'circumscribed', 'close', 'close-fitting', 'clumsy', 'confined', 'constricted', 'cramp'],
    'incommunicable': ['inalienable', 'indefeasible', 'indefinable', 'indescribable', 'ineffable', 'inenarrable', 'inexpressible', 'innominable', 'noncommunicable', 'noncontagious', 'noninfectious', 'undefinable'],
    'incommunicado': ['abstruse', 'beclouded', 'blind', 'buried', 'close', 'clouded', 'concealed', 'covered', 'covert', 'eclipsed', 'hid', 'hidden'],
    'incommutable': ['changeless', 'constant', 'immutable', 'inconvertible', 'indefeasible', 'inert', 'insusceptible of change', 'intransmutable', 'invariable', 'irretrievable', 'irreversible', 'irrevocable'],
    'incomparable': ['alien', 'apart', 'beyond compare', 'beyond comparison', 'detached', 'disconnected', 'discrete', 'disjunct', 'disrelated', 'dissimilar', 'dissociated', 'easily first'],
    'incomparably': ['egregiously', 'eminently', 'exceedingly', 'far and away', 'inimitably', 'invincibly', 'matchlessly', 'nulli secundus', 'par excellence', 'paramountly', 'peerlessly', 'preeminently'],
    'incompatibility': ['discordia', 'eris', 'ambiguity', 'ambivalence', 'antinomy', 'asymmetry', 'autism', 'bashfulness', 'chill', 'chilliness', 'clash', 'clashing'],
    'incompatible': ['abnormal', 'absurd', 'anomalous', 'antagonistic', 'antipathetic', 'antithetic', 'assorted', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war'],
    'incompetence': ['ad lib', 'baseness', 'deficiency', 'disability', 'disablement', 'disqualification', 'extemporaneousness', 'failure', 'falling short', 'faultiness', 'fewness', 'imbecility'],
    'incompetent': ['awkward', 'base', 'blank cartridge', 'bungling', 'castrato', 'clumsy', 'defective', 'deficient', 'disqualified', 'dud', 'dull tool', 'eunuch'],
    'incomplete': ['adulterated', 'arrested', 'blemished', 'broken', 'callow', 'crude', 'damaged', 'defective', 'deficient', 'embryonic', 'erroneous', 'failing'],
    'incompletely': ['after a fashion', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst', 'by halves', 'comparatively'],
    'incompleteness': ['absence', 'adulteration', 'beggary', 'broken thread', 'brokenness', 'defectibility', 'defectiveness', 'deficiency', 'deficit', 'deprivation', 'destitution', 'disconnectedness'],
    'incomprehensible': ['greek to one', 'abstruse', 'all-comprehensive', 'all-inclusive', 'ambiguous', 'antic', 'arcane', 'baffling', 'beguiling', 'bewildering', 'beyond understanding', 'boundless'],
    'incomprehension': ['blindness', 'deafness', 'dim-sightedness', 'imperceptiveness', 'impercipience', 'incognizance', 'insensibility', 'mindlessness', 'nearsightedness', 'nonrealization', 'nonrecognition', 'nonunderstanding'],
    'inconceivable': ['a bit thick', 'a bit thin', 'absurd', 'antic', 'barred', 'beguiling', 'bewildering', 'beyond belief', 'closed-out', 'contrary to reason', 'doubtable', 'doubtful'],
    'inconclusive': ['absonant', 'contradictory', 'contrary to reason', 'fallacious', 'faulty', 'feeble', 'flawed', 'flimsy', 'groundless', 'illogical', 'inauthentic', 'incongruous'],
    'incongruity': ['absurdity', 'absurdness', 'ambiguity', 'ambivalence', 'antilogy', 'antinomy', 'asymmetry', 'bizarreness', 'bizarrerie', 'contrariety', 'contrast', 'departure'],
    'incongruous': ['abnormal', 'absonant', 'absurd', 'amusing', 'anomalous', 'assorted', 'at odds', 'at variance', 'bad', 'bizarre', 'clashing', 'colliding'],
    'inconsequence': ['disassociation', 'disconnection', 'discreteness', 'disjunction', 'disjuncture', 'dissociation', 'immateriality', 'impertinence', 'inapplicability', 'inappositeness', 'inconnection', 'inconsequentiality'],
    'inconsequent': ['abnormal', 'absonant', 'absurd', 'adrift', 'anomalous', 'beside the mark', 'beside the point', 'beside the question', 'contradictory', 'contrary to reason', 'disproportionate', 'extraneous'],
    'inconsequential': ['absonant', 'back-burner', 'contradictory', 'contrary to reason', 'cursory', 'depthless', 'dinky', 'dispensable', 'fallacious', 'faulty', 'few', 'flawed'],
    'inconsiderable': ['back-burner', 'cursory', 'depthless', 'dinky', 'dispensable', 'few', 'footling', 'immaterial', 'inappreciable', 'inconsequential', 'inessential', 'inferior'],
    'inconsiderate': ['airy', 'arbitrary', 'boorish', 'brash', 'caddish', 'capricious', 'careless', 'casual', 'coarse', 'crude', 'cursory', 'degage'],
    'inconsistency': ['aloofness', 'ambiguity', 'ambivalence', 'anarchy', 'antagonism', 'antilogy', 'antinomy', 'antipathy', 'antithesis', 'asymmetry', 'capriciousness', 'changeability'],
    'inconsistent': ['abnormal', 'absonant', 'absurd', 'adrift', 'adversative', 'adverse', 'adversive', 'afloat', 'aloof', 'alternating', 'amorphous', 'anomalous'],
    'inconsonant': ['abnormal', 'absurd', 'anomalous', 'assorted', 'at odds', 'at variance', 'contrary', 'contrasted', 'contrasting', 'departing', 'deviating', 'deviative'],
    'inconspicuous': ['blear', 'bleared', 'bleary', 'blurred', 'blurry', 'confused', 'dark', 'dim', 'discreet', 'faint', 'feeble', 'filmy'],
    'inconstancy': ['punic faith', 'ambitendency', 'ambivalence', 'arrhythmia', 'bad faith', 'barratry', 'breach of faith', 'breach of promise', 'breach of trust', 'brokenness', 'capriciousness', 'change of mind'],
    'inconstant': ['adrift', 'afloat', 'alternating', 'amorphous', 'brittle', 'broken', 'capricious', 'careening', 'catchy', 'changeable', 'changeful', 'changing'],
    'incontestable': ['absolute', 'actual', 'admitting no question', 'certain', 'confirmable', 'demonstrable', 'demonstratable', 'factual', 'historical', 'impenetrable', 'impregnable', 'inappealable'],
    'incontinence': ['abandon', 'abandonment', 'acquisitiveness', 'avarice', 'avariciousness', 'avidity', 'avidness', 'boundlessness', 'carpe diem', 'conspicuous consumption', 'covetousness', 'crapulence'],
    'incontinent': ['a bit much', 'abandoned', 'bibulous', 'boundless', 'crapulent', 'crapulous', 'debauched', 'dirty', 'dissipative', 'dissolute', 'easy come', 'easy go'],
    'incontrovertible': ['absolute', 'actual', 'adducible', 'admissible', 'admitting no question', 'attestative', 'attestive', 'authentic', 'based on', 'certain', 'circumstantial', 'conclusive'],
    'inconvenience': ['abuse a privilege', 'ado', 'aggravate', 'aggravation', 'ail', 'annoy', 'annoyance', 'anxiety', 'awkwardness', 'be the matter', 'beset', 'besetment'],
    'inconvenient': ['annoying', 'awkward', 'bothersome', 'bulky', 'burdensome', 'clumsy', 'contrary', 'crosswise', 'cumbersome', 'detrimental', 'disadvantageous', 'discommodious'],
    'inconvertible': ['changeless', 'constant', 'immutable', 'incommutable', 'indefeasible', 'inert', 'insusceptible of change', 'intransmutable', 'invariable', 'irredeemable', 'irretrievable', 'irreversible'],
    'inconvincible': ['cautious', 'disinclined to believe', 'disposed to doubt', 'guarded', 'hard of belief', 'impervious to persuasion', 'incredulous', 'leery', 'shy of belief', 'skeptical', 'suspecting', 'suspicious'],
    'incorporate': ['add', 'admit', 'amalgamate', 'assemble', 'assimilate', 'blend', 'body', 'build', 'build up', 'coalesce', 'combine', 'come together'],
    'incorporated': ['allied', 'amalgamated', 'assembled', 'assimilated', 'associated', 'banded together', 'blended', 'bound', 'bracketed', 'collected', 'combinative', 'combinatory'],
    'incorporation': ['anschluss', 'addition', 'admissibility', 'admission', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alignment', 'alliance', 'amalgamation', 'assemblage'],
    'incorporeal': ['masan', 'airy', 'apparition', 'appearance', 'asomatous', 'astral', 'astral spirit', 'banshee', 'bodiless', 'control', 'decarnate', 'decarnated'],
    'incorporeality': ['airiness', 'airy nothing', 'bodilessness', 'ethereality', 'fineness', 'flimsiness', 'ghostliness', 'immateriality', 'immaterialness', 'impalpability', 'imponderability', 'incorporeity'],
    'incorrect': ['doric', 'aberrant', 'abnormal', 'abominable', 'approximate', 'approximative', 'atrocious', 'barbaric', 'barbarous', 'cacophonous', 'careless', 'clumsy'],
    'incorrigible': ['bad', 'beyond control', 'beyond recall', 'beyond remedy', 'breachy', 'chronic', 'confirmed', 'contumacious', 'cureless', 'deep-dyed', 'deep-fixed', 'deep-rooted'],
    'incorrupt': ['angelic', 'blameless', 'childlike', 'clear', 'correct', 'dovelike', 'faultless', 'flawless', 'good', 'guiltless', 'honest', 'honorable'],
    'incorruptible': ['amaranthine', 'deathless', 'dependable', 'embalmed', 'ever-fresh', 'everlasting', 'fadeless', 'faithworthy', 'frozen', 'immortal', 'imperishable', 'impregnable'],
    'incrassate': ['beat up', 'bloated', 'blown up', 'cake', 'caked', 'cakey', 'churn', 'clabber', 'clabbered', 'clot', 'clotted', 'clump'],
    'increase': ['accession', 'accessory', 'accompaniment', 'accretion', 'accrue', 'accumulate', 'add to', 'addenda', 'addendum', 'additament', 'addition', 'additive'],
    'increased': ['accelerated', 'aggrandized', 'aggravated', 'ampliate', 'amplified', 'annoyed', 'augmented', 'beefed-up', 'bloated', 'boosted', 'broadened', 'built-up'],
    'incredible': ['a bit thick', 'a bit thin', 'absurd', 'amazing', 'antic', 'appalling', 'astonishing', 'astounding', 'awe-inspiring', 'awesome', 'beguiling', 'bewildering'],
    'incredibly': ['abnormally', 'abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'beguilingly', 'bewilderingly', 'conspicuously', 'copiously', 'eminently'],
    'incredulity': ['humism', 'pyrrhonism', 'agnosticism', 'atheism', 'denial', 'disbelief', 'discredit', 'doubt', 'heresy', 'inability to believe', 'infidelity', 'minimifidianism'],
    'incredulous': ['humean', 'pyrrhonic', 'agnostic', 'cautious', 'creedless', 'disbelieving', 'disinclined to believe', 'disposed to doubt', 'distrustful', 'doubtful', 'doubting', 'dubious'],
    'increment': ['access', 'accession', 'accessory', 'accompaniment', 'accretion', 'accrual', 'accruement', 'accumulation', 'addenda', 'addendum', 'additament', 'addition'],
    'incriminate': ['accuse', 'arraign', 'assail', 'attack', 'blame', 'censure', 'charge', 'criminate', 'cry out against', 'cry out on', 'cry shame upon', 'entangle'],
    'incrustation': ['blanketing', 'blocking', 'blotting out', 'cementwork', 'cloaking', 'clouding', 'coating', 'coverage', 'covering', 'crust', 'curtaining', 'eclipse'],
    'incrusted': ['backed', 'calcified', 'callous', 'calloused', 'case-hardened', 'crusted', 'crusty', 'crystallized', 'fossilized', 'granulated', 'hardened', 'hornified'],
    'incubus': ['baba yaga', 'dracula', 'frankenstein', 'lilith', 'wolf-man', 'afreet', 'bad dream', 'bale', 'barghest', 'bogey', 'bogeyman', 'brown study'],
    'inculcate': ['beat into', 'brainwash', 'catechize', 'condition', 'engrave', 'etch', 'grave', 'imbue', 'implant', 'impregnate', 'impress', 'imprint'],
    'inculcated': ['chronic', 'confirmed', 'deep-dyed', 'deep-fixed', 'deep-rooted', 'deep-seated', 'deep-set', 'deep-settled', 'dyed-in-the-wool', 'established', 'fast', 'fixed'],
    'inculpable': ['above suspicion', 'blameless', 'clean', 'exemplary', 'faultless', 'guiltless', 'innocent', 'irreprehensible', 'irreproachable', 'irreprovable', 'pure', 'righteous'],
    'inculpated': ['accused', 'arraignable', 'arraigned', 'at fault', 'blamed', 'censurable', 'charged', 'cited', 'criminal', 'culpable', 'denounced', 'faulty'],
    'incumbency': ['accountability', 'accountableness', 'advowson', 'amenability', 'answerability', 'answerableness', 'appointment', 'bale', 'benefice', 'berth', 'billet', 'burden'],
    'incumbent': ['addressee', 'artist-in-residence', 'beetle', 'beetle-browed', 'beetling', 'behooving', 'benefice-holder', 'beneficiary', 'binding', 'bridging', 'burdensome', 'chargeable to'],
    'incur': ['acquire', 'arouse', 'attract', 'be responsible for', 'bring down', 'bring on', 'bring upon', 'contract', 'draw', 'fall in with', 'fall into', 'gain'],
    'incurable': ['apoplectic', 'arthritic', 'beyond recall', 'beyond remedy', 'case', 'consumptive', 'cureless', 'dyspeptic', 'epileptic', 'fatal', 'gone', 'habitual'],
    'incuriosity': ['absentmindedness', 'accidia', 'acedia', 'apathy', 'ataraxia', 'ataraxy', 'carelessness', 'casualness', 'detachment', 'disinterest', 'dispassion', 'disregard'],
    'incurious': ['absent', 'absentminded', 'abstracted', 'aloof', 'apathetic', 'ataractic', 'blase', 'bored', 'careless', 'casual', 'detached', 'devil-may-care'],
    'incursion': ['air attack', 'air raid', 'air strike', 'boarding', 'encroachment', 'entrance', 'entrenchment', 'escalade', 'fire raid', 'foray', 'impingement', 'imposition'],
    'incurve': ['arch', 'bend', 'bend back', 'bow', 'bowl', 'cast', 'change of pace', 'change-up', 'chuck', 'chunk', 'crook', 'cup'],
    'incurved': ['bent', 'billowing', 'billowy', 'boat-shaped', 'boatlike', 'bowl-shaped', 'bowllike', 'cavelike', 'cavernous', 'concave', 'concaved', 'craterlike'],
    'indebted': ['beholden', 'bound', 'burdened with debt', 'deep in debt', 'duty-bound', 'embarrassed', 'encumbered', 'in debt', 'in difficulties', 'in embarrassed circumstances', 'in hock', 'in the hole'],
    'indebted to': ['acknowledging', 'appreciative', 'beholden', 'beholden to', 'bound', 'bounden', 'bounden to', 'cognizant of', 'committed', 'crediting', 'duty-bound', 'grateful'],
    'indebtedness': ['accounts payable', 'accounts receivable', 'amount due', 'arrearage', 'arrears', 'bad debts', 'bankruptcy', 'bill', 'bills', 'borrowing', 'charges', 'chits'],
    'indecency': ['babbittry', 'andromania', 'aphrodisia', 'bad taste', 'biological urge', 'bodily appetite', 'bourgeois taste', 'camp', 'campiness', 'carnal desire', 'concupiscence', 'desire'],
    'indecent': ['besmirched', 'blue', 'chintzy', 'coarse', 'debauched', 'defiled', 'degenerate', 'dirty', 'distasteful', 'filthy', 'foul', 'gross'],
    'indecision': ['ambitendency', 'ambivalence', 'capriciousness', 'chance', 'chanciness', 'change of mind', 'changeableness', 'double-mindedness', 'dubiety', 'dubiousness', 'erraticism', 'erraticness'],
    'indecisive': ['adrift', 'afloat', 'agnostic', 'aleatoric', 'aleatory', 'alternating', 'ambiguous', 'ambitendent', 'ambivalent', 'amorphic', 'amorphous', 'anarchic'],
    'indecisiveness': ['ambitendency', 'ambivalence', 'amiable weakness', 'amorphia', 'amorphism', 'amorphousness', 'anarchy', 'blobbiness', 'blurriness', 'breakability', 'brittleness', 'broadness'],
    'indecorous': ['doric', 'aberrant', 'abnormal', 'abominable', 'atrocious', 'barbaric', 'barbarous', 'cacophonous', 'chintzy', 'clumsy', 'coarse', 'criminal'],
    'indecorum': ['babbittry', 'aberrance', 'aberrancy', 'abnormality', 'bad taste', 'blooper', 'boner', 'boo-boo', 'bourgeois taste', 'break', 'camp', 'campiness'],
    'indeed': ['ok', 'roger', 'a fortiori', 'above all', 'absolutely', 'actually', 'all joking aside', 'all right', 'all the more', 'alright', 'alrighty', 'amen'],
    'indefatigable': ['abiding', 'ardent', 'assiduous', 'constant', 'continuing', 'continuous', 'determined', 'diligent', 'dogged', 'enduring', 'energetic', 'faithful'],
    'indefeasible': ['certain', 'changeless', 'constant', 'fated', 'fateful', 'immutable', 'inalienable', 'incommunicable', 'incommutable', 'inconvertible', 'ineluctable', 'inert'],
    'indefensible': ['exceptionable', 'impossible', 'inadmissible', 'inexcusable', 'inexpiable', 'intolerable', 'irremissible', 'objectionable', 'unacceptable', 'unallowable', 'unconscionable', 'undesirable'],
    'indefinable': ['aleatoric', 'aleatory', 'amorphous', 'blobby', 'blurred', 'blurry', 'broad', 'chance', 'chancy', 'chaotic', 'confused', 'disordered'],
    'indefinite': ['abstract', 'aleatoric', 'aleatory', 'ambiguous', 'amorphic', 'amorphous', 'anarchic', 'baffling', 'baggy', 'bewildering', 'bland', 'blear'],
    'indefinitely': ['a outrance', 'absolutely', 'all out', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure', 'broadly', 'completely', 'dead', 'downright', 'essentially'],
    'indeliberate': ['automatic', 'casual', 'gut', 'ill-advised', 'ill-considered', 'ill-devised', 'inadvertent', 'involuntary', 'reflex', 'reflexive', 'snap', 'spontaneous'],
    'indelible': ['absorbing', 'acute', 'colorfast', 'constant', 'deathless', 'deep', 'deep-dyed', 'deep-felt', 'deepgoing', 'double-dyed', 'dyed-in-the-wool', 'enduring'],
    'indelicacy': ['babbittry', 'bad taste', 'boorishness', 'bourgeois taste', 'camp', 'campiness', 'churlishness', 'coarseness', 'crudeness', 'grossness', 'high camp', 'immodesty'],
    'indelicate': ['callow', 'chintzy', 'crude', 'improper', 'in bad taste', 'inappropriate', 'indecent', 'indecorous', 'indiscreet', 'inelegant', 'lewd', 'malodorous'],
    'indemnification': ['amends', 'atonement', 'balancing', 'blood money', 'commutation', 'compensation', 'composition', 'compromise', 'consideration', 'counteraction', 'counterbalancing', 'damages'],
    'indemnify': ['atone', 'compensate', 'cover', 'do penance', 'expiate', 'fee', 'fill up', 'get satisfaction', 'give and take', 'give satisfaction', 'guerdon', 'make amends'],
    'indemnity': ['absolution', 'amends', 'amnesty', 'assurance', 'atonement', 'award', 'balancing', 'blood money', 'bond', 'certification', 'commutation', 'compensation'],
    'indemonstrable': ['agnostic', 'ambiguous', 'capricious', 'chancy', 'changeable', 'dicey', 'doubting', 'equivocal', 'erratic', 'fickle', 'hesitant', 'hesitating'],
    'indent': ['vandyke', 'address', 'adopt', 'adoption', 'alveolation', 'alveolus', 'application', 'apply for', 'appropriate', 'appropriation', 'arrangement', 'arrogate'],
    'indentation': ['alveolation', 'alveolus', 'blaze', 'boss', 'bump', 'cleft', 'colophon', 'concavity', 'convexity', 'crena', 'cut', 'dactylogram'],
    'indented': ['alveolar', 'alveolate', 'battlemented', 'chopped', 'crenate', 'crenated', 'crenellated', 'crenulate', 'dentate', 'dentated', 'dented', 'depressed'],
    'indenture': ['fannie mae', 'federal agency bond', 'ginnie mae', 'series e bond', 'series h bond', 'adjustment bond', 'alveolation', 'alveolus', 'annuity bond', 'appreciation bond', 'apprentice', 'apprenticeship'],
    'independence': ['communist threat', 'declaration of independence', 'western imperialism', 'abstention', 'affluence', 'anythingarianism', 'aplomb', 'arrogance', 'assets', 'atrocity story', 'autarchy', 'autarky'],
    'independent': ['laodicean', 'abounding in riches', 'affluent', 'alien', 'anythingarian', 'apart', 'apart from', 'apathetic', 'arbitrary', 'aside from', 'autarchic', 'autarkic'],
    'independently': ['alone', 'by choice', 'electively', 'en grand seigneur', 'erectly', 'freely', 'gratuitously', 'individually', 'like a lord', 'optionally', 'pridefully', 'proudly'],
    'indescribable': ['exceptional', 'extraordinary', 'fabulous', 'incommunicable', 'indefinable', 'ineffable', 'inenarrable', 'inexpressible', 'innominable', 'legendary', 'marvelous', 'mythical'],
    'indestructible': ['ageless', 'ceaseless', 'changeless', 'coeternal', 'constant', 'continual', 'continuous', 'dateless', 'deathless', 'durable', 'endless', 'enduring'],
    'indeterminate': ['abstract', 'accidental', 'adventitious', 'aleatoric', 'aleatory', 'amorphic', 'amorphous', 'anarchic', 'baggy', 'bland', 'blind', 'blobby'],
    'index': ['art index', 'baedeker', 'bibliography index', 'books in print', 'cumulative book index', 'education index', 'eighteenth amendment', 'lambert conformal projection', 'mercator projection', 'miller projection', 'national union catalog', 'prohibition party'],
    'indexed': ['assorted', 'booked', 'cadastral', 'cataloged', 'classified', 'documented', 'down', 'enrolled', 'entered', 'enumerated', 'filed', 'graded'],
    'indian': ['american indian', 'amerind', 'antarctic', 'arctic', 'atlantic', 'australian aborigine', 'bushman', 'caucasian', 'malayan', 'mister charley', 'mongolian', 'negrillo'],
    'indian file': ['array', 'articulation', 'bank', 'buzz', 'catena', 'catenation', 'chain', 'chain reaction', 'chaining', 'concatenation', 'connection', 'consecution'],
    'indian reservation': ['archives', 'bank', 'bird sanctuary', 'forest preserve', 'game reserve', 'library', 'museum', 'national forest', 'national park', 'paradise', 'park', 'preserve'],
    'indicate': ['adumbrate', 'affect', 'allude to', 'approve', 'argue', 'assign', 'attest', 'augur', 'be construed as', 'be indicative of', 'be significant of', 'be symptomatic of'],
    'indicated': ['assumed', 'augured', 'called for', 'essential', 'foreshadowed', 'foreshown', 'foretokened', 'hinted', 'implicated', 'implied', 'indispensable', 'inferred'],
    'indicating': ['connotative', 'demonstrative', 'denominative', 'denotative', 'designative', 'diagnostic', 'emblematic', 'evidential', 'exhibitive', 'expressive', 'figural', 'figurative'],
    'indication': ['christophany', 'satanophany', 'adumbration', 'angelophany', 'appearance', 'augury', 'auspice', 'avatar', 'basis for belief', 'betokening', 'betokenment', 'body of evidence'],
    'indicative': ['christophanic', 'satanophanic', 'absolute', 'adducible', 'admissible', 'allegorical', 'allusive', 'allusory', 'angelophanic', 'appearing', 'associational', 'attestative'],
    'indicator': ['fathometer', 'jp', 'justice', 'arbiter', 'arbitrator', 'badge', 'banner', 'bencher', 'bob', 'character', 'characteristic', 'control indicator'],
    'indict': ['accuse', 'accuse of', 'allege', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'article', 'blame', 'blame for', 'book', 'bring accusation'],
    'indictable': ['accusable', 'arraignable', 'at fault', 'blamable', 'blameworthy', 'censurable', 'chargeable', 'criminal', 'culpable', 'faulty', 'guilty', 'impeachable'],
    'indicted': ['accused', 'arraigned', 'blamed', 'charged', 'cited', 'denounced', 'impeached', 'implicated', 'impugned', 'in complicity', 'incriminated', 'inculpated'],
    'indictment': ['accusal', 'accusation', 'accusing', 'allegation', 'allegement', 'anathema', 'arraignment', 'bail', 'bill of particulars', 'blame', 'bringing of charges', 'bringing to book'],
    'indifference': ['laodiceanism', 'abandon', 'abeyance', 'absentmindedness', 'abstraction', 'abulia', 'acedia', 'alienation', 'aloofness', 'anxiety', 'anxiety equivalent', 'anxiety state'],
    'indifferent': ['laodicean', 'olympian', 'airy', 'aloof', 'apathetic', 'average', 'backward', 'balking', 'balky', 'benumbed', 'betwixt and between', 'blah'],
    'indifferently': ['ad eundem', 'apathetically', 'as', 'as well', 'ceteris paribus', 'coldly', 'coolly', 'correspondingly', 'disinterestedly', 'dully', 'equally', 'equivalently'],
    'indigence': ['bare cupboard', 'bare subsistence', 'beggarliness', 'beggary', 'deprivation', 'destitution', 'empty purse', 'grinding poverty', 'gripe', 'hand-to-mouth existence', 'homelessness', 'impecuniousness'],
    'indigenous': ['aboriginal', 'atavistic', 'autochthonous', 'bodily', 'born', 'coeval', 'congenital', 'connatal', 'connate', 'connatural', 'constitutional', 'endemic'],
    'indigent': ['almsman', 'almswoman', 'bankrupt', 'beggar', 'beggared', 'beggarly', 'bereaved', 'bereft', 'casual', 'charity case', 'deprived', 'destitute'],
    'indigestion': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'bleeding'],
    'indignant': ['acrimonious', 'against', 'angered', 'angry', 'annoyed', 'browned-off', 'con', 'cross', 'disappointed', 'disapprobatory', 'disapproving', 'discontented'],
    'indignation': ['anger', 'annoyance', 'ban', 'blackball', 'blackballing', 'choler', 'complaint', 'dim view', 'disagreement', 'disappointment', 'disapprobation', 'disapproval'],
    'indignity': ['abuse', 'affront', 'aspersion', 'atrocity', 'belittling', 'brickbat', 'comedown', 'contempt', 'contumely', 'cut', 'decrial', 'depreciation'],
    'indirect': ['o-shaped', 'aberrant', 'aberrative', 'accessory', 'accidental', 'additional', 'adscititious', 'adventitious', 'ambagious', 'amoral', 'ancillary', 'artful'],
    'indirection': ['aberrancy', 'aberration', 'ambages', 'artfulness', 'bend', 'bias', 'branching off', 'cheat', 'chicane', 'chicanery', 'circling', 'circuition'],
    'indirectly': ['at an angle', 'by proxy', 'circlewise', 'circuitously', 'deceitfully', 'deviately', 'deviously', 'digressively', 'divagationally', 'divergently', 'excursively', 'fraudulently'],
    'indiscernible': ['alike', 'atomic', 'behind the curtain', 'behind the scenes', 'camouflaged', 'concealed', 'corpuscular', 'disguised', 'embryonic', 'evanescent', 'germinal', 'granular'],
    'indiscreet': ['audacious', 'blanket', 'bold', 'brash', 'brazen', 'brazenfaced', 'careless', 'casual', 'foolhardy', 'foolish', 'general', 'hasty'],
    'indiscretion': ['absurdity', 'act of folly', 'atrocity', 'audacity', 'babbling', 'betrayal', 'blabbering', 'blabbing', 'bloomer', 'blunder', 'boldness', 'boner'],
    'indiscriminate': ['aimless', 'amalgamated', 'ambiguous', 'ambivalent', 'amorphous', 'amphibious', 'assorted', 'blanket', 'blended', 'broad', 'capricious', 'careless'],
    'indiscrimination': ['accidia', 'acedia', 'apathy', 'ataraxia', 'ataraxy', 'carelessness', 'casualness', 'choicelessness', 'detachment', 'disinterest', 'dispassion', 'disregard'],
    'indispensable': ['bare necessities', 'basic', 'bedrock', 'call for', 'called for', 'cardinal', 'central', 'compelling', 'compulsory', 'crucial', 'demand', 'demand for'],
    'indispose': ['afflict', 'blunt', 'chill', 'cool', 'damp', 'dampen', 'debilitate', 'deflect', 'derange', 'deter', 'devitalize', 'disable'],
    'indisposed': ['afraid', 'ailing', 'antagonistic', 'antipathetic', 'at odds', 'averse', 'backward', 'bad', 'below par', 'critically ill', 'cursory', 'differing'],
    'indisposition': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'antipathy', 'atrophy', 'averseness', 'aversion', 'backwardness'],
    'indisputable': ['absolute', 'actual', 'adducible', 'admissible', 'admitting no exception', 'admitting no question', 'all-out', 'apparent', 'attestative', 'attestive', 'authentic', 'based on'],
    'indistinct': ['aleatoric', 'aleatory', 'alike', 'ambiguous', 'amorphous', 'barely audible', 'blear', 'bleared', 'bleary', 'blind', 'blobby', 'blurred'],
    'indistinguishable': ['alike', 'all one', 'all the same', 'blear', 'bleared', 'bleary', 'blurred', 'blurry', 'confused', 'consubstantial', 'dark', 'dim'],
    'indite': ['assemble', 'author', 'build', 'cast', 'coauthor', 'collaborate', 'compose', 'compound', 'concoct', 'construct', 'create', 'dash off'],
    'individual': ['adamite', 'a certain', 'absolute', 'aerobic organism', 'an', 'an existence', 'anaerobic organism', 'any', 'any one', 'article', 'atomic', 'autotrophic organism'],
    'individualism': ['declaration of independence', 'acquisitiveness', 'animus', 'aptitude', 'aroma', 'attribute', 'autarchy', 'autarky', 'autism', 'autonomy', 'badge', 'bent'],
    'individualist': ['narcissus', 'anomaly', 'braggart', 'capitalist', 'careerist', 'crosspatch', 'egocentric', 'egoist', 'egotist', 'fortune hunter', 'freak', 'free lance'],
    'individualistic': ['absolute', 'acquisitive', 'ambitious for self', 'autarchic', 'autarkic', 'autistic', 'autonomous', 'bourgeois', 'capitalist', 'careerist', 'certain', 'concrete'],
    'individuality': ['character', 'combination', 'complexion', 'difference', 'differentiation', 'differentness', 'dissimilarity', 'distinctiveness', 'egohood', 'fusion', 'human factor', 'humor'],
    'individualize': ['analyze', 'anatomize', 'atomize', 'change', 'chop logic', 'descend to particulars', 'desynonymize', 'detail', 'difference', 'differentiate', 'discriminate', 'disequalize'],
    'individually': ['alone', 'apart', 'by itself', 'in person', 'in propria persona', 'in the flesh', 'in the singular', 'independently', 'once', 'one by one', 'particularly', 'per se'],
    'indivisible': ['a certain', 'an', 'any', 'any one', 'atomic', 'austere', 'bare', 'basic', 'bound up in', 'bound up with', 'chaste', 'coherent'],
    'indocile': ['at odds', 'averse', 'beyond control', 'breachy', 'contumacious', 'cursory', 'defiant', 'differing', 'disagreeing', 'disinclined', 'disobedient', 'forced'],
    'indocility': ['antipathy', 'averseness', 'aversion', 'backwardness', 'civil disobedience', 'contumaciousness', 'contumacy', 'cursoriness', 'defiance', 'disagreement', 'disinclination', 'disobedience'],
    'indoctrinate': ['alienate', 'beat into', 'brainwash', 'catechize', 'condition', 'corrupt', 'counterindoctrinate', 'discipline', 'drill', 'imbue', 'implant', 'impregnate'],
    'indoctrination': ['absorption and regurgitation', 'agitprop', 'alienation', 'brainwashing', 'catechization', 'conditioning', 'corruption', 'counterindoctrination', 'dictation', 'imbuement', 'implantation', 'impregnation'],
    'indolence': ['a wise passiveness', 'abeyance', 'apathy', 'catalepsy', 'catatonia', 'cautiousness', 'circumspection', 'contemplation', 'contemplative life', 'creeping', 'deadliness', 'deathliness'],
    'indolent': ['ambling', 'bone-lazy', 'cadging', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'deliberate', 'dilatory', 'do-nothing'],
    'indomitable': ['assiduous', 'beyond control', 'brave', 'breachy', 'constant', 'continuing', 'contumacious', 'courageous', 'dauntless', 'defiant', 'determined', 'diligent'],
    'indorse': ['ok', 'abet', 'accede to', 'accept', 'accord to', 'accredit', 'admire', 'advocate', 'affirm', 'agree to', 'aid and abet', 'amen'],
    'indra': ['agni', 'asvins', 'avalokita', 'bhairava', 'bhairavi', 'brahma', 'chandi', 'daksha', 'devaki', 'devi', 'dharma', 'dharti mai'],
    'indraft': ['affluence', 'afflux', 'affluxion', 'air current', 'crosscurrent', 'current', 'current of air', 'downdraft', 'draft', 'fall wind', 'flow of air', 'following wind'],
    'indubitable': ['absolute', 'actual', 'admitting no question', 'apparent', 'bona fide', 'clear', 'clear as crystal', 'confirmable', 'crystal-clear', 'demonstrable', 'demonstratable', 'discernible'],
    'indubitably': ['actually', 'admittedly', 'assuredly', 'beyond doubt', 'beyond question', 'by all odds', 'certainly', 'clearly', 'decidedly', 'demonstrably', 'dollars to doughnuts', 'doubtless'],
    'induce': ['actuate', 'admonish', 'affect', 'argue', 'arouse', 'bend', 'bias', 'bring', 'bring about', 'bring around', 'bring forth', 'bring on'],
    'inducement': ['trinkgeld', 'agacerie', 'allure', 'allurement', 'appeal', 'attraction', 'attractiveness', 'bait', 'beguilement', 'beguiling', 'bewitchery', 'bewitchment'],
    'induct': ['anoint', 'bring up', 'broach', 'call up', 'chair', 'christen', 'commandeer', 'conscript', 'crown', 'detach', 'detach for service', 'draft'],
    'inductee': ['abecedarian', 'alphabetarian', 'apprentice', 'articled clerk', 'beginner', 'boot', 'catechumen', 'conscript', 'debutant', 'draft', 'drafted man', 'draftee'],
    'inductile': ['adamant', 'adamantine', 'immovable', 'immutable', 'inelastic', 'inextensible', 'inextensile', 'inextensional', 'inflexible', 'intractable', 'intractile', 'irresilient'],
    'induction': ['baconian method', 'a fortiori reasoning', 'a posteriori reasoning', 'a priori reasoning', 'accedence', 'acceptance', 'accession', 'admission', 'admittance', 'alphabet', 'analysis', 'apostolic orders'],
    'inductive': ['baconian', 'a fortiori', 'a posteriori', 'a priori', 'analytic', 'categorical', 'conditional', 'deductive', 'dialectic', 'discursive', 'enthymematic', 'epagogic'],
    'inductive reasoning': ['baconian method', 'a fortiori reasoning', 'a posteriori reasoning', 'a priori reasoning', 'analysis', 'deduction', 'deductive reasoning', 'demonstration', 'discourse', 'discourse of reason', 'discursive reason', 'epagoge'],
    'indulge': ['accommodate with', 'adore', 'afford', 'appreciate', 'baby', 'bask', 'bask in', 'bay', 'be pleased with', 'bear', 'bear with', 'benignancy'],
    'indulged': ['absolved', 'acquitted', 'blotted', 'canceled', 'coddled', 'condoned', 'disregarded', 'exculpated', 'excused', 'exonerated', 'forgiven', 'forgotten'],
    'indulgence': ['acceptance', 'accommodatingness', 'agreeableness', 'allowance', 'attentiveness', 'benevolence', 'blank check', 'carte blanche', 'charitableness', 'charity', 'coddling', 'complaisance'],
    'indulgent': ['spartan', 'accepting', 'accommodating', 'accommodative', 'admissive', 'affable', 'agreeable', 'allowing', 'amiable', 'armed with patience', 'attentive', 'benevolent'],
    'indurate': ['anneal', 'backed', 'brutalize', 'cake', 'calcified', 'calcify', 'callous', 'calloused', 'case harden', 'case-hardened', 'concrete', 'congeal'],
    'indurated': ['philistine', 'backed', 'brazen', 'calcified', 'callous', 'calloused', 'case-hardened', 'conscienceless', 'crusted', 'crusty', 'crystallized', 'flinty'],
    'induration': ['philistinism', 'armor', 'callosity', 'callousness', 'callus', 'flintiness', 'formidable defenses', 'hard heart', 'hard shell', 'hardenedness', 'hardheartedness', 'hardness'],
    'industrial': ['business', 'commercial', 'creational', 'executional', 'fabricational', 'formational', 'functional', 'manufacturing', 'mercantile', 'merchant', 'official', 'pro'],
    'industrial park': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery', 'brewery', 'brickyard', 'cannery'],
    'industrial school': ['pow camp', 'bastille', 'black hole', 'borstal', 'borstal institution', 'borstal school', 'bridewell', 'brig', 'business college', 'cell', 'commercial school', 'concentration camp'],
    'industrialist': ['ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'banker', 'baron', 'begetter', 'beginner', 'big boss', 'big businessman'],
    'industrialize': ['accomplish', 'achieve', 'act', 'be productive', 'bring about', 'bring into being', 'bring to fruition', 'cause', 'commercialize', 'do', 'effectuate', 'engineer'],
    'industrials': ['assessable stock', 'authorized capital stock', 'blue chip', 'blue chip stock', 'borrowed stock', 'capital stock', 'common stock', 'convertible preferred stock', 'corporate stock', 'cumulative preferred stock', 'cyclical stock', 'defensive stock'],
    'industrious': ['active', 'aggressive', 'ardent', 'assiduous', 'busy', 'conscientious', 'constant', 'continuing', 'diligent', 'dogged', 'dynamic', 'elaborate'],
    'industriously': ['ardently', 'arduously', 'assiduously', 'bec et ongles', 'carefully', 'cautiously', 'circumspectly', 'considerately', 'devotedly', 'diligently', 'doggedly', 'effortfully'],
    'industry': ['aktiengesellschaft', 'activity', 'aktiebolag', 'application', 'ardor', 'assiduity', 'assiduousness', 'balance of trade', 'big business', 'body corporate', 'bulldog tenacity', 'business'],
    'indwelling': ['accessible', 'at hand', 'attendant', 'available', 'congenital', 'constitutional', 'deep-seated', 'esoteric', 'essential', 'essentiality', 'fundamentality', 'immanence'],
    'inebriant': ['john barleycorn', 'alcohol', 'alcoholic beverage', 'alcoholic drink', 'aqua vitae', 'ardent spirits', 'beverage', 'booze', 'brew', 'drink', 'grog', 'hard liquor'],
    'inebriate': ['addle', 'addled', 'alcoholic', 'alcoholic addict', 'bacchanal', 'bacchanalian', 'beery', 'befuddle', 'bemuse', 'bemused', 'besot', 'besotted'],
    'inebriation': ['dutch courage', 'a high', 'befuddlement', 'besottedness', 'drunkenness', 'fuddle', 'fuddledness', 'fuddlement', 'hangover', 'inebriety', 'insobriety', 'intoxication'],
    'ineducable': ['boeotian', 'asinine', 'beef-brained', 'beef-witted', 'blockish', 'bovine', 'chumpish', 'cloddish', 'cowish', 'crass', 'dense', 'doltish'],
    'ineffable': ['abstract', 'awesome', 'awful', 'celestial', 'divine', 'empyreal', 'empyrean', 'ethereal', 'exceptional', 'extraordinary', 'fabulous', 'heavenly'],
    'ineffective': ['abortive', 'aimless', 'barren', 'bootless', 'counterproductive', 'effete', 'emasculate', 'empty', 'etiolated', 'failed', 'failing', 'fatuitous'],
    'ineffectiveness': ['absurdity', 'aimlessness', 'bootlessness', 'counterproductiveness', 'counterproductivity', 'emptiness', 'failure', 'fatuity', 'fecklessness', 'forcelessness', 'fruitlessness', 'futility'],
    'ineffectual': ['abortive', 'acarpous', 'aimless', 'arid', 'barren', 'bootless', 'borne', 'celibate', 'childless', 'counterproductive', 'desert', 'desolate'],
    'ineffectuality': ['absurdity', 'aimlessness', 'bootlessness', 'counterproductiveness', 'counterproductivity', 'emptiness', 'failure', 'fatuity', 'fecklessness', 'forcelessness', 'fruitlessness', 'futility'],
    'inefficiency': ['disability', 'disablement', 'disqualification', 'imbecility', 'inability', 'inadeptness', 'inadequacy', 'inaptitude', 'inaptness', 'inattentiveness', 'incapability', 'incapacitation'],
    'inefficient': ['artless', 'careless', 'half-assed', 'inadept', 'inapt', 'inattentive', 'incapable', 'incapable of', 'incompetent', 'ineffective', 'ineffectual', 'inefficacious'],
    'inelastic': ['adamant', 'adamantine', 'cast-iron', 'dour', 'firm', 'flinty', 'grim', 'hard', 'hard-core', 'immovable', 'immutable', 'implacable'],
    'inelegance': ['babbittry', 'awkwardness', 'bad taste', 'boorishness', 'bourgeois taste', 'bumblingness', 'cacophony', 'camp', 'campiness', 'clownishness', 'clumsiness', 'cumbersomeness'],
    'inelegant': ['doric', 'all thumbs', 'awkward', 'barbaric', 'barbarous', 'beautiless', 'blemished', 'blotted', 'blunderheaded', 'blundering', 'boorish', 'bumbling'],
    'ineluctable': ['absolute', 'apodictic', 'bound', 'certain', 'clear', 'clear and distinct', 'clear as day', 'conclusive', 'decisive', 'definite', 'determinate', 'fated'],
    'inept': ['apish', 'artless', 'asinine', 'awkward', 'bad', 'batty', 'befooled', 'beguiled', 'besotted', 'brainless', 'buffoonish', 'bumbling'],
    'ineptitude': ['urdummheit', 'absurdity', 'asininity', 'awkwardness', 'battiness', 'brainlessness', 'buffoonery', 'clownishness', 'clumsiness', 'crackpottedness', 'crankiness', 'craziness'],
    'ineptly': ['impolitically', 'impoliticly', 'inadeptly', 'inadequately', 'inadvisably', 'inappropriately', 'inaptly', 'incapably', 'incompetently', 'incongruously', 'inefficiently', 'inexpediently'],
    'inequality': ['antagonism', 'argumentation', 'asperity', 'bias', 'bumpiness', 'capriciousness', 'changeability', 'changeableness', 'choppiness', 'clashing', 'conflict', 'contradiction'],
    'inequitable': ['arbitrary', 'bad', 'high-handed', 'illegal', 'iniquitous', 'oppressive', 'unbalanced', 'undeserved', 'undue', 'unequal', 'unequitable', 'uneven'],
    'inequity': ['asymmetry', 'contrariety', 'difference', 'disequilibrium', 'disparity', 'disproportion', 'heterogeneity', 'illegality', 'imbalance', 'improperness', 'impropriety', 'inadequacy'],
    'ineradicable': ['deathless', 'immortal', 'imperishable', 'impregnable', 'incorruptible', 'indelible', 'indestructible', 'ineffaceable', 'inexpugnable', 'inextinguishable', 'invincible', 'invulnerable'],
    'inerrant': ['accurate', 'close', 'constant', 'correct', 'delicate', 'dependable', 'direct', 'even', 'exact', 'express', 'faithful', 'fine'],
    'inert': ['abeyant', 'abiotic', 'apathetic', 'asleep', 'azoic', 'benumbed', 'blase', 'bored', 'cataleptic', 'catatonic', 'changeless', 'constant'],
    'inertia': ['a wise passiveness', 'abeyance', 'apathy', 'catalepsy', 'catatonia', 'cautiousness', 'circumspection', 'contemplation', 'contemplative life', 'creeping', 'deadliness', 'deathliness'],
    'inescapable': ['certain', 'fated', 'fateful', 'indefeasible', 'ineluctable', 'ineludible', 'inevasible', 'inevitable', 'inexorable', 'inflexible', 'irresistible', 'irrevocable'],
    'inestimable': ['beyond price', 'certain', 'dear', 'golden', 'good as gold', 'immeasurable', 'ineluctable', 'ineludible', 'inescapable', 'invaluable', 'measureless', 'necessary'],
    'inevitability': ['friday', 'friday the thirteenth', 'absolute certainty', 'absoluteness', 'act of god', 'appointed lot', 'assurance', 'assuredness', 'astral influences', 'astrology', 'book of fate', 'certain knowledge'],
    'inevitable': ['absolute', 'apodictic', 'appointed', 'binding', 'bound', 'certain', 'clear', 'clear and distinct', 'clear as day', 'compulsory', 'conclusive', 'decided'],
    'inevitably': ['accordingly', 'and so', 'as a consequence', 'as a result', 'certainly', 'consequently', 'fatefully', 'finally', 'inconsequence', 'indefeasibly', 'ineluctably', 'inescapably'],
    'inexact': ['adulterated', 'aleatoric', 'aleatory', 'amorphous', 'approximate', 'approximative', 'blemished', 'blobby', 'blurred', 'blurry', 'broad', 'chance'],
    'inexcitable': ['affectless', 'anesthetized', 'apathetic', 'arctic', 'arid', 'ataractic', 'autistic', 'aweless', 'barren', 'blah', 'blank', 'blase'],
    'inexcusable': ['blamable', 'blameworthy', 'censurable', 'impermissible', 'indefensible', 'inexpiable', 'intolerable', 'irremissible', 'reprehensible', 'unallowable', 'unconscionable', 'unforgivable'],
    'inexcusably': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly', 'damnably', 'deadly'],
    'inexhaustible': ['abounding', 'abundant', 'affluent', 'all-comprehensive', 'all-inclusive', 'all-sufficing', 'ample', 'aplenty', 'bottomless', 'boundless', 'bounteous', 'bountiful'],
    'inexorable': ['adamant', 'adamantine', 'bowelless', 'cast-iron', 'certain', 'cruel', 'dog-eat-dog', 'dogged', 'dour', 'fated', 'fateful', 'firm'],
    'inexpedience': ['bad policy', 'badness', 'callowness', 'childishness', 'damnability', 'evilness', 'immaturity', 'impolicy', 'improperness', 'impropriety', 'imprudence', 'inaccuracy'],
    'inexpedient': ['bad', 'black', 'criminal', 'evil', 'futile', 'ill', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-gauged', 'ill-judged'],
    'inexpensive': ['budget', 'cheap', 'easy', 'economic', 'economical', 'economy', 'frugal', 'low', 'low-priced', 'manageable', 'moderate', 'modest'],
    'inexperience': ['agnosticism', 'amateurishness', 'amateurism', 'blankmindedness', 'callowness', 'dewiness', 'disaccustomedness', 'empty-headedness', 'freshness', 'greenhornism', 'greenness', 'hiatus of learning'],
    'inexperienced': ['a novice at', 'a stranger to', 'artless', 'awkward', 'befoolable', 'blankminded', 'born yesterday', 'budding', 'callow', 'dewy', 'disaccustomed', 'dumb'],
    'inexpert': ['artless', 'half-assed', 'inadept', 'inapt', 'inattentive', 'inefficient', 'inept', 'mediocre', 'pedestrian', 'poor', 'skill-less', 'thoughtless'],
    'inexplicable': ['aimless', 'baffling', 'bewildering', 'casual', 'causeless', 'confounding', 'designless', 'driftless', 'dysteleological', 'enigmatic', 'enwrapped in mystery', 'haphazard'],
    'inexpressible': ['awesome', 'awful', 'divine', 'heavenly', 'holy', 'incommunicable', 'indefinable', 'indescribable', 'ineffable', 'inenarrable', 'innominable', 'inviolable'],
    'inextensible': ['adamant', 'adamantine', 'immovable', 'immutable', 'inductile', 'inelastic', 'inextensile', 'inextensional', 'inflexible', 'intractable', 'intractile', 'irresilient'],
    'inextinguishable': ['deathless', 'enduring', 'eternal', 'everlasting', 'immortal', 'imperishable', 'impregnable', 'incorruptible', 'indelible', 'indestructible', 'ineffaceable', 'ineradicable'],
    'inextricable': ['aground', 'anchored', 'caught', 'chained', 'enwrapped in mystery', 'fast', 'fastened', 'fixed', 'grounded', 'held', 'high and dry', 'impacted'],
    'infallibility': ['absolute certainty', 'absoluteness', 'assurance', 'assuredness', 'certain knowledge', 'certainness', 'certainty', 'certitude', 'chastity', 'dead certainty', 'defectlessness', 'definiteness'],
    'infallible': ['absolute', 'acceptable', 'agreeable', 'beyond all praise', 'certain', 'chaste', 'close', 'constant', 'correct', 'defectless', 'delicate', 'dependable'],
    'infamous': ['aberrant', 'abhorrent', 'abnormal', 'abominable', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beneath contempt', 'black'],
    'infamously': ['abominably', 'atrociously', 'awfully', 'basely', 'bestially', 'brutally', 'contemptibly', 'criminally', 'crookedly', 'deceitfully', 'despicably', 'detestably'],
    'infamy': ['abhorrence', 'abomination', 'atrocity', 'bad', 'degradation', 'demotion', 'depluming', 'desecration', 'detestation', 'discredit', 'disesteem', 'disgrace'],
    'infancy': ['babyhood', 'beginnings', 'birth', 'callowness', 'childhood', 'commencement', 'cradle', 'dawn', 'dewiness', 'disability', 'disablement', 'disqualification'],
    'infant': ['abecedarian', 'aboriginal', 'adolescent', 'angel', 'antenatal', 'apprentice', 'arrested', 'autochthonous', 'babe', 'babish', 'baby', 'baby bunting'],
    'infantile': ['abecedarian', 'aboriginal', 'antenatal', 'autochthonous', 'babish', 'baby', 'babyish', 'beginning', 'budding', 'childish', 'childlike', 'creative'],
    'infantile paralysis': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'apoplexy'],
    'infantilism': ['amentia', 'arrested development', 'babyishness', 'backwardness', 'blithering idiocy', 'childishness', 'cretinism', 'half-wittedness', 'idiocy', 'idiotism', 'imbecility', 'immaturity'],
    'infantryman': ['zouave', 'ambulator', 'backpacker', 'bersagliere', 'carabineer', 'chasseur', 'dogface', 'doughfoot', 'expert rifleman', 'foot passenger', 'foot soldier', 'foot traveler'],
    'infarction': ['bar', 'barrier', 'blank wall', 'blind alley', 'blind gut', 'block', 'blockade', 'blockage', 'bottleneck', 'cecum', 'choking', 'choking off'],
    'infatuate': ['addict', 'admirer', 'adorer', 'aficionado', 'allure', 'amorist', 'attract', 'becharm', 'befool', 'beguile', 'beset', 'besotted'],
    'infatuated': ['apish', 'asinine', 'at fever pitch', 'batty', 'becharmed', 'befooled', 'beguiled', 'besotted', 'bewitched', 'brainless', 'buffoonish', 'captivated'],
    'infatuation': ['affection', 'ardor', 'blind faith', 'bug', 'calf love', 'case', 'craze', 'crazy fancy', 'credulity', 'credulousness', 'crush', 'devotion'],
    'infect': ['abuse', 'activate', 'adulterate', 'afflict', 'aggrieve', 'alloy', 'animate', 'befoul', 'benasty', 'bewitch', 'blight', 'canker'],
    'infected': ['activated', 'autoluminescent', 'bad', 'cankered', 'charged', 'contaminated', 'corrupted', 'diseased', 'gangrened', 'gangrenous', 'hot', 'impure'],
    'infection': ['abomination', 'adulteration', 'aerial infection', 'afflatus', 'airborne infection', 'animating spirit', 'animation', 'animus', 'atrocity', 'bad', 'bane', 'befouling'],
    'infectious': ['catching', 'communicable', 'contagious', 'deadly', 'destructive', 'endemic', 'envenomed', 'epidemial', 'epidemic', 'epiphytotic', 'epizootic', 'infective'],
    'infectious disease': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'cardiovascular disease'],
    'infecund': ['acarpous', 'arid', 'barren', 'celibate', 'childless', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'dull', 'earthbound'],
    'infelicitous': ['doric', 'bad', 'barbaric', 'barbarous', 'cacophonous', 'careless', 'clumsy', 'coarse', 'crude', 'doggerel', 'dysphemistic', 'erroneous'],
    'infelicity': ['gothicism', 'abnormality', 'aching heart', 'agony', 'agony of mind', 'anguish', 'anomaly', 'antiphrasis', 'bad taste', 'bale', 'barbarism', 'barbarousness'],
    'infer': ['allegorize', 'allude to', 'analyze', 'apply reason', 'assume', 'be afraid', 'believe', 'bring to mind', 'collect', 'conceive', 'conclude', 'connote'],
    'inference': ['baconian method', 'a fortiori reasoning', 'a posteriori reasoning', 'a priori reasoning', 'allegory', 'allusion', 'analysis', 'arcane meaning', 'assumption', 'axiom', 'coloration', 'conclusion'],
    'inferential': ['a fortiori', 'a posteriori', 'a priori', 'allusive', 'allusory', 'analytic', 'categorical', 'conditional', 'deductive', 'dialectic', 'discursive', 'enthymematic'],
    'inferior': ['mickey mouse', 'adherent', 'assistant', 'attendant', 'auxiliary', 'average', 'back-burner', 'bad', 'base', 'black', 'bootlicker', 'cheap'],
    'inferiority': ['aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'amorphism', 'anomalism', 'anomalousness', 'anomaly', 'arrear', 'arrearage', 'arrears'],
    'infernal': ['acherontic', 'draconian', 'hadean', 'lethean', 'mephistophelian', 'plutonian', 'plutonic', 'stygian', 'tartarean', 'absolute', 'animal', 'anthropophagous'],
    'inferno': ['abaddon', 'gehenna', 'hades', 'naraka', 'pandemonium', 'sheol', 'tophet', 'torrid zone', 'abyss', 'avichi', 'blazes', 'conflagration'],
    'inferred': ['accounted as', 'alleged', 'assumed', 'assumptive', 'conjectured', 'deemed', 'given', 'granted', 'hinted', 'implicated', 'implicit', 'implied'],
    'infertile': ['acarpous', 'arid', 'barren', 'celibate', 'childless', 'depleted', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'dull'],
    'infertility': ['aridity', 'aridness', 'barrenness', 'birth control', 'contraception', 'dearth', 'dearth of ideas', 'dry womb', 'dryness', 'dullness', 'family planning', 'famine'],
    'infest': ['beset', 'crawl with', 'creep with', 'flood', 'infiltrate', 'inundate', 'invade', 'overrun', 'overspread', 'overswarm', 'penetrate', 'permeate'],
    'infidel': ['agnostic', 'atheist', 'atheistic', 'disbeliever', 'disbelieving', 'ethnic', 'faithless', 'freethinker', 'gentile', 'giaour', 'goy', 'goyish'],
    'infidelity': ['punic faith', 'adulterous affair', 'adultery', 'affair', 'agnosticism', 'amor', 'amour', 'apostasy', 'atheism', 'bad faith', 'barratry', 'breach of faith'],
    'infield': ['archery ground', 'athletic field', 'badminton court', 'baseball field', 'basketball court', 'billiard parlor', 'bowling alley', 'bowling green', 'course', 'court', 'cricket ground', 'croquet ground'],
    'infighting': ['chinese boxing', 'aggressiveness', 'bellicosity', 'belligerence', 'bickering', 'bout', 'boxing', 'boxing match', 'close fighting', 'combativeness', 'contentiousness', 'dissension'],
    'infiltrate': ['absorb', 'adsorb', 'advance against', 'advance upon', 'assimilate', 'barge in', 'bathe', 'bear down upon', 'besprinkle', 'blot', 'blot up', 'break in'],
    'infiltration': ['absorbency', 'absorbent', 'absorption', 'access', 'admission', 'adsorbent', 'adsorption', 'aerial tactics', 'aggravated assault', 'aggression', 'airborne tactics', 'amphibious attack'],
    'infinite': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'ageless', 'algorismic', 'algorithmic', 'aliquot', 'all-comprehensive'],
    'infinitely': ['a outrance', 'abroad', 'absolutely', 'abundantly', 'acervatim', 'ad infinitum', 'all out', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure', 'boundlessly'],
    'infinitesimal': ['atomic', 'corpuscular', 'embryonic', 'evanescent', 'germinal', 'granular', 'impalpable', 'imperceptible', 'imponderable', 'inappreciable', 'indiscernible', 'intangible'],
    'infinity': ['gaussian integer', 'aesthetic distance', 'algebraic number', 'ampleness', 'amplitude', 'astronomical number', 'billion', 'boundlessness', 'bulk', 'cardinal', 'cardinal number', 'ceaselessness'],
    'infirm': ['adamic', 'abulic', 'adrift', 'afloat', 'afraid', 'ailing', 'alternating', 'amorphous', 'anile', 'backsliding', 'cachectic', 'capricious'],
    'infirmary': ['va hospital', 'asylum', 'base hospital', 'clinic', 'community hospital', 'convalescent home', 'convalescent hospital', 'dispensary', 'evacuation hospital', 'field hospital', 'general hospital', 'home'],
    'infirmity': ['abnormality', 'abulia', 'acute disease', 'advanced age', 'advanced years', 'affection', 'affliction', 'age of retirement', 'ailment', 'allergic disease', 'allergy', 'an incurable disease'],
    'infix': ['ic analysis', 'accidence', 'add', 'adjoin', 'affix', 'affixation', 'agglutinate', 'allomorph', 'allonge', 'annex', 'append', 'appendix'],
    'infixed': ['chronic', 'confirmed', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid', 'deep-rooted', 'deep-seated', 'deep-set', 'deep-settled', 'dyed-in-the-wool'],
    'inflame': ['afflict', 'aggravate', 'agitate', 'agonize', 'ail', 'anger', 'animate', 'annoy', 'arouse', 'augment', 'awake', 'awaken'],
    'inflamed': ['titian', 'titian-red', 'ablaze', 'afire', 'aflame', 'aflicker', 'aglow', 'agog', 'algetic', 'alight', 'angry', 'aquiver'],
    'inflammable': ['accendible', 'agitable', 'alcohol', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coke', 'combustible'],
    'inflammation': ['abscess', 'adenoiditis', 'adrenitis', 'aggravation', 'agitation', 'ague', 'algesia', 'anemia', 'animation', 'ankylosis', 'anoxia', 'apnea'],
    'inflammatory': ['agitating', 'agitational', 'agitative', 'breathtaking', 'charged', 'cliff-hanging', 'disquieting', 'distracting', 'disturbing', 'electric', 'enkindling', 'exciting'],
    'inflate': ['barnumize', 'add to', 'aggrandize', 'amplify', 'augment', 'balloon', 'bloat', 'blow', 'blow up', 'bombast', 'boost', 'broaden'],
    'inflated': ['accelerated', 'aggrandized', 'amplified', 'augmented', 'aureate', 'ballyhooed', 'beefed-up', 'big', 'bloated', 'blown up', 'bombastic', 'boosted'],
    'inflation': ['barnumism', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'affectation', 'aggrandizement', 'amplification'],
    'inflationary': ['cutthroat', 'dilatant', 'distensive', 'elastic', 'exacting', 'excessive', 'exorbitant', 'expansible', 'expansile', 'expansional', 'expansive', 'extensile'],
    'inflationary spiral': ['big price tag', 'bottom price', 'business index', 'ceiling', 'ceiling price', 'consumer price index', 'cost-of-living index', 'demand curve', 'extortionate price', 'famine price', 'fancy price', 'floor'],
    'inflect': ['analyze', 'arch', 'bend', 'bend back', 'bow', 'bracket', 'conjugate', 'crook', 'curl', 'curve', 'decline', 'decurve'],
    'inflection': ['ic analysis', 's-curve', 'accent', 'accidence', 'affix', 'affixation', 'allomorph', 'angle', 'apex', 'articulation', 'bend', 'bending'],
    'inflexibility': ['act of god', 'adamantness', 'certainty', 'concentration', 'constancy', 'dourness', 'fate', 'fatefulness', 'firmness', 'firmness of mind', 'fixedness', 'flintiness'],
    'inflexible': ['adamant', 'adamantine', 'at a standstill', 'cast-iron', 'certain', 'changeless', 'closed to', 'constant', 'determinate', 'determined', 'dogged', 'dour'],
    'inflict': ['accomplish', 'achieve', 'administer', 'afflict', 'apply', 'bring', 'bring about', 'bring off', 'bring to pass', 'bring upon', 'burden with', 'charge'],
    'infliction': ['affliction', 'bane', 'bitter cup', 'bitter draft', 'bitter draught', 'bitter pill', 'bother', 'bugbear', 'burden', 'burden of care', 'burdening', 'calamity'],
    'inflow': ['affluence', 'afflux', 'affluxion', 'air current', 'concourse', 'confluence', 'conflux', 'course', 'crosscurrent', 'current', 'current of air', 'defluxion'],
    'influence': ['rasputin', 'svengali', 'vip', 'access', 'acme', 'act on', 'act upon', 'actuation', 'advance', 'affect', 'alter', 'amperage'],
    'influence peddler': ['machiavel', 'machiavellian', 'machiavellianist', 'rasputin', 'svengali', 'vip', 'access', 'bad influence', 'big wheel', 'boodler', 'court', 'crooked politician'],
    'influential': ['absolute', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'charismatic', 'charming', 'clothed with authority', 'commanding', 'competent', 'consequential'],
    'influenza': ['african lethargy', 'asiatic cholera', 'asiatic flu', 'chagres fever', 'german measles', 'haverhill fever', 'hong kong flu', 'acute articular rheumatism', 'acute bronchitis', 'adenoiditis', 'ague', 'alkali disease'],
    'influx': ['accession', 'affluence', 'afflux', 'affluxion', 'augmentation', 'encroachment', 'entrance', 'entrenchment', 'impingement', 'imposition', 'increase', 'incursion'],
    'info': ['account', 'acquaintance', 'announcement', 'blue book', 'briefing', 'bulletin', 'communication', 'communique', 'data', 'datum', 'directory', 'dispatch'],
    'inform': ['acquaint', 'advertise', 'advertise of', 'advise', 'animate', 'announce', 'apprise', 'babble', 'be indiscreet', 'be unguarded', 'betray', 'betray a confidence'],
    'inform on': ['accuse', 'allege', 'arraign', 'article', 'babble', 'be indiscreet', 'be unguarded', 'bear witness against', 'betray', 'betray a confidence', 'blab', 'blabber'],
    'informal': ['bohemian', 'affable', 'beat', 'beat-up', 'bedraggled', 'blowzy', 'breakaway', 'careless', 'casual', 'chintzy', 'colloquial', 'common'],
    'informant': ['adviser', 'announcer', 'annunciator', 'attestant', 'attestator', 'attester', 'authority', 'bystander', 'channel', 'cojuror', 'communicant', 'communicator'],
    'information': ['algol', 'cobol', 'esp', 'fortran', 'accusal', 'accusation', 'accusing', 'acquaintance', 'advice', 'allegation', 'allegement', 'alphabetic data'],
    'information theory': ['edp', 'automatic electronics', 'autonetics', 'bionics', 'bit', 'channel', 'circuit analysis', 'communication engineering', 'communication explosion', 'communication technology', 'communication theory', 'communications'],
    'informative': ['advisory', 'autodidactic', 'coeducational', 'communicative', 'cultural', 'didactic', 'disciplinary', 'edifying', 'educating', 'educational', 'educative', 'elucidative'],
    'informed': ['abreast', 'abreast of', 'acquainted', 'advised', 'all ready', 'all set', 'armed', 'armed and ready', 'au courant', 'au fait', 'aware of', 'booted and spurred'],
    'informed of': ['alive to', 'appreciative of', 'apprised of', 'awake to', 'aware of', 'behind the curtain', 'behind the scenes', 'cognizant of', 'conscious of', 'hep to', 'in the know', 'in the secret'],
    'informer': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'quisling', 'accusant', 'accuser', 'adviser', 'allegator', 'announcer', 'annunciator', 'appellant'],
    'infraction': ['aberrance', 'aberrancy', 'abnormality', 'bad faith', 'breach', 'breach of contract', 'breach of faith', 'breach of law', 'breach of privilege', 'breach of promise', 'breach of trust', 'breaking'],
    'infrangible': ['chip-proof', 'coherent', 'cohesive', 'firm', 'firm as gibraltar', 'fractureproof', 'impartible', 'indiscerptible', 'indissoluble', 'indissolvable', 'indivisible', 'infusible'],
    'infrastructure': ['base'],
    'infrequency': ['chinchiness', 'chintziness', 'exiguity', 'fewness', 'meagerness', 'miserliness', 'niggardliness', 'paucity', 'rarity', 'restrictedness', 'scantiness', 'scarcity'],
    'infrequent': ['almost unheard-of', 'cheeseparing', 'chinchy', 'chintzy', 'exiguous', 'meager', 'miserly', 'niggardly', 'piddling', 'poor', 'rare', 'scant'],
    'infrequently': ['at infrequent intervals', 'at intervals', 'brokenly', 'by catches', 'by fits', 'by jerks', 'by skips', 'by snatches', 'disconnectedly', 'discontinuously', 'exceptionally', 'exiguously'],
    'infringe': ['adopt', 'advance upon', 'appropriate', 'arrogate', 'assume', 'barge in', 'breach', 'breach the law', 'break', 'break bounds', 'break in', 'break in upon'],
    'infringement': ['adoption', 'appropriation', 'arrogation', 'assumption', 'bad faith', 'bankruptcy', 'borrowed plumes', 'breach', 'breach of contract', 'breach of faith', 'breach of law', 'breach of privilege'],
    'infundibular': ['boat-shaped', 'boatlike', 'bowl-shaped', 'bowllike', 'cavelike', 'cavernous', 'concave', 'concaved', 'cone-shaped', 'coned', 'conelike', 'conic'],
    'infuriate': ['aggravate', 'agitate', 'alienate', 'anger', 'annoy', 'antagonize', 'arouse', 'awake', 'awaken', 'blow the coals', 'blow up', 'bother'],
    'infuse': ['animate', 'bathe', 'beat into', 'besprinkle', 'brainwash', 'breathe', 'brew', 'catechize', 'colliquate', 'color', 'concentrate', 'condition'],
    'infusion': ['absorption and regurgitation', 'afflatus', 'affusion', 'animating spirit', 'animation', 'animus', 'aspergation', 'aspersion', 'baptism', 'baptismal gown', 'baptismal regeneration', 'baptistery'],
    'ingenious': ['daedalian', 'machiavellian', 'machiavellic', 'acute', 'adept', 'adroit', 'apt', 'arch', 'artful', 'artistic', 'astute', 'authoritative'],
    'ingenue': ['roscius', 'actor', 'actress', 'antagonist', 'antihero', 'babe', 'bad guy', 'barnstormer', 'bit', 'bit part', 'cast', 'character'],
    'ingenuity': ['ability', 'acuteness', 'address', 'adeptness', 'adroitness', 'airmanship', 'aptness', 'art', 'artfulness', 'artisanship', 'artistry', 'bravura'],
    'ingenuous': ['artless', 'bluff', 'blunt', 'bold', 'born yesterday', 'broad', 'brusque', 'budding', 'callow', 'candid', 'childlike', 'confiding'],
    'ingest': ['ablate', 'absorb', 'assimilate', 'bleed white', 'burn up', 'consume', 'deplete', 'devour', 'digest', 'dispatch', 'dispose of', 'down'],
    'ingesta': ['board', 'bread', 'bread and butter', 'cheer', 'comestibles', 'creature comfort', 'cuisine', 'daily bread', 'eatables', 'edibles', 'fare', 'fast food'],
    'ingestion': ['ablation', 'absorption', 'appetite', 'assimilation', 'attrition', 'bile', 'burning up', 'cannibalism', 'carnivorism', 'carnivority', 'carnivorousness', 'chewing'],
    'ingle': ['ancestral halls', 'backfire', 'balefire', 'beacon', 'beacon fire', 'blaze', 'bonfire', 'burning ghat', 'campfire', 'cheerful fire', 'chimney', 'chimney corner'],
    'inglorious': ['derogatory', 'discreditable', 'disgraceful', 'dishonorable', 'disreputable', 'homely', 'humble', 'humble-looking', 'humble-visaged', 'humblest', 'ignoble', 'ignominious'],
    'ingoing': ['access', 'admission', 'biting', 'clear-cut', 'crisp', 'cutting', 'entering', 'entrance', 'entree', 'entry', 'import', 'importation'],
    'ingot': ['bar', 'billet', 'bullion', 'button', 'cast', 'casting', 'coin gold', 'coin silver', 'copper', 'gate', 'gold', 'gold nugget'],
    'ingrain': ['apply paint', 'bed', 'bedaub', 'bedizen', 'begild', 'besmear', 'brush on paint', 'calcimine', 'coat', 'color', 'complexion', 'confirm'],
    'ingrained': ['basic', 'chronic', 'colorfast', 'confirmed', 'congenital', 'constant', 'constitutional', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid'],
    'ingratiating': ['abject', 'adulatory', 'apple-polishing', 'backscratching', 'beggarly', 'bland', 'bootlicking', 'brown-nosing', 'buttery', 'cajoling', 'cowering', 'crawling'],
    'ingredient': ['adjunct', 'appurtenance', 'aspect', 'census', 'circumstance', 'component', 'composition', 'constituent', 'constituents', 'content', 'contents', 'detail'],
    'ingress': ['access', 'adit', 'admission', 'admittance', 'air lock', 'approach', 'channel', 'come in', 'conduit', 'corridor', 'course', 'ditch'],
    'ingroup': ['rasputin', 'svengali', 'vip', 'access', 'age group', 'bad influence', 'band', 'battalion', 'bevy', 'big wheel', 'body', 'brigade'],
    'ingrown': ['confirmed', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid', 'deep-rooted', 'deep-seated', 'deep-set', 'deep-settled', 'dyed-in-the-wool', 'embedded'],
    'inhabit': ['abide', 'abide in', 'anchor', 'be coextensive with', 'be comprised in', 'be constituted by', 'be contained in', 'be present in', 'berth', 'billet at', 'bivouac', 'bunk'],
    'inhabitant': ['aborigine', 'addressee', 'artist-in-residence', 'autochthon', 'citizen', 'citizenry', 'commonwealth', 'community', 'constituency', 'cultural community', 'denizen', 'dweller'],
    'inhalant': ['balm', 'balsam', 'drops', 'drug', 'electuary', 'elixir', 'ethical drug', 'generic name', 'herbs', 'lincture', 'linctus', 'materia medica'],
    'inhalation': ['aqua-lung', 'air current', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'breath', 'breath of air', 'breathing', 'broken wind', 'cough', 'crosscurrent', 'current'],
    'inhalator': ['aqua-lung', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'breath', 'breath of air', 'breathing', 'broken wind', 'cough', 'exhalation', 'expiration', 'exsufflation'],
    'inhale': ['aspirate', 'blow', 'breathe', 'breathe hard', 'breathe in', 'breathe out', 'chain-smoke', 'chaw', 'chew', 'cough', 'drag', 'draw'],
    'inharmonious': ['absonant', 'antagonistic', 'antipathetic', 'assorted', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'atonal', 'cacophonic', 'cacophonous'],
    'inhere': ['abide in', 'be born so', 'be coextensive with', 'be comprised in', 'be constituted by', 'be contained in', 'be found', 'be located', 'be met with', 'be present', 'be present in', 'be situated'],
    'inherence': ['accessibility', 'actual presence', 'availability', 'being here', 'being there', 'essentiality', 'existence', 'fundamentality', 'hereness', 'immanence', 'immediacy', 'inbeing'],
    'inherent': ['accessible', 'at hand', 'attendant', 'automatic', 'available', 'basic', 'born', 'characteristic', 'congenital', 'connate', 'constitutional', 'deep-seated'],
    'inheritance': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory', 'allele'],
    'inherited': ['atavistic', 'bodily', 'born', 'coeval', 'congenital', 'connatal', 'connate', 'connatural', 'constitutional', 'genetic', 'genic', 'hereditary'],
    'inheritor': ['apparent heir', 'backup man', 'beneficiary heir', 'breed', 'brood', 'children', 'coparcener', 'descendant', 'descendants', 'descent', 'family', 'fideicommissary heir'],
    'inhibit': ['arrest', 'avert', 'ban', 'bar', 'bit', 'bottle up', 'box up', 'bridle', 'cage', 'check', 'cloister', 'confine'],
    'inhibited': ['abashed', 'arrested', 'bridled', 'cold', 'constrained', 'controlled', 'curbed', 'embarrassed', 'guarded', 'in check', 'in leading strings', 'in remission'],
    'inhibiting': ['choking', 'constraining', 'constrictive', 'contrary', 'counterproductive', 'crosswise', 'hindering', 'hindersome', 'in the way', 'inhibitive', 'interrupting', 'interruptive'],
    'inhibition': ['eighteenth amendment', 'prohibition party', 'volstead act', 'arrest', 'arrestation', 'arrestment', 'ban', 'bar', 'barrier', 'block', 'blockage', 'blocking'],
    'inhibitive': ['choking', 'constraining', 'constrictive', 'contrary', 'counterproductive', 'crosswise', 'exclusive', 'forbidding', 'hindering', 'hindersome', 'in the way', 'inhibiting'],
    'inhospitable': ['chill', 'chilly', 'closed', 'cold', 'cool', 'disaccordant', 'disagreeable', 'frosty', 'icy', 'ill', 'incompatible', 'inimical'],
    'inhuman': ['draconian', 'tartarean', 'animal', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bestial', 'bloodthirsty', 'bloody', 'bloody-minded'],
    'inhumanity': ['acuteness', 'animality', 'atrociousness', 'atrocity', 'barbarity', 'barbarousness', 'beastliness', 'bestiality', 'bloodiness', 'bloodlust', 'bloodthirst', 'bloodthirstiness'],
    'inhume': ['bury', 'coffin', 'conduct a funeral', 'encoffin', 'ensepulcher', 'enshrine', 'entomb', 'hearse', 'inearth', 'inter', 'inurn', 'lay away'],
    'inimical': ['adversary', 'adversative', 'adverse', 'adversive', 'aggressive', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'antonymous', 'at cross-purposes'],
    'inimitable': ['beyond compare', 'beyond comparison', 'easily first', 'facile princeps', 'immortal', 'incomparable', 'invincible', 'matchless', 'nulli secundus', 'peerless', 'second to none', 'sui generis'],
    'iniquitous': ['abominable', 'arrant', 'atrocious', 'bad', 'baleful', 'base', 'bitchy', 'black', 'blamable', 'blameworthy', 'criminal', 'cussed'],
    'iniquity': ['abomination', 'atrocity', 'bad', 'breach', 'crime', 'crime against humanity', 'deadly sin', 'delinquency', 'dereliction', 'diablerie', 'disgrace', 'enormity'],
    'initial': ['ok', 'abecedarian', 'aboriginal', 'accept', 'accredit', 'affirm', 'alpha', 'alphabet', 'alphabetize', 'amen', 'antecedent', 'antenatal'],
    'initially': ['ab initio', 'ab ovo', 'aborigine', 'at first', 'at the start', 'before everything', 'chiefly', 'first', 'first and foremost', 'first thing', 'firstly', 'from the beginning'],
    'initials': ['id card', 'john hancock', 'autograph', 'badge', 'calligram', 'calling card', 'card', 'christcross', 'cipher', 'countermark', 'countersign', 'countersignature'],
    'initiate': ['greek', 'abecedarian', 'accept', 'accomplished', 'activate', 'actuate', 'admit', 'affiliate', 'alphabetarian', 'apprentice', 'articled clerk', 'associate'],
    'initiation': ['abecedarium', 'abecedary', 'acceptance', 'admission', 'admittance', 'anchorage', 'and arithmetic', 'baccalaureate service', 'baptism', 'beginning', 'celebration', 'ceremonial'],
    'initiative': ['abecedarian', 'aboriginal', 'adventuresomeness', 'adventurousness', 'aggression', 'aggressiveness', 'alpha', 'ambition', 'ambitiousness', 'antenatal', 'autochthonous', 'bang'],
    'initiator': ['ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner', 'builder', 'conceiver', 'constructor', 'craftsman'],
    'initiatory': ['abecedarian', 'aboriginal', 'antecedent', 'antenatal', 'anterior', 'autochthonous', 'autodidactic', 'baptismal', 'beginning', 'budding', 'chief', 'coeducational'],
    'inject': ['animate', 'bathe', 'brew', 'bring in', 'douche', 'drench', 'drive in', 'drouk', 'ease in', 'embue', 'enliven', 'exhilarate'],
    'inject in': ['drag in', 'edge in', 'foist in', 'fudge in', 'implant in', 'insert in', 'insinuate in', 'intercalate', 'interjaculate', 'interject', 'interpolate', 'interpose'],
    'injection': ['earth insertion', 'lem', 'lm', 'antitoxin', 'apogee', 'aside', 'attitude-control rocket', 'bag', 'ballistic capsule', 'bang', 'booster', 'booster dose'],
    'injudicious': ['brash', 'brazen', 'brazenfaced', 'hubristic', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-gauged', 'ill-judged', 'impolitic', 'improvident'],
    'injunction': ['eighteenth amendment', 'prohibition party', 'volstead act', 'admonition', 'arrest', 'arrestation', 'ban', 'bar', 'barring', 'behest', 'bench warrant', 'bidding'],
    'injure': ['abrade', 'abuse', 'afflict', 'affront', 'aggravate', 'aggrieve', 'bark', 'batter', 'befoul', 'bespatter', 'bewitch', 'blemish'],
    'injured': ['aching', 'aggravated', 'aggrieved', 'anguished', 'bleeding', 'broken', 'bruised', 'burned', 'burst', 'busted', 'checked', 'chipped'],
    'injurious': ['abusive', 'adverse', 'bad', 'bad for', 'baleful', 'baneful', 'calumnious', 'contaminated', 'contemptuous', 'corroding', 'corrosive', 'corrupting'],
    'injury': ['abomination', 'abrasion', 'abuse', 'ache', 'aching', 'affront', 'agony', 'aspersion', 'atrocity', 'bad', 'bane', 'bankruptcy'],
    'injustice': ['abstractionism', 'asymmetry', 'atrocity', 'bias', 'bigotry', 'breach', 'coloring', 'contrariety', 'crime', 'crime against humanity', 'damage', 'deadly sin'],
    'ink': ['autograph', 'ballpoint pen', 'bedarken', 'besmirch', 'black', 'blackboard', 'blacken', 'blackwash', 'blot', 'blotch', 'chalk', 'charcoal'],
    'inkblot test': ['binet-simon test', 'brown personality inventory', 'goldstein-sheerer test', 'iq', 'iq test', 'kent mental test', 'minnesota preschool scale', 'oseretsky test', 'rorschach test', 'stanford revision', 'stanford-binet test', 'szondi test'],
    'inkling': ['bare suggestion', 'broad hint', 'clue', 'cue', 'dash', 'gentle hint', 'gesture', 'glimmer', 'glimmering', 'half an idea', 'hazy idea', 'hint'],
    'inky': ['atramentous', 'besmirched', 'black', 'black as coal', 'black as ebony', 'black as ink', 'black as midnight', 'black as night', 'blackened', 'coal-black', 'coaly', 'dark'],
    'inland': ['heartland', 'hinterland', 'home', 'inlands', 'inshore', 'interior', 'internal', 'intestine', 'inward', 'inwardly', 'inwards', 'mediterranean'],
    'inlay': ['bed', 'bed in', 'bush', 'bushing', 'ceil', 'doubling', 'doublure', 'embed', 'face', 'facing', 'feather', 'fill'],
    'inlet': ['access', 'adit', 'air lock', 'aisle', 'alley', 'ambulatory', 'aperture', 'approach', 'arcade', 'arm', 'artery', 'avenue'],
    'inmate': ['addressee', 'artist-in-residence', 'captive', 'case', 'convict', 'denizen', 'dweller', 'habitant', 'house detective', 'incumbent', 'inhabitant', 'inhabiter'],
    'inmost': ['anonymous', 'central', 'closet', 'deep', 'incognito', 'indoor', 'inner', 'innermost', 'inside', 'interior', 'internal', 'intestine'],
    'inn': ['boardinghouse', 'dorm', 'dormitory', 'doss house', 'fleabag', 'flophouse', 'guest house', 'hospice', 'hostel', 'hostelry', 'hotel', 'lodge'],
    'innards': ['abdomen', 'action', 'anus', 'appendix', 'blind gut', 'bowels', 'brain', 'cecum', 'census', 'clockworks', 'colon', 'composition'],
    'innate': ['atavistic', 'automatic', 'bodily', 'born', 'coeval', 'congenital', 'connatal', 'connate', 'connatural', 'constitutional', 'deep-seated', 'elemental'],
    'inner': ['absolute', 'central', 'certain', 'close', 'concealed', 'concrete', 'constitutional', 'deep', 'deep-seated', 'defined', 'definite', 'detailed'],
    'inner circle': ['bunch', 'bureaucracy', 'cabal', 'cadre', 'camarilla', 'cell', 'charmed circle', 'circle', 'clan', 'clique', 'closed circle', 'coterie'],
    'inner directed': ['actuated', 'animated', 'autarchic', 'autarkic', 'autonomous', 'free-spirited', 'freewheeling', 'heretical', 'heterodox', 'impelled', 'inclined', 'independent'],
    'inner man': ['i myself', 'alter', 'alter ego', 'alterum', 'anima', 'anima humana', 'atman', 'ba', 'better self', 'bosom', 'breast', 'breath'],
    'inner nature': ['bosom', 'breast', 'center', 'center of life', 'core', 'deepest recesses', 'esoteric reality', 'heart', 'heart of hearts', 'inmost heart', 'inmost soul', 'inner'],
    'innermost': ['anonymous', 'central', 'closet', 'deep', 'incognito', 'indoor', 'inmost', 'inner', 'inside', 'interior', 'internal', 'intestine'],
    'innocence': ['agnosticism', 'artlessness', 'benignancy', 'benignity', 'blankmindedness', 'blotlessness', 'bluffness', 'bluntness', 'callowness', 'candor', 'chastity', 'childlikeness'],
    'innocent': ['above suspicion', 'angel', 'angelic', 'artless', 'awkward', 'babe', 'bairn', 'beginner', 'benign', 'blameless', 'blankminded', 'blotless'],
    'innocuous': ['benign', 'harmless', 'homely', 'humble', 'humble-looking', 'humble-visaged', 'humblest', 'inglorious', 'innocent', 'inoffensive', 'least', 'low'],
    'innovation': ['advance guard', 'alteration', 'archetype', 'authenticity', 'avant-garde', 'breakthrough', 'coinage', 'creativeness', 'creativity', 'deviation', 'discovery', 'freshness'],
    'innovative': ['original', 'modern', 'advanced', 'forward-looking', 'innovational', 'progressive'],
    'innovator': ['agent', 'alterant', 'alterative', 'alterer', 'ancestor', 'announcer', 'antecedent', 'architect', 'author', 'avant-garde', 'bellwether', 'buccinator'],
    'innuendo': ['accusal', 'accusation', 'accusing', 'allegation', 'allegement', 'allegory', 'allusion', 'animadversion', 'arcane meaning', 'arraignment', 'aspersion', 'assumption'],
    'innumerable': ['all-comprehensive', 'all-inclusive', 'boundless', 'countless', 'endless', 'eternal', 'exhaustless', 'extending everywhere', 'illimitable', 'illimited', 'immeasurable', 'immense'],
    'inobservance': ['absentmindedness', 'carelessness', 'default', 'delinquency', 'dereliction', 'disconformity', 'disregard', 'disregardfulness', 'distraction', 'failure', 'flightiness', 'flippancy'],
    'inobservant': ['careless', 'disregardant', 'disregardful', 'distracted', 'distrait', 'heedless', 'inadvertent', 'inattentive', 'inconstant', 'incurious', 'indifferent', 'negligent'],
    'inoculate': ['admit', 'animate', 'beat into', 'brainwash', 'catechize', 'condition', 'ease in', 'embue', 'enliven', 'enter', 'exhilarate', 'fire'],
    'inoculation': ['absorption and regurgitation', 'antitoxin', 'bang', 'booster', 'booster shot', 'brainwashing', 'catechization', 'conditioning', 'dictation', 'embedment', 'entrance', 'fix'],
    'inoffensive': ['admissible', 'allowable', 'benign', 'condonable', 'defensible', 'dispensable', 'excusable', 'exemptible', 'expiable', 'forgivable', 'harmless', 'innocent'],
    'inoperable': ['beyond one', 'beyond recall', 'beyond remedy', 'cureless', 'functionless', 'gone', 'immedicable', 'impracticable', 'impractical', 'in disrepair', 'inapplicable', 'incorrigible'],
    'inoperative': ['barren', 'bootless', 'broken', 'counterproductive', 'effete', 'empty', 'etiolated', 'fatuitous', 'fatuous', 'feckless', 'fruitless', 'functionless'],
    'inopportune': ['bad', 'futile', 'ill-advised', 'ill-considered', 'ill-seasoned', 'ill-suited', 'ill-timed', 'impolitic', 'improper', 'inadvisable', 'inappropriate', 'inapt'],
    'inordinance': ['abandon', 'boundlessness', 'egregiousness', 'enormousness', 'exaggeration', 'excess', 'excessiveness', 'exorbitance', 'exorbitancy', 'extravagance', 'extravagancy', 'extreme'],
    'inordinate': ['a bit much', 'abandoned', 'aggrandized', 'amplified', 'ballyhooed', 'bibulous', 'bigoted', 'boundless', 'crapulent', 'crapulous', 'cutthroat', 'disproportionate'],
    'inordinately': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'beyond all bounds', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly', 'damnably'],
    'inpatient': ['addressee', 'apoplectic', 'arthritic', 'artist-in-residence', 'case', 'consumptive', 'denizen', 'dweller', 'dyspeptic', 'epileptic', 'habitant', 'house detective'],
    'input': ['access', 'admission', 'entrance', 'entree', 'entry', 'import', 'importation', 'importing', 'income', 'incoming', 'infiltration', 'ingoing'],
    'input data': ['algol', 'cobol', 'fortran', 'alphabetic data', 'alphanumeric code', 'angular data', 'assembler', 'binary digit', 'binary scale', 'binary system', 'bit', 'bug'],
    'inquest': ['analysis', 'assize', 'autopsy', 'blue-ribbon jury', 'change of venue', 'coroner', 'country', 'court-martial', 'cross-examination', 'delving', 'examination', 'grand jury'],
    'inquietude': ['agitation', 'ailment', 'all-overs', 'angst', 'anguish', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat', 'anxiousness'],
    'inquire': ['ask', 'ask a question', 'ask about', 'ask questions', 'be curious', 'bring into question', 'burn with curiosity', 'catechize', 'demand', 'dig around for', 'dig up', 'enquire'],
    'inquire into': ['comment upon', 'criticize', 'deal with', 'descant', 'discourse', 'discuss', 'dissert', 'dissertate', 'entertain', 'go into', 'handle', 'investigate'],
    'inquirer': ['paul pry', 'peeping tom', 'asker', 'auditor', 'autodidact', 'busybody', 'catechist', 'cross-interrogator', 'cross-questioner', 'detective', 'eavesdropper', 'educatee'],
    'inquiring': ['socratic method', 'agape', 'agog', 'all agog', 'analysis', 'asking', 'bringing into question', 'burning with curiosity', 'catechetical method', 'catechistic', 'catechization', 'catechizing'],
    'inquiring mind': ['analysis', 'curiosity', 'curious mind', 'curiousness', 'ghoulishness', 'inquest', 'inquirendo', 'inquiring', 'inquiry', 'inquisition', 'inquisitiveness', 'interest'],
    'inquiry': ['amassing evidence', 'assize', 'audit', 'bone of contention', 'canvass', 'catechism', 'catechizing', 'change of venue', 'check', 'close inquiry', 'consumer research', 'consumer-preference survey'],
    'inquisition': ['areopagus', 'analysis', 'assize', 'board', 'change of venue', 'council', 'court-martial', 'cross-examination', 'cross-interrogation', 'cross-questioning', 'curia', 'delving'],
    'inquisitive': ['agape', 'agog', 'all agog', 'analytical', 'burning with curiosity', 'busy', 'busybody', 'consumed with curiosity', 'curious', 'exploring', 'forward', 'ghoulish'],
    'inquisitor': ['paul pry', 'peeping tom', 'asker', 'busybody', 'catechist', 'cross-interrogator', 'cross-questioner', 'detective', 'eavesdropper', 'examiner', 'gossip', 'inquirer'],
    'inroad': ['advances', 'air attack', 'air raid', 'air strike', 'attack', 'bankruptcy', 'boarding', 'breakage', 'breakdown', 'breakthrough', 'collapse', 'crack-up'],
    'inrush': ['affluence', 'afflux', 'affluxion', 'air current', 'crosscurrent', 'current', 'current of air', 'downdraft', 'draft', 'fall wind', 'flow in', 'flow of air'],
    'ins': ['bureaucracy', 'directorate', 'hierarchy', 'higher echelons', 'higher-ups', 'holdover', 'incumbent', 'jack-in-office', 'lame duck', 'management', 'ministry', 'new broom'],
    'ins and outs': ['chain of circumstances', 'chain reaction', 'chapter of accidents', 'circumstances', 'concatenation of events', 'context', 'details', 'environment', 'existing conditions', 'feast and famine', 'full particulars', 'minutiae'],
    'insalubrious': ['bad', 'bad for', 'contaminated', 'foul', 'harmful', 'injurious', 'insanitary', 'morbific', 'noisome', 'noxious', 'pathogenic', 'peccant'],
    'insalubrity': ['air', 'badness', 'contamination', 'harmfulness', 'health hazard', 'injuriousness', 'insalubriousness', 'menace to health', 'noise pollution', 'noisomeness', 'noxiousness', 'pathenogenicity'],
    'insane': ['abnormal', 'absurd', 'apish', 'asinine', 'at fever pitch', 'batty', 'bedlamite', 'befooled', 'beguiled', 'bereft of reason', 'besotted', 'bonkers'],
    'insanity': ['aberration', 'absurdity', 'alienation', 'amentia', 'arrested development', 'asininity', 'backwardness', 'battiness', 'blithering idiocy', 'brain disease', 'brainlessness', 'buffoonery'],
    'insatiable': ['apician', 'a hog for', 'acquisitive', 'all-devouring', 'avaricious', 'avid', 'bolting', 'bottomless', 'clamorous', 'coveting', 'covetous', 'cramming'],
    'inscribe': ['alphabet', 'alphabetize', 'autolithograph', 'be a printmaker', 'bed', 'book', 'calendar', 'capitalize', 'carve', 'catalog', 'chalk', 'chalk up'],
    'inscribed': ['autograph', 'autographic', 'booked', 'calligraphic', 'carved', 'chirographic', 'creased', 'cursive', 'cut', 'documented', 'down', 'enchased'],
    'inscription': ['acknowledgments', 'arch', 'back', 'back matter', 'barrow', 'bastard title', 'bibliography', 'booking', 'boundary stone', 'brass', 'burr', 'bust'],
    'inscrutable': ['greek to one', 'ambiguous', 'arcane', 'beyond understanding', 'cabalistic', 'impenetrable', 'inarticulate', 'incognizable', 'incoherent', 'incomprehensible', 'mystic', 'numinous'],
    'insect': ['chilopoda', 'chordata', 'echiuroidea', 'ectoprocta', 'entoprocta', 'lepisma', 'monoplacophora', 'nemertinea', 'phoronidea', 'animal', 'ant', 'aphid'],
    'insecticide': ['aborticide', 'acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bug bomb', 'carbamate insecticide', 'chemosterilant', 'contact poison', 'defoliant', 'disinfectant', 'eradicant'],
    'insectivore': ['amphibian', 'aquatic', 'biped', 'canine', 'cannibal', 'carnivore', 'cosmopolite', 'feline', 'gnawer', 'herbivore', 'invertebrate', 'mammal'],
    'insectivorous': ['cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'dining', 'eating', 'feeding', 'flesh-eating', 'fruitarian', 'gastronomic', 'gluttonous'],
    'insecure': ['afraid', 'anxious', 'apprehensive', 'dangerous', 'desultory', 'dickey', 'disconcerted', 'doubtful', 'dubious', 'exposed', 'fearful', 'flimsy'],
    'insecurity': ['chanciness', 'criticalness', 'danger', 'delicacy', 'desultoriness', 'doubtfulness', 'dubiousness', 'hazard', 'hazardousness', 'infirmity', 'insolidity', 'instability'],
    'inseminate': ['bed', 'broadcast', 'cross-fertilize', 'cross-pollen', 'cross-pollinate', 'cross-pollinize', 'dibble', 'disseminate', 'drill', 'fecundify', 'fertilize', 'forest'],
    'insemination': ['artificial insemination', 'broadcast', 'broadcasting', 'conjugation', 'cross-fertilization', 'cross-pollination', 'dissemination', 'fecundation', 'fertilization', 'getting with child', 'heterogamy', 'impregnation'],
    'insensate': ['abiotic', 'anarchic', 'anesthetic', 'angry', 'asleep', 'azoic', 'benumbed', 'bloodless', 'blustering', 'blusterous', 'blustery', 'brainless'],
    'insensibility': ['abstraction', 'abulia', 'alienation', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'blindness', 'casualness', 'catatonic stupor', 'compulsion', 'crudity of intellect'],
    'insensible': ['a stranger to', 'abiotic', 'absorbed', 'anesthetic', 'anesthetized', 'apathetic', 'asleep', 'azoic', 'behind the curtain', 'behind the scenes', 'benumbed', 'blind'],
    'insensitive': ['philistine', 'aloof', 'anesthetic', 'anesthetized', 'asleep', 'benumbed', 'blanket', 'bloodless', 'boorish', 'caddish', 'callous', 'calloused'],
    'insensitivity': ['philistinism', 'analgesia', 'anesthesia', 'armor', 'bad manners', 'caddishness', 'callosity', 'callousness', 'callus', 'casualness', 'coarseness', 'coldbloodedness'],
    'insentient': ['abiotic', 'asleep', 'azoic', 'benumbed', 'callous', 'dead', 'deadened', 'dull', 'dumb', 'exanimate', 'impassible', 'impassive'],
    'inseparability': ['accretion', 'adherence', 'adhesion', 'agglomeration', 'agglutination', 'cling', 'clinging', 'clotting', 'clustering', 'coagulation', 'coherence', 'cohesion'],
    'inseparable': ['bound up in', 'bound up with', 'close', 'coherent', 'cohesive', 'familiar', 'hand and glove', 'hand-in-hand', 'impartible', 'inalienable', 'indiscerptible', 'indissoluble'],
    'insert': ['ad', 'addendum', 'addition', 'admit', 'advert', 'advertisement', 'aside', 'barge in', 'be admitted', 'book', 'break in', 'breeze in'],
    'insertion': ['earth insertion', 'lem', 'lm', 'access', 'admission', 'apogee', 'aside', 'attitude-control rocket', 'ballistic capsule', 'booking', 'burn', 'capsule'],
    'inside': ['advantaged', 'advantageous', 'arranged', 'at', 'at bottom', 'auricular', 'backing', 'backwards', 'basically', 'between us', 'bosom', 'bowels'],
    'inside out': ['altogether', 'arsy-varsy', 'ass over elbows', 'back-to-front', 'backwards', 'capsized', 'chiastic', 'completely', 'comprehensively', 'entirely', 'everted', 'exhaustively'],
    'inside track': ['advantage', 'bulge', 'coign of vantage', 'drag', 'drop', 'edge', 'favor', 'flying start', 'head start', 'interest', 'jump', 'odds'],
    'insider': ['greek', 'affiliate', 'associate', 'belonger', 'brother', 'card-carrier', 'card-carrying member', 'cardholder', 'charter member', 'clubber', 'clubman', 'clubwoman'],
    'insides': ['abdomen', 'anus', 'appendix', 'blind gut', 'bowels', 'brain', 'cecum', 'census', 'colon', 'composition', 'constituents', 'content'],
    'insidious': ['byzantine', 'machiavellian', 'machiavellic', 'acute', 'amoral', 'arch', 'artful', 'astute', 'cagey', 'calculating', 'canny', 'chiseling'],
    'insight': ['esp', 'a priori knowledge', 'acuity', 'acumen', 'acuteness', 'anschauung', 'anticipation', 'apperception', 'appreciation', 'appreciativeness', 'astuteness', 'awareness'],
    'insightful': ['all-knowing', 'apperceptive', 'appercipient', 'apprehending', 'apprehensive', 'astute', 'aware', 'cognizant', 'comprehending', 'conscious', 'discerning', 'discriminating'],
    'insignia': ['badge', 'banner', 'character', 'characteristic', 'decoration', 'device', 'differentia', 'earmark', 'emblem', 'hallmark', 'idiosyncrasy', 'image'],
    'insignificance': ['aimlessness', 'daintiness', 'dead letter', 'delicacy', 'diminutiveness', 'emptiness', 'empty sound', 'exiguity', 'exiguousness', 'fewness', 'futility', 'immateriality'],
    'insignificancy': ['a little thing', 'a nobody', 'a nothing', 'cipher', 'common man', 'dummy', 'figurehead', 'hardly anything', 'inessential', 'jackstraw', 'lightweight', 'little fellow'],
    'insignificant': ['aimless', 'back-burner', 'casual', 'cursory', 'depthless', 'designless', 'dinky', 'dispensable', 'empty', 'few', 'footling', 'garbled'],
    'insignificantly': ['a bit', 'a little', 'aimlessly', 'barely', 'by a hair', 'by an ace', 'ever so little', 'exiguously', 'faintly', 'feebly', 'frivolously', 'hardly'],
    'insincere': ['machiavellian', 'tartuffian', 'tartuffish', 'adulatory', 'affected', 'ambidextrous', 'apparently sound', 'artful', 'artificial', 'bland', 'blandishing', 'blarneying'],
    'insincerity': ['tartuffery', 'tartuffism', 'affectation', 'affectedness', 'airs', 'airs and graces', 'apparent soundness', 'artfulness', 'artificiality', 'cant', 'casuistry', 'circularity'],
    'insinuate': ['accuse', 'adumbrate', 'allege', 'allegorize', 'allude to', 'arraign', 'article', 'ascribe', 'assume', 'barge in', 'book', 'break in'],
    'insinuating': ['adulatory', 'allusive', 'allusory', 'bland', 'blandishing', 'blarneying', 'buttery', 'cajoling', 'complimentary', 'courtierly', 'courtly', 'deferential'],
    'insinuation': ['access', 'accusal', 'accusation', 'accusing', 'admission', 'allegation', 'allegement', 'animadversion', 'apple-polishing', 'arraignment', 'ascendancy', 'ascription'],
    'insipid': ['arid', 'banal', 'bare', 'barren', 'betwixt and between', 'blah', 'bland', 'blank', 'bleached', 'bloodless', 'bromidic', 'changeable'],
    'insist': ['advocate', 'affirm', 'allege', 'announce', 'annunciate', 'argue', 'assert', 'assever', 'asseverate', 'aver', 'avouch', 'avow'],
    'insist upon': ['advocate', 'always trot out', 'assert', 'attach a condition', 'belabor', 'blandish', 'brook no denial', 'cajole', 'call on', 'call upon', 'coax', 'compel'],
    'insistence': ['abetment', 'application', 'assiduity', 'assiduousness', 'bulldog tenacity', 'concentration', 'constancy', 'demandingness', 'diligence', 'dogged perseverance', 'doggedness', 'encouragement'],
    'insistent': ['acute', 'assertive', 'assiduous', 'burning', 'cajoling', 'clamant', 'clamorous', 'coaxing', 'compelling', 'constant', 'continuing', 'critical'],
    'insobriety': ['dutch courage', 'a high', 'befuddlement', 'besottedness', 'drunkenness', 'fuddle', 'fuddledness', 'fuddlement', 'hangover', 'inebriation', 'inebriety', 'intoxication'],
    'insolation': ['air-drying', 'anhydration', 'calefaction', 'calenture', 'cooking', 'coup de soleil', 'dehumidification', 'dehydration', 'desiccation', 'dielectric heating', 'drainage', 'drying'],
    'insolence': ['arrogance', 'assumption', 'audacity', 'bold front', 'boldness', 'brash bearing', 'brashness', 'brass', 'brassiness', 'bravado', 'brazen boldness', 'brazenness'],
    'insolent': ['abusive', 'arrogant', 'assuming', 'atrocious', 'audacious', 'aweless', 'backhand', 'backhanded', 'bold', 'brash', 'brassy', 'brazen'],
    'insoluble': ['coherent', 'cohesive', 'enwrapped in mystery', 'impartible', 'indefinable', 'indiscerptible', 'indissoluble', 'indissolvable', 'indivisible', 'inexplicable', 'inextricable', 'infrangible'],
    'insolvency': ['bankruptcy', 'bouncing check', 'broken fortune', 'bust', 'collapse', 'crash', 'difficulties', 'distress', 'embarrassment', 'failure', 'genteel poverty', 'hard pinch'],
    'insolvent': ['bankrupt', 'broke', 'broken', 'busted', 'destitute', 'down-and-out', 'failed', 'failure', 'fortuneless', 'homeless', 'impoverished', 'in queer street'],
    'insomnia': ['abscess', 'ague', 'alertness', 'all-night vigil', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy'],
    'insomniac': ['alertness', 'all-night vigil', 'consciousness', 'insomnia', 'insomnious', 'insomnolence', 'insomnolency', 'lidless vigil', 'restless', 'restlessness', 'sentience', 'sleepless'],
    'insouciance': ['abandon', 'accidia', 'acedia', 'aloofness', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'boredom', 'careless abandon'],
    'inspect': ['autopsy', 'canvass', 'catechize', 'check', 'check out', 'check over', 'check up', 'check up on', 'con', 'contemplate', 'examine', 'eye'],
    'inspection': ['accounting', 'analysis', 'application', 'boning', 'brainwork', 'braking', 'checkup', 'computation', 'conning', 'contemplation', 'coordination', 'cram'],
    'inspector': ['big brother', 'g-man', 'mp', 'auditor', 'bailiff', 'beadle', 'beagle', 'boatswain', 'boss', 'bound bailiff', 'captain', 'catchpole'],
    'inspiration': ['apollo', 'apollo musagetes', 'aqua-lung', 'bragi', 'calliope', 'castilian spring', 'clio', 'erato', 'euterpe', 'geist', 'helicon', 'hippocrene'],
    'inspire': ['activate', 'actuate', 'affect', 'affirm', 'afford hope', 'animate', 'arouse', 'aspirate', 'assure', 'augur well', 'awaken', 'bid fair'],
    'inspired': ['biblical', 'gospel', 'mosaic', 'new-testament', 'old-testament', 'afire', 'apocalyptic', 'apostolic', 'appropriate', 'apt', 'canonical', 'comely'],
    'inspirer': ['abettor', 'actuator', 'agent', 'animator', 'author', 'begetter', 'beginner', 'cajoler', 'catalyst', 'causer', 'coax', 'coaxer'],
    'inspiring': ['animating', 'auspicious', 'bright with promise', 'cheerful', 'cheering', 'cheery', 'dignified', 'elevated', 'encouraging', 'enlivening', 'exhilarating', 'exhilarative'],
    'inspirit': ['afford hope', 'animate', 'assure', 'augur well', 'bid fair', 'bolster', 'boost', 'brace up', 'breathe life into', 'brighten', 'bring into being', 'bring into existence'],
    'inspissate': ['beat up', 'cake', 'caked', 'cakey', 'churn', 'clabber', 'clabbered', 'clot', 'clotted', 'clump', 'cluster', 'coagulate'],
    'instability': ['ambitendency', 'ambivalence', 'caducity', 'capriciousness', 'chanciness', 'change of mind', 'changeability', 'changeableness', 'choppiness', 'corruptibility', 'criticalness', 'danger'],
    'install': ['allocate', 'anoint', 'assign', 'base', 'bring up', 'broach', 'build', 'build in', 'chair', 'christen', 'collocate', 'connect'],
    'installation': ['accedence', 'acceptance', 'accession', 'accouterments', 'admission', 'admittance', 'agency', 'anchorage', 'apostolic orders', 'apparatus', 'appliances', 'appointment'],
    'installed': ['assigned', 'deployed', 'embosomed', 'emplaced', 'ensconced', 'established', 'fixed', 'located', 'placed', 'planted', 'positioned', 'posted'],
    'installment': ['accedence', 'accession', 'acquitment', 'acquittal', 'acquittance', 'adjunct', 'amortization', 'amortizement', 'anchorage', 'article', 'binder', 'book'],
    'installment plan': ['acquitment', 'acquittal', 'acquittance', 'amortization', 'amortizement', 'bank credit', 'binder', 'book credit', 'borrowing', 'borrowing power', 'cash', 'cash credit'],
    'instance': ['abetment', 'adduce', 'anatomize', 'article', 'as an example', 'aspect', 'atomize', 'call to mind', 'case', 'case history', 'case in point', 'circumstantiate'],
    'instant': ['a breath', 'about to be', 'actual', 'acute', 'alert', 'already in sight', 'approaching', 'apt', 'as is', 'at hand', 'being', 'bit'],
    'instantaneous': ['alert', 'apt', 'brief', 'compact', 'compendious', 'concise', 'curt', 'curtal', 'curtate', 'decisive', 'decurtate', 'expeditious'],
    'instantaneously': ['at once', 'directly', 'forthwith', 'immediately', 'in a flash', 'in a jiff', 'in a jiffy', 'in a twink', 'in a twinkling', 'in no time', 'in nothing flat', 'in short order'],
    'instantly': ['pdq', 'amain', 'apace', 'at once', 'away', 'by forced marches', 'cursorily', 'decisively', 'directly', 'expeditiously', 'feverishly', 'forthwith'],
    'instate': ['anoint', 'chair', 'crown', 'enlist', 'enroll', 'enthrone', 'inaugurate', 'induct', 'initiate', 'install', 'invest', 'ordain'],
    'instep': ['arch', 'clubfoot', 'digit', 'dog', 'extremity', 'fetlock', 'foot', 'forefoot', 'forepaw', 'harefoot', 'heel', 'hoof'],
    'instigate': ['abet', 'activate', 'actuate', 'agitate', 'arouse', 'blow the coals', 'bring', 'bring on', 'call forth', 'contrive', 'draw down', 'draw on'],
    'instigation': ['agitation', 'arousal', 'catalyst', 'exasperation', 'excitation', 'excitement', 'firing', 'fomentation', 'goad', 'impetus', 'impulse', 'incentive'],
    'instigator': ['agent', 'agent provocateur', 'agitator', 'agitprop', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner'],
    'instill': ['beat into', 'besprinkle', 'brainwash', 'breathe', 'brew', 'catechize', 'color', 'condition', 'decoct', 'dredge', 'dye', 'engrave'],
    'instilled': ['chronic', 'confirmed', 'deep-dyed', 'deep-fixed', 'deep-rooted', 'deep-seated', 'deep-set', 'deep-settled', 'dyed-in-the-wool', 'established', 'fast', 'fixed'],
    'instillment': ['absorption and regurgitation', 'brainwashing', 'catechization', 'conditioning', 'decoction', 'dictation', 'imbuement', 'implantation', 'impregnation', 'impression', 'inculcation', 'indoctrination'],
    'instinct': ['a thing for', 'ability', 'affinity', 'aptitude', 'aptness', 'archetypal pattern', 'archetype', 'automatic response', 'automatic writing', 'automatism', 'bent', 'bias'],
    'instinctive': ['animal', 'animalian', 'animalic', 'animalistic', 'atavistic', 'automatic', 'beastlike', 'beastly', 'bestial', 'blind', 'bodily', 'born'],
    'institute': ['schule', 'academy', 'alliance', 'association', 'author', 'bear', 'beget', 'begin', 'breed', 'bring about', 'bring forth', 'bring to effect'],
    'institution': ['academy', 'act', 'agency', 'alpha', 'apostolic orders', 'appointment', 'asylum', 'atelier', 'barbershop', 'beauty parlor', 'beauty shop', 'beginning'],
    'institutor': ['ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner', 'builder', 'conceiver', 'constructor', 'craftsman'],
    'instruct': ['acquaint', 'advertise', 'advertise of', 'advise', 'advocate', 'apprise', 'assign', 'bid', 'brief', 'bring word', 'broaden the mind', 'call on'],
    'instructable': ['apt', 'bright', 'clever', 'docile', 'educable', 'facile', 'formable', 'impressionable', 'intelligent', 'malleable', 'moldable', 'motivated'],
    'instruction': ['accomplishments', 'account', 'acquaintance', 'acquisition of knowledge', 'acquisitions', 'admonition', 'advice', 'advising', 'advocacy', 'announcement', 'assignment', 'attainments'],
    'instructions': ['algol', 'cobol', 'fortran', 'alphabetic data', 'alphanumeric code', 'angular data', 'assembler', 'binary digit', 'binary scale', 'binary system', 'bit', 'briefing'],
    'instructive': ['admonitory', 'advisory', 'authoritative', 'autodidactic', 'binding', 'canonical', 'cautionary', 'coeducational', 'commanding', 'communicative', 'compelling', 'consultative'],
    'instructor': ['dutch uncle', 'polonius', 'abecedarian', 'academe', 'academician', 'admonisher', 'adviser', 'aeronaut', 'aeroplaner', 'aeroplanist', 'air pilot', 'airplanist'],
    'instrument': ['bourdon tube', 'charlie mccarthy', 'danish balance', 'federal', 'gramophone', 'gyropilot', 'mach meter', 'roman balance', 'teletype', 'weightometer', 'x-ray machine', 'absolute altimeter'],
    'instrumental': ['accessory', 'adjuvant', 'advantageous', 'agential', 'agentival', 'agentive', 'ancillary', 'assistant', 'assisting', 'auxiliary', 'beneficial', 'catalytic'],
    'instrumentalist': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'accompanist', 'accompanyist', 'animist', 'animistic', 'atomistic', 'bandman', 'cosmotheistic'],
    'instrumentality': ['agency', 'agent', 'channel', 'device', 'energy', 'expedient', 'force', 'going between', 'instrument', 'instrumentation', 'intermediation', 'machinery'],
    'instrumentation': ['adaptation', 'agency', 'agent', 'appraisal', 'appraisement', 'approximation', 'arrangement', 'assessment', 'assize', 'assizement', 'calculation', 'channel'],
    'insubordinate': ['agitator', 'brawler', 'contrary', 'contumacious', 'defiant', 'disaffected', 'disobedient', 'dissentious', 'extremist', 'factious', 'fractious', 'frondeur'],
    'insubordination': ['civil disobedience', 'disobedience', 'frowardness', 'indiscipline', 'indocility', 'infraction', 'infringement', 'interregnum', 'intractability', 'irresponsibility', 'lawbreaking', 'lawlessness'],
    'insubstantial': ['adulterated', 'airy', 'asomatous', 'astral', 'attenuate', 'attenuated', 'bodiless', 'boyish', 'brittle', 'capricious', 'changeable', 'chimerical'],
    'insubstantiality': ['airiness', 'airy nothing', 'airy texture', 'attenuation', 'bodilessness', 'danger', 'delicacy', 'desultoriness', 'diaphanousness', 'dilutedness', 'dilution', 'ethereality'],
    'insufficiency': ['arrear', 'arrearage', 'arrears', 'asymmetry', 'baseness', 'contrariety', 'daintiness', 'decline', 'defalcation', 'default', 'defectiveness', 'deficiency'],
    'insufficient': ['asymmetric', 'base', 'defective', 'deficient', 'disappointing', 'disheartening', 'disparate', 'displeasing', 'disproportionate', 'dissatisfactory', 'failing', 'found wanting'],
    'insular': ['alien', 'alienated', 'alone', 'aloof', 'apart', 'archipelagian', 'archipelagic', 'asunder', 'authoritarian', 'bigot', 'bigoted', 'bipartite'],
    'insularity': ['jim crow', 'ait', 'alien', 'apartheid', 'archipelago', 'atoll', 'authoritarianism', 'bar', 'bigotry', 'blind side', 'blind spot', 'blinders'],
    'insulate': ['bolt', 'close off', 'cordon', 'cordon off', 'cover', 'cull out', 'cushion', 'cut off', 'detach', 'divide', 'enisle', 'fireproof'],
    'insulation': ['jim crow', 'aegis', 'alien', 'apartheid', 'buffer', 'bulwark', 'bumper', 'color bar', 'contraceptive', 'copyright', 'crash helmet', 'cushion'],
    'insult': ['abase', 'abuse', 'affront', 'airs', 'arrogance', 'asperse', 'aspersion', 'atrocity', 'barb', 'be above', 'be contemptuous of', 'brickbat'],
    'insulting': ['abusive', 'arrogant', 'atrocious', 'audacious', 'backhand', 'backhanded', 'bumptious', 'calumnious', 'cold', 'contumelious', 'cool', 'degrading'],
    'insuperable': ['beyond one', 'impassable', 'impenetrable', 'impracticable', 'impractical', 'impregnable', 'incontestable', 'indomitable', 'inexpugnable', 'inoperable', 'insurmountable', 'invincible'],
    'insuppressible': ['beyond control', 'breachy', 'contumacious', 'defiant', 'fractious', 'incorrigible', 'indocile', 'indomitable', 'intractable', 'irrepressible', 'obstreperous', 'out of hand'],
    'insurance': ['accident insurance', 'actuary', 'annuity', 'assurance', 'aviation insurance', 'bail bond', 'bond', 'business life insurance', 'casualty insurance', 'certificate of insurance', 'court bond', 'cover'],
    'insurance company': ['accident insurance', 'actuary', 'annuity', 'assurance', 'aviation insurance', 'bail bond', 'bond', 'business life insurance', 'casualty insurance', 'certificate of insurance', 'court bond', 'credit insurance'],
    'insurance policy': ['accident insurance', 'actuary', 'annuity', 'arrangement', 'assurance', 'aviation insurance', 'bail bond', 'bond', 'business life insurance', 'casualty insurance', 'certificate of insurance', 'contract by deed'],
    'insure': ['arm', 'armor', 'ascertain', 'assure', 'attest', 'back', 'be sponsor for', 'bless', 'bond', 'certify', 'champion', 'cinch'],
    'insured': ['assured', 'certain', 'certified', 'covered', 'ensured', 'guaranteed', 'immune', 'immunized', 'intact', 'protected', 'safe', 'safe and sound'],
    'insurer': ['approver', 'bailsman', 'bondsman', 'certifier', 'confirmer', 'cosignatory', 'cosigner', 'endorser', 'godfather', 'godparent', 'guarantee', 'guarantor'],
    'insurgent': ['agitator', 'anarch', 'anarchist', 'brawler', 'breakaway', 'contumacious', 'extreme', 'extremist', 'extremistic', 'factious', 'frondeur', 'insubordinate'],
    'insurmountable': ['beyond one', 'impassable', 'impracticable', 'impractical', 'indomitable', 'inoperable', 'insuperable', 'invincible', 'too much for', 'unachievable', 'unattainable', 'uncompassable'],
    'insurrectionary': ['breakaway', 'cataclysmic', 'catastrophic', 'extreme', 'extremistic', 'factious', 'insurgent', 'mutineering', 'mutinous', 'radical', 'rebel', 'rebellious'],
    'insusceptible': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity', 'cold-blooded', 'coldhearted'],
    'intact': ['platonic', 'abiding', 'abstinent', 'budding', 'callow', 'celibate', 'changeless', 'complete', 'conserved', 'constant', 'continent', 'continuing'],
    'intaglio': ['anaglyph', 'aquatint', 'bas-relief', 'boss', 'burin', 'cameo', 'cameo glass', 'cast', 'cavo-rilievo', 'cerography', 'chalcography', 'crayon engraving'],
    'intake': ['access', 'adit', 'admission', 'air lock', 'approach', 'avails', 'box office', 'commissions', 'corridor', 'credit', 'credits', 'disposable income'],
    'intangibility': ['airiness', 'bodilessness', 'ethereality', 'evanescence', 'flimsiness', 'ghostliness', 'immateriality', 'immaterialness', 'impalpability', 'imperceptibility', 'imponderability', 'incorporeality'],
    'intangible': ['aerial', 'aeriform', 'airy', 'asomatous', 'astral', 'atomic', 'bodiless', 'corpuscular', 'decarnate', 'decarnated', 'dim', 'discarnate'],
    'intangibles': ['assessed valuation', 'assets', 'assets and liabilities', 'circumstances', 'current assets', 'deferred assets', 'fixed assets', 'frozen assets', 'funds', 'intangible assets', 'liquid assets', 'material assets'],
    'integer': ['gaussian integer', 'algebraic number', 'article', 'cardinal', 'cardinal number', 'cipher', 'collectivity', 'complex', 'complex number', 'defective number', 'digit', 'embodiment'],
    'integral': ['a certain', 'aggregate', 'algorismic', 'algorithmic', 'aliquot', 'all', 'all-embracing', 'all-inclusive', 'an', 'any', 'any one', 'atomic'],
    'integrate': ['accommodate', 'add', 'adjust', 'admix', 'alloy', 'amalgamate', 'arrange', 'articulate', 'assemble', 'assimilate', 'attune', 'balance'],
    'integrated': ['aggregate', 'all', 'all-embracing', 'all-inclusive', 'allied', 'amalgamated', 'assembled', 'assimilated', 'associated', 'banded together', 'blended', 'bound'],
    'integration': ['anschluss', 'accommodation', 'adaptation', 'addition', 'adjustment', 'admixture', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alignment', 'alliance'],
    'integrity': ['absoluteness', 'assured probity', 'blamelessness', 'character', 'cleanness', 'coherence', 'collectivity', 'combination', 'completeness', 'complex', 'comprehensiveness', 'decency'],
    'integument': ['leatherette', 'leatheroid', 'border', 'circumference', 'coat', 'cortex', 'covering', 'crust', 'cuticle', 'dermis', 'envelope', 'epidermis'],
    'intellect': ['brahmin', 'iq', 'apprehension', 'authority', 'brain', 'brains', 'brainworker', 'caliber', 'capacity', 'cleverness', 'common sense', 'comprehension'],
    'intellectual': ['brahmin', 'academic', 'academician', 'affective', 'authority', 'bookish', 'brain', 'brainy', 'bright', 'cerebral', 'characteristic', 'conceptive'],
    'intellectuality': ['iq', 'apprehension', 'bibliolatry', 'bibliomania', 'bluestockingism', 'book learning', 'book madness', 'bookiness', 'bookishness', 'booklore', 'caliber', 'capacity'],
    'intellectualize': ['analyze', 'apply reason', 'cerebrate', 'cogitate', 'conceive', 'conceptualize', 'deduce', 'entertain ideas', 'exercise the mind', 'form ideas', 'generalize', 'hypothesize'],
    'intelligence': ['vernunft', 'account', 'acquaintance', 'acumen', 'advice', 'alertness', 'announcement', 'apprehension', 'aptitude', 'aptness', 'astuteness', 'atua'],
    'intelligence quotient': ['binet-simon test', 'brown personality inventory', 'goldstein-sheerer test', 'iq', 'iq test', 'kent mental test', 'minnesota preschool scale', 'oseretsky test', 'rorschach test', 'stanford revision', 'stanford-binet test', 'szondi test'],
    'intelligence test': ['binet-simon test', 'brown personality inventory', 'goldstein-sheerer test', 'iq', 'iq test', 'kent mental test', 'minnesota preschool scale', 'oseretsky test', 'rorschach test', 'stanford revision', 'stanford-binet test', 'szondi test'],
    'intelligence work': ['bugging', 'cloak-and-dagger work', 'counterespionage', 'counterintelligence', 'electronic surveillance', 'espial', 'espionage', 'following', 'intelligence', 'military intelligence', 'observation', 'secret police'],
    'intelligent': ['acute', 'adroit', 'alert', 'all-knowing', 'apperceptive', 'appercipient', 'apprehending', 'apprehensive', 'apt', 'astute', 'au fait', 'aware'],
    'intelligently': ['artfully', 'astutely', 'circumspectly', 'cleverly', 'consciously', 'considerately', 'cunningly', 'discerningly', 'discreetly', 'eruditely', 'judiciously', 'knowingly'],
    'intelligibility': ['clarity', 'clear coast', 'clear road', 'ease', 'easiness', 'easy going', 'effortlessness', 'expressiveness', 'facileness', 'facility', 'freedom', 'highroad'],
    'intelligible': ['allegorical', 'apprehensible', 'articulate', 'associational', 'clear', 'cognizable', 'comprehensible', 'connotational', 'connotative', 'decipherable', 'definable', 'denotational'],
    'intemperance': ['bacchus', 'dionysus', 'abandon', 'abandonment', 'bacchanalianism', 'bibaciousness', 'bibacity', 'bibulosity', 'bibulousness', 'boundlessness', 'carpe diem', 'conspicuous consumption'],
    'intemperate': ['apician', 'a bit much', 'abandoned', 'acute', 'all-devouring', 'bibacious', 'bibulous', 'bitter', 'bolting', 'boundless', 'brutal', 'cramming'],
    'intemperately': ['beyond all bounds', 'excessively', 'exorbitantly', 'high', 'immoderately', 'inordinately', 'outrageously', 'over', 'overly', 'overmuch', 'overweeningly', 'prodigally'],
    'intend': ['add up to', 'aim', 'aim at', 'aim to', 'arrange', 'aspire after', 'aspire to', 'assign', 'attempt', 'be after', 'calculate', 'cast'],
    'intended': ['advised', 'affianced', 'aimed', 'aimed at', 'assured', 'betrothed', 'bound', 'bride-to-be', 'calculated', 'committed', 'compromised', 'conscious'],
    'intense': ['abandoned', 'ablaze', 'accentuated', 'active', 'acute', 'advertent', 'afire', 'aggravated', 'aggressive', 'agog', 'alert', 'all ears'],
    'intensely': ['abundantly', 'actively', 'acutely', 'amazingly', 'amply', 'animatedly', 'ardently', 'assiduously', 'astonishingly', 'awesomely', 'breathlessly', 'briskly'],
    'intensification': ['accelerando', 'acceleration', 'aggravation', 'amplification', 'annoyance', 'augmentation', 'beefing-up', 'blowing up', 'blowup', 'concentration', 'condensation', 'consolidation'],
    'intensified': ['accelerated', 'aggrandized', 'aggravated', 'amplified', 'annoyed', 'augmented', 'beefed-up', 'bloated', 'boosted', 'broadened', 'deepened', 'deliberately provoked'],
    'intensify': ['accelerate', 'accent', 'accentuate', 'accrue', 'accumulate', 'advance', 'agent provocateur', 'aggrandize', 'aggravate', 'amplify', 'annoy', 'appreciate'],
    'intensity': ['asa scale', 'british candle', 'hefner candle', 'scheiner scale', 'technicolor', 'abandon', 'acuteness', 'ampleness', 'amplitude', 'animality', 'ardency', 'ardor'],
    'intensive': ['absolute', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'born', 'broad-based', 'clean', 'clear', 'comprehensive', 'concentrated', 'congenital'],
    'intensive care': ['x ray', 'blood bank', 'charity ward', 'clinic', 'consultation room', 'delivery room', 'dispensary', 'emergency', 'examining room', 'fever ward', 'hospital room', 'isolation'],
    'intent': ['abandoned', 'absorbed', 'absorbed in', 'acceptation', 'advertent', 'afire', 'agog', 'aim', 'alert', 'all ears', 'all eyes', 'ambition'],
    'intention': ['aim', 'ambition', 'animus', 'appetence', 'appetency', 'appetite', 'approach', 'arrangement', 'aspiration', 'attack', 'basis', 'blueprint'],
    'intentional': ['advised', 'aimed', 'aimed at', 'calculated', 'conscious', 'considered', 'contemplated', 'contrived', 'deliberate', 'deliberated', 'designed', 'envisaged'],
    'intentionally': ['advisedly', 'by design', 'calculatedly', 'consciously', 'contemplatedly', 'deliberately', 'designedly', 'in cold blood', 'knowingly', 'meditatedly', 'on purpose', 'pointedly'],
    'intently': ['absorbedly', 'advertently', 'ardently', 'assiduously', 'attentively', 'closely', 'continuously', 'determinedly', 'devotedly', 'devoutly', 'doggedly', 'eagerly'],
    'intentness': ['abandon', 'absorbed attention', 'absorption', 'advertence', 'advertency', 'alertness', 'application', 'ardency', 'ardor', 'assiduity', 'assiduousness', 'attention'],
    'inter': ['bury', 'coffin', 'conduct a funeral', 'encoffin', 'ensepulcher', 'enshrine', 'entomb', 'hearse', 'inearth', 'inhume', 'inurn', 'lay away'],
    'inter alia': ['above', 'additionally', 'again', 'all included', 'also', 'altogether', 'among other things', 'and all', 'and also', 'and so', 'as well', 'au reste'],
    'interacting': ['answering', 'communicating', 'communicational', 'communional', 'conversational', 'dovetailed', 'in gear', 'in mesh', 'interactional', 'interactive', 'intercommunicational', 'intercommunicative'],
    'interaction': ['esp', 'alternation', 'answer', 'coaction', 'commerce', 'communication', 'communion', 'complementary distribution', 'concurrence', 'congress', 'connection', 'contact'],
    'intercede': ['act between', 'arbitrate', 'bargain', 'go between', 'interfere', 'intermediate', 'interpose', 'intervene', 'judge', 'make terms', 'mediate', 'meet halfway'],
    'intercept': ['arrest', 'attend', 'attend to', 'auscultate', 'be all ears', 'bend an ear', 'block', 'bottle up', 'bug', 'catch', 'check', 'cock the ears'],
    'intercession': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'aid prayer', 'appeal', 'beadroll', 'beads', 'beseechment', 'bidding prayer'],
    'intercessional': ['christlike', 'christly', 'arbitrational', 'arbitrative', 'celestial', 'coming between', 'divine', 'empyrean', 'godlike', 'godly', 'going between', 'heavenly'],
    'intercessor': ['advocate', 'agent', 'amicus curiae', 'attorney', 'attorney-at-law', 'barrister', 'barrister-at-law', 'connection', 'counsel', 'counselor', 'counselor-at-law', 'deputy'],
    'interchange': ['esp', 'access', 'accord', 'agency', 'agree', 'agree with', 'aisle', 'alley', 'alternate', 'alternation', 'ambulatory', 'answer'],
    'interchangeable': ['alike', 'assignable', 'changeable', 'communicable', 'commutable', 'commutative', 'conductive', 'consignable', 'contagious', 'convertible', 'conveyable', 'equal'],
    'interchanged': ['changeable', 'commutable', 'commutative', 'convertible', 'equal', 'equalizing', 'equivalent', 'even', 'exchanged', 'give-and-take', 'interchangeable', 'mutual'],
    'intercom': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'intercommunicate': ['adhere', 'be in connection', 'be in contact', 'clinch', 'cohere', 'come together', 'commerce with', 'commune with', 'communicate', 'connect', 'converge', 'converse'],
    'intercommunication': ['esp', 'agglomeration', 'agglutination', 'aggregation', 'alternation', 'answer', 'articulation', 'bond', 'bracketing', 'clustering', 'coaction', 'collegiality'],
    'intercommunicational': ['answering', 'communicating', 'communicational', 'communional', 'conversational', 'interacting', 'interactional', 'interactive', 'intercommunicative', 'intercommunional', 'interresponsive', 'interrogative'],
    'intercosmic': ['cynthian', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical', 'celestial', 'circumplanetary', 'cislunar'],
    'intercourse': ['esp', 'accord', 'act of love', 'addition', 'adjunct', 'adultery', 'affairs', 'affiliation', 'affinity', 'agglomeration', 'agglutination', 'aggregation'],
    'interdict': ['eighteenth amendment', 'prohibition party', 'volstead act', 'arrest', 'arrestation', 'ban', 'bar', 'bench warrant', 'capias', 'caveat', 'check', 'constraint'],
    'interest': ['absolute interest', 'absorb', 'absorption', 'accent', 'accrued dividends', 'accumulated dividends', 'acquisitiveness', 'activities', 'activity', 'advantage', 'advocacy', 'aegis'],
    'interested': ['a party to', 'absorbed', 'affected', 'agape', 'agog', 'all agog', 'antiblack', 'attracted', 'biased', 'burning with curiosity', 'cathectic', 'chauvinistic'],
    'interesting': ['absorbing', 'alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching', 'charismatic'],
    'interests': ['establishment', 'vip', 'baron', 'big gun', 'big man', 'big name', 'bigwig', 'brass', 'brass hat', 'bureaucracy', 'celebrity', 'dignitary'],
    'interface': ['ankle', 'articulation', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bourn', 'break boundary', 'breakoff point', 'butt', 'ceiling'],
    'interfere': ['antagonize', 'arrest', 'baffle', 'balk', 'bar', 'barge in', 'be antipathetic', 'be inimical', 'beat against', 'block', 'bottle up', 'break in'],
    'interference': ['amplitude', 'antagonism', 'antinode', 'antipathy', 'arrest', 'arrestation', 'arrestment', 'atmospherics', 'backlash', 'blaring', 'blasting', 'blind spot'],
    'interfuse': ['add', 'amalgamate', 'assimilate', 'blend', 'coalesce', 'combine', 'come together', 'compound', 'comprise', 'connect', 'consolidate', 'diffuse'],
    'interfusion': ['admixture', 'alloy', 'alloyage', 'amalgam', 'amalgamation', 'blend', 'blending', 'coalescence', 'combination', 'comminglement', 'commingling', 'commixture'],
    'interim': ['abeyance', 'acting', 'ad interim', 'afterthought', 'bind', 'block', 'blockage', 'breach', 'break', 'bureaucratic delay', 'caesura', 'cease-fire'],
    'interior': ['airscape', 'amidships', 'anonymous', 'average', 'belly', 'bosom', 'center', 'central', 'cityscape', 'civil', 'closet', 'cloudscape'],
    'interject': ['allude to', 'blurt', 'blurt out', 'call attention to', 'comment', 'drag in', 'ease in', 'edge in', 'exclaim', 'fill in', 'foist in', 'fudge in'],
    'interjection': ['parthian shot', 'address', 'adjectival', 'adjective', 'adverb', 'adverbial', 'adversative conjunction', 'affirmation', 'allegation', 'answer', 'apostrophe', 'aside'],
    'interlace': ['admix', 'alloy', 'amalgamate', 'bemingle', 'blend', 'braid', 'coact', 'coalesce', 'combine', 'commingle', 'commix', 'compose'],
    'interlaced': ['braided', 'enlaced', 'entwined', 'fretted', 'handwoven', 'interknit', 'interthreaded', 'intertied', 'intertissued', 'intertwined', 'interwoven', 'knit'],
    'interlacing': ['alternation', 'braiding', 'coaction', 'complementary distribution', 'concurrence', 'cooperation', 'engagement', 'enlacement', 'entwinement', 'entwining', 'fabric', 'interaction'],
    'interlard': ['admix', 'alloy', 'amalgamate', 'bemingle', 'blend', 'coalesce', 'combine', 'commingle', 'commix', 'compose', 'compound', 'concoct'],
    'interlink': ['busybody', 'butt in', 'fool', 'horn in', 'interaffiliate', 'interally', 'interassociate', 'interconnect', 'intercouple', 'interdepend', 'interdigitate', 'interfere'],
    'interlinked': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'bound', 'bracketed', 'collateral', 'conjugate', 'connected', 'correlated', 'coupled'],
    'interlock': ['accord', 'aegis', 'agree', 'answer to', 'arm guard', 'assent', 'assort with', 'backstop', 'be consistent', 'be of one', 'be uniform with', 'buffer'],
    'interlocked': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'bound', 'bracketed', 'collateral', 'conjugate', 'connected', 'correlated', 'coupled'],
    'interlocutory': ['arbitrational', 'arbitrative', 'chatty', 'chitchatty', 'colloquial', 'coming between', 'communicative', 'confabulatory', 'conversational', 'cozy', 'going between', 'intercessional'],
    'interlope': ['barge in', 'break in', 'break in upon', 'burst in', 'butt in', 'charge in', 'come between', 'crash', 'crash in', 'crash the gates', 'creep in', 'crowd in'],
    'interloping': ['encroachment', 'entrance', 'entrenchment', 'impingement', 'imposition', 'incursion', 'infiltration', 'influx', 'infringement', 'injection', 'inroad', 'insinuation'],
    'interlude': ['abeyance', 'act', 'afterpiece', 'anacrusis', 'bass passage', 'bit', 'bourdon', 'break', 'breath', 'breather', 'breathing place', 'breathing space'],
    'intermarriage': ['a world-without-end bargain', 'alliance', 'bed', 'bond of matrimony', 'bridebed', 'cohabitation', 'conjugal bond', 'conjugal knot', 'coverture', 'holy matrimony', 'holy wedlock', 'husbandhood'],
    'intermeddle': ['paul-pry', 'arrest', 'bottle up', 'busybody', 'butt in', 'check', 'countercheck', 'curb', 'dam up', 'damp', 'dampen', 'delay'],
    'intermediary': ['charlie mccarthy', 'agency', 'agent', 'agential', 'agentival', 'agentive', 'amidships', 'ancilla', 'appliance', 'arbiter', 'arbitrational', 'arbitrative'],
    'intermediate': ['charlie mccarthy', 'hydromatic', 'act between', 'agent', 'amidships', 'ancilla', 'appliance', 'arbitrate', 'arbitrational', 'arbitrative', 'arbitrator', 'automatic transmission'],
    'intermediator': ['agent', 'connection', 'deputy', 'entrepreneur', 'front', 'front man', 'go-between', 'interagent', 'interceder', 'intercessor', 'intermediary', 'intermediate'],
    'interment': ['burial', 'burying', 'clouding', 'concealedness', 'concealment', 'covering', 'covering up', 'covertness', 'darkening', 'deception', 'entombment', 'hiddenness'],
    'intermezzo': ['abeyance', 'act', 'afterpiece', 'anacrusis', 'bass passage', 'bit', 'bourdon', 'break', 'bridge', 'burden', 'cadence', 'caesura'],
    'interminable': ['a mile long', 'ageless', 'all-comprehensive', 'all-inclusive', 'articulated', 'boundless', 'catenated', 'ceaseless', 'coeternal', 'concatenated', 'connected', 'constant'],
    'interminably': ['ad infinitum', 'again and again', 'and night', 'at a stretch', 'boundlessly', 'ceaselessly', 'connectedly', 'constantly', 'continually', 'continuously', 'cumulatively', 'cyclically'],
    'intermingle': ['admix', 'alloy', 'amalgamate', 'bemingle', 'blend', 'coalesce', 'combine', 'commingle', 'commix', 'compose', 'compound', 'concoct'],
    'intermingling': ['admixture', 'alloyage', 'amalgamation', 'blending', 'coalescence', 'combination', 'comminglement', 'commingling', 'commixture', 'composition', 'eclecticism', 'fusion'],
    'intermission': ['abeyance', 'act', 'afterpiece', 'bit', 'breach', 'break', 'breath', 'breather', 'breathing place', 'breathing space', 'breathing spell', 'breathing time'],
    'intermit': ['alternate', 'arrest', 'be here again', 'break', 'break off', 'call a break', 'call time', 'check', 'circle', 'cleanse', 'cleanse away', 'come again'],
    'intermittence': ['abeyance', 'alternation', 'arrhythmia', 'beat', 'break', 'broken thread', 'brokenness', 'caesura', 'capriciousness', 'cease-fire', 'choppiness', 'coffee break'],
    'intermittent': ['alternate', 'alternating', 'arrested', 'beating', 'broken', 'broken off', 'capricious', 'careening', 'catchy', 'checked', 'chopped-off', 'choppy'],
    'intermittently': ['at intervals', 'at irregular intervals', 'at random', 'at regular intervals', 'at stated times', 'brokenly', 'by catches', 'by fits', 'by jerks', 'by skips', 'by snatches', 'capriciously'],
    'intermix': ['admix', 'alloy', 'amalgamate', 'bemingle', 'blend', 'coalesce', 'combine', 'commingle', 'commix', 'compose', 'compound', 'concoct'],
    'intern': ['doctor of medicine', 'gp', 'md', 'addressee', 'allopath', 'allopathist', 'apprentice teacher', 'artist-in-residence', 'attending physician', 'bastille', 'bolt in', 'bosom'],
    'internal': ['bosom', 'center', 'central', 'cerebral', 'conceptive', 'conceptual', 'core', 'deep', 'deep-seated', 'deepest recesses', 'endopsychic', 'esoteric'],
    'internal medicine': ['medicaid', 'medicare', 'aerospace medicine', 'biomedicine', 'clinical medicine', 'comparative medicine', 'constitutional medicine', 'dosimetric medicine', 'enterology', 'experimental medicine', 'leechcraft', 'leechdom'],
    'internally': ['by birth', 'by nature', 'centrally', 'congenitally', 'deeply', 'genetically', 'immanently', 'inly', 'innately', 'interiorly', 'intimately', 'intrinsically'],
    'international': ['all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'allover', 'catholic', 'civic'],
    'internationalism': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'appeasement', 'balance of power', 'brinkmanship', 'catholicity', 'coexistence', 'colonialism', 'compromise', 'containment'],
    'internecine': ['baneful', 'brutal', 'calamitous', 'cataclysmal', 'cataclysmic', 'catastrophic', 'consuming', 'consumptive', 'deadly', 'death-bringing', 'deathful', 'deathly'],
    'internist': ['anesthesiologist', 'cardiologist', 'chiropodist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'immunologist', 'neurologist', 'obstetrician', 'oculist'],
    'interplanetary': ['cynthian', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical', 'celestial', 'circumplanetary', 'cislunar'],
    'interplay': ['esp', 'alternation', 'answer', 'battledore and shuttlecock', 'coact', 'coaction', 'commerce', 'communication', 'communion', 'commutation', 'complementary distribution', 'concurrence'],
    'interpol': ['al', 'anzus council', 'aspac', 'arab league', 'bis', 'british commonwealth', 'cacm', 'cento', 'central treaty organization', 'cheka', 'colombo plan', 'common market'],
    'interpolate': ['add', 'admit', 'annex', 'append', 'drag in', 'edge in', 'enter', 'fill in', 'foist in', 'fudge in', 'implant in', 'inject in'],
    'interpolation': ['addition', 'affix', 'allonge', 'appendix', 'approximation', 'aside', 'cadenza', 'coda', 'codicil', 'commentary', 'differentiation', 'division'],
    'interpose': ['act between', 'arbitrate', 'bargain', 'barge in', 'break in', 'break in upon', 'burst in', 'butt in', 'cast', 'charge in', 'come between', 'crash'],
    'interposition': ['encroachment', 'entrance', 'entrenchment', 'impingement', 'imposition', 'incursion', 'infiltration', 'influx', 'infringement', 'injection', 'inroad', 'insinuation'],
    'interpret': ['accompany', 'annotate', 'answer', 'bottom', 'chord', 'clarify', 'clear up', 'comment', 'commentate', 'concertize', 'construe', 'crack'],
    'interpretable': ['englishable', 'accountable', 'allegorical', 'associational', 'connotational', 'connotative', 'construable', 'definable', 'denotational', 'denotative', 'describable', 'explainable'],
    'interpretation': ['accomplishment', 'analysis', 'answer', 'ascertainment', 'clarification', 'clearing up', 'construal', 'construction', 'cracking', 'decipherment', 'decoding', 'definition'],
    'interpreter': ['allegorist', 'annotator', 'artist', 'artiste', 'cicerone', 'clarifier', 'commentator', 'concert artist', 'critic', 'cryptanalyst', 'cryptographer', 'cryptologist'],
    'interrelate': ['ally', 'apply', 'associate', 'bind', 'bracket', 'connect', 'correlate', 'couple', 'draw a parallel', 'equate', 'identify', 'interally'],
    'interrelated': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'bound', 'bracketed', 'collateral', 'conjugate', 'connected', 'correlated', 'coupled'],
    'interrogate': ['answer', 'approach', 'ask', 'be curious', 'burn with curiosity', 'catechize', 'communicate with', 'contact', 'correspond', 'dig around for', 'dig up', 'establish connection'],
    'interrogation': ['socratic method', 'asking', 'bone of contention', 'bringing into question', 'catechetical method', 'catechism', 'catechization', 'catechizing', 'challenge', 'cross-examination', 'cross-interrogatory', 'cross-question'],
    'interrogative': ['bone of contention', 'catechism', 'cross-interrogatory', 'cross-question', 'debating point', 'demand', 'feeler', 'inquiry', 'interrogation', 'interrogatory', 'issue', 'leader'],
    'interrogator': ['asker', 'catechist', 'cross-interrogator', 'cross-questioner', 'detective', 'examiner', 'inquirer', 'inquisitionist', 'inquisitor', 'interlocutor', 'interpellator', 'interrogatrix'],
    'interrogatory': ['answering', 'catechistic', 'communicating', 'communicational', 'communional', 'conversational', 'curious', 'inquiring', 'inquisitional', 'inquisitorial', 'interacting', 'interactional'],
    'interrupt': ['arrest', 'barge in', 'blow it', 'bottle up', 'break', 'break in', 'break in on', 'break off', 'butt in', 'cease', 'check', 'chime in'],
    'interrupted': ['broken', 'broken off', 'chopped-off', 'choppy', 'decousu', 'disconnected', 'discontinued', 'discontinuous', 'discrete', 'disjunctive', 'episodic', 'fitful'],
    'interruption': ['abeyance', 'arrest', 'arrestation', 'arrestment', 'blockage', 'blocking', 'breach', 'break', 'caesura', 'cease', 'cease-fire', 'ceasing'],
    'interruptive': ['choking', 'constrictive', 'contrary', 'counterproductive', 'crosswise', 'hindering', 'hindersome', 'in the way', 'inhibiting', 'inhibitive', 'interfering', 'interrupting'],
    'intersect': ['accord', 'agree', 'answer to', 'approach', 'assent', 'assort with', 'bar', 'be consistent', 'be of one', 'be uniform with', 'bisect', 'center'],
    'intersection': ['access', 'accord', 'accordance', 'affinity', 'agreement', 'aisle', 'alley', 'ambulatory', 'aperture', 'arcade', 'artery', 'assent'],
    'interseptum': ['barrier', 'brattice', 'buffer', 'buffer state', 'bulkhead', 'bumper', 'cloison', 'collision mat', 'cushion', 'diaphragm', 'dissepiment', 'dividing line'],
    'interspace': ['caesura', 'clearance', 'discontinuity', 'dispart', 'distance between', 'double space', 'em space', 'en space', 'freeboard', 'hair space', 'half space', 'hiatus'],
    'interstellar': ['cynthian', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical', 'celestial', 'circumplanetary', 'cislunar'],
    'interstice': ['caesura', 'clearance', 'discontinuity', 'distance between', 'double space', 'em space', 'en space', 'freeboard', 'hair space', 'half space', 'hiatus', 'interim'],
    'intertwine': ['admix', 'alloy', 'amalgamate', 'bemingle', 'blend', 'braid', 'coact', 'coalesce', 'combine', 'commingle', 'commix', 'compose'],
    'intertwined': ['braided', 'enlaced', 'entwined', 'fretted', 'handwoven', 'interknit', 'interlaced', 'interthreaded', 'intertied', 'intertissued', 'interwoven', 'knit'],
    'intertwining': ['alternation', 'braiding', 'coaction', 'complementary distribution', 'concurrence', 'cooperation', 'engagement', 'enlacement', 'entwinement', 'entwining', 'fabric', 'interaction'],
    'interurban': ['amtrak', 'baggage train', 'burghal', 'cable railroad', 'choo-choo', 'citified', 'city', 'civic', 'cog railroad', 'cog railway', 'downtown', 'el'],
    'interval': ['abeyance', 'amount', 'aperture', 'arrearage', 'breach', 'break', 'broaching', 'caesura', 'caliber', 'cavity', 'cease-fire', 'cessation'],
    'intervene': ['act between', 'arbitrate', 'arrest', 'bargain', 'barge in', 'bottle up', 'break', 'break in', 'break in upon', 'burst in', 'butt in', 'call a break'],
    'intervening': ['arbitrational', 'arbitrative', 'coming between', 'going between', 'intercessional', 'intercessory', 'intercurrent', 'interjacent', 'interlocutory', 'intermedial', 'intermediary', 'intermediate'],
    'intervention': ['encroachment', 'entrance', 'entrenchment', 'impingement', 'imposition', 'incursion', 'infiltration', 'influx', 'infringement', 'injection', 'inroad', 'insinuation'],
    'interview': ['appointment', 'appraisal', 'appraise', 'arrangement', 'assessment', 'attention', 'audience', 'audition', 'bargaining', 'bargaining session', 'blind date', 'bugging'],
    'interweave': ['admix', 'alloy', 'amalgamate', 'associate', 'bemingle', 'blend', 'braid', 'coact', 'coalesce', 'combine', 'commingle', 'commix'],
    'interweaving': ['alternation', 'braiding', 'coaction', 'complementary distribution', 'concurrence', 'cooperation', 'engagement', 'enlacement', 'entwinement', 'entwining', 'fabric', 'interaction'],
    'interworking': ['alternation', 'coaction', 'complementary distribution', 'concurrence', 'cooperation', 'dovetailed', 'engagement', 'in gear', 'in mesh', 'interacting', 'interaction', 'interactive'],
    'interwoven': ['braided', 'enlaced', 'entwined', 'fretted', 'handwoven', 'interknit', 'interlaced', 'interthreaded', 'intertied', 'intertissued', 'intertwined', 'knit'],
    'intestinal': ['abdominal', 'anal', 'appendical', 'cardiac', 'cecal', 'colic', 'colonic', 'coronary', 'duodenal', 'enteric', 'gastric', 'ileac'],
    'intestinal fortitude': ['backbone', 'bottom', 'chutzpah', 'decisiveness', 'endurance', 'energy', 'force', 'fortitude', 'grit', 'guts', 'gutsiness', 'guttiness'],
    'intestine': ['eustachian tube', 'fallopian tube', 'abatis', 'abdomen', 'anus', 'bowels', 'brain', 'brains', 'canal', 'cecum', 'chitterlings', 'cockscomb'],
    'intimacy': ['accord', 'acquaintance', 'act of love', 'addition', 'adjunct', 'adultery', 'affability', 'affairs', 'affiliation', 'affinity', 'alliance', 'amiability'],
    'intimate': ['absolute', 'acquaintance', 'acquainted with', 'adumbrate', 'advocate', 'affectionate', 'allegorize', 'allied', 'allude to', 'alter ego', 'amigo', 'anonymous'],
    'intimately': ['agreeably', 'amiably', 'amicably', 'ardently', 'arm in arm', 'centrally', 'congenially', 'cordially', 'deeply', 'familiarly', 'favorably', 'friendliwise'],
    'intimation': ['allegory', 'allusion', 'arcane meaning', 'assumption', 'bare suggestion', 'breath', 'broad hint', 'cast', 'catchword', 'clue', 'coloration', 'connotation'],
    'intimidate': ['abash', 'admonish', 'alarm', 'awe', 'badger', 'bait', 'be imminent', 'beat down', 'blackjack', 'bludgeon', 'bluff', 'bluster'],
    'intimidated': ['afraid', 'aghast', 'appalled', 'ashen', 'astounded', 'awed', 'awestricken', 'awestruck', 'blanched', 'chicken', 'chickenhearted', 'coward'],
    'intimidating': ['abusive', 'admonitory', 'bludgeoning', 'blustering', 'browbeating', 'bulldozing', 'bullying', 'cautionary', 'comminatory', 'denunciatory', 'deterrent', 'discouraging'],
    'intimidation': ['admonition', 'argumentum baculinum', 'bluff', 'bluster', 'bluster and bluff', 'blustering', 'boastfulness', 'bravado', 'browbeating', 'bulldozing', 'bullying', 'bustle'],
    'intolerable': ['a bit much', 'abhorrent', 'absolute', 'arrant', 'classical', 'complete', 'consummate', 'crass', 'decided', 'definitive', 'dislikable', 'displeasing'],
    'intolerably': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly', 'damnably', 'deadly'],
    'intolerance': ['ageism', 'balkiness', 'bias', 'bigotry', 'bullheadedness', 'classism', 'determination', 'discrimination', 'doggedness', 'dogmatism', 'fanaticism', 'fixed mind'],
    'intolerant': ['ageist', 'antipathetic', 'averse', 'balking', 'balky', 'biased', 'bigoted', 'bulldogged', 'bulletheaded', 'bullheaded', 'case-hardened', 'classist'],
    'intonate': ['anthem', 'ballad', 'carol', 'chant', 'chirp', 'chirrup', 'choir', 'chorus', 'croon', 'descant', 'do-re-mi', 'hum'],
    'intonation': ['af', 'accent', 'accentuation', 'adaptation', 'arrangement', 'articulation', 'audio frequency', 'bel canto', 'bravura', 'cantando', 'choral singing', 'coloratura'],
    'intone': ['anthem', 'ballad', 'carol', 'chant', 'chirp', 'chirrup', 'choir', 'chorus', 'croon', 'descant', 'do-re-mi', 'hum'],
    'intoxicate': ['addle', 'animate', 'befuddle', 'bemuse', 'besot', 'bewitch', 'cause vertigo', 'dizzy', 'elate', 'electrify', 'enchant', 'enliven'],
    'intoxicated': ['abandoned', 'ablaze', 'addled', 'affected', 'afire', 'amok', 'ardent', 'beery', 'befuddled', 'bellowing', 'bemused', 'berserk'],
    'intoxicating': ['agitating', 'alcoholic', 'breathtaking', 'charged', 'cliff-hanging', 'disquieting', 'distracting', 'disturbing', 'electric', 'electrifying', 'entrancing', 'exciting'],
    'intoxication': ['abandon', 'autointoxication', 'beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'blood poisoning', 'cheer', 'cheerfulness', 'cloud nine'],
    'intractability': ['civil disobedience', 'contumaciousness', 'contumacy', 'defiance', 'disobedience', 'fractiousness', 'frowardness', 'immovability', 'immutability', 'incorrigibility', 'indiscipline', 'indocility'],
    'intractable': ['adamant', 'adamantine', 'beyond control', 'breachy', 'bullheaded', 'contumacious', 'defiant', 'fractious', 'headstrong', 'immovable', 'immutable', 'incorrigible'],
    'intransient': ['abiding', 'age-long', 'aged', 'ancient', 'antique', 'chronic', 'constant', 'continuing', 'diuturnal', 'durable', 'enduring', 'evergreen'],
    'intransigence': ['adamantness', 'dourness', 'firmness', 'flintiness', 'grimness', 'hard-bittenness', 'hard-nosedness', 'immovability', 'immutability', 'implacability', 'impliability', 'inelasticity'],
    'intransigent': ['adamant', 'adamantine', 'ass', 'bigot', 'bitter-ender', 'brawler', 'bullethead', 'cast-iron', 'defendant', 'diehard', 'disputant', 'dissentient'],
    'intransitive': ['adjectival', 'adverbial', 'attributive', 'auxiliary', 'auxiliary verb', 'conjunctive', 'copula', 'copulative', 'correct', 'defective verb', 'deponent verb', 'finite verb'],
    'intransmutable': ['changeless', 'constant', 'immutable', 'incommutable', 'inconvertible', 'indefeasible', 'inert', 'insusceptible of change', 'invariable', 'irretrievable', 'irreversible', 'irrevocable'],
    'intrepid': ['adventurous', 'audacious', 'bold', 'bold-spirited', 'brave', 'chivalric', 'chivalrous', 'courageous', 'daring', 'dashing', 'dauntless', 'doughty'],
    'intrepidly': ['audaciously', 'boldly', 'bravely', 'bulldoggishly', 'chivalrously', 'courageously', 'daringly', 'doughtily', 'fearlessly', 'gallantly', 'gamely', 'gutsily'],
    'intricacy': ['abstruseness', 'arduousness', 'bothersomeness', 'burdensomeness', 'complexity', 'complexness', 'complication', 'convolution', 'crabbedness', 'crampedness', 'deepness', 'difficultness'],
    'intricate': ['byzantine', 'daedalian', 'herculean', 'abstruse', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'anfractuous', 'arduous', 'baffling', 'balled up'],
    'intrigue': ['byzantine intrigues', 'absorb', 'adulterous affair', 'adultery', 'affair', 'amor', 'amour', 'angle', 'appeal', 'art', 'artful dodge', 'artfulness'],
    'intriguing': ['byzantine', 'machiavellian', 'alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'calculating', 'captivating'],
    'intrinsic': ['actual', 'appropriate', 'basic', 'central', 'characteristic', 'congenital', 'connate', 'constitutional', 'deep', 'deep-seated', 'distinctive', 'distinguished'],
    'intrinsically': ['by birth', 'by nature', 'centrally', 'characteristically', 'congenitally', 'deeply', 'distinctively', 'genetically', 'immanently', 'inly', 'innately', 'interiorly'],
    'introduce': ['acquaint', 'add', 'admit', 'advance', 'announce', 'begin', 'blaze the trail', 'break the trail', 'bring before', 'bring forward', 'bring in', 'bring out'],
    'introducer': ['agent', 'alterant', 'alterative', 'alterer', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner'],
    'introduction': ['vorspiel', 'abecedarium', 'abecedary', 'access', 'acknowledgments', 'acquaintance', 'acquaintedness', 'act', 'admission', 'afterpiece', 'and arithmetic', 'aside'],
    'introductory': ['abecedarian', 'aboriginal', 'antenatal', 'autochthonous', 'autodidactic', 'baptismal', 'basic', 'beginning', 'budding', 'coeducational', 'creative', 'cultural'],
    'introit': ['negro spiritual', 'anthem', 'cantata', 'canticle', 'chorale', 'church music', 'doxology', 'gospel', 'gospel music', 'hymn', 'hymn-tune', 'hymnody'],
    'intromission': ['acceptance', 'admission', 'admittance', 'baptism', 'embedment', 'enlistment', 'enrollment', 'entrance', 'graft', 'grafting', 'immission', 'impaction'],
    'intromit': ['admit', 'ease in', 'give an entree', 'immit', 'infuse', 'inject', 'inoculate', 'insert', 'insinuate', 'interject', 'introduce', 'let in'],
    'introspect': ['be abstracted', 'brood', 'chew the cud', 'consider', 'contemplate', 'debate', 'deliberate', 'digest', 'meditate', 'muse', 'perpend', 'play around with'],
    'introspective': ['absorbed', 'abstracted', 'buried in thought', 'cogitative', 'cognitive', 'concentrating', 'concentrative', 'conceptive', 'conceptual', 'conceptualized', 'contemplating', 'contemplative'],
    'introversion': ['aloofness', 'ambiversion', 'backwardness', 'bashfulness', 'blankness', 'chilliness', 'coldness', 'complexion', 'constraint', 'coolness', 'cycloid personality', 'cyclothymia'],
    'introvert': ['ambivert', 'choleric', 'convert', 'cycloid', 'cyclothyme', 'cyclothymic', 'ectomorph', 'endomorph', 'evert', 'extrovert', 'intussuscept', 'invaginate'],
    'introverted': ['olympian', 'aloof', 'arsy-varsy', 'ass over elbows', 'back-to-front', 'backward', 'backwards', 'bashful', 'blank', 'capsized', 'chiastic', 'chilled'],
    'intrude': ['admit', 'advance upon', 'barge in', 'be admitted', 'blow it', 'bother', 'break bounds', 'break in', 'break in upon', 'breeze in', 'burst in', 'bust in'],
    'intruder': ['arrival', 'arriviste', 'black sheep', 'blemish', 'burglar', 'busybody', 'buttinsky', 'comer', 'crasher', 'emigrant', 'encroacher', 'entrant'],
    'intrusion': ['access', 'admission', 'alienage', 'alienism', 'encroachment', 'entrance', 'entree', 'entry', 'exteriority', 'extraneousness', 'extrinsicality', 'foreignness'],
    'intrusive': ['alien', 'barbarian', 'barbaric', 'barbarous', 'busy', 'entering', 'exotic', 'exterior', 'external', 'extraneous', 'extraterrestrial', 'extrinsic'],
    'intuition': ['esp', 'anschauung', 'clairsentience', 'clairvoyance', 'common sense', 'extrasensory perception', 'feeling', 'foreboding', 'forefeeling', 'foresight', 'funny feeling', 'hunch'],
    'intuitive': ['anticipant', 'anticipatory', 'augural', 'clairvoyant', 'direct', 'divinatory', 'farseeing', 'farsighted', 'feeling', 'forehanded', 'foreknowing', 'forerunning'],
    'intumescence': ['benign tumor', 'bloat', 'bloatedness', 'bloating', 'blowing up', 'boil', 'bump', 'bunion', 'callosity', 'callus', 'cancer', 'carbuncle'],
    'inundate': ['afflict', 'aggrieve', 'anguish', 'baptize', 'be prodigal with', 'board', 'break down', 'bring to tears', 'bury', 'cascade', 'cataract', 'crush'],
    'inundated': ['afloat', 'at flood', 'awash', 'bathed', 'broken-down', 'brokenhearted', 'buried', 'crushed', 'cut up', 'deluged', 'desolated', 'dipped'],
    'inundation': ['affusion', 'alluvion', 'alluvium', 'aspergation', 'aspersion', 'avalanche', 'baptism', 'bath', 'bathing', 'bedewing', 'burial', 'cataclysm'],
    'inure': ['acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'break', 'break in', 'brutalize', 'callous', 'case harden', 'condition'],
    'inured': ['philistine', 'acclimated', 'acclimatized', 'accommodated', 'accustomed', 'adapted', 'adjusted', 'brazen', 'callous', 'calloused', 'case-hardened', 'conditioned'],
    'invade': ['adopt', 'advance upon', 'appropriate', 'arrogate', 'assume', 'barge in', 'beset', 'board', 'break bounds', 'break in', 'break in upon', 'burst in'],
    'invalid': ['diogenes', 'hieronymian', 'hieronymite', 'timon of athens', 'absonant', 'afflict', 'ailing', 'anchoress', 'anchorite', 'annulled', 'apoplectic', 'arthritic'],
    'invalidate': ['abate', 'abolish', 'abrogate', 'annihilate', 'annul', 'belie', 'blow sky-high', 'blow up', 'bring to naught', 'bring to nothing', 'buffer', 'cancel'],
    'invalidated': ['belied', 'confounded', 'confuted', 'crippled', 'deflated', 'denied', 'disabled', 'disarmed', 'discarded', 'discredited', 'dismissed', 'disproved'],
    'invalidation': ['abolishment', 'abolition', 'abrogation', 'annulment', 'cancel', 'canceling', 'cancellation', 'cassation', 'counterbalancing', 'countermand', 'counterorder', 'defeasance'],
    'invariable': ['abiding', 'accordant', 'alike', 'automatic', 'balanced', 'blah', 'broken-record', 'changeless', 'consistent', 'consonant', 'constant', 'continuous'],
    'invariably': ['abidingly', 'all along', 'all over', 'all the time', 'all the while', 'always', 'at all times', 'at every turn', 'changelessly', 'constantly', 'continually', 'cosmically'],
    'invasion': ['adoption', 'aggression', 'air attack', 'air raid', 'air strike', 'appropriation', 'arrogation', 'assault', 'assumption', 'attack', 'blitzkrieg', 'boarding'],
    'invasive': ['advancing', 'assailing', 'assaulting', 'attacking', 'charging', 'driving', 'entering', 'in', 'inbound', 'incoming', 'incursionary', 'incursive'],
    'invective': ['abuse', 'abusive', 'address', 'after-dinner speech', 'allocution', 'assailing', 'assault', 'attack', 'berating', 'billingsgate', 'bitter words', 'blackening'],
    'inveigh against': ['accuse', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'blame', 'call to account', 'cast blame upon', 'cast reflection upon', 'censure', 'complain against', 'condemn'],
    'inveigle': ['allure', 'bait', 'bait the hook', 'birdlime', 'blandish', 'cajole', 'catch', 'catch out', 'coax', 'decoy', 'draw', 'draw in'],
    'inveiglement': ['agacerie', 'allure', 'allurement', 'appeal', 'attraction', 'attractiveness', 'bait', 'beguilement', 'beguiling', 'bewitchery', 'bewitchment', 'blandishment'],
    'invent': ['beget', 'break ground', 'break the ice', 'breed', 'bring forth', 'bring into being', 'call into being', 'coin', 'conceit', 'conceive', 'conceptualize', 'concoct'],
    'invented': ['coined', 'conceived', 'concocted', 'cooked-up', 'discovered', 'fabricated', 'fabulous', 'fancied', 'fantasied', 'fantastic', 'fictional', 'fictitious'],
    'invention': ['nachtmusik', 'absolute music', 'adaptation', 'air varie', 'aleatory', 'aleatory music', 'apparition', 'arrangement', 'artifact', 'authorship', 'beginning', 'brainchild'],
    'inventive': ['machiavellian', 'machiavellic', 'abecedarian', 'aboriginal', 'acute', 'antenatal', 'arch', 'artful', 'astute', 'autochthonous', 'beginning', 'budding'],
    'inventiveness': ['italian hand', 'acuteness', 'art', 'artfulness', 'artifice', 'astuteness', 'authenticity', 'cageyness', 'callidity', 'canniness', 'cleverness', 'craft'],
    'inventor': ['ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner', 'builder', 'conceiver', 'constructor', 'craftsman'],
    'inventory': ['abundance', 'account', 'account book', 'accounts', 'accounts payable ledger', 'accounts receivable ledger', 'accumulation', 'active list', 'add up', 'amassment', 'annals', 'assemblage'],
    'inverse': ['adversative', 'adverse', 'adversive', 'antagonistic', 'anti', 'antipathetic', 'antipodal', 'antipode', 'antipodes', 'antipole', 'antithesis', 'antithetic'],
    'inversely': ['a rebours', 'against the grain', 'arsy-varsy', 'backwards', 'bottom side up', 'bottom up', 'by contraries', 'contra', 'contrarily', 'contrariously', 'contrariwise', 'conversely'],
    'inversion': ['about-face', 'addition', 'approximation', 'differentiation', 'division', 'equation', 'evolution', 'extrapolation', 'integration', 'interpolation', 'involution', 'multiplication'],
    'invert': ['auntie', 'bi-guy', 'bisexual', 'bull dyke', 'butch', 'catamite', 'change', 'chicken', 'convert', 'dyke', 'evert', 'fag'],
    'invertebrate': ['milquetoast', 'abulic', 'afraid', 'amphibian', 'aquatic', 'baby', 'big baby', 'biped', 'canine', 'cannibal', 'carnivore', 'chicken'],
    'inverted': ['arsy-varsy', 'ass over elbows', 'back-to-front', 'backwards', 'capsized', 'chiastic', 'everted', 'gay', 'homoerotic', 'homophile', 'hyperbatic', 'inside out'],
    'invest': ['accommodate', 'afford', 'allot', 'anoint', 'apparel', 'arm', 'array', 'attire', 'authorize', 'base', 'bedeck', 'bedrape'],
    'invested': ['accoutered', 'appareled', 'armed', 'arrayed', 'attired', 'bedecked', 'breeched', 'capped', 'catered', 'chausse', 'clad', 'cloaked'],
    'investigate': ['air', 'analyze', 'canvass', 'comment upon', 'consider', 'controvert', 'deal with', 'debate', 'deliberate', 'deliberate upon', 'delve into', 'dig into'],
    'investigation': ['airing', 'amassing evidence', 'analysis', 'buzz session', 'canvassing', 'close inquiry', 'colloquium', 'conference', 'consideration', 'debate', 'debating', 'deliberation'],
    'investigative': ['analytic', 'curious', 'examinational', 'examinatorial', 'examining', 'explorational', 'explorative', 'exploratory', 'fact-finding', 'feeling', 'groping', 'heuristic'],
    'investigator': ['bow street runner', 'fbi', 'fbi agent', 'federal', 'g-man', 'secret service', 'sherlock', 'sherlock holmes', 't-man', 'detective', 'dick', 'examinant'],
    'investiture': ['accedence', 'acceptance', 'accession', 'accommodation', 'accordance', 'admission', 'admittance', 'anchorage', 'apostolic orders', 'apparel', 'appointment', 'array'],
    'investment': ['accouterment', 'aerial tactics', 'airborne tactics', 'appanage', 'apparel', 'applied tactics', 'armament', 'armored tactics', 'array', 'attire', 'barrier tactics', 'bedizenment'],
    'inveteracy': ['abidingness', 'aboriginality', 'accustomedness', 'age', 'ancien regime', 'ancientness', 'antiquity', 'atavism', 'changelessness', 'cobwebs of antiquity', 'commonness', 'confirmation'],
    'inveterate': ['abiding', 'accustomed', 'acknowledged', 'addicted', 'admitted', 'age-long', 'aged', 'ancient', 'antique', 'chronic', 'confirmed', 'constant'],
    'invidious': ['abhorrent', 'abominable', 'baleful', 'begrudging', 'bitchy', 'bitter', 'calumnious', 'covetous', 'cussed', 'defamatory', 'desirous of', 'detestable'],
    'invigorate': ['activate', 'animate', 'arouse', 'beef up', 'boost', 'brace', 'brace up', 'brighten', 'brisk', 'brisken', 'buck up', 'buoy up'],
    'invigorating': ['activating', 'analeptic', 'animating', 'animative', 'beneficial', 'benign', 'bracing', 'brisk', 'cheerful', 'cheering', 'cheery', 'chill'],
    'invincibility': ['authenticity', 'authoritativeness', 'calculability', 'deathlessness', 'dependability', 'faithworthiness', 'firmness', 'immortality', 'impenetrability', 'imperishability', 'impregnability', 'incorruptibility'],
    'invincible': ['assiduous', 'beyond compare', 'beyond comparison', 'calculable', 'constant', 'continuing', 'deathless', 'dependable', 'diligent', 'dogged', 'easily first', 'enduring'],
    'inviolable': ['awesome', 'awful', 'blessed', 'chaste', 'consecrated', 'dependable', 'divine', 'faithworthy', 'hallowed', 'heavenly', 'holy', 'impenetrable'],
    'inviolate': ['christian', 'abiding', 'awesome', 'awful', 'blameless', 'bright', 'changeless', 'clean', 'constant', 'continuing', 'creditable', 'decent'],
    'invisibility': ['burial', 'burying', 'clouding', 'concealedness', 'concealment', 'covering', 'covering up', 'covertness', 'darkening', 'deception', 'evanescence', 'hiddenness'],
    'invisible': ['atomic', 'behind the curtain', 'behind the scenes', 'camouflaged', 'concealed', 'corpuscular', 'covered', 'disguised', 'embryonic', 'evanescent', 'germinal', 'granular'],
    'invitation': ['advance', 'agacerie', 'allure', 'allurement', 'appeal', 'approach', 'asking price', 'attraction', 'attractiveness', 'bait', 'beguilement', 'beguiling'],
    'invite': ['abet', 'acquire', 'affect the interest', 'aid and abet', 'appeal', 'ask', 'ask for', 'attract', 'be attractive', 'be responsible for', 'beckon', 'bid'],
    'inviting': ['admissible', 'admissive', 'admissory', 'alluring', 'appealing', 'appetizing', 'attractive', 'beckoning', 'beguiling', 'bewitching', 'blandishing', 'cajoling'],
    'invocation': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'adjuration', 'agape', 'aid prayer', 'appeal', 'asperges', 'aspersion'],
    'invoice': ['account', 'bill', 'bill of account', 'bill of fare', 'bill of lading', 'books', 'call', 'call in', 'carte', 'check', 'demand payment', 'dun'],
    'invoke': ['accost', 'address', 'adjure', 'apostrophize', 'appeal', 'appeal to', 'approach', 'beg', 'beseech', 'bespeak', 'bid come', 'buttonhole'],
    'involuntarily': ['automatically', 'blindly', 'by reflex', 'carelessly', 'compulsively', 'heedlessly', 'inadvertently', 'inconsiderately', 'indeliberately', 'instinctively', 'malgre soi', 'mechanically'],
    'involuntary': ['at odds', 'automatic', 'averse', 'binding', 'blind', 'casual', 'compulsive', 'compulsory', 'conditioned', 'cursory', 'dictated', 'differing'],
    'involuted': ['byzantine', 'ambagious', 'anfractuous', 'balled up', 'circuitous', 'circumlocutory', 'complex', 'complicated', 'confounded', 'confused', 'convoluted', 'convolutional'],
    'involution': ['absorption', 'addition', 'ambages', 'anfractuosity', 'approximation', 'circuitousness', 'circumambages', 'circumbendibus', 'circumlocution', 'circumvolution', 'comedown', 'complexity'],
    'involve': ['absorb', 'absorb the attention', 'adorn', 'affect', 'affect the interest', 'allegorize', 'allude to', 'answer to', 'appertain to', 'apply to', 'approve', 'argue'],
    'involved': ['byzantine', 'a party to', 'absorbed', 'absorbed in', 'accessory', 'accused', 'active', 'affected', 'affiliate', 'affiliated', 'allied', 'arraignable'],
    'involvement': ['absorbed attention', 'absorption', 'application', 'arraignability', 'arraignableness', 'assault', 'association', 'assumption', 'attack', 'bias', 'blameworthiness', 'bloody hands'],
    'invulnerable': ['armed', 'cloaked', 'copyrighted', 'covered', 'deathless', 'defended', 'dependable', 'fail-safe', 'firm', 'guaranteed', 'guarded', 'harmless'],
    'inward': ['anonymous', 'bosom', 'center', 'central', 'closet', 'core', 'deep', 'deep-seated', 'deepest recesses', 'entering', 'esoteric', 'guts'],
    'inwardly': ['by birth', 'by nature', 'centrally', 'congenitally', 'deeply', 'genetically', 'immanently', 'in', 'inland', 'inly', 'innately', 'inshore'],
    'inwardness': ['depth', 'essentiality', 'experience', 'familiarity', 'fundamentality', 'immanence', 'inbeing', 'indigenousness', 'indwelling', 'inherence', 'innateness', 'innerness'],
    'iodine': ['argyrol', 'mercurochrome', 'merthiolate', 'salol', 'alcohol', 'boric acid', 'calomel', 'camphor', 'carbolic acid', 'chloramine', 'cresol', 'gentian violet'],
    'ion': ['acid', 'acidity', 'agent', 'alkali', 'alkalinity', 'alloisomer', 'anion', 'antacid', 'atom', 'atomic model', 'base', 'biochemical'],
    'ionization': ['alpha decay', 'anion', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction', 'atomization', 'beta decay', 'bombardment', 'breeding', 'bullet', 'cation'],
    'ionosphere': ['appleton layer', 'cat', 'f layer', 'heaviside-kennelly layer', 'van allen belt', 'aerospace', 'aerosphere', 'air hole', 'air pocket', 'airspace', 'belt', 'bump'],
    'iota': ['ace', 'atom', 'bit', 'crumb', 'dab', 'dole', 'dot', 'dram', 'dribble', 'driblet', 'drop', 'droplet'],
    'iou': ['cd', 'mo', 'acceptance', 'acceptance bill', 'bank acceptance', 'bank check', 'bill', 'bill of draft', 'bill of exchange', 'blank check', 'certificate', 'certificate of deposit'],
    'ipse dixit': ['affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'appointment', 'assertion', 'asseveration', 'averment', 'avouchment', 'avowal', 'brevet'],
    'iq': ['binet-simon test', 'brown personality inventory', 'goldstein-sheerer test', 'iq test', 'kent mental test', 'minnesota preschool scale', 'oseretsky test', 'rorschach test', 'stanford revision', 'stanford-binet test', 'szondi test', 'tat'],
    'irascibility': ['aggressiveness', 'agitability', 'bearishness', 'bellicosity', 'belligerence', 'bickering', 'bitchiness', 'cantankerousness', 'churlishness', 'combativeness', 'combustibility', 'contentiousness'],
    'irascible': ['agitable', 'bearish', 'bitchy', 'cankered', 'cantankerous', 'churlish', 'contrary', 'crabbed', 'cranky', 'cross', 'cross-grained', 'crusty'],
    'irate': ['angered', 'angry', 'browned-off', 'choleric', 'cross', 'incensed', 'indignant', 'ireful', 'livid', 'mad', 'pissed', 'pissed-off'],
    'ire': ['a transient madness', 'anger', 'angriness', 'enrage', 'enragement', 'fury', 'grapes of wrath', 'heat', 'incense', 'indignation', 'infuriate', 'infuriation'],
    'irenic': ['appeasing', 'civilian', 'conciliatory', 'dovish', 'mollifying', 'nonaggressive', 'noncombatant', 'nonmilitant', 'nonviolent', 'pacific', 'pacificatory', 'pacifist'],
    'iridescent': ['burele', 'chatoyant', 'creamy', 'delicate', 'eggshell', 'flat', 'gloss', 'iridal', 'iridial', 'iridian', 'irisated', 'irised'],
    'iris': ['dalmatian', 'antigorite', 'baby blues', 'band', 'banjo eyes', 'bar', 'bespangle', 'bespeckle', 'bespot', 'blotch', 'bright eyes', 'butterfly'],
    'irk': ['abrade', 'aggravate', 'ail', 'annoy', 'badger', 'bait', 'be at', 'be infinitely repetitive', 'be tedious', 'be the matter', 'bedevil', 'beset'],
    'irked': ['aggravated', 'angry', 'annoyed', 'anxious', 'beset', 'blase', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'chafed', 'dispirited'],
    'irksome': ['aggravating', 'annoying', 'backbreaking', 'besetting', 'boresome', 'boring', 'bothering', 'bothersome', 'burdensome', 'chafing', 'crushing', 'disturbing'],
    'iron': ['gibraltar', 'oregon boat', 'adamant', 'adamantine', 'aluminum', 'americium', 'aureate', 'barium', 'beryllium', 'bicycle', 'bike', 'bilbo'],
    'iron curtain': ['berlin wall', 'bolshevism', 'castroism', 'communist information bureau', 'communist party', 'maoism', 'marxian socialism', 'marxism', 'marxism-leninism', 'pillars of hercules', 'stalinism', 'titoism'],
    'iron grip': ['bear hug', 'bite', 'clamp', 'clasp', 'clench', 'clinch', 'cling', 'clinging', 'clutch', 'death grip', 'embrace', 'firm hold'],
    'iron hand': ['administration', 'argumentum baculinum', 'authority', 'big stick', 'claws', 'clutches', 'command', 'control', 'despotism', 'disposition', 'domination', 'domineering'],
    'iron lung': ['aqua-lung', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'breath', 'breath of air', 'breathing', 'broken wind', 'cough', 'exhalation', 'expiration', 'exsufflation'],
    'ironbound': ['asperous', 'bound', 'corrugated', 'cragged', 'craggy', 'crinkled', 'crumpled', 'dour', 'fettered', 'firm', 'fundamentalist', 'gravelly'],
    'ironclad': ['armed cap-a-pie', 'armor-plated', 'armored', 'constant', 'dour', 'firm', 'fixed', 'fundamentalist', 'hard', 'hidebound', 'immovable', 'immutable'],
    'ironic': ['rabelaisian', 'allusive', 'allusory', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'amphibological', 'amphibolous', 'antinomic', 'biting', 'blended'],
    'ironmonger': ['baker', 'bookdealer', 'bookseller', 'butcher', 'chandler', 'clothing merchant', 'confectioner', 'draper', 'drysalter', 'fishmonger', 'fishwife', 'florist'],
    'irony': ['atticism', 'janus', 'agile wit', 'ambiguity', 'ambiguousness', 'ambivalence', 'amphibology', 'antinomy', 'biformity', 'bifurcation', 'black humor', 'burlesque'],
    'irradiate': ['x-ray', 'activate', 'anhydrate', 'beacon', 'blast-freeze', 'brighten', 'brighten up', 'brine', 'charge', 'contaminate', 'corn', 'cure'],
    'irradiated': ['ablaze', 'activated', 'aglow', 'alight', 'autoluminescent', 'bathed with light', 'bespangled', 'brightened', 'candlelit', 'charged', 'contaminated', 'enlightened'],
    'irradiation': ['x-ray dosimetry', 'x-ray therapy', 'anhydration', 'arc lighting', 'black and white', 'blast-freezing', 'bottling', 'brining', 'canning', 'chiaroscuro', 'cobalt therapy', 'contrast'],
    'irrational': ['abnormal', 'absonant', 'algorismic', 'algorithmic', 'aliquot', 'bereft of reason', 'bigoted', 'brainless', 'brainsick', 'cardinal', 'contradictory', 'contrary to reason'],
    'irrationality': ['urdummheit', 'aberration', 'abnormality', 'alienation', 'antilogy', 'brain damage', 'brainlessness', 'brainsickness', 'callowness', 'childishness', 'clouded mind', 'craziness'],
    'irreclaimable': ['beyond recall', 'beyond remedy', 'cureless', 'gone', 'graceless', 'immedicable', 'incorrigible', 'incurable', 'inoperable', 'irrecoverable', 'irredeemable', 'irreformable'],
    'irreconcilable': ['abnormal', 'absurd', 'adamant', 'adamantine', 'alienated', 'anomalous', 'assorted', 'at odds', 'at variance', 'avenging', 'bitter-ender', 'brawler'],
    'irrecoverable': ['ago', 'antiquated', 'antique', 'beyond recall', 'beyond remedy', 'blown over', 'by', 'bygone', 'bypast', 'cureless', 'dated', 'dead'],
    'irredeemable': ['beyond recall', 'beyond remedy', 'cureless', 'gone', 'graceless', 'immedicable', 'inconvertible', 'incorrigible', 'incurable', 'inoperable', 'irreclaimable', 'irrecoverable'],
    'irreducible': ['a certain', 'an', 'any', 'any one', 'atomic', 'austere', 'bare', 'basic', 'called for', 'chaste', 'deep-seated', 'either'],
    'irreformable': ['beyond recall', 'beyond remedy', 'cureless', 'gone', 'graceless', 'immedicable', 'incorrigible', 'incurable', 'inoperable', 'irreclaimable', 'irrecoverable', 'irredeemable'],
    'irrefutable': ['absolute', 'actual', 'adducible', 'admissible', 'admitting no question', 'attestative', 'attestive', 'authentic', 'based on', 'certain', 'circumstantial', 'conclusive'],
    'irregardless': ['anyhow', 'anyway', 'anywise', 'at all', 'at all costs', 'at any cost', 'at any rate', 'by any means', 'despite', 'even with', 'however', 'in any case'],
    'irregular': ['bohemian', 'charley', 'mickey mouse', 'vc', 'vietcong', 'aberrant', 'abnormal', 'actionable', 'adrift', 'affable', 'afloat', 'against the law'],
    'irregularity': ['bohemianism', 'aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'affability', 'amorphism', 'anamorphism', 'anamorphosis', 'anomalism', 'anomalousness'],
    'irregularly': ['at haphazard', 'at intervals', 'at irregular intervals', 'at random', 'brokenly', 'by catches', 'by chance', 'by fits', 'by jerks', 'by snatches', 'capriciously', 'carelessly'],
    'irrelevance': ['abnormality', 'anomaly', 'disassociation', 'disconnection', 'discreteness', 'disjunction', 'disjuncture', 'dissociation', 'immateriality', 'impertinence', 'impropriety', 'inadmissibility'],
    'irrelevant': ['adrift', 'alien', 'back-burner', 'beside the mark', 'beside the point', 'beside the question', 'dinky', 'dispensable', 'extraneous', 'extrinsic', 'foreign', 'gratuitous'],
    'irreligion': ['apostasy', 'atheism', 'backsliding', 'desertion', 'fall from grace', 'godlessness', 'impiety', 'impiousness', 'irreverence', 'lapse', 'lapse from grace', 'recidivism'],
    'irreligious': ['amoral', 'apostate', 'atheistic', 'backsliding', 'blasphemous', 'creedless', 'disbelieving', 'faithless', 'fallen', 'fallen from grace', 'godless', 'heretical'],
    'irremediable': ['ausgespielt', 'bankrupt', 'beyond recall', 'beyond remedy', 'blasted', 'blighted', 'broken', 'cureless', 'desolated', 'destroyed', 'devastated', 'done for'],
    'irremovable': ['adamant', 'adamantine', 'at a standstill', 'firm', 'fixed', 'frozen', 'immobile', 'immotile', 'immotive', 'immovable', 'inflexible', 'pat'],
    'irreparable': ['beyond recall', 'beyond remedy', 'cureless', 'gone', 'immedicable', 'impossible', 'incorrigible', 'incurable', 'inoperable', 'irreclaimable', 'irrecoverable', 'irredeemable'],
    'irrepressible': ['abandoned', 'beaming', 'beyond control', 'blithe', 'blithesome', 'boisterous', 'breachy', 'bright', 'bright and sunny', 'bubbling', 'buoyant', 'cheerful'],
    'irreproachable': ['christian', 'above suspicion', 'absolute', 'beyond all praise', 'blameless', 'chaste', 'clean', 'creditable', 'decent', 'defectless', 'erect', 'errorless'],
    'irresistible': ['absolute', 'adducible', 'admissible', 'alluring', 'appealing', 'appetizing', 'armipotent', 'attestative', 'attestive', 'attractive', 'authentic', 'authoritative'],
    'irresolute': ['adrift', 'afloat', 'agnostic', 'alternating', 'ambiguous', 'ambitendent', 'ambivalent', 'amorphous', 'at loose ends', 'bland', 'capricious', 'chancy'],
    'irresolution': ['amiable weakness', 'breakability', 'brittleness', 'capriciousness', 'chance', 'chanciness', 'changeableness', 'collapse', 'daintiness', 'delicacy', 'destructibility', 'disintegration'],
    'irresponsible': ['adrift', 'afloat', 'alternating', 'amorphous', 'capricious', 'carefree', 'careless', 'changeable', 'changeful', 'chartered', 'desultory', 'deviable'],
    'irretrievable': ['ablated', 'beyond recall', 'beyond remedy', 'by the board', 'changeless', 'constant', 'consumed', 'cureless', 'depleted', 'dissipated', 'eroded', 'expended'],
    'irretrievably': ['absolutely', 'clean', 'irreclaimably', 'irrecoverably', 'irredeemably', 'irremediably', 'irreparably', 'irreversibly', 'irrevocably', 'perfectly', 'plain', 'plumb'],
    'irreverence': ['apostasy', 'atheism', 'backsliding', 'desertion', 'discourtesy', 'disesteem', 'dishonor', 'disparagement', 'disrespect', 'disrespectfulness', 'fall from grace', 'impiety'],
    'irreverent': ['apostate', 'atheistic', 'aweless', 'backsliding', 'blasphemous', 'cheeky', 'derisive', 'discourteous', 'disparaging', 'disrespectful', 'fallen', 'fallen from grace'],
    'irreversible': ['beyond recall', 'beyond remedy', 'changeless', 'chronic', 'confirmed', 'constant', 'cureless', 'deep-dyed', 'deep-fixed', 'deep-rooted', 'deep-seated', 'deep-set'],
    'irrevocable': ['absolute', 'beyond recall', 'beyond remedy', 'binding', 'certain', 'changeless', 'compulsory', 'conclusive', 'constant', 'cureless', 'decisive', 'decretory'],
    'irrevocably': ['absolutely', 'certainly', 'clean', 'fatefully', 'indefeasibly', 'ineluctably', 'inescapably', 'inevasibly', 'inevitably', 'inexorably', 'inflexibly', 'irreclaimably'],
    'irrigate': ['adulterate', 'asperge', 'attenuate', 'baptize', 'bath', 'bathe', 'bedew', 'bespatter', 'besprinkle', 'cut', 'dabble', 'damp'],
    'irrigation': ['ablution', 'affusion', 'aspergation', 'aspersion', 'baptism', 'bath', 'bathing', 'bedewing', 'cleaning out', 'dampening', 'damping', 'deluge'],
    'irritable': ['aggressive', 'agitable', 'all nerves', 'allergic', 'anaphylactic', 'apprehensive', 'bad-tempered', 'bearish', 'bellicose', 'belligerent', 'bickering', 'bitchy'],
    'irritate': ['abrade', 'afflict', 'affront', 'agent provocateur', 'aggravate', 'agonize', 'ail', 'alienate', 'amplify', 'anger', 'annoy', 'arouse'],
    'irritated': ['aggravated', 'algetic', 'amplified', 'angry', 'annoyed', 'augmented', 'bothered', 'broken', 'browned-off', 'bugged', 'burned', 'burning'],
    'irritating': ['acerbic', 'acid', 'acrid', 'aggravating', 'aggravative', 'annoying', 'asperous', 'astringent', 'biting', 'bitter', 'bothering', 'bothersome'],
    'irritation': ['adverse circumstances', 'adversity', 'affliction', 'aggravation', 'agitation', 'algesia', 'amplification', 'animation', 'annoyance', 'arousal', 'arousing', 'augmentation'],
    'irrupt': ['admit', 'advance upon', 'arise', 'barge in', 'be admitted', 'be born', 'become', 'belch', 'bob up', 'break bounds', 'break forth', 'break in'],
    'irruption': ['air attack', 'air raid', 'air strike', 'blaze', 'boarding', 'burst', 'convulsion', 'cyclone', 'encroachment', 'entrance', 'entrenchment', 'eruption'],
    'irruptive': ['advancing', 'assailing', 'assaulting', 'attacking', 'charging', 'driving', 'entering', 'in', 'inbound', 'incoming', 'incursionary', 'incursive'],
    'isaiah': ['abraham', 'amos', 'daniel', 'ezekiel', 'haggai', 'hosea', 'isaac', 'jacob', 'jeremiah', 'joel', 'jonah', 'joseph'],
    'ishmael': ['dp', 'castaway', 'declasse', 'derelict', 'displaced person', 'evictee', 'exile', 'expatriate', 'expellee', 'leper', 'outcast', 'outcast of society'],
    'isis': ['amen-ra', 'anubis', 'ashtoreth', 'astarte', 'baal', 'bast', 'ceres', 'demeter', 'dionysus', 'frey', 'horus', 'khem'],
    'island': ['aerodrome', 'air base', 'airdrome', 'airfield', 'airport', 'ait', 'archipelagian', 'archipelagic', 'archipelago', 'atoll', 'bar', 'cay'],
    'island universe': ['milky way', 'via lactea', 'barred spiral', 'barred spiral galaxy', 'cosmic noise', 'galactic circle', 'galactic cluster', 'galactic coordinates', 'galactic latitude', 'galactic longitude', 'galactic nebula', 'galactic noise'],
    'isle': ['ait', 'archipelago', 'atoll', 'bar', 'cay', 'continental island', 'coral head', 'coral island', 'coral reef', 'holm', 'insularity', 'island'],
    'ism': ['weltanschauung', 'adherents', 'articles of religion', 'catechism', 'church', 'class', 'communion', 'confession', 'credenda', 'credo', 'creed', 'cult'],
    'isobar': ['air mass', 'anticyclone', 'artificial isotope', 'cold front', 'cold sector', 'cyclone', 'deuterium', 'front', 'heavy hydrogen', 'high', 'high-pressure area', 'isomer'],
    'isolate': ['abrupt', 'abscind', 'abstract', 'alienate', 'amputate', 'annihilate', 'apart', 'avoid', 'ban', 'banish', 'bar', 'block off'],
    'isolated': ['abandoned', 'alien', 'alienated', 'alone', 'aloof', 'anchoretical', 'anomalous', 'anonymous', 'apart', 'archipelagian', 'archipelagic', 'at rest'],
    'isolation': ['jim crow', 'x ray', 'abstraction', 'alien', 'alienation', 'aloneness', 'aloofness', 'anonymity', 'apartheid', 'apartness', 'autism', 'autistic thinking'],
    'isolationism': ['eisenhower doctrine', 'jim crow', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'apartheid', 'apartness', 'appeasement', 'balance of power', 'brinkmanship', 'capitalism', 'coexistence'],
    'isolationist': ['diogenes', 'hieronymian', 'hieronymite', 'timon of athens', 'anchoress', 'anchorite', 'ascetic', 'bedridden invalid', 'cloistered monk', 'closet cynic', 'desert fathers', 'desert saints'],
    'isomer': ['acid', 'acidity', 'agent', 'alkali', 'alkalinity', 'alloisomer', 'anion', 'antacid', 'artificial isotope', 'atom', 'base', 'biochemical'],
    'isometric': ['aerographic', 'aerologic', 'baric', 'barographic', 'barometric', 'climatologic', 'cyclonic', 'elemental', 'equiangular', 'equidimensional', 'equilateral', 'equiproportional'],
    'isotherm': ['air mass', 'anticyclone', 'cold front', 'cold sector', 'cyclone', 'front', 'high', 'high-pressure area', 'isobar', 'isometric', 'isometric line', 'isopiestic line'],
    'issue': ['accomplishment', 'accord', 'activity', 'administer', 'affair', 'afford', 'airing', 'allot', 'allow', 'announce', 'answer', 'appear'],
    'issue forth': ['appear', 'arise', 'bail out', 'be born', 'be illegitimate', 'be off', 'become', 'become manifest', 'become visible', 'break cover', 'break forth', 'break out'],
    'issue price': ['asking price', 'bearish prices', 'bid price', 'book value', 'bullish prices', 'call price', 'closing price', 'decline', 'face value', 'fixed price', 'flash price', 'flurry'],
    'issueless': ['acarpous', 'arid', 'barren', 'celibate', 'childless', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'exhausted', 'fallow'],
    'isthmus': ['abbreviation', 'astriction', 'astringency', 'bottleneck', 'canal', 'cervix', 'channel', 'circumscription', 'coarctation', 'compactedness', 'compaction', 'compression'],
    'it': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'ego', 'ethical self', 'he', 'her', 'herself', 'him', 'himself'],
    'italic': ['ascender', 'autograph', 'autographic', 'back', 'bastard type', 'beard', 'belly', 'bevel', 'black letter', 'body', 'calligraphic', 'cap'],
    'italicize': ['accent', 'accentuate', 'belabor', 'dwell on', 'emphasize', 'feature', 'give emphasis to', 'harp on', 'highlight', 'overaccentuate', 'overemphasize', 'overstress'],
    'italicized': ['accented', 'accentuated', 'autograph', 'autographic', 'calligraphic', 'chirographic', 'cursive', 'decided', 'emphasized', 'emphatic', 'engrossed', 'flowing'],
    'itch': ['ache', 'acne', 'acne vulgaris', 'an universal wolf', 'andromania', 'aphrodisia', 'appetence', 'appetency', 'appetite', 'appetition', 'biological urge', 'bodily appetite'],
    'itch for': ['ache for', 'be dying for', 'be hurting for', 'be in heat', 'clamor for', 'come in', 'cry for', 'desire', 'estruate', 'gape for', 'hone for', 'hope for'],
    'itch to': ['ache to', 'be dying to', 'burn to', 'chafe', 'choose to', 'dearly love to', 'fret', 'fuss', 'get excited', 'hardly wait', 'hasten', 'jump the gun'],
    'itching': ['abscess', 'aching for', 'ague', 'an universal wolf', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'appetence', 'appetency', 'appetite', 'appetition'],
    'itching palm': ['acquisitiveness', 'avarice', 'avariciousness', 'avidity', 'avidness', 'covetousness', 'cupidity', 'frenzy of desire', 'fury of desire', 'gluttony', 'grasping', 'graspingness'],
    'itchy': ['acquisitive', 'agape', 'agog', 'all agog', 'allergic', 'anaphylactic', 'burning with curiosity', 'consumed with curiosity', 'curious', 'delicate', 'desirous', 'empathetic'],
    'item': ['above', 'additionally', 'adjunct', 'adversaria', 'again', 'aide-memoire', 'all included', 'along', 'also', 'altogether', 'among other things', 'and all'],
    'itemization': ['active list', 'analysis', 'anatomization', 'atomization', 'blacklist', 'blocking', 'cameo', 'catalog', 'cataloging', 'character', 'character sketch', 'characterization'],
    'itemize': ['add up', 'adduce', 'anatomize', 'atomize', 'block out', 'book', 'calendar', 'call to mind', 'cast up', 'catalog', 'cipher up', 'circumstantiate'],
    'itemized': ['blow-by-blow', 'cadastral', 'cataloged', 'detailed', 'entered', 'enumerated', 'filed', 'full', 'indexed', 'inventorial', 'listed', 'minute'],
    'items': ['active list', 'blacklist', 'census', 'checklist', 'civil list', 'composition', 'constituents', 'content', 'contents', 'divisions', 'elements', 'enumeration'],
    'iterate': ['battologize', 'fill', 'give an encore', 'go over', 'go through', 'ingeminate', 'pad', 'practice', 'reaffirm', 'reassert', 'recapitulate', 'recite'],
    'iteration': ['conduplication', 'copy', 'copying', 'critique', 'doubling', 'duplicate', 'duplication', 'dwelling upon', 'elaboration', 'gemination', 'going over', 'imitation'],
    'iterative': ['battological', 'duplicative', 'echoic', 'echoing', 'imitative', 'parrotlike', 'recapitulative', 'redundant', 'reduplicative', 'reechoing', 'reiterant', 'reiterative'],
    'itinerancy': ['wanderjahr', 'afoot and lighthearted', 'bumming', 'discursion', 'divagation', 'drifting', 'errantry', 'flitting', 'gadding', 'hoboism', 'itineracy', 'nomadism'],
    'itinerant': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'ambulant', 'ambulative', 'ambulatory'],
    'itinerary': ['baedeker', 'yellow pages', 'air lane', 'beat', 'bibliography', 'business directory', 'catalog', 'checklist', 'circuit', 'city directory', 'classified directory', 'course'],
    'itself': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'ego', 'ethical self', 'he', 'her', 'herself', 'him', 'himself'],
    'ivories': ['alveolar ridge', 'bird cage', 'bones', 'bridgework', 'choir', 'claviature', 'console', 'crap game', 'crap shooting', 'craps', 'crooked dice', 'cubes'],
    'ivory': ['alabaster', 'alabastrine', 'albescent', 'billiard table', 'bones', 'bowling alley', 'bowling green', 'chalk', 'cream', 'creamy', 'cubes', 'dice'],
    'ivory carving': ['cysp sculpture', 'anaglyptics', 'anaglyptography', 'architectural sculpture', 'bone-carving', 'casting', 'ceroplastics', 'chasing', 'clay sculpture', 'decorative sculpture', 'earth art', 'embossing'],
    'ivory tower': ['adytum', 'ashram', 'cell', 'cloister', 'den', 'hermitage', 'hideaway', 'hideout', 'hiding place', 'holy of holies', 'lair', 'mew'],
    'ivy': ['aestival', 'algae', 'autophyte', 'bean', 'beryl-green', 'berylline', 'blue-green', 'bluish-green', 'bracken', 'brown algae', 'chartreuse', 'chloranemic'],
    'izzard': ['apodosis', 'catastrophe', 'ceasing', 'cessation', 'coda', 'conclusion', 'consummation', 'crack of doom', 'culmination', 'curtain', 'curtains', 'death'],
    'jab': ['parthian shot', 'assault', 'back answer', 'bang', 'barrack', 'bash', 'bat', 'bear', 'bear upon', 'bearing', 'beating', 'belt'],
    'jabber': ['greek', 'absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bavardage', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather'],
    'jabberer': ['agreeable rattle', 'babbler', 'big talker', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'blatherer', 'chatterbox', 'chatterer', 'gabber', 'gabbler'],
    'jack': ['ab', 'ancient mariner', 'argonaut', 'dannebrog', 'dylan', 'flying dutchman', 'jolly roger', 'neptune', 'od', 'old glory', 'poseidon', 'rocky mountain canary'],
    'jack up': ['add to', 'aggrandize', 'amplify', 'augment', 'bawl out', 'boost', 'broaden', 'build', 'build up', 'chew', 'chew ass', 'chew out'],
    'jackal': ['african hunting dog', 'cape hunting dog', 'adherent', 'apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bootlick', 'bootlicker', 'brown-nose', 'brownie', 'brush wolf'],
    'jackass': ['rocky mountain canary', 'ass', 'born fool', 'buffoon', 'burro', 'clown', 'cuddy', 'dickey', 'donkey', 'doodle', 'egregious ass', 'figure of fun'],
    'jacket': ['eton jacket', 'leatherette', 'leatheroid', 'mao jacket', 'smyth sewing', 'backing', 'bandage', 'bandaging', 'bark', 'bibliopegy', 'binder', 'binder board'],
    'jackknife': ['adz', 'ax', 'belly buster', 'belly flop', 'belly whopper', 'bread knife', 'bushwhacker', 'butcher knife', 'cannonball', 'carving knife', 'chaser', 'chisel'],
    'jackrabbit': ['belgian hare', 'broad jumper', 'buck', 'bucking bronco', 'buckjumper', 'bunny', 'cottontail', 'doe', 'flea', 'frog', 'gazelle', 'goat'],
    'jacks': ['agate', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble', 'blocks', 'checkerboard', 'chessboard', 'club', 'cockhorse', 'cricket bat'],
    'jacobin': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'cong', 'fenian', 'guevarist'],
    'jactitation': ['ague', 'bluster', 'boast', 'boastfulness', 'boasting', 'bombast', 'brag', 'braggadocio', 'braggartism', 'bragging', 'bravado', 'bumpiness'],
    'jade': ['egyptian green', 'guinea green', 'irish green', 'janus green', 'jezebel', 'kelly green', 'kendal green', 'kildare green', 'lincoln green', 'mitis green', 'montpellier green', 'nile green'],
    'jaded': ['allayed', 'apathetic', 'ausgespielt', 'benumbed', 'blase', 'bone-weary', 'bored', 'bushed', 'cloyed', 'crammed', 'dead', 'debilitated'],
    'jag': ['vandyke', 'bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'bear', 'bender', 'binge', 'blaze', 'booze', 'bout', 'buck'],
    'jaganmati': ['agni', 'asvins', 'avalokita', 'bhairava', 'bhairavi', 'brahma', 'chandi', 'daksha', 'devaki', 'devi', 'dharma', 'dharti mai'],
    'jagged': ['v-shaped', 'y-shaped', 'akimbo', 'angular', 'asperous', 'battlemented', 'bent', 'boozy', 'broken', 'broken off', 'canned', 'capricious'],
    'jaguar': ['dalmatian', 'leo', 'siberian tiger', 'antigorite', 'bobcat', 'butterfly', 'candy cane', 'cat-a-mountain', 'catamount', 'chameleon', 'cheetah', 'chrysotile'],
    'jail': ['pow camp', 'bastille', 'beleaguer', 'beset', 'besiege', 'big house', 'black hole', 'blockade', 'bolt in', 'borstal', 'borstal institution', 'bound'],
    'jailbird': ['judas', 'pow', 'betrayer', 'cageling', 'captive', 'chain gang', 'con', 'convict', 'criminal', 'crook', 'deceiver', 'desperado'],
    'jailbreak': ['break', 'breakout', 'deliverance', 'delivery', 'emergence', 'escape', 'escapism', 'evasion', 'extrication', 'flight', 'freeing', 'getaway'],
    'jailed': ['barred', 'behind bars', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'cabined', 'caged', 'cloistered', 'closed-in', 'confined'],
    'jailer': ['advance guard', 'armed guard', 'bank guard', 'bull', 'coast guard', 'commandant', 'cordon', 'cordon sanitaire', 'custodian', 'gaoler', 'garrison', 'goalie'],
    'jailing': ['captivity', 'close arrest', 'confinement', 'detention', 'dismemberment', 'durance', 'durance vile', 'duress', 'estrapade', 'galleys', 'hard labor', 'house arrest'],
    'jalopy': ['auto', 'autocar', 'automobile', 'boat', 'buggy', 'bus', 'car', 'crate', 'dog', 'heap', 'machine', 'motor'],
    'jam': ['great mogul', 'jell-o', 'mogul', 'a mass of', 'a world of', 'abound with', 'afterthought', 'albumen', 'arch dam', 'army', 'articulate', 'assault'],
    'jam in': ['admit', 'barge in', 'be admitted', 'break in', 'breeze in', 'burst in', 'bust in', 'come barging in', 'come breezing in', 'come busting in', 'come in', 'cram in'],
    'jam packed': ['sro', 'alive with', 'bloated', 'brimful', 'brimming', 'bristling', 'bulging', 'bursting', 'capacity', 'chock-full', 'choked', 'chuck-full'],
    'jamb': ['samson post', 'ankle', 'baluster', 'balustrade', 'banister', 'bayonet legs', 'bowlegs', 'calf', 'cnemis', 'doorjamb', 'doorpost', 'drumstick'],
    'jamboree': ['mardi gras', 'saturnalia', 'banquet', 'blowout', 'carnival', 'carouse', 'celebration', 'charivari', 'do', 'fair', 'feast', 'festival'],
    'jammed': ['aground', 'alive with', 'anchored', 'arrested', 'back', 'backward', 'behindhand', 'belated', 'bloated', 'blocked', 'bonded', 'bound'],
    'jangle': ['babel', 'bedlam let loose', 'discordia', 'eris', 'agree to disagree', 'babel', 'be at cross-purposes', 'be at variance', 'bedlam', 'belch', 'blare', 'blast'],
    'jangling': ['ajar', 'antagonistic', 'antipathetic', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'clashing', 'conflicting', 'confused', 'contradictory'],
    'janitor': ['air warden', 'attendant', 'caretaker', 'castellan', 'cerberus', 'char', 'charwoman', 'cleaner', 'cleaner-off', 'cleaner-up', 'cleaning lady', 'cleaning man'],
    'janus': ['ambiguity', 'ambivalence', 'biformity', 'bifurcation', 'conjugation', 'dichotomy', 'doubleness', 'doublethink', 'doubling', 'dualism', 'duality', 'duplexity'],
    'janus like': ['ambidextrous', 'bifacial', 'bifold', 'biform', 'bilateral', 'binary', 'binate', 'biparous', 'bivalent', 'conduplicate', 'disomatous', 'double'],
    'jape': ['parthian shot', 'back answer', 'badinage', 'banter', 'barrack', 'be merry with', 'belly laugh', 'blue story', 'caustic remark', 'chaff', 'comeback', 'crack'],
    'jar': ['babel', 'discordia', 'eris', 'agitate', 'agitation', 'agree to disagree', 'bag', 'barrel', 'basket', 'be at cross-purposes', 'be at variance', 'belch'],
    'jargon': ['aesopian language', 'babel', 'beach-la-mar', 'greek', 'kitchen kaffir', 'oregon jargon', 'sabir', 'abracadabra', 'absurdity', 'amphigory', 'argot', 'auxiliary language'],
    'jarring': ['agitating', 'ajar', 'antagonistic', 'antipathetic', 'astonishing', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'bouncy', 'breathtaking'],
    'jaundice': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'aurify', 'backache'],
    'jaundiced': ['antiblack', 'biased', 'bigoted', 'bilious', 'bitter', 'chauvinistic', 'choleric', 'colored', 'corrupt', 'critical', 'cynical', 'disapproving'],
    'jaundiced eye': ['bent', 'bias', 'envy', 'favoritism', 'forejudgment', 'green-eyed jealousy', 'green-eyed monster', 'heartburn', 'heartburning', 'horn-madness', 'inclination', 'jalousie'],
    'jaunt': ['airing', 'amble', 'bat around', 'bum', 'campaign', 'circuit', 'constitutional', 'count ties', 'course', 'cruise', 'divagate', 'drift'],
    'jaunty': ['airy', 'blithe', 'brave', 'bravura', 'braw', 'breezy', 'brisk', 'buoyant', 'carefree', 'cheerful', 'chic', 'chichi'],
    'jaw': ['abuse', 'babble', 'bark at', 'baste', 'bat the breeze', 'bazoo', 'beat the gums', 'berate', 'betongue', 'blab', 'blabber', 'blacken'],
    'jawboning': ['allurement', 'blandishment', 'cajolement', 'cajolery', 'coaxing', 'conning', 'engagement', 'enlistment', 'exhortation', 'hortation', 'inducement', 'lobbying'],
    'jawbreaking': ['herculean', 'abstruse', 'arduous', 'brutal', 'complex', 'critical', 'delicate', 'demanding', 'difficile', 'difficult', 'exacting', 'formidable'],
    'jawing': ['abuse', 'assailing', 'assault', 'attack', 'berating', 'bitter words', 'blackening', 'contumely', 'diatribe', 'execration', 'hard words', 'invective'],
    'jaws': ['bazoo', 'chaps', 'chops', 'claws', 'clutches', 'digits', 'embouchure', 'fangs', 'fingernails', 'fingers', 'gab', 'gob'],
    'jaywalk': ['ambulate', 'ankle', 'circumambulate', 'foot', 'foot it', 'hoof it', 'jog on', 'leg', 'leg it', 'pace', 'pad', 'pedestrianize'],
    'jaywalker': ['ambulator', 'backpacker', 'foot passenger', 'foot soldier', 'foot traveler', 'footslogger', 'hiker', 'hitchhiker', 'hoofer', 'infantryman', 'marcher', 'paddlefoot'],
    'jazz': ['acid rock', 'avant-garde jazz', 'ballroom music', 'baloney', 'bebop', 'boogie-woogie', 'bop', 'bull', 'bushwa', 'concert', 'country rock', 'crap'],
    'jazz band': ['german band', 'philharmonic', 'band', 'big band', 'brass', 'brass band', 'brass choir', 'brass quintet', 'brass section', 'brasses', 'callithumpian band', 'chamber orchestra'],
    'jazz up': ['accelerate', 'aggravate', 'animate', 'arouse', 'beef up', 'blow up', 'complicate', 'concentrate', 'condense', 'consolidate', 'deepen', 'double'],
    'jazzy': ['brave', 'bravura', 'braw', 'chichi', 'concert', 'daring', 'dashing', 'dramatico-musical', 'dressy', 'exhibitionistic', 'flashing', 'flashy'],
    'jealous': ['anxious', 'begrudging', 'bitter', 'covetous', 'demanding', 'desirous of', 'distrustful', 'doubting', 'envious', 'enviousness', 'envying', 'grasping'],
    'jeer': ['parthian shot', 'affront', 'aspersion', 'atrocity', 'back answer', 'barrack', 'boo', 'brickbat', 'bullyrag', 'call names', 'catcall', 'caustic remark'],
    'jeering': ['affront', 'aspersion', 'atrocity', 'banter', 'bantering', 'booing', 'brickbat', 'catcalling', 'chaffing', 'contempt', 'contumely', 'cut'],
    'jehovah': ['almighty god', 'alpha and omega', 'demiourgos', 'demiurge', 'god', 'god almighty', 'heaven', 'i am', 'king of kings', 'lord', 'lord of lords', 'lord of hosts'],
    'jejune': ['lenten', 'spartan', 'abstemious', 'acarpous', 'ankle-deep', 'arid', 'ascetic', 'attenuated', 'austere', 'banal', 'barren', 'blah'],
    'jell': ['albumen', 'batter', 'beat up', 'bonnyclabber', 'butter', 'cake', 'churn', 'clabber', 'clot', 'clump', 'cluster', 'coagulate'],
    'jellied': ['adhesive', 'amylaceous', 'caked', 'cakey', 'clabbered', 'clammy', 'clotted', 'coagulated', 'congealed', 'curded', 'curdled', 'doughy'],
    'jelly': ['jell-o', 'albumen', 'batter', 'beat up', 'blancmange', 'bonnyclabber', 'butter', 'cake', 'candy', 'churn', 'clabber', 'clot'],
    'jellyfish': ['chilopoda', 'chordata', 'echiuroidea', 'ectoprocta', 'entoprocta', 'milquetoast', 'monoplacophora', 'nemertinea', 'phoronidea', 'baby', 'big baby', 'chicken'],
    'jenny': ['partlet', 'rocky mountain canary', 'ass', 'biddy', 'bitch', 'bossy', 'brood mare', 'burro', 'cow', 'cuddy', 'dickey', 'doe'],
    'jeopardize': ['compromise', 'encounter danger', 'endanger', 'expose', 'gamble', 'gamble with', 'hazard', 'imperil', 'incur danger', 'jeopard', 'jeopardy', 'lay open'],
    'jeopardy': ['accident', 'breakers ahead', 'cardhouse', 'cause for alarm', 'chance', 'compromise', 'crisis', 'danger', 'dangerous ground', 'emergency', 'endangerment', 'exposure'],
    'jeremiah': ['abraham', 'amos', 'cassandra', 'daniel', 'ezekiel', 'haggai', 'hosea', 'isaac', 'isaiah', 'jacob', 'joel', 'jonah'],
    'jerk': ['sob', 'anhydrate', 'ass', 'asshole', 'backslide', 'bastard', 'blast-freeze', 'bob', 'bobble', 'boob', 'booby', 'bounce'],
    'jerkily': ['at irregular intervals', 'at random', 'brokenly', 'by catches', 'by fits', 'by jerks', 'by snatches', 'capriciously', 'desultorily', 'disconnectedly', 'discontinuously', 'eccentrically'],
    'jerking': ['anhydration', 'blast-freezing', 'bottling', 'brining', 'canning', 'convulsive', 'corning', 'curing', 'dehydration', 'desiccation', 'dry-curing', 'drying'],
    'jerky': ['aspic', 'barbecue', 'beef', 'beef extract', 'beef tea', 'boiled meat', 'bouilli', 'bouillon', 'broken', 'broken off', 'bully', 'bully beef'],
    'jerry built': ['breakable', 'brittle', 'cheap-jack', 'cobwebby', 'crumbly', 'dainty', 'delicate', 'delicately weak', 'effeminate', 'flimsy', 'fragile', 'frail'],
    'jest': ['parthian shot', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'back answer', 'badinage', 'bagatelle', 'banter', 'bauble', 'be merry with'],
    'jester': ['columbine', 'hanswurst', 'harlequin', 'pantalone', 'pantaloon', 'polichinelle', 'pulcinella', 'punch', 'punchinello', 'scaramouch', 'banana', 'buffo'],
    'jesting': ['attic', 'bantering', 'biting', 'brilliant', 'chaffing', 'clever', 'droll', 'facetious', 'fooling', 'funny', 'hazing', 'humorous'],
    'jesuit': ['augustinian', 'augustinian hermit', 'austin friar', 'benedictine', 'bernardine', 'black friar', 'black monk', 'bonhomme', 'brigittine', 'capuchin', 'carmelite', 'carthusian'],
    'jesuitical': ['apparently sound', 'casuistic', 'colorable', 'deceptive', 'dishonest', 'disingenuous', 'empty', 'fallacious', 'hollow', 'illusive', 'insincere', 'jesuitic'],
    'jesus christ': ['christ', 'christ jesus', 'emmanuel', 'god the son', 'god-man', 'immanuel', 'jesu', 'jesus', 'jesus of nazareth', 'king of glory', 'king of heaven', 'king of kings'],
    'jet': ['jet liner', 'anabasis', 'ascension', 'ascent', 'black', 'blowtorch', 'business jet', 'charcoal', 'clamber', 'climb', 'climbing', 'coal'],
    'jet lag': ['minamata disease', 'altitude sickness', 'anoxemia', 'anoxia', 'anoxic anoxia', 'anthrax', 'black lung', 'caisson disease', 'chilblain', 'decompression sickness', 'frostbite', 'immersion foot'],
    'jet propulsion': ['action and reaction', 'aeromotor', 'charge', 'diesel propulsion', 'exhaust', 'fuel', 'gas propulsion', 'gasoline propulsion', 'jet power', 'liquid oxygen', 'plasma-jet propulsion', 'power plant'],
    'jet set': ['vanity fair', 'adventurer', 'alpinist', 'astronaut', 'beau monde', 'beautiful people', 'best people', 'cafe society', 'camper', 'carriage trade', 'climber', 'comers and goers'],
    'jete': ['highland fling', 'and jump', 'bounce', 'bound', 'broad jump', 'buck', 'buckjump', 'capriole', 'curvet', 'demivolt', 'flying jump', 'galliard'],
    'jetsam': ['castaway', 'castoff', 'derelict', 'discard', 'dogie', 'flotsam', 'flotsam and jetsam', 'foundling', 'junk', 'lagan', 'orphan', 'refuse'],
    'jetstream': ['cat', 'aerospace', 'aerosphere', 'air current', 'air hole', 'air pocket', 'airspace', 'bump', 'ceiling', 'crosscurrent', 'crosswind', 'current'],
    'jettison': ['abandon', 'abandonment', 'abdicate', 'absentation', 'back out', 'beg off', 'boot out', 'booting out', 'bounce', 'cashier', 'cast', 'cast aside'],
    'jetty': ['abutment', 'anchorage', 'anchorage ground', 'arc-boutant', 'arch dam', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier', 'basin'],
    'jewel': ['acceptable person', 'anklet', 'armlet', 'ball bearing', 'bangle', 'bead', 'beads', 'bearing', 'bejewel', 'beribbon', 'beset', 'bespangle'],
    'jeweled': ['adorned', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'decked out', 'decorated', 'embellished', 'feathered'],
    'jeweler': ['baker', 'bookdealer', 'bookseller', 'butcher', 'chandler', 'clothing merchant', 'confectioner', 'draper', 'drysalter', 'fishmonger', 'fishwife', 'florist'],
    'jezebel': ['aspasia', 'delilah', 'messalina', 'phryne', 'thais', 'adventuress', 'bad woman', 'baggage', 'beldam', 'bitch', 'bitch-kitty', 'broad'],
    'jib': ['avert', 'avoid', 'back down', 'balance', 'balk', 'balloon sail', 'batten', 'bear off', 'blench', 'blink', 'boggle', 'cringe'],
    'jibe': ['about ship', 'accord', 'agree', 'alter', 'ameliorate', 'answer to', 'assent', 'assort with', 'back and fill', 'be changed', 'be consistent', 'be converted into'],
    'jiffy': ['breath', 'breathing', 'coup', 'crack', 'flash', 'half a jiffy', 'half a mo', 'half a second', 'half a shake', 'instant', 'jiff', 'microsecond'],
    'jig': ['charleston', 'highland fling', 'lambeth walk', 'mexican hat dance', 'portland fancy', 'virginia reel', 'watusi', 'allemande', 'and jump', 'angle', 'bait', 'bait the hook'],
    'jigger': ['affair', 'angler', 'article', 'artifact', 'cat flea', 'chigoe', 'cockroach', 'concern', 'crab', 'dibber', 'dibbler', 'dingus'],
    'jiggle': ['agitate', 'bob', 'bobble', 'bounce', 'bump', 'didder', 'dither', 'falter', 'fidget', 'flick', 'flip', 'flirt'],
    'jillion': ['a billion', 'a crore', 'a lakh', 'a million', 'a myriad', 'a nonillion', 'a quadrillion', 'a thousand', 'a zillion', 'astronomical number', 'billion', 'considerable'],
    'jilt': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'abandon', 'actor', 'back out', 'bamboozler', 'befuddler', 'beg off'],
    'jilter': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'actor', 'bamboozler', 'befuddler', 'beguiler', 'charmer', 'counterfeiter'],
    'jim crow': ['jim crow law', 'alien', 'anti-semitism', 'apartheid', 'apartness', 'black power', 'black supremacy', 'chauvinism', 'class consciousness', 'class distinction', 'class hatred', 'class prejudice'],
    'jimjams': ['agitation', 'all-overs', 'blue johnnies', 'blue devils', 'chills of fear', 'cold creeps', 'cold shivers', 'cold sweat', 'creeps', 'disquiet', 'disquietude', 'dithers'],
    'jimmy': ['bar', 'beam', 'boom', 'cant hook', 'claw bar', 'crank', 'crow', 'crowbar', 'get a foothold', 'get leverage', 'handspike', 'iron crow'],
    'jingle': ['alexandrine', 'english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'accent', 'accentuation', 'alba', 'alliterate'],
    'jingling': ['alliterative', 'assonant', 'assonantal', 'change ringing', 'chime', 'chiming', 'chink', 'clang', 'clanging', 'clangor', 'clank', 'clanking'],
    'jingo': ['bigot', 'chauvin', 'chauvinist', 'doctrinaire', 'dogmatist', 'fanatic', 'flag waver', 'hard hat', 'hawk', 'hundred-percent american', 'hundred-percenter', 'illiberal'],
    'jingoism': ['americanism', 'anglicism', 'briticism', 'aggression', 'aggressiveness', 'antagonism', 'bellicism', 'bellicosity', 'belligerence', 'belligerency', 'chauvinism', 'combativeness'],
    'jinni': ['baba yaga', 'lilith', 'afreet', 'barghest', 'cacodemon', 'daeva', 'demon', 'devil', 'dybbuk', 'evil genius', 'evil spirit', 'fiend'],
    'jinx': ['jonah', 'abuse', 'afflict', 'aggrieve', 'bad influence', 'bedevil', 'befoul', 'bewitch', 'blight', 'bring bad luck', 'cantrip', 'charm'],
    'jitters': ['agitation', 'all-overs', 'apprehension', 'apprehensiveness', 'bluster', 'bobbery', 'boil', 'boiling', 'brouhaha', 'bustle', 'churn', 'cold shivers'],
    'jittery': ['agitated', 'all shook up', 'all-overish', 'discomposed', 'disquieted', 'disturbed', 'excited', 'feverish', 'fidgeting', 'fidgety', 'flurried', 'flustered'],
    'jiva': ['anima', 'anima humana', 'animating force', 'atman', 'ba', 'bathmism', 'beating heart', 'biological clock', 'biorhythm', 'blood', 'breath', 'breath of life'],
    'jive': ['acid rock', 'avant-garde jazz', 'badinage', 'ballroom music', 'banter', 'bebop', 'boogie-woogie', 'bop', 'chaff', 'country rock', 'dance music', 'dances'],
    'job': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adventure', 'affair', 'appointment', 'assignment', 'bamboozle', 'be in'],
    'job lot': ['catalog goods', 'commodities', 'consumer goods', 'consumer items', 'effects', 'goods', 'goods for sale', 'inventory', 'line', 'line of goods', 'mail-order goods', 'merchandise'],
    'jobber': ['wall streeter', 'agent', 'blue-collar worker', 'bond crowd', 'breadwinner', 'broker', 'casual', 'casual laborer', 'chandler', 'common laborer', 'connection', 'curb broker'],
    'jobbing': ['machiavellianism', 'machiavellism', 'agency', 'barter', 'bartering', 'brokerage', 'buying and selling', 'consumer preference study', 'consumer research', 'consumer survey', 'dealing', 'diplomacy'],
    'jobholder': ['blue-collar worker', 'breadwinner', 'casual', 'casual laborer', 'common laborer', 'day laborer', 'employee', 'factory worker', 'flunky', 'free lance', 'free-lancer', 'full-time worker'],
    'jobless': ['at leisure', 'at liberty', 'at loose ends', 'available', 'disengaged', 'fallow', 'free', 'idle', 'leisure', 'leisured', 'lumpen', 'off'],
    'jock': ['anzac', 'aussie', 'boche', 'fritz', 'gi', 'heinie', 'hun', 'jerry', 'johnny', 'kraut', 'tommy', 'tommy atkins'],
    'jockey': ['jehu', 'angle', 'beguile', 'bellyband', 'broncobuster', 'buckaroo', 'caballero', 'cavalier', 'cavalryman', 'challenge', 'chevalier', 'cinch'],
    'jocose': ['attic', 'biting', 'blithe', 'brilliant', 'clever', 'comic', 'comical', 'droll', 'facetious', 'funny', 'humorous', 'humorsome'],
    'jocular': ['attic', 'biting', 'brilliant', 'buxom', 'clever', 'comic', 'comical', 'droll', 'facetious', 'frivolous', 'funny', 'gleeful'],
    'jocularity': ['amusement', 'brilliance', 'cleverness', 'facetiousness', 'frivolity', 'fun', 'funniness', 'glee', 'gleefulness', 'high glee', 'hilariousness', 'hilarity'],
    'jog': ['agitate', 'amble', 'andante', 'assault', 'barge', 'bear', 'bear upon', 'bearing', 'bilge', 'blain', 'blaze', 'bleb'],
    'jog on': ['abide', 'ambulate', 'ankle', 'bide', 'carry on', 'cease not', 'chug on', 'circumambulate', 'continue', 'drag on', 'drift along', 'endure'],
    'jog trot': ['alliterating', 'alliterative', 'andante', 'assonant', 'beat', 'beaten path', 'belabored', 'blah', 'broken-record', 'bureaucracy', 'bureaucratism', 'burst'],
    'john': ['wc', 'backhouse', 'basement', 'bathroom', 'bedpan', 'can', 'chamber', 'chamber pot', 'chemical closet', 'chemical toilet', 'closet', 'comfort station'],
    'john doe': ['everyman', 'jane doe', 'public', 'richard roe', 'alias', 'anonym', 'assumed name', 'body politic', 'citizenry', 'common man', 'commonwealth', 'community'],
    'john hancock': ['ok', 'acceptance', 'affirmance', 'affirmation', 'approbation', 'approval', 'authentication', 'authorization', 'autograph', 'certification', 'christcross', 'cipher'],
    'johnny': ['adamite', 'wc', 'backhouse', 'basement', 'bastard', 'bathroom', 'bedpan', 'being', 'bird', 'body', 'bugger', 'can'],
    'johnsonian': ['gongoresque', 'affected', 'bedizened', 'big-sounding', 'convoluted', 'declamatory', 'elevated', 'euphuistic', 'flamboyant', 'flaming', 'flashy', 'flaunting'],
    'joie de vivre': ['activity', 'amusement', 'animal pleasure', 'animation', 'ardor', 'bodily pleasure', 'brio', 'briskness', 'carnal delight', 'comfort', 'content', 'contentment'],
    'join': ['abut', 'abut on', 'accompany', 'accord', 'accouple', 'accumulate', 'act in concert', 'act together', 'act with', 'add', 'adhere', 'adjoin'],
    'join battle': ['antagonize', 'battle', 'beat against', 'beat up against', 'breast the wave', 'buck', 'buffet', 'buffet the waves', 'close with', 'combat', 'compete with', 'contend against'],
    'join forces': ['affiliate', 'ally', 'associate', 'band together', 'be in cahoots', 'bunch', 'bunch up', 'cabal', 'cement a union', 'centralize', 'club', 'club together'],
    'joined': ['accessory', 'accompanying', 'accumulated', 'adjacent', 'adjoining', 'affiliate', 'affiliated', 'agglomerate', 'aggregate', 'allied', 'amalgamated', 'amassed'],
    'joiner': ['greek', 'affiliate', 'associate', 'belonger', 'bon vivant', 'brother', 'card-carrier', 'card-carrying member', 'cardholder', 'charter member', 'clubber', 'clubman'],
    'joining': ['accession', 'addition', 'adjunct', 'adjunction', 'affixation', 'agglutination', 'ankle', 'annexation', 'articulation', 'attachment', 'augmentation', 'binding'],
    'joint': ['babylon', 'det', 'dmt', 'gomorrah', 'lsd', 'mary jane', 'stp', 'sodom', 'thc', 'abutment', 'abysm', 'abyss'],
    'joint control': ['association', 'cochairmanship', 'complicity', 'condominium', 'contribution', 'copartnership', 'copartnery', 'cotenancy', 'engagement', 'having a part', 'involvement', 'joint chairmanship'],
    'joint effort': ['bipartisanship', 'coaction', 'coadjuvancy', 'coadministration', 'coagency', 'cochairmanship', 'codirectorship', 'collaboration', 'collaborativeness', 'collectivism', 'collusion', 'commensalism'],
    'joint operation': ['action', 'amphibious operations', 'bipartisanship', 'coaction', 'coadjuvancy', 'coadministration', 'coagency', 'cochairmanship', 'codirectorship', 'collaboration', 'collaborativeness', 'collectivism'],
    'joint ownership': ['association', 'cochairmanship', 'complicity', 'condominium', 'contribution', 'copartnership', 'copartnery', 'cotenancy', 'engagement', 'having a part', 'involvement', 'joint chairmanship'],
    'jointly': ['all at once', 'all together', 'as one', 'as one man', 'at once', 'back to back', 'cheek by jowl', 'coactively', 'coefficiently', 'collectively', 'combinedly', 'commonly'],
    'jointure': ['agglomeration', 'agglutination', 'aggregation', 'appanage', 'articulation', 'bond', 'bracketing', 'clustering', 'combination', 'communication', 'concatenation', 'concourse'],
    'joke': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'absurdity', 'anecdote', 'antic', 'badinage', 'bagatelle', 'banter', 'bauble'],
    'joker': ['adamite', 'artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'ace', 'actor', 'artful dodge', 'artifice', 'astonishment'],
    'joking': ['attic', 'bantering', 'biting', 'brilliance', 'brilliant', 'chaffing', 'clever', 'cleverness', 'droll', 'facetious', 'facetiousness', 'fooling'],
    'jollies': ['marine corps', 'royal marines', 'bang', 'boot', 'charge', 'devil dogs', 'flush', 'kick', 'leathernecks', 'lift', 'marines', 'quiver'],
    'jollity': ['amusement', 'blitheness', 'cheer', 'conviviality', 'disport', 'festivity', 'frivolity', 'frolic', 'fun', 'gaiety', 'gambol', 'glee'],
    'jolly': ['naval reservist', 'royal marine', 'seabee', 'addled', 'animated', 'appease', 'banter', 'beery', 'bemused', 'besotted', 'blandish', 'blarney'],
    'jolly roger': ['dannebrog', 'old glory', 'star-spangled banner', 'stars and stripes', 'union flag', 'union jack', 'and blue', 'banderole', 'banner', 'banneret', 'black flag', 'blue ensign'],
    'jolt': ['agitate', 'amaze', 'amble', 'assault', 'astonish', 'astound', 'barge', 'bear', 'bear upon', 'bearing', 'blow', 'bob'],
    'jolting': ['agitating', 'astonishing', 'bouncy', 'breathtaking', 'bumpy', 'charged', 'choppy', 'cliff-hanging', 'disquieting', 'distracting', 'disturbing', 'electric'],
    'jonah': ['abraham', 'amos', 'daniel', 'ezekiel', 'haggai', 'hosea', 'isaac', 'isaiah', 'jacob', 'jeremiah', 'joel', 'joseph'],
    'jongleur': ['meistersinger', 'parnassian', 'arch-poet', 'ballad maker', 'ballad singer', 'balladeer', 'balladmonger', 'bard', 'beat poet', 'bucoliast', 'elegist', 'epic poet'],
    'joshing': ['attic', 'banter', 'bantering', 'biting', 'booing', 'brilliance', 'brilliant', 'catcalling', 'chaffing', 'clever', 'cleverness', 'derision'],
    'jostle': ['agree to disagree', 'assault', 'battle', 'be at cross-purposes', 'be at variance', 'bear', 'bear upon', 'bearing', 'bob', 'bobble', 'boost', 'bounce'],
    'jot': ['ace', 'atom', 'birthmark', 'bit', 'blaze', 'blemish', 'blotch', 'book', 'brand', 'calendar', 'carve', 'caste mark'],
    'jotting': ['adversaria', 'aide-memoire', 'annotation', 'docket', 'entry', 'footnote', 'item', 'marginal note', 'marginalia', 'memo', 'memoir', 'memorandum'],
    'jounce': ['bob', 'bobble', 'bounce', 'bump', 'chatter', 'collision', 'concussion', 'didder', 'falter', 'have an ague', 'hustle', 'impingement'],
    'journal': ['clio', 'domesday book', 'muse of history', 'account book', 'accounts payable ledger', 'accounts receivable ledger', 'address book', 'adventures', 'adversaria', 'album', 'almanac', 'annal'],
    'journalese': ['varietyese', 'wall streetese', 'washingtonese', 'business english', 'businessese', 'cinemese', 'collegese', 'commercialism', 'computerese', 'economese', 'editorial', 'federalese'],
    'journalism': ['ap', 'associated press', 'fleet street', 'reuters', 'upi', 'united press international', 'advice', 'artistry', 'authorcraft', 'authorship', 'automatic writing', 'book publishing'],
    'journalist': ['anchorman', 'broadcaster', 'city editor', 'columnist', 'commentator', 'copy chief', 'copy editor', 'copyman', 'copyreader', 'correspondent', 'cub reporter', 'diaskeuast'],
    'journey': ['campaign', 'career', 'circuit', 'course', 'cruise', 'excursion', 'expedition', 'fare', 'gad about', 'gallivant', 'globe-trot', 'go'],
    'journeyer': ['adventurer', 'alpinist', 'astronaut', 'camper', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser', 'excursionist', 'explorer', 'fare'],
    'journeying': ['ambulant', 'ambulative', 'ambulatory', 'circuit-riding', 'commutation', 'course', 'crossing', 'expeditionary', 'globe-girdling', 'globe-trotting', 'going', 'itinerant'],
    'journeyman': ['admirable crichton', 'adept', 'ancestors', 'apprentice', 'architect', 'artificer', 'artisan', 'artist', 'attache', 'author', 'authority', 'begetter'],
    'joust': ['olympic games', 'olympics', 'battle', 'bout', 'box', 'brawl', 'broil', 'clash', 'close', 'collide', 'combat', 'come to blows'],
    'jove': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'jovial': ['affable', 'amiable', 'bantering', 'blithe', 'blithesome', 'boon', 'buxom', 'chaffing', 'convivial', 'facetious', 'festal', 'festive'],
    'joviality': ['amusement', 'cheer', 'conviviality', 'festivity', 'frivolity', 'fun', 'gaiety', 'glee', 'gleefulness', 'good cheer', 'heartiness', 'high glee'],
    'jowl': ['bank', 'bazoo', 'beam', 'border', 'broadside', 'chaps', 'cheek', 'chop', 'chops', 'coast', 'embouchure', 'flank'],
    'joy': ['amusement', 'be in heaven', 'be pleased', 'beam', 'beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'caper', 'caracole'],
    'joyful': ['animating', 'beaming', 'beatific', 'beatified', 'blessed', 'blissful', 'blithe', 'blithesome', 'buoyant', 'buxom', 'capering', 'cheerful'],
    'joyfully': ['airily', 'blessedly', 'blissfully', 'blithely', 'cheerfully', 'cheerily', 'delightedly', 'ecstatically', 'elatedly', 'exultantly', 'genially', 'gladly'],
    'joyfulness': ['amusement', 'beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'cheer', 'cheerfulness', 'cloud nine', 'delectation', 'delight'],
    'joyless': ['affecting', 'afflictive', 'anguished', 'anxious', 'austere', 'bitter', 'black', 'bleak', 'bored', 'cheerless', 'comfortless', 'crestfallen'],
    'joylessness': ['angst', 'anguish', 'anxiety', 'bitterness', 'bleakness', 'boredom', 'cheerlessness', 'comfortlessness', 'depression', 'discomfort', 'discomposure', 'discontent'],
    'joyous': ['animating', 'beaming', 'beatific', 'beatified', 'blessed', 'blissful', 'buxom', 'capering', 'cheerful', 'cheering', 'cheery', 'chirping'],
    'joyride': ['sunday drive', 'airing', 'bicycle', 'bike', 'bus', 'catch a train', 'chauffeur', 'cycle', 'drive', 'entrain', 'go by rail', 'lift'],
    'jubilant': ['bursting with happiness', 'carried away', 'cock-a-hoop', 'crowing', 'delighting', 'ecstatic', 'elate', 'elated', 'enchanted', 'enraptured', 'enravished', 'entranced'],
    'jubilate': ['beat the drum', 'blow the trumpet', 'caper', 'caracole', 'carol', 'celebrate', 'chirp', 'chirrup', 'clap hands', 'commemorate', 'crow', 'crow over'],
    'jubilation': ['banquet', 'celebration', 'crowing', 'elation', 'exultation', 'feast', 'festivity', 'gloating', 'hoopla', 'joyance', 'jubilance', 'jubilee'],
    'jubilee': ['anniversaries', 'anniversary', 'annual holiday', 'bicentenary', 'bicentennial', 'biennial', 'birthday', 'bissextile day', 'celebrating', 'celebration', 'centenary', 'centennial'],
    'judas': ['benedict arnold', 'brutus', 'judas iscariot', 'quisling', 'archtraitor', 'betrayer', 'cockatrice', 'conniver', 'conspirator', 'conspirer', 'convict', 'criminal'],
    'judge': ['account', 'account as', 'act between', 'adjudge', 'adjudicate', 'adjudicator', 'administer', 'administer justice', 'administrate', 'allow', 'amateur', 'appraise'],
    'judgement': ['acumen', 'adjudication', 'appraisal', 'assessment', 'belief', 'censure', 'common sense', 'conclusion', 'condemnation', 'criticism', 'decision', 'decree'],
    'judgment': ['acquittal', 'acumen', 'anathematizing', 'appraisal', 'appraisement', 'assessment', 'assumption', 'astuteness', 'attitude', 'belief', 'castigation', 'censure'],
    'judgmental': ['abusive', 'blackening', 'blameful', 'censorious', 'condemnatory', 'contemptuous', 'critical', 'damnatory', 'denunciatory', 'deprecative', 'deprecatory', 'depreciative'],
    'judicature': ['areopagus', 'adjudgment', 'adjudication', 'arbitrament', 'arbitration', 'board', 'choice', 'council', 'court', 'court of arbitration', 'court of justice', 'court of law'],
    'judicial': ['actionable', 'analytical', 'applicable', 'authorized', 'careful', 'circumspect', 'competent', 'considerate', 'constitutional', 'critical', 'curial', 'discerning'],
    'judicial process': ['action', 'case', 'cause', 'cause in court', 'judgment', 'judicatory', 'judicature', 'judiciary', 'justice', 'lawsuit', 'legal action', 'legal case'],
    'judiciary': ['areopagus', 'board', 'council', 'critical', 'curia', 'curial', 'forum', 'inquisition', 'judgment', 'judgmental', 'judicative', 'judicatorial'],
    'judicious': ['astute', 'aware', 'bland', 'canny', 'careful', 'cautious', 'circumspect', 'considerate', 'considered', 'critical', 'deliberate', 'diplomatic'],
    'judiciously': ['artfully', 'astutely', 'calmly', 'cannily', 'carefully', 'cautiously', 'circumspectly', 'cleverly', 'composedly', 'conservatively', 'considerately', 'coolly'],
    'judiciousness': ['abnegation', 'abstinence', 'appreciation', 'appreciation of differences', 'appreciativeness', 'artistic judgment', 'calculation', 'calm', 'calmness', 'canniness', 'care', 'careful consideration'],
    'jug': ['adobe', 'bastille', 'biscuit', 'bisque', 'bowl', 'brick', 'calabash', 'calaboose', 'can', 'canteen', 'carafe', 'carboy'],
    'juggle': ['adulterate', 'alter', 'arrange', 'bamboozle', 'beguile', 'betray', 'bluff', 'cajole', 'cheat on', 'circumvent', 'conjure', 'cook'],
    'juggler': ['acrobat', 'aerialist', 'bareback rider', 'blackleg', 'cheat', 'cheater', 'chiseler', 'circus artist', 'clown', 'conjurer', 'cozener', 'crook'],
    'jughead': ['addlebrain', 'addlehead', 'addlepate', 'balker', 'balky horse', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead'],
    'juice': ['ac', 'dc', 'absorption current', 'active current', 'alcohol', 'alternating current', 'aqua vitae', 'beverage', 'blood', 'booze', 'conduction current', 'convection current'],
    'juiceless': ['saharan', 'anhydrous', 'arid', 'athirst', 'bone-dry', 'desert', 'droughty', 'dry', 'dry as dust', 'dusty', 'high and dry', 'like parchment'],
    'juiciness': ['callowness', 'chylifaction', 'chylification', 'delectability', 'delectableness', 'deliciousness', 'dewiness', 'flavorsomeness', 'flow', 'fluency', 'fluidity', 'fluidness'],
    'juicy': ['agreeable', 'ambrosial', 'budding', 'callow', 'colorful', 'dainty', 'delectable', 'delicate', 'delicious', 'delightful', 'dewy', 'exciting'],
    'juke joint': ['amusement park', 'ballroom', 'cabaret', 'cafe chantant', 'cafe dansant', 'casino', 'dance floor', 'dance hall', 'dancing pavilion', 'entertainment industry', 'fun-fair', 'night spot'],
    'jukebox': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'jumble': ['aesopian language', 'babel', 'boston cream pie', 'greek', 'admix', 'all sorts', 'alloy', 'amalgamate', 'angel cake', 'angel food cake', 'argot', 'arsy-varsiness'],
    'jumbled': ['amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'anarchic', 'arsy-varsy', 'ass-backwards', 'balled up', 'balled-up', 'beyond one', 'blended', 'bollixed up'],
    'jumbo': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'astronomic', 'colossal', 'cyclopean', 'dinosaur', 'elephant'],
    'jump': ['highland fling', 'abandon', 'abscond', 'absquatulate', 'accept', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition'],
    'jump bail': ['abscond', 'absquatulate', 'beat a retreat', 'bolt', 'clear out', 'cut and run', 'decamp', 'depart', 'desert', 'elope', 'flee', 'fly'],
    'jump in': ['admit', 'back', 'barge in', 'be admitted', 'bestraddle', 'bestride', 'board', 'break in', 'breeze in', 'buckle down', 'burst in', 'bust in'],
    'jump on': ['asphyxiate', 'bottle up', 'call down', 'censor', 'choke off', 'clamp down on', 'come down on', 'cork', 'cork up', 'crack down on', 'crush', 'damp down'],
    'jump the gun': ['anticipate', 'be predisposed', 'burn to', 'chafe', 'foreglimpse', 'forejudge', 'forerun', 'foresee', 'forestall', 'foretaste', 'fret', 'fuss'],
    'jump up': ['add to', 'aggrandize', 'amplify', 'arise', 'augment', 'bob up', 'boost', 'break water', 'bristle', 'broaden', 'build', 'build up'],
    'jumper': ['amateur athlete', 'archer', 'athlete', 'baby clothes', 'baby linen', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'blocking back', 'bowman'],
    'jumping': ['bouncing', 'bounding', 'capering', 'hopping', 'hurdle race', 'hurdling', 'leaping', 'pole vaulting', 'prancing', 'saltant', 'saltation', 'saltatorial'],
    'jumping off place': ['china', 'darkest africa', 'god knows where', 'greenland', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'siberia', 'south pole', 'thule', 'tierra del fuego'],
    'jumpy': ['agitated', 'all shook up', 'all-overish', 'anxious', 'bashful', 'bustling', 'convulsive', 'cowardly', 'diffident', 'discomposed', 'disquieted', 'disturbed'],
    'junction': ['anschluss', 'abutment', 'abuttal', 'access', 'accession', 'accompaniment', 'accord', 'accordance', 'accretion', 'addition', 'adherence', 'adhesion'],
    'juncture': ['ankle', 'articulation', 'boundary', 'butt', 'caesura', 'cervix', 'circumstance', 'clause boundary', 'clause terminal', 'clinch', 'close juncture', 'closure'],
    'jungle': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 'afforestation', 'arboretum', 'boondocks', 'bush', 'bushveld', 'can of worms', 'chase', 'climax forest', 'cloud forest'],
    'junior': ['adolescent', 'after', 'assistant', 'attendant', 'baby', 'cadet', 'cog', 'common', 'commonality', 'commonalty', 'consecutive', 'creature'],
    'junior college': ['academe', 'academia', 'alma mater', 'college', 'college of engineering', 'community college', 'degree-granting institution', 'four-year college', 'graduate school', 'institute of technology', 'ivied halls', 'journalism school'],
    'junior high school': ['gymnasium', 'latin school', 'realgymnasium', 'realschule', 'academy', 'grammar school', 'high', 'high school', 'intermediate school', 'junior high', 'middle school', 'prep school'],
    'junk': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'ng', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill'],
    'junket': ['charlotte', 'campaign', 'carrot pudding', 'chocolate mousse', 'circuit', 'course', 'custard', 'duff', 'excursion', 'expedition', 'flan', 'grand tour'],
    'junkie': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser'],
    'junking': ['castaway', 'castoff', 'deep six', 'discard', 'discarding', 'disposal', 'disposition', 'dumping', 'elimination', 'jettison', 'refuse', 'reject'],
    'juno': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'junoesque': ['agreeable', 'amply endowed', 'becoming', 'bonny', 'braw', 'built', 'built for comfort', 'buxom', 'callipygian', 'callipygous', 'comely', 'curvaceous'],
    'junta': ['anschluss', 'british cabinet', 'sanhedrin', 'us cabinet', 'addition', 'advisory body', 'affiliation', 'age group', 'agglomeration', 'aggregation', 'agreement', 'alliance'],
    'jupiter': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'jupiter fulgur': ['thor', 'ball lightning', 'bolt', 'bolt of lightning', 'chain lightning', 'dark lightning', 'fireball', 'firebolt', 'flying flame', 'forked lightning', 'fulguration', 'fulmination'],
    'juridical': ['actionable', 'applicable', 'authorized', 'competent', 'constitutional', 'critical', 'judgmental', 'judicative', 'judicatorial', 'judicatory', 'judicial', 'judiciary'],
    'jurisdiction': ['accountability', 'acme', 'actionability', 'administration', 'agency', 'agentship', 'ambit', 'applicability', 'area', 'arena', 'ascendancy', 'assignment'],
    'jury rig': ['action', 'ad hoc measure', 'ad lib', 'ad-lib', 'ad-libbing', 'answer', 'arrangement', 'artifice', 'bat out', 'botch', 'bungle', 'contrivance'],
    'jury rigged': ['ad hoc', 'ad libitum', 'ad-lib', 'band-aid', 'extemporaneous', 'extemporary', 'extempore', 'impromptu', 'improvisational', 'improvisatorial', 'improvise', 'improvised'],
    'jus': ['act', 'bill', 'bylaw', 'canon', 'decree', 'dictate', 'dictation', 'edict', 'enactment', 'form', 'formality', 'formula'],
    'just': ['christian', 'ok', 'absolute', 'absolutely', 'accurate', 'accurately', 'actionable', 'admissible', 'all', 'all in all', 'all right', 'all-knowing'],
    'just about': ['about', 'all but', 'almost', 'approximately', 'around', 'as good as', 'circa', 'close', 'close upon', 'closely', 'near', 'near enough to'],
    'just right': ['ok', 'a propos', 'absolute', 'absolutely', 'accurate', 'accurately', 'ad rem', 'adapted', 'agreeably', 'all right', 'applicable', 'apposite'],
    'juste milieu': ['abnegation', 'abstinence', 'average', 'balance', 'calm', 'calmness', 'center', 'conservatism', 'constraint', 'continence', 'control', 'cool'],
    'justice': ['astraea', 'dike', 'jp', 'jupiter fidius', 'justitia', 'minos', 'nemesis', 'rhadamanthus', 'themis', 'actionability', 'applicability', 'arbiter'],
    'justifiable': ['admissible', 'allowable', 'balanced', 'cogent', 'condonable', 'credible', 'defensible', 'deserved', 'dispensable', 'due', 'equitable', 'even'],
    'justification': ['intertype', 'linotype', 'monotype', 'account', 'apologetic', 'apologia', 'beatification', 'beatitude', 'blessedness', 'blessing', 'canonization', 'cold-type typesetting'],
    'justified': ['balanced', 'born again', 'circumcised', 'converted', 'defensible', 'deserved', 'due', 'earned', 'entitled', 'equitable', 'even', 'evenhanded'],
    'justify': ['absolve', 'account', 'account for', 'acquit', 'allow', 'amnesty', 'approve', 'argue', 'assert', 'authenticate', 'authorize', 'back'],
    'justly': ['correctly', 'decently', 'decorously', 'deservedly', 'disinterestedly', 'dispassionately', 'duly', 'equally', 'equitably', 'evenly', 'fair', 'fairly'],
    'jut': ['arch over', 'beetle', 'bestraddle', 'bestride', 'bridge', 'bristle up', 'bulge', 'cock up', 'elongate', 'extend', 'extend over', 'extrude'],
    'jutting': ['beetle', 'beetle-browed', 'beetling', 'bold', 'eminent', 'emissile', 'excrescent', 'excrescential', 'extruding', 'impendence', 'impendency', 'impendent'],
    'jutty': ['abutment', 'anchorage', 'anchorage ground', 'arc-boutant', 'bank', 'basin', 'beam', 'berth', 'breakwater', 'bulkhead', 'bulwark', 'buttress'],
    'juvenile': ['roscius', 'actor', 'actress', 'adolescent', 'antagonist', 'at half cock', 'baby', 'babyish', 'bad guy', 'barnstormer', 'best seller', 'book'],
    'juvenility': ['adolescence', 'bloom', 'budtime', 'early years', 'florescence', 'flowering time', 'greenness', 'jeunesse', 'juvenescence', 'my burning youth', 'my green age', 'prime of life'],
    'juxtapose': ['abut', 'accumulate', 'adjoin', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'appose', 'assemble', 'batch', 'bring near', 'bring together'],
    'juxtaposed': ['adjacent', 'adjoining', 'bordering', 'connecting', 'conterminous', 'contiguous', 'coterminous', 'end to end', 'endways', 'endwise', 'face to face', 'immediate'],
    'juxtaposition': ['abutment', 'abuttal', 'accession', 'addition', 'adjacency', 'adjoiningness', 'adjunct', 'adjunction', 'affixation', 'agglutination', 'annexation', 'apposition'],
    'juxtapositional': ['adjacent', 'adjoining', 'bordering', 'connecting', 'conterminous', 'contiguous', 'coterminous', 'end to end', 'endways', 'endwise', 'face to face', 'immediate'],
    'kaiser': ['dalai lama', 'holy roman emperor', 'inca', 'ardri', 'bey', 'cacique', 'caesar', 'cham', 'czar', 'kaid', 'khan', 'mikado'],
    'kaleidoscopic': ['able to adapt', 'adaptable', 'adjustable', 'alterable', 'alterative', 'amorphic', 'amorphous', 'anarchic', 'baggy', 'bicolor', 'bicolored', 'blobby'],
    'kali': ['agni', 'asvins', 'avalokita', 'bhairava', 'bhairavi', 'brahma', 'chandi', 'daksha', 'devaki', 'devi', 'dharma', 'dharti mai'],
    'kama': ['agni', 'amor', 'aphrodite', 'astarte', 'asvins', 'avalokita', 'bhairava', 'bhairavi', 'brahma', 'chandi', 'cupid', 'daksha'],
    'kangaroo': ['angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'indian buffalo', 'kodiak bear', 'virginia deer', 'aardvark', 'aardwolf', 'alpaca', 'anteater', 'antelope'],
    'kangaroo court': ['appellate court', 'assizes', 'chancery', 'chancery court', 'circuit court', 'civil court', 'common-law court', 'conciliation court', 'county court', 'court of appeals', 'court of assize', 'court of chancery'],
    'kapok': ['blubber', 'breeze', 'butter', 'clay', 'cushion', 'dough', 'down', 'eiderdown', 'feather bed', 'feathers', 'fleece', 'floss'],
    'kaput': ['sol', 'all bets off', 'all gone', 'all off', 'all over', 'all up', 'annihilated', 'at an end', 'ausgespielt', 'bankrupt', 'blasted', 'blighted'],
    'karroo': ['arabia deserta', 'death valley', 'sahara', 'barren', 'barren land', 'barrens', 'brush', 'bush', 'desert', 'desolation', 'dust bowl', 'heath'],
    'kava': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'diethyltryptamine', 'dimethyltryptamine', 'gage'],
    'kayo': ['cadmean victory', 'ko', 'pyrrhic victory', 'anesthetize', 'ascendancy', 'bedaze', 'benumb', 'besot', 'blackout', 'blunt', 'call off', 'cancel'],
    'keck': ['barf', 'be nauseated', 'be seasick', 'be sick', 'bring up', 'choke on', 'chuck up', 'disgorge', 'egest', 'feed the fish', 'feel disgust', 'gag'],
    'kedge': ['anchor', 'board', 'boom', 'cast anchor', 'cast loose', 'clap on ratlines', 'clear hawse', 'come to anchor', 'cut loose', 'disembark', 'dock', 'drop the hook'],
    'keel': ['argosy', 'ascend', 'bank', 'bark', 'base', 'baseboard', 'basement', 'be lost', 'boat', 'bottom', 'bucket', 'cant'],
    'keel over': ['be lost', 'black out', 'capsize', 'careen', 'culbuter', 'drop', 'faint', 'fall senseless', 'founder', 'go down', 'gray out', 'keel'],
    'keelhauling': ['confinement', 'dismemberment', 'estrapade', 'galleys', 'hard labor', 'impalement', 'imprisonment', 'incarceration', 'jailing', 'martyrdom', 'penal servitude', 'picketing'],
    'keen': ['attic', 'ok', 'siberian', 'ablaze', 'absorbing', 'ace-high', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent'],
    'keen on': ['aching for', 'attracted', 'bent on', 'cathectic', 'concerned', 'crazy to', 'curious', 'desirous of', 'dying for', 'dying to', 'enthused', 'enthusiastic'],
    'keenly': ['acerbically', 'acerbly', 'acidly', 'acridly', 'acrimoniously', 'actively', 'animatedly', 'anxiously', 'ardently', 'avidly', 'bitingly', 'bitterly'],
    'keenness': ['absolute zero', 'acerbity', 'acidity', 'acidness', 'acidulousness', 'acridity', 'acrimony', 'acuity', 'acumen', 'acumination', 'acuteness', 'adroitness'],
    'keep': ['pow camp', 'tlc', 'abide', 'abide by', 'abstain', 'accede to', 'accommodate', 'accommodation', 'accommodations', 'accumulate', 'acknowledge', 'acropolis'],
    'keep alive': ['be spared', 'cheat death', 'conserve', 'copyright', 'embalm', 'endure', 'eternalize', 'eternize', 'extend', 'freeze', 'guard', 'hang on'],
    'keep at it': ['carry on', 'continue', 'endure', 'get along', 'get on', 'go on', 'go on with', 'hang in', 'hang tough', 'keep at', 'keep busy', 'keep driving'],
    'keep back': ['abstain', 'arrest', 'backpedal', 'backwater', 'block', 'bosom', 'bottle up', 'brake', 'bridle', 'check', 'classify', 'clip the wings'],
    'keep books': ['balance', 'balance the books', 'book', 'capitalize', 'carry', 'carry over', 'cast up accounts', 'charge off', 'close out', 'close the books', 'credit', 'debit'],
    'keep down': ['asphyxiate', 'beat down', 'bottle up', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'censor', 'choke off', 'clamp down on', 'coerce'],
    'keep faith': ['abide by', 'act up to', 'adhere to', 'attend to', 'be faithful to', 'comply with', 'conform to', 'do justice to', 'fill', 'follow', 'fulfill', 'heed'],
    'keep from': ['abstain', 'abstain from', 'anticipate', 'arrest', 'avert', 'avoid', 'bar', 'bosom', 'bridle', 'check', 'classify', 'conceal'],
    'keep going': ['abide', 'bide', 'carry on', 'cease not', 'continue', 'drag on', 'endure', 'extend', 'go along', 'go on', 'hold', 'hold on'],
    'keep house': ['anchor', 'billet at', 'bivouac', 'burrow', 'camp', 'colonize', 'come to anchor', 'domesticate', 'drop anchor', 'ensconce', 'establish residence', 'hive'],
    'keep in mind': ['bear in mind', 'brood over', 'cherish', 'consider', 'contemplate', 'dwell on', 'dwell upon', 'entertain thoughts of', 'fan the embers', 'harbor an idea', 'have in mind', 'have regard for'],
    'keep in sight': ['and listen', 'be vigilant', 'be watchful', 'bear in mind', 'eye', 'eyeball', 'follow', 'gaze at', 'have a looksee', 'have regard for', 'hold in mind', 'hold in view'],
    'keep in touch': ['answer', 'approach', 'communicate with', 'contact', 'correspond', 'establish connection', 'get to', 'interrogate', 'maintain connection', 'make advances', 'make contact with', 'make overtures'],
    'keep off': ['anticipate', 'avert', 'bar', 'beat back', 'beat off', 'block', 'brush off', 'chase', 'chase away', 'chase off', 'check', 'counter'],
    'keep on': ['abide', 'bide', 'carry on', 'cease not', 'continue', 'continue to be', 'defeat time', 'defy time', 'drag on', 'dwell', 'endure', 'exist'],
    'keep out': ['ban', 'bar', 'bar out', 'blockade', 'count out', 'cut off', 'debar', 'detain', 'embargo', 'exclude', 'freeze out', 'hold'],
    'keep quiet': ['abide', 'be mute', 'be silent', 'be still', 'coast', 'forswear speech', 'freeze', 'keep mum', 'keep silent', 'keep still', 'lie still', 'make no sign'],
    'keep score': ['book', 'calendar', 'catalog', 'enroll', 'enter', 'enumerate', 'file', 'impanel', 'index', 'inventory', 'itemize', 'list'],
    'keep the peace': ['be conservative', 'be moderate', 'be pacifistic', 'keep within bounds', 'keep within compass', 'live temperately', 'not make waves', 'not resist', 'practice nonviolence', 'practice self-control', 'relent', 'remain at peace'],
    'keep up': ['afford support', 'au courant', 'back', 'back up', 'be employed', 'bear', 'bear up', 'bolster', 'bolster up', 'brace', 'buoy up', 'buttress'],
    'keeper': ['audubon society', 'national wildlife service', 'sierra club', 'air warden', 'attendant', 'bull', 'caretaker', 'castellan', 'cerberus', 'commandant', 'conservationist', 'conservator'],
    'keeping': ['accommodation', 'accord', 'accordance', 'acquiescence', 'acquittal', 'acquittance', 'adaptation', 'adaption', 'adherence', 'adjustment', 'administration', 'agreement'],
    'keister': ['arse', 'ass', 'behind', 'bottom', 'bum', 'can', 'cheeks', 'duff', 'fanny', 'posterior', 'prat', 'rump'],
    'kelp': ['algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'diatom', 'fern', 'fruits and vegetables'],
    'kelpie': ['davy', 'davy jones', 'neptune', 'nereid', 'oceanid', 'oceanus', 'poseidon', 'thetis', 'triton', 'fresh-water nymph', 'limniad', 'man fish'],
    'ken': ['absorb', 'acquaintance', 'appreciate', 'apprehend', 'assimilate', 'be acquainted with', 'be apprised of', 'be aware of', 'be cognizant of', 'be conscious of', 'be conversant with', 'be informed'],
    'kennel': ['aqueduct', 'army', 'beleaguer', 'beset', 'besiege', 'blockade', 'bound', 'box in', 'bunch', 'cage', 'canal', 'canalization'],
    'keno': ['bingo', 'card games', 'chuck and toss', 'chuck farthing', 'chuck-a-luck', 'class lottery', 'crack-loo', 'crap game', 'crap shooting', 'craps', 'draft lottery', 'drawing'],
    'kept': ['conserved', 'held', 'held back', 'held in reserve', 'intact', 'preserved', 'protected', 'put by', 'reserved', 'retained', 'saved', 'spare'],
    'kernel': ['brazil nut', 'acorn', 'almond', 'almond paste', 'amande', 'amande douce', 'amandes mondees', 'axiom', 'axis', 'bench mark', 'berry', 'bird seed'],
    'kerosene': ['alcohol', 'avgas', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coal oil', 'coke', 'combustible'],
    'kettledrum': ['bongo drum', 'conga', 'drum', 'drumhead', 'drumskin', 'drumstick', 'jazz stick', 'kettle', 'membranophone', 'side drum', 'snare', 'snare drum'],
    'key': ['french pitch', 'rasputin', 'svengali', 'telautography', 'teletype', 'teletype network', 'teletyping', 'vip', 'access', 'accommodate', 'accord', 'achromatism'],
    'key signature': ['accent', 'accent mark', 'bar', 'cancel', 'character', 'custos', 'direct', 'dominant', 'dot', 'expression mark', 'fermata', 'hold'],
    'key up': ['accelerate', 'aggravate', 'annoy', 'arouse', 'awake', 'awaken', 'beef up', 'blow the coals', 'blow up', 'call forth', 'call up', 'complicate'],
    'keyboard': ['autotype', 'choir', 'claviature', 'console', 'echo', 'eighty-eight', 'electrotype', 'fingerboard', 'great', 'ivories', 'keys', 'linotype'],
    'keyed up': ['agog', 'anxious', 'apprehensive', 'aquiver', 'aroused', 'atingle', 'atwitter', 'bursting', 'carried away', 'ebullient', 'effervescent', 'excited'],
    'keyhole': ['air hole', 'armhole', 'blowhole', 'bullet-hole', 'bunghole', 'cringle', 'deadeye', 'eye', 'eyelet', 'gasket', 'grommet', 'guide'],
    'keynote': ['aroma', 'attribute', 'badge', 'banner', 'be characteristic', 'brand', 'cachet', 'cast', 'character', 'characteristic', 'characterize', 'configuration'],
    'keys': ['choir', 'claviature', 'console', 'crook', 'crosier', 'echo', 'eighty-eight', 'fingerboard', 'great', 'ivories', 'keyboard', 'manual'],
    'keystone': ['apse', 'arcade', 'arcature', 'arch', 'arched roof', 'archway', 'basis', 'bench mark', 'camber', 'cardinal point', 'ceilinged roof', 'chief thing'],
    'khaki': ['beige', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'chocolate', 'cinnamon', 'cocoa', 'cocoa-brown', 'coffee', 'coffee-brown', 'drab'],
    'khan': ['dalai lama', 'esquire', 'great mogul', 'holy roman emperor', 'inca', 'kaiser', 'master', 'mister', 'mogul', 'muslim rulers', 'prinz', 'sir'],
    'kibbutz': ['arable land', 'barnyard', 'barton', 'cattle ranch', 'chicken farm', 'collective farm', 'collectivism', 'collectivity', 'collegiality', 'common ownership', 'communal effort', 'communion'],
    'kibitz': ['paul-pry', 'advise', 'advocate', 'brief', 'busybody', 'coach', 'confer', 'consult with', 'counsel', 'direct', 'fool with', 'guide'],
    'kibitzer': ['dutch uncle', 'paul pry', 'polonius', 'tv-viewer', 'admonisher', 'adviser', 'backseat driver', 'beholder', 'bird-watcher', 'busybody', 'butt-in', 'buttinsky'],
    'kibosh': ['ko', 'bugger', 'call off', 'cancel', 'complete', 'cripple', 'de-energize', 'debilitate', 'delete', 'disable', 'disenable', 'dispose of'],
    'kick': ['roman candle', 'abandon', 'aggressiveness', 'aid to navigation', 'air a grievance', 'alarm', 'amber light', 'amusement', 'animal pleasure', 'antagonism', 'antipathy', 'backfire'],
    'kick back': ['abate', 'allow', 'atone', 'backfire', 'backlash', 'bate', 'boomerang', 'bounce', 'bounce back', 'bound', 'bound back', 'cannon'],
    'kick in': ['buy it', 'cash in', 'check in', 'check out', 'chip in', 'come', 'come across', 'come across with', 'come down with', 'come through with', 'contribute', 'contribute to'],
    'kick off': ['antecede', 'begin', 'blast away', 'blast off', 'bundle', 'bundle off', 'buy it', 'cash in', 'check in', 'check out', 'come before', 'come first'],
    'kick out': ['ax', 'boot out', 'bounce', 'can', 'cashier', 'cast', 'cast out', 'chase', 'chuck', 'chuck out', 'defenestrate', 'detrude'],
    'kick upstairs': ['advance', 'aggrandize', 'boot', 'bounce', 'break', 'bump', 'bust', 'can', 'cashier', 'deconsecrate', 'defrock', 'degrade'],
    'kickback': ['abatement', 'agio', 'allowance', 'backfire', 'backlash', 'backlashing', 'bank discount', 'boomerang', 'bounce', 'bound', 'breakage', 'bribe'],
    'kicker': ['astonishment', 'bellyacher', 'blockbuster', 'blow', 'bomb', 'bombshell', 'boundary condition', 'catch', 'clause', 'complainant', 'complainer', 'condition'],
    'kickshaw': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'agate', 'ambrosia', 'bagatelle', 'ball', 'baseball bat', 'bat', 'battledore'],
    'kid': ['babyhood', 'bairn', 'bamboozle', 'banter', 'be merry with', 'befool', 'billy', 'billy goat', 'birdling', 'boyhood', 'breed', 'brood'],
    'kid around': ['be merry with', 'coquet', 'crack a joke', 'crack wise', 'dabble', 'dally', 'fiddle', 'fiddle with', 'fiddle-faddle', 'fidget with', 'finger with', 'fleer at'],
    'kidder': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'actor', 'bamboozler', 'banterer', 'befuddler', 'beguiler', 'chaffer'],
    'kidding': ['badinage', 'bamboozlement', 'banter', 'bantering', 'befooling', 'bluffing', 'booing', 'calculated deception', 'catcalling', 'chaff', 'chaffing', 'circumvention'],
    'kidnap': ['abduce', 'abduct', 'capture', 'carry away', 'carry off', 'coax', 'crimp', 'decoy', 'entice', 'hold for ransom', 'impress', 'inveigh'],
    'kidnapping': ['abduction', 'apprehension', 'arrest', 'arrestation', 'capture', 'catch', 'catching', 'collaring', 'coup', 'crimping', 'dragnet', 'forcible seizure'],
    'kidney': ['abatis', 'abdomen', 'animus', 'anus', 'appendix', 'aptitude', 'bent', 'bias', 'blind gut', 'blood', 'bowels', 'brain'],
    'kill': ['ko', 'abbreviate', 'abridge', 'absorb', 'adolescent stream', 'amuse', 'annihilate', 'arroyo', 'asphyxiate', 'assassinate', 'bane', 'beasts of venery'],
    'kill crazy': ['atrocious', 'barbaric', 'barbarous', 'bestial', 'bloody', 'brutal', 'brutish', 'feral', 'ferine', 'ferocious', 'fierce', 'inhuman'],
    'kill time': ['beguile the time', 'burn daylight', 'buy time', 'consume time', 'dabble', 'diddle', 'doodle', 'drown care', 'footle', 'fribble', 'fritter away time', 'have a ball'],
    'killer': ['bluebeard', 'cain', 'mafioso', 'young turk', 'apache', 'assassin', 'assassinator', 'beast', 'beldam', 'berserk', 'berserker', 'bloodletter'],
    'killer diller': ['ace', 'beaut', 'corker', 'crackerjack', 'daisy', 'dandy', 'darb', 'dilly', 'dream', 'honey', 'humdinger', 'knockout'],
    'killing': ['herculean', 'arduous', 'asphyxiation', 'assault', 'attack', 'backbreaking', 'baneful', 'battering', 'beaming', 'best seller', 'big hit', 'blood'],
    'killjoy': ['cassandra', 'eeyore', 'calamity howler', 'crepehanger', 'cynic', 'damp', 'dampener', 'damper', 'defeatist', 'gloomy gus', 'grouch', 'grump'],
    'kiln': ['seger cone', 'acid kiln', 'air-dry', 'anhydrate', 'bake', 'blot', 'brickkiln', 'brush', 'burn', 'cement kiln', 'cure', 'dehumidify'],
    'kilo': ['carat', 'centigram', 'chiliad', 'chiliagon', 'chiliahedron', 'chiliarch', 'chiliarchia', 'decagram', 'decigram', 'dram', 'dram avoirdupois', 'dyne'],
    'kilocycle': ['af', 'cps', 'ehf', 'hf', 'hz', 'mf', 'rf', 'shf', 'uhf', 'vhf', 'vlf', 'audio frequency'],
    'kilometer': ['angstrom unit', 'astronomical unit', 'block', 'centimeter', 'chain', 'chiliad', 'chiliagon', 'chiliahedron', 'chiliarch', 'chiliarchia', 'cubit', 'decameter'],
    'kilowatt hour': ['abampere', 'abcoulomb', 'abfarad', 'abhenry', 'abohm', 'abvolt', 'ampere', 'ampere-foot', 'ampere-hour', 'ampere-minute', 'atomerg', 'calorie'],
    'kin': ['agnate', 'ancestry', 'blood', 'blood relation', 'blood relative', 'bracket', 'branch', 'brand', 'breed', 'cast', 'caste', 'category'],
    'kind': ['christian', 'christlike', 'christly', 'accommodating', 'advantageous', 'affable', 'affectionate', 'agreeable', 'altruistic', 'amiable', 'amicable', 'animal kingdom'],
    'kind of': ['a bit', 'a little', 'as it were', 'extremely', 'fairly', 'in a manner', 'in a measure', 'in a way', 'in some measure', 'moderately', 'more', 'pretty'],
    'kindergartner': ['classmate', 'fellow student', 'grade schooler', 'high schooler', 'infant', 'intermediate schooler', 'nursery school child', 'prep schooler', 'preschool child', 'preschooler', 'primary schooler', 'school child'],
    'kindhearted': ['christian', 'christlike', 'christly', 'affectionate', 'benign', 'benignant', 'brotherly', 'compassionate', 'decent', 'fraternal', 'good', 'gracious'],
    'kindle': ['agitate', 'anger', 'animate', 'annoy', 'arouse', 'awake', 'awaken', 'bank', 'bestir', 'blaze', 'blaze up', 'blow the coals'],
    'kindled': ['ablaze', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'blazing', 'burning', 'candent', 'candescent', 'comburent'],
    'kindling': ['backlog', 'bavin', 'brush', 'brushwood', 'enkindling', 'fagot', 'firewood', 'firing', 'flammation', 'ignition', 'incendiary', 'inflaming'],
    'kindly': ['christian', 'christlike', 'christly', 'accommodating', 'affable', 'affably', 'affectionate', 'agreeable', 'agreeably', 'amiable', 'amiably', 'amicable'],
    'kindness': ['accommodatingness', 'act of grace', 'act of kindness', 'advantageousness', 'affability', 'agreeableness', 'aid', 'amiability', 'amiableness', 'amicability', 'amicableness', 'amity'],
    'kindred': ['affiliated', 'affiliation', 'affinal', 'agnate', 'agnation', 'akin', 'alliance', 'allied', 'analogous', 'ancestry', 'associated', 'avuncular'],
    'kine': ['brahman', 'indian buffalo', 'aurochs', 'beef', 'beef cattle', 'beeves', 'bison', 'bossy', 'bovine', 'bovine animal', 'buffalo', 'bull'],
    'kinescope': ['boom shot', 'cathode-ray tube', 'close-up', 'color kinescope', 'deuce shot', 'direct-viewing tube', 'follow-focus shot', 'full shot', 'group shot', 'long shot', 'matte shot', 'medium shot'],
    'kinesis': ['activity', 'actuation', 'dynamics', 'going', 'kinematics', 'kinesipathy', 'kinesitherapy', 'kinetics', 'mobilization', 'motion', 'motivation', 'move'],
    'kinetic': ['active', 'acute', 'aggressive', 'animated', 'brisk', 'dynamic', 'electrodynamic', 'energetic', 'enterprising', 'enthusiastic', 'forceful', 'forcible'],
    'kinetics': ['activity', 'actuation', 'aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology'],
    'kinfolk': ['agnate', 'ancestry', 'blood', 'blood relation', 'blood relative', 'clansman', 'cognate', 'collateral', 'collateral relative', 'connections', 'consanguinean', 'distaff side'],
    'king': ['muslim rulers', 'prinz', 'ace', 'anointed king', 'atheling', 'banker', 'baron', 'best bower', 'big boss', 'big businessman', 'bishop', 'bower'],
    'king size': ['gargantuan', 'amplitudinous', 'astronomical', 'awesome', 'boundless', 'bulky', 'colossal', 'cosmic', 'enormous', 'extensive', 'galactic', 'gigantic'],
    'kingdom': ['ally', 'animal kingdom', 'antonomasia', 'archduchy', 'archdukedom', 'area', 'bailiwick', 'binomial nomenclature', 'biological classification', 'biosystematics', 'biosystematy', 'biotype'],
    'kingdom come': ['agapemone', 'arcadia', 'beulah', 'beulah land', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden'],
    'kingly': ['aristocratic', 'august', 'chivalrous', 'courtly', 'dignified', 'ducal', 'dynastic', 'exalted', 'genteel', 'gentle', 'gentlemanlike', 'gentlemanly'],
    'kingmaker': ['machiavellian', 'rasputin', 'svengali', 'vip', 'access', 'bad influence', 'behind-the-scenes operator', 'big wheel', 'court', 'eminence grise', 'finagler', 'five-percenter'],
    'kingship': ['acme', 'authority', 'authorization', 'baronetcy', 'barony', 'be-all and end-all', 'blue ribbon', 'caliphate', 'championship', 'command', 'control', 'czardom'],
    'kink': ['acute pain', 'birthmark', 'bite', 'blackhead', 'bleb', 'blemish', 'blister', 'boring pain', 'boutade', 'brainstorm', 'bug', 'bulla'],
    'kinked': ['blemished', 'checked', 'cicatrized', 'cracked', 'crazed', 'crisp', 'crisped', 'crispy', 'curled', 'curly', 'defaced', 'defective'],
    'kinky': ['bohemian', 'abnormal', 'anomalous', 'arbitrary', 'beat', 'bizarre', 'breakaway', 'capricious', 'crank', 'crankish', 'cranky', 'crimped'],
    'kinship': ['accord', 'accordance', 'affiliation', 'affinity', 'agape', 'agnation', 'agreement', 'alliance', 'amity', 'ancestry', 'association', 'blood'],
    'kinsmen': ['agnate', 'ancestry', 'blood', 'blood relation', 'blood relative', 'clansman', 'cognate', 'collateral', 'collateral relative', 'connections', 'consanguinean', 'distaff side'],
    'kiosk': ['nissen hut', 'quonset hut', 'alcove', 'arbor', 'booth', 'bower', 'conservatory', 'crib', 'gatehouse', 'gazebo', 'glasshouse', 'greenhouse'],
    'kipper': ['loch ness monster', 'alevin', 'anguille', 'anhydrate', 'benthon', 'benthos', 'blast-freeze', 'brine', 'caviar', 'cetacean', 'corn', 'cure'],
    'kishkes': ['abdomen', 'abomasum', 'anus', 'appendix', 'bay window', 'beerbelly', 'belly', 'blind gut', 'bowels', 'brain', 'breadbasket', 'cecum'],
    'kismet': ['friday', 'friday the thirteenth', 'appointed lot', 'astral influences', 'astrology', 'book of fate', 'circumstance', 'constellation', 'cup', 'destination', 'destiny', 'dies funestis'],
    'kiss': ['abandon', 'accost', 'address', 'attouchement', 'bid good day', 'bid good morning', 'blow a kiss', 'bob', 'bow', 'bow to', 'breath', 'brush'],
    'kiss good bye': ['abandon', 'abjure', 'be bereaved of', 'cede', 'default', 'disgorge', 'dispense with', 'dispose of', 'do without', 'drop', 'dump', 'forfeit'],
    'kisser': ['bazoo', 'chaps', 'chops', 'countenance', 'dial', 'embouchure', 'face', 'facies', 'favor', 'features', 'gab', 'gob'],
    'kit': ['a string', 'amati', 'cheshire cat', 'chinchilla cat', 'cremona', 'd string', 'e string', 'g string', 'maltese cat', 'strad', 'stradivari', 'stradivarius'],
    'kitchen': ['automat', 'bakehouse', 'bakery', 'beanery', 'bistro', 'buffet', 'buvette', 'caboose', 'cafe', 'cafeteria', 'camboose', 'canteen'],
    'kitchen cabinet': ['british cabinet', 'sanhedrin', 'us cabinet', 'advisory body', 'advisory council', 'assembly', 'association', 'bench', 'board', 'body of advisers', 'borough council', 'brain trust'],
    'kitchen police': ['kp', 'army', 'army group', 'battalion', 'battery', 'battle group', 'brigade', 'cadre', 'cohort', 'column', 'combat command', 'combat team'],
    'kite': ['eddy kite', 'aeroplane', 'aircraft', 'airplane', 'aspire', 'avion', 'bad check', 'bad money', 'base coin', 'become airborne', 'begone', 'bogus money'],
    'kith and kin': ['agnate', 'ancestry', 'blood', 'blood relation', 'blood relative', 'clansman', 'cognate', 'collateral', 'collateral relative', 'connections', 'consanguinean', 'distaff side'],
    'kitsch': ['babbittry', 'french literature', 'renaissance literature', 'ancient literature', 'art object', 'bad taste', 'belles lettres', 'bourgeois taste', 'brainchild', 'bric-a-brac', 'camp', 'campiness'],
    'kitten': ['cheshire cat', 'chinchilla cat', 'maltese cat', 'alley cat', 'bairn', 'be confined', 'bear', 'bear a child', 'bear young', 'birdling', 'blue cat', 'calf'],
    'kittenish': ['babish', 'baby', 'babyish', 'catlike', 'cattish', 'catty', 'coltish', 'coquettish', 'coy', 'distaff', 'doll-like', 'dollish'],
    'kitty': ['cheshire cat', 'chinchilla cat', 'maltese cat', 'swiss bank account', 'alley cat', 'assets', 'balance', 'bank', 'bank account', 'blue cat', 'bottom dollar', 'budget'],
    'kittycorner': ['across', 'athwart', 'bendwise', 'bias', 'biased', 'biaswise', 'catercorner', 'catercornered', 'catercornerways', 'cornerways', 'cornerwise', 'crossways'],
    'klaxon': ['mayday', 'sos', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert', 'all clear', 'beacon', 'blinking light'],
    'klutz': ['asshole', 'blockhead', 'blunderer', 'blunderhead', 'boob', 'booby', 'boor', 'botcher', 'bumbler', 'bungler', 'chump', 'clod'],
    'klutzy': ['boeotian', 'asinine', 'beef-brained', 'beef-witted', 'blockish', 'bovine', 'chumpish', 'cloddish', 'cowish', 'crass', 'dense', 'doltish'],
    'knack': ['ability', 'adroitness', 'aptitude', 'aptness', 'art', 'bauble', 'bent', 'bibelot', 'bric-a-brac', 'capacity', 'command', 'dexterity'],
    'knave': ['ace', 'bad boy', 'bastard', 'best bower', 'blackguard', 'booger', 'bower', 'buffoon', 'bugger', 'cards', 'clubs', 'cutup'],
    'knavery': ['abomination', 'art', 'artful dodge', 'artifice', 'atrocity', 'bad', 'baseness', 'blind', 'chicanery', 'conspiracy', 'contrivance', 'coup'],
    'knavish': ['abominable', 'arch', 'arrant', 'atrocious', 'bad', 'base', 'black', 'blackguardly', 'blamable', 'blameworthy', 'criminal', 'damnable'],
    'knead': ['admix', 'alloy', 'amalgamate', 'bemingle', 'blend', 'block out', 'caress', 'carve', 'cast', 'chisel', 'coalesce', 'combine'],
    'knee': ['angle', 'ankle', 'apex', 'articulation', 'bayonet legs', 'bend', 'bifurcation', 'bight', 'boot', 'boundary', 'bowlegs', 'butt'],
    'knee deep': ['ankle-deep', 'cursory', 'deep', 'deep-cut', 'deep-down', 'deep-engraven', 'deep-fixed', 'deep-laid', 'deep-lying', 'deep-reaching', 'deep-rooted', 'deep-seated'],
    'knee high': ['couchant', 'cramped', 'crouched', 'debased', 'depressed', 'dinky', 'exiguous', 'flat', 'half-pint', 'knocked flat', 'laid low', 'limited'],
    'kneel': ['bend', 'bend the knee', 'bend the neck', 'bob', 'bob a curtsy', 'bob down', 'bootlick', 'bow', 'bow and scrape', 'bow down', 'bow the head', 'cower'],
    'kneel to': ['adjure', 'appeal', 'appeal to', 'beg', 'bend', 'bend the neck', 'bend to', 'beseech', 'bow', 'bow and scrape', 'bow down', 'bow to'],
    'knell': ['annihilation', 'bane', 'bell', 'bemoan', 'bewail', 'biological death', 'bong', 'cessation of life', 'change ringing', 'chime', 'chiming', 'chink'],
    'knickknack': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'agate', 'bagatelle', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble'],
    'knife': ['ax', 'barong', 'bayonet', 'blade', 'bolo', 'bowie', 'bowie knife', 'cold steel', 'cut', 'cutlery', 'cutter', 'dagger'],
    'knight': ['bayard', 'don quixote', 'gawain', 'lancelot', 'ritter', 'sidney', 'sir galahad', 'advance', 'aggrandize', 'bachelor', 'banneret', 'baronet'],
    'knight errantry': ['bigheartedness', 'bigness', 'chivalrousness', 'chivalry', 'elevation', 'errantry', 'exaltation', 'generosity', 'generousness', 'great heart', 'greatheartedness', 'greatness'],
    'knighthood': ['arms', 'art of war', 'baronetcy', 'barony', 'chivalry', 'dukedom', 'earldom', 'generalship', 'kingship', 'knight-errantship', 'ladyship', 'lordship'],
    'knightly': ['aristocratic', 'big', 'bighearted', 'bold', 'bold-spirited', 'brave', 'ceremonious', 'chivalric', 'chivalrous', 'courageous', 'courtly', 'doughty'],
    'knit': ['abbreviate', 'adhere', 'affix', 'anchor', 'annex', 'attach', 'belay', 'bind', 'braid', 'cement', 'cicatrize', 'cinch'],
    'knitted': ['clamped', 'cockled', 'cockly', 'compressed', 'concentrated', 'condensed', 'consolidated', 'constricted', 'contracted', 'corrugate', 'corrugated', 'cramped'],
    'knitting': ['abbreviation', 'applique', 'astriction', 'astringency', 'basting', 'binding', 'bottleneck', 'braiding', 'buttonholing', 'cervix', 'circumscription', 'coarctation'],
    'knob': ['anthill', 'ball', 'balloon', 'barrow', 'bilge', 'bladder', 'blain', 'bleb', 'blister', 'blob', 'boll', 'bolus'],
    'knobbed': ['burled', 'gnarled', 'gnarly', 'knobby', 'knoblike', 'knotted', 'knotty', 'knurled', 'knurly', 'nappy', 'nodal', 'noded'],
    'knobby': ['alpen', 'alpestrine', 'alpigene', 'alpine', 'burled', 'gnarled', 'gnarly', 'hilly', 'knobbed', 'knobbly', 'knoblike', 'knotted'],
    'knock': ['ko', 'abuse', 'adverse criticism', 'animadversion', 'arouse', 'aspersion', 'associate with', 'astonish', 'astound', 'awaken', 'bad notices', 'bad press'],
    'knock about': ['abuse', 'bat around', 'batter', 'bruise', 'buffet', 'bum', 'count ties', 'divagate', 'do violence to', 'do wrong by', 'do wrong to', 'drift'],
    'knock around': ['air', 'analyze', 'bat around', 'bum', 'canvass', 'comment upon', 'consider', 'controvert', 'count ties', 'deal with', 'debate', 'deliberate'],
    'knock dead': ['amuse', 'beam', 'becharm', 'beggar description', 'beguile', 'bewitch', 'bloom', 'captivate', 'carry away', 'charm', 'convulse', 'delectate'],
    'knock down': ['auction', 'auction off', 'auctioneer', 'bang', 'bash', 'bat', 'beat down', 'belittle', 'belt', 'biff', 'blow down', 'blow over'],
    'knock it off': ['abandon', 'abort', 'belay', 'cancel', 'cease', 'cut it out', 'desist', 'discontinue', 'drop it', 'end', 'give over', 'halt'],
    'knock kneed': ['bandy', 'bandy-legged', 'blemished', 'bloated', 'bowlegged', 'club-footed', 'defaced', 'deformed', 'disfigured', 'dwarfed', 'flatfooted', 'grotesque'],
    'knock off': ['abscind', 'accomplish', 'achieve', 'ad-lib', 'amputate', 'annihilate', 'assassinate', 'attain', 'author', 'ban', 'bar', 'bat out'],
    'knock out': ['ko', 'anesthetize', 'author', 'bang', 'bash', 'bat', 'bat out', 'beat', 'becharm', 'bedaze', 'belt', 'benumb'],
    'knock over': ['beat down', 'blow down', 'bowl over', 'break down', 'bring down', 'bulldoze', 'burn down', 'cast down', 'chop down', 'commit robbery', 'cut down', 'down'],
    'knock-down-and-drag-out': ['affray', 'altercation', 'barney', 'bickering', 'boisterous', 'brawl', 'broil', 'dispute', 'donnybrook', 'donnybrook fair', 'dustup', 'fight'],
    'knocker': ['thersites', 'backbiter', 'bag', 'belittler', 'boobs', 'bosom', 'breast', 'breasts', 'brisket', 'bust', 'calumniator', 'carper'],
    'knockout': ['cadmean victory', 'ko', 'miss america', 'pyrrhic victory', 'ace', 'ascendancy', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'beauty queen'],
    'knockout drops': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill'],
    'knockwurst': ['vienna sausage', 'bangers', 'black pudding', 'blood pudding', 'bologna', 'braunschweiger', 'frank', 'frankfurter', 'gooseliver', 'headcheese', 'hot dog', 'liver sausage'],
    'knoll': ['anthill', 'barrow', 'brae', 'butte', 'crest', 'down', 'drumlin', 'dune', 'elevation', 'fell', 'foothills', 'hill'],
    'knot': ['blackwall hitch', 'chinese puzzle', 'flemish knot', 'french shroud knot', 'german knot', 'gordian knot', 'matthew walker knot', 'rube goldberg contraption', 'windsor knot', 'accouple', 'accumulate', 'adhesive'],
    'knothole': ['air hole', 'armhole', 'blowhole', 'bullet-hole', 'bunghole', 'cringle', 'deadeye', 'eye', 'eyelet', 'gasket', 'grommet', 'guide'],
    'knotted': ['byzantine', 'herculean', 'abstruse', 'accumulated', 'affiliate', 'affiliated', 'agglomerate', 'aggregate', 'alike', 'allied', 'amassed', 'arduous'],
    'knotty': ['byzantine', 'herculean', 'abstruse', 'arduous', 'beyond one', 'brutal', 'burled', 'complex', 'complicated', 'crabbed', 'cramp', 'critical'],
    'know': ['absorb', 'account', 'acquaintance', 'aller sans dire', 'announcement', 'appreciate', 'apprehend', 'assimilate', 'associate with', 'be acquainted with', 'be apprised of', 'be aware of'],
    'know how': ['ability', 'acquaintance', 'address', 'adeptness', 'adroitness', 'airmanship', 'art', 'artfulness', 'artisanship', 'artistry', 'bravura', 'brilliance'],
    'know no bounds': ['advance upon', 'break bounds', 'carry too far', 'encroach', 'exaggerate', 'exhaust', 'fill', 'flood', 'go overboard', 'go to extremes', 'go too far', 'infringe'],
    'know nothing': ['antiblack', 'awkward', 'be green', 'be ignorant', 'benighted', 'biased', 'blankminded', 'callow', 'chauvinistic', 'colored', 'dabbler', 'dilettante'],
    'know well': ['attain mastery of', 'be expert in', 'be informed', 'be learned in', 'be master of', 'be told', 'be up on', 'be well-informed', 'become adept in', 'command', 'get down cold', 'get down pat'],
    'know-it-all': ['narcissus', 'aggressively self-confident', 'biggety', 'braggart', 'bumptious', 'chesty', 'cocky', 'conceited', 'egocentric', 'egoist', 'egotist', 'immodest'],
    'knowing': ['byzantine', 'machiavellian', 'machiavellic', 'acute', 'advised', 'aimed', 'aimed at', 'alive', 'all-knowing', 'apperceptive', 'appercipient', 'apprehending'],
    'knowingly': ['advisedly', 'artfully', 'astutely', 'by design', 'cagily', 'calculatedly', 'cannily', 'circumspectly', 'cleverly', 'consciously', 'considerately', 'contemplatedly'],
    'knowledge': ['iq', 'account', 'acquaintance', 'adeptness', 'advice', 'announcement', 'appreciation', 'apprehension', 'awareness', 'blue book', 'briefing', 'broadening the mind'],
    'knowledgeable': ['all-knowing', 'apperceptive', 'appercipient', 'apprehending', 'apprehensive', 'au courant', 'au fait', 'authoritative', 'aware', 'brainy', 'bright', 'brilliant'],
    'knub': ['feel', 'finish', 'grain', 'granular texture', 'indentation', 'nap', 'nub', 'pile', 'pit', 'pock', 'protuberance', 'shag'],
    'knuckle': ['chateaubriand', 'ankle', 'articulation', 'blade roast', 'boundary', 'bow', 'breast', 'brisket', 'butt', 'capitulate', 'cave', 'cervix'],
    'knuckle down': ['accede', 'accept', 'acquiesce', 'assent', 'be agreeable', 'buckle down', 'comply', 'consent', 'endeavor', 'face the music', 'go all out', 'go along with'],
    'knuckle under': ['accede', 'accept', 'acquiesce', 'assent', 'be agreeable', 'bow', 'capitulate', 'cave', 'comply', 'consent', 'defer', 'face the music'],
    'knucklehead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead'],
    'knuckleheaded': ['beetleheaded', 'blockheaded', 'blunderheaded', 'boneheaded', 'cabbageheaded', 'chowderheaded', 'chuckleheaded', 'clodpated', 'dumbheaded', 'dunderheaded', 'fatheaded', 'jolterheaded'],
    'knurl': ['vandyke', 'bilge', 'blain', 'blaze', 'bleb', 'blister', 'blob', 'boss', 'bow', 'bubble', 'bulb', 'bulge'],
    'knurled': ['burled', 'gnarled', 'gnarly', 'knobbed', 'knobbly', 'knobby', 'knoblike', 'knotted', 'knotty', 'knurly', 'lumpy', 'nodal'],
    'ko': ['cadmean victory', 'pyrrhic victory', 'anesthetize', 'ascendancy', 'bedaze', 'benumb', 'besot', 'blackout', 'blunt', 'call off', 'cancel', 'catalepsy'],
    'kook': ['alien', 'aliene', 'bedlamite', 'borderline case', 'case', 'character', 'crackbrain', 'crackpot', 'crank', 'cuckoo', 'dement', 'demoniac'],
    'kooky': ['abnormal', 'absurd', 'anomalous', 'apish', 'asinine', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'befooled'],
    'kore': ['agdistis', 'aides', 'aidoneus', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus'],
    'kosher': ['accordant', 'according to hoyle', 'actionable', 'anal', 'applicable', 'appropriate', 'authorized', 'bleached', 'bourgeois', 'bright', 'clean', 'cleanly'],
    'kowtow': ['apple-polish', 'bend', 'bend the knee', 'bend the neck', 'bend to', 'bending the knee', 'bob', 'bob a curtsy', 'bob down', 'bootlick', 'bow', 'bow and scrape'],
    'kraut': ['anzac', 'aussie', 'boche', 'canuck', 'chink', 'fritz', 'gi', 'guinea', 'heinie', 'hun', 'hunk', 'hunkie'],
    'kudos': ['acclaim', 'acclamation', 'accolade', 'adulation', 'apotheosis', 'applause', 'award', 'badge', 'bays', 'bepraisement', 'celebrity', 'character'],
    'kvetch': ['bellyacher', 'complainant', 'complainer', 'crab', 'crank', 'croaker', 'faultfinder', 'frondeur', 'griper', 'grouch', 'grouser', 'growler'],
    'kyrie eleison': ['agnus dei', 'alleluia', 'anamnesis', 'angelus', 'ave', 'ave maria', 'blessing', 'canon', 'collect', 'communion', 'consecration', 'credo'],
    'label': ['achievement', 'alerion', 'animal charge', 'annulet', 'appellation', 'appellative', 'argent', 'armorial bearings', 'armory', 'arms', 'azure', 'bandeau'],
    'labial': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation', 'back'],
    'labor': ['accouchement', 'activities', 'activity', 'affair', 'affairs', 'aim', 'always trot out', 'amplify', 'assignment', 'bag', 'be busy', 'be confined'],
    'labor camp': ['pow camp', 'bastille', 'black hole', 'borstal', 'borstal institution', 'bridewell', 'brig', 'cell', 'concentration camp', 'condemned cell', 'death cell', 'death house'],
    'labor in vain': ['be found wanting', 'be unsuccessful', 'beat the air', 'bootless errand', 'come to grief', 'fail', 'fail of success', 'flunk', 'flunk out', 'go bankrupt', 'labor of sisyphus', 'lash the waves'],
    'labor of love': ['act of grace', 'act of kindness', 'benefaction', 'benefit', 'benevolence', 'benignity', 'blessing', 'complimentariness', 'costlessness', 'courtesy', 'expenselessness', 'favor'],
    'labor saving': ['scotch', 'canny', 'careful', 'chary', 'cheeseparing', 'conserving', 'economic', 'economizing', 'forehanded', 'frugal', 'money-saving', 'parsimonious'],
    'labor under': ['ail', 'be affected with', 'be exposed to', 'be subjected to', 'complain of', 'encounter', 'endure', 'experience', 'feel', 'feel ill', 'go through', 'have'],
    'laboratory': ['x ray', 'blood bank', 'charity ward', 'clinic', 'consultation room', 'delivery room', 'dispensary', 'emergency', 'examining room', 'fever ward', 'hospital room', 'intensive care'],
    'labored': ['herculean', 'latinate', 'affected', 'alliterating', 'alliterative', 'arabesque', 'arduous', 'artificial', 'assonant', 'awkward', 'backbreaking', 'baroque'],
    'laborer': ['blue-collar worker', 'bourgeoisie', 'breadwinner', 'casual', 'casual laborer', 'common laborer', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty'],
    'laborious': ['herculean', 'abstruse', 'ardent', 'arduous', 'assiduous', 'backbreaking', 'brutal', 'burdensome', 'careful', 'complex', 'critical', 'crushing'],
    'laboriously': ['ardently', 'arduously', 'assiduously', 'bec et ongles', 'burdensomely', 'difficultly', 'diligently', 'effortfully', 'energetically', 'fervently', 'hammer and tongs', 'hard'],
    'labyrinth': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 'can of worms', 'complex', 'jungle', 'knot', 'maze', 'meander', 'mesh', 'mess', 'morass'],
    'labyrinthine': ['byzantine', 'gongoresque', 'johnsonian', 'aberrant', 'aberrative', 'affected', 'ambagious', 'anamorphous', 'anfractuous', 'askew', 'asymmetric', 'balled up'],
    'lace': ['brussels point', 'roman lace', 'shetland lace', 'venetian point', 'adulterate', 'arabesque', 'assail', 'assault', 'attack', 'band', 'bandage', 'basketry'],
    'laced': ['barred', 'braided', 'cancellated', 'crossbarred', 'enlaced', 'entwined', 'filigreed', 'fretted', 'grated', 'gridded', 'handwoven', 'interknit'],
    'lacerate': ['abrade', 'afflict', 'agonize', 'ail', 'bark', 'bite', 'blemish', 'bloody', 'break', 'burn', 'chafe', 'check'],
    'lacerated': ['afflicted', 'aggravated', 'agonized', 'battlemented', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped', 'chopped', 'clawed'],
    'laceration': ['abrasion', 'abscission', 'amputation', 'blemish', 'break', 'burn', 'butchering', 'chafe', 'check', 'chip', 'chopping', 'clawing'],
    'lachrymal': ['bloody', 'blubbering', 'chylifactive', 'chylifactory', 'chylific', 'crying', 'dissolved in tears', 'excretory', 'humoral', 'ichorous', 'in tears', 'lachrymose'],
    'lachrymose': ['blubbering', 'crying', 'dissolved in tears', 'excretory', 'in tears', 'lachrymal', 'lacrimatory', 'lactational', 'lacteal', 'lacteous', 'ready to cry', 'rheumy'],
    'lacing': ['adulteration', 'anchor', 'arabesque', 'band', 'bandage', 'bar', 'barrette', 'basketry', 'basketwork', 'bastardizing', 'bastinado', 'basting'],
    'lack': ['absence', 'adulteration', 'arrearage', 'awayness', 'bare cupboard', 'bare subsistence', 'be found wanting', 'be in want', 'be insufficient', 'be pinched', 'be poor', 'beggarliness'],
    'lackadaisical': ['micawberish', 'apathetic', 'ataractic', 'backward', 'benumbed', 'blase', 'bored', 'careless', 'casual', 'cold', 'cool', 'dallying'],
    'lackey': ['adherent', 'apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bootlick', 'bootlicker', 'brown-nose', 'brownie', 'clawback', 'courtier', 'creature'],
    'lacking': ['absconded', 'absent', 'adulterated', 'arrested', 'away', 'bankrupt in', 'bare of', 'bereaved', 'bereaved of', 'bereft', 'bereft of', 'blemished'],
    'lackluster': ['absence of color', 'achromatic', 'achromaticity', 'achromatism', 'achromic', 'anemic', 'ashen', 'ashy', 'betwixt and between', 'bled white', 'blind', 'bloodless'],
    'lacklustre': ['blah', 'bland', 'boring', 'colorless', 'dense', 'dingy', 'dismal', 'drab', 'dreary', 'dull', 'flat', 'insipid'],
    'laconic': ['spartan', 'abbreviated', 'abridged', 'aposiopestic', 'brief', 'brusque', 'clipped', 'close', 'close-tongued', 'closemouthed', 'compact', 'compendious'],
    'lacquer': ['apply paint', 'bedaub', 'bedizen', 'begild', 'besmear', 'brush on paint', 'butter', 'calcimine', 'coat', 'coating', 'color', 'complexion'],
    'lacquered': ['buffed', 'burnished', 'finished', 'furbished', 'glace', 'glassy', 'glazed', 'gleaming', 'glossy', 'polished', 'rubbed', 'satiny'],
    'lactate': ['aliment', 'breast-feed', 'dry-nurse', 'excrete', 'fatten', 'fatten up', 'force-feed', 'foster', 'give out', 'nourish', 'nurse', 'nurture'],
    'lactation': ['chyle', 'chylifaction', 'chylification', 'colostrum', 'discharge', 'excretion', 'external secretion', 'flow', 'fluency', 'fluidity', 'fluidness', 'flux'],
    'lacteal': ['excretory', 'lachrymal', 'lachrymose', 'lacrimatory', 'lactational', 'lacteous', 'lactescent', 'lactic', 'lactiferous', 'milch', 'milk', 'milky'],
    'lacuna': ['alveolation', 'alveolus', 'antrum', 'aperture', 'armpit', 'arrearage', 'basin', 'bowl', 'breach', 'break', 'broaching', 'caesura'],
    'lacy': ['airy', 'attenuate', 'attenuated', 'barred', 'boyish', 'cancellated', 'crossbarred', 'delicate', 'diaphanous', 'diluted', 'ethereal', 'filigreed'],
    'lad': ['bastard', 'bird', 'boy', 'bub', 'bubba', 'buck', 'bud', 'buddy', 'bugger', 'cat', 'chap', 'character'],
    'lade': ['bag', 'bail', 'barrel', 'bear hard upon', 'bottle', 'box', 'brim', 'burden', 'burthen', 'can', 'charge', 'chock'],
    'laden': ['burdened', 'charged', 'cumbered', 'encumbered', 'fraught', 'freighted', 'full-charged', 'full-fraught', 'hampered', 'heavy-laden', 'loaded', 'oppressed'],
    'lading': ['allocation', 'assignment', 'baggage', 'bale', 'bellyful', 'bumper', 'burden', 'burdening', 'burthen', 'capacity', 'cargo', 'carload'],
    'ladino': ['cape colored', 'eurasian', 'cattalo', 'citrange', 'cross', 'crossbreed', 'griffe', 'half blood', 'half-bred', 'half-breed', 'half-caste', 'high yellow'],
    'ladle': ['bail', 'bucket', 'calabash', 'cup', 'decant', 'dip', 'dipper', 'dish', 'dish out', 'dish up', 'fork', 'gourd'],
    'lady': ['eminence', 'grace', 'her excellency', 'her highness', 'her ladyship', 'her majesty', 'highness', 'his lordship', 'his majesty', 'honor', 'imperial highness', 'imperial majesty'],
    'lady bountiful': ['maecenas', 'santa claus', 'almoner', 'almsgiver', 'angel', 'assignor', 'awarder', 'backer', 'bestower', 'cheerful giver', 'conferrer', 'consignor'],
    'lady killer': ['beau brummel', 'casanova', 'don juan', 'lothario', 'romeo', 'amoroso', 'beau', 'blade', 'blood', 'boulevardier', 'boyfriend', 'caballero'],
    'ladylike': ['aristocratic', 'chivalrous', 'correct', 'courteous', 'courtly', 'cultivated', 'cultured', 'decorous', 'dignified', 'distaff', 'ducal', 'elegant'],
    'lag': ['afterthought', 'antedate', 'arrest', 'be found wanting', 'bind', 'block', 'blockage', 'bureaucratic delay', 'cast out', 'check', 'closing', 'collapse'],
    'lag behind': ['back', 'back up', 'come after', 'come last', 'dawdle', 'drag', 'fall astern', 'fall back', 'fall behind', 'follow', 'get behind', 'go back'],
    'laggard': ['micawberish', 'apathetic', 'backward', 'balking', 'balky', 'bone-lazy', 'cadging', 'clock watcher', 'comatose', 'dallier', 'dallying', 'dawdle'],
    'lagging': ['micawberish', 'afterthought', 'backward', 'bind', 'block', 'blockage', 'bureaucratic delay', 'dalliance', 'dallying', 'dawdling', 'delay', 'delayage'],
    'lagniappe': ['trinkgeld', 'balance', 'bonus', 'bonus system', 'bounty', 'bribe', 'consideration', 'decoration', 'dividend', 'donative', 'double time', 'extra'],
    'lagoon': ['artificial lake', 'bayou lake', 'cistern', 'dam', 'dead water', 'dike', 'etang', 'farm pond', 'fishpond', 'freshwater lake', 'glacial lake', 'inland sea'],
    'laid low': ['ailing', 'ausgespielt', 'bad', 'below par', 'couchant', 'critically ill', 'crouched', 'debased', 'depressed', 'done', 'done up', 'down'],
    'laid up': ['accumulated', 'amassed', 'backlogged', 'bedfast', 'bedridden', 'collected', 'confined', 'down', 'garnered', 'gathered', 'hoarded', 'hospitalized'],
    'lair': ['abri', 'adytum', 'antre', 'ashram', 'asylum', 'bolt-hole', 'bordello', 'brothel', 'bunker', 'burrow', 'cache', 'cathouse'],
    'laird': ['brahman', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'beneficiary', 'blue blood', 'cestui', 'cestui que trust', 'cestui que use', 'count'],
    'laissez faire': ['a wise passiveness', 'autarky', 'bimetallism', 'capitalism', 'capitalistic system', 'contemplation', 'contemplative', 'contemplative life', 'culpa', 'culpable negligence', 'culpably negligent', 'default'],
    'lallygag': ['bill and coo', 'bum', 'copulate', 'dally', 'dawdle', 'delay', 'diddle', 'dillydally', 'doodle', 'drag', 'falter', 'flag'],
    'lam': ['absquatulate', 'batter', 'beat', 'beat it', 'blow', 'breakout', 'decamp', 'dog it', 'drub', 'duck and run', 'duck out', 'flight'],
    'lamb': ['agneau', 'angel', 'babe', 'baby', 'baby-doll', 'bairn', 'bellwether', 'birdling', 'breast of lamb', 'buttercup', 'calf', 'catling'],
    'lambaste': ['admonish', 'attack', 'bang', 'baste', 'batter', 'bawl out', 'beat', 'beat all hollow', 'beat hollow', 'belabor', 'berate', 'best'],
    'lambent': ['aflicker', 'barely touching', 'beaming', 'bickering', 'blinking', 'brilliant', 'dancing', 'effulgent', 'flashing', 'flickering', 'flickery', 'flicky'],
    'lame': ['abortive', 'awkward', 'bad', 'bootless', 'bugger', 'burden', 'castrate', 'castrated', 'clumsy', 'cramp', 'cripple', 'crippled'],
    'lame duck': ['adventurer', 'also-ran', 'aspirant', 'baby kisser', 'bankrupt', 'big operator', 'candidate', 'dark horse', 'defeated candidate', 'dud', 'failure', 'favorite son'],
    'lamebrain': ['boeotian', 'block', 'clod', 'dimwit', 'dolt', 'donkey', 'dope', 'dullard', 'dumb cluck', 'dumbbell', 'dummy', 'dunce'],
    'lamebrained': ['boeotian', 'asinine', 'beef-brained', 'beef-witted', 'blockish', 'bovine', 'chumpish', 'cloddish', 'cowish', 'crass', 'dense', 'doltish'],
    'lamellate': ['filmy', 'foliaceous', 'foliated', 'in layers', 'lamellar', 'lamellated', 'lamelliform', 'laminate', 'laminated', 'laminous', 'leaflike', 'leafy'],
    'lament': ['bawl', 'bemoan', 'bewail', 'coronach', 'cry', 'deplore', 'dirge', 'discomfort', 'dismay', 'distress', 'dolorous tirade', 'elegize'],
    'lamentable': ['abominable', 'affecting', 'afflictive', 'aggrieved', 'anguished', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beneath contempt', 'bitter'],
    'lamentation': ['agony', 'anguish', 'bitterness', 'bleakness', 'care', 'carking care', 'cheerlessness', 'comfortlessness', 'crying', 'depression', 'discomfort', 'dismalness'],
    'laminate': ['adhesive', 'arrange in layers', 'cast plastic', 'cellulose plastic', 'delaminate', 'desquamate', 'exfoliate', 'extruded plastic', 'flake', 'lay down', 'lay up', 'layer'],
    'laminated': ['filmy', 'foliaceous', 'foliated', 'in layers', 'lamellar', 'lamellate', 'lamellated', 'lamelliform', 'laminate', 'laminous', 'leaflike', 'leafy'],
    'lamp': ['chinese lantern', 'finsen light', 'moore light', 'arc light', 'battery lamp', 'broadside', 'candle', 'candlelight', 'cresset', 'dark lantern', 'electric candle', 'electric lamp'],
    'lampoon': ['atticism', 'agile wit', 'black humor', 'burlesque', 'caricature', 'comedy', 'dry wit', 'esprit', 'farce', 'hatchet job', 'hit off on', 'humor'],
    'lampooner': ['banana', 'burlesquer', 'caricaturist', 'clown', 'comedian', 'comic', 'cutup', 'epigrammatist', 'funnyman', 'gag writer', 'gagman', 'gagster'],
    'lance': ['amputate', 'assegai', 'auger', 'ax', 'bayonet', 'bisect', 'bite', 'bore', 'bowl', 'broach', 'butcher', 'carve'],
    'lancelot': ['bayard', 'don quixote', 'gawain', 'ritter', 'sidney', 'sir galahad', 'bachelor', 'banneret', 'baronet', 'caballero', 'cavalier', 'chevalier'],
    'lancinate': ['agonize', 'bloody', 'claw', 'convulse', 'crucify', 'excruciate', 'harrow', 'impale', 'kill by inches', 'lacerate', 'macerate', 'martyr'],
    'land': ['acquire', 'acreage', 'acres', 'airspace', 'alight', 'ally', 'archduchy', 'archdukedom', 'area', 'arrive', 'bag', 'belt'],
    'land on': ['ambush', 'assail', 'assault', 'attack', 'blitz', 'bushwhack', 'come at', 'come down on', 'crack down on', 'descend on', 'descend upon', 'fall on'],
    'landed': ['blessed with', 'enfeoffed', 'having', 'having and holding', 'holding', 'in possession of', 'landholding', 'landowning', 'master of', 'occupying', 'owning', 'possessed of'],
    'landholding': ['acres', 'alluvion', 'alluvium', 'arable land', 'blessed with', 'clay', 'clod', 'crust', 'dirt', 'dominion', 'dominium', 'dry land'],
    'landing': ['aerodrome', 'air base', 'airdrome', 'airfield', 'airport', 'anchorage', 'anchorage ground', 'approach', 'arrival', 'back stairs', 'balcony', 'basin'],
    'landlady': ['beneficiary', 'cestui', 'cestui que trust', 'cestui que use', 'deedholder', 'feoffee', 'feudatory', 'hostess', 'householder', 'laird', 'landlord', 'lord'],
    'landloper': ['arab', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'dogie', 'gamin', 'gamine', 'guttersnipe', 'hobo'],
    'landloping': ['circumforaneous', 'discursive', 'divagatory', 'drifting', 'errant', 'flitting', 'floating', 'footloose', 'footloose and fancy-free', 'fugitive', 'gadding', 'gypsy-like'],
    'landlord': ['beneficiary', 'cestui', 'cestui que trust', 'cestui que use', 'deedholder', 'feoffee', 'feudatory', 'freeholder', 'host', 'hostess', 'householder', 'innkeeper'],
    'landmark': ['bench mark', 'bookmark', 'cairn', 'cardinal point', 'catstone', 'chief thing', 'climax', 'core', 'cornerstone', 'crisis', 'critical', 'critical point'],
    'landmass': ['africa', 'america', 'antarctica', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'australia', 'east', 'eastern hemisphere', 'eurasia'],
    'landscape': ['airscape', 'aspect', 'cityscape', 'cloudscape', 'countryside', 'diorama', 'exterior', 'farmscape', 'interior', 'lookout', 'outlook', 'panorama'],
    'landslide': ['cadmean victory', 'ko', 'pyrrhic victory', 'abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'ascendancy', 'avalanche', 'bonanza', 'bountifulness'],
    'lane': ['autobahn', 'us highway', 'access', 'air lane', 'air line', 'air route', 'airway', 'aisle', 'alley', 'alleyway', 'ambulatory', 'aperture'],
    'lang syne': ['auld lang syne', 'days beyond recall', 'days of old', 'days of yore', 'early times', 'eld', 'foretime', 'good old times', 'long ago', 'old days', 'old story', 'old times'],
    'language': ['abnaki', 'afghan', 'afghani', 'afrikaans', 'afro-asiatic', 'ainu', 'akan', 'akkadian', 'albanian', 'aleut', 'algonquian', 'algonquin'],
    'languid': ['laodicean', 'olympian', 'abeyant', 'aloof', 'ambling', 'anemic', 'anesthetized', 'apathetic', 'asthenic', 'benumbed', 'blah', 'blase'],
    'languish': ['abate', 'ablate', 'bate', 'be eaten away', 'become suicidal', 'break', 'cave in', 'collapse', 'come apart', 'come unstuck', 'conk out', 'consume'],
    'languishing': ['heimweh', 'aching', 'adoring', 'affectionate', 'bowed-down', 'cachectic', 'cachexia', 'cachexy', 'cast down', 'chronic ill health', 'coming apart', 'conjugal'],
    'languor': ['abeyance', 'acedia', 'adynamia', 'anemia', 'apathy', 'atony', 'blah feeling', 'bloodlessness', 'blues', 'boredom', 'brain fag', 'cachexia'],
    'languorous': ['abeyant', 'ambling', 'anemic', 'apathetic', 'asthenic', 'benumbed', 'blase', 'bloodless', 'bored', 'cataleptic', 'catatonic', 'cautious'],
    'lanky': ['angular', 'bony', 'colossal', 'flat', 'flat-chested', 'fleshless', 'gangling', 'gangly', 'gaunt', 'gawky', 'giant', 'gigantic'],
    'lanolin': ['balm', 'balsam', 'brilliantine', 'chrism', 'cold cream', 'collyrium', 'cream', 'demulcent', 'embrocation', 'emollient', 'eye-lotion', 'eyewash'],
    'lantern': ['antenna tower', 'barbican', 'bay', 'bay window', 'belfry', 'bell tower', 'bow window', 'campanile', 'candle', 'casement', 'casement window', 'ceiling'],
    'lantern jaws': ['boniness', 'fleshlessness', 'frailness', 'gauntness', 'gawkiness', 'haggardness', 'hatchet face', 'lankiness', 'lankness', 'leanness', 'meagerness', 'paperiness'],
    'lap': ['le mans', 'adjoin', 'air race', 'ambit', 'anteriority', 'apparel', 'applique', 'arch over', 'array', 'attire', 'automobile race', 'babble'],
    'lap of luxury': ['easy street', 'affluence', 'bed of roses', 'clover', 'comfort', 'ease', 'easy circumstances', 'felicity', 'fleshpots', 'gracious life', 'gracious living', 'happiness'],
    'lap up': ['and sinker', 'be a sucker', 'be taken in', 'bib', 'bite', 'devour', 'drain the cup', 'dram', 'drink', 'drink bottoms-up', 'drink deep', 'drink hard'],
    'lapidary': ['aquatint', 'aquatinta', 'autolithographic', 'burinist', 'carver', 'cerographer', 'chalcographer', 'engraver', 'etcher', 'gem engraver', 'glyptic', 'glyptographic'],
    'lappet': ['crease', 'creasing', 'crimp', 'dog-ear', 'double', 'doubling', 'drape', 'duplicature', 'ear lobe', 'flection', 'flexure', 'flounce'],
    'lapping': ['babbling', 'bridging', 'bubbling', 'burbling', 'compotation', 'drinking', 'drunkenness', 'guggling', 'gulping', 'gurgling', 'guzzling', 'imbibing'],
    'lapse': ['abeyance', 'about-face', 'advance', 'alchemy', 'apostasy', 'apostatize', 'assimilation', 'assumption', 'atavism', 'atheism', 'atrocity', 'backing'],
    'lapsed': ['adamic', 'circean', 'ago', 'animal', 'animalistic', 'antiquated', 'antique', 'apostate', 'atheistic', 'backsliding', 'beastlike', 'beastly'],
    'lard': ['haliver oil', 'acculturate', 'adipose tissue', 'advance', 'ameliorate', 'amend', 'animal oils', 'anoint', 'bacon', 'beef tallow', 'beeswax', 'better'],
    'larder': ['abundance', 'accumulation', 'amassment', 'backlog', 'budget', 'buttery', 'canned foods', 'collection', 'commissariat', 'commissary', 'cornucopia', 'cumulation'],
    'lares and penates': ['hestia', 'vesta', 'ancestral spirits', 'angel', 'attendant godling', 'belongings', 'chattels', 'control', 'daemon', 'demon', 'effects', 'fairy godmother'],
    'large': ['brobdingnagian', 'gargantuan', 'adipose', 'altogether', 'ample', 'amplitudinous', 'as a whole', 'astronomical', 'at large', 'at liberty', 'awesome', 'beamy'],
    'large scale': ['big', 'broad', 'bumper', 'considerable', 'diffuse', 'extensive', 'far-embracing', 'far-extending', 'far-flung', 'far-flying', 'far-going', 'far-ranging'],
    'largehearted': ['almsgiving', 'altruistic', 'beneficent', 'benevolent', 'big', 'bighearted', 'bounteous', 'bountiful', 'charitable', 'chivalrous', 'eleemosynary', 'elevated'],
    'largely': ['a deal', 'a great deal', 'a lot', 'abundantly', 'altogether', 'as a rule', 'as all creation', 'as all get-out', 'at bottom', 'basically', 'beaucoup', 'by and large'],
    'largeness': ['ampleness', 'amplitude', 'area', 'bigheartedness', 'bigness', 'body', 'boundlessness', 'bounteousness', 'bountifulness', 'bounty', 'breadth', 'broadness'],
    'largess': ['trinkgeld', 'benevolence', 'bigheartedness', 'bonus', 'boon', 'bounteousness', 'bountifulness', 'bounty', 'bribe', 'compliment', 'consideration', 'donative'],
    'largesse': ['aid', 'alms', 'bonuses', 'bounty', 'charity', 'donations', 'endowments', 'generosity', 'gifts', 'grants', 'largess', 'liberality'],
    'largo': ['a poco', 'adagietto', 'adagio', 'allargando', 'allegretto', 'allegro', 'andante', 'andante tempo', 'andantino', 'beat', 'calando', 'compound time'],
    'lariat': ['bait', 'birdlime', 'bola', 'cobweb', 'dragnet', 'fishhook', 'fly', 'gill net', 'ground bait', 'hook', 'jig', 'lasso'],
    'lark': ['philomel', 'adventure', 'antic', 'bat', 'bender', 'binge', 'bout', 'bulbul', 'bust', 'canary', 'caper', 'carousal'],
    'larrup': ['bang', 'baste', 'batter', 'beat', 'buffet', 'clobber', 'dress down', 'drub', 'dust', 'flagellate', 'flail', 'flap'],
    'larva': ['anlage', 'masan', 'apparition', 'appearance', 'arachnid', 'arthropod', 'astral', 'astral spirit', 'aurelia', 'banshee', 'beetle', 'blastula'],
    'laryngitis': ['asiatic flu', 'hong kong flu', 'acute bronchitis', 'adenoiditis', 'adrenitis', 'aluminosis', 'amygdalitis', 'anthracosilicosis', 'anthracosis', 'appendicitis', 'arteritis', 'arthritis deformans'],
    'larynx': ['alveolar ridge', 'alveolus', 'apex', 'arytenoid cartilages', 'back', 'blade', 'dorsum', 'hard palate', 'lips', 'nasal cavity', 'oral cavity', 'palate'],
    'lascivious': ['cyprian', 'fescennine', 'amative', 'amatory', 'amorous', 'animal', 'aphrodisiomaniacal', 'appetitive', 'ardent', 'bawdy', 'blue', 'carnal'],
    'lash': ['anchor', 'assail', 'attack', 'band', 'bandage', 'baste', 'bastinado', 'bawl out', 'beat', 'belabor', 'belt', 'bend'],
    'lashing': ['adhesive', 'affixation', 'annexation', 'attachment', 'bastinado', 'basting', 'battery', 'beating', 'belting', 'binding', 'bond', 'buffeting'],
    'lass': ['dulcinea', 'eve', 'frau', 'babe', 'baby', 'best girl', 'broad', 'chick', 'colleen', 'cutie', 'dame', 'damoiselle'],
    'lassitude': ['acedia', 'adynamia', 'anemia', 'apathy', 'atony', 'blah feeling', 'bloodlessness', 'blues', 'boredom', 'brain fag', 'cachexia', 'cachexy'],
    'lasso': ['annular muscle', 'annulus', 'areola', 'aureole', 'bag', 'bait', 'birdlime', 'bola', 'catch', 'chaplet', 'circle', 'circuit'],
    'last': ['abide', 'advance', 'aforegoing', 'after', 'aftermost', 'apodosis', 'at last', 'at length', 'at long last', 'at the end', 'at the last', 'be spared'],
    'last minute': ['belatedness', 'cursory', 'deathbed', 'eleventh hour', 'eleventh-hour', 'expeditious', 'festinate', 'feverish', 'flying', 'furious', 'hasty', 'high time'],
    'last resort': ['action', 'ad hoc measure', 'answer', 'artifice', 'contrivance', 'countermove', 'coup', 'course of action', 'demarche', 'dernier ressort', 'device', 'dodge'],
    'last rites': ['burial service', 'chrism', 'chrismal', 'chrismation', 'chrismatory', 'chrisom', 'deathwatch', 'dirge', 'eulogy', 'exequies', 'extreme unction', 'funeral oration'],
    'last straw': ['causa causans', 'causa finalis', 'causal sequence', 'causing cause', 'efficient cause', 'final cause', 'first cause', 'formal cause', 'immanent cause', 'immediate cause', 'occasional cause', 'provocation'],
    'last supper': ['communion', 'eucharist', 'holy communion', 'host', 'sacrament sunday', 'altar bread', 'bread', 'bread and wine', 'consecrated bread', 'consecrated elements', 'consubstantiation', 'elements'],
    'last word': ['ps', 'parthian shot', 'acme', 'acme of perfection', 'addendum', 'advance guard', 'afterthought', 'apodosis', 'appendix', 'avant-garde', 'back matter', 'catastrophe'],
    'lasting': ['abiding', 'adamantine', 'age-long', 'aged', 'alive', 'ancient', 'antique', 'assiduous', 'bulky', 'cartilaginous', 'changeless', 'chewy'],
    'latch': ['articulate', 'bang', 'bar', 'barricade', 'batten', 'batten down', 'bolt', 'buckle', 'butt', 'button', 'button up', 'choke'],
    'late': ['after time', 'ahead of time', 'anachronistic', 'ancient', 'antedated', 'arrested', 'asleep', 'asleep in jesus', 'at rest', 'back', 'backward', 'beforehand'],
    'late lamented': ['ashes', 'asleep', 'asleep in jesus', 'at rest', 'bereft of life', 'body', 'bones', 'breathless', 'cadaver', 'called home', 'carcass', 'carrion'],
    'latency': ['abeyance', 'apathy', 'catalepsy', 'catatonia', 'cold storage', 'deadliness', 'deathliness', 'delitescence', 'doldrums', 'dormancy', 'entropy', 'indifference'],
    'lateness': ['afterlife', 'anachronism', 'antedating', 'anticipation', 'brand-newness', 'callowness', 'dewiness', 'earliness', 'following', 'freshness', 'future time', 'gloss of novelty'],
    'latent': ['abeyant', 'abstruse', 'apathetic', 'arcane', 'beclouded', 'behind the curtain', 'behind the scenes', 'between the lines', 'blind', 'buried', 'cabalistic', 'camouflaged'],
    'later': ['after', 'after a time', 'after a while', 'after all', 'after that', 'afterward', 'afterwards', 'anon', 'approaching', 'attendant', 'before long', 'behind'],
    'lateral': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation', 'back'],
    'latest': ['actual', 'as is', 'being', 'closing', 'concluding', 'contemporaneous', 'contemporary', 'current', 'eventual', 'existent', 'existing', 'extant'],
    'lath': ['mystik tape', 'scotch tape', 'adhesive tape', 'band', 'bandage', 'batten', 'beam', 'belt', 'billet', 'board', 'boarding', 'brick'],
    'lathe': ['t square', 'alembic', 'anvil', 'awl', 'bale breaker', 'bar', 'battering ram', 'bevel', 'bevel square', 'bodkin', 'bradawl', 'buffer'],
    'lather': ['bo', 'aerate', 'anxiety', 'baptize', 'bath', 'bathe', 'beaded brow', 'beads of sweat', 'beat', 'beat all hollow', 'beat hollow', 'belabor'],
    'latitude': ['antarctic zone', 'arctic circle', 'arctic zone', 'cartesian coordinates', 'frigid zones', 'lambert conformal projection', 'mercator projection', 'miller projection', 'torrid zone', 'tropic of cancer', 'tropic of capricorn', 'variable zones'],
    'latitudinarian': ['big person', 'broad-gauge person', 'broad-minded', 'ecumenicist', 'esprit fort', 'free lance', 'free spirit', 'free trader', 'freethinker', 'freethinking', 'humanist', 'independent'],
    'latrine': ['wc', 'backhouse', 'basement', 'bathroom', 'bedpan', 'can', 'chamber', 'chamber pot', 'chemical closet', 'chemical toilet', 'closet', 'comfort station'],
    'lattice': ['kekule formula', 'arabesque', 'atomic cluster', 'atomic pile', 'basketry', 'basketwork', 'bay', 'bay window', 'benzene ring', 'bow window', 'branched chain', 'breeder reactor'],
    'laud': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'nunc dimittis', 'te deum', 'trisagion', 'vedic hymn'],
    'laudable': ['admirable', 'advantageous', 'auspicious', 'beneficial', 'benevolent', 'beyond all praise', 'bon', 'bonny', 'braw', 'bueno', 'capital', 'cogent'],
    'laudanum': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'lauded': ['august', 'distinguished', 'elevated', 'eminent', 'exalted', 'famous', 'glorious', 'godlike', 'heroic', 'high', 'lofty', 'magnanimous'],
    'laugh': ['homeric laughter', 'be in heaven', 'be in stitches', 'be pleased', 'beam', 'belittle', 'belly laugh', 'blue story', 'boff', 'boffola', 'break up', 'brush aside'],
    'laugh at': ['deride', 'despise', 'disdain', 'disregard', 'flout', 'grin at', 'hold in derision', 'laugh to scorn', 'make fun of', 'make game of', 'make merry with', 'pan'],
    'laugh it up': ['be in stitches', 'beguile the time', 'break up', 'burst into laughter', 'burst out', 'burst out laughing', 'burst with laughter', 'bust a gut', 'cachinnate', 'cackle', 'chortle', 'chuckle'],
    'laughable': ['absurd', 'amusing', 'beyond belief', 'bizarre', 'cockamamie', 'crazy', 'droll', 'eccentric', 'extravagant', 'fantastic', 'foolish', 'funny'],
    'laughing': ['homeric laughter', 'beaming', 'beatific', 'beatified', 'belly laugh', 'blessed', 'blissful', 'blithe', 'blithesome', 'boff', 'boffola', 'bright'],
    'laughingstock': ['butt', 'byword', 'byword of reproach', 'derision', 'dupe', 'fair game', 'figure of fun', 'fool', 'game', 'gazingstock', 'goat', 'jest'],
    'laughter': ['homeric laughter', 'amusement', 'belly laugh', 'boff', 'boffola', 'burst of laughter', 'cachinnation', 'cackle', 'chortle', 'chortling', 'chuckle', 'convulsion'],
    'launch': ['advance', 'altitude peak', 'automatic control', 'begin', 'blast off', 'blast-off', 'boat', 'bowl', 'bring before', 'bring forward', 'bring up', 'broach'],
    'launch into': ['accept', 'assume', 'attack', 'attempt', 'buckle to', 'dive into', 'embark in', 'embark upon', 'endeavor', 'engage in', 'enter on', 'enter upon'],
    'launching': ['coming out', 'curtain raiser', 'debut', 'embarkation', 'embarkment', 'first appearance', 'floating', 'flotation', 'inaugural address', 'inauguration', 'induction', 'initiation'],
    'launching pad': ['mark', 'balcony', 'bazooka', 'calliope', 'catafalque', 'dais', 'emplacement', 'estrade', 'floor', 'gallery', 'hedgehog', 'heliport'],
    'launder': ['baptize', 'bath', 'bathe', 'clean', 'cleanse', 'douche', 'flush', 'flush out', 'gargle', 'holystone', 'irrigate', 'lather'],
    'laureate': ['a per se', 'meistersinger', 'olympic medal winner', 'parnassian', 'ace', 'arch-poet', 'award winner', 'ballad maker', 'balladmonger', 'bard', 'beat poet', 'boss'],
    'laurels': ['old mug', 'acclaim', 'acclamation', 'accolade', 'accomplishments', 'award', 'awards', 'badge', 'bays', 'celebrity', 'chaplet', 'civic crown'],
    'lava': ['aa', 'abyssal rock', 'ash', 'ashes', 'basalt', 'bedrock', 'block lava', 'brand', 'brash', 'breccia', 'calx', 'carbon'],
    'lavatory': ['wc', 'aquamanile', 'automatic dishwasher', 'backhouse', 'bagnio', 'balneae', 'balneum', 'basement', 'basin', 'bath', 'bathhouse', 'bathroom'],
    'lave': ['baptize', 'bath', 'bathe', 'brew', 'douche', 'drench', 'drouk', 'flush', 'flush out', 'gargle', 'holystone', 'imbrue'],
    'lavender': ['amethystine', 'lilac', 'livid', 'magenta', 'mauve', 'mulberry', 'orchid', 'pansy-purple', 'plum-colored', 'plum-purple', 'purple', 'purplescent'],
    'lavish': ['abounding', 'abundant', 'accord', 'administer', 'affluent', 'afford', 'alive with', 'all-sufficing', 'allot', 'allow', 'ample', 'aplenty'],
    'lavishly': ['abundantly', 'affluently', 'aplenty', 'beyond measure', 'bigheartedly', 'bottomlessly', 'bounteously', 'bountifully', 'copiously', 'diffusely', 'effusely', 'extravagantly'],
    'lavishness': ['babylonian splendor', 'abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bonanza', 'bountifulness', 'bountiousness', 'brilliance', 'bumper crop'],
    'law': ['dogberry', 'eighteenth amendment', 'john law', 'procrustean law', 'prohibition party', 'volstead act', 'a priori truth', 'act', 'appointment', 'assize', 'axiom', 'ban'],
    'law abiding': ['christian', 'acquiescent', 'blameless', 'clean', 'compliant', 'complying', 'conforming', 'creditable', 'decent', 'devoted', 'duteous', 'dutiful'],
    'law enforcement agency': ['cheka', 'fbi', 'gestapo', 'interpol', 'mp', 'mvd', 'mounties', 'nkvd', 'ogpu', 'rcmp', 'sp', 'scotland yard'],
    'law of averages': ['accidentality', 'actuarial calculation', 'adventitiousness', 'break', 'casualness', 'chance', 'destiny', 'fate', 'flukiness', 'fortuitousness', 'fortuity', 'fortune'],
    'lawbreaker': ['judas', 'bad person', 'betrayer', 'convict', 'criminal', 'crook', 'deceiver', 'delinquent', 'desperado', 'desperate criminal', 'double-dealer', 'evildoer'],
    'lawbreaking': ['breach of law', 'civil disobedience', 'contravention', 'crime', 'criminal tendency', 'criminality', 'criminosis', 'disobedience', 'evil courses', 'evildoing', 'feloniousness', 'frowardness'],
    'lawful': ['actionable', 'admissible', 'allowable', 'allowed', 'applicable', 'authentic', 'authoritative', 'authorized', 'balanced', 'binding', 'bona fide', 'candid'],
    'lawfulness': ['actionability', 'admissibility', 'admissibleness', 'allowableness', 'applicability', 'constitutional validity', 'constitutionalism', 'constitutionality', 'defensibility', 'drumhead justice', 'due process', 'dueness'],
    'lawgiver': ['mp', 'member of congress', 'member of parliament', 'alderman', 'assemblyman', 'chosen freeholder', 'city father', 'congressman', 'congresswoman', 'councilman', 'floor leader', 'lawmaker'],
    'lawless': ['actionable', 'against the law', 'anarchic', 'anarchical', 'anarchistic', 'anomic', 'black-market', 'bootleg', 'chaotic', 'chargeable', 'contraband', 'contrary to law'],
    'lawlessness': ['anarchy', 'anomie', 'assumption', 'chaos', 'civil disobedience', 'conflict', 'contention', 'criminalism', 'criminality', 'difference', 'discord', 'disobedience'],
    'lawmaker': ['mp', 'member of congress', 'member of parliament', 'alderman', 'assemblyman', 'chosen freeholder', 'city father', 'congressman', 'congresswoman', 'councilman', 'floor leader', 'lawgiver'],
    'lawmaking': ['act', 'bicameral', 'concurrent resolution', 'congressional', 'constitution', 'deliberative', 'enaction', 'enactment', 'joint resolution', 'legislation', 'legislative', 'legislatorial'],
    'lawn': ['astroturf', 'artificial turf', 'bowling green', 'common', 'fairway', 'golf course', 'golf links', 'grassplot', 'green', 'greensward', 'greenyard', 'grounds'],
    'lawsuit': ['accusal', 'accusation', 'accusing', 'action', 'allegation', 'allegement', 'arraignment', 'bill of particulars', 'blame', 'bringing of charges', 'bringing to book', 'case'],
    'lax': ['micawberish', 'paphian', 'abandoned', 'accented', 'accepting', 'admissive', 'aleatoric', 'aleatory', 'allowing', 'alveolar', 'amorphous', 'apical'],
    'laxative': ['agar', 'aloes', 'aperient', 'bran', 'calomel', 'carminative', 'cascara', 'castor oil', 'cathartic', 'colocynth', 'diuretic', 'magnesia'],
    'laxity': ['allowance', 'amorphousness', 'approximation', 'bagginess', 'blobbiness', 'blurriness', 'broadness', 'carelessness', 'chambering', 'culpa', 'culpable negligence', 'default'],
    'laxness': ['fabian policy', 'micawberism', 'abandon', 'abandonment', 'acceptance', 'backwardness', 'bagginess', 'clemency', 'clementness', 'compassion', 'culpa', 'culpable negligence'],
    'lay': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'abate', 'accredit', 'address', 'advance', 'aim', 'air', 'alba'],
    'lay aside': ['abandon', 'adjourn', 'bolt', 'brush aside', 'brush off', 'carry away', 'carry off', 'cart away', 'cast', 'chuck', 'continue', 'cordon'],
    'lay away': ['bank', 'bundle away', 'cache', 'coffer', 'delay', 'deposit', 'entomb', 'file', 'hutch', 'inhume', 'inter', 'lay aside'],
    'lay before': ['advance', 'affront', 'brave', 'breast', 'bring before', 'bring forward', 'bring up', 'broach', 'challenge', 'commend to attention', 'confront', 'confront with'],
    'lay by': ['abandon', 'adjourn', 'aestivate', 'arrange for', 'assign', 'cede', 'conserve', 'continue', 'decree', 'defer', 'define', 'delay'],
    'lay down': ['abdicate', 'abjure', 'acknowledge defeat', 'advance', 'affirm', 'align', 'allege', 'announce', 'annunciate', 'ante', 'ante up', 'appoint'],
    'lay figure': ['charlie mccarthy', 'air brush', 'art paper', 'brush', 'bust', 'camera lucida', 'camera obscura', 'canvas', 'carving', 'chalk', 'charcoal', 'cipher'],
    'lay hands on': ['abduct', 'administer the eucharist', 'ambush', 'annex', 'anoint', 'assail', 'assault', 'attack', 'bless', 'blitz', 'bushwhack', 'carry off'],
    'lay in': ['approach anchorage', 'bank', 'bear down on', 'bear down upon', 'bear up for', 'bear up to', 'bundle away', 'cache', 'close with', 'coffer', 'deposit', 'fetch'],
    'lay into': ['ambush', 'assail', 'assault', 'attack', 'blitz', 'bushwhack', 'come at', 'come down on', 'crack down on', 'descend on', 'descend upon', 'draw first blood'],
    'lay low': ['abate', 'align', 'attenuate', 'blow down', 'blow over', 'blow to pieces', 'blow up', 'blunt', 'bowl down', 'bowl over', 'brain', 'bring down'],
    'lay off': ['abandon', 'abort', 'aestivate', 'belay', 'blueprint', 'boot', 'bounce', 'bound', 'break', 'breathe', 'bump', 'bust'],
    'lay on': ['administer', 'apply', 'apply to', 'attack', 'baste', 'bastinado', 'beat', 'bedaub', 'belabor', 'belt', 'besmear', 'bestow'],
    'lay out': ['ko', 'align', 'anesthetize', 'arrange', 'array', 'bedaze', 'benumb', 'besot', 'blast', 'block out', 'blot out', 'blow down'],
    'lay over': ['adjourn', 'apply to', 'blanket', 'block', 'canopy', 'cloak', 'clothe', 'cloud', 'continue', 'cope', 'cover', 'cover up'],
    'lay the foundation': ['base', 'blaze the trail', 'break the ice', 'build', 'build in', 'clear the way', 'cultivate the soil', 'establish', 'fix', 'found', 'go in advance', 'ground'],
    'lay to': ['account for', 'accredit with', 'accrete to', 'acknowledge', 'aestivate', 'apply to', 'ascribe to', 'assign to', 'attach to', 'attribute to', 'blame', 'blame for'],
    'lay waste': ['assault', 'attack', 'barbarize', 'batter', 'bring to ruin', 'brutalize', 'burn', 'butcher', 'carry on', 'condemn', 'confound', 'consume'],
    'layer': ['appleton layer', 'f layer', 'heaviside-kennelly layer', 'van allen belt', 'arrange in layers', 'belt', 'bookie', 'chemosphere', 'delaminate', 'desquamate', 'exfoliate', 'flake'],
    'layered': ['filmy', 'foliaceous', 'foliated', 'in layers', 'lamellar', 'lamellate', 'lamellated', 'lamelliform', 'laminate', 'laminated', 'laminous', 'leaflike'],
    'layoff': ['abeyance', 'break', 'caesura', 'cashiering', 'cease-fire', 'conge', 'cyclical unemployment', 'day off', 'deposal', 'discharge', 'disemployment', 'dismissal'],
    'layout': ['intertype', 'linotype', 'monotype', 'platonic form', 'platonic idea', 'aesthetic form', 'approach', 'archetype', 'arrangement', 'array', 'art form', 'attack'],
    'laze': ['amble', 'bum', 'bum around', 'claudicate', 'crawl', 'creep', 'do nothing', 'dogtrot', 'drag', 'drag along', 'drag out', 'go dead slow'],
    'laziness': ['abandon', 'careless abandon', 'carelessness', 'casualness', 'cautiousness', 'circumspection', 'creeping', 'cursoriness', 'deliberateness', 'deliberation', 'dilatoriness', 'disregardfulness'],
    'lazy': ['micawberish', 'airy', 'ambling', 'backward', 'bone-lazy', 'bum', 'bum around', 'cadging', 'careless', 'casual', 'cautious', 'circumspect'],
    'lea': ['campo', 'grass', 'grass veld', 'grassland', 'grazing', 'haugh', 'haughland', 'llano', 'mead', 'meadow', 'meadow land', 'pampa'],
    'leach': ['abate', 'abrade', 'abstract', 'bate', 'bathe', 'bleed', 'bolt', 'brew', 'chemical solution', 'clarify', 'clear', 'colliquate'],
    'leached': ['acarpous', 'arid', 'barren', 'celibate', 'childless', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'exhausted', 'fallow'],
    'lead': ['t square', 'accent', 'accent mark', 'accomplishment', 'actor', 'administer', 'administrate', 'advance', 'advantage', 'affect', 'aim', 'aluminum'],
    'lead item': ['article', 'article of commerce', 'article of merchandise', 'commodity', 'drug', 'feature', 'item', 'leader', 'leading card', 'loss leader', 'main feature', 'product'],
    'lead off': ['antecede', 'break ground', 'break the ice', 'come before', 'come first', 'commence', 'create', 'embark', 'enter', 'front', 'go ahead of', 'go before'],
    'lead on': ['act on', 'allure', 'approach', 'bait', 'bait the hook', 'be responsible for', 'bear upon', 'blandish', 'cajole', 'call the signals', 'captain', 'carry on'],
    'lead the way': ['be the bellwether', 'beacon', 'break ground', 'break the ice', 'create', 'epitomize', 'exemplify', 'fit the pattern', 'get ahead of', 'get before', 'go before', 'guide'],
    'lead to': ['advance', 'affect', 'assume', 'bring', 'call for', 'carry to', 'come to', 'comprise', 'conduce to', 'conduct to', 'contain', 'contribute to'],
    'leaden': ['latinate', 'quaker-colored', 'abeyant', 'achromatic', 'achromic', 'acier', 'anemic', 'apathetic', 'arid', 'ashen', 'ashy', 'aureate'],
    'leader': ['a per se', 'ag', 'da', 'kc', 'kapellmeister', 'mahdi', 'qc', 'ssc', 'us attorney', 'ace', 'analysis', 'ancestor'],
    'leadership': ['acme', 'administration', 'aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'ascendancy', 'authority', 'authorization', 'be-all and end-all', 'bishopric'],
    'leading': ['absolute', 'all-absorbing', 'antecedent', 'anterior', 'arch', 'ascendant', 'at the head', 'authoritarian', 'authoritative', 'authority', 'authorized', 'autocratic'],
    'leading lady': ['actor', 'antagonist', 'antihero', 'bit', 'bit part', 'cast', 'character', 'cue', 'danseur noble', 'diva', 'fat part', 'feature attraction'],
    'leading light': ['chief', 'electronics king', 'first-rater', 'genius', 'honcho', 'king', 'lead', 'luminary', 'master spirit', 'paramount', 'prima donna', 'principal'],
    'leaf': ['burley', 'cuban', 'havana', 'havana seed', 'latakia', 'maryland', 'russian', 'turkish', 'virginia', 'acknowledgments', 'back', 'back matter'],
    'leaflet': ['advert', 'advertisement', 'bill', 'blade', 'booklet', 'bract', 'bracteole', 'bractlet', 'brochure', 'chapbook', 'circular', 'comic book'],
    'leafy': ['aestival', 'arborescent', 'beryl-green', 'berylline', 'blue-green', 'bluish-green', 'bosky', 'bowery', 'branched', 'branching', 'branchy', 'chartreuse'],
    'league': ['anschluss', 'bund', 'nato', 'rochdale cooperative', 'seato', 'accouple', 'accumulate', 'act in concert', 'act together', 'addition', 'affiliate', 'affiliate with'],
    'leagued': ['accumulated', 'affiliate', 'affiliated', 'agglomerate', 'aggregate', 'allied', 'amassed', 'assembled', 'associate', 'associated', 'banded together', 'bound'],
    'leak': ['abysm', 'abyss', 'aperture', 'arroyo', 'babble', 'babbling', 'be indiscreet', 'be revealed', 'be unguarded', 'become known', 'betray', 'betray a confidence'],
    'leak out': ['appear', 'be revealed', 'become known', 'break forth', 'break out', 'break through', 'come forth', 'come out', 'come to light', 'debouch', 'distill', 'dribble'],
    'leakage': ['ablation', 'access', 'admission', 'break', 'breakout', 'consumption', 'decrease', 'decrement', 'deliverance', 'delivery', 'depletion', 'depreciation'],
    'leakproof': ['airtight', 'ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'corrosionproof', 'dampproof', 'dripproof', 'fire-resisting', 'fireproof', 'flameproof', 'floodproof'],
    'lean': ['lenten', 'spartan', 'abstemious', 'acquiesce', 'agree', 'angular', 'angularity', 'arid', 'ascend', 'ascetic', 'austere', 'bad'],
    'lean on': ['abut on', 'bank on', 'be based on', 'bear against', 'bear down on', 'bear down upon', 'bear hard upon', 'bear on', 'bestraddle', 'bestride', 'bet on', 'calculate on'],
    'lean to': ['nissen hut', 'quonset hut', 'booth', 'crib', 'gatehouse', 'hut', 'hutch', 'kiosk', 'outbuilding', 'outhouse', 'pavilion', 'sentry box'],
    'lean toward': ['be disposed to', 'choose rather', 'favor', 'feel about it', 'have a bias', 'have preference', 'have rather', 'honor before', 'incline toward', 'lean towards', 'like better', 'look at it'],
    'leaning': ['a thing for', 'affinity', 'an ear for', 'an eye for', 'angularity', 'animus', 'aptitude', 'aptness', 'aslant', 'aslope', 'atilt', 'bag'],
    'leap': ['accept', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'aggrandizement', 'amount', 'amplification'],
    'leap year': ['abundant year', 'academic year', 'anniversary', 'annual holiday', 'annum', 'bicentenary', 'bicentennial', 'biennial', 'birthday', 'bissextile day', 'bissextile year', 'calendar month'],
    'leapfrog': ['bounce', 'bound', 'buck', 'buckjump', 'capriole', 'clear', 'curvet', 'hippety-hop', 'hop', 'hurdle', 'jump', 'jump over'],
    'leaping': ['anabatic', 'ascendant', 'ascending', 'ascensional', 'ascensive', 'beaming', 'beatific', 'beatified', 'blessed', 'blissful', 'bouncing', 'bounding'],
    'learn': ['absorb', 'appreciate', 'apprehend', 'ascertain', 'assimilate', 'attend classes', 'attend school', 'awaken to', 'be informed', 'be with one', 'become acquainted with', 'become alive to'],
    'learned': ['abstruse', 'academic', 'accomplished', 'au fait', 'autodidactic', 'bookish', 'broad-minded', 'civilized', 'college-bred', 'collegiate', 'cultivated', 'cultured'],
    'learned man': ['academician', 'bookman', 'classicist', 'clerk', 'colossus of knowledge', 'genius', 'giant of learning', 'humanist', 'learned clerk', 'literary man', 'litterateur', 'lover of learning'],
    'learner': ['abecedarian', 'apprentice', 'auditor', 'autodidact', 'baby', 'beginner', 'catechumen', 'deb', 'debutant', 'educatee', 'entrant', 'fledgling'],
    'learning': ['accomplishments', 'acquisition of knowledge', 'acquisitions', 'attainments', 'culture', 'edification', 'education', 'enlightenment', 'erudition', 'illumination', 'information', 'instruction'],
    'lease': ['adverse possession', 'alodium', 'bareboat charter', 'burgage', 'charter', 'claim', 'colony', 'copyhold', 'de facto', 'de jure', 'dependency', 'derivative title'],
    'lease lend': ['accommodate with', 'advance', 'charter', 'farm', 'farm out', 'float a loan', 'hire', 'hire out', 'job', 'lease', 'lease out', 'lease-back'],
    'leasehold': ['adverse possession', 'alodial', 'alodium', 'burgage', 'claim', 'colony', 'copyhold', 'de facto', 'de jure', 'dependency', 'derivative title', 'equitable estate'],
    'leaseholder': ['hirer', 'homesteader', 'incumbent', 'lessee', 'lodger', 'occupant', 'occupier', 'paying guest', 'renter', 'resident', 'roomer', 'squatter'],
    'leash': ['oregon boat', 'anchor', 'band', 'bandage', 'belt', 'bend', 'bilbo', 'bind', 'bind up', 'bond', 'bonds', 'brace'],
    'least': ['at a disadvantage', 'at the nadir', 'below', 'below the mark', 'few', 'homely', 'humble', 'humble-looking', 'humble-visaged', 'humblest', 'in the gutter', 'inglorious'],
    'leather': ['leatherette', 'leatheroid', 'morocco', 'buff', 'cartilage', 'chamois', 'coat', 'cordovan', 'cuticle', 'dermis', 'dress down', 'fell'],
    'leatherneck': ['marine corps', 'naval reservist', 'royal marine', 'royal marines', 'seabee', 'bluejacket', 'boot', 'cadet', 'devil dogs', 'frogman', 'gob', 'horse marine'],
    'leathery': ['buff', 'cartilaginous', 'chewy', 'cohesive', 'coriaceous', 'durable', 'fibrous', 'gristly', 'hard', 'hardy', 'lasting', 'leather'],
    'leave': ['awol', 'french leave', 'godspeed', 'ok', 'abandon', 'abdicate', 'abrupt', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism'],
    'leave alone': ['be conservative', 'butt out', 'do nothing', 'give carte blanche', 'give full power', 'hold aloof', 'keep hands off', 'leave', 'leave be', 'let alone', 'let be', 'not butt in'],
    'leave behind': ['abandon', 'back out', 'beg off', 'bereave', 'catch up with', 'come up to', 'come up with', 'cry off', 'depart from', 'discard', 'distance', 'drop out'],
    'leave of absence': ['awol', 'french leave', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'cut', 'day off', 'default', 'departure'],
    'leave off': ['abandon', 'abdicate', 'abjure', 'abort', 'acknowledge defeat', 'belay', 'break the habit', 'cancel', 'cease', 'cede', 'come off', 'cry quits'],
    'leave out': ['ban', 'bar', 'bar out', 'blockade', 'count out', 'cut off', 'debar', 'embargo', 'exclude', 'freeze out', 'ignore', 'keep out'],
    'leave word': ['acquaint', 'advertise', 'advertise of', 'advise', 'apprise', 'brief', 'bring word', 'broadcast', 'communicate', 'convey', 'disclose', 'disseminate'],
    'leaved': ['aestival', 'beryl-green', 'berylline', 'blue-green', 'bluish-green', 'bowery', 'branched', 'branching', 'branchy', 'chartreuse', 'chloranemic', 'chlorine'],
    'leaven': ['abate', 'adjust to', 'agent', 'alter', 'alterant', 'alterative', 'alterer', 'assuage', 'bespread', 'besprinkle', 'box in', 'breathe'],
    'leaving': ['awol', 'french leave', 'abandonment', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'casting away', 'cessation', 'cut'],
    'leaving out': ['aside from', 'bar', 'barring', 'beside', 'besides', 'discounting', 'ex', 'except', 'except for', 'excepting', 'exception taken of', 'excluding'],
    'leavings': ['afterglow', 'afterimage', 'balance', 'bones', 'butt', 'butt end', 'candle ends', 'chaff', 'culm', 'deadwood', 'debris', 'detritus'],
    'lecher': ['priapus', 'aphrodisiomaniac', 'backslider', 'bad egg', 'bad lot', 'black sheep', 'degenerate', 'dirty old man', 'eroticomaniac', 'erotomaniac', 'fallen angel', 'goat'],
    'lecherous': ['animal', 'aphrodisiomaniacal', 'bawdy', 'carnal', 'clitoromaniacal', 'concupiscent', 'decadent', 'degenerate', 'depraved', 'dirty', 'dirty-minded', 'dissolute'],
    'lechery': ['animality', 'bawdiness', 'carnality', 'clitoromania', 'concupiscence', 'dirtiness', 'eroticism', 'eroticomania', 'erotomania', 'fleshliness', 'furor uterinus', 'goatishness'],
    'lector': ['bible clerk', 'bible reader', 'acolyte', 'acolytus', 'almoner', 'anagnost', 'beadle', 'bedral', 'capitular', 'capitulary', 'choir chaplain', 'churchwarden'],
    'lecture': ['address', 'admonish', 'admonishment', 'admonition', 'assignment', 'berate', 'berating', 'bring to book', 'call to account', 'castigation', 'censure', 'chalk talk'],
    'lecturer': ['bible clerk', 'bible reader', 'boanerges', 'acolyte', 'almoner', 'anagnost', 'assistant', 'assistant professor', 'associate', 'associate professor', 'beadle', 'bedral'],
    'lecturing': ['autodidactic', 'coeducational', 'cultural', 'debating', 'declamation', 'demagogism', 'didactic', 'disciplinary', 'edifying', 'educating', 'educational', 'educative'],
    'ledge': ['band', 'bank', 'beam-end', 'bed', 'bedding', 'belt', 'billiard table', 'board', 'border', 'bordure', 'bowling green', 'brim'],
    'ledger': ['domesday book', 'account', 'account book', 'accounts payable ledger', 'accounts receivable ledger', 'address book', 'adversaria', 'album', 'annual', 'appointment calendar', 'appointment schedule', 'balance sheet'],
    'lee': ['cover', 'defense', 'eye', 'flanking', 'glancing', 'guard', 'lateral', 'lee sheet', 'lee shore', 'lee side', 'lee tack', 'leeward'],
    'leech': ['chilopoda', 'chordata', 'doctor of medicine', 'echiuroidea', 'ectoprocta', 'entoprocta', 'gp', 'md', 'monoplacophora', 'nemertinea', 'phoronidea', 'adherent'],
    'leer': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'beacon', 'beacon fire', 'beat the drum', 'bell', 'bell buoy', 'blinker', 'blue peter'],
    'leering': ['banter', 'bantering', 'booing', 'catcalling', 'chaffing', 'derision', 'derisive', 'derisory', 'fleering', 'flippancy', 'flippant', 'fooling'],
    'leery': ['pyrrhonic', 'agnostic', 'cagey', 'careful', 'cautious', 'chary', 'disinclined to believe', 'disposed to doubt', 'distrustful', 'doubtful', 'doubting', 'dubious'],
    'lees': ['alluvion', 'alluvium', 'ash', 'bones', 'chaff', 'cinder', 'clinker', 'culm', 'deadwood', 'deposition', 'deposits', 'diluvium'],
    'leeward': ['alee', 'anticlockwise', 'aweather', 'clockwise', 'counterclockwise', 'downwind', 'earthward', 'flanking', 'glancing', 'heavenward', 'homeward', 'landward'],
    'leeway': ['aesthetic distance', 'air space', 'ample scope', 'blank check', 'caesura', 'carte blanche', 'clearance', 'compass', 'deep space', 'depths of space', 'discontinuity', 'distance'],
    'left': ['gospel side', 'abandoned', 'aport', 'cantorial side', 'castaway', 'communistic', 'counterclockwise', 'departed', 'derelict', 'deserted', 'discarded', 'disused'],
    'left handed': ['abusive', 'all thumbs', 'atrocious', 'awkward', 'backhand', 'backhanded', 'blunderheaded', 'blundering', 'boorish', 'bumbling', 'bungling', 'butterfingered'],
    'left wing': ['gospel side', 'cantorial side', 'counterclockwise', 'larboard', 'left', 'left hand', 'left of center', 'left-hand', 'left-hand side', 'left-winger', 'left-wingish', 'leftism'],
    'left winger': ['gospel side', 'cantorial side', 'larboard', 'left', 'left hand', 'left wing', 'left-hand side', 'leftist', 'liberal', 'liberalist', 'near side', 'port'],
    'leftover': ['afterglow', 'afterimage', 'as a bonus', 'balance', 'bonus', 'butt', 'butt end', 'candle ends', 'chaff', 'debris', 'detritus', 'dividend'],
    'leftward': ['anticlockwise', 'aport', 'clockwise', 'counterclockwise', 'earthward', 'heavenward', 'homeward', 'landward', 'larboard', 'leeward', 'left', 'leftwardly'],
    'leg': ['ambulate', 'ankle', 'appendage', 'arm', 'assist', 'bayonet legs', 'boost', 'bough', 'bowlegs', 'branch', 'break', 'breast'],
    'leg man': ['city editor', 'columnist', 'copy chief', 'copy editor', 'copyman', 'copyreader', 'correspondent', 'cub reporter', 'diaskeuast', 'editor', 'editorial writer', 'feature editor'],
    'legacy': ['attested copy', 'bequeathal', 'bequest', 'birthright', 'borough-english', 'by-product', 'codicil', 'coheirship', 'consequence', 'consequent', 'coparcenary', 'corollary'],
    'legal': ['acceptable', 'actionable', 'admissible', 'allowable', 'applicable', 'authoritative', 'authorized', 'balanced', 'binding', 'booked', 'cogent', 'competent'],
    'legal age': ['adulthood', 'adultness', 'age of consent', 'driving age', 'flower of age', 'full age', 'full bloom', 'full growth', 'fullgrownness', 'grown-upness', 'legalis homo', 'majority'],
    'legal counselor': ['advocate', 'agent', 'amicus curiae', 'attorney', 'attorney-at-law', 'barrister', 'barrister-at-law', 'counsel', 'counselor', 'counselor-at-law', 'deputy', 'friend at court'],
    'legal tender': ['and pence', 'cash', 'circulating medium', 'coinage', 'coined liberty', 'cold cash', 'currency', 'dollars', 'emergency money', 'filthy lucre', 'fractional currency', 'gold'],
    'legalistic': ['cavilling', 'contentious', 'conventionalized', 'disputatious', 'extrinsic', 'fine', 'forensic', 'formal', 'formalist', 'formalistic', 'formulary', 'hair-splitting'],
    'legality': ['admissibility', 'admissibleness', 'allowableness', 'defensibility', 'drumhead justice', 'dueness', 'equitableness', 'equity', 'evenhandedness', 'give-and-take', 'justice', 'justifiability'],
    'legalize': ['authorize', 'certificate', 'certify', 'charter', 'constitute', 'declare lawful', 'decree', 'empower', 'enable', 'enact', 'enfranchise', 'entitle'],
    'legate': ['ambassador', 'ambassadress', 'apostolic delegate', 'attache', 'career diplomat', 'chancellor', 'charge', 'commercial attache', 'commissar', 'commissary', 'commissionaire', 'commissioner'],
    'legation': ['agency', 'agentship', 'assignment', 'authority', 'authorization', 'booking office', 'box office', 'branch', 'branch office', 'brevet', 'cabinet', 'care'],
    'legato': ['a cappella', 'abbandono', 'accrescendo', 'adagietto', 'adagio', 'affettuoso', 'agilmente', 'agitato', 'allegretto', 'allegro', 'amabile', 'amoroso'],
    'legend': ['clio', 'lambert conformal projection', 'marchen', 'mercator projection', 'miller projection', 'mishnah', 'muse of history', 'spiritus mundi', 'sunna', 'talmud', 'western', 'western story'],
    'legendary': ['acclaimed', 'acknowledged', 'admitted', 'allegoric', 'autobiographical', 'biographical', 'celebrated', 'chronologic', 'concocted', 'conventional', 'cooked-up', 'customary'],
    'legion': ['kp', 'a mass of', 'a world of', 'armed force', 'armed service', 'army', 'army group', 'array', 'battalion', 'battery', 'battle group', 'bevy'],
    'legionary': ['amazon', 'air serviceman', 'brave', 'cannon fodder', 'fighting man', 'food for powder', 'halberdier', 'hoplite', 'man-at-arms', 'military man', 'navy man', 'pikeman'],
    'legislate': ['authorize', 'constitute', 'declare lawful', 'decree', 'enact', 'enact laws', 'establish', 'filibuster', 'formulate', 'get the floor', 'have the floor', 'kill'],
    'legislation': ['act', 'authorization', 'bill', 'bylaw', 'canon', 'concurrent resolution', 'constitution', 'decree', 'dictate', 'dictation', 'edict', 'enaction'],
    'legislative': ['actionable', 'applicable', 'authorized', 'bicameral', 'competent', 'congressional', 'constitutional', 'deliberative', 'judicial', 'juridical', 'just', 'justiciable'],
    'legislator': ['mp', 'member of congress', 'member of parliament', 'alderman', 'archon', 'assemblyman', 'bailie', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor'],
    'legislature': ['british cabinet', 'sanhedrin', 'us cabinet', 'act', 'advisory body', 'assembly', 'association', 'bench', 'board', 'body of advisers', 'borough council', 'brain trust'],
    'legit': ['broadway', 'actionable', 'applicable', 'authorized', 'burlesque', 'carnival', 'circus', 'competent', 'constitutional', 'drama', 'entertainment industry', 'judicial'],
    'legitimacy': ['absolute power', 'absolute realism', 'absolutism', 'actionability', 'admissibility', 'admissibleness', 'allowableness', 'applicability', 'artlessness', 'authenticity', 'authority', 'bona fideness'],
    'legitimate': ['acceptable', 'actionable', 'actor-proof', 'admissible', 'all-star', 'allowable', 'applicable', 'authentic', 'authoritative', 'authorize', 'authorized', 'ballet'],
    'legume': ['algae', 'autophyte', 'bean', 'boll', 'bracken', 'brown algae', 'burr', 'capsule', 'climber', 'cod', 'conferva', 'confervoid'],
    'legwork': ['amassing evidence', 'ambling', 'ambulation', 'backpacking', 'close inquiry', 'department of investigation', 'detection', 'detective work', 'exhaustive study', 'footing', 'footing it', 'footwork'],
    'leisure': ['at leisure', 'at liberty', 'at loose ends', 'available', 'disengaged', 'ease', 'fallow', 'free', 'free time', 'freedom', 'holiday', 'idle'],
    'leisure class': ['beggar', 'bummer', 'cadger', 'coupon clippers', 'drone', 'freeloader', 'idle rich', 'lounge lizard', 'lumpen proletariat', 'mendicant', 'moocher', 'nonworker'],
    'leisured': ['affluent', 'at leisure', 'at liberty', 'at loose ends', 'available', 'disengaged', 'fallow', 'free', 'idle', 'jobless', 'leisure', 'lumpen'],
    'leisurely': ['ambling', 'cautious', 'cautiously', 'circumspect', 'circumspectly', 'claudicant', 'comfortable', 'crawling', 'crawlingly', 'creeping', 'creeping like snail', 'creepingly'],
    'lemon': ['acid', 'acidulant', 'aureate', 'auric', 'beige', 'bomb', 'bread-and-butter pickle', 'buff', 'buff-yellow', 'bust', 'canary', 'canary-yellow'],
    'lend': ['accommodate', 'accommodate with', 'add', 'advance', 'allow', 'bestow', 'borrow', 'confer', 'contribute', 'discount', 'discount notes', 'fit'],
    'lend a hand': ['abet', 'aid', 'assist', 'avail', 'bail out', 'bear a hand', 'befriend', 'benefit', 'comfort', 'do good', 'doctor', 'ease'],
    'lend lease': ['accommodate with', 'advance', 'advancement', 'advancing', 'bareboat charter', 'charter', 'farm', 'farm out', 'float a loan', 'hire', 'hire out', 'hiring'],
    'length': ['aesthetic distance', 'amplitude', 'area', 'at full length', 'at length', 'at long last', 'bigness', 'body', 'breadth', 'bulk', 'caliber', 'clearance'],
    'lengthen': ['add to', 'aggrandize', 'amplify', 'augment', 'boost', 'broaden', 'build', 'build up', 'continue', 'dawdle', 'drag out', 'draw'],
    'lengthened': ['dragged out', 'drawn', 'drawn out', 'drawn-out', 'elongated', 'extended', 'interminable', 'languishing', 'lasting', 'lingering', 'long', 'long-continuing'],
    'lengthening': ['continualness', 'continuance', 'continuation', 'continuity', 'crescendoing', 'crescent', 'elongation', 'endurance', 'expanding', 'extension', 'growing', 'increasing'],
    'lengthwise': ['along', 'at full length', 'at length', 'endlong', 'endways', 'endwise', 'evenly', 'flat', 'flatly', 'flatways', 'flatwise', 'flush'],
    'lengthy': ['a mile long', 'boring', 'colossal', 'de longue haleine', 'dragging', 'drawn-out', 'dull', 'elongate', 'elongated', 'endless', 'extended', 'extensive'],
    'leniency': ['abatement', 'acceptance', 'accommodatingness', 'agreeableness', 'allayment', 'alleviation', 'assuagement', 'attentiveness', 'benevolence', 'blunting', 'calming', 'carelessness'],
    'lenient': ['spartan', 'accepting', 'accommodating', 'accommodative', 'admissive', 'agreeable', 'allowing', 'armed with patience', 'attentive', 'balmy', 'bland', 'bleeding'],
    'lenitive': ['alleviating', 'alleviative', 'alleviator', 'altering', 'analgesic', 'anesthetic', 'anodyne', 'assuager', 'assuasive', 'balm', 'balmy', 'balsam'],
    'lens': ['baby blues', 'banjo eyes', 'bright eyes', 'clear eyes', 'cornea', 'eye', 'eyeball', 'eyelid', 'goggle eyes', 'iris', 'lid', 'naked eye'],
    'lent': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas'],
    'lenten': ['apostolic', 'encratic', 'pythagorean', 'rechabite', 'shaker', 'spartan', 'stoic', 'abstemious', 'abstinent', 'ascetic', 'austere', 'celibate'],
    'leopard': ['dalmatian', 'leo', 'siberian tiger', 'antigorite', 'bobcat', 'butterfly', 'candy cane', 'cat-a-mountain', 'catamount', 'chameleon', 'cheetah', 'chrysotile'],
    'leper': ['dp', 'ishmael', 'castaway', 'declasse', 'derelict', 'displaced person', 'evictee', 'exile', 'expatriate', 'expellee', 'outcast', 'outcast of society'],
    'leprechaun': ['ariel', 'befind', 'corrigan', 'finnbeara', 'mab', 'oberon', 'titania', 'banshee', 'brownie', 'cluricaune', 'dwarf', 'elf'],
    'leprosy': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acne', 'acne vulgaris', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery'],
    'leprous': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'cancerous', 'chlorotic', 'colicky', 'consumptive', 'dropsical', 'dyspeptic', 'edematous'],
    'lesbian': ['ac-dc', 'amazon', 'amphierotic', 'androgyne', 'auntie', 'autoerotic', 'bi-guy', 'bisexed', 'bisexual', 'bull dyke', 'butch', 'catamite'],
    'lesbianism': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'bisexuality', 'coprophilia', 'exhibitionism', 'fetishism', 'heterosexuality', 'homoeroticism', 'homosexualism'],
    'lesion': ['abrasion', 'abscess', 'ache', 'aching', 'aposteme', 'bed sore', 'blain', 'bleb', 'blemish', 'blister', 'blow', 'boil'],
    'less': ['abated', 'ablated', 'at a disadvantage', 'at the nadir', 'attenuated', 'barring', 'bated', 'belittled', 'below', 'below the mark', 'common', 'consumed'],
    'lessee': ['board-and-roomer', 'boarder', 'hirer', 'homesteader', 'incumbent', 'leaseholder', 'lodger', 'occupant', 'occupier', 'paying guest', 'renter', 'resident'],
    'lessen': ['abate', 'ablate', 'abrade', 'abridge', 'abstract', 'allay', 'alleviate', 'allow for', 'amputate', 'anesthetize', 'appease', 'assuage'],
    'lessening': ['abatement', 'abating', 'abridgment', 'allaying', 'allayment', 'alleviating', 'alleviation', 'analgesia', 'anesthesia', 'anesthetizing', 'appeasement', 'assuagement'],
    'lesser': ['abated', 'ablated', 'attenuated', 'bated', 'belittled', 'common', 'consumed', 'contracted', 'curtailed', 'decreased', 'deflated', 'demeaning'],
    'lesson': ['admonish', 'admonishment', 'admonition', 'alarm', 'assignment', 'call down', 'castigation', 'caution', 'caveat', 'chalk talk', 'chastening', 'chastisement'],
    'let': ['ok', 'accord', 'accredit', 'admit', 'allow', 'approve', 'arrest', 'arrestation', 'arrestment', 'assume', 'authorize', 'bareboat charter'],
    'let alone': ['abandon', 'abstain', 'abstain from', 'added to', 'along with', 'as well as', 'aside from', 'attended by', 'avoid', 'bar', 'barring', 'be conservative'],
    'let be': ['abandon', 'assume', 'be afraid', 'be conservative', 'believe', 'butt out', 'conceive', 'conclude', 'consider', 'cut', 'daresay', 'deduce'],
    'let down': ['abate', 'apostatize', 'arrest', 'backpedal', 'backwater', 'baffle', 'baffled', 'balk', 'balked', 'bamboozle', 'bate', 'bear down'],
    'let drop': ['allude to', 'babble', 'be indiscreet', 'be unguarded', 'betray', 'betray a confidence', 'blab', 'blabber', 'blurt', 'blurt out', 'call attention to', 'comment'],
    'let fly': ['bowl', 'cast', 'catapult', 'charge', 'chuck', 'chunk', 'cock', 'dart', 'dash', 'detonate', 'discharge', 'drop'],
    'let fly at': ['cast at', 'chuck at', 'cut and thrust', 'feint', 'fire at', 'flail at', 'flail away at', 'fling at', 'heave at', 'hit at', 'hurl against', 'hurl at'],
    'let go': ['abandon', 'abjure', 'absolve', 'acquit', 'amnesty', 'be caught napping', 'be neglectful', 'be negligent', 'boot', 'bounce', 'break', 'break up'],
    'let in on': ['air', 'alert', 'awaken', 'break it to', 'break the news', 'break the spell', 'breathe', 'burst the bubble', 'buzz', 'come out with', 'confide', 'confide to'],
    'let it go': ['abandon', 'allow for', 'bear with', 'blink at', 'brush aside', 'brush off', 'bury the hatchet', 'charge off', 'charge to experience', 'condone', 'connive at', 'dismiss'],
    'let loose': ['carouse', 'cast loose', 'celebrate', 'cut loose', 'debauch', 'demobilize', 'discharge', 'dismiss', 'give way to', 'go all out', 'go bail for', 'go flat out'],
    'let off': ['absolve', 'acquit', 'amnesty', 'backfire', 'blast', 'blow out', 'blow up', 'burst', 'bust', 'cast loose', 'charge', 'charter'],
    'let on': ['acknowledge', 'act', 'act a part', 'admit', 'admit everything', 'affect', 'allow', 'assume', 'avow', 'betray', 'bluff', 'come clean'],
    'let out': ['air', 'articulate', 'ax', 'bare', 'betray', 'bleed', 'blow', 'boot', 'boot out', 'bounce', 'break', 'break it to'],
    'let pass': ['accept', 'be blind to', 'be caught out', 'be inattentive', 'be unwary', 'blink at', 'condone', 'connive at', 'countenance', 'disregard', 'give no heed', 'grin and abide'],
    'let ride': ['be caught napping', 'be neglectful', 'be negligent', 'default', 'disregard', 'fail', 'gloss over', 'ignore', 'lapse', 'let go', 'let pass', 'let slide'],
    'let slide': ['be caught napping', 'be neglectful', 'be negligent', 'default', 'disregard', 'fail', 'gloss over', 'ignore', 'lapse', 'let go', 'let pass', 'let ride'],
    'let slip': ['abandon', 'babble', 'be bereaved of', 'be caught napping', 'be indiscreet', 'be neglectful', 'be negligent', 'be unguarded', 'betray', 'betray a confidence', 'blab', 'blabber'],
    'let up': ['abate', 'ablate', 'arrest', 'backpedal', 'backwater', 'bate', 'be eaten away', 'brake', 'call a recess', 'check', 'clip the wings', 'consume'],
    'letdown': ['abasement', 'abatement', 'allayment', 'alleviation', 'arrest', 'assuagement', 'bafflement', 'balk', 'betrayed hope', 'blasted expectation', 'blighted hope', 'blow'],
    'lethal': ['baleful', 'baneful', 'brutal', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'counterproductive', 'damaging', 'deadly', 'death-bringing', 'deathful'],
    'lethality': ['balefulness', 'banefulness', 'deadliness', 'detrimentalness', 'fatality', 'harmfulness', 'hurtfulness', 'injuriousness', 'malignance', 'malignancy', 'malignity', 'mischievousness'],
    'lethargic': ['laodicean', 'olympian', 'aloof', 'anesthetized', 'apathetic', 'benumbed', 'blah', 'blase', 'bored', 'cataleptic', 'comatose', 'dead'],
    'lethargy': ['abstraction', 'abulia', 'acedia', 'alienation', 'aloofness', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'asininity', 'ataraxia', 'ataraxy'],
    'letter': ['pp', 'rd', 'rfd', 'accurately', 'acknowledgment', 'advice', 'airmail', 'alphabet', 'alphabetize', 'answer', 'art', 'article'],
    'letter carrier': ['aquarius', 'ganymede', 'hebe', 'bearer', 'bheesty', 'busboy', 'caddie', 'cargo handler', 'carrier', 'carrier pigeon', 'carter', 'common carrier'],
    'letter of credit': ['cd', 'iou', 'mo', 'pastoral epistle', 'acceptance', 'acceptance bill', 'aerogram', 'air letter', 'airgraph', 'bank acceptance', 'bank check', 'bill'],
    'lettered': ['abecedarian', 'abstruse', 'allographic', 'alphabetic', 'capital', 'civilized', 'cultivated', 'cultured', 'deep', 'educated', 'encyclopedic', 'enlightened'],
    'letterer': ['amanuensis', 'calligrapher', 'chirographer', 'clerk', 'copier', 'copyist', 'ink spiller', 'inkslinger', 'pen', 'pencil driver', 'penman', 'penner'],
    'letterhead': ['address', 'billhead', 'book stamp', 'bookplate', 'brand', 'broad arrow', 'cachet', 'check', 'colophon', 'counterfoil', 'countermark', 'destination'],
    'lettering': ['italian hand', 'spencerian writing', 'block letter', 'bold hand', 'book hand', 'chancery hand', 'copperplate hand', 'coup de plume', 'cryptography', 'cursive', 'cursive hand', 'engrossment'],
    'letterpress': ['advance sheets', 'advertising matter', 'albertype', 'book printing', 'chromotypography', 'chromotypy', 'chromoxylography', 'collotype', 'color printing', 'electronography', 'electrostatic printing', 'graphic arts'],
    'letters': ['french literature', 'ipa', 'ita', 'initial teaching alphabet', 'renaissance literature', 'account', 'alphabet', 'alphabetics', 'ancient literature', 'annals', 'belles lettres', 'bibliolatry'],
    'letters of marque': ['pastoral epistle', 'aerogram', 'air letter', 'air piracy', 'airgraph', 'airplane hijacking', 'billet-doux', 'buccaneering', 'bull', 'chain letter', 'dead letter', 'dimissorial'],
    'letting go': ['abandonment', 'abjuration', 'cession', 'dispensation', 'disposal', 'disposition', 'dumping', 'forgoing', 'forswearing', 'getting rid of', 'giving up', 'recantation'],
    'letup': ['abatement', 'abeyance', 'abridgment', 'allayment', 'alleviation', 'arrest', 'assuagement', 'attenuation', 'blunting', 'breach', 'break', 'breath'],
    'leukemia': ['christmas disease', 'letterer-siwe syndrome', 'acute leukemia', 'anemia', 'angiohemophilia', 'aplastic anemia', 'chronic leukemia', 'cyclic neutropenia', 'erythrocytosis', 'hemoglobinopathy', 'hemophilia', 'hemophilia a'],
    'leukocyte': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'antibody', 'antigen', 'arterial blood', 'blood', 'blood bank', 'blood cell', 'blood count'],
    'levant': ['africa', 'america', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'east', 'eastern hemisphere', 'eurasia', 'europe', 'far east'],
    'levanter': ['euroclydon', 'tehuantepec wind', 'tehuantepecer', 'bise', 'defaulter', 'delinquent', 'east wind', 'easter', 'easterly', 'gregale', 'mistral', 'nonpayer'],
    'levee': ['affair', 'arch dam', 'assemblee', 'assembly', 'assignation', 'at home', 'backstop', 'ball', 'bamboo curtain', 'bank', 'bar', 'barrage'],
    'level': ['ic analysis', 'accommodate', 'accordant', 'address', 'adjust', 'aim', 'akin', 'alabaster', 'align', 'aligned', 'alike', 'alkali flat'],
    'level at': ['aim', 'aim at', 'bend', 'determine', 'direct', 'directionize', 'fix', 'fix on', 'hold on', 'point', 'point at', 'point to'],
    'level head': ['aplomb', 'assurance', 'balance', 'common sense', 'confidence', 'cool head', 'coolheadedness', 'coolness', 'due sense of', 'equability', 'equanimity', 'equilibrium'],
    'level-headed': ['calm', 'collected', 'composed', 'cool', 'even-tempered', 'imperturbable', 'level', 'poised', 'reasonable', 'relaxed', 'sane', 'self-possessed'],
    'levelheaded': ['assured', 'balanced', 'calm', 'collected', 'commonsense', 'composed', 'confident', 'cool', 'coolheaded', 'dispassionate', 'equable', 'equanimous'],
    'lever': ['charlie mccarthy', 'agent', 'ancilla', 'appliance', 'bar', 'beam', 'boom', 'cant hook', 'claw bar', 'contrivance', 'crab', 'crane'],
    'leverage': ['aeromechanics', 'animal mechanics', 'ascendancy', 'authority', 'biomechanics', 'celestial mechanics', 'charisma', 'charm', 'clout', 'consequence', 'control', 'credit'],
    'leviathan': ['argosy', 'bark', 'boat', 'bottom', 'bucket', 'craft', 'cyclopean', 'dinosaur', 'elephant', 'elephantine', 'enormous', 'gargantuan'],
    'levitate': ['arise', 'ascend', 'boost', 'buoy up', 'cast up', 'come up', 'curl upwards', 'elevate', 'erect', 'escalate', 'float', 'go up'],
    'levitation': ['ouija', 'airiness', 'anabasis', 'ascension', 'ascent', 'automatic writing', 'automatism', 'bubbliness', 'buoyancy', 'clamber', 'climb', 'climbing'],
    'levity': ['absentmindedness', 'absurdity', 'airiness', 'amusement', 'ascent', 'banter', 'big deal', 'booing', 'bounce', 'breeziness', 'bubbliness', 'buoyancy'],
    'levy': ['angary', 'annex', 'annexation', 'annexure', 'ask', 'ask for', 'assess', 'assessment', 'attach', 'attachment', 'beat the drums', 'blackmail'],
    'lewd': ['fescennine', 'rabelaisian', 'animal', 'aphrodisiomaniacal', 'bawdy', 'blue', 'carnal', 'clitoromaniacal', 'coarse', 'concupiscent', 'crude', 'debauched'],
    'lewdness': ['rabelaisianism', 'x-rated movie', 'animality', 'bawdiness', 'bawdry', 'blue movie', 'carnality', 'clitoromania', 'concupiscence', 'dirt', 'dirtiness', 'dirty movie'],
    'lex': ['act', 'bill', 'bylaw', 'canon', 'decree', 'dictate', 'dictation', 'edict', 'enactment', 'form', 'formality', 'formula'],
    'lexeme': ['antonym', 'articulation', 'expression', 'free form', 'glosseme', 'homograph', 'homonym', 'homophone', 'icon', 'lexical form', 'linguistic form', 'locution'],
    'lexical': ['conjugate', 'derivative', 'echoic', 'etymologic', 'glossematic', 'iconic', 'lexemic', 'lexicographic', 'lexicologic', 'lexigraphic', 'morphemic', 'onomastic'],
    'lexicographer': ['allegorist', 'annotator', 'cicerone', 'clarifier', 'commentator', 'critic', 'cryptanalyst', 'cryptographer', 'cryptologist', 'decoder', 'definer', 'demonstrator'],
    'lexicography': ['criticism', 'cryptanalysis', 'cryptography', 'cryptology', 'diagnostics', 'epigraphy', 'exegetics', 'glossography', 'hermeneutics', 'lexicology', 'lexigraphy', 'literary criticism'],
    'lexicologist': ['dialectician', 'etymologer', 'etymologist', 'glossarist', 'glossographer', 'grammarian', 'grammaticaster', 'grammatist', 'lexicographer', 'linguist', 'linguistic scholar', 'linguistic scientist'],
    'lexicology': ['bowwow theory', 'comparative linguistics', 'derivation', 'descriptive linguistics', 'dialectology', 'dingdong theory', 'etymology', 'glossematics', 'glossography', 'glossology', 'glottochronology', 'glottology'],
    'lexicon': ['biographical dictionary', 'cant', 'chemical dictionary', 'desk dictionary', 'dialect dictionary', 'dictionary', 'dictionary of quotations', 'electronics dictionary', 'etymological dictionary', 'foreign-language dictionary', 'gazetteer', 'general dictionary'],
    'lexigraphic': ['abecedarian', 'allographic', 'alphabetic', 'capital', 'conjugate', 'derivative', 'echoic', 'etymologic', 'graphemic', 'ideographic', 'lettered', 'lexical'],
    'liabilities': ['accounts', 'accounts payable', 'accounts receivable', 'assets', 'budget', 'budget items', 'budgeting', 'burden of expenditure', 'carrying charge', 'charges', 'cost', 'cost of living'],
    'liability': ['a thing for', 'accountability', 'accountableness', 'accounts payable', 'accounts receivable', 'affinity', 'amenability', 'amount due', 'answerability', 'answerableness', 'aptitude', 'aptness'],
    'liable': ['accountable', 'actionable', 'amenable', 'answerable', 'answerable for', 'apt', 'assailable', 'attackable', 'beatable', 'blameworthy', 'bound', 'chargeable'],
    'liable to': ['answerable for', 'apt to', 'calculated to', 'capable of', 'dependent on', 'disposed to', 'exposed to', 'given to', 'in danger of', 'incident to', 'inclined to', 'likely to'],
    'liaison': ['accord', 'addition', 'adjunct', 'adulterous affair', 'adultery', 'affair', 'affairs', 'affiliation', 'affinity', 'agent', 'agglomeration', 'agglutination'],
    'liana': ['algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'diatom', 'fern', 'fruits and vegetables'],
    'liar': ['ananias', 'baron munchausen', 'father of lies', 'satan', 'sir john mandeville', 'consummate liar', 'dirty liar', 'equivocator', 'fabricator', 'fabulist', 'false witness', 'falsifier'],
    'libation': ['beverage', 'bumper', 'burnt offering', 'collection', 'draft', 'dram', 'drench', 'drink', 'drink offering', 'drop', 'ex voto offering', 'gargle'],
    'libel': ['affidavit', 'allegation', 'asperse', 'aspersion', 'backbite', 'backbiting', 'bad-mouth', 'barefaced lie', 'belittle', 'belittlement', 'besmirch', 'bill'],
    'libelous': ['abusive', 'back-biting', 'backbiting', 'belittling', 'bitchy', 'calumniatory', 'calumnious', 'catty', 'censorious', 'contemptuous', 'contumelious', 'debasing'],
    'liberal': ['gospel side', 'abounding', 'abundant', 'advanced', 'affluent', 'all-sufficing', 'amiable', 'ample', 'aplenty', 'benevolent', 'big', 'big person'],
    'liberal arts': ['academic specialty', 'area', 'classical education', 'core curriculum', 'course', 'course of study', 'curriculum', 'discipline', 'elective', 'field', 'general education', 'general studies'],
    'liberalism': ['broad-mindedness', 'capitalism', 'catholicity', 'free competition', 'free enterprise', 'free thought', 'free trade', 'freethinking', 'isolationism', 'laissez-aller', 'laissez-faire', 'laissez-faireism'],
    'liberality': ['trinkgeld', 'abundance', 'accommodation', 'accordance', 'affluence', 'amiability', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'award', 'awarding'],
    'liberally': ['abundantly', 'affluently', 'aplenty', 'bigheartedly', 'bottomlessly', 'bounteously', 'bountifully', 'chivalrously', 'copiously', 'diffusely', 'effusely', 'extravagantly'],
    'liberate': ['affranchise', 'appropriate', 'cast off', 'clear', 'deliver', 'detach', 'disburden', 'discharge', 'disembarrass', 'disembroil', 'disencumber', 'disengage'],
    'liberated': ['afoot and lighthearted', 'at large', 'at liberty', 'clear', 'delivered', 'detached', 'disengaged', 'easygoing', 'emancipated', 'extricated', 'footloose', 'footloose and fancy-free'],
    'liberation': ['abstraction', 'annexation', 'appropriation', 'boosting', 'break', 'breakout', 'broad-mindedness', 'conversion', 'conveyance', 'deliverance', 'delivery', 'emancipation'],
    'libertarian': ['big person', 'broad-gauge person', 'broad-minded', 'ecumenicist', 'free lance', 'free spirit', 'free trader', 'freethinker', 'freethinking', 'independent', 'individualist', 'isolationist'],
    'libertine': ['casanova', 'don juan', 'lothario', 'paphian', 'adulterer', 'amoral', 'bestial', 'broad-minded', 'carnal', 'debauched', 'debauchee', 'debaucher'],
    'libertinism': ['broad-mindedness', 'debauchery', 'debauchment', 'dissipation', 'dissoluteness', 'fastness', 'free thought', 'freethinking', 'gallantry', 'latitudinarianism', 'liberalism', 'liberation'],
    'liberty': ['lehrfreiheit', 'ok', 'a leg up', 'academic freedom', 'admission', 'allowance', 'assumption', 'at liberty', 'authorization', 'autonomy', 'blank check', 'brevet'],
    'libidinal': ['amorous', 'appetitive', 'automatic', 'carnal', 'desiderative', 'desireful', 'desiring', 'desirous', 'eager', 'erogenic', 'erogenous', 'erotic'],
    'libidinous': ['animal', 'aphrodisiomaniacal', 'appetitive', 'bawdy', 'carnal', 'clitoromaniacal', 'coarse', 'concupiscent', 'desiderative', 'desireful', 'desiring', 'desirous'],
    'libido': ['amor', 'christian love', 'eros', 'platonic love', 'admiration', 'adoration', 'affection', 'agape', 'anima', 'archetypal pattern', 'archetype', 'ardency'],
    'librarian': ['mc', 'accountant', 'amanuensis', 'archivist', 'attorney', 'bailiff', 'bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliomane', 'bibliomaniac'],
    'library': ['ala', 'american library association', 'bodleian library', 'british museum', 'festschrift', 'indian reservation', 'library of congress', 'vatican library', 'ana', 'anthology', 'aquarium', 'archives'],
    'librettist': ['meistersinger', 'parnassian', 'arch-poet', 'arranger', 'ballad maker', 'balladeer', 'balladist', 'balladmonger', 'bard', 'beat poet', 'bucoliast', 'choreographer'],
    'libretto': ['arrangement', 'book', 'continuity', 'copy', 'cue', 'draft', 'edition', 'hymnal', 'hymnbook', 'instrumental score', 'lines', 'lute tablature'],
    'licence': ['authority', 'authorization', 'carte blanche', 'certificate', 'charter', 'credentials', 'departure', 'deviation', 'dispensation', 'disregard', 'divergence', 'entitlement'],
    'license': ['lehrfreiheit', 'ok', 'academic freedom', 'accredit', 'admission', 'agency', 'agentship', 'allow', 'allowance', 'anarchy', 'approve', 'assign'],
    'licensed': ['authorized', 'chartered', 'empowered', 'enfranchised', 'entitled', 'excepted', 'excused', 'exempt', 'exempted', 'favored', 'franchised', 'immune'],
    'licentious': ['abandoned', 'amoral', 'animal', 'carnal', 'corrupt', 'debauched', 'depraved', 'disobedient', 'dissipated', 'dissolute', 'fast', 'fleshly'],
    'lichen': ['acne', 'acne vulgaris', 'algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'dermamycosis'],
    'licit': ['actionable', 'admissible', 'allowable', 'applicable', 'approved', 'authorized', 'competent', 'constitutional', 'innocent', 'judicial', 'juridical', 'just'],
    'lick': ['addle', 'amaze', 'approach', 'assay', 'attempt', 'baffle', 'bamboozle', 'bang', 'bash', 'bat', 'bear the palm', 'beat'],
    'licked': ['addled', 'all up with', 'at a loss', 'baffled', 'bamboozled', 'beat', 'beaten', 'bested', 'buffaloed', 'confounded', 'dazed', 'defeated'],
    'lickerish': ['animal', 'aphrodisiomaniacal', 'appetitive', 'bawdy', 'carnal', 'clitoromaniacal', 'concupiscent', 'desiderative', 'desireful', 'desiring', 'desirous', 'dirty'],
    'lickety split': ['amain', 'apace', 'at flank speed', 'double-quick', 'expeditiously', 'fast', 'hand over fist', 'hand over hand', 'hastily', 'hell for leather', 'hell-bent', 'hell-bent for election'],
    'licking': ['waterloo', 'appetite', 'beating', 'cannibalism', 'carnivorism', 'carnivority', 'carnivorousness', 'chewing', 'collapse', 'conquering', 'conquest', 'consumption'],
    'lid': ['baby blues', 'banjo eyes', 'bright eyes', 'bung', 'cap', 'chapeau', 'check valve', 'clear eyes', 'cock', 'cork', 'cornea', 'cover'],
    'lido': ['bank', 'beach', 'berm', 'coast', 'coastland', 'coastline', 'embankment', 'foreshore', 'ironbound coast', 'littoral', 'plage', 'playa'],
    'lie': ['aim', 'aspect', 'attitude', 'azimuth', 'be found', 'be located', 'be met with', 'be present', 'be situated', 'be there', 'be untruthful', 'bearing'],
    'lie down': ['bed', 'bed down', 'couch', 'crawl', 'curl up', 'go to bed', 'go to rest', 'grovel', 'lay', 'lie', 'lie flat', 'lie limply'],
    'lie in': ['abide in', 'approach anchorage', 'be coextensive with', 'be comprised in', 'be confined', 'be constituted by', 'be contained in', 'be found', 'be located', 'be present in', 'be situated', 'bear'],
    'lie in wait': ['abide', 'ambuscade', 'ambush', 'await', 'bide', 'couch', 'creep', 'gumshoe', 'lay for', 'lay wait', 'lay wait for', 'lie in ambush'],
    'lie low': ['be incognito', 'be latent', 'beware', 'burrow', 'couch', 'crawl', 'crouch', 'disappear', 'drop from sight', 'escape notice', 'go into hiding', 'go to ground'],
    'lie on': ['abut on', 'be based on', 'be contingent on', 'be dependent on', 'be predicated on', 'bear hard upon', 'bear on', 'bear upon', 'bestraddle', 'bestride', 'burden', 'depend'],
    'lied': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'alba', 'anthem', 'aria', 'art song', 'aubade', 'ballad', 'ballade'],
    'liege': ['ardent', 'bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'boss', 'bwana', 'captive', 'chattel', 'chattel slave', 'chef'],
    'lien': ['adjustment mortgage', 'antichresis', 'blanket mortgage', 'bottomry', 'bottomry bond', 'chattel mortgage', 'closed mortgage', 'common-law lien', 'dead pledge', 'deed of trust', 'first mortgage', 'general lien'],
    'lieu': ['abode', 'area', 'bearings', 'bench mark', 'district', 'emplacement', 'hole', 'latitude and longitude', 'locale', 'locality', 'location', 'locus'],
    'lieutenant': ['adc', 'co', 'g-man', 'mp', 'od', 'acolyte', 'adjutant', 'admiral', 'advocate', 'agent', 'aid', 'aide'],
    'life': ['adamite', 'clio', 'muse of history', 'activator', 'activity', 'adventures', 'affairs', 'age', 'alacrity', 'an existence', 'animal spirits', 'animation'],
    'life after death': ['heaven', 'paradise', 'a better place', 'afterlife', 'afterworld', 'destiny', 'eternal home', 'fate', 'future state', 'home', 'life to come', 'next world'],
    'life cycle': ['anima', 'animating force', 'atman', 'bathmism', 'beating heart', 'biological clock', 'biorhythm', 'blood', 'breath', 'breath of life', 'divine breath', 'divine spark'],
    'life force': ['anima', 'animating force', 'atman', 'bathmism', 'beating heart', 'biological clock', 'biorhythm', 'blood', 'breath', 'breath of life', 'divine breath', 'divine spark'],
    'life jacket': ['mae west', 'breeches buoy', 'buoy', 'cork jacket', 'ejection capsule', 'ejection seat', 'ejector seat', 'life belt', 'life buoy', 'life net', 'life preserver', 'life raft'],
    'life preserver': ['carling float', 'mae west', 'aegis', 'arm guard', 'backstop', 'balsa', 'balsa raft', 'bob', 'boom', 'breeches buoy', 'buffer', 'bulwark'],
    'life principle': ['anima', 'animating force', 'astral body', 'atman', 'bathmism', 'beating heart', 'biological clock', 'biorhythm', 'blood', 'breath', 'breath of life', 'buddhi'],
    'life savings': ['swiss bank account', 'assets', 'balance', 'bank account', 'bottom dollar', 'budget', 'cash reserves', 'checking account', 'command of money', 'exchequer', 'finances', 'fund'],
    'life science': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology', 'biometrics'],
    'life story': ['clio', 'muse of history', 'adventures', 'annals', 'autobiography', 'biographical sketch', 'biography', 'case history', 'chronicle', 'chronicles', 'chronology', 'confessions'],
    'lifeblood': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'anima', 'animating force', 'antibody', 'antigen', 'arterial blood', 'atman', 'bathmism'],
    'lifeboat': ['mae west', 'air-sea rescue', 'bolt-hole', 'breeches buoy', 'buoy', 'coast guard', 'cork jacket', 'ejection capsule', 'ejection seat', 'ejector seat', 'emergency exit', 'escape hatch'],
    'lifeguard': ['air warden', 'air-sea rescue', 'attendant', 'caretaker', 'castellan', 'coast guard', 'conservator', 'curator', 'custodian', 'forest ranger', 'game warden', 'gamekeeper'],
    'lifeless': ['abeyant', 'abiotic', 'apathetic', 'arid', 'asleep', 'asleep in jesus', 'at rest', 'azoic', 'bare', 'barren', 'benumbed', 'bereft of life'],
    'lifelike': ['authentic', 'bona fide', 'breathing', 'candid', 'card-carrying', 'delineative', 'depictive', 'descriptive', 'dinkum', 'expositive', 'expressive', 'faithful'],
    'lifeline': ['mae west', 'aegis', 'arm guard', 'backstop', 'bolt-hole', 'breeches buoy', 'buffer', 'bulwark', 'bumper', 'buoy', 'contraceptive', 'copyright'],
    'lifer': ['pow', 'cageling', 'captive', 'chain gang', 'con', 'convict', 'detenu', 'ex-convict', 'gaolbird', 'internee', 'jailbird', 'parolee'],
    'lifesaver': ['audubon society', 'national wildlife service', 'sierra club', 'air warden', 'air-sea rescue', 'attendant', 'caretaker', 'castellan', 'coast guard', 'conservationist', 'conservator', 'curator'],
    'lifetime': ['age', 'animal spirits', 'animate existence', 'animation', 'being alive', 'birth', 'existence', 'for life', 'generation', 'having life', 'immortality', 'life'],
    'lifework': ['activity', 'art', 'business', 'calling', 'campaign', 'career', 'career building', 'careerism', 'cause', 'commitment', 'craft', 'crusade'],
    'lift': ['caelus', 'great leap forward', 'olympian heights', 'sunday drive', 'a leg up', 'abstract', 'acculturate', 'acme', 'advance', 'advancement', 'aerial heights', 'aerosphere'],
    'lifter': ['andiron', 'body snatcher', 'booster', 'chain', 'chicken thief', 'coal tongs', 'con man', 'crab', 'crane', 'crook', 'damper', 'den of thieves'],
    'ligament': ['bone', 'braid', 'brail', 'cable', 'cartilage', 'cord', 'knot', 'ligation', 'ligature', 'line', 'link', 'nexus'],
    'ligature': ['accent', 'accent mark', 'ascender', 'back', 'bar', 'bastard type', 'beard', 'belly', 'bevel', 'black letter', 'body', 'braid'],
    'light': ['asa scale', 'anschauung', 'british candle', 'hefner candle', 'mickey mouse', 'paphian', 'scheiner scale', 'very flare', 'abuse', 'accented', 'account', 'acquaintance'],
    'light bulb': ['candle', 'electric light bulb', 'fire', 'flame', 'glim', 'illuminant', 'illuminator', 'incandescent body', 'lamp', 'lantern', 'light', 'light source'],
    'light footed': ['agile', 'breakneck', 'dashing', 'double-quick', 'eagle-winged', 'expeditious', 'express', 'fast', 'featly', 'fleet', 'flying', 'galloping'],
    'light into': ['ambush', 'assail', 'assault', 'attack', 'blitz', 'bushwhack', 'come at', 'come down on', 'crack down on', 'descend on', 'descend upon', 'dive into'],
    'light meter': ['asa exposure index', 'asa scale', 'british candle', 'din number', 'hefner candle', 'scheiner scale', 'bougie decimale', 'candle', 'candle lumen', 'candle power', 'candle-foot', 'candle-hour'],
    'light opera': ['broadway musical', 'singspiel', 'ballad opera', 'ballet', 'ballet divertissement', 'chorus show', 'comedy ballet', 'comic opera', 'dance drama', 'grand opera', 'lyric drama', 'minstrel'],
    'light out': ['bear', 'dash off', 'dig out', 'hasten off', 'head', 'hurry away', 'make', 'nip', 'nip off', 'scamper off', 'set out', 'skin out'],
    'light show': ['burelage', 'burlesque show', 'carnival', 'circus', 'coochie show', 'cosmorama', 'cyclorama', 'dance', 'dancing', 'diorama', 'display', 'exhibit'],
    'light source': ['chinese lantern', 'finsen light', 'moore light', 'arc light', 'battery lamp', 'benzine', 'broadside', 'candle', 'candlelight', 'coal oil', 'cresset', 'dark lantern'],
    'light touch': ['breath', 'brush', 'caress', 'contact', 'cutaneous sense', 'feel', 'feeling', 'fingertip caress', 'flick', 'glance', 'graze', 'hand-mindedness'],
    'light up': ['annoy', 'arouse', 'awake', 'awaken', 'bank', 'beacon', 'blow the coals', 'blow up', 'brace up', 'brighten', 'brighten up', 'buck up'],
    'light upon': ['alight upon', 'arrive at', 'arrive upon', 'blunder upon', 'bump into', 'chance upon', 'come across', 'come among', 'come at', 'come down on', 'come on', 'come up against'],
    'light year': ['aesthetic distance', 'astronomical unit', 'celestial spaces', 'chaos', 'clearance', 'compass', 'cosmic space', 'deep space', 'depths of space', 'distance', 'divergence', 'empty space'],
    'lighted': ['ablaze', 'afire', 'aflame', 'aglow', 'alight', 'bathed with light', 'bespangled', 'blazing', 'brightened', 'candlelit', 'enlightened', 'fiery'],
    'lighten': ['abate', 'allay', 'alleviate', 'assuage', 'attemper', 'attenuate', 'bank the fire', 'be light', 'beacon', 'blunt', 'break', 'brighten'],
    'lightened': ['ablaze', 'aglow', 'alight', 'bathed with light', 'bespangled', 'blanched', 'bleached', 'bleached white', 'brightened', 'candlelit', 'decolored', 'decolorized'],
    'lightening': ['abatement', 'achromatization', 'allayment', 'alleviating', 'alleviation', 'alleviative', 'assuagement', 'blanching', 'bleach', 'bleaching', 'blunting', 'brightening'],
    'lighthearted': ['airy', 'blithe', 'blithesome', 'breezy', 'buoyant', 'carefree', 'corky', 'debonair', 'effervescent', 'expansive', 'festive', 'free'],
    'lighthouse': ['klaxon', 'mayday', 'sos', 'texas tower', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert', 'all clear'],
    'lighting': ['arc lighting', 'black and white', 'brightening', 'chiaroscuro', 'contrast', 'decorative lighting', 'direct lighting', 'electric lighting', 'enkindling', 'enlightening', 'enlightenment', 'festoon lighting'],
    'lightly': ['a bit', 'a little', 'airily', 'arbitrarily', 'barely', 'blithely', 'by a hair', 'by an ace', 'capriciously', 'cheerfully', 'cheerily', 'easily'],
    'lightness': ['munsell chroma', 'achroma', 'achromasia', 'achromatosis', 'agility', 'airiness', 'airy texture', 'albescence', 'albinism', 'albino', 'albinoism', 'amiable weakness'],
    'lightning': ['jupiter fulgur', 'thor', 'antelope', 'arrow', 'ball lightning', 'blue darter', 'blue streak', 'bolt', 'bolt of lightning', 'cannonball', 'chain lightning', 'courser'],
    'lightning rod': ['aegis', 'arm guard', 'backstop', 'buffer', 'bulwark', 'bumper', 'contraceptive', 'copyright', 'crash helmet', 'cushion', 'dashboard', 'dodger'],
    'lightproof': ['airtight', 'close', 'compact', 'dustproof', 'dusttight', 'fast', 'firm', 'gasproof', 'gastight', 'hermetic', 'hermetically sealed', 'lighttight'],
    'lights': ['arc', 'arc light', 'assumption', 'attitude', 'bellows', 'climate of opinion', 'color filter', 'common belief', 'community sentiment', 'conceit', 'concept', 'conception'],
    'lightsome': ['airy', 'blithe', 'breezy', 'buoyant', 'carefree', 'cheery', 'chirk', 'chirpy', 'chirrupy', 'clear', 'cloudless', 'corky'],
    'lightweight': ['boeotian', 'chinese boxer', 'milquetoast', 'a nobody', 'a nothing', 'baby', 'bantam', 'bantamweight', 'banty', 'big baby', 'black belt', 'block'],
    'likable': ['acceptable', 'admirable', 'adorable', 'affable', 'agreeable', 'ambrosial', 'amiable', 'amicable', 'angelic', 'appetizing', 'attractive', 'blissful'],
    'like': ['amor', 'christian love', 'eros', 'platonic love', 'admiration', 'admire', 'adoration', 'adore', 'adulate', 'affection', 'after this fashion', 'agape'],
    'like clockwork': ['always', 'at every turn', 'at regular intervals', 'at stated times', 'constantly', 'continually', 'easily', 'effortlessly', 'evenly', 'every so often', 'facilely', 'hands down'],
    'like mad': ['a corps perdu', 'all to pieces', 'carelessly', 'demonically', 'desperately', 'fanatically', 'fiercely', 'frantically', 'frenetically', 'furiously', 'happen what may', 'hastily'],
    'like minded': ['accordant', 'affirmative', 'agreeable', 'agreeing', 'akin', 'amicable', 'answerable', 'at one', 'at one with', 'attuned', 'carried by acclamation', 'coexistent'],
    'likelihood': ['aptitude', 'aptness', 'bare possibility', 'best bet', 'chance', 'conceivability', 'conceivableness', 'contingency', 'even chance', 'eventuality', 'expectation', 'expectations'],
    'likely': ['junoesque', 'a propos', 'able', 'acceptable', 'ad rem', 'adapted', 'advantageous', 'advisable', 'agreeable', 'amply endowed', 'applicable', 'apposite'],
    'likely to': ['answerable for', 'apt to', 'calculated to', 'capable of', 'dependent on', 'disposed to', 'exposed to', 'given to', 'in danger of', 'incident to', 'inclined to', 'liable to'],
    'liken': ['analogize', 'assimilate', 'balance', 'bring into analogy', 'bring into comparison', 'compare', 'compare and contrast', 'compare with', 'confront', 'contrast', 'counterpose', 'draw a comparison'],
    'likeness': ['abstract', 'abstraction', 'accordance', 'affinity', 'agreement', 'alikeness', 'alliance', 'ally', 'altarpiece', 'alter ego', 'analogon', 'analogousness'],
    'likewise': ['above', 'additionally', 'again', 'alike', 'all included', 'along', 'also', 'altogether', 'among other things', 'and all', 'and also', 'and so'],
    'liking': ['amor', 'christian love', 'eros', 'platonic love', 'a thing for', 'admiration', 'adoration', 'affection', 'affinity', 'agape', 'animus', 'appetence'],
    'lilliputian': ['tom thumb', 'brownie', 'dumpy', 'dwarf', 'dwarfed', 'dwarfish', 'elf', 'elfin', 'gnome', 'homunculus', 'incipient', 'manikin'],
    'lilt': ['alexandrine', 'brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'accent', 'accentuation', 'alba', 'amphibrach', 'amphimacer', 'anacrusis'],
    'lily livered': ['afraid', 'chicken', 'chickenhearted', 'coward', 'cowardly', 'cowed', 'craven', 'daunted', 'dismayed', 'fainthearted', 'fearful', 'funking'],
    'limb': ['ankle', 'appendage', 'arm', 'bank', 'bar', 'bayonet legs', 'beam', 'bine', 'board', 'boom', 'border', 'bordure'],
    'limber': ['adaptable', 'anemic', 'asthenic', 'bendable', 'bending', 'bloodless', 'chicken', 'compliant', 'cowardly', 'debilitated', 'drooping', 'droopy'],
    'limber up': ['cushion', 'ease', 'fluff', 'gentle', 'get ready', 'get set', 'knead', 'laxate', 'limber', 'loosen', 'mash', 'massage'],
    'limbo': ['abaddon', 'gehenna', 'hades', 'naraka', 'pandemonium', 'sheol', 'tophet', 'avichi', 'cage', 'coop', 'enclosure', 'hell'],
    'lime': ['acid', 'acidulant', 'allure', 'bait', 'bait the hook', 'birdlime', 'bola', 'bread-and-butter pickle', 'burden', 'catch', 'catch out', 'chokecherry'],
    'limelight': ['pr', 'arc', 'arc light', 'ballyhoo', 'blurb', 'bright light', 'celebrity', 'color filter', 'common knowledge', 'cry', 'currency', 'daylight'],
    'limen': ['affectibility', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bourn', 'break boundary', 'breakoff point', 'ceiling', 'circumscription', 'compass'],
    'limerick': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'limey': ['ab', 'ancient mariner', 'argonaut', 'aussie', 'boche', 'canuck', 'chink', 'dylan', 'flying dutchman', 'guinea', 'hunk', 'hunkie'],
    'limit': ['thule', 'ultima thule', 'abate', 'accommodation', 'acme', 'adjust to', 'all', 'alter', 'apex', 'apogee', 'appoint', 'area'],
    'limitation': ['absolute interest', 'allowance', 'benefit', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bounds', 'bourn', 'break boundary', 'breakoff point'],
    'limited': ['amtrak', 'lenten', 'spartan', 'abstemious', 'angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'ascetic', 'austere', 'authoritative', 'baggage train'],
    'limiting': ['altering', 'assuasive', 'bordering', 'borderline', 'boundary', 'bounding', 'caudal', 'claustral', 'coastal', 'conclusive', 'confining', 'cramping'],
    'limitless': ['a hog for', 'absolute', 'acquisitive', 'all-comprehensive', 'all-devouring', 'all-inclusive', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'avaricious'],
    'limits': ['boundaries', 'bounds', 'bourns', 'circumference', 'circumscription', 'compass', 'confines', 'coordinates', 'edges', 'fringes', 'limitations', 'marches'],
    'limn': ['bring to life', 'cartoon', 'catch a likeness', 'chalk', 'character', 'characterize', 'charcoal', 'chart', 'color', 'contour', 'copy', 'crayon'],
    'limp': ['amble', 'andante', 'anemic', 'asthenic', 'bagging', 'baggy', 'ballooning', 'barge', 'bloodless', 'bowl along', 'bundle', 'chicken'],
    'limpet': ['chilopoda', 'chordata', 'dungeness crab', 'echiuroidea', 'ectoprocta', 'entoprocta', 'japanese crab', 'monoplacophora', 'nemertinea', 'phoronidea', 'adherent', 'adhesive'],
    'limpid': ['attic', 'ciceronian', 'chaste', 'classic', 'clean-cut', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'coherent', 'connected', 'consistent'],
    'limping': ['ambling', 'bad', 'castrated', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'crippled', 'deliberate', 'disabled'],
    'line': ['dmz', 'indian file', 'mo', 'spenserian stanza', 'wats', 'wats line', 'zeitgeist', 'abut', 'accommodation', 'accompaniment', 'accord', 'accordance'],
    'line up': ['align', 'allocate', 'allot', 'apportion', 'arrange', 'array', 'bank', 'bill', 'book', 'budget', 'calendar', 'collimate'],
    'lineage': ['indian file', 'affiliation', 'aftermath', 'ancestry', 'animal kingdom', 'apparentation', 'array', 'articulation', 'bank', 'birth', 'blood', 'bloodline'],
    'lineal': ['after', 'arrowlike', 'attendant', 'cadet', 'catenary', 'clannish', 'consecutive', 'dead straight', 'diphyletic', 'direct', 'ensuing', 'ethnic'],
    'lineaments': ['air', 'angle', 'appearance', 'aroma', 'aspect', 'attribute', 'badge', 'bearing', 'border', 'brand', 'brow', 'cachet'],
    'linear': ['plimsoll line', 'plimsoll mark', 'arrowlike', 'catenary', 'consecutive', 'dead straight', 'direct', 'even', 'flat', 'high-water mark', 'horizontal', 'in a line'],
    'lined up': ['aligned', 'analogous', 'coextending', 'coextensive', 'collateral', 'concurrent', 'equal', 'equidistant', 'equispaced', 'even', 'nonconvergent', 'nondivergent'],
    'lineman': ['amateur athlete', 'archer', 'athlete', 'baggage man', 'bakehead', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'blocking back', 'bowman'],
    'linen': ['skivvies', 'afghan', 'apparel', 'array', 'attire', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedizenment', 'bedsheet', 'bedspread'],
    'liner': ['bush', 'bushing', 'doubling', 'doublure', 'facing', 'filler', 'filling', 'floating hotel', 'floating palace', 'inlay', 'inlayer', 'insole'],
    'lines': ['konzentrationslager', 'lager', 'mo', 'actor', 'air', 'algorithm', 'antagonist', 'antihero', 'approach', 'attack', 'back band', 'backstrap'],
    'lineup': ['agenda', 'approach', 'arrangement', 'array', 'attack', 'batting order', 'beadroll', 'bill', 'bill of fare', 'blueprint', 'blueprinting', 'budget'],
    'linger': ['abide', 'amble', 'await', 'bide', 'bide the issue', 'carry on', 'cease not', 'continue', 'crawl', 'creep', 'dally', 'dawdle'],
    'lingerer': ['clock watcher', 'dallier', 'dawdle', 'dawdler', 'diddler', 'dillydallier', 'do-nothing', 'dolittle', 'doodler', 'drone', 'faineant', 'foot-dragger'],
    'lingering': ['micawberish', 'backward', 'booming', 'continuation', 'dalliance', 'dallying', 'dawdling', 'delaying', 'dilatoriness', 'dilatory', 'dillydallying', 'dolce far niente'],
    'lingo': ['argot', 'cant', 'dialect', 'gibberish', 'gobbledygook', 'idiom', 'jargon', 'language', 'langue', 'lingua', 'locution', 'mumbo jumbo'],
    'lingual': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'linguist': ['bilingual', 'dialectician', 'diglot', 'etymologer', 'etymologist', 'glossarist', 'glossographer', 'grammarian', 'grammaticaster', 'grammatist', 'lexicographer', 'lexicologist'],
    'linguistic': ['answering', 'articulated', 'communicating', 'communicational', 'communional', 'conversational', 'descriptive', 'enunciated', 'glottochronological', 'grammatic', 'graphemic', 'interacting'],
    'linguistics': ['bowwow theory', 'comparative linguistics', 'derivation', 'descriptive linguistics', 'dialectology', 'dingdong theory', 'etymology', 'glossematics', 'glossology', 'glottochronology', 'glottology', 'grammar'],
    'lining': ['smyth sewing', 'backing', 'bibliopegy', 'binder board', 'binding', 'book cloth', 'book cover', 'book jacket', 'bookbinding', 'bookcase', 'burr', 'bush'],
    'link': ['accord', 'accouple', 'accumulate', 'addition', 'adjunct', 'affairs', 'affiliation', 'affinity', 'agent', 'agglutinate', 'alliance', 'ally'],
    'linkage': ['accord', 'addition', 'adjunct', 'affairs', 'affiliation', 'affinity', 'agglomeration', 'agglutination', 'aggregation', 'alliance', 'approximation', 'articulation'],
    'linked': ['affiliate', 'affiliated', 'allied', 'articulated', 'assembled', 'associate', 'associated', 'banded together', 'bound', 'bracketed', 'catenated', 'ceaseless'],
    'linotype': ['intertype', 'monotype', 'cold-type typesetting', 'composing', 'composing stick', 'composition', 'computerized typesetting', 'dummy', 'furniture', 'galley chase', 'hot-metal typesetting', 'imposition'],
    'lint': ['ace bandage', 'band-aid', 'adhesive tape', 'air pollution', 'application', 'attritus', 'band', 'bandage', 'bandaging', 'binder', 'brace', 'bran'],
    'lintel': ['french door', 'archway', 'back door', 'barway', 'bulkhead', 'carriage entrance', 'cellar door', 'cellarway', 'door', 'doorjamb', 'doorpost', 'doorway'],
    'lion': ['achilles', 'david', 'establishment', 'gibraltar', 'hector', 'leo', 'roland', 'samson', 'siberian tiger', 'vip', 'a man', 'achievement'],
    'lionhearted': ['bold', 'bold-spirited', 'brave', 'chivalric', 'chivalrous', 'courageous', 'dauntless', 'doughty', 'fearless', 'gallant', 'greathearted', 'hardy'],
    'lionize': ['adulate', 'aggrandize', 'apotheose', 'apotheosize', 'beatify', 'belaud', 'bepraise', 'bless', 'blow up', 'boast of', 'brag about', 'canonize'],
    'lip': ['aerophone', 'answer back', 'articulate', 'back talk', 'backchat', 'bagpipe', 'bank', 'bell', 'bilge', 'blain', 'bleb', 'blister'],
    'lip service': ['bomfog', 'pecksniffery', 'tartuffery', 'tartuffism', 'cant', 'empty gesture', 'false piety', 'formalism', 'hypocrisy', 'hypocriticalness', 'lip devotion', 'lip homage'],
    'lipid': ['animal oil', 'cerate', 'cholesterol', 'drying oil', 'essential oil', 'ester', 'fat', 'fatty oil', 'fixed oil', 'glyceride', 'grease', 'hydrogenated fat'],
    'lips': ['alveolar ridge', 'alveolus', 'apex', 'arytenoid cartilages', 'back', 'bag', 'ballocks', 'balls', 'basket', 'bazoo', 'beard', 'blade'],
    'lipstick': ['base', 'carmine', 'clown white', 'cold cream', 'compact', 'cosmetics', 'crimson', 'drugstore complexion', 'eye shadow', 'eyebrow pencil', 'foundation', 'foundation cream'],
    'liquefaction': ['chylifaction', 'chylification', 'flow', 'fluency', 'fluidity', 'fluidness', 'flux', 'fluxility', 'fluxion', 'juiciness', 'lactation', 'lactescence'],
    'liquefy': ['colliquate', 'cut', 'decoagulate', 'decoct', 'deliquesce', 'dissolve', 'fluidify', 'fluidize', 'flux', 'fuse', 'hold in solution', 'infuse'],
    'liquid': ['accented', 'alcoholic drink', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'aquatic', 'aqueous', 'articulated', 'articulation', 'aspiration'],
    'liquid assets': ['assessed valuation', 'assets', 'assets and liabilities', 'available funds', 'available means', 'balance', 'balance in hand', 'capital', 'capital goods', 'capitalization', 'cash', 'cash in hand'],
    'liquid oxygen': ['dry ice', 'freon', 'ammonia', 'carbon dioxide', 'charge', 'coolant', 'ether', 'ethyl chloride', 'exhaust', 'freezing mixture', 'fuel', 'ice'],
    'liquidate': ['abstract', 'amortize', 'annihilate', 'assassinate', 'bereave of life', 'break', 'bump off', 'bust', 'carry away', 'carry off', 'cash', 'cash in'],
    'liquidated': ['acquitted', 'banned', 'barred', 'debarred', 'deported', 'discharged', 'ejected', 'excluded', 'exiled', 'expelled', 'expended', 'hired'],
    'liquidation': ['abolishment', 'abolition', 'acquitment', 'acquittal', 'acquittance', 'agiotage', 'amortization', 'amortizement', 'annihilation', 'annulment', 'arbitrage', 'assassination'],
    'liquidator': ['accountant', 'auditor', 'bookkeeper', 'bursar', 'cashier', 'cashkeeper', 'chamberlain', 'compensator', 'comptroller', 'controller', 'curator', 'defrayer'],
    'liquor': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'john barleycorn', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill'],
    'lisp': ['aphonia', 'artificial voice', 'assibilate', 'assibilation', 'broken speech', 'broken tones', 'broken voice', 'buzz', 'childish treble', 'choked voice', 'cracked voice', 'croak'],
    'lisping': ['blurred', 'breathy', 'choked', 'choking', 'croaking', 'drawling', 'drawly', 'dysphonic', 'guttural', 'harsh', 'hawking', 'hoarse'],
    'lissome': ['adaptable', 'bendable', 'bending', 'compliant', 'ductile', 'elastic', 'extensible', 'extensile', 'fabricable', 'facile', 'fictile', 'flexible'],
    'list': ['mystik tape', 'scotch tape', 'account', 'adhesive tape', 'adjoin', 'alphabetize', 'analyze', 'angularity', 'annals', 'arena', 'arrange', 'ascend'],
    'list price': ['asking price', 'bargain price', 'bid', 'bid price', 'cash price', 'controlled price', 'current price', 'current quotation', 'cut price', 'fixed price', 'flat rate', 'going price'],
    'listen': ['nb', 'attend', 'attend to', 'auscultate', 'be all ears', 'bend an ear', 'bug', 'cock the ears', 'eavesdrop', 'examine by ear', 'give attention', 'give audience to'],
    'listen in': ['attend', 'attend to', 'auscultate', 'be all ears', 'bend an ear', 'bug', 'buzz', 'call', 'call up', 'cock the ears', 'dial', 'eavesdrop'],
    'listener': ['accepter', 'acquirer', 'addressee', 'audience', 'audient', 'audiophile', 'auditor', 'beholder', 'consignee', 'eavesdropper', 'getter', 'hearer'],
    'listening': ['all ears', 'attention', 'attentive', 'audibility', 'audience', 'audition', 'aural examination', 'aural sense', 'auscultation', 'bugging', 'conference', 'eager attention'],
    'listing': ['aslant', 'aslope', 'atilt', 'bevel', 'beveled', 'bias', 'biased', 'booking', 'canted', 'canting', 'careening', 'cataloging'],
    'listless': ['laodicean', 'olympian', 'aloof', 'anemic', 'apathetic', 'asthenic', 'ataractic', 'benumbed', 'blah', 'blase', 'bloodless', 'bored'],
    'listlessness': ['accidia', 'acedia', 'adynamia', 'aloofness', 'anemia', 'apathy', 'ataraxia', 'ataraxy', 'atony', 'benumbedness', 'blah', 'blah feeling'],
    'lit': ['ablaze', 'afflicted', 'aglow', 'alight', 'bathed with light', 'bent', 'bespangled', 'boiled', 'bombed', 'boozy', 'brightened', 'candlelit'],
    'litany': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'sefer torah', 'torah', 'torah scroll', 'virginal', 'agape', 'aid prayer'],
    'literacy': ['bibliolatry', 'bibliomania', 'bluestockingism', 'book learning', 'book madness', 'bookiness', 'bookishness', 'booklore', 'classical scholarship', 'classicism', 'culture', 'donnishness'],
    'literal': ['christian', 'abecedarian', 'accepted', 'allographic', 'alphabetic', 'approved', 'arid', 'authentic', 'authoritative', 'barren', 'basic', 'bona fide'],
    'literal meaning': ['affective meaning', 'bearing', 'coloring', 'connotation', 'consequence', 'denotation', 'drift', 'effect', 'essence', 'extension', 'force', 'gist'],
    'literal minded': ['arid', 'barren', 'dry', 'dull', 'earthbound', 'infecund', 'infertile', 'literal', 'mundane', 'prosaic', 'prosing', 'prosy'],
    'literally': ['absolutely', 'actually', 'closely', 'dead', 'definitely', 'direct', 'directly', 'even', 'exactly', 'expressly', 'faithfully', 'in all respects'],
    'literary': ['academic', 'belletristic', 'bibliophagic', 'bluestocking', 'book-fed', 'book-learned', 'book-loving', 'book-minded', 'book-read', 'book-wise', 'bookish', 'booky'],
    'literary style': ['affectation', 'command of language', 'exaggeration', 'expression of ideas', 'fashion', 'feeling for words', 'form of speech', 'grace of expression', 'grandiloquence', 'inflation', 'manner', 'manner of speaking'],
    'literate': ['brahmin', 'abstruse', 'brainworker', 'civilized', 'cultivated', 'cultured', 'deep', 'educated', 'egghead', 'encyclopedic', 'erudite', 'highbrow'],
    'literature': ['french literature', 'renaissance literature', 'ancient literature', 'article', 'autograph', 'belles lettres', 'belles-lettres', 'bibliography', 'body of knowledge', 'body of learning', 'brainchild', 'brochures'],
    'lithe': ['adaptable', 'bendable', 'bending', 'compliant', 'ductile', 'elastic', 'extensible', 'extensile', 'fabricable', 'facile', 'fictile', 'flexible'],
    'lithograph': ['aquatint', 'autolithograph', 'be a printmaker', 'block', 'block print', 'carve', 'character', 'chisel', 'chromolithograph', 'color print', 'copperplate', 'copperplate print'],
    'lithographer': ['burinist', 'carver', 'cerographer', 'chalcographer', 'engraver', 'etcher', 'gem engraver', 'graphic artist', 'graver', 'inscriber', 'lapidary', 'line engraver'],
    'lithography': ['albertype', 'artist lithography', 'book printing', 'chromotypography', 'chromotypy', 'chromoxylography', 'collotype', 'color printing', 'coloration', 'coloring', 'dyeing', 'electronography'],
    'litigant': ['accessory', 'accused', 'actionable', 'appellant', 'appellee', 'bitter-ender', 'brawler', 'causidical', 'defendant', 'diehard', 'disputant', 'dissentient'],
    'litigate': ['bring action against', 'bring into court', 'bring suit', 'bring to justice', 'bring to trial', 'drag into court', 'go into litigation', 'go to law', 'implead', 'law', 'prosecute', 'prosecute at law'],
    'litigation': ['kilkenny cats', 'action', 'altercation', 'apologetics', 'apologia', 'apology', 'argument', 'argumentation', 'bicker', 'bickering', 'case', 'casuistry'],
    'litigious': ['actionable', 'aggressive', 'argumental', 'argumentative', 'bellicose', 'belligerent', 'bickering', 'cat-and-dog', 'cat-and-doggish', 'causidical', 'combative', 'contentious'],
    'litter': ['air mattress', 'arsy-varsiness', 'be confined', 'bear', 'bear a child', 'bear young', 'bed', 'bed down', 'bedding', 'bedstead', 'bier', 'bolster'],
    'litterateur': ['academician', 'advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'bookman', 'classicist', 'clerk', 'coauthor'],
    'little': ['lilliputian', 'a bit', 'a breath', 'a little', 'abject', 'abominable', 'ace', 'arrant', 'atom', 'atrocious', 'authoritarian', 'baby'],
    'little by little': ['bit by bit', 'by degrees', 'by inches', 'by inchmeal', 'by slow degrees', 'by snatches', 'degreewise', 'drop by drop', 'foot by foot', 'gradatim', 'grade by grade', 'gradually'],
    'little fellow': ['cockney', 'everyman', 'john smith', 'a nobody', 'a nothing', 'average man', 'bairn', 'bourgeois', 'cherub', 'child', 'chit', 'cipher'],
    'little known': ['ignotus', 'inglorious', 'nameless', 'no credit to', 'obscure', 'renownless', 'uncelebrated', 'undistinguished', 'unfamed', 'unglorified', 'unheard-of', 'unhonored'],
    'little minded': ['authoritarian', 'bigot', 'bigoted', 'borne', 'closed', 'constricted', 'cramped', 'creedbound', 'deaf', 'deaf to reason', 'fanatical', 'hidebound'],
    'littleness': ['abjectness', 'abominableness', 'atrociousness', 'authoritarianism', 'baseness', 'beggarliness', 'bigotry', 'blind side', 'blind spot', 'blinders', 'brevity', 'briefness'],
    'littoral': ['aquatic', 'balneal', 'bank', 'beach', 'benthic zone', 'berm', 'bordering', 'borderline', 'boundary', 'bounding', 'coast', 'coastal'],
    'liturgic': ['high-church', 'alto', 'baptismal', 'baritone', 'bass', 'bravura', 'ceremonial', 'ceremonious', 'choral', 'choric', 'coloratura', 'conventional'],
    'liturgical': ['high-church', 'alto', 'baptismal', 'baritone', 'bass', 'bravura', 'ceremonial', 'ceremonious', 'choral', 'choric', 'coloratura', 'conventional'],
    'liturgy': ['mass', 'baccalaureate service', 'bedtime prayer', 'camp meeting', 'celebration', 'ceremonial', 'ceremony', 'church', 'church service', 'commencement', 'compline', 'convocation'],
    'live': ['be', 'abide', 'ablaze', 'aboveground', 'active', 'activist', 'activistic', 'actual', 'afire', 'aflame', 'aflicker', 'aglow'],
    'live down': ['atone', 'atone for', 'compensate', 'expiate', 'give satisfaction', 'make amends', 'make compensation', 'make good', 'make matters up', 'make reparation', 'make right', 'make up for'],
    'live on': ['abide', 'batten upon', 'bide', 'browse', 'carry on', 'continue', 'continue to be', 'continue to exist', 'crop', 'defeat time', 'defy time', 'dwell'],
    'live through': ['abide', 'bear up', 'beat the game', 'beat the system', 'bide', 'carry on', 'come through', 'come up fighting', 'come up smiling', 'continue', 'continue to be', 'defeat time'],
    'live up to': ['abide by', 'act up to', 'adhere to', 'attend to', 'be faithful to', 'comply with', 'conform to', 'do justice to', 'fill', 'follow', 'fulfill', 'heed'],
    'live wire': ['activist', 'ball of fire', 'beaver', 'big-time operator', 'bustler', 'busy bee', 'charge', 'doer', 'dynamo', 'eager beaver', 'electric charge', 'enthusiast'],
    'live with': ['abide with', 'accede', 'accept', 'acquiesce', 'assent', 'be agreeable', 'be big', 'be content with', 'be easy with', 'bear up', 'blink at', 'brook'],
    'lived in': ['comfortable', 'comfy', 'commodious', 'contented', 'convenient', 'cozy', 'cushioned', 'cushiony', 'cushy', 'easeful', 'easy', 'friendly'],
    'livelihood': ['tlc', 'alimentation', 'alimony', 'art', 'bread', 'bread and butter', 'care', 'craft', 'daily bread', 'economic support', 'emolument', 'endowment'],
    'liveliness': ['activity', 'adaptability', 'alacrity', 'animal spirits', 'animate existence', 'animation', 'anxiety', 'anxiousness', 'appetite', 'ardency', 'ardor', 'avidity'],
    'lively': ['ablaze', 'active', 'actively', 'activist', 'activistic', 'acute', 'adaptable', 'adaptive', 'afire', 'aggressive', 'agile', 'agog'],
    'liven': ['activate', 'animate', 'arouse', 'boost', 'brighten', 'buoy up', 'cheer', 'dynamize', 'electrify', 'encourage', 'energize', 'enliven'],
    'liver': ['abatis', 'abdomen', 'absorption', 'anus', 'appendix', 'assimilation', 'bile', 'blind gut', 'bowels', 'brain', 'brains', 'cecum'],
    'liveried': ['appareled', 'arrayed', 'attired', 'bedecked', 'breeched', 'capped', 'chausse', 'clad', 'cloaked', 'clothed', 'coifed', 'costumed'],
    'livery': ['accouterments', 'armory', 'badge', 'badge of office', 'badges', 'baton', 'blazonry', 'brassard', 'button', 'cap and gown', 'caparison', 'chain'],
    'livestock': ['animalia', 'and fish', 'animal kingdom', 'animal life', 'animality', 'beasts', 'beasts of field', 'beasts of prey', 'big game', 'birds', 'brute creation', 'cattle'],
    'livid': ['quaker-colored', 'achromatic', 'achromic', 'acier', 'amethystine', 'anemic', 'angered', 'angry', 'ashen', 'ashy', 'azure', 'azure-blue'],
    'living': ['tlc', 'abiding', 'ablaze', 'abode', 'aboveground', 'active', 'acute', 'advowson', 'afire', 'aflame', 'aflicker', 'aggressive'],
    'living being': ['aerobic organism', 'anaerobic organism', 'animal', 'autotrophic organism', 'beast', 'being', 'brute', 'creature', 'creeping thing', 'critter', 'dumb animal', 'dumb friend'],
    'living quarters': ['accommodations', 'assembly-line housing', 'berth', 'billeting', 'diggings', 'digs', 'domiciliation', 'doss', 'hospitality', 'housing', 'housing bill', 'housing development'],
    'llano': ['alkali flat', 'alluvial plain', 'basin', 'bottomland', 'bushveld', 'campo', 'champaign', 'champaign country', 'coastal plain', 'delta', 'desert', 'down'],
    'load': ['abundance', 'acres', 'adulterate', 'affliction', 'albatross', 'anxiety', 'bag', 'baggage', 'bags', 'bale', 'barrel', 'barrels'],
    'loaded': ['abounding in riches', 'afflicted', 'affluent', 'all ready', 'all set', 'armed', 'armed and ready', 'bent', 'big-rich', 'boiled', 'bombed', 'booted and spurred'],
    'loading': ['allocation', 'assignment', 'bale', 'bother', 'burden', 'burdening', 'burthen', 'cargo', 'charge', 'charging', 'collocation', 'cumber'],
    'loaf': ['communion', 'eucharist', 'holy communion', 'host', 'last supper', 'sacrament sunday', 'altar bread', 'batch', 'bean', 'block', 'brains', 'bread'],
    'loafer': ['arab', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'cadger', 'clock watcher', 'dallier', 'dawdle', 'dawdler'],
    'loan': ['wall street loan', 'accommodate with', 'accommodation', 'advance', 'allow', 'allowance', 'call loan', 'call money', 'collateral loan', 'credit', 'demand loan', 'external loan'],
    'loan shark': ['shylock', 'accommodate with', 'advance', 'banker', 'float a loan', 'lease-lend', 'lend', 'lend-lease', 'lender', 'loan', 'loan officer', 'loaner'],
    'loan sharking': ['cosa nostra', 'mafia', 'advance', 'advancement', 'advancing', 'black market', 'bootlegging', 'exploitation', 'extortion', 'gambling', 'gray market', 'highway robbery'],
    'loath': ['afraid', 'apathetic', 'averse', 'backward', 'balking', 'balky', 'dilatory', 'disinclined', 'grudging', 'hesitant', 'indifferent', 'indisposed'],
    'loathe': ['abhor', 'abominate', 'be hostile to', 'decline', 'despise', 'detest', 'disapprove of', 'disfavor', 'dislike', 'disrelish', 'execrate', 'hate'],
    'loathing': ['anglophobia', 'russophobia', 'abhorrence', 'abhorrent', 'abomination', 'allergy', 'antagonism', 'anti-semitism', 'antipathy', 'averse to', 'aversion', 'bigotry'],
    'loathsome': ['abhorrent', 'abominable', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'below contempt', 'beneath contempt', 'blameworthy', 'brutal', 'contemptible'],
    'lob': ['boost', 'bowl', 'buoy up', 'cast', 'cast up', 'catapult', 'chuck', 'chunk', 'dart', 'dash', 'elevate', 'erect'],
    'lobby': ['rasputin', 'svengali', 'vip', 'access', 'act on', 'advocate', 'approach', 'bad influence', 'bear upon', 'big wheel', 'blandish', 'cajole'],
    'lobbying': ['byzantine intrigues', 'allurement', 'backscratching', 'backstairs influence', 'blandishment', 'cajolement', 'cajolery', 'coaxing', 'connections', 'conning', 'deals', 'engagement'],
    'lobbyist': ['rasputin', 'svengali', 'vip', 'access', 'bad influence', 'big wheel', 'court', 'eminence grise', 'five-percenter', 'friend at court', 'good influence', 'gray eminence'],
    'lobe': ['eustachian tube', 'anvil', 'appendage', 'arachnoid', 'arbor vitae', 'archipallium', 'arm', 'auditory apparatus', 'auditory canal', 'auditory meatus', 'auditory nerve', 'auditory ossicles'],
    'lobotomy': ['amygdalotomy', 'ankylotomy', 'arteriotomy', 'blepharotomy', 'caesarean', 'cardiotomy', 'celiotomy', 'cholecystotomy', 'cirsotomy', 'coccygotomy', 'colpotomy', 'craniotomy'],
    'lobster': ['chilopoda', 'chordata', 'dungeness crab', 'echiuroidea', 'ectoprocta', 'entoprocta', 'japanese crab', 'monoplacophora', 'nemertinea', 'phoronidea', 'blue point', 'clam'],
    'local': ['amtrak', 'pullman', 'pullman car', 'aboriginal', 'aborigine', 'adjoining', 'affiliate', 'alehouse', 'arm', 'autochthon', 'baggage car', 'baggage train'],
    'local color': ['action', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'argument', 'atmosphere', 'background', 'catastrophe', 'characterization', 'color', 'complication'],
    'locale': ['abode', 'agora', 'amphitheater', 'area', 'arena', 'athletic field', 'auditorium', 'back', 'backdrop', 'background', 'bear garden', 'bearings'],
    'localism': ['acadian', 'anglo-indian', 'brooklynese', 'cajun', 'canadian french', 'cockney', 'french canadian', 'gullah', 'midland', 'midland dialect', 'new england dialect', 'pennsylvania dutch'],
    'locality': ['abode', 'area', 'bailiwick', 'bearings', 'belt', 'bench mark', 'district', 'domain', 'emplacement', 'field', 'habitat', 'haunt'],
    'localize': ['allocate', 'assign', 'box', 'box in', 'box up', 'circumscribe', 'collocate', 'confine', 'cramp', 'deploy', 'dispose', 'emplace'],
    'locate': ['allocate', 'anchor', 'assign', 'base', 'billet at', 'bivouac', 'burrow', 'camp', 'chance upon', 'collocate', 'colonize', 'come across'],
    'located': ['assigned', 'deployed', 'embosomed', 'emplaced', 'ensconced', 'established', 'fixed', 'installed', 'placed', 'planted', 'positioned', 'posted'],
    'locating': ['allocation', 'assignment', 'bringing to light', 'casual discovery', 'catching', 'chance discovery', 'collocation', 'deployment', 'deposit', 'deposition', 'detection', 'determination'],
    'location': ['allocation', 'arable land', 'assignment', 'barnyard', 'barton', 'bearings', 'bringing to light', 'case', 'casual discovery', 'catching', 'cattle ranch', 'chance discovery'],
    'loch': ['arm', 'armlet', 'artificial lake', 'bay', 'bayou', 'bayou lake', 'belt', 'bight', 'boca', 'cistern', 'cove', 'creek'],
    'loch ness monster': ['argus', 'briareus', 'cerberus', 'charybdis', 'cyclops', 'echidna', 'gorgon', 'harpy', 'hydra', 'medusa', 'minotaur', 'pegasus'],
    'lock': ['aboideau', 'accord', 'agree', 'air lock', 'answer to', 'articulate', 'assent', 'assort with', 'authority', 'bang', 'bar', 'barricade'],
    'lock in': ['bolt in', 'bottle up', 'cast in prison', 'clap in jail', 'clap up', 'cork up', 'gaol', 'hold captive', 'hold in', 'hold in captivity', 'hold prisoner', 'immure'],
    'lock out': ['ban', 'bang', 'bar', 'bar out', 'barricade', 'batten', 'batten down', 'blockade', 'bolt', 'boycott', 'button', 'button up'],
    'lock up': ['bang', 'bar', 'barricade', 'batten', 'batten down', 'bolt', 'bolt in', 'bosom', 'bottle up', 'bury', 'button', 'button up'],
    'locker': ['fort knox', 'archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box'],
    'locket': ['anklet', 'armlet', 'bangle', 'beads', 'bijou', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet', 'charm', 'chatelaine'],
    'lockjaw': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'acute articular rheumatism'],
    'lockout': ['arrest', 'ban', 'bar', 'barring', 'bell', 'blockade', 'boycott', 'boycottage', 'check', 'checkmate', 'circumscription', 'cutoff'],
    'lockup': ['pow camp', 'bastille', 'black hole', 'borstal', 'borstal institution', 'bridewell', 'brig', 'caging', 'calaboose', 'can', 'cell', 'check'],
    'loco': ['abnormal', 'bereft of reason', 'brainsick', 'crackbrained', 'cracked', 'crazed', 'crazy', 'daft', 'deluded', 'demented', 'deprived of reason', 'deranged'],
    'locomotion': ['commutation', 'course', 'crossing', 'globe-trotting', 'going', 'journeying', 'mobility', 'motility', 'motion', 'motive power', 'motivity', 'movableness'],
    'locomotive': ['aeromechanical', 'ambulant', 'ambulative', 'ambulatory', 'automechanical', 'automobile', 'automotive', 'biomechanical', 'circuit-riding', 'expeditionary', 'globe-girdling', 'globe-trotting'],
    'locus': ['abode', 'area', 'bearings', 'bench mark', 'district', 'emplacement', 'hole', 'latitude and longitude', 'lieu', 'locale', 'locality', 'location'],
    'locution': ['adjectival phrase', 'antonym', 'articulation', 'choice of words', 'clause', 'composition', 'construction', 'dialect', 'diction', 'expression', 'formulation', 'free form'],
    'lode': ['eldorado', 'golconda', 'bonanza', 'chimney', 'chute', 'cornucopia', 'country rock', 'deposit', 'dike', 'font', 'fount', 'fountain'],
    'lodestar': ['aldebaran', 'canicula', 'dog star', 'hesper', 'hesperus', 'lucifer', 'north star', 'phosphor', 'phosphorus', 'polaris', 'sirius', 'venus'],
    'lodestone': ['ambition', 'artificial magnet', 'bar magnet', 'catch', 'dearest wish', 'desideration', 'desideratum', 'desire', 'field magnet', 'forbidden fruit', 'glimmering goal', 'golden vision'],
    'lodge': ['dymaxion house', 'white house', 'abide', 'accept', 'accommodate', 'admit', 'adobe house', 'affiliate', 'arm', 'bank', 'bed', 'berth'],
    'lodger': ['board-and-roomer', 'boarder', 'hirer', 'homesteader', 'incumbent', 'leaseholder', 'lessee', 'occupant', 'occupier', 'paying guest', 'renter', 'resident'],
    'lodging': ['abiding', 'abiding place', 'abode', 'accommodations', 'address', 'apartment', 'assembly-line housing', 'berth', 'billeting', 'cantonment', 'cohabitation', 'commorancy'],
    'loess': ['alluvion', 'alluvium', 'ash', 'cinder', 'clinker', 'debris', 'deposit', 'deposition', 'deposits', 'detritus', 'diluvium', 'draff'],
    'loft': ['agency', 'atelier', 'attic', 'attic room', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'butcher shop', 'cockloft', 'company', 'concern'],
    'loftily': ['olympianly', 'aloofly', 'arrogantly', 'bombastically', 'condescendingly', 'contemptuously', 'contumeliously', 'disdainfully', 'flatulently', 'grandiloquently', 'grandiosely', 'grandly'],
    'lofty': ['gongoresque', 'johnsonian', 'olympian', 'aerial', 'affected', 'aggrandized', 'airy', 'altitudinous', 'ambitious', 'analytic', 'analytical', 'apotheosized'],
    'log': ['domesday book', 'mach meter', 'accelerometer', 'account book', 'accounts payable ledger', 'accounts receivable ledger', 'address book', 'adversaria', 'album', 'anemometer', 'annals', 'annual'],
    'logarithmic': ['algorismic', 'algorithmic', 'aliquot', 'cardinal', 'decimal', 'differential', 'digital', 'even', 'exponential', 'figural', 'figurate', 'figurative'],
    'loge': ['auditorium', 'balcony', 'box', 'box seat', 'dress circle', 'fauteuil', 'gallery', 'nigger heaven', 'orchestra', 'orchestra circle', 'paradise', 'parquet'],
    'logged': ['booked', 'documented', 'down', 'enrolled', 'entered', 'filed', 'indexed', 'inscribed', 'legal', 'minuted', 'of record', 'official'],
    'logging': ['christmas tree farming', 'afforestation', 'arboriculture', 'booking', 'cataloging', 'chronicling', 'enlistment', 'enrollment', 'entering', 'entry', 'forest management', 'forestation'],
    'logic': ['aristotelian logic', 'boolean algebra', 'ramistic logic', 'admissibility', 'aesthetics', 'algebra of classes', 'algebra of relations', 'axiology', 'casuistry', 'common sense', 'cosmology', 'deduction'],
    'logic chopping': ['bickering', 'boggling', 'captious', 'captiousness', 'caviling', 'chicane', 'chicanery', 'choplogic', 'dodging', 'equivocation', 'equivocatory', 'evasion'],
    'logical': ['admissible', 'authoritative', 'balanced', 'binding', 'cogent', 'coherent', 'commonsense', 'consistent', 'cool', 'coolheaded', 'credible', 'deductive'],
    'logistics': ['accouterment', 'action', 'amphibious operations', 'armament', 'catering', 'chandlery', 'combined operations', 'dry run', 'endowment', 'equipment', 'finding', 'fitting out'],
    'logjam': ['afterthought', 'arch dam', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier', 'bear-trap dam', 'beaver dam', 'bind', 'block'],
    'logogram': ['abuse of terms', 'acrostic', 'allegory', 'alphabet', 'amphibologism', 'amphiboly', 'anagram', 'arrowhead', 'art', 'blueprint', 'calembour', 'character'],
    'logomachy': ['kilkenny cats', 'altercation', 'apologetics', 'apologia', 'apology', 'argument', 'argumentation', 'bicker', 'bickering', 'blood feud', 'brawl', 'broil'],
    'logorrhea': ['abundance', 'amplitude', 'cloud of words', 'copiousness', 'diffuseness', 'diffusion', 'diffusiveness', 'effusion', 'effusiveness', 'extravagance', 'exuberance', 'fecundity'],
    'logotype': ['allegory', 'ascender', 'back', 'bastard type', 'beard', 'belly', 'bevel', 'billhead', 'black letter', 'body', 'book stamp', 'bookplate'],
    'logroller': ['machiavellian', 'behind-the-scenes operator', 'eminence grise', 'finagler', 'five-percenter', 'fixer', 'four-percenter', 'gamesman', 'gray eminence', 'influence peddler', 'kingmaker', 'machinator'],
    'logrolling': ['backscratching', 'barter', 'cloture', 'committee consideration', 'debate', 'deliberation', 'division', 'even trade', 'filibuster', 'filibustering', 'filing', 'first reading'],
    'logy': ['abeyant', 'apathetic', 'cataleptic', 'catatonic', 'dead', 'dopey', 'dormant', 'dull', 'flat', 'foul', 'groggy', 'heavy'],
    'loin': ['chateaubriand', 'back', 'blade roast', 'breast', 'brisket', 'chuck', 'chuck roast', 'clod', 'cold cuts', 'dorsal region', 'dorsum', 'filet mignon'],
    'loiter': ['abide', 'await', 'bide', 'bide the issue', 'bum', 'bum around', 'coquet', 'dabble', 'dally', 'dawdle', 'delay', 'diddle'],
    'loiterer': ['clock watcher', 'dallier', 'dawdle', 'dawdler', 'diddler', 'dillydallier', 'do-nothing', 'dolittle', 'doodler', 'drone', 'faineant', 'foot-dragger'],
    'loitering': ['micawberish', 'backward', 'coquetry', 'dabbling', 'dalliance', 'dallying', 'dawdling', 'delaying', 'dilatoriness', 'dilatory', 'dillydallying', 'dolce far niente'],
    'loki': ['aesir', 'aides', 'aidoneus', 'balder', 'bor', 'bori', 'bragi', 'cerberus', 'charon', 'cora', 'despoina', 'dis'],
    'loll': ['bed', 'bed down', 'bum', 'bum around', 'couch', 'crawl', 'curl up', 'diddle', 'do nothing', 'droop', 'go to bed', 'go to rest'],
    'lollapaloosa': ['ace', 'beaut', 'corker', 'crackerjack', 'daisy', 'dandy', 'darb', 'dilly', 'dream', 'honey', 'humdinger', 'killer-diller'],
    'lolling': ['accumbent', 'couchant', 'couche', 'crawling', 'dallying', 'dawdling', 'decumbent', 'dillydallying', 'dolce far niente', 'draped', 'flat', 'goofing off'],
    'lollygag': ['bill and coo', 'copulate', 'dally', 'dawdle', 'delay', 'diddle', 'dillydally', 'doodle', 'drag', 'falter', 'flag', 'goof off'],
    'lollygagging': ['amorous dalliance', 'billing and cooing', 'bundling', 'caressing', 'cuddling', 'dalliance', 'dallying', 'dawdling', 'delaying', 'dilatoriness', 'dilatory', 'dillydallying'],
    'lone': ['a certain', 'abandoned', 'absolute', 'alienated', 'all alone', 'alone', 'aloof', 'an', 'any', 'any one', 'apart', 'atomic'],
    'lone wolf': ['alien', 'careerist', 'case', 'character', 'crackpot', 'crank', 'eccentric', 'egotist', 'fanatic', 'fortune hunter', 'hermit', 'hobo'],
    'loneliness': ['alienation', 'aloneness', 'aloofness', 'celibacy', 'detachment', 'isolation', 'keeping apart', 'loneness', 'lonesomeness', 'moving apart', 'privacy', 'seclusion'],
    'lonely': ['abandoned', 'alienated', 'all alone', 'alone', 'aloof', 'apart', 'barren', 'companionless', 'deserted', 'desolate', 'detached', 'forsaken'],
    'loner': ['diogenes', 'hieronymian', 'hieronymite', 'timon of athens', 'alien', 'anchoress', 'anchorite', 'ascetic', 'bedridden invalid', 'careerist', 'case', 'character'],
    'lonesome': ['abandoned', 'alienated', 'all alone', 'alone', 'aloof', 'apart', 'companionless', 'deserted', 'detached', 'devious', 'estranged', 'forsaken'],
    'lonesomeness': ['alienation', 'aloneness', 'aloofness', 'celibacy', 'detachment', 'isolation', 'keeping apart', 'loneliness', 'loneness', 'moving apart', 'privacy', 'seclusion'],
    'long': ['a mile long', 'ache', 'ache for', 'ache to', 'aeon', 'age', 'ages', 'aim', 'and night', 'aspire', 'be dying for', 'be dying to'],
    'long ago': ['ages ago', 'anciently', 'and night', 'auld lang syne', 'away back', 'day after day', 'days beyond recall', 'days of old', 'days of yore', 'early', 'early times', 'eld'],
    'long distance': ['ddd', 'pbx operator', 'apart', 'asunder', 'at a distance', 'away', 'busy signal', 'buzz', 'call', 'central', 'dial tone', 'direct distance dialing'],
    'long established': ['acknowledged', 'admitted', 'chronic', 'confirmed', 'conventional', 'customary', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid', 'deep-rooted'],
    'long face': ['decorousness', 'demureness', 'earnestness', 'formality', 'frown', 'glower', 'gravity', 'grimace', 'grimness', 'lower', 'moue', 'mow'],
    'long faced': ['brooding', 'broody', 'chapfallen', 'crestfallen', 'decorous', 'demure', 'dumpish', 'earnest', 'formal', 'frowning', 'glum', 'grave'],
    'long lasting': ['abiding', 'age-long', 'aged', 'ancient', 'antique', 'chronic', 'constant', 'continuing', 'diuturnal', 'durable', 'enduring', 'evergreen'],
    'long lived': ['abiding', 'aboveground', 'age-long', 'aged', 'alive', 'alive and kicking', 'among the living', 'ancient', 'animate', 'animated', 'antique', 'breathing'],
    'long range': ['apart', 'aphelion', 'apogee', 'asunder', 'at a distance', 'away', 'distal', 'distant', 'exotic', 'far', 'far cry', 'far off'],
    'long shot': ['accident', 'adventure', 'bare possibility', 'boom shot', 'casualty', 'chance hit', 'close-up', 'contingency', 'contingent', 'dark horse', 'deuce shot', 'equivalent odds'],
    'long since': ['aeons ago', 'ages ago', 'anciently', 'and night', 'away back', 'day after day', 'early', 'enduringly', 'ever since', 'for an age', 'for life', 'for long'],
    'long standing': ['abiding', 'acknowledged', 'admitted', 'age-long', 'aged', 'ancient', 'antique', 'chronic', 'constant', 'continuing', 'conventional', 'customary'],
    'long suffering': ['spartan', 'acceptance', 'accepting', 'armed with patience', 'benevolence', 'benevolent', 'charitable', 'charitableness', 'charity', 'conciliatory', 'condonation', 'disciplined'],
    'long suit': ['ability', 'area', 'bag', 'bump', 'caliber', 'capability', 'capacity', 'cup of tea', 'dower', 'dowry', 'endowment', 'equipment'],
    'long term': ['abiding', 'age-long', 'aged', 'ancient', 'antique', 'chronic', 'constant', 'continuing', 'diuturnal', 'durable', 'enduring', 'evergreen'],
    'long time': ['aeon', 'age', 'ages', 'century', 'distance', 'eternity', 'extension', 'extent', 'infinity', 'length', 'lengthiness', 'linear measures'],
    'long winded': ['all jaw', 'blah', 'broken-record', 'candid', 'chatty', 'communicative', 'conversational', 'de longue haleine', 'drawn-out', 'drearisome', 'dreary', 'dry'],
    'longanimity': ['acceptance', 'benevolence', 'condonation', 'disregard', 'endurance', 'forbearance', 'forbearing', 'forbearingness', 'forgiveness', 'forgivingness', 'fortitude', 'indulgence'],
    'longevity': ['abidingness', 'advanced age', 'advanced years', 'age', 'age of retirement', 'an incurable disease', 'anility', 'animal spirits', 'animate existence', 'animation', 'antiquity', 'being alive'],
    'longhair': ['methuselah', 'antediluvian', 'antique', 'back number', 'conservative', 'dad', 'dodo', 'elder', 'fogy', 'fossil', 'fud', 'fuddy-duddy'],
    'longhand': ['italian hand', 'spencerian writing', 'autograph', 'autographic', 'block letter', 'bold hand', 'book hand', 'calligraphic', 'chancery hand', 'chirographic', 'copperplate hand', 'cursive'],
    'longing': ['heimweh', 'aching', 'craving', 'desiderium', 'desire', 'fancy', 'hankering', 'homesick', 'homesickness', 'honing', 'hunger', 'languishing'],
    'longitude': ['antarctic zone', 'arctic circle', 'arctic zone', 'cartesian coordinates', 'frigid zones', 'lambert conformal projection', 'mercator projection', 'miller projection', 'torrid zone', 'tropic of cancer', 'tropic of capricorn', 'variable zones'],
    'longsighted': ['acute', 'anticipant', 'anticipatory', 'apperceptive', 'appercipient', 'argute', 'asquint', 'astigmatic', 'astute', 'blink-eyed', 'blinking', 'blinky'],
    'loo': ['wc', 'backhouse', 'basement', 'bathroom', 'can', 'closet', 'comfort station', 'convenience', 'crapper', 'earth closet', 'head', 'john'],
    'looby': ['babbitt', 'boeotian', 'philistine', 'arriviste', 'block', 'blockhead', 'blunderer', 'blunderhead', 'boor', 'botcher', 'bounder', 'bourgeois'],
    'look': ['nb', 'admire', 'air', 'angle', 'angle for', 'animadvert', 'anticipate', 'appear', 'appear like', 'appearance', 'ask for', 'aspect'],
    'look after': ['administer to', 'attend', 'attend on', 'attend to', 'baby-sit', 'be vigilant', 'be watchful', 'care for', 'chaperon', 'cherish', 'chore', 'conserve'],
    'look around': ['beat the bushes', 'burrow', 'delve', 'dig', 'explore', 'forage', 'frisk', 'go through', 'hunt', 'look round', 'look through', 'nose around'],
    'look at': ['attend', 'autopsy', 'be disposed to', 'be vigilant', 'be watchful', 'canvass', 'check', 'check out', 'check over', 'check up on', 'consider', 'contemplate'],
    'look back': ['bring back', 'bring to mind', 'call back', 'call to mind', 'call up', 'conjure up', 'evoke', 'hark back', 'mind', 'recall', 'recall to mind', 'recapture'],
    'look down upon': ['be above', 'be contemptuous of', 'bestraddle', 'bestride', 'care nothing for', 'clear', 'command', 'contemn', 'deride', 'despise', 'disdain', 'disparage'],
    'look for': ['address', 'angle for', 'anticipate', 'approach', 'ask for', 'await', 'be destined', 'be fated', 'be imminent', 'be to be', 'be to come', 'beat about for'],
    'look forward to': ['anticipate', 'approach', 'await', 'be destined', 'be fated', 'be imminent', 'be to be', 'be to come', 'calculate on', 'come', 'come on', 'contemplate'],
    'look in': ['admit', 'barge in', 'be admitted', 'break in', 'breeze in', 'burst in', 'bust in', 'call', 'call on', 'call upon', 'come barging in', 'come breezing in'],
    'look like': ['ape', 'appear', 'appear like', 'approach', 'approximate', 'be like', 'be redolent of', 'bear resemblance', 'bring to mind', 'call to mind', 'call up', 'come close'],
    'look on': ['appear', 'assister', 'attend', 'be at', 'be present at', 'be vigilant', 'be watchful', 'behold', 'catch', 'catch sight of', 'clap eyes on', 'come to'],
    'look out': ['and listen', 'attend to business', 'be alert', 'be obsessed with', 'be vigilant', 'be watchful', 'beware', 'concentrate on', 'fix on', 'focus on', 'give heed', 'have a care'],
    'look over': ['autopsy', 'canvass', 'check', 'check out', 'check over', 'check up on', 'contemplate', 'examine', 'eye', 'face upon', 'front on', 'give an examination'],
    'look through': ['beat the bushes', 'burrow', 'delve', 'dig', 'examination', 'explore', 'forage', 'frisk', 'go through', 'hunt', 'inspection', 'look around'],
    'look to': ['advert to', 'attend to', 'baby-sit', 'be aware of', 'be engrossed in', 'bend to', 'bias', 'bring into play', 'calculate on', 'care for', 'chaperon', 'cherish'],
    'look up': ['advance', 'ameliorate', 'amend', 'angle for', 'ask for', 'beat about for', 'call', 'come along', 'come by', 'come on', 'come over', 'convalesce'],
    'look up to': ['accord respect to', 'admire', 'adore', 'apotheosize', 'appreciate', 'defer to', 'deify', 'entertain respect for', 'esteem', 'exalt', 'favor', 'hero-worship'],
    'looker': ['miss america', 'tv-viewer', 'accepter', 'acquirer', 'addressee', 'audience', 'auditor', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner'],
    'looking up': ['advancing', 'ameliorative', 'auspicious', 'bettering', 'bright with promise', 'cheering', 'encouraging', 'favorable', 'full of promise', 'improving', 'inspiring', 'inspiriting'],
    'lookout': ['argus', 'cassandra', 'charley', 'jeremiah', 'texas tower', 'activities', 'activity', 'admonisher', 'affair', 'affairs', 'airplane spotter', 'airscape'],
    'looks': ['air', 'bearing', 'brow', 'carriage', 'cast', 'cast of countenance', 'color', 'complexion', 'countenance', 'demeanor', 'face', 'facial appearance'],
    'loom': ['anticipate', 'appear', 'approach', 'arise', 'ascend', 'await', 'be destined', 'be fated', 'be imminent', 'be in store', 'be to be', 'be to come'],
    'loom large': ['appear', 'be evident', 'be noticeable', 'be revealed', 'be seen', 'be visible', 'bulk', 'bulk large', 'exceed', 'glare', 'loom', 'meet the gaze'],
    'looming': ['about to be', 'already in sight', 'approaching', 'at hand', 'brewing', 'close', 'close at hand', 'coming', 'fata morgana', 'forthcoming', 'future', 'gathering'],
    'loon': ['boeotian', 'aliene', 'bedlamite', 'block', 'borderline case', 'clod', 'crackbrain', 'crackpot', 'dement', 'demoniac', 'dimwit', 'dolt'],
    'loony': ['absurd', 'apish', 'asinine', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bedlamite', 'befooled', 'beguiled'],
    'loop': ['air hole', 'ambit', 'annular muscle', 'annulus', 'arc', 'arch', 'areola', 'armhole', 'association', 'aureole', 'band', 'bank'],
    'loophole': ['texas tower', 'abatis', 'advanced work', 'air hole', 'alternative', 'armhole', 'avenue', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican'],
    'loose': ['bohemian', 'paphian', 'abandoned', 'abate', 'absonant', 'adrift', 'affable', 'afloat', 'afoot and lighthearted', 'aid', 'aimless', 'aleatoric'],
    'loose ends': ['sisyphean labor', 'bad job', 'botch', 'bungling', 'endless task', 'failure', 'haphazardness', 'inexecution', 'messiness', 'neglect', 'nonaccomplishment', 'nonachievement'],
    'loose woman': ['jezebel', 'bad woman', 'baggage', 'bitch', 'broad', 'chippy', 'clitoromaniac', 'cocotte', 'drab', 'easy lay', 'easy woman', 'floozy'],
    'loosen': ['abate', 'bate', 'cast off', 'cushion', 'cut apart', 'detach', 'diffuse', 'discharge', 'disengage', 'disenthrall', 'disjoin', 'disperse'],
    'loosen up': ['amuse', 'beguile', 'beguile the time', 'convulse', 'delight', 'divert', 'drown care', 'ease off', 'enliven', 'entertain', 'exhilarate', 'fracture one'],
    'looseness': ['bohemianism', 'affability', 'allowance', 'amorphousness', 'approximation', 'bagginess', 'blobbiness', 'blowziness', 'blurriness', 'broadness', 'carelessness', 'casualness'],
    'loosening': ['abatement', 'allayment', 'alleviation', 'assuagement', 'blunting', 'calming', 'carelessness', 'damping', 'deadening', 'demulcent', 'demulsion', 'diminution'],
    'loosing': ['demobilization', 'discharge', 'dismissal', 'parole', 'release', 'unbinding', 'unbolting', 'unbridling', 'unbuckling', 'uncaging', 'unchaining', 'unfettering'],
    'loot': ['abduct', 'assault', 'attack', 'barbarize', 'batter', 'blackmail', 'boodle', 'booty', 'brutalize', 'burn', 'butcher', 'carry off'],
    'looter': ['depredator', 'despoiler', 'forager', 'forayer', 'freebooter', 'marauder', 'pillager', 'plunderer', 'raider', 'rapparee', 'ravager', 'ravisher'],
    'looting': ['assault', 'attack', 'banditry', 'battering', 'brigandage', 'brigandism', 'butchery', 'depredation', 'despoiling', 'despoilment', 'despoliation', 'direption'],
    'lop': ['abscind', 'amputate', 'annihilate', 'bag', 'bagging', 'baggy', 'ballooning', 'ban', 'bar', 'bob', 'bounce', 'bound'],
    'lope': ['amble', 'bound', 'burst', 'burst of speed', 'canter', 'caracole', 'curvet', 'dash', 'dead run', 'dogtrot', 'flank speed', 'flat-out speed'],
    'lopsided': ['anamorphous', 'askew', 'asymmetric', 'asymmetrical', 'awry', 'bent', 'biased', 'bowed', 'canted', 'cockeyed', 'contorted', 'crazy'],
    'loquacious': ['all jaw', 'candid', 'chatty', 'communicative', 'conversational', 'effusive', 'expansive', 'flip', 'fluent', 'frank', 'gabby', 'garrulous'],
    'loquacity': ['big mouth', 'candor', 'communicativeness', 'conversableness', 'effusion', 'effusiveness', 'flow of words', 'flowing tongue', 'fluency', 'fluent tongue', 'flux de bouche', 'flux de paroles'],
    'loran': ['gyrosin compass', 'rdf', 'var', 'astronavigation', 'celestial navigation', 'chronometer', 'coastwise navigation', 'compass', 'consolan', 'dead reckoning', 'direction finder', 'electronic navigation'],
    'lord': ['brahman', 'christ', 'god', 'god almighty', 'jehovah', 'jesus', 'affect', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet'],
    'lord it over': ['beat down', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'clamp down on', 'coerce', 'compel', 'cow', 'daunt', 'despotize'],
    'lordliness': ['arbitrariness', 'augustness', 'authoritarianism', 'authoritativeness', 'autocraticalness', 'bossism', 'courtliness', 'dignifiedness', 'dignity', 'domineering', 'domineeringness', 'elitism'],
    'lordly': ['absolute', 'absolutist', 'absolutistic', 'affected', 'arbitrary', 'aristocratic', 'arrogant', 'august', 'authoritarian', 'authoritative', 'autocratic', 'bossy'],
    'lordship': ['eminence', 'grace', 'her excellency', 'her highness', 'her ladyship', 'her majesty', 'highness', 'his lordship', 'his majesty', 'honor', 'imperial highness', 'imperial majesty'],
    'lore': ['lorelei', 'mishnah', 'spiritus mundi', 'sunna', 'talmud', 'ancient wisdom', 'archetypal myth', 'archetypal pattern', 'bibliography', 'body of knowledge', 'body of learning', 'charm'],
    'lorelei': ['circe', 'don juan', 'parthenope', 'siren', 'charmer', 'coquette', 'enchanter', 'enchantress', 'enticer', 'femme fatale', 'flirt', 'inveigler'],
    'lorgnette': ['polaroid glasses', 'bifocals', 'blinkers', 'cheaters', 'colored glasses', 'contact lens', 'dark glasses', 'divided spectacles', 'eyeglass', 'eyeglasses', 'glasses', 'goggles'],
    'lose': ['be bereaved of', 'be found wanting', 'be unsuccessful', 'bereave', 'bite the dust', 'bow', 'bow to', 'capitulate', 'clear', 'come to grief', 'consume', 'decline'],
    'lose ground': ['arrest', 'backpedal', 'backslide', 'backwater', 'be found wanting', 'brake', 'check', 'clip the wings', 'cock', 'collapse', 'come short', 'curb'],
    'lose heart': ['abandon hope', 'become suicidal', 'despair', 'despair of', 'despond', 'droop', 'falter', 'give up', 'give up hope', 'give way', 'hit rock bottom', 'languish'],
    'lose sight of': ['be caught napping', 'be neglectful', 'be negligent', 'default', 'disregard', 'draw a blank', 'fail', 'forget', 'gloss over', 'ignore', 'lapse', 'let go'],
    'loser': ['also-ran', 'bankrupt', 'bomb', 'booby', 'bummer', 'bust', 'clinker', 'con', 'defeatee', 'duck', 'dud', 'failure'],
    'loss': ['ablation', 'annihilation', 'attrition', 'bankruptcy', 'bereavement', 'breakage', 'breakdown', 'collapse', 'confusion', 'consumption', 'corrosion', 'crack-up'],
    'lost': ['abandoned', 'abashed', 'ablated', 'abroad', 'absent', 'absentminded', 'absorbed', 'abstracted', 'accursed', 'adrift', 'astray', 'at sea'],
    'lost in': ['absorbed', 'absorbed in', 'buried in', 'caught up in', 'contemplating', 'contemplative', 'devoted', 'devoted to', 'engaged', 'engrossed', 'engrossed in', 'immersed in'],
    'lost in thought': ['absent', 'absentminded', 'absorbed', 'abstracted', 'bemused', 'buried in thought', 'castle-building', 'daydreaming', 'daydreamy', 'dreaming', 'dreamy', 'drowsing'],
    'lost soul': ['backslider', 'bad egg', 'bad lot', 'black sheep', 'damned spirits', 'degenerate', 'demonkind', 'demons', 'denizens of hell', 'evil spirits', 'fallen angel', 'hellish host'],
    'lot': ['a to z', 'a to izzard', 'friday', 'friday the thirteenth', 'a mass of', 'a world of', 'abundance', 'accidentality', 'acres', 'actuarial calculation', 'adventitiousness', 'affluence'],
    'lothario': ['casanova', 'don juan', 'romeo', 'amoroso', 'beau', 'boyfriend', 'caballero', 'cavalier', 'cavaliere servente', 'debauchee', 'esquire', 'fellow'],
    'lotion': ['florida water', 'abstergent', 'after-shave lotion', 'balm', 'balsam', 'bay rum', 'brilliantine', 'cathartic', 'cerate', 'chrism', 'cleaner', 'cleaning agent'],
    'lotus eater': ['don quixote', 'quixote', 'clock watcher', 'dallier', 'dawdle', 'dawdler', 'daydreamer', 'diddler', 'dillydallier', 'do-nothing', 'dolittle', 'doodler'],
    'loud': ['aloud', 'blaring', 'blatant', 'blinding', 'booming', 'brassy', 'brazen', 'brazenfaced', 'chintzy', 'clamant', 'clamorous', 'coarse'],
    'loud and clear': ['clean-cut', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'coherent', 'connected', 'consistent', 'crisp', 'crystal-clear', 'crystalline', 'defined'],
    'loudly': ['aloud', 'clamantly', 'clamorously', 'deafeningly', 'demandingly', 'exactingly', 'exigently', 'exorbitantly', 'extortionately', 'firmly', 'forcefully', 'forcibly'],
    'loudmouthed': ['bawling', 'blatant', 'boanergean', 'boisterous', 'brawling', 'brazen-mouthed', 'clamorous', 'clamoursome', 'crying', 'full-throated', 'loud-voiced', 'multivocal'],
    'loudness': ['amplitude', 'arsenic green', 'auditory effect', 'auditory phenomenon', 'blatancy', 'brazenness', 'clashing colors', 'coarseness', 'color clash', 'colorfulness', 'crassness', 'crudeness'],
    'loudspeaker': ['acoustical network', 'capacitor speaker', 'coaxial speaker', 'cone', 'crossover network', 'diaphragm', 'dynamic speaker', 'earphone', 'electrodynamic speaker', 'electromagnetic speaker', 'electrostatic speaker', 'excited-field speaker'],
    'lounge': ['antechamber', 'anteroom', 'audience chamber', 'bar', 'barroom', 'bed', 'bed down', 'bum', 'bum around', 'cocktail lounge', 'couch', 'crawl'],
    'lounge lizard': ['beau brummel', 'barnacle', 'blood', 'bloodsucker', 'buck', 'coxcomb', 'dandy', 'dude', 'exquisite', 'fop', 'freeloader', 'hanger-on'],
    'lounger': ['clock watcher', 'dallier', 'dawdle', 'dawdler', 'diddler', 'dillydallier', 'do-nothing', 'dolittle', 'doodler', 'faineant', 'gentleman of leisure', 'goldbrick'],
    'lounging': ['accubation', 'accumbency', 'accumbent', 'couchant', 'couche', 'crawling', 'dallying', 'dawdling', 'decumbency', 'decumbent', 'dillydallying', 'dolce far niente'],
    'lour': ['abase', 'abash', 'abated', 'ablated', 'abridge', 'apprehend', 'approach', 'attenuated', 'await', 'bated', 'be imminent', 'be in store'],
    'louse': ['sob', 'bastard', 'bugger', 'cat flea', 'chigoe', 'cockroach', 'crab', 'creep', 'cur', 'dog', 'dog flea', 'fart'],
    'louse up': ['ball up', 'bitch', 'bitch up', 'blow', 'bobble', 'bollix', 'bollix up', 'bonehead into it', 'boot', 'bugger', 'bugger up', 'bungle'],
    'lousy': ['abominable', 'alive with', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beneath contempt', 'beset', 'blameworthy', 'brutal'],
    'lout': ['babbitt', 'philistine', 'arriviste', 'babe', 'blockhead', 'blunderer', 'blunderhead', 'boor', 'botcher', 'bounder', 'bourgeois', 'bucolic'],
    'loutish': ['all thumbs', 'awkward', 'blunderheaded', 'blundering', 'boorish', 'bumbling', 'bungling', 'butterfingered', 'caddish', 'callow', 'careless', 'carlish'],
    'louver': ['air duct', 'air hole', 'air passage', 'air shaft', 'air tube', 'airway', 'blowhole', 'breathing hole', 'louverwork', 'naris', 'nostril', 'shaft'],
    'lovable': ['acceptable', 'admirable', 'adorable', 'affectionate', 'agreeable', 'alluring', 'angelic', 'appealing', 'appetizing', 'attractive', 'bewitching', 'captivating'],
    'love': ['amor', 'aphrodite', 'astarte', 'bomfog', 'benthamism', 'christian charity', 'christian love', 'cupid', 'eros', 'freya', 'kama', 'venus'],
    'love affair': ['adulterous affair', 'adultery', 'affair', 'amour', 'cuckoldry', 'entanglement', 'eternal triangle', 'flirtation', 'forbidden love', 'hanky-panky', 'illicit love', 'infidelity'],
    'love letter': ['pastoral epistle', 'aerogram', 'air letter', 'airgraph', 'billet-doux', 'bull', 'chain letter', 'dead letter', 'dimissorial', 'dimissory letter', 'drop letter', 'encyclical'],
    'love nest': ['assignation', 'assignation house', 'blockhouse', 'box', 'bungalow', 'cabin', 'chalet', 'cot', 'cote', 'cottage', 'lodge', 'log cabin'],
    'love song': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'alba', 'anthem', 'art song', 'aubade', 'ballad', 'ballade', 'ballata'],
    'love story': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'apologue', 'bedtime story', 'detective story', 'fable', 'fabliau', 'fairy tale'],
    'loved': ['admired', 'adored', 'beloved', 'cherished', 'darling', 'dear', 'dearly beloved', 'esteemed', 'favorite', 'held dear', 'pet', 'popular'],
    'loveless': ['desireless', 'forsaken', 'inappetent', 'jilted', 'lovelorn', 'nirvanic', 'passionless', 'rejected', 'spurned', 'unambitious', 'unaspiring', 'unattracted'],
    'loveliness': ['adorability', 'agreeability', 'allurement', 'amiability', 'appeal', 'appealingness', 'attractiveness', 'beauteousness', 'beautifulness', 'beauty', 'beauty unadorned', 'bewitchment'],
    'lovelorn': ['adoring', 'affectionate', 'conjugal', 'demonstrative', 'devoted', 'faithful', 'filial', 'fond', 'forsaken', 'husbandly', 'jilted', 'languishing'],
    'lovely': ['admirable', 'adorable', 'aesthetic', 'aesthetically appealing', 'agreeable', 'alluring', 'angelic', 'appealing', 'attractive', 'beaut', 'beauteous', 'beautiful'],
    'lovemaking': ['amor', 'christian love', 'eros', 'platonic love', 'act of love', 'admiration', 'adoration', 'adultery', 'affection', 'agape', 'aphrodisia', 'ardency'],
    'lover': ['maecenas', 'abettor', 'acquaintance', 'addict', 'admirer', 'adorer', 'advocate', 'aficionado', 'alter ego', 'amorist', 'angel', 'apologist'],
    'lovesick': ['adoring', 'affectionate', 'conjugal', 'demonstrative', 'devoted', 'faithful', 'filial', 'fond', 'husbandly', 'languishing', 'lovelorn', 'lovesome'],
    'loving': ['christian', 'christlike', 'christly', 'adoring', 'affectionate', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'amatory', 'amorous'],
    'lovingly': ['adoringly', 'affectionately', 'amorously', 'ardently', 'assiduously', 'carefully', 'cautiously', 'circumspectly', 'considerately', 'dearly', 'devotedly', 'diligently'],
    'low': ['doric', 'hydromatic', 'a la sourdine', 'abject', 'abominable', 'accented', 'against', 'ailing', 'air mass', 'alveolar', 'anticyclone', 'apical'],
    'low class': ['mickey mouse', 'base', 'cheap', 'cheesy', 'coarse', 'common', 'fourth-class', 'inferior', 'irregular', 'low quality', 'low-grade', 'low-quality'],
    'low down': ['abject', 'abominable', 'arrant', 'atrocious', 'base', 'beggarly', 'cheesy', 'contemptible', 'crummy', 'debased', 'degraded', 'depraved'],
    'low grade': ['mickey mouse', 'base', 'cheap', 'cheesy', 'coarse', 'common', 'declasse', 'fourth-class', 'hack', 'inferior', 'irregular', 'low-class'],
    'low opinion': ['ban', 'blackball', 'blackballing', 'complaint', 'dim view', 'disagreement', 'disappointment', 'disapprobation', 'disapproval', 'discontent', 'discontentedness', 'discontentment'],
    'low price': ['bargain prices', 'budget prices', 'cut price', 'easy prices', 'economy prices', 'low tariff', 'manageable price', 'moderate price', 'nominal price', 'popular prices', 'reasonable charge', 'reasonable price'],
    'low priced': ['budget', 'cheap', 'easy', 'economic', 'economy', 'frugal', 'inexpensive', 'low', 'manageable', 'moderate', 'modest', 'nominal'],
    'low priority': ['immateriality', 'inconsequence', 'inconsequentiality', 'inconsiderableness', 'indifference', 'ineffectuality', 'inferior', 'inferiority', 'insignificance', 'irrelevance', 'littleness', 'marginal'],
    'low profile': ['blear', 'bleared', 'bleariness', 'bleary', 'blur', 'blurred', 'blurriness', 'blurry', 'confused', 'dark', 'darkness', 'defocus'],
    'low spirited': ['arid', 'barren', 'blah', 'blank', 'bloodless', 'blue', 'bowed-down', 'cast down', 'characterless', 'cold', 'colorless', 'dashed'],
    'low spirits': ['schmerz', 'slough of despond', 'blank despondency', 'death wish', 'dejectedness', 'dejection', 'depression', 'despair', 'despondency', 'despondentness', 'discouragement', 'disheartenment'],
    'low test': ['mickey mouse', 'base', 'cheap', 'cheesy', 'coarse', 'common', 'fourth-class', 'inferior', 'irregular', 'low-class', 'low-grade', 'low-quality'],
    'low tide': ['dead low water', 'direct tide', 'ebb', 'ebb and flow', 'ebb tide', 'flood', 'flood tide', 'flow', 'flux', 'flux and reflux', 'full tide', 'high tide'],
    'low voice': ['aspiration', 'bated breath', 'breath', 'breathy voice', 'exhalation', 'little voice', 'mumble', 'mumbling', 'murmur', 'murmuration', 'murmuring', 'mutter'],
    'lowbrow': ['gothic', 'philistine', 'barbarous', 'bookless', 'dabbler', 'deceived', 'dilettante', 'dunce', 'fool', 'functionally illiterate', 'grammarless', 'greenhorn'],
    'lower': ['abase', 'abash', 'abated', 'ablated', 'abridge', 'apprehend', 'approach', 'attenuated', 'await', 'bated', 'be imminent', 'be in store'],
    'lower case': ['abecedarian', 'allographic', 'alphabetic', 'ascender', 'back', 'bastard type', 'beard', 'belly', 'bevel', 'black letter', 'blackface', 'body'],
    'lower class': ['bourgeoisie', 'cog', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty', 'commoners', 'commons', 'creature', 'flunky'],
    'lower house': ['australia', 'barbados', 'belgium', 'chamber of deputies', 'chile', 'colombia', 'dominican republic', 'ecuador', 'ethiopia', 'fiji', 'france', 'house of commons'],
    'lowered': ['abated', 'ablated', 'attenuated', 'bated', 'belittled', 'bowed down', 'brought down', 'brought low', 'consumed', 'contracted', 'curtailed', 'debased'],
    'lowering': ['acheronian', 'acherontic', 'cimmerian', 'stygian', 'abatement', 'about to be', 'abridgment', 'abusive', 'alleviation', 'already in sight', 'apocalyptic', 'approaching'],
    'lowest': ['bedrock', 'best', 'bottom', 'bottommost', 'cut', 'down', 'earlier', 'few', 'giveaway', 'ground', 'half-price', 'homely'],
    'lowlands': ['agricultural region', 'alkali flat', 'alluvial plain', 'arable land', 'basin', 'black belt', 'bottomland', 'bushveld', 'campo', 'champaign', 'champaign country', 'citrus belt'],
    'lowlife': ['bowery bum', 'bastard', 'beachcomber', 'beggar', 'beggarly fellow', 'blackguard', 'blighter', 'budmash', 'bum', 'bummer', 'caitiff', 'derelict'],
    'lowly': ['base', 'baseborn', 'below the salt', 'cockney', 'common', 'commonplace', 'deferential', 'demeaning', 'despised', 'disadvantaged', 'disliked', 'everyday'],
    'lowness': ['schmerz', 'slough of despond', 'abjectness', 'abominableness', 'atrociousness', 'baseness', 'bassness', 'beggarliness', 'blank despondency', 'brevity', 'briefness', 'commonness'],
    'loyal': ['abandoned', 'acquiescent', 'active', 'afire', 'ardent', 'assiduous', 'burning', 'committed', 'compliant', 'complying', 'conforming', 'conscientious'],
    'loyalist': ['conservative', 'democrat', 'labourite', 'republican', 'tory', 'whig', 'heeler', 'partisan', 'party faithful', 'party hack', 'party man', 'party member'],
    'loyalty': ['abandon', 'acquiescence', 'adherence', 'adhesion', 'allegiance', 'application', 'ardency', 'ardor', 'assiduity', 'assiduousness', 'assigned task', 'attachment'],
    'lozenge': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'azure', 'bandeau', 'bar', 'bar sinister'],
    'lsd': ['det', 'dmt', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'diethyltryptamine', 'dimethyltryptamine', 'gage', 'ganja'],
    'lubber': ['blockhead', 'blunderer', 'blunderhead', 'boor', 'botcher', 'bumbler', 'bumpkin', 'bungler', 'clock watcher', 'clod', 'clodhopper', 'clodknocker'],
    'lubricate': ['aid', 'anoint', 'beeswax', 'buy', 'buy off', 'clear the way', 'dab', 'daub', 'drag', 'dress', 'dub', 'ease'],
    'lubricious': ['animal', 'aphrodisiomaniacal', 'bawdy', 'buttery', 'capricious', 'carnal', 'changeable', 'clitoromaniacal', 'concupiscent', 'dirty', 'erotic', 'eroticomaniacal'],
    'lucent': ['beaming', 'bright', 'brilliant', 'clear', 'clear-cut', 'crystal', 'effulgent', 'fulgent', 'incandescent', 'lambent', 'luminous', 'pellucid'],
    'lucid': ['attic', 'ciceronian', 'all there', 'apprehensible', 'balanced', 'beaming', 'bright', 'brilliant', 'chaste', 'classic', 'clean-cut', 'clear'],
    'lucidity': ['atticism', 'esp', 'admission of light', 'appropriateness', 'balance', 'chasteness', 'chastity', 'clairsentience', 'clairvoyance', 'clarity', 'classicalism', 'classicism'],
    'lucifer': ['aldebaran', 'apollyon', 'beelzebub', 'canicula', 'dog star', 'hesper', 'hesperus', 'his satanic majesty', 'north star', 'old nick', 'old scratch', 'phosphor'],
    'luck': ['accident', 'accidentality', 'actuarial calculation', 'adventitiousness', 'blessing', 'break', 'bump', 'calculated risk', 'capriciousness', 'casualness', 'chance', 'chances'],
    'luckless': ['badly off', 'depressed', 'dire', 'donsie', 'doomful', 'evil-starred', 'fatal', 'fortuneless', 'funest', 'hapless', 'ill off', 'ill-fated'],
    'lucky': ['advantageous', 'appropriate', 'auspicious', 'befitting', 'beneficial', 'benign', 'benignant', 'blessed', 'blessed with luck', 'bright', 'charmed', 'convenient'],
    'lucky piece': ['amulet', 'charm', 'fetish', 'fylfot', 'gammadion', 'good-luck charm', 'hoodoo', 'juju', 'love charm', 'lucky bean', 'madstone', 'mascot'],
    'lucrative': ['advantageous', 'banausic', 'breadwinning', 'compensating', 'compensative', 'compensatory', 'fat', 'gainful', 'good', 'moneymaking', 'paying', 'productive'],
    'lucre': ['affluence', 'and pence', 'assets', 'bottomless purse', 'bulging purse', 'capital gains', 'cash', 'circulating medium', 'cleanup', 'clear profit', 'coinage', 'coined liberty'],
    'lucubration': ['advisement', 'application', 'article', 'autograph', 'boning', 'brainchild', 'brainwork', 'brooding', 'causerie', 'composition', 'computer printout', 'conning'],
    'ludicrous': ['absurd', 'amusing', 'antic', 'beyond belief', 'bizarre', 'cockamamie', 'comic', 'comical', 'crazy', 'droll', 'eccentric', 'extravagant'],
    'lug': ['eustachian tube', 'anvil', 'auditory apparatus', 'auditory canal', 'auditory meatus', 'auditory nerve', 'auditory ossicles', 'auditory tube', 'auricle', 'basilar membrane', 'bear', 'bony labyrinth'],
    'luggage': ['gladstone', 'apparatus', 'attache case', 'backpack', 'bag', 'bag and baggage', 'baggage', 'bags', 'bandbox', 'belongings', 'briefcase', 'cargo'],
    'lugubrious': ['aggrieved', 'anguished', 'black', 'bleak', 'careworn', 'cheerless', 'depressant', 'depressing', 'dismal', 'dispiriting', 'doleful', 'dolorous'],
    'lukewarm': ['laodicean', 'aestival', 'apathetic', 'blood-hot', 'blood-warm', 'calid', 'chill', 'chilly', 'cold', 'cool', 'equatorial', 'fervorless'],
    'lull': ['abate', 'abeyance', 'allay', 'alleviate', 'anesthetize', 'anticyclone', 'appease', 'assuage', 'awful silence', 'balm', 'becalm', 'benumb'],
    'lullaby': ['schlummerlied', 'wiegenlied', 'anesthetic', 'berceuse', 'cradlesong', 'hypnotic', 'mandrake', 'morphia', 'morphine', 'nightcap', 'opiate', 'opium'],
    'lulling': ['abatement', 'allayment', 'alleviation', 'analgesia', 'anesthesia', 'anesthetizing', 'appeasement', 'appeasing', 'assuagement', 'blunting', 'calming', 'cradling'],
    'lulu': ['ace', 'beaut', 'corker', 'crackerjack', 'daisy', 'dandy', 'darb', 'dilly', 'dream', 'honey', 'humdinger', 'killer-diller'],
    'lumbago': ['abscess', 'adenoiditis', 'adrenitis', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa'],
    'lumber': ['amble', 'barge', 'be all thumbs', 'beam', 'beams', 'billet', 'blunder', 'blunder away', 'blunder into', 'blunder on', 'blunder upon', 'board'],
    'lumbering': ['christmas tree farming', 'latinate', 'afforestation', 'all thumbs', 'ambling', 'ambulation', 'arboriculture', 'awkward', 'backpacking', 'blunderheaded', 'blundering', 'bombastic'],
    'lumberyard': ['archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box', 'bunker'],
    'lumen': ['asa scale', 'british candle', 'hefner candle', 'scheiner scale', 'bougie decimale', 'candle', 'candle lumen', 'candle power', 'candle-foot', 'candle-hour', 'candle-meter', 'decimal candle'],
    'luminary': ['vip', 'actinic', 'big', 'big name', 'big-timer', 'candle', 'catoptric', 'celebrity', 'chief', 'constellation', 'cynosure', 'electric light bulb'],
    'luminescence': ['autoluminescence', 'bioluminescence', 'cathode luminescence', 'chemicoluminescence', 'chemiluminescence', 'corposant', 'crystalloluminescence', 'double corposant', 'electroluminescence', 'fata morgana', 'fluorescence', 'fox fire'],
    'luminous': ['ablaze', 'acute', 'aglow', 'alight', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'apprehensible', 'bathed with light', 'beaming'],
    'lummox': ['boor', 'bumpkin', 'butterfingers', 'clod', 'clodhopper', 'clumsy', 'dub', 'duffer', 'foozler', 'foul-up', 'fumble-fist', 'gawk'],
    'lump': ['abide', 'abide with', 'accumulation', 'acervation', 'agglomerate', 'agglomeration', 'aggregate', 'aggregation', 'allow', 'amassment', 'barrel', 'batch'],
    'lump together': ['accouple', 'accumulate', 'add', 'agglomerate', 'agglutinate', 'aggregate', 'aggroup', 'amalgamate', 'amass', 'articulate', 'assemble', 'assimilate'],
    'lumpen': ['abject', 'abominable', 'amorphic', 'amorphous', 'anarchic', 'arrant', 'at leisure', 'at liberty', 'at loose ends', 'atrocious', 'available', 'baggy'],
    'lumpen proletariat': ['beggar', 'bourgeoisie', 'bummer', 'cadger', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty', 'commoners', 'commons'],
    'lumpish': ['boeotian', 'all thumbs', 'apathetic', 'asinine', 'awkward', 'beef-brained', 'beef-witted', 'benumbed', 'blase', 'blockish', 'blunderheaded', 'blundering'],
    'lumpy': ['awkward', 'bulky', 'bumpy', 'caked', 'cakey', 'chunky', 'clabbered', 'clotted', 'clumsy', 'coagulated', 'congealed', 'crude'],
    'lunacy': ['aberration', 'abnormality', 'absurdity', 'alienation', 'asininity', 'battiness', 'brain damage', 'brainlessness', 'brainsickness', 'buffoonery', 'clouded mind', 'clownishness'],
    'lunar': ['cynthian', 's-shaped', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical', 'bicorn', 'celestial'],
    'lunar module': ['earth insertion', 'lem', 'lm', 'apogee', 'attitude-control rocket', 'ballistic capsule', 'burn', 'capsule', 'deep-space ship', 'docking', 'docking maneuver', 'ferry rocket'],
    'lunatic': ['abnormal', 'absurd', 'aliene', 'ass', 'balmy', 'batty', 'bedlamite', 'bereft of reason', 'borderline case', 'born fool', 'brainsick', 'buffoon'],
    'lunatic fringe': ['bolshevik', 'jacobin', 'wobbly', 'aficionado', 'anarchist', 'anarcho-syndicalist', 'buff', 'bug', 'crank', 'devotee', 'energumen', 'enthusiast'],
    'lunch': ['tv dinner', 'alfresco meal', 'barbecue', 'board', 'break bread with', 'breakfast', 'brunch', 'buffet supper', 'clambake', 'coffee break', 'cook out', 'cookout'],
    'lunch counter': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop'],
    'luncheon': ['tv dinner', 'alfresco meal', 'barbecue', 'breakfast', 'brunch', 'buffet supper', 'clambake', 'coffee break', 'cookout', 'diner', 'dinner', 'elevenses'],
    'lunchroom': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee'],
    'lung': ['abdomen', 'anus', 'appendix', 'bellows', 'blind gut', 'bowels', 'brain', 'cecum', 'colon', 'ctenidia', 'duodenum', 'endocardium'],
    'lunge': ['amble', 'barge', 'bound', 'bowl along', 'bundle', 'charge', 'clump', 'cut', 'cut and thrust', 'dash', 'dive', 'drag'],
    'lunkhead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'boob', 'booby', 'bufflehead', 'cabbagehead'],
    'lupine': ['all-devouring', 'all-engulfing', 'bloodsucking', 'canine', 'doggy', 'extortionate', 'foxlike', 'foxy', 'grabby', 'grasping', 'parasitic', 'predacious'],
    'lurch': ['abandon', 'amble', 'barge', 'bend', 'bent', 'bias', 'blunder', 'bob', 'bobble', 'bowl along', 'bumble', 'bundle'],
    'lurching': ['broken', 'capricious', 'careening', 'catchy', 'choppy', 'dangling', 'desultory', 'deviative', 'disconnected', 'discontinuous', 'eccentric', 'erratic'],
    'lure': ['adduct', 'adductor', 'allure', 'allurement', 'appeal', 'attract', 'attractant', 'attraction', 'attractiveness', 'attrahent', 'bag', 'bait'],
    'lurid': ['barnumesque', 'fescennine', 'gongoresque', 'johnsonian', 'rabelaisian', 'titian', 'titian-red', 'achromatic', 'achromic', 'affected', 'aglow', 'anemic'],
    'lurk': ['be latent', 'couch', 'creep', 'escape notice', 'gumshoe', 'hibernate', 'hide', 'lay wait', 'lie beneath', 'lie dormant', 'lie hid', 'lie in wait'],
    'lurking': ['abeyant', 'about to be', 'already in sight', 'approaching', 'at hand', 'between the lines', 'brewing', 'close', 'close at hand', 'coming', 'covert', 'cryptic'],
    'luscious': ['adorable', 'agreeable', 'ambrosial', 'appetizing', 'baroque', 'choice', 'cloying', 'dainty', 'darling', 'delectable', 'delicate', 'delicious'],
    'lush': ['abundant', 'adorable', 'adorned', 'agreeable', 'alcohol', 'ambrosial', 'befrilled', 'bibber', 'blooming', 'booze', 'boozehound', 'boozer'],
    'lust': ['acedia', 'ache', 'ache for', 'acquisitiveness', 'ambition', 'andromania', 'anger', 'animality', 'animus', 'aphrodisia', 'appetence', 'appetency'],
    'lust after': ['aim at', 'aspire after', 'be desirous of', 'be in heat', 'choose', 'come in', 'covet', 'crave', 'crave after', 'crawl after', 'desiderate', 'desire'],
    'luster': ['abundant year', 'academic year', 'afterglow', 'air glow', 'annum', 'aura', 'be bright', 'beacon', 'beam', 'bedazzle', 'bissextile year', 'blaze'],
    'lusterless': ['achromatic', 'achromic', 'anemic', 'ashen', 'ashy', 'bled white', 'blind', 'bloodless', 'cadaverous', 'chloranemic', 'colorless', 'dead'],
    'lustful': ['animal', 'aphrodisiomaniacal', 'appetitive', 'bawdy', 'burning', 'carnal', 'clitoromaniacal', 'concupiscent', 'desiderative', 'desireful', 'desiring', 'desirous'],
    'lustily': ['actively', 'aloud', 'animatedly', 'briskly', 'con brio', 'deafeningly', 'energetically', 'firmly', 'forcefully', 'forcibly', 'forte', 'fortemente'],
    'lustral': ['abstergent', 'apologetic', 'ascetic', 'atoning', 'cathartic', 'cleaning', 'cleansing', 'compensational', 'compensatory', 'depurative', 'detergent', 'diuretic'],
    'lustrous': ['aglow', 'beaming', 'beamy', 'blushing', 'bright', 'bright and sunny', 'brilliant', 'burning', 'burnished', 'candescent', 'charismatic', 'effulgent'],
    'lusty': ['active', 'acute', 'adipose', 'aggressive', 'animated', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'bouncing', 'brawny'],
    'lute': ['dobro guitar', 'f-hole guitar', 'spanish guitar', 'archlute', 'balalaika', 'banjo', 'banjo-uke', 'banjo-ukulele', 'banjo-zither', 'banjorine', 'banjuke', 'bass guitar'],
    'lux': ['asa scale', 'british candle', 'hefner candle', 'scheiner scale', 'bougie decimale', 'candle', 'candle lumen', 'candle power', 'candle-foot', 'candle-hour', 'candle-meter', 'decimal candle'],
    'luxuriant': ['abounding', 'abundant', 'adorned', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'arabesque', 'baroque', 'befrilled', 'blooming', 'bottomless'],
    'luxuriate': ['appreciate', 'bask', 'bask in', 'bud', 'burgeon', 'burst forth', 'delight in', 'eat up', 'enjoy', 'feast', 'fill', 'flood'],
    'luxuriate in': ['adore', 'appreciate', 'bask in', 'be pleased with', 'delight in', 'derive pleasure from', 'devour', 'eat up', 'enjoy', 'feast on', 'freak out on', 'get high on'],
    'luxurious': ['babylonian', 'corinthian', 'cyrenaic', 'abounding in riches', 'affluent', 'appealing', 'appetitive', 'arabesque', 'attractive', 'awe-inspiring', 'awful', 'barbaric'],
    'luxury': ['babylonian splendor', 'cyrenaic hedonism', 'cyrenaicism', 'easy street', 'affluence', 'amenity', 'amusement', 'animal pleasure', 'appeal', 'appealingness', 'appetite', 'appetitiveness'],
    'lyceum': ['gymnasium', 'latin school', 'realgymnasium', 'realschule', 'academy', 'amphitheater', 'arena', 'assembly hall', 'auditorium', 'chapel', 'concert hall', 'convention hall'],
    'lying': ['accubation', 'accumbency', 'accumbent', 'couchancy', 'couchant', 'couche', 'crawling', 'credibility gap', 'debasement', 'deceit', 'deceitful', 'deceptive'],
    'lymph': ['chyle', 'colostrum', 'discharge', 'gleet', 'humor', 'ichor', 'lachryma', 'lactation', 'leukorrhea', 'matter', 'milk', 'mucor'],
    'lynch': ['and quarter', 'annihilate', 'bereave of life', 'carry away', 'carry off', 'chloroform', 'cut down', 'cut off', 'deprive of life', 'destroy', 'dispatch', 'dispose of'],
    'lynch law': ['anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism', 'chaos', 'confusion', 'criminal syndicalism', 'disorder', 'disorderliness', 'disorganization', 'disruption', 'misrule'],
    'lynx': ['argus', 'leo', 'siberian tiger', 'bobcat', 'cat', 'cat-a-mountain', 'catamount', 'cheetah', 'cougar', 'eagle', 'ferret', 'hawk'],
    'lyric': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'lyrical': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'achingly sweet', 'agreeable', 'agreeable-sounding', 'alto'],
    'ma': ['dam', 'foster mother', 'genetrix', 'mam', 'mama', 'mammy', 'mater', 'materfamilias', 'maternal ancestor', 'matriarch', 'mom', 'mommy'],
    'mab': ['ariel', 'befind', 'corrigan', 'finnbeara', 'oberon', 'titania', 'banshee', 'brownie', 'cluricaune', 'dwarf', 'elf', 'fairy'],
    'macabre': ['appalling', 'astounding', 'awe-inspiring', 'awesome', 'awful', 'blue', 'cadaverous', 'corpselike', 'deadly', 'deathlike', 'deathly', 'deathly pale'],
    'macadam': ['tarmac', 'tarvia', 'asphalt', 'bitumen', 'bituminous macadam', 'blacktop', 'brick', 'cement', 'cobble', 'cobblestone', 'concrete', 'curb'],
    'macaroni': ['beau brummel', 'italian paste', 'beau', 'blade', 'blood', 'boulevardier', 'buck', 'clotheshorse', 'coxcomb', 'dandy', 'dude', 'dumpling'],
    'mace': ['armory', 'badge', 'badge of office', 'badges', 'bastinado', 'bat', 'baton', 'battering ram', 'billy', 'billy club', 'blackjack', 'blazonry'],
    'macerate': ['sanforize', 'agonize', 'attenuate', 'bathe', 'bloody', 'brew', 'chew', 'claw', 'consume', 'convulse', 'crucify', 'crush'],
    'machiavellian': ['artful dodger', 'byzantine', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellianist', 'machiavellic', 'actor', 'acute', 'ambidextrous', 'arch'],
    'machinate': ['angle', 'brew', 'cabal', 'cogitate', 'collude', 'complot', 'concoct', 'connive', 'conspire', 'contrive', 'cook up', 'countermine'],
    'machination': ['artifice', 'behind-the-scenes influence', 'cabal', 'chicane', 'chicanery', 'collusion', 'complicity', 'complot', 'confederacy', 'connivance', 'connivery', 'conspiracy'],
    'machinator': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'machiavellian', 'quisling', 'archtraitor', 'behind-the-scenes operator', 'betrayer', 'calculator', 'cockatrice', 'coconspirator'],
    'machine': ['american party', 'anti-monopoly party', 'bull moose party', 'bund', 'communist party', 'composaline', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'diatype', 'ditto'],
    'machine made': ['assembled', 'built', 'cast', 'constructed', 'crafted', 'created', 'custom', 'custom-built', 'custom-made', 'extracted', 'fabricated', 'fashioned'],
    'machinery': ['accouterments', 'action', 'adding machine', 'addressing machine', 'agency', 'agent', 'all-crop harvester', 'apparatus', 'appliance', 'appliances', 'appointments', 'appurtenances'],
    'macrobiotic': ['abiding', 'age-long', 'aged', 'ancient', 'antique', 'chronic', 'constant', 'continuing', 'diuturnal', 'durable', 'enduring', 'evergreen'],
    'macrocosm': ['copernican universe', 'einsteinian universe', 'newtonian universe', 'ptolemaic universe', 'all', 'all being', 'all creation', 'allness', 'cosmos', 'created nature', 'created universe', 'creation'],
    'maculate': ['besmirched', 'bespangled', 'bespeckled', 'blotched', 'blotchy', 'defiled', 'dotted', 'dotty', 'flea-bitten', 'flecked', 'fleckered', 'frecked'],
    'mad': ['dionysiac', 'a transient madness', 'abandoned', 'abnormal', 'absurd', 'accident-prone', 'acrimonious', 'affronted', 'amok', 'anarchic', 'anger', 'angered'],
    'mad about': ['ape about', 'attached to', 'bugs on', 'cracked on', 'crazy about', 'devoted to', 'enamored of', 'far gone on', 'fond of', 'freaked-out', 'gaga over', 'gone on'],
    'mad dog': ['mafioso', 'young turk', 'beast', 'beldam', 'berserk', 'berserker', 'bomber', 'bravo', 'brute', 'bucko', 'bully', 'bullyboy'],
    'madam': ['frau', 'fraulein', 'miss', 'mistress', 'mlle', 'mme', 'mmes', 'abbess', 'bawd', 'chatelaine', 'dame', 'dona'],
    'madame': ['frau', 'fraulein', 'miss', 'mistress', 'mlle', 'mme', 'mmes', 'dame', 'dona', 'donna', 'lady', 'madam'],
    'madcap': ['mafioso', 'young turk', 'adventurer', 'adventuress', 'adventurous', 'ardent', 'audacious', 'banana', 'beast', 'beldam', 'berserk', 'berserker'],
    'madden': ['aggravate', 'alienate', 'anger', 'annoy', 'antagonize', 'arouse', 'awake', 'awaken', 'badger', 'bait', 'bedevil', 'blow the coals'],
    'maddening': ['agitating', 'breathtaking', 'charged', 'cliff-hanging', 'disquieting', 'distracting', 'disturbing', 'electric', 'exciting', 'exhilarating', 'galvanic', 'heady'],
    'made': ['assembled', 'assured of success', 'brought about', 'built', 'cast', 'caused', 'coming', 'constructed', 'crafted', 'created', 'crowned with success', 'custom'],
    'made up': ['coined', 'conceived', 'concocted', 'cooked-up', 'discovered', 'fabricated', 'fabulous', 'fancied', 'fantasied', 'fantastic', 'fictional', 'fictitious'],
    'mademoiselle': ['frau', 'fraulein', 'miss', 'mistress', 'mlle', 'mme', 'mmes', 'babe', 'baby', 'broad', 'chick', 'colleen'],
    'madly': ['a corps perdu', 'absurdly', 'all to pieces', 'angrily', 'ardently', 'carelessly', 'crazily', 'deliriously', 'demonically', 'desperately', 'distractedly', 'energetically'],
    'madman': ['aliene', 'ass', 'bedlamite', 'borderline case', 'crackbrain', 'crackpot', 'dement', 'demoniac', 'donkey', 'energumen', 'fanatic', 'flake'],
    'madness': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'abandon', 'aberration', 'abnormality', 'acute articular rheumatism', 'ague', 'alienation', 'alkali disease'],
    'madonna': ['dei mater', 'deipara', 'holy mary', 'immaculate conception', 'mariolatry', 'mariology', 'mother of god', 'notre dame', 'our lady', 'queen of angels', 'queen of heaven', 'regina angelorum'],
    'madrigal': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'mae west': ['breeches buoy', 'buoy', 'cork jacket', 'ejection capsule', 'ejection seat', 'ejector seat', 'life belt', 'life buoy', 'life jacket', 'life net', 'life preserver', 'life raft'],
    'maelstrom': ['charybdis', 'ado', 'agitation', 'back stream', 'backflow', 'backwash', 'backwater', 'bluster', 'bobbery', 'boil', 'boiling', 'bother'],
    'maestro': ['abecedarian', 'artist', 'artiste', 'certified teacher', 'concert artist', 'docent', 'doctor', 'dominie', 'don', 'educationist', 'educator', 'executant'],
    'maffick': ['be noisy', 'beat the drum', 'blow the trumpet', 'brawl', 'carry on', 'celebrate', 'chirm', 'clamor', 'clangor', 'commemorate', 'cut up', 'cut up rough'],
    'mafia': ['black hand', 'cosa nostra', 'black market', 'bootlegging', 'gambling', 'gangdom', 'gangland', 'gray market', 'illegal commerce', 'illegal operations', 'illegitimate business', 'illicit business'],
    'mafioso': ['young turk', 'beast', 'beldam', 'berserk', 'berserker', 'black marketeer', 'bomber', 'bootlegger', 'brute', 'dealer', 'demon', 'devil'],
    'magazine': ['ammo dump', 'annual', 'archives', 'armory', 'arsenal', 'artillery park', 'atomic arsenal', 'attic', 'bank', 'basement', 'bay', 'bimonthly'],
    'magenta': ['amethystine', 'lavender', 'lilac', 'livid', 'mauve', 'mulberry', 'orchid', 'pansy-purple', 'plum-colored', 'plum-purple', 'purple', 'purplescent'],
    'maggot': ['alabaster', 'apparition', 'arachnid', 'arthropod', 'aurelia', 'bee', 'beetle', 'boutade', 'brainchild', 'brainstorm', 'bubble', 'bug'],
    'maggoty': ['gothic', 'abnormal', 'anomalous', 'arbitrary', 'bad', 'barfy', 'baroque', 'bizarre', 'blasted', 'blighted', 'blown', 'brackish'],
    'magic': ['prospero', 'abracadabra', 'airiness', 'alchemy', 'allure', 'allurement', 'appearance', 'augury', 'aura', 'bewitchery', 'bewitching', 'bewitchment'],
    'magical': ['bewitched', 'bright', 'brilliant', 'cantrip', 'charismatic', 'enchanted', 'glamorous', 'glorious', 'hoodoo', 'illustrious', 'incantational', 'incantatory'],
    'magically': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'conspicuously', 'copiously', 'eminently', 'emphatically', 'exceptionally', 'exquisitely'],
    'magician': ['circe', 'merlin', 'prospero', 'ace', 'airiness', 'appearance', 'artist', 'artiste', 'belly dancer', 'burlesque queen', 'charmer', 'chorine'],
    'magisterial': ['daedalian', 'absolute', 'absolutist', 'absolutistic', 'accepted', 'adept', 'adroit', 'approved', 'apt', 'arbitrary', 'arch', 'aristocratic'],
    'magistracy': ['kreis', 'aedileship', 'archbishopric', 'archdiocese', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'arrondissement', 'bailiwick', 'bishopric', 'borough', 'canton'],
    'magistrate': ['jp', 'justice', 'alderman', 'arbiter', 'arbitrator', 'archon', 'bailie', 'beak', 'bencher', 'burghermaster', 'burgomaster', 'cabinet member'],
    'magnanimity': ['ambition', 'ambitiousness', 'benevolence', 'bigheartedness', 'bigness', 'bounteousness', 'bountifulness', 'bounty', 'careerism', 'charitableness', 'charity', 'chivalrousness'],
    'magnanimous': ['altruistic', 'august', 'benevolent', 'big', 'bighearted', 'bounteous', 'bountiful', 'charitable', 'chivalrous', 'conciliatory', 'considerate', 'distinguished'],
    'magnanimously': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'bigheartedly', 'chivalrously', 'conspicuously', 'copiously', 'eminently', 'emphatically'],
    'magnate': ['brahman', 'establishment', 'vip', 'archduke', 'aristocrat', 'armiger', 'banker', 'baron', 'baronet', 'big boss', 'big businessman', 'big gun'],
    'magnet': ['ambition', 'artificial magnet', 'bar magnet', 'catch', 'center of attraction', 'center of consciousness', 'center of interest', 'cynosure', 'dearest wish', 'desideration', 'desideratum', 'desire'],
    'magnetic': ['absorbing', 'adductive', 'alluring', 'appealing', 'arresting', 'attracting', 'attractive', 'attrahent', 'authoritative', 'beguiling', 'bewitching', 'captivating'],
    'magnetic tape': ['flexowriter typewriter', 'teleplotter', 'alphabetical printer', 'bulletin board', 'card', 'catalog card', 'digital graph plotter', 'disc', 'file', 'filing card', 'film', 'hard copy'],
    'magnetism': ['acceptability', 'adduction', 'affinity', 'agacerie', 'agreeability', 'allure', 'allurement', 'appeal', 'ascendancy', 'attractance', 'attraction', 'attractiveness'],
    'magnetize': ['act on', 'adduct', 'allure', 'anesthetize', 'approach', 'attract', 'be magnetic', 'bear upon', 'bewitch', 'captivate', 'charm', 'degauss'],
    'magnification': ['accelerando', 'acceleration', 'accolade', 'addition', 'adjunct', 'adulation', 'aggrandizement', 'aggravation', 'ampliation', 'amplification', 'annoyance', 'apotheosis'],
    'magnificence': ['babylonian splendor', 'brilliance', 'elaborateness', 'elegance', 'exquisiteness', 'glory', 'gorgeousness', 'grandeur', 'grandiosity', 'grandness', 'imposingness', 'impressiveness'],
    'magnificent': ['babylonian', 'corinthian', 'august', 'awe-inspiring', 'awful', 'barbaric', 'brilliant', 'commanding', 'deluxe', 'distinguished', 'divine', 'elaborate'],
    'magnificently': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'conspicuously', 'copiously', 'divinely', 'elaborately', 'elegantly', 'eminently'],
    'magnified': ['accelerated', 'aggrandized', 'aggravated', 'amplified', 'annoyed', 'apotheosized', 'augmented', 'awesome', 'ballyhooed', 'beatified', 'beefed-up', 'big'],
    'magnifier': ['achromatic lens', 'astigmatic lens', 'burning glass', 'camera', 'coated lens', 'concave lens', 'concavo-convex lens', 'condenser', 'convex lens', 'eyeglass', 'eyepiece', 'glass'],
    'magnify': ['accelerate', 'add to', 'adulate', 'agent provocateur', 'aggrandize', 'aggravate', 'amplify', 'annoy', 'apotheose', 'apotheosize', 'augment', 'ballyhoo'],
    'magnifying glass': ['achromatic lens', 'astigmatic lens', 'burning glass', 'camera', 'coated lens', 'concave lens', 'concavo-convex lens', 'condenser', 'convex lens', 'eyeglass', 'eyepiece', 'glass'],
    'magnitude': ['beehive', 'cepheid variable', 'hertzsprung-russell diagram', 'hyades', 'messier catalog', 'ngc', 'pleiades', 'seven sisters', 'absolute magnitude', 'amount', 'ampleness', 'amplitude'],
    'magpie': ['audubon warbler', 'canada goose', 'english sparrow', 'accumulator', 'adjutant bird', 'agreeable rattle', 'albatross', 'all sorts', 'argala', 'assemblage', 'assortment', 'auk'],
    'maharani': ['kaiserin', 'begum', 'crown princess', 'czarina', 'empress', 'grand duchess', 'infanta', 'kumari', 'kunwari', 'malikzadi', 'princess', 'princesse'],
    'mahatma': ['ace', 'adept', 'angel', 'anthroposophist', 'authority', 'cabalist', 'crackerjack', 'doctor', 'elder', 'elder statesman', 'esoteric', 'first-rater'],
    'maid': ['abigail', 'amah', 'au pair girl', 'ayah', 'babe', 'baby', 'bachelor girl', 'betweenmaid', 'biddy', 'broad', 'chambermaid', 'chaperon'],
    'maiden': ['ax', 'babe', 'baby', 'bachelor girl', 'bachelorlike', 'beardless', 'block', 'boyish', 'boylike', 'broad', 'calflike', 'callow'],
    'maiden speech': ['coming out', 'curtain raiser', 'debut', 'embarkation', 'embarkment', 'first appearance', 'floating', 'flotation', 'inaugural address', 'inauguration', 'induction', 'initiation'],
    'maidenhead': ['platonic love', 'abstinence', 'allantoic membrane', 'amnion', 'amniotic sac', 'arachnoid membrane', 'bachelordom', 'bachelorhood', 'bachelorism', 'bachelorship', 'basement membrane', 'boyhood'],
    'maidenly': ['platonic', 'abstinent', 'bachelorlike', 'beardless', 'boyish', 'boylike', 'calflike', 'callow', 'celibate', 'childish', 'childlike', 'coltish'],
    'mail': ['pp', 'rd', 'rfd', 'air-express', 'airfreight', 'airmail', 'armature', 'armor', 'armor plate', 'body armor', 'book post', 'buckler'],
    'mail coach': ['autobus', 'bus', 'cab', 'carrier', 'carrier pigeon', 'chartered bus', 'diligence', 'double-decker', 'hack', 'hired car', 'homer', 'homing pigeon'],
    'mail order house': ['boutique', 'chain store', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dime store', 'discount house', 'discount store', 'emporium'],
    'mailing list': ['pp', 'rd', 'rfd', 'airmail', 'book post', 'correspondence', 'direct mail', 'direct-mail selling', 'express', 'fourth-class mail', 'frank', 'halfpenny post'],
    'maim': ['abrade', 'bark', 'batter', 'blemish', 'bloody', 'break', 'bugger', 'bung up', 'burn', 'castrate', 'chafe', 'check'],
    'maiming': ['bankruptcy', 'breakage', 'breakdown', 'castration', 'collapse', 'crack-up', 'crippling', 'damage', 'demasculinization', 'destruction', 'detriment', 'dilapidation'],
    'main': ['africa', 'antarctica', 'asia', 'australia', 'eurasia', 'eurasian landmass', 'europe', 'north america', 'south america', 'absolute', 'all-absorbing', 'arch'],
    'main drag': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'main line': ['branch', 'cable railway', 'cog railway', 'el', 'electric railway', 'elevated', 'elevated railway', 'embankment', 'feeder', 'feeder line', 'gravity-operated railway', 'horse railway'],
    'main office': ['cp', 'ghq', 'hq', 'base', 'base of operations', 'booking office', 'box office', 'branch', 'branch office', 'cabinet', 'center of authority', 'central administration'],
    'main point': ['basis', 'bench mark', 'burden', 'cardinal point', 'case', 'chapter', 'chief thing', 'climax', 'concern', 'core', 'cornerstone', 'crisis'],
    'mainlining': ['antitoxin', 'bag', 'bang', 'booster', 'booster dose', 'booster shot', 'deck', 'dose', 'draft', 'dropping', 'drug packet', 'fix'],
    'mainly': ['a fortiori', 'ab initio', 'ab ovo', 'aborigine', 'above all', 'all in all', 'all the more', 'all things considered', 'almost entirely', 'altogether', 'approximately', 'as a rule'],
    'mainspring': ['ambition', 'aspiration', 'basis', 'calling', 'cause', 'consideration', 'font', 'fount', 'fountain', 'fountainhead', 'goal', 'ground'],
    'mainstay': ['maecenas', 'abettor', 'admirer', 'advocate', 'afford support', 'aficionado', 'alpenstock', 'angel', 'apologist', 'arm', 'athletic supporter', 'back'],
    'mainstream': ['zeitgeist', 'bearing', 'course', 'current', 'direction', 'drift', 'glacial movement', 'line', 'main current', 'motion', 'movement', 'run'],
    'maintain': ['abide', 'accommodate', 'account as', 'advocate', 'affirm', 'afford', 'afford support', 'allege', 'allege in support', 'announce', 'annunciate', 'answer'],
    'maintenance': ['tlc', 'abidingness', 'age', 'aid', 'alimentation', 'alimony', 'allowance', 'antiquity', 'backing', 'bottling up', 'bread', 'care'],
    'majestic': ['babylonian', 'corinthian', 'affected', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'aristocratic', 'arrogant', 'august', 'awe-inspiring'],
    'majesty': ['eminence', 'grace', 'her excellency', 'her highness', 'her ladyship', 'her majesty', 'highness', 'his lordship', 'his majesty', 'honor', 'imperial highness', 'imperial majesty'],
    'major': ['adc', 'co', 'od', 'a cut above', 'above', 'academic specialty', 'adult', 'ahead', 'aide', 'aide-de-camp', 'area', 'ascendant'],
    'major league': ['big', 'big-league', 'big-name', 'big-time', 'bigwig', 'bigwigged', 'consequential', 'considerable', 'double-barreled', 'earthshaking', 'grand', 'great'],
    'majordomo': ['mc', 'attorney', 'bailiff', 'butler', 'chamberlain', 'croupier', 'curator', 'custodian', 'emcee', 'factor', 'guardian', 'house steward'],
    'majority': ['accomplishment', 'adulthood', 'adultness', 'age of consent', 'ascendancy', 'best part', 'better part', 'body', 'bulk', 'deanship', 'driving age', 'essence'],
    'majority leader': ['mp', 'member of congress', 'member of parliament', 'alderman', 'assemblyman', 'chosen freeholder', 'city father', 'congressman', 'congresswoman', 'councilman', 'floor leader', 'lawgiver'],
    'make': ['platonic form', 'platonic idea', 'abide by', 'abscond', 'accomplish', 'achieve', 'acquire', 'act', 'add up to', 'adhere to', 'administer', 'aesthetic form'],
    'make a deal': ['accommodate', 'adjust', 'agree', 'agree to', 'bargain', 'bargain for', 'be a bargain', 'be a deal', 'be a go', 'be on', 'buy', 'buy back'],
    'make a killing': ['be caught short', 'be short', 'bear the palm', 'belong', 'break the bank', 'bucket', 'bucketshop', 'capitalize on', 'capture', 'carry', 'carry away', 'carry it'],
    'make advances': ['act on', 'answer', 'approach', 'bear upon', 'break the ice', 'communicate with', 'contact', 'correspond', 'court', 'cultivate', 'draw', 'draw on'],
    'make allowance for': ['admit', 'admit exceptions', 'allow', 'allow for', 'bear with', 'blink at', 'color', 'concede', 'condone', 'connive at', 'consider', 'consider the circumstances'],
    'make amends': ['atone', 'atone for', 'compensate', 'cover', 'do penance', 'expiate', 'fill up', 'get satisfaction', 'give and take', 'give satisfaction', 'indemnify', 'kick back'],
    'make an impression': ['affect', 'arrest the thoughts', 'assail the ear', 'be heard', 'be remembered', 'caress the ear', 'catch the thoughts', 'come home to', 'contact', 'gain a hearing', 'get across', 'get through to'],
    'make believe': ['act', 'act a part', 'affect', 'affected', 'apocryphal', 'apparition', 'artificial', 'assume', 'assumed', 'bastard', 'bluff', 'bogus'],
    'make clear': ['account for', 'affect', 'aid', 'allegorize', 'betoken', 'brandish', 'breathe', 'bring forth', 'bring forward', 'bring into view', 'bring out', 'bring to notice'],
    'make do': ['beget', 'breed', 'bring forth', 'bring into being', 'call into being', 'change', 'change for', 'coin', 'commute', 'compound for', 'conceive', 'concoct'],
    'make ends meet': ['cope', 'economize', 'eke out', 'enforce economies', 'get by', 'husband', 'keep afloat', 'keep within compass', 'make out', 'manage', 'put something aside', 'save'],
    'make fun of': ['be merry with', 'crack a joke', 'crack wise', 'deride', 'fleer at', 'fun', 'gibe at', 'grin at', 'hold in derision', 'jape', 'jest', 'joke'],
    'make good': ['abide by', 'accomplish', 'achieve success', 'act up to', 'adhere to', 'advance', 'afford proof of', 'amend', 'arrive', 'ascertain', 'atone', 'atone for'],
    'make haste': ['bolt', 'bundle', 'bustle', 'career', 'chase', 'crowd', 'dart', 'dash', 'dash off', 'dash on', 'double-time', 'festinate'],
    'make headway': ['achieve success', 'advance', 'ameliorate', 'amend', 'arrive', 'be a success', 'break through', 'come along', 'come on', 'come through', 'cover ground', 'cut a swath'],
    'make it': ['accomplish', 'achieve', 'achieve success', 'advance', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be a success', 'be able'],
    'make known': ['air', 'break it to', 'break the news', 'breathe', 'broach', 'broadcast', 'come out with', 'communicate', 'confide', 'confide to', 'convey', 'display'],
    'make light of': ['be blind to', 'be caught out', 'be inattentive', 'be unwary', 'belittle', 'blink at', 'connive at', 'cool it', 'de-emphasize', 'deprecate', 'depreciate', 'disparage'],
    'make love': ['ball', 'be intimate', 'beget', 'bill and coo', 'breed', 'breed true', 'cohabit', 'come together', 'commit adultery', 'copulate', 'couple', 'cover'],
    'make merry': ['beat the drum', 'blow the trumpet', 'carouse', 'celebrate', 'commemorate', 'cut loose', 'debauch', 'dress ship', 'fire a salute', 'hallow', 'hell around', 'hold jubilee'],
    'make money': ['capitalize on', 'cash in on', 'clean up', 'clear', 'coin money', 'come into money', 'commercialize', 'gain by', 'get rich', 'gross', 'grow rich', 'make a fortune'],
    'make nothing of': ['be at sea', 'be lost', 'belittle', 'de-emphasize', 'deprecate', 'depreciate', 'disparage', 'downplay', 'give up', 'make light of', 'make little of', 'minimize'],
    'make off': ['abscond', 'bolt', 'decamp', 'depart', 'escape', 'flee', 'fly', 'go', 'leave', 'quit', 'retire', 'run'],
    'make out': ['abide by', 'accept', 'adhere to', 'administer', 'afford proof of', 'answer', 'appreciate', 'apprehend', 'ascertain', 'ball', 'be acquainted with', 'be apprised of'],
    'make over': ['abalienate', 'alien', 'alienate', 'amortize', 'assign', 'assimilate to', 'barter', 'become', 'bequeath', 'bring to', 'carry over', 'cede'],
    'make plain': ['account for', 'affect', 'allegorize', 'betoken', 'brandish', 'breathe', 'bring forth', 'bring forward', 'bring into view', 'bring out', 'bring to notice', 'clarify'],
    'make possible': ['ok', 'accord', 'admit', 'allow', 'consent', 'dispense', 'enable', 'give leave', 'give permission', 'give the go-ahead', 'give the word', 'grant'],
    'make the grade': ['answer', 'avail', 'be able', 'be equal to', 'be up to', 'bear', 'can', 'can do', 'clear', 'clear the hurdle', 'come along', 'come on'],
    'make the scene': ['achieve success', 'advance', 'arrive', 'be a success', 'be enfranchised', 'be implicated in', 'bear a hand', 'break through', 'chip in', 'come on', 'come through', 'contribute'],
    'make up': ['accommodate', 'accomplish', 'accumulate', 'ad-lib', 'adjust', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'arrange', 'assemble', 'atone for'],
    'make up to': ['act on', 'act up to', 'agree to anything', 'answer', 'approach', 'atone', 'bear for', 'bear up for', 'bear up to', 'bear upon', 'break for', 'break the ice'],
    'maker': ['meistersinger', 'parnassian', 'actor', 'agent', 'ancestors', 'apprentice', 'arch-poet', 'architect', 'artificer', 'artisan', 'artist', 'artiste'],
    'makeshift': ['action', 'ad hoc', 'ad hoc measure', 'ad lib', 'ad libitum', 'ad-lib', 'ad-libbing', 'adulterated', 'agent', 'alternate', 'alternative', 'analogy'],
    'makeup': ['platonic form', 'platonic idea', 'acknowledgments', 'aesthetic form', 'anatomy', 'animus', 'aptitude', 'archetype', 'architectonics', 'architecture', 'arrangement', 'art form'],
    'making': ['accession', 'acquirement', 'acquisition', 'addition', 'anatomy', 'architectonics', 'architecture', 'arrangement', 'assembly', 'attainment', 'batch', 'build'],
    'makings': ['ability', 'adjunct', 'appurtenance', 'aspect', 'bump', 'caliber', 'capability', 'capacity', 'capital gains', 'circumstance', 'cleanup', 'clear profit'],
    'maladjusted': ['ill-adapted', 'ill-assorted', 'ill-chosen', 'ill-fitted', 'ill-matched', 'ill-qualified', 'ill-sorted', 'ill-suited', 'ill-timed', 'improper', 'inadequate', 'inadmissible'],
    'maladjustment': ['abnormality', 'anomaly', 'brain disease', 'crack-up', 'emotional disorder', 'emotional instability', 'functional nervous disorder', 'impropriety', 'inability', 'inadeptness', 'inadequacy', 'inadmissibility'],
    'maladroit': ['all thumbs', 'awkward', 'base', 'blunderheaded', 'blundering', 'boorish', 'brash', 'bumbling', 'bungling', 'butterfingered', 'careless', 'clownish'],
    'malady': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'cardiovascular disease'],
    'malaise': ['schmerz', 'slough of despond', 'abnormality', 'aches and pains', 'acute disease', 'affection', 'affliction', 'agitation', 'ailment', 'all-overs', 'allergic disease', 'allergy'],
    'malapropism': ['irish bull', 'abuse of terms', 'acrostic', 'alliteration', 'allusion', 'amphibologism', 'amphiboly', 'anacoluthon', 'anadiplosis', 'anagram', 'analogy', 'anaphora'],
    'malapropos': ['bad', 'futile', 'ill-adapted', 'ill-advised', 'ill-assorted', 'ill-chosen', 'ill-considered', 'ill-fitted', 'ill-matched', 'ill-seasoned', 'ill-sorted', 'ill-suited'],
    'malaria': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'afterdamp', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax'],
    'malarial': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'cancerous', 'chlorotic', 'colicky', 'consumptive', 'dropsical', 'dyspeptic', 'edematous'],
    'malarial fever': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'malarkey': ['balderdash', 'baloney', 'bilge', 'blah', 'blah-blah', 'blatherskite', 'bop', 'bosh', 'bull', 'bullshit', 'bunk', 'bunkum'],
    'malcontent': ['agitator', 'alienated', 'anarch', 'anarchist', 'beefing', 'bellyacher', 'bellyaching', 'bitching', 'brawler', 'complainant', 'complainer', 'complaining'],
    'male': ['andric', 'bull', 'gentleman', 'gentlemanlike', 'gentlemanly', 'he', 'him', 'his', 'hombre', 'homme', 'male being', 'male person'],
    'male chauvinism': ['jim crow', 'jim crow law', 'anti-semitism', 'apartheid', 'black power', 'black supremacy', 'chauvinism', 'class consciousness', 'class distinction', 'class hatred', 'class prejudice', 'class war'],
    'male organs': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'malediction': ['anathema', 'ban', 'blasphemy', 'commination', 'curse', 'damnation', 'denunciation', 'evil eye', 'excommunication', 'execration', 'fulmination', 'hex'],
    'maledictory': ['rabelaisian', 'abusive', 'blasphemous', 'calumniatory', 'calumnious', 'comminatory', 'contumelious', 'cursing', 'damnatory', 'denunciatory', 'dirty', 'dysphemistic'],
    'malefactor': ['bad person', 'blackguard', 'criminal', 'crook', 'culprit', 'deceiver', 'delinquent', 'evil man', 'evil person', 'evildoer', 'felon', 'gangster'],
    'malevolence': ['anglophobia', 'russophobia', 'abhorrence', 'abomination', 'antagonism', 'anti-semitism', 'antipathy', 'aversion', 'bad blood', 'bad temper', 'bad will', 'badness'],
    'malevolent': ['acrid', 'antagonistic', 'antipathetic', 'bad', 'baleful', 'baneful', 'belligerent', 'bitchy', 'bitter', 'black', 'caustic', 'clashing'],
    'malevolently': ['balefully', 'banefully', 'corrodingly', 'corrosively', 'counterproductively', 'damagingly', 'deleteriously', 'detrimentally', 'disadvantageously', 'disserviceably', 'harmfully', 'hatefully'],
    'malfeasance': ['abuse', 'abuse of office', 'atrocity', 'bad policy', 'befoulment', 'breach', 'conversion', 'corrupt administration', 'crime', 'crime against humanity', 'criminal tendency', 'criminality'],
    'malformation': ['absurdity', 'anticness', 'bizarreness', 'bizarrerie', 'bowlegs', 'camelback', 'cleft palate', 'clubfoot', 'crookback', 'curiousness', 'defacement', 'deformation'],
    'malformed': ['bandy', 'bandy-legged', 'baroque', 'bizarre', 'blemished', 'bloated', 'bowlegged', 'cacogenic', 'club-footed', 'defaced', 'deformed', 'disfigured'],
    'malice': ['anglophobia', 'russophobia', 'abhorrence', 'abomination', 'animosity', 'animus', 'antagonism', 'anti-semitism', 'antipathy', 'aversion', 'bane', 'belligerence'],
    'malicious': ['acrid', 'antagonistic', 'antipathetic', 'baleful', 'baneful', 'belligerent', 'bitchy', 'bitter', 'catty', 'caustic', 'clashing', 'colliding'],
    'maliciously': ['balefully', 'harmfully', 'hatefully', 'in spite', 'iniquitously', 'invidiously', 'maleficently', 'malevolently', 'malignantly', 'meanly', 'nastily', 'noxiously'],
    'malign': ['antagonistic', 'antipathetic', 'asperse', 'atrocious', 'backbite', 'bad-mouth', 'baleful', 'baneful', 'barbaric', 'barbarous', 'befoul', 'besmirch'],
    'malignancy': ['balefulness', 'banefulness', 'bitchiness', 'communicability', 'contagiousness', 'cussedness', 'deadliness', 'despite', 'destructiveness', 'detrimentalness', 'devilment', 'devilry'],
    'malignant': ['acrid', 'allergic', 'anemic', 'antagonistic', 'antipathetic', 'apoplectic', 'arthritic', 'atrocious', 'baleful', 'baneful', 'barbaric', 'barbarous'],
    'malignant growth': ['benign tumor', 'callosity', 'callus', 'cancer', 'carcinoma', 'corn', 'cyst', 'excrescence', 'fungosity', 'fungus', 'growth', 'intumescence'],
    'malignantly': ['balefully', 'banefully', 'corrodingly', 'corrosively', 'counterproductively', 'damagingly', 'deleteriously', 'detrimentally', 'disadvantageously', 'disserviceably', 'harmfully', 'hatefully'],
    'malinger': ['abandon', 'cut', 'dodge', 'dog it', 'duck', 'duck duty', 'get out of', 'goldbrick', 'goof off', 'jump', 'leave', 'leave loose ends'],
    'malingerer': ['blagueur', 'bluff', 'bluffer', 'bungler', 'charlatan', 'clock watcher', 'disregarder', 'dodger', 'eye-servant', 'fake', 'faker', 'fourflusher'],
    'malingering': ['cagey', 'clock-watching', 'dodging', 'ducking', 'elusive', 'elusory', 'evasive', 'goofing off', 'shifty', 'shirking', 'skulking', 'slacking'],
    'mall': ['alameda', 'beaten path', 'beaten track', 'berm', 'bicycle path', 'boardwalk', 'bridle path', 'catwalk', 'esplanade', 'fastwalk', 'foot pavement', 'footpath'],
    'malleable': ['able to adapt', 'accessible', 'acquiescent', 'adaptable', 'adaptive', 'adjustable', 'alterable', 'alterative', 'amenable', 'apt', 'bendable', 'bending'],
    'mallet': ['air hammer', 'ball peen hammer', 'beetle', 'chipping hammer', 'chisel', 'claw hammer', 'drop hammer', 'electric hammer', 'jackhammer', 'modeling clay', 'pile hammer', 'point'],
    'malnutrition': ['lombardy leprosy', 'anemia', 'ariboflavinosis', 'beriberi', 'cachexia', 'chlorosis', 'deficiency anemia', 'dermatitis', 'dietary deficiency', 'goiter', 'greensickness', 'keratomalacia'],
    'malocchio': ['jonah', 'anathema', 'bad blood', 'bad influence', 'bad temper', 'bad will', 'ban', 'bedroom eyes', 'blasphemy', 'blighting glance', 'cantrip', 'charm'],
    'malodorous': ['abhorrent', 'abominable', 'aromatic', 'bad', 'bad-smelling', 'barfy', 'base', 'beastly', 'below contempt', 'beneath contempt', 'contemptible', 'crappy'],
    'malpractice': ['abuse', 'abuse of office', 'bad policy', 'befoulment', 'conversion', 'corrupt administration', 'crime', 'criminal tendency', 'criminality', 'criminosis', 'debasement', 'defalcation'],
    'maltreat': ['abuse', 'afflict', 'aggrieve', 'batter', 'befoul', 'bewitch', 'blight', 'bruise', 'buffet', 'condemn', 'corrupt', 'crucify'],
    'mama': ['dam', 'foster mother', 'genetrix', 'ma', 'mam', 'mammy', 'mater', 'materfamilias', 'maternal ancestor', 'matriarch', 'mom', 'mommy'],
    'mammal': ['angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'indian buffalo', 'kodiak bear', 'reptilia', 'virginia deer', 'aardvark', 'aardwolf', 'alpaca', 'amphibian'],
    'mammalian': ['bosomed', 'breasted', 'cetacean', 'chested', 'chordate', 'mammary', 'mammate', 'mammiform', 'mammillary', 'marsupial', 'nippled', 'papillary'],
    'mammary gland': ['bag', 'boobs', 'bosom', 'breast', 'breasts', 'brisket', 'bust', 'chest', 'crop', 'dug', 'knockers', 'mama'],
    'mammon': ['affluence', 'and pence', 'assets', 'bottomless purse', 'bulging purse', 'cash', 'circulating medium', 'coinage', 'coined liberty', 'cold cash', 'currency', 'dollars'],
    'mammoth': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'jumbo', 'abysmal', 'ammonite', 'amplitudinous', 'ankylosaur', 'archaeohippus'],
    'mammy': ['amah', 'ayah', 'dam', 'dry nurse', 'foster mother', 'genetrix', 'ma', 'mam', 'mama', 'mater', 'materfamilias', 'maternal ancestor'],
    'man': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'man eater': ['brillat-savarin', 'cain', 'loch ness monster', 'lucullus', 'alevin', 'animal', 'anthropophagite', 'apache', 'assassin', 'assassinator', 'barbarian', 'beast'],
    'man eating': ['cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'dining', 'eating', 'feeding', 'flesh-eating', 'fruitarian', 'gastronomic', 'gluttonous'],
    'man hour': ['abundant year', 'academic year', 'annum', 'bissextile year', 'calendar month', 'calendar year', 'century', 'common year', 'day', 'decade', 'decennary', 'decennium'],
    'man made': ['affected', 'apocryphal', 'artificial', 'assembled', 'assumed', 'bastard', 'bogus', 'brummagem', 'built', 'cast', 'colorable', 'colored'],
    'man of action': ['activist', 'ball of fire', 'beaver', 'big-time operator', 'bustler', 'busy bee', 'doer', 'eager beaver', 'enthusiast', 'go-getter', 'human dynamo', 'hustler'],
    'man-about-town': ['beau brummel', 'arbiter of fashion', 'beau', 'blade', 'blood', 'bon vivant', 'boulevardier', 'city slicker', 'clotheshorse', 'clubman', 'clubwoman', 'cosmopolitan'],
    'mana': ['amperage', 'armipotence', 'authority', 'beef', 'black power', 'brute force', 'charge', 'charisma', 'clout', 'cogence', 'cogency', 'compulsion'],
    'manacle': ['oregon boat', 'anchor', 'bilbo', 'bind', 'bond', 'bonds', 'bracelets', 'bridle', 'camisole', 'chain', 'chains', 'check'],
    'manage': ['accomplish', 'achieve', 'administer', 'administrate', 'animal husbandry', 'animal rearing', 'attain', 'automobiling', 'be master', 'be responsible for', 'be so', 'be such'],
    'manageability': ['adaptability', 'compassability', 'controllability', 'convenience', 'corrigibility', 'domesticability', 'ductility', 'feasibility', 'flexibility', 'governability', 'handiness', 'housebrokenness'],
    'manageable': ['actable', 'adaptable', 'amenable', 'budget', 'cheap', 'compassable', 'compliant', 'controllable', 'convenient', 'corrigible', 'doable', 'docile'],
    'management': ['accomplishment', 'achievement', 'acme', 'action', 'administration', 'agency', 'archon', 'auspices', 'austerity', 'austerity program', 'authority', 'authorization'],
    'manager': ['administrator', 'agent', 'banker', 'baron', 'big boss', 'big businessman', 'boss', 'business leader', 'businessman', 'captain', 'captain of industry', 'castellan'],
    'managerial': ['agential', 'agentival', 'agentive', 'chief', 'commanding', 'controlling', 'directing', 'directive', 'directorial', 'directory', 'functional', 'governing'],
    'managership': ['captainship', 'chairmanship', 'convenership', 'custody', 'dictatorship', 'directorate', 'directorship', 'foremanship', 'generalship', 'governorship', 'guardianship', 'headship'],
    'managing': ['administrative', 'bureaucratic', 'chief', 'commanding', 'controlling', 'directing', 'directive', 'directorial', 'directory', 'executive', 'governing', 'guiding'],
    'manana': ['after a time', 'after a while', 'aftertime', 'afterward', 'afterwards', 'afteryears', 'anon', 'before long', 'by and by', 'by destiny', 'by-and-by', 'course ahead'],
    'manchild': ['boy', 'bub', 'bubba', 'buck', 'bud', 'buddy', 'colt', 'cub', 'fellow', 'fledgling', 'hobbledehoy', 'lad'],
    'mandarin': ['brahmin', 'authority', 'brainworker', 'bureaucrat', 'civil servant', 'doctor', 'egghead', 'elder', 'elder statesman', 'elitist', 'functionary', 'functionnaire'],
    'mandate': ['adverse possession', 'agency', 'agentship', 'ally', 'alodium', 'archduchy', 'archdukedom', 'assignment', 'authority', 'authorization', 'behest', 'bench warrant'],
    'mandated': ['absolute', 'binding', 'compulsory', 'conclusive', 'decisive', 'decretory', 'dictated', 'entailed', 'final', 'hard-and-fast', 'imperative', 'imposed'],
    'mandatory': ['absolute', 'authoritative', 'binding', 'canonical', 'choiceless', 'commanded', 'commanding', 'compelling', 'compulsatory', 'compulsory', 'conclusive', 'de rigueur'],
    'mandibles': ['bazoo', 'chaps', 'chops', 'claws', 'clutches', 'digits', 'embouchure', 'fangs', 'fingernails', 'fingers', 'gab', 'gob'],
    'mandolin': ['dobro guitar', 'f-hole guitar', 'spanish guitar', 'archlute', 'balalaika', 'banjo', 'banjo-uke', 'banjo-ukulele', 'banjo-zither', 'banjorine', 'banjuke', 'bass guitar'],
    'mane': ['bristle', 'capillament', 'cilium', 'coat', 'crop', 'fleece', 'fur', 'hair', 'head', 'head of hair', 'horsehair', 'locks'],
    'maneuver': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'act on', 'act upon', 'acta', 'action', 'ad hoc measure', 'adventure', 'amphibious operations', 'angle'],
    'maneuverability': ['adaptability', 'compassability', 'convenience', 'ductility', 'feasibility', 'flexibility', 'handiness', 'malleability', 'manageability', 'manageableness', 'manipulatability', 'negotiability'],
    'maneuverable': ['actable', 'adaptable', 'compassable', 'convenient', 'doable', 'ductile', 'feasible', 'flexible', 'foolproof', 'handy', 'malleable', 'manageable'],
    'maneuvering': ['artifice', 'behind-the-scenes influence', 'cabal', 'collusion', 'complicity', 'complot', 'confederacy', 'connivance', 'conspiracy', 'contrivance', 'contriving', 'counterplot'],
    'manfully': ['arduously', 'bec et ongles', 'courageously', 'dauntlessly', 'effortfully', 'gamely', 'hammer and tongs', 'hard', 'heart and soul', 'heroically', 'industriously', 'laboriously'],
    'mange': ['texas fever', 'anthrax', 'aphthous fever', 'bighead', 'black quarter', 'blackleg', 'blackwater', 'blind staggers', 'bloody flux', 'broken wind', 'cattle plague', 'charbon'],
    'mangle': ['bung up', 'butcher', 'calender', 'contort', 'cripple', 'crush', 'cut', 'damage', 'deface', 'defoliate', 'deform', 'denude'],
    'mangled': ['aggravated', 'broken', 'burned', 'burst', 'busted', 'butchered', 'castrated', 'checked', 'chipped', 'cleft', 'cloven', 'cracked'],
    'mangy': ['abject', 'base', 'contemptible', 'decrepit', 'despicable', 'dingy', 'dirty', 'disreputable', 'down-at-heel', 'filthy', 'ignominious', 'low'],
    'manhandle': ['abuse', 'batter', 'bear', 'beat up', 'belabor', 'bruise', 'buffet', 'bung up', 'carry', 'carry away', 'carry off', 'cart away'],
    'manhole': ['air hole', 'armhole', 'blowhole', 'bullet-hole', 'bunghole', 'cringle', 'deadeye', 'eye', 'eyelet', 'gasket', 'grommet', 'guide'],
    'manhood': ['dutch courage', 'adulthood', 'adultness', 'age of consent', 'boldness', 'braveness', 'bravery', 'chivalrousness', 'chivalry', 'conspicuous gallantry', 'courage', 'courageousness'],
    'mania': ['aberration', 'abnormality', 'abstraction', 'abulia', 'alienation', 'an universal wolf', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'appetence', 'appetency'],
    'maniac': ['aliene', 'batty', 'bedlamite', 'berserk', 'borderline case', 'crackbrain', 'cracked', 'crackpot', 'crazed', 'crazy', 'delirious', 'dement'],
    'maniacal': ['dionysiac', 'abandoned', 'amok', 'bacchic', 'bellowing', 'berserk', 'carried away', 'corybantic', 'crazy', 'delirious', 'demented', 'demoniac'],
    'manic': ['abnormal', 'agog', 'aquiver', 'aroused', 'atingle', 'atwitter', 'bereft of reason', 'brainsick', 'bursting', 'carried away', 'crackbrained', 'cracked'],
    'manic depressive': ['brain-damaged', 'brain-injured', 'catatoniac', 'catatonic', 'certifiable', 'certifiable case', 'disturbed', 'mental', 'mental case', 'mentally ill', 'mentally sick', 'neurotic'],
    'manifest': ['account', 'advertise', 'affect', 'aggrandize', 'air', 'apparent', 'appear', 'approve', 'argue', 'attest', 'augment', 'bare'],
    'manifestation': ['announcement', 'apocalypse', 'apparition', 'appearance', 'appearing', 'arising', 'avatar', 'avowal', 'baring', 'basis for belief', 'blazon', 'body of evidence'],
    'manifestly': ['absolutely', 'actually', 'apparently', 'assuredly', 'certainly', 'clearly', 'conspicuously', 'de facto', 'decidedly', 'definitely', 'demonstrably', 'discernibly'],
    'manifesto': ['affidavit', 'affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'assertion', 'asseveration', 'averment', 'avouchment', 'avowal', 'bulletin board'],
    'manifold': ['allotropic', 'assorted', 'divers', 'diverse', 'diversified', 'diversiform', 'heteromorphic', 'heteromorphous', 'increased', 'many', 'many-sided', 'metamorphic'],
    'manipulate': ['abuse', 'adulterate', 'angle', 'barnstorm', 'be responsible for', 'beguile', 'bleed', 'bleed white', 'call the signals', 'captain', 'carry on', 'carry out'],
    'manipulation': ['accounting', 'action', 'agency', 'anal intercourse', 'analysis', 'artifice', 'authority', 'autoeroticism', 'bear raid', 'behind-the-scenes influence', 'bestiality', 'braking'],
    'manipulator': ['rasputin', 'svengali', 'vip', 'access', 'agent', 'bad influence', 'big wheel', 'calculator', 'conductor', 'court', 'driver', 'eminence grise'],
    'manliness': ['dutch courage', 'boldness', 'braveness', 'bravery', 'chivalrousness', 'chivalry', 'conspicuous gallantry', 'courage', 'courageousness', 'doughtiness', 'gallantness', 'gallantry'],
    'manly': ['christian', 'andric', 'blameless', 'bold', 'bold-spirited', 'brave', 'bull', 'chivalric', 'chivalrous', 'clean', 'courageous', 'creditable'],
    'manna': ['tlc', 'ambrosia', 'benefaction', 'benefit', 'benevolence', 'blessing', 'bonne bouche', 'boon', 'bread', 'care', 'cate', 'choice morsel'],
    'mannequin': ['bust', 'carving', 'clay model', 'doll', 'dolly', 'dummy', 'fantoccini', 'figure', 'figurehead', 'figurine', 'gingerbread man', 'lay figure'],
    'manner': ['mo', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'affectedness', 'air', 'algorithm', 'amenities', 'angle'],
    'manner of speaking': ['adjectival phrase', 'affectation', 'asiaticism', 'clause', 'command of language', 'construction', 'device', 'euphuism', 'exaggeration', 'expression', 'expression of ideas', 'fashion'],
    'mannered': ['gongoresque', 'gongoristic', 'marinistic', 'affected', 'allusive', 'artificial', 'behaved', 'behavioral', 'behaviored', 'behaviorist', 'behavioristic', 'conscious'],
    'mannerism': ['gongorism', 'affectation', 'affectedness', 'airs', 'airs and graces', 'aroma', 'artfulness', 'artifice', 'artificiality', 'attribute', 'badge', 'brand'],
    'mannerly': ['accommodatingly', 'attentively', 'chivalrously', 'civilly', 'complacently', 'complaisantly', 'correct', 'courteous', 'courteously', 'courtly', 'deferentially', 'gallantly'],
    'manners': ['action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'amenities', 'bearing', 'behavior', 'behavior pattern', 'behavioral norm'],
    'mannish': ['ac-dc', 'amphierotic', 'andric', 'autoerotic', 'bisexed', 'bisexual', 'bull', 'butch', 'deviant', 'effeminate', 'gay', 'gentlemanlike'],
    'manoeuvre': ['artifice', 'contrive', 'demarche', 'device', 'devise', 'dodge', 'drill', 'drive', 'engineer', 'exercise', 'finagle', 'finesse'],
    'manor': ['acres', 'castle', 'chateau', 'chattels real', 'demesne', 'domain', 'grounds', 'honor', 'land', 'landed property', 'lands', 'lot'],
    'manor house': ['dymaxion house', 'white house', 'adobe house', 'building', 'casa', 'cliff dwelling', 'consulate', 'country house', 'country seat', 'dacha', 'deanery', 'dwelling house'],
    'manque': ['abortive', 'bootless', 'failed', 'failing', 'fruitless', 'futile', 'ineffective', 'ineffectual', 'inefficacious', 'lame', 'miscarried', 'miscarrying'],
    'mansion': ['aspect', 'astrodiagnosis', 'astrology', 'astromancy', 'castle', 'chateau', 'court', 'estate', 'genethliac astrology', 'genethliacism', 'genethliacs', 'genethlialogy'],
    'mantle': ['aerate', 'apply to', 'arachnoid', 'arbor vitae', 'archipallium', 'armory', 'badge', 'badge of office', 'badges', 'baton', 'beat', 'between brain'],
    'mantled': ['appareled', 'armored', 'arrayed', 'attired', 'bedecked', 'breeched', 'capped', 'cased', 'ceiled', 'chausse', 'clad', 'cloaked'],
    'mantra': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'nunc dimittis', 'te deum', 'trisagion', 'vedic hymn'],
    'manual': ['sefer torah', 'torah', 'torah scroll', 'virginal', 'abecedarium', 'abecedary', 'alphabet book', 'battledore', 'breviary', 'canon', 'casebook', 'choir'],
    'manual labor': ['dirty work', 'donkeywork', 'drudgery', 'employment', 'fag', 'fatigue', 'grind', 'handiwork', 'handwork', 'industry', 'labor', 'lick'],
    'manufacture': ['anatomy', 'architectonics', 'architecture', 'arrangement', 'artifact', 'assemble', 'assembly', 'basic training', 'brainchild', 'briefing', 'build', 'building'],
    'manufactured': ['assembled', 'built', 'cast', 'concocted', 'constructed', 'cooked-up', 'crafted', 'created', 'custom', 'custom-built', 'custom-made', 'extracted'],
    'manufacturer': ['ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner', 'builder', 'conceiver', 'constructor', 'craftsman'],
    'manure': ['bm', 'ammonia', 'bowel movement', 'buffalo chips', 'ca-ca', 'castor-bean meal', 'commercial fertilizer', 'compost', 'coprolite', 'coprolith', 'cow chips', 'cow flops'],
    'manuscript': ['aldine', 'aldine book', 'elzevir', 'elzevir book', 'article', 'autograph', 'autographic', 'autography', 'brainchild', 'calligraphic', 'calligraphy', 'chirographic'],
    'many': ['a mass of', 'a world of', 'abounding', 'abundance', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'army', 'assorted', 'at odds'],
    'many sided': ['able to adapt', 'adaptable', 'adjustable', 'all-around', 'alterable', 'alterative', 'amalgamated', 'ambidextrous', 'ambiguous', 'ambivalent', 'amphibious', 'bifacial'],
    'maoism': ['bolshevikism', 'bolshevism', 'carbonarism', 'castroism', 'communist information bureau', 'communist party', 'jacobinism', 'marxian socialism', 'marxism', 'marxism-leninism', 'sinn feinism', 'stalinism'],
    'maoist': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'communist sympathizer', 'cong', 'fenian'],
    'map': ['lambert conformal projection', 'mercator projection', 'miller projection', 'aeronautical chart', 'alphabet', 'art', 'astronomical chart', 'atlas', 'azimuthal projection', 'blueprint', 'cartographer', 'cartography'],
    'map maker': ['lambert conformal projection', 'mercator projection', 'miller projection', 'aeronautical chart', 'astronomical chart', 'atlas', 'azimuthal projection', 'cartographer', 'cartography', 'celestial chart', 'celestial globe', 'chart'],
    'mar': ['be all thumbs', 'blemish', 'blight', 'blot', 'blunder', 'blunder away', 'blunder into', 'blunder on', 'blunder upon', 'boggle', 'botch', 'bruise'],
    'maraca': ['battery', 'bells', 'bones', 'castanets', 'celesta', 'chime', 'chimes', 'clappers', 'crash cymbal', 'cymbals', 'finger cymbals', 'gamelan'],
    'marathon': ['arica movement', 'erhard seminars training', 'le mans', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'air race', 'assertiveness training', 'automobile race', 'behavior modification', 'behavior therapy'],
    'maraud': ['depredate', 'despoil', 'fleece', 'forage', 'foray', 'freeboot', 'gut', 'harass', 'harry', 'loot', 'pillage', 'plunder'],
    'marauder': ['bandit', 'brigand', 'buccaneer', 'bummer', 'depredator', 'desperado', 'despoiler', 'forager', 'forayer', 'freebooter', 'looter', 'pillager'],
    'marauding': ['banditry', 'brigandage', 'brigandism', 'depredation', 'despoiling', 'despoilment', 'despoliation', 'direption', 'foraging', 'foray', 'freebooting', 'looting'],
    'marble': ['dalmatian', 'adamant', 'agate', 'alabaster', 'antigorite', 'argent', 'argentine', 'ball', 'band', 'bar', 'baseball bat', 'bat'],
    'marbled': ['banded', 'barred', 'brinded', 'brindle', 'brindled', 'calico', 'clouded', 'dapple', 'dappled', 'listed', 'marbleized', 'motley'],
    'marbleize': ['band', 'bar', 'bespangle', 'bespeckle', 'bespot', 'blotch', 'check', 'checker', 'dapple', 'dot', 'flake', 'fleck'],
    'marbleized': ['banded', 'barred', 'brinded', 'brindle', 'brindled', 'listed', 'marbled', 'streaked', 'streaky', 'striatal', 'striate', 'striated'],
    'marblelike': ['adamant', 'adamantine', 'bony', 'cement', 'cemental', 'concrete', 'corneous', 'dense', 'diamondlike', 'dure', 'flintlike', 'flinty'],
    'march': ['berlin wall', 'pillars of hercules', 'abut', 'accord', 'adjoin', 'advance', 'advancement', 'advancing', 'airing', 'ambit', 'amble', 'anabasis'],
    'marcher': ['ambulator', 'backpacker', 'foot passenger', 'foot soldier', 'foot traveler', 'footslogger', 'hiker', 'hitchhiker', 'hoofer', 'infantryman', 'jaywalker', 'paddlefoot'],
    'marching': ['ambling', 'ambulation', 'backpacking', 'footing', 'footing it', 'footwork', 'going on foot', 'hiking', 'hitchhiking', 'hitching', 'hoofing', 'legwork'],
    'mardi gras': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas'],
    'mare': ['houyhnhnm', 'partlet', 'alkali flat', 'alluvial plain', 'basin', 'biddy', 'bitch', 'bossy', 'bottomland', 'brood mare', 'bushveld', 'campo'],
    'margarine': ['butter', 'buttermilk', 'certified milk', 'cheese', 'condensed milk', 'cream', 'dairy products', 'ghee', 'half-and-half', 'heavy cream', 'light cream', 'milk'],
    'margin': ['abut', 'adjoin', 'aesthetic distance', 'air space', 'allowance', 'ample scope', 'balance', 'bank', 'befringe', 'bind', 'blank check', 'board'],
    'marginal': ['bordering', 'borderline', 'boundary', 'bounding', 'coastal', 'determinant', 'determinative', 'determining', 'disputable', 'doubtful', 'dubious', 'extreme'],
    'marginalia': ['adversaria', 'affix', 'aide-memoire', 'allonge', 'annotation', 'appendix', 'coda', 'codicil', 'commentary', 'docket', 'enclitic', 'entry'],
    'marijuana': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'boo', 'cannabis', 'diethyltryptamine'],
    'marijuana smoker': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser'],
    'marimba': ['battery', 'bells', 'bones', 'castanets', 'celesta', 'chime', 'chimes', 'clappers', 'crash cymbal', 'cymbals', 'finger cymbals', 'gamelan'],
    'marina': ['anchorage', 'anchorage ground', 'basin', 'berth', 'breakwater', 'bulkhead', 'dock', 'dockage', 'dockyard', 'dry dock', 'embankment', 'groin'],
    'marinate': ['anhydrate', 'blast-freeze', 'brine', 'corn', 'cure', 'dehydrate', 'desiccate', 'dry', 'dry-cure', 'dry-salt', 'embalm', 'evaporate'],
    'marination': ['anhydration', 'blast-freezing', 'bottling', 'brining', 'canning', 'corning', 'curing', 'decoction', 'dehydration', 'desiccation', 'dry-curing', 'drying'],
    'marine': ['naval construction battalion', 'naval reservist', 'rn', 'royal marine', 'royal navy', 'seabee', 'seabees', 'usn', 'united states navy', 'abyssal', 'aquatic', 'argosy'],
    'marine animal': ['loch ness monster', 'alevin', 'benthon', 'benthos', 'cetacean', 'crustacean', 'dolphin', 'dugong', 'fingerling', 'fish', 'fry', 'game fish'],
    'mariner': ['adventurer', 'alpinist', 'astronaut', 'bluejacket', 'camper', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser', 'excursionist', 'explorer'],
    'marionette': ['agate', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble', 'blocks', 'bust', 'carving', 'checkerboard', 'chessboard', 'club'],
    'maritime': ['bathymetric', 'bathyorographical', 'deep-sea', 'hydrographic', 'marine', 'nautical', 'naval', 'navigational', 'ocean-going', 'oceanic', 'oceanographic', 'pelagic'],
    'mark': ['john hancock', 'accent', 'accent mark', 'account', 'affection', 'aim', 'alphabet', 'alphabetize', 'amount', 'ampersand', 'analyze', 'anatomize'],
    'mark down': ['beat down', 'book', 'break', 'calendar', 'carve', 'catalog', 'chalk', 'chalk up', 'cheapen', 'check in', 'chronicle', 'clip'],
    'mark off': ['allocate', 'allot', 'analyze', 'anatomize', 'appoint', 'appropriate to', 'assign', 'assign to', 'atomize', 'be characteristic', 'blaze', 'blaze a trail'],
    'mark time': ['abide', 'await', 'be still', 'beat time', 'bide', 'bide the issue', 'clock', 'coast', 'dally', 'dawdle', 'delay', 'dillydally'],
    'markdown': ['break', 'cheapening', 'cut', 'decline', 'deflation', 'depreciation', 'devaluation', 'dive', 'lowering', 'nose dive', 'plummet', 'plummeting'],
    'marked': ['a cut above', 'above', 'acclaimed', 'ahead', 'appalling', 'apparent', 'appointed', 'appropriate', 'arresting', 'ascendant', 'astonishing', 'better'],
    'markedly': ['abundantly', 'acutely', 'amazingly', 'amply', 'apparently', 'arrantly', 'astonishingly', 'awesomely', 'blatantly', 'boldly', 'characteristically', 'clearly'],
    'marker': ['accountant', 'amanuensis', 'arch', 'archivist', 'barrow', 'beacon', 'beam', 'bench mark', 'bookkeeper', 'bookmark', 'boundary stone', 'brass'],
    'market': ['dow-jones industrial average', 'wall street', 'agora', 'auto show', 'balance of trade', 'bazaar', 'be in', 'big business', 'bill of sale', 'boat show', 'browse', 'business'],
    'market research': ['consumer preference study', 'consumer research', 'consumer survey', 'direct-mail selling', 'hard sell', 'hawking', 'high-pressure salesmanship', 'huckstering', 'jobbing', 'low-pressure salesmanship', 'mail-order selling', 'marketing'],
    'market value': ['account', 'asking price', 'bearish prices', 'bid price', 'book value', 'bullish prices', 'call price', 'closing price', 'conversion factor', 'decline', 'face', 'face value'],
    'marketing': ['balance of trade', 'big business', 'business', 'business dealings', 'buy', 'buying', 'buying power', 'buying up', 'catalog buying', 'coemption', 'commerce', 'commercial affairs'],
    'marketplace': ['agora', 'amphitheater', 'arena', 'athletic field', 'auditorium', 'auto show', 'background', 'bazaar', 'bear garden', 'boat show', 'bowl', 'boxing ring'],
    'marking': ['armory', 'aroma', 'attribute', 'badge', 'badge of office', 'badges', 'baton', 'birthmark', 'blaze', 'blazonry', 'blemish', 'blotch'],
    'marksman': ['admirable crichton', 'nimrod', 'zouave', 'adept', 'archer', 'artilleryman', 'artisan', 'artist', 'attache', 'authority', 'bersagliere', 'bowman'],
    'marksmanship': ['ability', 'address', 'adeptness', 'adroitness', 'airmanship', 'artfulness', 'artisanship', 'artistry', 'bravura', 'brilliance', 'capability', 'capacity'],
    'marmalade': ['jell-o', 'blancmange', 'candy', 'comfit', 'compote', 'confection', 'confectionery', 'confiture', 'conserve', 'frosting', 'gelatin', 'glaze'],
    'maroon': ['titian', 'titian-red', 'abandon', 'back out', 'beg off', 'bivouac', 'bricky', 'cardinal', 'carmine', 'carnation', 'carnelian', 'cast away'],
    'marooned': ['abandoned', 'aground', 'castaway', 'derelict', 'deserted', 'discarded', 'disused', 'forsaken', 'foundered', 'grounded', 'high and dry', 'jettisoned'],
    'marquis': ['brahman', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'blue blood', 'count', 'daimio', 'duke', 'earl', 'esquire'],
    'marred': ['bandy', 'bandy-legged', 'battered', 'beautiless', 'blemished', 'blighted', 'bloated', 'blotted', 'botched', 'bowlegged', 'bruised', 'cacophonic'],
    'marriage': ['anschluss', 'gretna green wedding', 'addition', 'affiliation', 'agglomeration', 'agglutination', 'aggregation', 'agreement', 'alliance', 'amalgamation', 'articulation', 'assimilation'],
    'married': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'bridal', 'cabalistic', 'confederate', 'confederated', 'conjugal', 'connubial', 'conspiratorial'],
    'marrow': ['abatis', 'axiom', 'axis', 'bottom', 'brains', 'center', 'center of action', 'center of gravity', 'centroid', 'centrum', 'chitterlings', 'cockscomb'],
    'marry': ['accouple', 'accumulate', 'affiliate', 'agglutinate', 'ally', 'amalgamate', 'amass', 'arrange a match', 'articulate', 'assemble', 'associate', 'band'],
    'mars': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'bellona', 'ceres'],
    'marsh': ['bog', 'cesspool', 'cloaca', 'cloaca maxima', 'drain', 'dump', 'fen', 'garbage dump', 'marshland', 'mire', 'morass', 'quag'],
    'marshal': ['adc', 'abbot of unreason', 'co', 'g-man', 'lord of misrule', 'mc', 'mp', 'od', 'accouple', 'accumulate', 'adduce', 'advance'],
    'marshy': ['boggish', 'boggy', 'damp', 'dampish', 'dank', 'dewy', 'fenny', 'humid', 'marish', 'mirish', 'miry', 'moist'],
    'marsupial': ['amphibian', 'aquatic', 'biped', 'camerated', 'canine', 'cannibal', 'capsular', 'carnivore', 'cellular', 'cetacean', 'chordate', 'cosmopolite'],
    'mart': ['agora', 'auto show', 'bazaar', 'boat show', 'boutique', 'campo', 'chain store', 'co-op', 'commercial complex', 'concession', 'cooperative', 'countinghouse'],
    'martial': ['aggressive', 'antagonistic', 'battling', 'bellicose', 'belligerent', 'bloodthirsty', 'bloody', 'bloody-minded', 'brave', 'chauvinist', 'chauvinistic', 'combative'],
    'martial law': ['corpus juris canonici', 'roman law', 'absolute monarchy', 'activation', 'admiralty law', 'aristocracy', 'arms race', 'autarchy', 'autocracy', 'autonomy', 'blue law', 'canon law'],
    'martinet': ['simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'autocrat', 'caesar', 'commissar', 'czar', 'despot', 'dictator'],
    'martyr': ['afflict', 'agonize', 'ail', 'angel', 'angel of light', 'angel of love', 'annihilate', 'archangel', 'beatified soul', 'bereave of life', 'bite', 'bloody'],
    'martyrdom': ['agony', 'anguish', 'atrocious pain', 'bane', 'blood', 'bloodletting', 'bloodshed', 'braining', 'clawing', 'confinement', 'cruciation', 'crucifixion'],
    'martyred': ['afflicted', 'agonized', 'angelic', 'archangelic', 'asleep', 'asleep in jesus', 'at rest', 'beatified', 'bereft of life', 'breathless', 'called home', 'canonized'],
    'marvel': ['admiration', 'amaze', 'amazement', 'astonishing thing', 'astonishment', 'astoundment', 'awe', 'be amazed', 'be astonished', 'beaut', 'beguilement', 'bewilderment'],
    'marvellous': ['amazing', 'astonishing', 'astounding', 'breathtaking', 'crazy', 'excellent', 'extraordinary', 'fabulous', 'fantastic', 'glorious', 'great', 'groovy'],
    'marvelous': ['agreeable', 'amazing', 'appalling', 'astonishing', 'astounding', 'awe-inspiring', 'awesome', 'awful', 'awing', 'beguiling', 'bewildering', 'confounding'],
    'marvelously': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'beguilingly', 'bewilderingly', 'conspicuously', 'copiously', 'divinely', 'eminently'],
    'marxism': ['bolshevism', 'castroism', 'communist information bureau', 'communist party', 'fabian socialism', 'fabianism', 'maoism', 'marxian socialism', 'marxism-leninism', 'saint-simonism', 'stalinism', 'titoism'],
    'marxist': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'communist sympathizer', 'cong', 'fabian'],
    'mascara': ['base', 'clown white', 'cold cream', 'compact', 'cosmetics', 'drugstore complexion', 'eye shadow', 'eyebrow pencil', 'foundation', 'foundation cream', 'greasepaint', 'hand cream'],
    'mascot': ['amulet', 'charm', 'fetish', 'fylfot', 'gammadion', 'good-luck charm', 'hoodoo', 'juju', 'love charm', 'luck', 'lucky bean', 'lucky piece'],
    'masculine': ['andric', 'animate', 'bull', 'common gender', 'feminine', 'gender', 'gentleman', 'gentlemanlike', 'gentlemanly', 'he', 'him', 'his'],
    'mash': ['tv dinner', 'abrade', 'alfresco meal', 'all sorts', 'assemblage', 'assortment', 'atomize', 'barbecue', 'barley', 'bear', 'beat', 'bird seed'],
    'masher': ['beau brummel', 'casanova', 'don juan', 'beau', 'beetle', 'blade', 'blood', 'boulevardier', 'chaser', 'cheese grater', 'clotheshorse', 'comminutor'],
    'mashing': ['abrasion', 'atomization', 'attrition', 'beating', 'brecciation', 'comminution', 'crumbling', 'crushing', 'detrition', 'disintegration', 'fragmentation', 'granulation'],
    'mask': ['kaffeeklatsch', 'aegis', 'affectation', 'air', 'alibi', 'anaglyph', 'apology', 'appearance', 'apply to', 'arm guard', 'aspect', 'backstop'],
    'masked': ['armored', 'camouflaged', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'coped', 'covered', 'covert', 'cowled', 'curtained'],
    'masochism': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'bisexuality', 'coprophilia', 'exhibitionism', 'fetishism', 'heterosexuality', 'homoeroticism', 'homosexualism'],
    'masochist': ['bugger', 'coprophiliac', 'erotomaniac', 'exhibitionist', 'fetishist', 'narcissist', 'necrophiliac', 'nymphomaniac', 'paraphiliac', 'pederast', 'pedophiliac', 'rapist'],
    'mason': ['carver', 'chaser', 'clay modeler', 'earth artist', 'figurer', 'figuriste', 'gem carver', 'graver', 'modeler', 'molder', 'monumental mason', 'sculptor'],
    'masonry': ['adobe', 'ashlar', 'brick', 'bricks and mortar', 'cement', 'clinker', 'concrete', 'covering materials', 'ferroconcrete', 'firebrick', 'flag', 'flagstone'],
    'masque': ['grand guignol', 'kaffeeklatsch', 'passion play', 'tom show', 'antimasque', 'audience success', 'bal', 'bal costume', 'bal masque', 'ball', 'ballet', 'barn dance'],
    'masquerade': ['kaffeeklatsch', 'accouter', 'act', 'act a part', 'act as', 'act out', 'acting', 'affectation', 'ape', 'aping', 'appearance', 'attitudinize'],
    'mass': ['g suit', 'negro spiritual', 'a mass of', 'a world of', 'abundance', 'accouple', 'accumulate', 'accumulation', 'acervation', 'acres', 'adhere', 'agglomerate'],
    'massacre': ['annihilate', 'annihilating', 'annihilation', 'assassination', 'assault', 'attack', 'battering', 'bloodbath', 'bloodshed', 'bump off', 'butcher', 'butchering'],
    'massage': ['bandage', 'bathe', 'care for', 'caress', 'cure', 'cushion', 'diagnose', 'doctor', 'ease', 'facial', 'facial massage', 'feel up'],
    'masses': ['cog', 'commonality', 'commonalty', 'creature', 'flunky', 'follower', 'hoi polloi', 'ignobile vulgus', 'inferior', 'junior', 'lightweight', 'lower class'],
    'massive': ['brobdingnagian', 'cyclopean', 'gargantuan', 'adamantine', 'amplitudinous', 'astronomical', 'awesome', 'awkward', 'big', 'boundless', 'broad-bodied', 'bulky'],
    'mast': ['advocate', 'alpenstock', 'antenna tower', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'barbican', 'bare pole', 'bearer'],
    'mastectomy': ['adenoidectomy', 'appendectomy', 'arteriectomy', 'castration', 'cholecystectomy', 'craniectomy', 'cricoidectomy', 'cystectomy', 'enterectomy', 'gastrectomy', 'hemorrhoidectomy', 'hysterectomy'],
    'master': ['a per se', 'ja', 'od', 'abecedarian', 'absorb', 'academic dean', 'ace', 'adept', 'administration', 'administrator', 'all-absorbing', 'amicus curiae'],
    'master of ceremonies': ['aftra', 'abbot of unreason', 'dj', 'lord of misrule', 'mc', 'anchor man', 'announcer', 'attorney', 'auteur', 'bailiff', 'ballyhoo man', 'barker'],
    'masterful': ['daedalian', 'absolute', 'absolutist', 'absolutistic', 'accomplished', 'adept', 'adroit', 'apt', 'arbitrary', 'archetypical', 'aristocratic', 'arrogant'],
    'masterfully': ['ably', 'adeptly', 'adroitly', 'agilely', 'aptly', 'arbitrarily', 'artfully', 'artistically', 'autocratically', 'brilliantly', 'capably', 'cleverly'],
    'mastermind': ['academician', 'ace', 'architect', 'authority', 'be responsible for', 'bookman', 'brains', 'call the signals', 'captain', 'carry on', 'classicist', 'clerk'],
    'masterpiece': ['archetype', 'art object', 'artifact', 'brainchild', 'bric-a-brac', 'child', 'classic', 'coinage', 'composition', 'concoction', 'creation', 'creature'],
    'mastership': ['ability', 'acme', 'address', 'adeptness', 'adroitness', 'aedileship', 'airmanship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'artfulness'],
    'mastery': ['cadmean victory', 'ko', 'pyrrhic victory', 'waterloo', 'ability', 'acme', 'address', 'adeptness', 'adroitness', 'aedileship', 'airmanship', 'apprehension'],
    'masthead': ['billhead', 'book stamp', 'bookplate', 'brand', 'broad arrow', 'cachet', 'check', 'colophon', 'counterfoil', 'countermark', 'docket', 'government mark'],
    'masticate': ['bite', 'bruise', 'champ', 'chaw', 'chew', 'chew the cud', 'chew up', 'chomp', 'chump', 'crunch', 'crush', 'gnash'],
    'mat': ['achromatic', 'achromic', 'agora', 'air mattress', 'amphitheater', 'anemic', 'arena', 'ashen', 'ashy', 'athletic field', 'auditorium', 'background'],
    'matador': ['cain', 'apache', 'assassin', 'assassinator', 'banderillero', 'bloodletter', 'bloodshedder', 'bravo', 'burker', 'butcher', 'button man', 'cannibal'],
    'match': ['congreve', 'congreve match', 'olympic games', 'olympics', 'a world-without-end bargain', 'accompany', 'accord', 'accumulate', 'adjust', 'admit of comparison', 'adversary', 'affiliation'],
    'matched': ['adapted', 'allied', 'assembled', 'associated', 'balanced', 'banded together', 'biconjugate', 'biform', 'bifurcated', 'bigeminate', 'bijugate', 'bilateral'],
    'matching': ['olympic games', 'olympics', 'allegory', 'analogous', 'analogy', 'balancing', 'bout', 'chromatic', 'cold', 'colorific', 'coloring', 'comparable'],
    'matchless': ['best', 'beyond compare', 'beyond comparison', 'champion', 'choice', 'easily first', 'elect', 'elite', 'facile princeps', 'for the best', 'greatest', 'handpicked'],
    'mate': ['od', 'accompanier', 'accompanist', 'accompanyist', 'ace', 'acquaintance', 'ally', 'alter ego', 'amigo', 'analogon', 'analogue', 'associate'],
    'mated': ['allied', 'assembled', 'associated', 'banded together', 'biconjugate', 'bigeminate', 'bijugate', 'bound', 'bracketed', 'collected', 'conjoined', 'conjugate'],
    'material': ['adamic', 'circean', 'formica', 'masonite', 'philistine', 'a propos', 'ab ovo', 'absolute', 'abundance', 'accumulation', 'actual', 'ad rem'],
    'materialism': ['adam', 'marxism', 'philistinism', 'animalism', 'animality', 'atomism', 'beastliness', 'behaviorism', 'bestiality', 'brutality', 'brutishness', 'carnal nature'],
    'materialistic': ['adamic', 'circean', 'cyrenaic', 'eleatic', 'epicurean', 'marxian', 'marxist', 'megarian', 'philistine', 'stoic', 'animal', 'animalistic'],
    'materiality': ['accent', 'air', 'applicability', 'application', 'appositeness', 'atom', 'atomic particles', 'bearing', 'being', 'body', 'brute matter', 'building block'],
    'materialization': ['christophany', 'masan', 'ouija', 'satanophany', 'accident', 'angelophany', 'apparition', 'appearance', 'appearing', 'arising', 'astral', 'astral spirit'],
    'materialize': ['affect', 'appear', 'approach', 'arise', 'be found', 'be realized', 'be revealed', 'become manifest', 'become visible', 'betoken', 'betray itself', 'body'],
    'materiel': ['abundance', 'accouterments', 'accumulation', 'amassment', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'backlog', 'budget', 'collection'],
    'maternal': ['adoring', 'affectionate', 'ancestorial', 'ancestral', 'caring', 'conjugal', 'demonstrative', 'devoted', 'doting', 'faithful', 'fatherlike', 'fatherly'],
    'maternity': ['affiliation', 'agnation', 'alliance', 'ancestry', 'blood', 'blood relationship', 'brotherhood', 'brothership', 'cognation', 'common ancestry', 'common descent', 'connection'],
    'mathematical': ['algebraic', 'analytic', 'arithmetical', 'close', 'constant', 'delicate', 'direct', 'even', 'exact', 'express', 'faithful', 'fine'],
    'mathematics': ['boolean algebra', 'euclidean geometry', 'fourier analysis', 'lagrangian function', 'algebra', 'algebraic geometry', 'algorism', 'algorithm', 'analysis', 'analytic geometry', 'applied mathematics', 'arithmetic'],
    'matinee idol': ['roscius', 'actor', 'actress', 'antagonist', 'bad guy', 'barnstormer', 'character', 'character actor', 'character man', 'character woman', 'child actor', 'cosset'],
    'mating': ['act of love', 'adultery', 'aphrodisia', 'ass', 'balling', 'carnal knowledge', 'climax', 'cohabitation', 'coition', 'coitus', 'coitus interruptus', 'commerce'],
    'matins': ['am', 'ack emma', 'mass', 'ante meridiem', 'bedtime prayer', 'camp meeting', 'church', 'church service', 'compline', 'devotions', 'divine service', 'duty'],
    'matriarch': ['methuselah', 'abbess', 'antediluvian', 'antique', 'back number', 'chatelaine', 'conservative', 'dad', 'dam', 'dame', 'dodo', 'dowager'],
    'matriarchal': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'civic', 'civil', 'constitutional', 'democratic', 'despotic', 'dictatorial'],
    'matricide': ['aborticide', 'fratricide', 'fungicide', 'genocide', 'germicide', 'herbicide', 'homicide', 'infanticide', 'insecticide', 'microbicide', 'parricide', 'patricide'],
    'matriculation': ['booking', 'cataloging', 'chronicling', 'enlistment', 'enrollment', 'entering', 'entry', 'impanelment', 'indexing', 'inscribing', 'inscription', 'insertion'],
    'matrilineage': ['affiliation', 'agnation', 'alliance', 'ancestry', 'blood', 'blood relationship', 'brotherhood', 'brothership', 'cognation', 'common ancestry', 'common descent', 'connection'],
    'matrimony': ['a world-without-end bargain', 'alliance', 'baptism', 'bed', 'bond of matrimony', 'bridebed', 'cohabitation', 'confirmation', 'conjugal bond', 'conjugal knot', 'coverture', 'extreme unction'],
    'matrix': ['platonic form', 'platonic idea', 'aesthetic form', 'archetype', 'art form', 'build', 'cast', 'chimney', 'chute', 'configuration', 'conformation', 'country rock'],
    'matron': ['eve', 'frau', 'abbess', 'better half', 'chatelaine', 'common-law wife', 'concubine', 'dame', 'daughter of eve', 'distaff', 'domina', 'donna'],
    'matronly': ['distaff', 'female', 'feminine', 'fortyish', 'gentlewomanlike', 'girlish', 'gynecic', 'gynecoid', 'gynic', 'kittenish', 'ladylike', 'little-girlish'],
    'matte': ['photostat', 'xerox', 'xerox copy', 'blowup', 'blueprint', 'contact printing', 'cyanotype', 'enlargement', 'glossy', 'hologram', 'lantern slide', 'microcopy'],
    'matted': ['byzantine', 'balled up', 'bristly', 'bushy', 'cirrose', 'complex', 'complicated', 'confounded', 'confused', 'convoluted', 'crabbed', 'daedal'],
    'matter': ['activities', 'activity', 'ado', 'affair', 'affairs', 'air', 'ambition', 'amount', 'amount to something', 'amplitude', 'annoyance', 'anxiety'],
    'matter of fact': ['absolute fact', 'accepted fact', 'actual fact', 'admitted fact', 'adventure', 'axiom', 'bald fact', 'bare fact', 'brutal fact', 'circumstance', 'cold fact', 'conceded fact'],
    'matter-of-fact': ['boring', 'colorless', 'direct', 'dry', 'dull', 'factual', 'featureless', 'flat', 'forthright', 'lifeless', 'mundane', 'prosaic'],
    'maturation': ['accomplishment', 'advance', 'advancement', 'aging', 'amplification', 'beautification', 'blossoming', 'budding', 'burgeoning', 'close', 'completing', 'completion'],
    'mature': ['accomplish', 'accrue', 'adult', 'advance', 'age', 'aged', 'all ready', 'all set', 'archetypical', 'armed', 'armed and ready', 'assemble'],
    'matured': ['adult', 'archetypical', 'blase', 'classic', 'complete', 'consummate', 'cosmopolitan', 'cosmopolite', 'developed', 'entire', 'exemplary', 'experienced'],
    'maturity': ['ability', 'accounts payable', 'accounts receivable', 'adulthood', 'adultness', 'age of consent', 'amount due', 'applicability', 'bad debts', 'bill', 'bills', 'borrowing'],
    'matzo': ['agnus dei', 'french bread', 'holy grail', 'host', 'irish soda bread', 'italian bread', 'pieta', 'sanctus bell', 'sangraal', 'ark', 'asperger', 'asperges'],
    'maudlin': ['addled', 'apish', 'asinine', 'bathetic', 'batty', 'beery', 'befooled', 'befuddled', 'beguiled', 'bemused', 'besotted', 'blind drunk'],
    'maul': ['abrade', 'abuse', 'assault', 'attack', 'bang', 'barbarize', 'bark', 'bash', 'baste', 'batter', 'beat', 'blemish'],
    'mausoleum': ['arch', 'barrow', 'beehive tomb', 'bone house', 'boundary stone', 'box grave', 'brass', 'burial', 'burial chamber', 'burial mound', 'bust', 'cairn'],
    'mauve': ['amethystine', 'lavender', 'lilac', 'livid', 'magenta', 'mulberry', 'orchid', 'pansy-purple', 'plum-colored', 'plum-purple', 'purple', 'purplescent'],
    'maven': ['adept', 'amateur', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'authority', 'bon vivant', 'cognoscente', 'collector', 'connaisseur', 'connoisseur', 'critic'],
    'maverick': ['bohemian', 'brahman', 'indian buffalo', 'agitator', 'alien', 'ass', 'aurochs', 'beat', 'beatnik', 'beef', 'beef cattle', 'beeves'],
    'maw': ['abdomen', 'abomasum', 'bay window', 'bazoo', 'beerbelly', 'belly', 'breadbasket', 'chaps', 'chops', 'craw', 'crop', 'diaphragm'],
    'mawkish': ['bad', 'barfy', 'bathetic', 'beery', 'brackish', 'cloying', 'fetid', 'foul', 'fulsome', 'gooey', 'gushing', 'high'],
    'maxim': ['procrustean law', 'a belief', 'adage', 'aphorism', 'apophthegm', 'apothegm', 'article of faith', 'axiom', 'brocard', 'byword', 'canon', 'cliche'],
    'maximal': ['abounding', 'abundant', 'acmatic', 'affluent', 'all-sufficing', 'ample', 'apical', 'aplenty', 'best', 'bottomless', 'bounteous', 'bountiful'],
    'maximize': ['add to', 'aggrandize', 'amplify', 'augment', 'boost', 'broaden', 'build', 'build up', 'elaborate', 'embellish', 'enhance', 'enlarge'],
    'maximum': ['abundance', 'acmatic', 'acme', 'affluence', 'all', 'ample sufficiency', 'ampleness', 'amplitude', 'apex', 'apical', 'apogee', 'authority'],
    'mayday': ['klaxon', 'sos', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert', 'all clear', 'beacon', 'blinking light'],
    'mayhem': ['bankruptcy', 'breakage', 'breakdown', 'chaos', 'collapse', 'commotion', 'confusion', 'crack-up', 'cripple', 'crippling', 'damage', 'destruction'],
    'mayor': ['alderman', 'archon', 'bailie', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor', 'city councilman', 'city father', 'city manager', 'commissar'],
    'mayoralty': ['aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'bishopric', 'chairmanship', 'chancellery', 'chancellorate', 'chancellorship', 'chiefery', 'chiefry'],
    'maze': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 'addle', 'addle the wits', 'amaze', 'baffle', 'ball up', 'bamboozle', 'beat', 'becloud', 'bedazzle'],
    'mazy': ['byzantine', 'aberrant', 'aberrative', 'adrift', 'affluent', 'afloat', 'alternating', 'ambagious', 'amorphous', 'anfractuous', 'balled up', 'bent'],
    'mc': ['aftra', 'abbot of unreason', 'dj', 'lord of misrule', 'anchor man', 'announcer', 'attorney', 'auteur', 'bailiff', 'ballyhoo man', 'barker', 'broadcaster'],
    'md': ['doctor of medicine', 'gp', 'allopath', 'allopathist', 'attending physician', 'coroner', 'country doctor', 'croaker', 'doc', 'doctor', 'family doctor', 'general practitioner'],
    'me': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'ego', 'ethical self', 'he', 'her', 'herself', 'him', 'himself'],
    'meadow': ['baygall', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'campo', 'everglade', 'fen', 'fenland', 'field', 'glade'],
    'meager': ['lenten', 'lilliputian', 'spartan', 'tom thumb', 'abstemious', 'angular', 'angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'ascetic', 'austere'],
    'meagre': ['bare', 'barren', 'bony', 'broad', 'deficient', 'emaciated', 'exiguous', 'gaunt', 'general', 'half-starved', 'inadequate', 'indefinite'],
    'meal': ['c ration', 'k ration', 'air pollution', 'allotment', 'allowance', 'attritus', 'barley', 'bird seed', 'board', 'bran', 'breakfast', 'carry too far'],
    'mealy': ['achromatic', 'achromic', 'anemic', 'ashen', 'ashy', 'bled white', 'bloodless', 'branny', 'cadaverous', 'chalklike', 'chalky', 'chloranemic'],
    'mealy-mouthed': ['ambiguous', 'artful', 'circumlocutory', 'deceitful', 'equivocal', 'equivocating', 'euphemistic', 'hesitant', 'hypocritical', 'indirect', 'mincing', 'oily'],
    'mealymouth': ['joseph surface', 'pecksniff', 'tartuffe', 'apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bootlick', 'bootlicker', 'brown-nose', 'brownie', 'canter'],
    'mealymouthed': ['pecksniffian', 'tartuffian', 'tartuffish', 'abject', 'adulatory', 'affected', 'backscratching', 'beggarly', 'bland', 'blandishing', 'blarneying', 'bootlicking'],
    'mean': ['herculean', 'lenten', 'mickey mouse', 'ok', 'spartan', 'abject', 'abominable', 'absolutely', 'abstemious', 'abstruse', 'abysmal', 'ace-high'],
    'meander': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 's-curve', 'ambages', 'amble', 'anfractuosity', 'bat around', 'bend', 'bending', 'bends', 'bow'],
    'meandering': ['byzantine', 'o-shaped', 'aberrant', 'aberrative', 'affluent', 'aimlessness', 'ambages', 'ambagious', 'anfractuosity', 'anfractuous', 'backhanded', 'balled up'],
    'meanie': ['sob', 'bastard', 'bugger', 'creep', 'fart', 'heel', 'hood', 'hooligan', 'jerk', 'louse', 'mother', 'pill'],
    'meaning': ['acceptation', 'aim', 'allegory', 'allusion', 'ambition', 'animus', 'arcane meaning', 'aspiration', 'assumption', 'balefulness', 'banefulness', 'bodefulness'],
    'meaningful': ['allegorical', 'associational', 'augural', 'big', 'connotational', 'connotative', 'consequential', 'considerable', 'deep', 'definable', 'demonstrative', 'denominative'],
    'meaningfully': ['ardently', 'effectively', 'eloquently', 'expressively', 'fervently', 'fluently', 'forcefully', 'glibly', 'glowingly', 'graphically', 'impressively', 'in glowing terms'],
    'meaningfulness': ['articulateness', 'command of language', 'command of words', 'effective style', 'eloquence', 'eloquent tongue', 'expression', 'expressiveness', 'facundity', 'felicitousness', 'felicity', 'gift of expression'],
    'meaningless': ['absurd', 'aimless', 'amorphous', 'asinine', 'blank', 'bootless', 'capricious', 'casual', 'designless', 'desultory', 'disarticulated', 'discontinuous'],
    'meanly': ['abjectly', 'abominably', 'arrantly', 'atrociously', 'balefully', 'basely', 'closefistedly', 'commonly', 'contemptibly', 'despicably', 'execrably', 'flagrantly'],
    'meanness': ['lenten fare', 'abjectness', 'abominableness', 'atrociousness', 'austerity', 'authoritarianism', 'baseness', 'bearishness', 'beggarliness', 'bigotry', 'bitchiness', 'blind side'],
    'means': ['mo', 'swiss bank account', 'action', 'ad hoc measure', 'algorithm', 'answer', 'apparatus', 'approach', 'artifice', 'assessed valuation', 'assets', 'assets and liabilities'],
    'meant': ['advised', 'aimed', 'aimed at', 'assumed', 'calculated', 'conscious', 'considered', 'contemplated', 'deliberate', 'deliberated', 'designed', 'envisaged'],
    'meanwhile': ['ad interim', 'at a stretch', 'between acts', 'betweentimes', 'betweenwhiles', 'during the interval', 'during the time', 'en attendant', 'for a time', 'for the meantime', 'for the moment', 'for the nonce'],
    'measles': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'measly': ['abject', 'abominable', 'allergic', 'anemic', 'apoplectic', 'arrant', 'arthritic', 'atrocious', 'base', 'beggarly', 'bilious', 'cancerous'],
    'measurable': ['appraisable', 'appreciable', 'assessable', 'calculable', 'computable', 'countable', 'determinable', 'estimable', 'fathomable', 'gaugeable', 'mensurable', 'meterable'],
    'measure': ['alexandrine', 'spenserian stanza', 'stabreim', 'accent', 'accent mark', 'accentuation', 'accommodate', 'accommodation', 'accomplished fact', 'accomplishment', 'accord', 'achievement'],
    'measure for measure': ['alternation', 'amends', 'atonement', 'balancing', 'battledore and shuttlecock', 'blow for blow', 'commutation', 'compensation', 'cooperation', 'counteraction', 'counterbalancing', 'counterchange'],
    'measure out': ['administer', 'deal', 'deal out', 'disburse', 'dispense', 'disperse', 'dispose', 'distribute', 'divide', 'divvy', 'dole', 'dole out'],
    'measure up to': ['admit of comparison', 'amount to', 'balance', 'be commensurable', 'be comparable', 'break even', 'check out', 'come to', 'come up to', 'compare', 'compare to', 'compare with'],
    'measured': ['accordant', 'admeasured', 'alike', 'alternate', 'an', 'antispastic', 'any', 'appraised', 'assessed', 'automatic', 'balanced', 'beating'],
    'measurement': ['accounting', 'acreage', 'amount', 'amplitude', 'analyzing', 'appraisal', 'appraisement', 'appraising', 'appreciation', 'area', 'ascertainment', 'assessing'],
    'measuring': ['appraisal', 'appraisement', 'approximation', 'approximative', 'assessment', 'assize', 'assizement', 'calculation', 'chorographic', 'computation', 'correction', 'determination'],
    'meat': ['brazil nut', 'tlc', 'act of love', 'adultery', 'almond', 'almond paste', 'amande', 'amande douce', 'amandes mondees', 'aphrodisia', 'aspic', 'ass'],
    'meat eater': ['brillat-savarin', 'lucullus', 'board-and-roomer', 'boarder', 'bon vivant', 'cannibal', 'carnivore', 'connoisseur of food', 'consumer', 'diner', 'diner-out', 'eater'],
    'meat eating': ['cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'dining', 'eating', 'feeding', 'flesh-eating', 'fruitarian', 'gastronomic', 'gluttonous'],
    'meathead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead'],
    'meathooks': ['claws', 'clutches', 'digits', 'fangs', 'fingernails', 'fingers', 'hands', 'hooks', 'jaws', 'mandibles', 'maxillae', 'mitts'],
    'meaty': ['adipose', 'allegorical', 'associational', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby'],
    'mechanic': ['aeromechanic', 'aeronautical engineer', 'aircraftsman', 'apprentice', 'artificer', 'artisan', 'artist', 'cobbler', 'craftsman', 'craftswoman', 'doctor', 'fixer'],
    'mechanical': ['accordant', 'aeromechanical', 'alike', 'automated', 'automatic', 'balanced', 'biomechanical', 'blind', 'cold', 'colorless', 'compulsive', 'conditioned'],
    'mechanics': ['newtonian physics', 'acoustics', 'aerophysics', 'applied physics', 'art', 'astrophysics', 'basic conductor physics', 'biophysics', 'chemical physics', 'craft', 'cryogenics', 'crystallography'],
    'mechanism': ['charlie mccarthy', 'marxism', 'action', 'agency', 'agent', 'ancilla', 'animalism', 'apparatus', 'appliance', 'approach', 'arrangement', 'art'],
    'mechanistic': ['cyrenaic', 'eleatic', 'epicurean', 'marxian', 'marxist', 'megarian', 'stoic', 'aeromechanical', 'animist', 'animistic', 'atomistic', 'biomechanical'],
    'medal': ['bronze star medal', 'croix de guerre', 'distinguished conduct medal', 'distinguished flying cross', 'distinguished service cross', 'distinguished service medal', 'distinguished service order', 'distinguished unit citation', 'medaille militaire', 'military cross', 'navy cross', 'unit citation'],
    'medallion': ['bronze star medal', 'croix de guerre', 'distinguished conduct medal', 'distinguished flying cross', 'distinguished service cross', 'distinguished service medal', 'distinguished service order', 'distinguished unit citation', 'medaille militaire', 'military cross', 'navy cross', 'unit citation'],
    'meddle': ['paul-pry', 'advise', 'advocate', 'arrest', 'bottle up', 'brief', 'busybody', 'butt in', 'check', 'coach', 'confer', 'consult with'],
    'meddler': ['dutch uncle', 'paul pry', 'polonius', 'admonisher', 'adviser', 'backseat driver', 'busybody', 'butt-in', 'buttinsky', 'confidant', 'consultant', 'counsel'],
    'meddling': ['busy', 'busybody', 'butting-in', 'forward', 'forwardness', 'impertinence', 'impertinent', 'inquisitive', 'inquisitiveness', 'intermeddling', 'intrusiveness', 'meddlesome'],
    'media': ['communication engineering', 'communication explosion', 'communication technology', 'communication theory', 'communications', 'communications engineer', 'communications industry', 'communications medium', 'communications network', 'electrical communication', 'electronic communication', 'electronic communications'],
    'medial': ['amidships', 'average', 'banal', 'center', 'centermost', 'central', 'common', 'core', 'equatorial', 'equidistant', 'fair', 'fairish'],
    'median': ['amidships', 'average', 'balance', 'banal', 'center', 'centermost', 'central', 'common', 'core', 'diameter', 'diaphragm', 'equator'],
    'mediate': ['accommodate', 'act between', 'act for', 'adjust', 'advance', 'arbitrate', 'arrange matters', 'assist', 'bargain', 'be instrumental', 'bring to terms', 'bring together'],
    'mediating': ['agential', 'agentival', 'agentive', 'arbitrational', 'arbitrative', 'assisting', 'coming between', 'conducive', 'employable', 'facilitating', 'favoring', 'forwarding'],
    'mediation': ['united nations troops', 'agency', 'appeasement', 'calming', 'conciliation', 'detente', 'device', 'dulcification', 'easing of relations', 'expedient', 'going between', 'instrumentality'],
    'mediator': ['charlie mccarthy', 'agent', 'ancilla', 'appeaser', 'appliance', 'arbiter', 'arbitrator', 'broker', 'conciliator', 'connection', 'contact', 'contrivance'],
    'mediatory': ['christlike', 'christly', 'arbitrational', 'arbitrative', 'celestial', 'coming between', 'divine', 'empyrean', 'godlike', 'godly', 'going between', 'heavenly'],
    'medicaid': ['adc', 'medicare', 'aerospace medicine', 'biomedicine', 'clinical medicine', 'comparative medicine', 'constitutional medicine', 'cradle-to-grave security', 'dosimetric medicine', 'experimental medicine', 'guaranteed annual income', 'guaranteed income'],
    'medical': ['allopathic', 'chiropodic', 'chiropractic', 'clinical', 'croaker', 'dental', 'doc', 'doctor', 'exodontic', 'homeopathic', 'hydropathic', 'iatric'],
    'medical examiner': ['doctor of medicine', 'gp', 'md', 'allopath', 'allopathist', 'attending physician', 'autopsy', 'coroner', 'country doctor', 'croaker', 'doc', 'doctor'],
    'medicare': ['adc', 'medicaid', 'aerospace medicine', 'biomedicine', 'clinical medicine', 'comparative medicine', 'constitutional medicine', 'cradle-to-grave security', 'dosimetric medicine', 'experimental medicine', 'guaranteed annual income', 'guaranteed income'],
    'medication': ['balm', 'balsam', 'curative measures', 'cure', 'drops', 'drug', 'electuary', 'elixir', 'ethical drug', 'first aid', 'generic name', 'healing arts'],
    'medicinal': ['adjuvant', 'alexipharmic', 'alterative', 'analeptic', 'corrective', 'curative', 'healing', 'iatric', 'medical', 'medicative', 'pharmaceutical', 'remedial'],
    'medicine': ['anatomy', 'anesthesiology', 'audiology', 'bacteriology', 'balm', 'balsam', 'cardiology', 'chiropody', 'corpse reviver', 'cure', 'cure-all', 'dental surgery'],
    'medicine man': ['charlatan', 'exorciser', 'exorcist', 'horse doctor', 'medicaster', 'medicine monger', 'mundunugu', 'obeah doctor', 'quack', 'quacksalver', 'shaman', 'shamanist'],
    'medico': ['doctor of medicine', 'gp', 'md', 'md', 'allopath', 'allopathist', 'attending physician', 'coroner', 'country doctor', 'croaker', 'doc', 'doctor'],
    'mediocre': ['adulterated', 'amidships', 'artless', 'average', 'bad', 'banal', 'base', 'betwixt and between', 'blemished', 'central', 'common', 'commonplace'],
    'mediocrity': ['middle america', 'a nobody', 'a nothing', 'adulteration', 'average', 'balance', 'baseness', 'bourgeoisie', 'burgherdom', 'center', 'cipher', 'common man'],
    'meditate': ['be abstracted', 'brood', 'brood over', 'cerebrate', 'chaw', 'chew over', 'chew the cud', 'cogitate', 'con over', 'conceive', 'consider', 'contemplate'],
    'meditation': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'a wise passiveness', 'absorbed attention', 'absorption', 'advisement', 'aid prayer', 'appeal'],
    'meditative': ['absent', 'absentminded', 'absorbed', 'absorbed in', 'abstracted', 'bemused', 'brooding', 'buried in', 'castle-building', 'caught up in', 'cogitative', 'cognitive'],
    'medium': ['charlie mccarthy', 'actor', 'agency', 'agent', 'air brush', 'ambiance', 'ambience', 'ambient', 'amidships', 'ancilla', 'appliance', 'approach'],
    'medium of exchange': ['and pence', 'cash', 'circulating medium', 'coinage', 'coined liberty', 'cold cash', 'currency', 'dollars', 'emergency money', 'filthy lucre', 'fractional currency', 'gold'],
    'medley': ['agglomeration', 'all sorts', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'assemblage', 'assortment', 'bicolor', 'bicolored', 'blend', 'blended'],
    'medusa': ['argus', 'briareus', 'cerberus', 'charybdis', 'circe', 'cyclops', 'echidna', 'euryale', 'gorgon', 'harpy', 'hydra', 'loch ness monster'],
    'meed': ['allotment', 'allowance', 'amends', 'apportionment', 'atonement', 'big end', 'bigger half', 'bit', 'bite', 'blood money', 'budget', 'carrot'],
    'meek': ['abject', 'accommodating', 'acquiescent', 'adapting', 'adaptive', 'adjusting', 'amenable', 'bland', 'broken', 'chastened', 'compliant', 'deferential'],
    'meekly': ['abjectly', 'acquiescently', 'compliantly', 'gently', 'humbly', 'like a lamb', 'mildly', 'modestly', 'on all fours', 'on bended knee', 'pacifically', 'passively'],
    'meerschaum': ['missouri meerschaum', 'accommodate', 'act between', 'adjust', 'arbitrate', 'bargain', 'briar', 'briar pipe', 'calean', 'calumet', 'churchwarden', 'clay'],
    'meet': ['highland games', 'olympiad', 'olympic games', 'olympics', 'abide by', 'abut', 'accepted', 'accommodate', 'accommodate with', 'accommodated', 'accord', 'accost'],
    'meet head on': ['affront', 'alight upon', 'antagonize', 'be antipathetic', 'be inimical', 'beard', 'beat against', 'bell the cat', 'bite the bullet', 'brave', 'brazen', 'brazen out'],
    'meeting': ['mass', 'olympic games', 'olympics', 'accompanying', 'accordant', 'accumulated', 'agglomerate', 'agglomeration', 'agglutination', 'aggregate', 'aggregation', 'agreeing'],
    'meeting of minds': ['acclamation', 'accord', 'accordance', 'agreement', 'agreement of all', 'chorus', 'common assent', 'common consent', 'concert', 'concord', 'concordance', 'concurrence'],
    'meetinghouse': ['amphitheater', 'arena', 'assembly hall', 'auditorium', 'basilica', 'bethel', 'cathedral', 'cathedral church', 'chapel', 'church', 'church house', 'concert hall'],
    'megacycles': ['af', 'cps', 'ehf', 'hf', 'hz', 'mf', 'rf', 'shf', 'uhf', 'vhf', 'vlf', 'audio frequency'],
    'melancholia': ['abstraction', 'abulia', 'aching heart', 'agony', 'agony of mind', 'alienation', 'anguish', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'bale'],
    'melancholic': ['ambivert', 'atrabiliar', 'atrabilious', 'blase', 'blue', 'brooder', 'choleric', 'cycloid', 'cyclothyme', 'cyclothymic', 'depressing', 'depressive'],
    'melancholy': ['absorption', 'abstraction', 'aching heart', 'agony', 'agony of mind', 'anguish', 'atrabiliar', 'atrabilious', 'bale', 'beetle-browed', 'bitterness', 'black'],
    'melange': ['all sorts', 'assemblage', 'assortment', 'broad spectrum', 'conglomeration', 'gallimaufry', 'hash', 'hodgepodge', 'hotchpot', 'hotchpotch', 'jumble', 'magpie'],
    'meld': ['anschluss', 'add', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'amalgamate', 'amalgamation', 'assimilate', 'assimilation'],
    'melding': ['anschluss', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'amalgamation', 'assimilation', 'association', 'blend', 'blending'],
    'melee': ['ado', 'bother', 'brawl', 'broil', 'brouhaha', 'brush', 'commotion', 'disturbance', 'dogfight', 'donnybrook', 'donnybrook fair', 'dustup'],
    'meliorate': ['accommodate', 'acculturate', 'adapt', 'adjust', 'advance', 'air', 'alter', 'ameliorate', 'amend', 'be changed', 'be converted into', 'be renewed'],
    'mellifluous': ['accordant', 'achingly sweet', 'affable', 'agreeable', 'agreeable-sounding', 'ambrosial', 'amiable', 'amicable', 'appealing', 'ariose', 'arioso', 'bittersweet'],
    'mellow': ['achingly sweet', 'addled', 'advance', 'affable', 'age', 'aged', 'agreeable', 'agreeable-sounding', 'amiable', 'amicable', 'appealing', 'ariose'],
    'mellowness': ['affability', 'agreeability', 'agreeableness', 'amenity', 'amiability', 'amicability', 'bassness', 'bliss', 'blissfulness', 'compatibility', 'complaisance', 'congeniality'],
    'melodeon': ['hammond organ', 'baroque organ', 'calliope', 'calliophone', 'choralcelo', 'electric organ', 'electro-pneumatic organ', 'harmonium', 'hydraulic organ', 'melodica', 'orchestrelle', 'organ'],
    'melodic': ['achingly sweet', 'agreeable', 'agreeable-sounding', 'appealing', 'ariose', 'arioso', 'canorous', 'cantabile', 'catchy', 'dulcet', 'euphonic', 'euphonious'],
    'melodious': ['achingly sweet', 'agreeable', 'agreeable-sounding', 'appealing', 'ariose', 'arioso', 'canorous', 'cantabile', 'catchy', 'dulcet', 'euphonic', 'euphonious'],
    'melodist': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'arranger', 'ballad maker', 'balladeer', 'balladist', 'balladmonger', 'baritenor', 'baritone', 'bass'],
    'melodrama': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'blood and thunder', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger'],
    'melodramatic': ['barnumesque', 'actor-proof', 'all-star', 'ballet', 'balletic', 'cinematic', 'cinematographic', 'cloak-and-dagger', 'dramatic', 'dramatical', 'dramaturgic', 'emotionalistic'],
    'melodramatics': ['thespian art', 'amateur theatricals', 'blood and thunder', 'demonstrativeness', 'dramatic art', 'dramatic form', 'dramatic irony', 'dramatic stroke', 'dramatic structure', 'dramaticism', 'dramatics', 'dramatism'],
    'melody': ['air', 'aria', 'bel canto', 'canto', 'cantus', 'descant', 'diapason', 'dulcetness', 'euphoniousness', 'euphony', 'harmony', 'lay'],
    'melt': ['affect', 'assuage', 'bake', 'be consumed', 'be gone', 'blend', 'broil', 'cease', 'cease to be', 'cease to exist', 'colliquate', 'come home to'],
    'melt away': ['abate', 'ablate', 'bate', 'be annihilated', 'be consumed', 'be destroyed', 'be eaten away', 'be gone', 'be no more', 'be wiped out', 'cease', 'cease to be'],
    'melt down': ['colliquate', 'concentrate', 'cut', 'decoagulate', 'decoct', 'defrost', 'deliquesce', 'dissolve', 'distill', 'essentialize', 'express', 'fluidify'],
    'melted': ['abject', 'apologetic', 'contrite', 'decoagulated', 'deliquescent', 'fused', 'fusible', 'humble', 'humbled', 'in solution', 'in suspension', 'liquefied'],
    'melting': ['adoring', 'affectionate', 'blackout', 'bleeding', 'blocking', 'charitable', 'clement', 'colliquation', 'colliquative', 'commiserative', 'compassionate', 'condolent'],
    'melting pot': ['america', 'columbia', 'land of liberty', 'us', 'usa', 'uncle sugar', 'united states', 'yankeeland', 'agitator', 'alembic', 'anvil', 'beater'],
    'member': ['greek', 'affiliate', 'appendage', 'arm', 'associate', 'belonger', 'bough', 'branch', 'brother', 'card-carrier', 'card-carrying member', 'cardholder'],
    'membership': ['admissibility', 'admission', 'affiliates', 'affiliation', 'assimilation', 'associates', 'association', 'body of affiliates', 'companionship', 'company', 'completeness', 'comprehension'],
    'membrane': ['allantoic membrane', 'amnion', 'amniotic sac', 'arachnoid membrane', 'basement membrane', 'coat', 'coating', 'collop', 'conjuctiva', 'covering', 'cut', 'deal'],
    'membranous': ['filmy', 'foliaceous', 'foliated', 'in layers', 'lamellar', 'lamellate', 'lamellated', 'lamelliform', 'laminate', 'laminated', 'laminous', 'leaflike'],
    'memento': ['arch', 'barrow', 'boundary stone', 'brass', 'bust', 'cairn', 'cenotaph', 'column', 'commemoration', 'cromlech', 'cross', 'cup'],
    'memo': ['adversaria', 'aide-memoire', 'annotation', 'chit', 'directive', 'docket', 'entry', 'footnote', 'item', 'jotting', 'marginal note', 'marginalia'],
    'memoir': ['clio', 'muse of history', 'account', 'accounts', 'adventures', 'adversaria', 'aide-memoire', 'anecdote', 'annals', 'annotation', 'article', 'autobiography'],
    'memorabilia': ['clio', 'muse of history', 'adventures', 'ana', 'annals', 'archives', 'autobiography', 'biographical material', 'biographical records', 'biographical sketch', 'biography', 'case history'],
    'memorable': ['catchy', 'celebrated', 'conspicuous', 'deathless', 'distinguished', 'eminent', 'esteemed', 'estimable', 'eventful', 'exceptional', 'extraordinary', 'great'],
    'memorandum': ['adversaria', 'aide-memoire', 'annotation', 'announcement', 'chit', 'cue', 'diary', 'directive', 'dispatch', 'docket', 'entry', 'epistle'],
    'memorial': ['clio', 'muse of history', 'account', 'adventures', 'adversaria', 'aide-memoire', 'annals', 'annotation', 'arch', 'autobiography', 'barrow', 'biographical sketch'],
    'memorialize': ['accost', 'apply to', 'approach', 'beat the drum', 'bespeak', 'blow the trumpet', 'bring to mind', 'call on', 'call upon', 'celebrate', 'circulate a petition', 'commemorate'],
    'memorize': ['commit to memory', 'con', 'get', 'get by heart', 'get letter-perfect', 'have by heart', 'know by heart', 'learn', 'learn by heart', 'learn verbatim', 'parrot', 'recite'],
    'memory': ['ram', 'anamnesis', 'anniversaries', 'archetypal pattern', 'archetype', 'awareness', 'celebrating', 'celebration', 'ceremony', 'cognizance', 'commemoration', 'consciousness'],
    'men': ['everyman', 'john doe', 'public', 'body politic', 'citizenry', 'common man', 'commonwealth', 'community', 'community at large', 'crew', 'employees', 'estate'],
    'menace': ['abuse', 'afflict', 'aggrieve', 'alarm', 'apprehend', 'approach', 'await', 'be imminent', 'be in store', 'befoul', 'bewitch', 'blight'],
    'menacing': ['about to be', 'abusive', 'alarming', 'already in sight', 'apocalyptic', 'approaching', 'at hand', 'bad', 'baleful', 'baneful', 'black', 'bludgeoning'],
    'menage': ['ancestral halls', 'brood', 'children', 'chimney corner', 'domestic economy', 'domestic management', 'family', 'family homestead', 'fireplace', 'fireside', 'folks', 'foyer'],
    'menagerie': ['festschrift', 'ana', 'anthology', 'aquarium', 'body', 'chrestomathy', 'collectanea', 'collection', 'compilation', 'corpus', 'data', 'florilegium'],
    'mend': ['great leap forward', 'acculturate', 'advance', 'advancement', 'ameliorate', 'amelioration', 'amend', 'amendment', 'ascent', 'better', 'bettering', 'betterment'],
    'mendable': ['ameliorable', 'amendable', 'correctable', 'corrigible', 'curable', 'emendable', 'fixable', 'improvable', 'medicable', 'reclaimable', 'recoverable', 'rectifiable'],
    'mendacious': ['deceitful', 'dishonest', 'equivocal', 'equivocating', 'erroneous', 'fallacious', 'false', 'fibbing', 'forsworn', 'knavish', 'lying', 'paltering'],
    'mendacity': ['blague', 'boggling', 'caviling', 'cock-and-bull story', 'credibility gap', 'dishonesty', 'dodging', 'equivocation', 'exaggeration', 'fairy tale', 'falsehood', 'falsity'],
    'mendicancy': ['bare cupboard', 'bare subsistence', 'beggarliness', 'beggary', 'begging', 'bumming', 'cadging', 'deprivation', 'destitution', 'empty purse', 'grinding poverty', 'gripe'],
    'mendicant': ['albigensian', 'catharist', 'franciscan', 'sabbatarian', 'trappist', 'waldensian', 'abbacomes', 'abbot', 'abstainer', 'abstinent', 'anchorite', 'anchoritic'],
    'mending': ['great leap forward', 'advance', 'advancement', 'advancing', 'amelioration', 'ameliorative', 'amendment', 'amends', 'ascent', 'bettering', 'betterment', 'boost'],
    'menial': ['attendant', 'attending', 'base', 'blue-collar worker', 'bootlicker', 'breadwinner', 'brown-nosing', 'casual', 'casual laborer', 'common laborer', 'cringing', 'day laborer'],
    'meningitis': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'adenoiditis', 'adrenitis', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery'],
    'meniscus': ['achromatic lens', 'astigmatic lens', 'burning glass', 'camera', 'coated lens', 'concave lens', 'concavo-convex lens', 'condenser', 'convex lens', 'crescent', 'crescent moon', 'eyeglass'],
    'menorah': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'ark', 'asperger', 'asperges', 'aspergillum', 'bambino', 'beadroll'],
    'mensch': ['acceptable person', 'capital fellow', 'diamond', 'gem', 'gentleman', 'good fellow', 'good lot', 'good man', 'good person', 'good sort', 'good woman', 'honest man'],
    'menstrual': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'decennial', 'diurnal', 'fortnightly'],
    'mensuration': ['altimetry', 'appraisal', 'appraisement', 'approximation', 'assessment', 'assize', 'assizement', 'bathymetry', 'biometrics', 'biometry', 'cadastration', 'calculation'],
    'mental': ['abnormal', 'abstract', 'affective', 'balmy', 'bananas', 'barmy', 'batty', 'bereft of reason', 'bonkers', 'brainsick', 'cerebral', 'certifiable'],
    'mental block': ['agnosia', 'block', 'blocking', 'conversion', 'defense mechanism', 'delirium', 'delusion', 'delusion of persecution', 'disorientation', 'flight of ideas', 'hallucination', 'hallucinosis'],
    'mental deficiency': ['aberration', 'abnormality', 'alienation', 'amentia', 'arrested development', 'backwardness', 'blithering idiocy', 'brain damage', 'brainsickness', 'clouded mind', 'craziness', 'cretinism'],
    'mental health': ['hygeia', 'balance', 'bloom', 'contact with reality', 'emotional health', 'fitness', 'flush', 'glow', 'health', 'healthy mind', 'lucid interval', 'lucidity'],
    'mental hospital': ['va hospital', 'asylum', 'base hospital', 'bedlam', 'bughouse', 'clinic', 'community hospital', 'convalescent home', 'convalescent hospital', 'evacuation hospital', 'field hospital', 'general hospital'],
    'mental illness': ['aberration', 'abnormality', 'alienation', 'brain damage', 'brain disease', 'brainsickness', 'clouded mind', 'crack-up', 'craziness', 'daftness', 'dementedness', 'dementia'],
    'mental picture': ['vorstellung', 'concept', 'conception', 'conceptualization', 'eidetic image', 'envisaging', 'envisioning', 'image', 'imagery', 'imagery study', 'imaging', 'imagism'],
    'mentality': ['iq', 'vernunft', 'acuity', 'acumen', 'apprehension', 'attitude', 'bent', 'brain', 'brains', 'caliber', 'capacity', 'comprehension'],
    'mentally retarded': ['arrested', 'babbling', 'backward', 'blithering', 'burbling', 'crackbrained', 'cracked', 'crazy', 'cretinistic', 'cretinous', 'dithering', 'driveling'],
    'mention': ['parthian shot', 'accolade', 'account', 'acknowledge', 'acquaint', 'acquaintance', 'address', 'address to', 'adduce', 'advert', 'advertise', 'advertise of'],
    'mentor': ['dutch uncle', 'polonius', 'abecedarian', 'admonisher', 'adviser', 'authority', 'backseat driver', 'buttinsky', 'certified teacher', 'coach', 'confidant', 'consultant'],
    'menu': ['account', 'agenda', 'batting order', 'bill', 'bill of fare', 'bill of lading', 'blueprint', 'books', 'budget', 'calendar', 'card', 'carte'],
    'meow': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'bray', 'call', 'caterwaul'],
    'mercenary': ['a hog for', 'acquisitive', 'adventurer', 'all-devouring', 'assistant', 'avaricious', 'avid', 'bottomless', 'bought', 'bribable', 'chartered', 'condottiere'],
    'merchandise': ['advertise', 'be in', 'buy and sell', 'carry', 'close out', 'commodities', 'convert into cash', 'cut under', 'deal in', 'distribute', 'dump', 'effect a sale'],
    'merchandising': ['agency', 'barter', 'bartering', 'brokerage', 'buying and selling', 'consumer preference study', 'consumer research', 'consumer survey', 'dealing', 'direct-mail selling', 'doing business', 'exchange'],
    'merchant': ['agent', 'baron', 'broker', 'business', 'businessman', 'caterer', 'chandler', 'commercial', 'commissariat', 'commissary', 'dealer', 'distributor'],
    'merchant marine': ['naval construction battalion', 'rn', 'royal navy', 'seabees', 'usn', 'united states navy', 'argosy', 'armada', 'bottoms', 'coast guard', 'division', 'escadrille'],
    'merciful': ['accepting', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'beneficent', 'benign', 'benignant', 'big', 'bleeding', 'boundless'],
    'mercifulness': ['acceptance', 'bleeding heart', 'bowels of compassion', 'clemency', 'clementness', 'compassion', 'compassionateness', 'easiness', 'easygoingness', 'forbearance', 'forbearing', 'gentleness'],
    'merciless': ['atrocious', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'bloody', 'bowelless', 'brutal', 'brutish', 'callous', 'cold', 'crude'],
    'mercurial': ['active', 'activist', 'activistic', 'adrift', 'adroit', 'afloat', 'agile', 'alive', 'alternating', 'ambitendent', 'ambivalent', 'amorphous'],
    'mercury': ['april showers', 'gyropilot', 'proteus', 'antelope', 'arrow', 'automatic pilot', 'blue darter', 'blue streak', 'boatheader', 'boatsteerer', 'cannonball', 'chameleon'],
    'mercury poisoning': ['minamata disease', 'altitude sickness', 'anoxemia', 'anoxia', 'anoxic anoxia', 'anthrax', 'black lung', 'caisson disease', 'chilblain', 'decompression sickness', 'frostbite', 'immersion foot'],
    'mercy': ['acceptance', 'act of grace', 'act of kindness', 'benefaction', 'beneficence', 'benefit', 'benevolence', 'benignancy', 'benignity', 'blessing', 'caritas', 'charity'],
    'mercy killing': ['bane', 'blood', 'bloodletting', 'bloodshed', 'braining', 'dealing death', 'destruction', 'destruction of life', 'dispatch', 'euthanasia', 'execution', 'extermination'],
    'mere': ['absolute', 'austere', 'bare', 'basic', 'chaste', 'elementary', 'essential', 'fundamental', 'homely', 'homespun', 'homogeneous', 'indivisible'],
    'mere nothing': ['a little thing', 'bagatelle', 'hardly anything', 'inessential', 'insignificancy', 'marginal matter', 'matter of indifference', 'minor matter', 'naught', 'next to nothing', 'nihility', 'no great matter'],
    'merely': ['after a fashion', 'alone', 'appreciably', 'at any rate', 'at best', 'at bottom', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst'],
    'meretricious': ['gongoresque', 'johnsonian', 'affected', 'apparent', 'bedizened', 'beggarly', 'beneath contempt', 'big-sounding', 'blatant', 'brazen', 'brazenfaced', 'cheap'],
    'merge': ['accouple', 'accumulate', 'act in concert', 'act together', 'add', 'adhere', 'admix', 'affiliate', 'agglutinate', 'alloy', 'ally', 'alter into'],
    'merged': ['allied', 'amalgamated', 'assembled', 'assimilated', 'associated', 'banded together', 'blended', 'bound', 'bracketed', 'collected', 'combinative', 'combinatory'],
    'merger': ['anschluss', 'addition', 'admixture', 'affiliation', 'agglomeration', 'agglutination', 'aggregation', 'agreement', 'alignment', 'alliance', 'alloyage', 'amalgamation'],
    'merging': ['acme', 'agglomeration', 'agglutination', 'aggregation', 'apex', 'apogee', 'articulation', 'associative', 'blending', 'bond', 'bracketing', 'climax'],
    'meridian': ['antarctic zone', 'arctic circle', 'arctic zone', 'frigid zones', 'lambert conformal projection', 'mercator projection', 'miller projection', 'torrid zone', 'tropic of cancer', 'tropic of capricorn', 'variable zones', 'acmatic'],
    'meringue': ['jell-o', 'blancmange', 'breakers', 'candy', 'collar', 'comfit', 'compote', 'confection', 'confectionery', 'confiture', 'conserve', 'foam'],
    'merit': ['accent', 'advantage', 'advantageousness', 'agreeableness', 'arete', 'assets', 'auspiciousness', 'award', 'be deserving', 'be entitled to', 'be worthy of', 'beneficialness'],
    'merited': ['appropriate', 'balanced', 'condign', 'defensible', 'deserved', 'due', 'earned', 'entitled', 'equitable', 'even', 'evenhanded', 'fair'],
    'meritorious': ['admirable', 'ascribable', 'attributable', 'beyond all praise', 'commendable', 'creditable', 'deserving', 'due', 'entitled to', 'esteemed', 'estimable', 'excellent'],
    'mermaid': ['davy', 'davy jones', 'dylan', 'neptune', 'nereid', 'nereus', 'oceanid', 'oceanus', 'poseidon', 'thetis', 'triton', 'varuna'],
    'merriment': ['amusement', 'blithesomeness', 'buoyancy', 'celebration', 'cheer', 'cheerfulness', 'conviviality', 'elation', 'enjoyment', 'exhilaration', 'exuberance', 'exultation'],
    'merry': ['addled', 'animated', 'beery', 'bemused', 'besotted', 'blind drunk', 'blithe', 'blithesome', 'boon', 'buoyant', 'buxom', 'carefree'],
    'merry-go-round': ['ferris wheel', 'carousel', 'chute-the-chutes', 'chutes', 'disk', 'flying horses', 'mad round', 'roller', 'roller coaster', 'rolling stone', 'rotator', 'rotor'],
    'merrymaking': ['banquet', 'celebration', 'cheer', 'convivial', 'conviviality', 'feast', 'festal', 'festive', 'festivity', 'gaiety', 'gala', 'gay'],
    'mesa': ['alkali flat', 'alluvial plain', 'basin', 'bench', 'bottomland', 'bushveld', 'campo', 'champaign', 'champaign country', 'coastal plain', 'delta', 'desert'],
    'mescaline': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'diethyltryptamine', 'dimethyltryptamine', 'gage'],
    'mesh': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 'allure', 'alternation', 'arabesque', 'bag', 'bait the hook', 'basketry', 'basketwork', 'birdlime', 'can of worms'],
    'meshed': ['barred', 'cancellated', 'crossbarred', 'filigreed', 'grated', 'gridded', 'laced', 'lacelike', 'lacy', 'latticelike', 'meshy', 'mullioned'],
    'meshes': ['arabesque', 'bait', 'basketry', 'basketwork', 'birdlime', 'bola', 'cancellation', 'cobweb', 'cross-hatching', 'crossing-out', 'dragnet', 'filigree'],
    'meshing': ['a propos', 'ad rem', 'adapted', 'alternation', 'applicable', 'apposite', 'appropriate', 'apropos', 'apt', 'becoming', 'befitting', 'coaction'],
    'mesmeric': ['absorbing', 'alluring', 'appealing', 'appetizing', 'arresting', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching'],
    'mesmerize': ['absorb', 'absorb the attention', 'anesthetize', 'arrest', 'becharm', 'beguile', 'bewitch', 'captivate', 'carry away', 'cast a spell', 'catch', 'catch up'],
    'mesmerized': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'arrested', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'becharmed'],
    'mesmerizer': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'mesmer', 'svengali', 'actor', 'bamboozler', 'befuddler', 'beguiler'],
    'meson': ['kern', 'nmr', 'alpha particle', 'antibaryon', 'antilepton', 'antimeson', 'atom', 'atomic nucleus', 'atomic particle', 'aurora particle', 'baryon', 'beta particle'],
    'mess': ['c ration', 'chinese puzzle', 'gordian knot', 'k ration', 'rube goldberg contraption', 'all sorts', 'allotment', 'allowance', 'amount', 'arsy-varsiness', 'assemblage', 'assortment'],
    'mess around': ['paul-pry', 'bat out', 'botch', 'bungle', 'busybody', 'butt in', 'coquet', 'dabble', 'dally', 'dash off', 'do anyhow', 'do by halves'],
    'mess hall': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop'],
    'mess up': ['ball up', 'befoul', 'benasty', 'bitch', 'bitch up', 'blur', 'bobble', 'bollix', 'bollix up', 'bonehead into it', 'bugger', 'bugger up'],
    'message': ['algol', 'cobol', 'esp', 'fortran', 'acceptation', 'account', 'acknowledgment', 'acquaintance', 'address', 'advice', 'alphabetic data', 'alphanumeric code'],
    'messed up': ['byzantine', 'ass-backwards', 'balled up', 'bitched', 'bitched up', 'bollixed up', 'buggered', 'buggered up', 'complex', 'complicated', 'confounded', 'confused'],
    'messenger': ['hermes', 'mercury', 'pheidippides', 'ancestor', 'announcer', 'antecedent', 'avant-garde', 'bellwether', 'buccinator', 'buccinator novi temporis', 'bushwhacker', 'commissar'],
    'messiah': ['mahdi', 'bell cow', 'bell mare', 'bellwether', 'born leader', 'charismatic leader', 'choirmaster', 'choragus', 'conductor', 'coryphaeus', 'duce', 'file leader'],
    'messily': ['airily', 'any old way', 'any which way', 'anyhow', 'bunglingly', 'carelessly', 'casually', 'clumsily', 'cursorily', 'disregardfully', 'forgetfully', 'haphazardly'],
    'messiness': ['amorphia', 'amorphism', 'amorphousness', 'anarchy', 'bad job', 'blowziness', 'blurriness', 'botch', 'bungling', 'carelessness', 'chaos', 'chintziness'],
    'messmate': ['ace', 'amigo', 'associate', 'bedfellow', 'bedmate', 'birthmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty', 'camarade'],
    'messy': ['beat-up', 'bedraggled', 'blowzy', 'botched', 'bungling', 'careless', 'chintzy', 'clumsy', 'deficient', 'dilapidated', 'dingy', 'dirty'],
    'mestizo': ['cape colored', 'eurasian', 'cattalo', 'citrange', 'cross', 'crossbreed', 'griffe', 'half blood', 'half-bred', 'half-breed', 'half-caste', 'high yellow'],
    'metabolism': ['assimilation', 'avatar', 'basal metabolism', 'catabolism', 'catalysis', 'consubstantiation', 'displacement', 'heterotopia', 'metagenesis', 'metamorphism', 'metamorphosis', 'metastasis'],
    'metal': ['dutch foil', 'achievement', 'alerion', 'aluminum', 'aluminum foil', 'americium', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms'],
    'metallic': ['brassy', 'brazen', 'choked', 'coarse', 'cracked', 'croaking', 'croaky', 'dry', 'gruff', 'guttural', 'harsh', 'harsh-sounding'],
    'metalworks': ['blacksmith shop', 'bleachworks', 'bloomery', 'bottling works', 'brassworks', 'copperworks', 'dye works', 'forge', 'foundry', 'furnace', 'gasworks', 'glassworks'],
    'metamorphic': ['able to adapt', 'adaptable', 'adjustable', 'allotropic', 'alterable', 'alterative', 'anabolic', 'catabolic', 'catalytic', 'changeable', 'checkered', 'diversiform'],
    'metamorphosis': ['avatar', 'catabolism', 'catalysis', 'consubstantiation', 'displacement', 'heterotopia', 'metabolism', 'metagenesis', 'metamorphism', 'metastasis', 'metathesis', 'metempsychosis'],
    'metaphor': ['accordance', 'agent', 'agreement', 'alikeness', 'allegory', 'alliance', 'alliteration', 'allusion', 'alternate', 'alternative', 'anacoluthon', 'anadiplosis'],
    'metaphorical': ['allegoric', 'allegorical', 'allusive', 'anagogic', 'associational', 'connotational', 'connotative', 'definable', 'demonstrative', 'denominative', 'denotational', 'denotative'],
    'metaphysical': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'anagogic', 'animist', 'animistic', 'atomistic', 'bodiless', 'cabalic', 'cabalistic'],
    'metaphysics': ['aesthetics', 'axiology', 'casuistry', 'cosmology', 'epistemology', 'ethics', 'existentialism', 'first philosophy', 'gnosiology', 'hyperphysics', 'logic', 'mental philosophy'],
    'metastasis': ['anastrophe', 'avatar', 'catabolism', 'catalysis', 'chiasmus', 'communication', 'conduction', 'consubstantiation', 'contagion', 'convection', 'delivery', 'deportation'],
    'mete': ['accord', 'administer', 'afford', 'allocate', 'allot', 'allow', 'apportion', 'appraise', 'appreciate', 'assay', 'assess', 'assign'],
    'meteor': ['aerolite', 'asteroids', 'aurora particles', 'blackout', 'bolide', 'chondrite', 'cosmic dust', 'cosmic particles', 'cosmic ray bombardment', 'fireball', 'intergalactic matter', 'meteor crater'],
    'meteoric': ['cynthian', 'ablaze', 'aflame', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical', 'blazing'],
    'meteorologist': ['aerial photographer', 'aerographer', 'aerologist', 'aircrew', 'aircrewman', 'avigator', 'belly gunner', 'bombardier', 'crew', 'crew chief', 'flight attendant', 'flight crew'],
    'meteorology': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics'],
    'meter': ['alexandrine', 'stabreim', 'vom', 'vtvm', 'accent', 'accentuation', 'alliterative meter', 'alternation', 'ammeter', 'ampere-hour meter', 'amphibrach', 'amphimacer'],
    'methadone': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'methane': ['alcohol', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coke', 'combustible', 'dope', 'ethane'],
    'methedrine': ['benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'amphetamine', 'amphetamine sulfate', 'cocaine', 'coke', 'crystal', 'dextroamphetamine sulfate'],
    'method': ['mo', 'ability', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'algorithm', 'anality', 'apple-pie order'],
    'methodical': ['accordant', 'alike', 'analytical', 'arranged', 'automatic', 'balanced', 'businesslike', 'careful', 'consistent', 'consonant', 'constant', 'continuous'],
    'methodically': ['always', 'at every turn', 'at regular intervals', 'at stated times', 'constantly', 'continually', 'every so often', 'harmoniously', 'intermittently', 'invariably', 'like clockwork', 'never otherwise'],
    'methodized': ['aligned', 'arranged', 'arrayed', 'assorted', 'blueprinted', 'calculated', 'categorized', 'charted', 'classified', 'composed', 'constituted', 'contrived'],
    'methodologist': ['babbitt', 'middle american', 'philistine', 'anal character', 'bourgeois', 'burgher', 'compulsive character', 'conformer', 'conformist', 'conventionalist', 'formalist', 'middle-class type'],
    'methodology': ['mo', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'algorithm', 'anality', 'apple-pie order', 'approach'],
    'methuselah': ['father time', 'nestor', 'old paar', 'antediluvian', 'antique', 'back number', 'centenarian', 'conservative', 'dad', 'dodo', 'dotard', 'elder'],
    'meticulous': ['ok', 'spartan', 'spartanic', 'absolute', 'accurate', 'active', 'advertent', 'agog', 'alert', 'all ears', 'all eyes', 'all right'],
    'meticulousness': ['spartanism', 'absoluteness', 'accuracy', 'astringency', 'attention to detail', 'attention to fact', 'austerity', 'authoritarianism', 'care for truth', 'censoriousness', 'choosiness', 'circumstantiality'],
    'metier': ['ability', 'area', 'art', 'bag', 'bump', 'business', 'caliber', 'calling', 'capability', 'capacity', 'career', 'career building'],
    'metric': ['antispastic', 'approximative', 'beating', 'cadenced', 'cadent', 'chorographic', 'dactylic', 'estimative', 'hypsographic', 'iambic', 'in numbers', 'in rhythm'],
    'metric system': ['appraisal', 'appraisement', 'approximation', 'assessment', 'assize', 'assizement', 'calculation', 'computation', 'correction', 'determination', 'estimate', 'estimation'],
    'metrical': ['antispastic', 'approximative', 'beating', 'cadenced', 'cadent', 'chorographic', 'dactylic', 'estimative', 'hypsographic', 'iambic', 'in numbers', 'in rhythm'],
    'metrics': ['stabreim', 'accent', 'accentuation', 'alliterative meter', 'beat', 'cadence', 'emphasis', 'ictus', 'level of stress', 'lilt', 'measure', 'meter'],
    'metro': ['amtrak', 'baggage train', 'branch', 'cable railroad', 'cable railway', 'choo-choo', 'cog railroad', 'cog railway', 'el', 'electric', 'electric railway', 'electric train'],
    'metronome': ['baton', 'diapason', 'monochord', 'music stand', 'mute', 'oscillator', 'pendulum', 'pitch pipe', 'rhythmometer', 'rocker', 'rocking chair', 'rocking stone'],
    'metronomic': ['alternate', 'annalistic', 'beating', 'calendarial', 'calendric', 'chronogrammatic', 'chronographic', 'chronologic', 'chronoscopic', 'circling', 'cyclic', 'dated'],
    'metropolis': ['kreis', 'stadt', 'archbishopric', 'archdiocese', 'arrondissement', 'art center', 'bailiwick', 'banlieue', 'bishopric', 'boom town', 'borough', 'bourg'],
    'mettle': ['activity', 'animation', 'animus', 'aptitude', 'ardor', 'backbone', 'bent', 'bias', 'bottom', 'brio', 'briskness', 'cast'],
    'mettlesome': ['active', 'acute', 'aggressive', 'agitable', 'animated', 'beany', 'brisk', 'bulldoggish', 'courageous', 'dauntless', 'dynamic', 'edgy'],
    'mew': ['adytum', 'ashram', 'bark', 'bawl', 'bay', 'beleaguer', 'bell', 'bellow', 'beset', 'besiege', 'blare', 'blat'],
    'mewl': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'bray', 'call', 'caterwaul'],
    'mews': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'barn'],
    'mezzo': ['amidships', 'average', 'central', 'core', 'equatorial', 'equidistant', 'halfway', 'interior', 'intermediary', 'intermediate', 'mean', 'medial'],
    'mezzo soprano': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso profundo', 'blues singer'],
    'miasma': ['bo', 'afterdamp', 'bad breath', 'bad smell', 'blackdamp', 'body odor', 'breath', 'chokedamp', 'cloud', 'coal gas', 'damp', 'effluvium'],
    'miasmic': ['abhorrent', 'abominable', 'aerial', 'aerodynamic', 'aerostatic', 'aery', 'airy', 'bad', 'bad-smelling', 'base', 'beastly', 'below contempt'],
    'mick': ['aussie', 'boche', 'canuck', 'chink', 'guinea', 'hunk', 'hunkie', 'jerry', 'kraut', 'krauthead', 'mickey', 'paddy'],
    'mickey finn': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'mickey mouse': ['base', 'casual', 'cheap', 'cheesy', 'clear', 'coarse', 'common', 'cushy', 'easy', 'easy as pie', 'effortless', 'facile'],
    'microbe': ['adenovirus', 'aerobe', 'aerobic bacteria', 'aerobic organism', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'anaerobic organism', 'autotrophic organism', 'bacillus', 'bacteria', 'bacterium'],
    'microbiology': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology', 'biometrics'],
    'microcosmic': ['atomic', 'corpuscular', 'embryonic', 'evanescent', 'germinal', 'granular', 'impalpable', 'imperceptible', 'imponderable', 'inappreciable', 'indiscernible', 'infinitesimal'],
    'microdot': ['bulletin board', 'card', 'catalog card', 'disc', 'file', 'filing card', 'film', 'index card', 'library catalog', 'magnetic tape', 'microcard', 'microfiche'],
    'microfiche': ['flexowriter typewriter', 'teleplotter', 'alphabetical printer', 'apograph', 'bulletin board', 'carbon', 'carbon copy', 'card', 'catalog card', 'digital graph plotter', 'disc', 'fiche'],
    'microfilm': ['flexowriter typewriter', 'photostat', 'teleplotter', 'x-ray', 'xerox', 'alphabetical printer', 'backing', 'bibliofilm', 'bipack', 'black-and-white film', 'bulletin board', 'calotype'],
    'microorganism': ['euglena', 'adenovirus', 'aerobe', 'aerobic bacteria', 'aerobic organism', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'anaerobic organism', 'animalcule', 'autotrophic organism', 'bacillus'],
    'microscopic': ['atomic', 'close', 'constant', 'corpuscular', 'delicate', 'direct', 'embryonic', 'evanescent', 'even', 'exact', 'express', 'faithful'],
    'microscopy': ['electron microscopy', 'electron optics', 'infrared spectroscopy', 'microbiology', 'micrography', 'microphotography', 'microphysics', 'microscopics', 'microspectroscopy', 'optical physics', 'optics', 'optometry'],
    'mid': ['accented', 'alveolar', 'amid', 'amidships', 'amidst', 'among', 'amongst', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated'],
    'mid victorian': ['gothic', 'methuselah', 'quakerish', 'victorian', 'antediluvian', 'antiquated', 'antique', 'archaic', 'back number', 'bluenose', 'censorious', 'classical'],
    'middle': ['active', 'active voice', 'amidships', 'arbitrational', 'arbitrative', 'average', 'axial', 'axis', 'balance', 'bisect', 'center', 'center of action'],
    'middle america': ['bourgeoisie', 'burgherdom', 'fourth-rater', 'mediocrity', 'middle class', 'middle order', 'middle orders', 'no prize', 'nobody special', 'nonentity', 'nothing special', 'second-rater'],
    'middle american': ['babbitt', 'philistine', 'anal character', 'bourgeois', 'burgher', 'compulsive character', 'conformer', 'conformist', 'conventionalist', 'formalist', 'methodologist', 'middle-class type'],
    'middle class': ['middle america', 'bourgeoisie', 'burgherdom', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty', 'commoners', 'commons', 'fourth-rater'],
    'middle east': ['africa', 'america', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'east', 'eastern hemisphere', 'eurasia', 'europe', 'far east'],
    'middle ground': ['average', 'balance', 'center', 'compromise', 'fence', 'generality', 'golden mean', 'half measures', 'half-and-half measures', 'halfway measures', 'happy medium', 'juste-milieu'],
    'middle school': ['gymnasium', 'latin school', 'realgymnasium', 'realschule', 'academy', 'grammar school', 'high', 'high school', 'intermediate school', 'junior high', 'junior high school', 'prep school'],
    'middle west': ['dixie', 'dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'new england', 'north', 'north central region', 'northeast', 'northwest', 'pacific northwest'],
    'middlebrow': ['babbitt', 'boeotian', 'boob', 'dabbler', 'dilettante', 'dunce', 'fool', 'greenhorn', 'greeny', 'ignoramus', 'illiterate', 'illiterati'],
    'middleman': ['agent', 'arbitrator', 'broker', 'chandler', 'connection', 'contact', 'dealer', 'deputy', 'distributor', 'entrepreneur', 'front', 'front man'],
    'middlemost': ['amidships', 'average', 'axial', 'center', 'centermost', 'central', 'centralized', 'centric', 'centroidal', 'centrosymmetric', 'concentrated', 'core'],
    'middleweight': ['chinese boxer', 'bantamweight', 'black belt', 'boxer', 'brown belt', 'bruiser', 'catchweight', 'featherweight', 'fighter', 'fisticuffer', 'flyweight', 'heavyweight'],
    'middling': ['amidships', 'average', 'banal', 'betwixt and between', 'central', 'common', 'core', 'dull', 'equatorial', 'equidistant', 'fair', 'fair to middling'],
    'midge': ['lilliputian', 'tom thumb', 'brownie', 'crumb', 'dot', 'drop', 'droplet', 'dwarf', 'elf', 'fleck', 'flyspeck', 'gnat'],
    'midget': ['lilliputian', 'tom thumb', 'brownie', 'diminutive', 'dumpy', 'dwarf', 'dwarfed', 'dwarfish', 'elf', 'elfin', 'gnome', 'homunculus'],
    'midland': ['amidships', 'average', 'central', 'core', 'equatorial', 'equidistant', 'halfway', 'heartland', 'hinterland', 'inland', 'inlands', 'inshore'],
    'midmost': ['amidships', 'average', 'axial', 'center', 'centermost', 'central', 'centralized', 'centric', 'centroidal', 'centrosymmetric', 'concentrated', 'core'],
    'midnight': ['all-night', 'atramentous', 'black', 'black as coal', 'black as ebony', 'black as ink', 'black as midnight', 'black as night', 'coal-black', 'coaly', 'dark', 'dark as night'],
    'midriff': ['abdomen', 'abomasum', 'barrier', 'bay window', 'beerbelly', 'belly', 'brattice', 'breadbasket', 'buffer', 'buffer state', 'bulkhead', 'bumper'],
    'midsection': ['barrier', 'brattice', 'buffer', 'buffer state', 'bulkhead', 'bumper', 'cloison', 'collision mat', 'cushion', 'diaphragm', 'dissepiment', 'dividing line'],
    'midshipman': ['naval reservist', 'royal marine', 'seabee', 'bluejacket', 'boot', 'cadet', 'freshman', 'frogman', 'gob', 'horse marine', 'jolly', 'junior'],
    'midst': ['amid', 'amidst', 'among', 'amongst', 'between', 'betwixt', 'betwixt and between', 'center', 'core', 'diameter', 'diaphragm', 'equator'],
    'midterm': ['audition', 'blue book', 'exam', 'examen', 'examination', 'final', 'final examination', 'great go', 'hearing', 'honors', 'midsemester', 'oral'],
    'midtown': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'barrio', 'black ghetto', 'blighted area', 'burghal'],
    'midway': ['laodicean', 'amidships', 'apathetic', 'average', 'betwixt and between', 'bisection', 'central', 'centrally', 'centrist', 'core', 'equatorial', 'equidistance'],
    'midwife': ['charlie mccarthy', 'agent', 'ancilla', 'appliance', 'bonesetter', 'chiropractor', 'contrivance', 'creature', 'device', 'dummy', 'dupe', 'go-between'],
    'mien': ['action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'appearance', 'aspect', 'bearing', 'behavior', 'behavior pattern'],
    'miff': ['aggravate', 'altercation', 'annoy', 'arouse', 'badger', 'bait', 'be at', 'bedevil', 'beef', 'beset', 'bother', 'bristle'],
    'miffed': ['aggravated', 'angry', 'annoyed', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'chafed', 'disturbed', 'exasperated', 'galled', 'griped'],
    'might': ['adequacy', 'amperage', 'ampleness', 'amplitude', 'arm', 'armipotence', 'ascendancy', 'authoritativeness', 'authority', 'beef', 'black power', 'boundlessness'],
    'might and main': ['amperage', 'armipotence', 'authority', 'beef', 'black power', 'brute force', 'charge', 'charisma', 'clout', 'cogence', 'cogency', 'compulsion'],
    'mightily': ['almighty', 'arduously', 'authoritatively', 'awfully', 'big', 'cogently', 'commandingly', 'consequentially', 'deafeningly', 'dynamically', 'effectively', 'effectually'],
    'mighty': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'able-bodied', 'absolute', 'abysmal', 'aggrandized', 'almighty', 'apotheosized'],
    'migraine': ['ms', 'ache', 'aching', 'amyotrophic lateral sclerosis', 'angina', 'backache', 'bellyache', 'brain disease', 'cephalalgia', 'cerebral palsy', 'chorea', 'colic'],
    'migrant': ['dp', 'avifauna', 'baby bird', 'bird', 'bird of jove', 'bird of juno', 'bird of minerva', 'bird of night', 'bird of passage', 'bird of prey', 'birdie', 'birdlife'],
    'migrate': ['drift', 'emigrate', 'expatriate', 'flit', 'go', 'immigrate', 'in-migrate', 'intermigrate', 'move', 'nomadize', 'out-migrate', 'range'],
    'migration': ['communication', 'conduction', 'contagion', 'convection', 'delivery', 'deportation', 'diapedesis', 'diffusion', 'dissemination', 'emigration', 'expatriation', 'export'],
    'migratory': ['circumforaneous', 'discursive', 'divagatory', 'drifting', 'errant', 'flitting', 'floating', 'footloose', 'footloose and fancy-free', 'fugitive', 'gadding', 'gypsy-like'],
    'mikado': ['dalai lama', 'holy roman emperor', 'inca', 'kaiser', 'ardri', 'bey', 'cacique', 'caesar', 'cham', 'czar', 'kaid', 'khan'],
    'milady': ['eminence', 'eve', 'frau', 'grace', 'her excellency', 'her highness', 'her ladyship', 'her majesty', 'highness', 'his lordship', 'his majesty', 'honor'],
    'milcher': ['brahman', 'indian buffalo', 'aurochs', 'beef', 'beef cattle', 'beeves', 'bison', 'bossy', 'bovine', 'bovine animal', 'buffalo', 'bull'],
    'mild': ['saturnian', 'accepting', 'aestival', 'affable', 'agreeable', 'amiable', 'balmy', 'benign', 'benignant', 'bland', 'blood-hot', 'blood-warm'],
    'mildew': ['biodegradability', 'biodegradation', 'blast', 'blight', 'break up', 'breakup', 'cancer', 'canker', 'corrosion', 'corrupt', 'corruption', 'crumble'],
    'mildewed': ['bad', 'bad-smelling', 'blasted', 'blighted', 'blown', 'crumbling', 'despoiled', 'dilapidated', 'dusty', 'fecal', 'fetid', 'flyblown'],
    'mildly': ['after a fashion', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst', 'comparatively', 'detectably'],
    'mildness': ['abnegation', 'abstinence', 'acceptance', 'affability', 'amiability', 'bonhomie', 'calm', 'calmness', 'clemency', 'clementness', 'compassion', 'conservatism'],
    'mileage': ['account', 'aesthetic distance', 'allowance', 'assessment', 'bill', 'blackmail', 'blood money', 'clearance', 'compass', 'deep space', 'depths of space', 'distance'],
    'milepost': ['samson post', 'arrow', 'baluster', 'balustrade', 'banister', 'bench mark', 'blaze', 'bookmark', 'cairn', 'catstone', 'compass needle', 'direction'],
    'miles per hour': ['air speed', 'celerity', 'dispatch', 'expedition', 'fastness', 'flight', 'flit', 'flurry', 'ground speed', 'haste', 'hurry', 'instantaneousness'],
    'milestone': ['bench mark', 'bookmark', 'cairn', 'cardinal point', 'catstone', 'chief thing', 'climax', 'core', 'cornerstone', 'crisis', 'critical point', 'crux'],
    'milieu': ['agora', 'air', 'airspace', 'alentours', 'ambiance', 'ambience', 'ambient', 'ambit', 'amphitheater', 'area', 'arena', 'athletic field'],
    'militancy': ['action', 'activeness', 'activism', 'activity', 'aggression', 'aggressiveness', 'antagonism', 'bellicism', 'bellicosity', 'belligerence', 'belligerency', 'business'],
    'militant': ['active', 'activist', 'activistic', 'aggressive', 'aggressor', 'alive', 'animated', 'antagonistic', 'assertive', 'at war', 'ball of fire', 'battler'],
    'militarism': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'absolute monarchy', 'aggression', 'aggressiveness', 'antagonism', 'appeasement', 'aristocracy', 'autarchy', 'autocracy'],
    'military': ['aggressive', 'air force', 'antagonistic', 'armed force', 'armed forces', 'armed service', 'army', 'array', 'battling', 'bellicose', 'belligerent', 'bloodthirsty'],
    'military operations': ['action', 'all-out war', 'amphibious operations', 'appeal to arms', 'armed combat', 'armed conflict', 'attack', 'battle', 'belligerence', 'belligerency', 'bloodshed', 'combat'],
    'military police': ['cheka', 'fbi', 'gestapo', 'interpol', 'mp', 'mvd', 'mounties', 'nkvd', 'ogpu', 'rcmp', 'sp', 'scotland yard'],
    'militate': ['act', 'aid', 'be effective', 'be in action', 'cancel out', 'count', 'counter', 'countervail', 'discourage', 'favor', 'foil', 'function'],
    'militate against': ['antagonize', 'battle', 'be antipathetic', 'be inimical', 'beat against', 'beat up against', 'breast the wave', 'buck', 'buffet', 'buffet the waves', 'clash', 'close with'],
    'milk': ['abridge', 'abuse', 'alabaster', 'bed', 'bed down', 'bereave', 'beverage', 'bleed', 'bleed white', 'blood', 'break', 'bridle'],
    'milker': ['brahman', 'indian buffalo', 'aurochs', 'beef', 'beef cattle', 'beeves', 'bison', 'bossy', 'bovine', 'bovine animal', 'buffalo', 'bull'],
    'milkiness': ['achroma', 'achromasia', 'achromatosis', 'albescence', 'albinism', 'albino', 'albinoism', 'blondness', 'canescence', 'chalkiness', 'chylifaction', 'chylification'],
    'milking': ['aspiration', 'bleeding', 'bloodletting', 'broaching', 'cupping', 'drafting', 'drainage', 'draining', 'drawing', 'emptying', 'phlebotomy', 'pipetting'],
    'milksop': ['lord fauntleroy', 'milquetoast', 'percy', 'ass', 'baby', 'big baby', 'born fool', 'buffoon', 'caitiff', 'chicken', 'chicken liver', 'clown'],
    'milky': ['argent', 'argentine', 'bland', 'canescent', 'chalky', 'changeable', 'cretaceous', 'fleecy-white', 'frosted', 'frosty', 'grizzled', 'grizzly'],
    'milky way': ['via lactea', 'barred spiral', 'barred spiral galaxy', 'cosmic noise', 'galactic circle', 'galactic cluster', 'galactic coordinates', 'galactic latitude', 'galactic longitude', 'galactic nebula', 'galactic noise', 'galactic pole'],
    'mill': ['c-note', 'g-note', 'vandyke', 'abrade', 'amble', 'armory', 'arrastra', 'arsenal', 'assemble', 'assembly line', 'assembly plant', 'atomic energy plant'],
    'milled': ['assembled', 'branny', 'built', 'cast', 'chalklike', 'chalky', 'comminute', 'comminuted', 'constructed', 'crafted', 'created', 'crushed'],
    'millenarian': ['leibnizian', 'leibnizian optimist', 'pollyanna', 'aspirant', 'aspirer', 'bright', 'cheerful', 'chiliast', 'chiliastic', 'couleur de rose', 'hopeful', 'hoper'],
    'millennium': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley'],
    'millet': ['breakfast food', 'cereal', 'cornflakes', 'dry cereal', 'farina', 'frumenty', 'grits', 'gruel', 'hasty pudding', 'hominy grits', 'hot cereal', 'kasha'],
    'milliner': ['antique store', 'apothecary', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'chemist', 'cigar store', 'clothiers', 'clothing store', 'confectionery', 'dress shop'],
    'millinery': ['bootmaking', 'cap', 'chapeau', 'cobbling', 'coverchief', 'dressmaking', 'garment making', 'handkerchief', 'hat', 'hatmaking', 'headcloth', 'headdress'],
    'milling': ['architecture', 'assembly', 'building', 'casting', 'composition', 'construction', 'conversion', 'crafting', 'craftsmanship', 'creation', 'cultivation', 'devising'],
    'million': ['a billion', 'a crore', 'a lakh', 'a million', 'a myriad', 'a nonillion', 'a quadrillion', 'a thousand', 'a zillion', 'billion', 'considerable', 'crore'],
    'millionaire': ['daddy warbucks', 'billionaire', 'bloated plutocrat', 'capitalist', 'fat cat', 'man of means', 'man of substance', 'man of wealth', 'moneybags', 'moneyed man', 'multimillionaire', 'nabob'],
    'millstone': ['bale', 'burden', 'burdening', 'burthen', 'cargo', 'charge', 'charging', 'cheese grater', 'comminutor', 'crusher', 'cumber', 'cumbrance'],
    'millstream': ['adolescent stream', 'arroyo', 'beck', 'bourn', 'braided stream', 'branch', 'brook', 'brooklet', 'burn', 'channel', 'creek', 'crick'],
    'milord': ['eminence', 'grace', 'her excellency', 'her highness', 'her ladyship', 'her majesty', 'highness', 'his lordship', 'his majesty', 'honor', 'imperial highness', 'imperial majesty'],
    'milquetoast': ['baby', 'big baby', 'chicken', 'chicken liver', 'coward', 'crybaby', 'doormat', 'dull tool', 'fence-sitter', 'fraid-cat', 'fraidy-cat', 'funk'],
    'mime': ['roscius', 'thalia', 'act', 'act a part', 'act as', 'act as foil', 'act out', 'actor', 'actress', 'antagonist', 'ape', 'appear'],
    'mimeograph': ['photostat', 'xerox', 'albertype', 'book printing', 'bring out', 'chromotypography', 'chromotypy', 'chromoxylography', 'clone', 'collotype', 'color printing', 'copy'],
    'mimer': ['roscius', 'actor', 'actress', 'antagonist', 'ape', 'bad guy', 'barnstormer', 'character', 'character actor', 'character man', 'character woman', 'child actor'],
    'mimetic': ['apish', 'delineatory', 'depictive', 'echoic', 'embodying', 'emulative', 'figurative', 'graphic', 'ideographic', 'illustrational', 'illustrative', 'imitative'],
    'mimic': ['roscius', 'act', 'act a part', 'act as', 'act out', 'actor', 'actress', 'antagonist', 'ape', 'apish', 'appear like', 'approach'],
    'mimicry': ['acting', 'aggressive mimicry', 'apery', 'aping', 'buffoonery', 'business', 'caricature', 'characterization', 'cryptic mimicry', 'dumb show', 'embodiment', 'enacting'],
    'miming': ['acting', 'aping', 'buffoonery', 'business', 'characterization', 'dumb show', 'embodiment', 'enacting', 'enactment', 'gag', 'ham', 'hammy acting'],
    'minaret': ['antenna tower', 'barbican', 'belfry', 'bell tower', 'campanile', 'colossus', 'column', 'cupola', 'derrick', 'dome', 'fire tower', 'lantern'],
    'minatory': ['abusive', 'bludgeoning', 'blustering', 'browbeating', 'bulldozing', 'bullying', 'comminatory', 'denunciatory', 'fear-inspiring', 'foreboding', 'hectoring', 'imminent'],
    'mince': ['allow for', 'amble', 'aspic', 'atomize', 'barbecue', 'barge', 'boiled meat', 'bouilli', 'bowl along', 'break into pieces', 'break to pieces', 'break up'],
    'mincing': ['affected', 'dainty', 'dandyish', 'delicate', 'effeminate', 'elegant', 'euphemistic', 'euphuistic', 'exquisite', 'fastidious', 'finical', 'finicking'],
    'mind': ['mnemosyne', 'affect memory', 'aim', 'ambition', 'ambivalent', 'anima', 'anima humana', 'animadvert', 'animus', 'anterograde memory', 'appetence', 'appetency'],
    'mind altering drug': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'diethyltryptamine', 'dimethyltryptamine', 'gage'],
    'mind blowing': ['agitating', 'breathtaking', 'charged', 'cliff-hanging', 'consciousness-expanding', 'disquieting', 'distracting', 'disturbing', 'electric', 'exciting', 'exhilarating', 'galvanic'],
    'mind boggler': ['chinese puzzle', 'baffling problem', 'brain twister', 'crossword puzzle', 'crux', 'enigma', 'enigmatic question', 'floorer', 'jigsaw puzzle', 'knot', 'knotty point', 'mystery'],
    'mind expanding drug': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'diethyltryptamine', 'dimethyltryptamine', 'gage'],
    'minded': ['acquiescent', 'actuated', 'agreeable', 'alacritous', 'amenable', 'animated', 'apt', 'apt to', 'ardent', 'bent', 'calculated to', 'compliant'],
    'mindful': ['accommodating', 'accommodative', 'active', 'advertent', 'agog', 'agreeable', 'alert', 'alive', 'alive to', 'all ears', 'all eyes', 'all-knowing'],
    'mindfully': ['absorbedly', 'advertently', 'assiduously', 'attentively', 'cannily', 'carefully', 'cautiously', 'circumspectly', 'considerately', 'devotedly', 'diligently', 'discreetly'],
    'mindless': ['a stranger to', 'aimless', 'airy', 'aloof', 'anarchic', 'angry', 'animal', 'animalian', 'animalic', 'animalistic', 'apathetic', 'asinine'],
    'mindlessly': ['angrily', 'apathetically', 'carelessly', 'disinterestedly', 'dispassionately', 'frantically', 'frenziedly', 'furiously', 'heedlessly', 'insensately', 'insouciantly', 'lackadaisically'],
    'mindlessness': ['urdummheit', 'accidia', 'acedia', 'acuteness', 'animality', 'apathy', 'asininity', 'ataraxia', 'ataraxy', 'atrocity', 'barbarity', 'battiness'],
    'mine': ['dionaea', 'eldorado', 'golconda', 'abri', 'abridge', 'abundance', 'abysm', 'abyss', 'approach trench', 'arm', 'armor', 'armor-plate'],
    'mined': ['assembled', 'built', 'cast', 'constructed', 'crafted', 'created', 'custom', 'custom-built', 'custom-made', 'extracted', 'fabricated', 'fashioned'],
    'miner': ['butty', 'collier', 'desert rat', 'digger', 'dredge', 'dredger', 'driller', 'excavator', 'gold digger', 'gold miner', 'gold panner', 'groundhog'],
    'mineral': ['alabaster', 'alabastrine', 'amphibole', 'antimony', 'apatite', 'aplite', 'arsenic', 'asbestine', 'asbestos', 'asphalt', 'azurite', 'bauxite'],
    'mineral kingdom': ['animal kingdom', 'brute matter', 'chain of being', 'class structure', 'domain', 'establishment', 'gel mineral', 'hierarchy', 'inorganic matter', 'inorganic substance', 'kingdom', 'metamict substance'],
    'mineral oil': ['animal oil', 'cerate', 'drying oil', 'essential oil', 'ester', 'fat', 'fatty oil', 'fixed oil', 'grease', 'hydrogenated fat', 'lipid', 'oil'],
    'mineralogy': ['cosmical geology', 'crystallography', 'dynamic geology', 'geodesy', 'geodetics', 'geodynamics', 'geognosy', 'geographics', 'geography', 'geological chemistry', 'geological engineering', 'geology'],
    'minerva': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'bellona', 'ceres'],
    'mingle': ['admix', 'alloy', 'amalgamate', 'associate', 'associate with', 'assort with', 'bemingle', 'blend', 'chum', 'chum together', 'chum with', 'circulate'],
    'mingled': ['amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'blended', 'combined', 'complex', 'composite', 'compound', 'compounded', 'conglomerate', 'dappled'],
    'mingling': ['admixture', 'alloyage', 'amalgamation', 'blending', 'coalescence', 'combination', 'comminglement', 'commingling', 'commixture', 'composition', 'eclecticism', 'fusion'],
    'mini': ['elzevir', 'baby', 'bantam', 'banty', 'button', 'chit', 'diminutive', 'doll', 'duodecimo', 'featherweight', 'fingerling', 'lightweight'],
    'miniature': ['elzevir', 'lilliputian', 'abstract', 'abstraction', 'altarpiece', 'baby', 'baby-sized', 'bantam', 'banty', 'block print', 'collage', 'color print'],
    'miniaturization': ['abatement', 'abridgment', 'alleviation', 'attenuation', 'contraction', 'dampening', 'damping', 'decrease', 'decrement', 'decrescence', 'deduction', 'deflation'],
    'miniaturized': ['abated', 'ablated', 'attenuated', 'baby', 'baby-sized', 'bantam', 'banty', 'bated', 'belittled', 'compact', 'consumed', 'contracted'],
    'minim': ['accidental', 'ace', 'atom', 'bit', 'breve', 'breve rest', 'crotchet', 'crumb', 'dab', 'demisemiquaver', 'dole', 'dominant'],
    'minimal': ['adequate', 'ample', 'baby', 'baby-sized', 'bantam', 'banty', 'barely sufficient', 'basal', 'basic', 'commensurate', 'compact', 'competent'],
    'minimally': ['a bit', 'a little', 'adequately', 'amply', 'barely', 'by a hair', 'by an ace', 'competently', 'enough', 'ever so little', 'exiguously', 'faintly'],
    'minimize': ['abbreviate', 'abridge', 'bedwarf', 'belittle', 'bring down', 'bring into discredit', 'bring low', 'cry down', 'curtail', 'cut down', 'de-emphasize', 'debase'],
    'minimized': ['abated', 'ablated', 'attenuated', 'bated', 'belittled', 'consumed', 'contracted', 'curtailed', 'decreased', 'deflated', 'diminished', 'dissipated'],
    'minimum': ['ace', 'adequacy', 'adequate', 'adequate supply', 'adequateness', 'ample', 'atom', 'bare minimum', 'bare sufficiency', 'barely sufficient', 'bit', 'commensurate'],
    'minimum wage': ['base pay', 'compensation', 'dismissal wage', 'earnings', 'escalator clause', 'escalator plan', 'financial remuneration', 'gross income', 'guaranteed annual wage', 'hire', 'income', 'living wage'],
    'mining': ['architecture', 'assembly', 'avulsion', 'building', 'casting', 'coal mining', 'composition', 'construction', 'conversion', 'crafting', 'craftsmanship', 'creation'],
    'minion': ['charlie mccarthy', 'adherent', 'agent', 'ancilla', 'apple-polisher', 'appliance', 'ass-licker', 'backscratcher', 'backslapper', 'bootlick', 'bootlicker', 'brown-nose'],
    'minister': ['dd', 'doctor of divinity', 'holy joe', 'abbe', 'accommodate', 'administer the eucharist', 'agent', 'aid', 'alderman', 'ambassador', 'ambassadress', 'anoint'],
    'minister of state': ['alderman', 'archon', 'bailie', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor', 'city councilman', 'city father', 'city manager', 'commissar'],
    'minister to': ['act for', 'administer to', 'advance', 'assist', 'attend', 'attend on', 'attend to', 'baby-sit', 'bandage', 'bathe', 'be instrumental', 'care for'],
    'ministerial': ['abbatial', 'abbatical', 'accessory', 'adjuvant', 'administrating', 'administrative', 'agential', 'agentival', 'agentive', 'ambassadorial', 'ancillary', 'archiepiscopal'],
    'ministering': ['accessory', 'adjuvant', 'agential', 'agentival', 'agentive', 'ancillary', 'assistant', 'assisting', 'attendant', 'attending', 'auxiliary', 'conducive'],
    'ministration': ['aid', 'assistance', 'attendance', 'benefit', 'comfort', 'ease', 'employ', 'employment', 'good offices', 'help', 'ministry', 'office'],
    'ministry': ['sacred college', 'administration', 'advisory council', 'agency', 'agent', 'aid', 'assistance', 'attendance', 'auspices', 'bailiwick', 'benefit', 'bureau'],
    'minor': ['academic specialty', 'adolescent', 'area', 'average', 'baby', 'back-burner', 'boy', 'budding', 'callow', 'casual', 'child', 'classical education'],
    'minor matter': ['a little thing', 'hardly anything', 'inessential', 'insignificancy', 'marginal matter', 'matter of indifference', 'mere nothing', 'naught', 'nihility', 'no great matter', 'nothing', 'nothing in particular'],
    'minority': ['back seat', 'callowness', 'dewiness', 'disability', 'disablement', 'disqualification', 'freshness', 'greenness', 'humbleness', 'humility', 'imbecility', 'immaturity'],
    'minority group': ['breakaway group', 'camp', 'caucus', 'division', 'ethnic group', 'faction', 'interest', 'interest group', 'least', 'minority', 'offshoot', 'party'],
    'minority leader': ['mp', 'member of congress', 'member of parliament', 'alderman', 'assemblyman', 'chosen freeholder', 'city father', 'congressman', 'congresswoman', 'councilman', 'floor leader', 'lawgiver'],
    'minority opinion': ['agreement to disagree', 'alienation', 'apostasy', 'counter-culture', 'difference', 'disaccord', 'disagreement', 'disapprobation', 'disapproval', 'disparity', 'dissatisfaction', 'dissension'],
    'minos': ['aeacus', 'aides', 'aidoneus', 'astraea', 'cerberus', 'charon', 'cora', 'despoina', 'dike', 'dis', 'dis pater', 'erebus'],
    'minstrel': ['broadway musical', 'meistersinger', 'parnassian', 'singspiel', 'arch-poet', 'artist', 'artiste', 'ballad maker', 'ballad opera', 'ballad singer', 'balladeer', 'balladist'],
    'minstrel show': ['broadway musical', 'grand guignol', 'passion play', 'singspiel', 'tom show', 'antimasque', 'audience success', 'ballad opera', 'ballet', 'ballet divertissement', 'bomb', 'broadcast drama'],
    'mint': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'batch', 'beget', 'bindery', 'block out', 'boatyard', 'boilery', 'bomb'],
    'mint condition': ['brand-newness', 'callowness', 'dewiness', 'eupepsia', 'fine fettle', 'fine shape', 'fine whack', 'freshness', 'gloss of novelty', 'glowing health', 'good condition', 'good constitution'],
    'mintage': ['and pence', 'artifact', 'authorship', 'beginning', 'brainchild', 'cash', 'child', 'circulating medium', 'coinage', 'coined liberty', 'coining', 'cold cash'],
    'minus': ['barring', 'bereaved', 'bereaved of', 'bereft', 'cut off', 'decrement', 'deduction', 'deficient', 'denuded', 'deprived of', 'devoid', 'discounting'],
    'minuscule': ['abecedarian', 'allographic', 'alphabetic', 'baby', 'baby-sized', 'bantam', 'banty', 'capital', 'compact', 'diminutive', 'duodecimo', 'graphemic'],
    'minute': ['lilliputian', 'absolute', 'abundant year', 'academic year', 'accurate', 'all the rage', 'annum', 'attentive', 'baby', 'back-burner', 'balance', 'balance the books'],
    'minutely': ['a bit', 'a little', 'accurately', 'at length', 'barely', 'by a hair', 'by an ace', 'completely', 'concretely', 'conscientiously', 'definitely', 'distinctly'],
    'minutes': ['account', 'account rendered', 'accounting', 'acta', 'adversaria', 'aide-memoire', 'annotation', 'annual', 'brief', 'bulletin', 'census report', 'docket'],
    'minutiae': ['ace', 'article', 'aspect', 'atom', 'bit', 'bric-a-brac', 'case', 'chaff', 'chicken feed', 'chickenshit', 'count', 'crumb'],
    'minx': ['jd', 'jane', 'bad boy', 'baggage', 'biddy', 'bird', 'bitch', 'boldface', 'booger', 'brat', 'brazenface', 'broad'],
    'miracle': ['grand guignol', 'passion play', 'tom show', 'amazement', 'antimasque', 'astonishing thing', 'astonishment', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show'],
    'miracle play': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger', 'closet drama'],
    'miraculous': ['amazing', 'astonishing', 'astounding', 'beguiling', 'bewildering', 'bewitched', 'crazy', 'enchanted', 'enigmatic', 'exceptional', 'extraordinary', 'fabulous'],
    'miraculously': ['beguilingly', 'bewilderingly', 'enigmatically', 'exceptionally', 'extraordinarily', 'fabulously', 'fantastically', 'fascinatingly', 'incomprehensibly', 'inconceivably', 'incredibly', 'marvelously'],
    'mirage': ['apparition', 'appearance', 'bafflement', 'balk', 'bamboozlement', 'befooling', 'betrayed hope', 'blasted expectation', 'blighted hope', 'blow', 'bluffing', 'buffet'],
    'mire': ['adhere', 'baygall', 'befoul', 'begrime', 'bemire', 'bemud', 'besmirch', 'besmoke', 'blacken', 'bog', 'bog down', 'bottom'],
    'mirror': ['acme', 'act like', 'adumbrate', 'affect', 'antetype', 'antitype', 'ape', 'apotheosis', 'appear like', 'approach', 'approximate', 'archetype'],
    'mirror image': ['antipode', 'antipodes', 'antipole', 'antithesis', 'antonym', 'contra', 'converse', 'counter', 'counterbalance', 'countercheck', 'counterpoint', 'counterpoise'],
    'mirroring': ['companion', 'copy', 'copying', 'counterfeiting', 'dead ringer', 'double', 'duplicate', 'effigy', 'emulation', 'exact likeness', 'fakery', 'fellow'],
    'mirth': ['amusement', 'buoyancy', 'cheer', 'cheerfulness', 'diversion', 'divertisement', 'divertissement', 'enjoyment', 'entertainment', 'frivolity', 'frolic', 'fun'],
    'mirthful': ['blithe', 'blithesome', 'buxom', 'festive', 'frivolous', 'gay', 'gleeful', 'hilarious', 'jocular', 'jocund', 'jolly', 'jovial'],
    'miry': ['boggish', 'boggy', 'dingy', 'dirty', 'dusty', 'fenny', 'grimy', 'grubby', 'grungy', 'marish', 'marshy', 'messy'],
    'misadventure': ['accident', 'blow', 'blunder', 'boner', 'bull', 'calamity', 'casualty', 'cataclysm', 'catastrophe', 'collision', 'contretemps', 'crack-up'],
    'misalliance': ['a world-without-end bargain', 'abnormality', 'alliance', 'anomaly', 'bed', 'bond of matrimony', 'bridebed', 'cohabitation', 'conjugal bond', 'conjugal knot', 'coverture', 'holy matrimony'],
    'misanthrope': ['anglophobe', 'russophobe', 'anchoret', 'anchorite', 'bigot', 'cynic', 'hater', 'hermit', 'lone wolf', 'loner', 'man-hater', 'misanthropist'],
    'misanthropic': ['timonistic', 'antisocial', 'cynical', 'egocentric', 'egoistic', 'eremitic', 'man-hating', 'misogynic', 'misogynous', 'reclusive', 'reserved', 'sexist'],
    'misanthropy': ['anglophobia', 'russophobia', 'abhorrence', 'abomination', 'anti-semitism', 'antipathy', 'aversion', 'bigotry', 'despitefulness', 'detestation', 'dislike', 'execration'],
    'misapplication': ['aberrancy', 'aberration', 'abuse', 'abuse of office', 'abuse of terms', 'apparent soundness', 'befoulment', 'casuistry', 'catachresis', 'circularity', 'contorting', 'conversion'],
    'misapply': ['abuse', 'argue insincerely', 'befoul', 'contort', 'convert', 'debase', 'defalcate', 'defile', 'desecrate', 'distort', 'divert', 'do amiss'],
    'misapprehend': ['contort', 'distort', 'garble', 'get one wrong', 'get wrong', 'gloss', 'make a miscue', 'make a mistake', 'misapply', 'miscite', 'misconceive', 'misconstrue'],
    'misapprehension': ['abuse of terms', 'catachresis', 'clerical error', 'contorting', 'corrigendum', 'distortion', 'eisegesis', 'erratum', 'error', 'failure', 'fault', 'faute'],
    'misappropriate': ['abuse', 'befoul', 'convert', 'debase', 'defalcate', 'defile', 'desecrate', 'divert', 'embezzle', 'expropriate', 'filch', 'foul'],
    'misappropriation': ['abuse', 'abuse of office', 'befoulment', 'conversion', 'corrupt administration', 'debasement', 'defalcation', 'defilement', 'desecration', 'diversion', 'embezzlement', 'fouling'],
    'misbegotten': ['bandy', 'bandy-legged', 'baroque', 'baseborn', 'bastard', 'bizarre', 'blemished', 'bloated', 'bowlegged', 'cacogenic', 'club-footed', 'defaced'],
    'misbelief': ['albigensianism', 'arianism', 'catharism', 'ebionitism', 'erastianism', 'gnosticism', 'jovinianism', 'lollardy', 'manichaeanism', 'manichaeism', 'monophysism', 'monophysitism'],
    'misbelieve': ['be in error', 'be mistaken', 'be wrong', 'deny', 'deviate', 'disbelieve', 'discredit', 'err', 'fall into error', 'gag on', 'go astray', 'go wrong'],
    'misbeliever': ['albigensian', 'arian', 'cathar', 'donatist', 'ebionite', 'erastian', 'gnostic', 'jansenist', 'lollard', 'manichaean', 'monophysite', 'montanist'],
    'miscalculate': ['deviate', 'discount', 'disregard', 'err', 'fall into error', 'go amiss', 'go astray', 'go awry', 'go wrong', 'judge amiss', 'lapse', 'misappreciate'],
    'miscalculation': ['clerical error', 'corrigendum', 'erratum', 'error', 'error in judgment', 'failure', 'fault', 'faute', 'human error', 'injudiciousness', 'misappreciation', 'misapprehension'],
    'miscarriage': ['abortion', 'abortive attempt', 'breakdown', 'clerical error', 'collapse', 'corrigendum', 'defeat', 'dud', 'erratum', 'error', 'failing', 'failure'],
    'miscarry': ['abort', 'break down', 'come to grief', 'die', 'fail', 'fall through', 'flop', 'founder', 'go amiss', 'go astray', 'go awry', 'go wrong'],
    'miscegenate': ['be made one', 'be spliced', 'become one', 'contract matrimony', 'couple', 'cross', 'crossbreed', 'espouse', 'get hitched', 'hybridize', 'interbreed', 'intermarry'],
    'miscegenation': ['a world-without-end bargain', 'alliance', 'bed', 'bond of matrimony', 'bridebed', 'cohabitation', 'conjugal bond', 'conjugal knot', 'coverture', 'crossbreeding', 'crossing', 'holy matrimony'],
    'miscellaneous': ['amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'assorted', 'blended', 'combined', 'complex', 'composite', 'compound', 'compounded', 'conglomerate'],
    'miscellany': ['festschrift', 'album', 'all sorts', 'ana', 'analects', 'anthology', 'assemblage', 'assortment', 'beauties', 'brew', 'broad spectrum', 'canon'],
    'mischance': ['accident', 'adversity', 'blow', 'calamity', 'casualty', 'cataclysm', 'catastrophe', 'collision', 'contretemps', 'crack-up', 'crash', 'disaster'],
    'mischief': ['discordia', 'eris', 'abomination', 'atrocity', 'bad', 'bad boy', 'badness', 'bane', 'bankruptcy', 'befoulment', 'blight', 'booger'],
    'mischief maker': ['agent provocateur', 'agitator', 'agitprop', 'bad boy', 'booger', 'buffoon', 'bugger', 'catalyst', 'cutup', 'demagogue', 'devil', 'elf'],
    'mischievous': ['annoying', 'arch', 'artful', 'bad', 'baleful', 'baneful', 'bothering', 'bothersome', 'corroding', 'corrosive', 'corrupting', 'corruptive'],
    'mischievousness': ['annoying', 'belie', 'color', 'devilment', 'devilry', 'deviltry', 'diablerie', 'distort', 'evil', 'falsify', 'garble', 'harm'],
    'misconceive': ['contort', 'distort', 'garble', 'get one wrong', 'get wrong', 'gloss', 'make a miscue', 'make a mistake', 'misapply', 'misapprehend', 'miscite', 'misconstrue'],
    'misconception': ['abuse of terms', 'airy nothing', 'autism', 'bubble', 'catachresis', 'chimera', 'clerical error', 'contorting', 'corrigendum', 'daydream', 'deception', 'deluded belief'],
    'misconduct': ['abuse', 'abuse of office', 'bad policy', 'badness', 'be negligent', 'befoulment', 'conversion', 'corrupt administration', 'crime', 'criminal tendency', 'criminality', 'criminosis'],
    'misconstruction': ['aberrancy', 'aberration', 'abuse of terms', 'antiphrasis', 'barbarism', 'catachresis', 'coloring', 'confabulation', 'contorting', 'corruption', 'defectiveness', 'delusion'],
    'misconstrue': ['bias', 'color', 'contort', 'distort', 'err', 'garble', 'get one wrong', 'get wrong', 'gloss', 'judge amiss', 'misapply', 'misappreciate'],
    'miscreant': ['backslider', 'bad egg', 'bad lot', 'base', 'bastard', 'black sheep', 'blackguard', 'caitiff', 'corrupt', 'criminal', 'crook', 'degenerate'],
    'miscue': ['bad job', 'balk', 'be all thumbs', 'bevue', 'blooper', 'blunder', 'blunder away', 'blunder into', 'blunder on', 'blunder upon', 'bobble', 'boggle'],
    'misdate': ['anachronism', 'antedate', 'antedating', 'anticipation', 'earliness', 'foredate', 'historical error', 'lag', 'lateness', 'metachronism', 'misdating', 'mistime'],
    'misdated': ['ahead of time', 'anachronistic', 'antedated', 'beforehand', 'behind time', 'behindhand', 'dated', 'early', 'foredated', 'late', 'metachronistic', 'mistimed'],
    'misdeed': ['atrocity', 'breach', 'crime', 'crime against humanity', 'deadly sin', 'delinquency', 'dereliction', 'enormity', 'error', 'evil', 'failure', 'fault'],
    'misdemeanor': ['atrocity', 'badness', 'breach', 'crime', 'crime against humanity', 'criminal tendency', 'criminality', 'criminosis', 'deadly sin', 'delict', 'delinquency', 'dereliction'],
    'misdirect': ['be negligent', 'bias', 'bowl a googly', 'color', 'corrupt', 'garble', 'lead astray', 'maladminister', 'misaddress', 'misadminister', 'misadvise', 'misconduct'],
    'misdirected': ['botched', 'bungled', 'butchered', 'fumbled', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-done', 'ill-executed', 'ill-managed', 'impolitic'],
    'misdirection': ['bad policy', 'bum steer', 'college of laputa', 'corruption', 'false coloring', 'impolicy', 'inexpedience', 'inexpediency', 'maladministration', 'malfeasance', 'malpractice', 'misadministration'],
    'miser': ['silas marner', 'accumulator', 'bill collector', 'cheapskate', 'churl', 'collection agent', 'collector', 'connoisseur', 'curmudgeon', 'douanier', 'dunner', 'exciseman'],
    'miserable': ['abject', 'abominable', 'adverse', 'afflicted', 'antagonistic', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'beggarly', 'beneath contempt'],
    'miserably': ['abjectly', 'abominably', 'agonizingly', 'arrantly', 'atrociously', 'awfully', 'baldly', 'balefully', 'basely', 'bitterly', 'blatantly', 'brashly'],
    'miserere': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'nunc dimittis', 'te deum', 'trisagion', 'vedic hymn', 'alleluia'],
    'miserly': ['lenten', 'spartan', 'a hog for', 'abject', 'abstemious', 'acquisitive', 'all-devouring', 'ascetic', 'austere', 'avaricious', 'avid', 'bottomless'],
    'misery': ['cassandra', 'schmerz', 'ache', 'aches and pains', 'aching heart', 'adversity', 'affliction', 'agony', 'agony of mind', 'angst', 'anguish', 'anxiety'],
    'misfeasance': ['aberrancy', 'aberration', 'abuse', 'abuse of office', 'atrocity', 'bad policy', 'befoulment', 'breach', 'conversion', 'corrupt administration', 'crime', 'crime against humanity'],
    'misfire': ['abort', 'abortion', 'abortive attempt', 'blow up', 'come a cropper', 'come to nothing', 'dud', 'explode', 'fail', 'fail miserably', 'failure', 'fall through'],
    'misfit': ['bohemian', 'anomaly', 'beatnik', 'black sheep', 'blemish', 'crosspatch', 'deviant', 'dissenter', 'dropout', 'eccentric', 'flower child', 'foreign body'],
    'misfortune': ['accident', 'adversity', 'bad luck', 'bad news', 'blow', 'calamity', 'casualty', 'cataclysm', 'catastrophe', 'collision', 'contretemps', 'crack-up'],
    'misgiving': ['pyrrhonism', 'agitated', 'agitation', 'all-overish', 'all-overs', 'angst', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious', 'anxious bench', 'anxious concern'],
    'misguidance': ['bad policy', 'bum steer', 'college of laputa', 'corruption', 'impolicy', 'inexpedience', 'inexpediency', 'maladministration', 'malfeasance', 'malpractice', 'misadministration', 'misconduct'],
    'misguide': ['be negligent', 'bowl a googly', 'corrupt', 'lead astray', 'maladminister', 'misadminister', 'misadvise', 'misconduct', 'misdirect', 'miseducate', 'misgovern', 'mishandle'],
    'misguided': ['botched', 'bungled', 'butchered', 'erroneous', 'fallacious', 'foolish', 'fumbled', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-done'],
    'mishandle': ['abuse', 'batter', 'be negligent', 'beat up', 'befoul', 'botch', 'bruise', 'brutalize', 'buffet', 'bugger up', 'bungle', 'convert'],
    'mishandling': ['abuse', 'abuse of office', 'bad policy', 'befoulment', 'conversion', 'corrupt administration', 'debasement', 'defalcation', 'defilement', 'desecration', 'diversion', 'embezzlement'],
    'mishap': ['accident', 'adversity', 'blow', 'calamity', 'casualty', 'cataclysm', 'catastrophe', 'collision', 'contretemps', 'crack-up', 'crash', 'disaster'],
    'mishmash': ['all sorts', 'arsy-varsiness', 'assemblage', 'assortment', 'broad spectrum', 'clutter', 'conglomeration', 'farrago', 'gallimaufry', 'goulash', 'hash', 'helter-skelter'],
    'misinform': ['bowl a googly', 'con', 'corrupt', 'deceive', 'defraud', 'delude', 'dupe', 'fool', 'gull', 'lead astray', 'misadvise', 'misdirect'],
    'misinformed': ['gothic', 'philistine', 'barbarous', 'bookless', 'deceived', 'functionally illiterate', 'grammarless', 'heathen', 'hoodwinked', 'ill-educated', 'illiterate', 'led astray'],
    'misinterpret': ['bias', 'bugger up', 'color', 'contort', 'distort', 'err', 'garble', 'get one wrong', 'get wrong', 'gloss', 'judge amiss', 'make a miscue'],
    'misinterpretation': ['aberrancy', 'aberration', 'corruption', 'defectiveness', 'delusion', 'deviancy', 'distortion', 'errancy', 'erroneousness', 'error', 'error in judgment', 'fallaciousness'],
    'misjudge': ['contort', 'distort', 'err', 'garble', 'get one wrong', 'get wrong', 'gloss', 'judge amiss', 'misapply', 'misappreciate', 'misapprehend', 'miscalculate'],
    'misjudgment': ['aberrancy', 'aberration', 'abuse of terms', 'catachresis', 'clerical error', 'contorting', 'corrigendum', 'defectiveness', 'delusion', 'deviancy', 'distortion', 'eisegesis'],
    'mislay': ['be bereaved of', 'default', 'drop', 'forfeit', 'go astray from', 'incur loss', 'kiss good-bye', 'let slip', 'lose', 'lose out', 'mislocate', 'misplace'],
    'mislead': ['abuse', 'bamboozle', 'be untruthful', 'beguile', 'betray', 'bluff', 'bowl a googly', 'bunk', 'con', 'corrupt', 'cozen', 'debauch'],
    'misleading': ['barmecidal', 'barmecide', 'airy', 'apparent', 'apparitional', 'autistic', 'beguiling', 'bewildering', 'bum steer', 'catchy', 'chimeric', 'college of laputa'],
    'mismanage': ['abuse', 'be negligent', 'befoul', 'convert', 'debase', 'defalcate', 'defile', 'desecrate', 'divert', 'do amiss', 'embezzle', 'foul'],
    'mismanaged': ['botched', 'bungled', 'butchered', 'fumbled', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-done', 'ill-executed', 'ill-managed', 'impolitic'],
    'mismanagement': ['abuse', 'abuse of office', 'bad policy', 'befoulment', 'conversion', 'corrupt administration', 'debasement', 'defalcation', 'defilement', 'desecration', 'diversion', 'embezzlement'],
    'mismatch': ['abnormality', 'agree to disagree', 'anomaly', 'be at cross-purposes', 'break', 'break off', 'clash', 'collide', 'conflict', 'contradict', 'counter', 'differ'],
    'mismatched': ['asymmetric', 'discordant', 'disparate', 'disproportionate', 'ill-adapted', 'ill-assorted', 'ill-chosen', 'ill-fitted', 'ill-matched', 'ill-sorted', 'ill-suited', 'ill-timed'],
    'misogynist': ['anglophobe', 'russophobe', 'bigot', 'celibataire', 'celibate', 'cynic', 'hater', 'man-hater', 'misanthrope', 'misanthropist', 'misogamist', 'monastic'],
    'misogyny': ['anglophobia', 'russophobia', 'abhorrence', 'abomination', 'anti-semitism', 'antipathy', 'aversion', 'bachelordom', 'bachelorhood', 'bachelorism', 'bachelorship', 'bigotry'],
    'misplaced': ['amiss', 'askew', 'awry', 'cockeyed', 'convulsed', 'deranged', 'disarranged', 'discomfited', 'discomposed', 'disconcerted', 'dislocated', 'disordered'],
    'misplay': ['clerical error', 'corrigendum', 'do amiss', 'erratum', 'error', 'failure', 'fault', 'faute', 'human error', 'misapply', 'misapprehension', 'miscalculation'],
    'misprint': ['clerical error', 'corrigendum', 'do amiss', 'erratum', 'error', 'failure', 'fault', 'faute', 'human error', 'literal', 'misapply', 'misapprehension'],
    'misprize': ['be above', 'be contemptuous of', 'belittle', 'care nothing for', 'contemn', 'deprecate', 'depreciate', 'deride', 'despise', 'disdain', 'disparage', 'disprize'],
    'mispronounced': ['blurred', 'breathy', 'choked', 'choking', 'croaking', 'drawling', 'drawly', 'dysphonic', 'guttural', 'harsh', 'hawking', 'hoarse'],
    'mispronunciation': ['irish bull', 'anacoluthon', 'bull', 'cacoepy', 'cacology', 'catachresis', 'corruption', 'fluff', 'folk etymology', 'gammacism', 'grammatical error', 'hypercorrection'],
    'misquote': ['belie', 'burlesque', 'camouflage', 'caricature', 'color', 'contort', 'disguise', 'distort', 'do amiss', 'dress up', 'embellish', 'embroider'],
    'misquoted': ['biased', 'cooked', 'doctored', 'garbled', 'inauthentic', 'miscited', 'misreported', 'misrepresented', 'misstated', 'perverted', 'slanted', 'spurious'],
    'misread': ['catachrestic', 'contort', 'distort', 'distorted', 'do amiss', 'eisegetical', 'garble', 'garbled', 'get one wrong', 'get wrong', 'gloss', 'misapply'],
    'misreading': ['abuse of terms', 'catachresis', 'contorting', 'distortion', 'eisegesis', 'error', 'error in judgment', 'garbling', 'gloss', 'injudiciousness', 'malentendu', 'malobservation'],
    'misrender': ['bias', 'color', 'contort', 'distort', 'garble', 'get one wrong', 'get wrong', 'gloss', 'misapply', 'misapprehend', 'miscite', 'misconceive'],
    'misrendering': ['abuse of terms', 'catachresis', 'contorting', 'distortion', 'eisegesis', 'error', 'garbling', 'gloss', 'malentendu', 'malobservation', 'misapplication', 'misapprehension'],
    'misrepresent': ['belie', 'bias', 'burlesque', 'camouflage', 'caricature', 'cloak', 'color', 'confuse', 'counterfeit', 'disguise', 'dissemble', 'distort'],
    'misrepresentation': ['canard', 'coloring', 'confabulation', 'corruption', 'distortion', 'equivocation', 'exaggeration', 'false coloring', 'false swearing', 'falsehood', 'falsification', 'falsifying'],
    'misrule': ['anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism', 'bad policy', 'be negligent', 'chaos', 'confusion', 'criminal syndicalism', 'disorder', 'disorderliness', 'disorganization'],
    'miss': ['frau', 'fraulein', 'mistress', 'mlle', 'mme', 'mmes', 'dame', 'dona', 'donna', 'lady', 'madam', 'madame'],
    'miss america': ['bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'beauty queen', 'belle', 'bunny', 'charmer', 'cover girl', 'dazzler', 'dream'],
    'miss the boat': ['be behindhand', 'be late', 'be overdue', 'blow the chance', 'get up late', 'go amiss', 'go astray', 'keep everyone waiting', 'keep late hours', 'lose the chance', 'lose the opportunity', 'miscarry'],
    'miss the mark': ['blunder', 'bungle', 'come short', 'err', 'fall down', 'fall short', 'foozle', 'go amiss', 'go astray', 'goof', 'miscarry', 'misfire'],
    'missal': ['sefer torah', 'torah', 'torah scroll', 'virginal', 'breviary', 'canon', 'church book', 'euchologion', 'euchology', 'farse', 'formulary', 'lectionary'],
    'missed': ['abandoned', 'deserted', 'disregarded', 'half-done', 'ignored', 'laid aside', 'left undone', 'neglected', 'omitted', 'overlooked', 'passed by', 'passed over'],
    'misshapen': ['acromegalic', 'aimless', 'amorphous', 'awry', 'bandy', 'bandy-legged', 'baroque', 'bizarre', 'blemished', 'bloated', 'bowlegged', 'cacogenic'],
    'missile': ['aa target rocket', 'abm', 'asm', 'ats', 'asp', 'asroc', 'atlas', 'atlas-agena', 'atlas-centaur', 'bullpup', 'cajun', 'corporal'],
    'missilery': ['a-weapons', 'archery', 'armament', 'arms', 'artillery', 'ballistics', 'biological weapons', 'conventional weapons', 'deadly weapons', 'gunnery', 'instrumentation', 'instruments of destruction'],
    'missing': ['absconded', 'absent', 'arrested', 'away', 'bankrupt in', 'bare of', 'bereft of', 'callow', 'defective', 'deficient', 'deleted', 'denuded of'],
    'missing link': ['bronze age man', 'hominidae', 'iron age man', 'stone age man', 'aboriginal', 'aborigine', 'ancient', 'antediluvian', 'anthropoid', 'ape-man', 'arrearage', 'autochthon'],
    'mission': ['accredit', 'action', 'activity', 'adventure', 'agency', 'agentship', 'aim', 'air cover', 'air raid', 'air support', 'allegiance', 'amphibious operations'],
    'misstate': ['belie', 'burlesque', 'camouflage', 'caricature', 'color', 'disguise', 'distort', 'dress up', 'embellish', 'embroider', 'exaggerate', 'falsify'],
    'misstatement': ['abstractionism', 'bloomer', 'blooper', 'blunder', 'clerical error', 'coloring', 'confabulation', 'corrigendum', 'deformation', 'distortion', 'equivocation', 'erratum'],
    'misstep': ['balk', 'bevue', 'bloomer', 'blooper', 'blunder', 'error', 'false move', 'false step', 'faux pas', 'gaffe', 'goof', 'howler'],
    'mist': ['london fog', 'london special', 'scotch mist', 'addle', 'addle the wits', 'air', 'airy nothing', 'amorphousness', 'ball up', 'becloud', 'bedazzle', 'befog'],
    'mistake': ['bad job', 'bevue', 'bloomer', 'blooper', 'blunder', 'bobble', 'boggle', 'bonehead play', 'boner', 'boo-boo', 'boob', 'botch'],
    'mistaken': ['all wet', 'all wrong', 'amiss', 'catachrestic', 'distorted', 'eisegetical', 'erring', 'erroneous', 'fallacious', 'false', 'faulty', 'flawed'],
    'mistaught': ['gothic', 'philistine', 'barbarous', 'bookless', 'deceived', 'functionally illiterate', 'grammarless', 'heathen', 'hoodwinked', 'ill-educated', 'illiterate', 'led astray'],
    'misteach': ['belie', 'burlesque', 'camouflage', 'caricature', 'color', 'corrupt', 'disguise', 'distort', 'exaggerate', 'falsify', 'garble', 'misadvise'],
    'misteaching': ['abstractionism', 'coloring', 'deformation', 'distortion', 'exaggeration', 'expressionism', 'false coloring', 'falsification', 'garbling', 'hyperbole', 'inaccuracy', 'injustice'],
    'mistimed': ['ahead of time', 'anachronistic', 'antedated', 'beforehand', 'behind time', 'behindhand', 'dated', 'early', 'foredated', 'ill-considered', 'ill-seasoned', 'ill-timed'],
    'mistral': ['euroclydon', 'tehuantepec wind', 'tehuantepecer', 'bise', 'east wind', 'easter', 'easterly', 'gregale', 'levanter', 'north wind', 'northeaster', 'norther'],
    'mistreat': ['abuse', 'afflict', 'aggrieve', 'batter', 'befoul', 'bewitch', 'blight', 'bruise', 'brutalize', 'buffet', 'condemn', 'corrupt'],
    'mistress': ['frau', 'fraulein', 'miss', 'mlle', 'mme', 'mmes', 'dame', 'dona', 'donna', 'lady', 'madam', 'madame'],
    'mistrust': ['pyrrhonism', 'apprehension', 'apprehensiveness', 'awake a doubt', 'be diffident', 'be doubtful', 'be dubious', 'be possessive', 'be skeptical', 'be uncertain', 'beware', 'cageyness'],
    'mistrustful': ['pyrrhonic', 'agnostic', 'cagey', 'chary', 'distrustful', 'doubtful', 'doubting', 'dubious', 'from missouri', 'in doubt', 'leery', 'mistrusting'],
    'misty': ['addlebrained', 'addled', 'addleheaded', 'addlepated', 'airy', 'amorphic', 'amorphous', 'anarchic', 'attenuate', 'attenuated', 'baggy', 'beclouded'],
    'misunderstand': ['contort', 'distort', 'garble', 'get one wrong', 'get wrong', 'gloss', 'make a miscue', 'make a mistake', 'misapply', 'misapprehend', 'miscalculate', 'miscite'],
    'misunderstanding': ['abuse of terms', 'agreement to disagree', 'argument', 'catachresis', 'clerical error', 'contorting', 'controversy', 'corrigendum', 'cross-purposes', 'difference', 'difference of opinion', 'difficulty'],
    'misunderstood': ['catachrestic', 'despised', 'disliked', 'distorted', 'eisegetical', 'garbled', 'lowly', 'misapprehended', 'misconceived', 'misconstrued', 'misinterpreted', 'misprized'],
    'misusage': ['irish bull', 'abuse', 'abuse of office', 'anacoluthon', 'antiphrasis', 'barbarism', 'befoulment', 'bull', 'catachresis', 'conversion', 'corrupt administration', 'corruption'],
    'misuse': ['abuse', 'active use', 'adulterate', 'adulteration', 'alloy', 'appliance', 'application', 'barbarism', 'befoul', 'befouling', 'bias', 'bleed'],
    'mite': ['ace', 'arachnid', 'arthropod', 'atom', 'bairn', 'bawbee', 'beetle', 'bit', 'bug', 'cat flea', 'caterpillar', 'centipede'],
    'miter': ['ankle', 'articulate', 'articulation', 'batten', 'batten down', 'bolt', 'boundary', 'buckle', 'butt', 'button', 'cervix', 'clasp'],
    'mithras': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'mitigate': ['abate', 'accommodate', 'adapt', 'adjust', 'adjust to', 'allay', 'alleviate', 'allow for', 'alter', 'ameliorate', 'anesthetize', 'appease'],
    'mitigating': ['abating', 'allaying', 'alleviating', 'alleviative', 'altering', 'analgesic', 'anesthetic', 'anodyne', 'assuaging', 'assuasive', 'balmy', 'balsamic'],
    'mitigation': ['abatement', 'about-face', 'abridgment', 'accommodation', 'adaptation', 'adjustment', 'allayment', 'alleviation', 'allowance', 'alteration', 'amelioration', 'analgesia'],
    'mitigator': ['alleviative', 'alleviator', 'anodyne', 'assuager', 'balm', 'calmative', 'cushion', 'dolorifuge', 'lenitive', 'moderator', 'modulator', 'mollifier'],
    'mitzvah': ['act of grace', 'act of kindness', 'benefaction', 'benefit', 'benevolence', 'benignity', 'blessing', 'canon', 'code', 'commandment', 'convention', 'courtesy'],
    'mix': ['add', 'admix', 'admixture', 'all sorts', 'alloy', 'amalgam', 'amalgamate', 'amalgamation', 'assemblage', 'assemble', 'assimilate', 'associate'],
    'mix up': ['addle', 'addle the wits', 'admix', 'alloy', 'amalgamate', 'anarchy', 'ball up', 'becloud', 'bedazzle', 'befuddle', 'bemingle', 'bewilder'],
    'mixed': ['adulterated', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'assimilated', 'associated', 'assorted', 'blemished', 'blended', 'clashing', 'combinative'],
    'mixed bag': ['all sorts', 'assemblage', 'assortment', 'broad spectrum', 'conglomeration', 'gallimaufry', 'hash', 'hodgepodge', 'hotchpot', 'hotchpotch', 'jumble', 'magpie'],
    'mixed blood': ['cape colored', 'eurasian', 'cattalo', 'citrange', 'cross', 'crossbreed', 'griffe', 'half blood', 'half-bred', 'half-breed', 'half-caste', 'high yellow'],
    'mixed marriage': ['a world-without-end bargain', 'alliance', 'bed', 'bond of matrimony', 'bridebed', 'cohabitation', 'conjugal bond', 'conjugal knot', 'coverture', 'holy matrimony', 'holy wedlock', 'husbandhood'],
    'mixed up': ['byzantine', 'anarchic', 'arsy-varsy', 'ass-backwards', 'balled up', 'balled-up', 'bollixed up', 'bothered', 'chaotic', 'complex', 'complicated', 'confounded'],
    'mixer': ['arrl', 'agitator', 'amateur radio operator', 'bal', 'bal costume', 'bal masque', 'ball', 'barn dance', 'beater', 'blender', 'bon vivant', 'cement mixer'],
    'mixing': ['fcc', 'fm broadcasting', 'admixture', 'alloyage', 'amalgamation', 'blending', 'broadcasting', 'coalescence', 'combination', 'comminglement', 'commingling', 'commixture'],
    'mixture': ['english horn', 'admixture', 'alloy', 'alloying', 'amalgam', 'amalgamating', 'amalgamation', 'assemblage', 'assembly', 'associating', 'association', 'assortment'],
    'moan': ['bawl', 'beef', 'bemoan', 'bewail', 'bitch', 'complain', 'complaint', 'cry', 'cry out', 'deplore', 'dirge', 'dolorous tirade'],
    'moaning': ['bemoaning', 'bewailing', 'grieving', 'howling', 'in mourning', 'keening', 'lamentation', 'lamenting', 'mourning', 'sigh', 'sighing', 'sobbing'],
    'moat': ['abri', 'abysm', 'abyss', 'approach trench', 'aqueduct', 'arch dam', 'arroyo', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage'],
    'mob': ['black hand', 'bund', 'cosa nostra', 'rochdale cooperative', 'a mass of', 'a world of', 'age group', 'alliance', 'army', 'assemblage', 'association', 'axis'],
    'mob rule': ['absolute monarchy', 'anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism', 'aristocracy', 'autarchy', 'autocracy', 'autonomy', 'chaos', 'coalition government', 'colonialism'],
    'mobile': ['able to adapt', 'active', 'adaptable', 'adjustable', 'agile', 'alert', 'all-around', 'alterable', 'alterative', 'ambidextrous', 'ambulant', 'ambulatory'],
    'mobility': ['adaptability', 'adjustability', 'alterability', 'changeability', 'changeableness', 'changefulness', 'flexibility', 'fluidity', 'impermanence', 'locomotion', 'malleability', 'modifiability'],
    'mobilization': ['activation', 'activity', 'actuation', 'arms race', 'arrangement', 'assemblage', 'assembly', 'basic training', 'briefing', 'bugle call', 'call', 'call to arms'],
    'mobilize': ['accouple', 'accumulate', 'activate', 'actuate', 'agglomerate', 'agglutinate', 'aggregate', 'aggroup', 'amass', 'arrange', 'articulate', 'assemble'],
    'mobilized': ['all ready', 'all set', 'armed', 'armed and ready', 'booted and spurred', 'briefed', 'coached', 'cocked', 'equipped', 'familiarized', 'good and ready', 'groomed'],
    'mobster': ['judas', 'bad person', 'bandit', 'betrayer', 'brigand', 'convict', 'criminal', 'crook', 'dacoit', 'deceiver', 'delinquent', 'desperado'],
    'mock': ['parthian shot', 'abuse', 'adopt', 'affect', 'affected', 'affront', 'alike', 'alternate', 'alternative', 'ape', 'aped', 'apocryphal'],
    'mock heroic': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'bardic', 'broad', 'bucolic', 'burlesque'],
    'mock up': ['burlesque', 'clay model', 'copy', 'dummy', 'duplication', 'facsimile', 'imitation', 'knockoff', 'lay figure', 'mannequin', 'model', 'paraphrase'],
    'mocker': ['ape', 'conformist', 'copier', 'copycat', 'copyist', 'counterfeiter', 'cuckoo', 'dissembler', 'dissimulator', 'echo', 'echoer', 'echoist'],
    'mockery': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'absurdity', 'abuse', 'affront', 'aggressive mimicry', 'apery', 'aspersion', 'atrocity'],
    'mocking': ['adoption', 'appropriation', 'assumption', 'bantering', 'booing', 'borrowed plumes', 'catcalling', 'chaffing', 'copying', 'derisive', 'derisory', 'derivation'],
    'mockingbird': ['philomel', 'ape', 'bulbul', 'canary', 'conformist', 'copier', 'copycat', 'copyist', 'counterfeiter', 'cuckoo', 'dissembler', 'dissimulator'],
    'mod': ['a la mode', 'advanced', 'all the rage', 'all the thing', 'avant-garde', 'contemporary', 'current', 'far out', 'fashionable', 'forward-looking', 'hip', 'in'],
    'modality': ['platonic form', 'platonic idea', 'aesthetic form', 'archetype', 'art form', 'bearings', 'build', 'case', 'cast', 'circumstance', 'condition', 'configuration'],
    'mode': ['aeolian mode', 'aristotelian sorites', 'dorian mode', 'goclenian sorites', 'greek modes', 'hindu mode', 'indian mode', 'locrian mode', 'lydian mode', 'mo', 'phrygian mode', 'platonic form'],
    'model': ['geistesgeschichte', 'hegelian idea', 'kantian idea', 'miss america', 'platonic form', 'platonic idea', 'admirable', 'aesthetic form', 'apotheosis', 'archetypal', 'archetype', 'archetypical'],
    'modeled': ['anaglyphic', 'anaglyptic', 'anastatic', 'carved', 'ceroplastic', 'chased', 'embossed', 'engraven', 'glyphic', 'glyptic', 'graven', 'hammered'],
    'modeler': ['carver', 'chaser', 'clay modeler', 'earth artist', 'figurer', 'figuriste', 'gem carver', 'graver', 'mason', 'molder', 'monumental mason', 'sculptor'],
    'modeling': ['cysp sculpture', 'anaglyptics', 'anaglyptography', 'architectural sculpture', 'bone-carving', 'casting', 'ceroplastics', 'chasing', 'clay sculpture', 'conformation', 'creation', 'decorative sculpture'],
    'moderate': ['laodicean', 'abate', 'acceptable', 'accepting', 'act between', 'adequate', 'adjust to', 'admissible', 'all right', 'allay', 'alleviate', 'alter'],
    'moderately': ['acceptably', 'adequately', 'after a fashion', 'appreciably', 'at a bargain', 'at a sacrifice', 'at any rate', 'at best', 'at budget prices', 'at cost', 'at cost price', 'at least'],
    'moderation': ['abnegation', 'boundary', 'bounds', 'center', 'compromise', 'confinement', 'constraint', 'continence', 'denial', 'discipline', 'fence', 'forbearance'],
    'moderator': ['jp', 'justice', 'mc', 'alleviative', 'alleviator', 'anchorman', 'anodyne', 'arbiter', 'arbitrator', 'assuager', 'balm', 'bencher'],
    'modern': ['young turk', 'a la mode', 'actual', 'advanced', 'all the rage', 'all the thing', 'arriviste', 'as is', 'avant-garde', 'being', 'brand-new', 'bright young man'],
    'modernist': ['meistersinger', 'parnassian', 'young turk', 'arch-poet', 'arriviste', 'ballad maker', 'balladmonger', 'bard', 'beat poet', 'bright young man', 'bucoliast', 'comer'],
    'modernized': ['a la mode', 'advanced', 'avant-garde', 'contemporary', 'far out', 'fashionable', 'forward-looking', 'in', 'mod', 'modern', 'modernistic', 'modish'],
    'modest': ['olympian', 'aloof', 'altruistic', 'backward', 'bashful', 'becoming', 'betwixt and between', 'blank', 'boggling', 'budget', 'cheap', 'chilled'],
    'modestly': ['abjectly', 'after a fashion', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst', 'comparatively'],
    'modesty': ['aloofness', 'altruism', 'backwardness', 'bashfulness', 'blankness', 'boggle', 'boggling', 'chilliness', 'coldness', 'commitment', 'compunction', 'consecration'],
    'modicum': ['ace', 'allotment', 'allowance', 'atom', 'big end', 'bigger half', 'bit', 'bite', 'budget', 'butt', 'chip', 'chunk'],
    'modifiable': ['able to adapt', 'adaptable', 'adjustable', 'alterable', 'alterative', 'changeable', 'checkered', 'convertible', 'ever-changing', 'flexible', 'fluid', 'impermanent'],
    'modification': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'allophone', 'allowance', 'alteration', 'alveolar', 'amelioration', 'analysis', 'anatomization', 'apico-alveolar'],
    'modified': ['altered', 'better', 'changeable', 'changed', 'conditioned', 'converted', 'degenerate', 'deviant', 'divergent', 'hedged', 'hedged about', 'improved'],
    'modifier': ['ic analysis', 'agent', 'alterant', 'alterative', 'alterer', 'appositive', 'attribute', 'attributive', 'catalyst', 'catalytic agent', 'complement', 'construction modifier'],
    'modify': ['abate', 'accommodate', 'adapt', 'adjust', 'adjust to', 'alter', 'ameliorate', 'amend', 'analyze', 'anatomize', 'assuage', 'atomize'],
    'modifying': ['altering', 'assuasive', 'bounding', 'extenuating', 'extenuatory', 'lenitive', 'limitative', 'limiting', 'mitigating', 'mitigative', 'mitigatory', 'modificatory'],
    'modish': ['a la mode', 'advanced', 'avant-garde', 'chic', 'contemporary', 'dashing', 'dressed to advantage', 'dressed up', 'en grande tenue', 'endimanche', 'exclusive', 'far out'],
    'modulate': ['abate', 'accommodate', 'adapt', 'adjust', 'adjust to', 'allay', 'alleviate', 'alter', 'ameliorate', 'assuage', 'attemper', 'balance'],
    'modulation': ['am', 'fm', 'pm', 'abatement', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'allayment', 'alleviation', 'alteration', 'amelioration'],
    'modulator': ['alleviative', 'alleviator', 'anodyne', 'assuager', 'balm', 'calmative', 'cushion', 'dolorifuge', 'lenitive', 'mitigator', 'moderator', 'mollifier'],
    'module': ['earth insertion', 'lem', 'lm', 'apogee', 'article', 'attitude-control rocket', 'ballistic capsule', 'burn', 'capsule', 'deep-space ship', 'docking', 'docking maneuver'],
    'modus operandi': ['mo', 'algorithm', 'approach', 'attack', 'course', 'fashion', 'form', 'guise', 'line', 'line of action', 'lines', 'manner'],
    'modus vivendi': ['pax dei', 'pax romana', 'peace of god', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'armistice', 'bearing'],
    'mogul': ['establishment', 'vip', 'avalanche', 'baron', 'big cheese', 'big gun', 'big man', 'big name', 'big noise', 'big shot', 'big wheel', 'bigwig'],
    'moiety': ['allotment', 'allowance', 'ashram', 'big end', 'bigger half', 'bisection', 'bit', 'bite', 'body', 'budget', 'butt', 'caste'],
    'moil': ['agitation', 'be turbulent', 'bluster', 'bobbery', 'boil', 'boiling', 'brouhaha', 'bubble', 'bustle', 'churn', 'clamor', 'commotion'],
    'moire': ['dalmatian', 'antigorite', 'burele', 'butterfly', 'candy cane', 'chameleon', 'chatoyant', 'cheetah', 'chrysotile', 'confetti', 'crazy quilt', 'firedog'],
    'moist': ['boggy', 'clammy', 'damp', 'dampish', 'dank', 'dewy', 'drippy', 'drizzly', 'fenny', 'foggy', 'gooey', 'humid'],
    'moisten': ['asperge', 'bedew', 'bespatter', 'besprinkle', 'dabble', 'damp', 'dampen', 'dash', 'dew', 'douche', 'hose', 'hose down'],
    'moistening': ['affusion', 'aspergation', 'aspersion', 'baptism', 'bath', 'bathing', 'bedewing', 'dampening', 'damping', 'deluge', 'dewing', 'drenching'],
    'moisture': ['scotch mist', 'blood rain', 'chylifaction', 'chylification', 'drizzle', 'evening mist', 'fall', 'flow', 'fluency', 'fluidity', 'fluidness', 'flurry'],
    'molar': ['baby tooth', 'bicuspid', 'bucktooth', 'canine', 'crown', 'cuspid', 'cutter', 'deciduous tooth', 'dent', 'dental', 'denticle', 'denticulation'],
    'molasses': ['adherent', 'adhesive', 'albumen', 'ambrosia', 'artificial sweetener', 'barnacle', 'batter', 'blackstrap', 'bonnyclabber', 'bramble', 'brier', 'bulldog'],
    'mold': ['ectocarpales', 'phaeophyceae', 'platonic form', 'platonic idea', 'accommodate', 'accommodate with', 'accord', 'acres', 'adapt', 'adapt to', 'adenovirus', 'adjust'],
    'moldable': ['adaptable', 'apt', 'bendable', 'bending', 'biddable', 'bright', 'clever', 'compliant', 'docile', 'ductile', 'educable', 'elastic'],
    'molded': ['anaglyphic', 'anaglyptic', 'anastatic', 'assembled', 'built', 'carved', 'cast', 'ceroplastic', 'chased', 'constructed', 'crafted', 'created'],
    'molder': ['ablate', 'age', 'antiquate', 'atomize', 'become extinct', 'become obsolete', 'break down', 'break up', 'calm', 'calm down', 'canker', 'carver'],
    'moldering': ['ablative', 'at rest', 'biodegradable', 'blasted', 'blighted', 'blown', 'calm', 'cloistered', 'cool', 'corrosive', 'crumbling', 'decomposable'],
    'molding': ['cysp sculpture', 'anaglyptics', 'anaglyptography', 'anatomy', 'architectonics', 'architectural sculpture', 'architecture', 'arrangement', 'assembly', 'bone-carving', 'build', 'building'],
    'moldy': ['archaic', 'bad', 'bad-smelling', 'blasted', 'blighted', 'blown', 'bygone', 'crumbling', 'dated', 'despoiled', 'dilapidated', 'dusty'],
    'mole': ['abutment', 'anchorage', 'anchorage ground', 'arc-boutant', 'arch dam', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier', 'basin'],
    'molecular': ['atomic', 'corpuscular', 'embryonic', 'evanescent', 'germinal', 'granular', 'impalpable', 'imperceptible', 'imponderable', 'inappreciable', 'indiscernible', 'infinitesimal'],
    'molecule': ['kekule formula', 'ace', 'acid', 'acidity', 'agent', 'air', 'alkali', 'alkalinity', 'alloisomer', 'anion', 'antacid', 'atom'],
    'molehill': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'anthill', 'bagatelle', 'bank', 'barrow', 'bauble', 'bean', 'bibelot'],
    'molest': ['abuse', 'accost', 'afflict', 'aggravate', 'aggrieve', 'annoy', 'attack', 'badger', 'bait', 'batter', 'be at', 'bedevil'],
    'mollify': ['abate', 'allay', 'alleviate', 'anesthetize', 'appease', 'assuage', 'benumb', 'calm', 'calm down', 'compose', 'conciliate', 'cool'],
    'mollifying': ['appeasing', 'calming', 'conciliatory', 'cradling', 'demulcent', 'dreamy', 'drowsy', 'easing', 'emollient', 'gentling', 'hushing', 'irenic'],
    'mollycoddle': ['lord fauntleroy', 'milquetoast', 'percy', 'baby', 'bay', 'big baby', 'cater to', 'chicken', 'cocker', 'coddle', 'cosset', 'cream puff'],
    'moloch': ['adad', 'adapa', 'anu', 'anunaki', 'ashur', 'baal', 'beltu', 'dagon', 'damkina', 'dumuzi', 'ea', 'enlil'],
    'mom': ['dam', 'foster mother', 'genetrix', 'ma', 'mam', 'mama', 'mammy', 'mater', 'materfamilias', 'maternal ancestor', 'matriarch', 'mommy'],
    'moment': ['a breath', 'abundant year', 'academic year', 'accent', 'advantage', 'annum', 'ascendancy', 'authority', 'avail', 'bissextile year', 'bit', 'breath'],
    'moment of truth': ['a-day', 'd day', 'h hour', 'charged moment', 'critical moment', 'crucial moment', 'day', 'deadline', 'decisive moment', 'eleventh hour', 'fateful moment', 'hour'],
    'momentarily': ['briefly', 'fleetingly', 'flickeringly', 'flittingly', 'for a moment', 'immediately', 'in an instant', 'instantaneously', 'instanter', 'instantly', 'just now', 'just then'],
    'momentary': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'brief', 'brittle', 'capricious', 'catamenial', 'centenary', 'centennial', 'changeable'],
    'momentous': ['absolute', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'big', 'big-league', 'big-name', 'big-time', 'bigwig', 'bigwigged'],
    'momentum': ['clout', 'compulsion', 'drive', 'driving force', 'energy', 'force', 'impellent', 'impelling force', 'impetus', 'impulse', 'impulsion', 'incentive'],
    'monad': ['ace', 'air', 'an existence', 'atom', 'atomic particles', 'being', 'body', 'brute matter', 'building block', 'chemical element', 'component', 'constituent'],
    'monarch': ['anointed king', 'boss', 'chief', 'chieftain', 'crowned head', 'czar', 'dynast', 'emperor', 'empress', 'grand duke', 'high chief', 'imperator'],
    'monarchical': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'civic', 'civil', 'constitutional', 'democratic', 'despotic', 'dictatorial'],
    'monarchism': ['bourbonism', 'nazism', 'toryism', 'backwardness', 'centralism', 'collectivism', 'communism', 'conservatism', 'conservativeness', 'constitutionalism', 'democratism', 'die-hardism'],
    'monarchist': ['bircher', 'bourbon', 'tory', 'conservatist', 'conservative', 'diehard', 'extreme right-winger', 'hard hat', 'imperialist', 'radical right', 'reactionarist', 'reactionary'],
    'monarchy': ['caesarism', 'stalinism', 'absolute monarchy', 'absolutism', 'aristocracy', 'autarchy', 'authoritarianism', 'autocracy', 'autonomy', 'benevolent despotism', 'coalition government', 'colonialism'],
    'monastic': ['abbacomes', 'abbot', 'ascetic', 'beadsman', 'brother', 'caloyer', 'celibataire', 'celibate', 'cenobite', 'claustral', 'cloistered', 'conventical'],
    'monasticism': ['albigensianism', 'catharism', 'franciscanism', 'sabbatarianism', 'trappism', 'waldensianism', 'yoga', 'abstinence', 'anchoritic monasticism', 'anchoritism', 'asceticism', 'austerity'],
    'monaural system': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'monde': ['vanity fair', 'beau monde', 'beautiful people', 'best people', 'cafe society', 'carriage trade', 'cream of society', 'drawing room', 'elite', 'fashionable society', 'good society', 'haut monde'],
    'money': ['swiss bank account', 'affluence', 'affluent', 'assets', 'balance', 'bank account', 'banknotes', 'bankroll', 'bills', 'blunt', 'boodle', 'bottom dollar'],
    'money changer': ['realtor', 'bank clerk', 'bank manager', 'bank officer', 'bank president', 'banker', 'banking executive', 'bill broker', 'broker', 'cambist', 'cashier', 'cotton broker'],
    'money hungry': ['a hog for', 'acquisitive', 'all-devouring', 'avaricious', 'avid', 'bottomless', 'coveting', 'covetous', 'devouring', 'esurient', 'gluttonous', 'gobbling'],
    'money mad': ['a hog for', 'acquisitive', 'all-devouring', 'avaricious', 'avid', 'bottomless', 'coveting', 'covetous', 'devouring', 'esurient', 'gluttonous', 'gobbling'],
    'money order': ['cd', 'iou', 'mo', 'acceptance', 'acceptance bill', 'bank acceptance', 'bank check', 'bill', 'bill of draft', 'bill of exchange', 'blank check', 'certificate'],
    'money saving': ['scotch', 'canny', 'careful', 'chary', 'cheeseparing', 'conserving', 'economic', 'economizing', 'forehanded', 'frugal', 'labor-saving', 'parsimonious'],
    'moneybags': ['daddy warbucks', 'affluence', 'assets', 'billionaire', 'bloated plutocrat', 'bottomless purse', 'bulging purse', 'capitalist', 'easy circumstances', 'embarras de richesses', 'fat cat', 'fortune'],
    'moneyed': ['abounding in riches', 'affluent', 'big-rich', 'comfortable', 'disgustingly rich', 'fat', 'flush', 'frightfully rich', 'in funds', 'in the money', 'independent', 'independently rich'],
    'moneylender': ['shylock', 'bank clerk', 'bank manager', 'bank officer', 'bank president', 'banker', 'banking executive', 'bill broker', 'cambist', 'cashier', 'discounter', 'investment banker'],
    'moneymaking': ['accession', 'acquirement', 'acquisition', 'addition', 'advantageous', 'attainment', 'banausic', 'breadwinning', 'businesslike', 'coming by', 'commercial', 'compensating'],
    'monger': ['arab', 'chandler', 'dealer', 'distributor', 'duffer', 'hawk', 'hawker', 'higgler', 'huckster', 'importer', 'jobber', 'marketer'],
    'mongolism': ['christmas disease', 'hartnup disease', 'werdnig-hoffmann disease', 'achromatic vision', 'albinism', 'amentia', 'arrested development', 'backwardness', 'blithering idiocy', 'color blindness', 'cretinism', 'cystic fibrosis'],
    'mongoloid': ['arrested', 'babbling', 'backward', 'blithering', 'burbling', 'crackbrained', 'cracked', 'crazy', 'cretinistic', 'cretinous', 'dithering', 'driveling'],
    'mongrel': ['cape colored', 'eurasian', 'animal', 'bastard', 'beast', 'cattalo', 'citrange', 'cross', 'crossbred', 'crossbreed', 'crossed', 'cur'],
    'moniker': ['appellation', 'appellative', 'binomen', 'binomial name', 'byname', 'byword', 'cognomen', 'cryptonym', 'denomination', 'designation', 'empty title', 'epithet'],
    'monition': ['admonishment', 'admonition', 'advice', 'advising', 'advocacy', 'alarm', 'alerting', 'briefing', 'caution', 'cautioning', 'caveat', 'certiorari'],
    'monitor': ['arrl', 'big brother', 'crt', 'cassandra', 'dutch uncle', 'jeremiah', 'polonius', 'tv man', 'admonisher', 'adviser', 'amateur radio operator', 'announcer'],
    'monitoring': ['custodianship', 'custody', 'eagle eye', 'guard', 'guardedness', 'guardianship', 'interlaced scanning', 'invigilation', 'lookout', 'mixing', 'observance', 'peeled eye'],
    'monitory': ['admonishing', 'admonitory', 'advisory', 'augural', 'cautionary', 'cautioning', 'communicative', 'consultative', 'consultatory', 'counseling', 'critical', 'deterrent'],
    'monk': ['cape polecat', 'abbacomes', 'abbot', 'ape', 'ascetic', 'bar', 'beadsman', 'bear', 'brother', 'caloyer', 'cavy', 'celibataire'],
    'monkey': ['cape polecat', 'chiroptera', 'irish', 'lagomorpha', 'primates', 'rodentia', 'ape', 'ass', 'babe', 'bad temper', 'bantam', 'bar'],
    'monkey with': ['paul-pry', 'busybody', 'butt in', 'fool', 'fool with', 'horn in', 'interfere', 'interlope', 'intermeddle', 'kibitz', 'make', 'meddle'],
    'monkeying': ['coquetry', 'dabbling', 'dalliance', 'dallying', 'fiddling', 'flirtation', 'fooling', 'fooling around', 'idling', 'jerking off', 'kidding around', 'loitering'],
    'mono': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'monochromatic': ['chromatic', 'cold', 'colorific', 'coloring', 'cool', 'dichromatic', 'glowing', 'harmonious', 'many-colored', 'matching', 'medley', 'monochrome'],
    'monochrome': ['maxwell triangle', 'munsell scale', 'acrylic painting', 'chromatic', 'chromatic circle', 'chromatic spectrum', 'chromaticity diagram', 'cold', 'color circle', 'color cycle', 'color index', 'color mixture curve'],
    'monocle': ['polaroid glasses', 'bifocals', 'blinkers', 'cheaters', 'colored glasses', 'contact lens', 'dark glasses', 'divided spectacles', 'eyeglass', 'eyeglasses', 'glasses', 'goggles'],
    'monocratic': ['absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'ascendant', 'autarchic', 'authoritarian', 'authoritative', 'authorized', 'autocratic'],
    'monody': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'accord', 'accordance', 'alba', 'anacreontic', 'attune'],
    'monogamy': ['beena marriage', 'bigamy', 'common-law marriage', 'companionate marriage', 'concubinage', 'deuterogamy', 'left-handed marriage', 'levirate', 'leviration', 'love match', 'marriage of convenience', 'monandry'],
    'monogram': ['id card', 'john hancock', 'alphabetic character', 'autograph', 'badge', 'calligram', 'calling card', 'card', 'character', 'christcross', 'cipher', 'countermark'],
    'monograph': ['article', 'causerie', 'descant', 'discourse', 'discussion', 'disquisition', 'dissertation', 'essay', 'etude', 'examination', 'excursus', 'exposition'],
    'monolith': ['aa', 'abyssal rock', 'arch', 'barrow', 'basalt', 'bedrock', 'block lava', 'boundary stone', 'brash', 'brass', 'breccia', 'bust'],
    'monolithic': ['accordant', 'alike', 'austere', 'automatic', 'balanced', 'bare', 'basic', 'characterless', 'chaste', 'colossal', 'consistent', 'consonant'],
    'monologist': ['hamlet', 'roscius', 'actor', 'actress', 'antagonist', 'bad guy', 'barnstormer', 'character', 'character actor', 'character man', 'character woman', 'child actor'],
    'monologue': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'aside', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger'],
    'monomania': ['absorbed attention', 'absorption', 'application', 'complex', 'compulsion', 'concentration', 'contemplation', 'deep study', 'deep thought', 'engagement', 'engrossment', 'fascination'],
    'monopolist': ['careerist', 'censor', 'egotist', 'fortune hunter', 'hog', 'individualist', 'lone wolf', 'loner', 'narcissist', 'protectionist', 'restrictionist', 'road hog'],
    'monopolize': ['absorb', 'absorb the attention', 'adopt', 'appropriate', 'arrest', 'arrogate', 'assume', 'buy', 'buy back', 'buy in', 'buy into', 'buy off'],
    'monopoly': ['a corner on', 'arrest', 'arrestation', 'bear raid', 'bull raid', 'cartel', 'check', 'consortium', 'constraint', 'control', 'cooling', 'cooling down'],
    'monorail': ['amtrak', 'baggage train', 'branch', 'cable railroad', 'cable railway', 'choo-choo', 'cog railroad', 'cog railway', 'el', 'electric', 'electric railway', 'electric train'],
    'monosyllable': ['antonym', 'articulation', 'expression', 'free form', 'homograph', 'homonym', 'homophone', 'lexeme', 'linguistic form', 'locution', 'logos', 'metonym'],
    'monotheism': ['acosmism', 'allotheism', 'anthropolatry', 'anthropomorphism', 'anthropotheism', 'autotheism', 'cosmotheism', 'deism', 'ditheism', 'dualism', 'dyotheism', 'henotheism'],
    'monotheist': ['allotheist', 'anthropolater', 'anthropotheist', 'autotheist', 'cosmotheist', 'deist', 'ditheist', 'dualist', 'henotheist', 'hylotheist', 'multitheist', 'myriotheist'],
    'monotone': ['af', 'indian file', 'alliterating', 'alliteration', 'alliterative', 'array', 'articulation', 'assonance', 'assonant', 'audio frequency', 'banausic', 'bank'],
    'monotonous': ['alliterating', 'alliterative', 'articulated', 'assonant', 'banal', 'banausic', 'belabored', 'blah', 'boring', 'broken-record', 'catenated', 'ceaseless'],
    'monotonously': ['ad infinitum', 'again and again', 'at a stretch', 'boresomely', 'boringly', 'ceaselessly', 'connectedly', 'constantly', 'continually', 'continuously', 'cumulatively', 'cyclically'],
    'monotony': ['af', 'alliteration', 'assonance', 'audio frequency', 'boredom', 'broken record', 'ceaselessness', 'chime', 'clockwork regularity', 'consecutiveness', 'constancy', 'constant flow'],
    'monsoon': ['air current', 'cat-and-dog weather', 'crosscurrent', 'current', 'current of air', 'dirty weather', 'downdraft', 'draft', 'fall wind', 'flow of air', 'following wind', 'head wind'],
    'monster': ['argus', 'atlantean', 'briareus', 'brobdingnagian', 'cerberus', 'charybdis', 'cyclopean', 'cyclops', 'dracula', 'echidna', 'frankenstein', 'gargantuan'],
    'monstrosity': ['aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'abortion', 'absurdity', 'amorphism', 'anomalism', 'anomalousness', 'anomaly', 'anticness'],
    'monstrous': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'a bit much', 'abandoned', 'abject', 'abominable', 'absurd', 'abysmal'],
    'monstrously': ['abjectly', 'abominably', 'arrantly', 'atrociously', 'basely', 'contemptibly', 'despicably', 'eerily', 'execrably', 'fancifully', 'fantastically', 'flagrantly'],
    'montage': ['telephoto', 'wirephoto', 'abstract', 'abstraction', 'aerial photograph', 'altarpiece', 'black-and-white photograph', 'block print', 'candid photograph', 'cheesecake', 'chronophotograph', 'collage'],
    'month': ['abundant year', 'academic year', 'annum', 'bissextile year', 'calendar month', 'calendar year', 'century', 'common year', 'day', 'decade', 'decennary', 'decennium'],
    'monthly': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'daybook', 'decennial', 'diary'],
    'monument': ['antenna tower', 'arch', 'archives', 'barbican', 'barrow', 'belfry', 'bell tower', 'bench mark', 'bookmark', 'boundary stone', 'brass', 'bust'],
    'monumental': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'olympian', 'abject', 'abysmal', 'aerial', 'airy', 'altitudinous'],
    'moo': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'bray', 'call', 'caterwaul'],
    'mooch': ['bat', 'bat around', 'beg', 'bum', 'bum around', 'cadge', 'count ties', 'divagate', 'do nothing', 'drift', 'flit', 'gad'],
    'moocher': ['beggar', 'bum', 'bummer', 'cadger', 'caller', 'company', 'coupon clippers', 'drone', 'freeloader', 'frequenter', 'gate-crasher', 'guest'],
    'mood': ['aristotelian sorites', 'goclenian sorites', 'action', 'affection', 'air', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'argument', 'atmosphere', 'attitude'],
    'moodiness': ['arbitrariness', 'bouderie', 'caprice', 'capriciousness', 'crankiness', 'crotchetiness', 'dejection', 'desultoriness', 'deviability', 'dumpishness', 'eccentricity', 'erraticism'],
    'moody': ['abrupt', 'adrift', 'afloat', 'alternating', 'amorphous', 'arbitrary', 'beetle-browed', 'black', 'black-browed', 'blue', 'brooding', 'broody'],
    'moolah': ['blunt', 'boodle', 'brass', 'bread', 'bucks', 'cabbage', 'chips', 'dinero', 'dough', 'gelt', 'gilt', 'grease'],
    'moon': ['april showers', 'artemis', 'ashtoreth', 'astarte', 'cynthia', 'diana', 'hecate', 'hekate', 'luna', 'phoebe', 'proteus', 'selene'],
    'moon shaped': ['cynthian', 's-shaped', 'bicorn', 'corniform', 'crescent', 'crescent-shaped', 'crescentic', 'crescentiform', 'crescentlike', 'falcate', 'falciform', 'horn-shaped'],
    'moon struck': ['abnormal', 'bereft of reason', 'brainsick', 'crackbrained', 'cracked', 'crazed', 'crazy', 'daft', 'deluded', 'demented', 'deprived of reason', 'deranged'],
    'mooning': ['walter mitty', 'absence of mind', 'absent', 'absentminded', 'absentmindedness', 'absorbed', 'absorption', 'abstracted', 'abstractedness', 'abstraction', 'bemused', 'bemusement'],
    'moonlight': ['be employed', 'bootleg', 'brew', 'carry on business', 'distill', 'do business', 'follow a trade', 'have a job', 'keep up', 'labor', 'moonbeam', 'moonglow'],
    'moonlighting': ['appointment', 'berth', 'billet', 'employment', 'engagement', 'gig', 'incumbency', 'job', 'office', 'opening', 'place', 'position'],
    'moonlit': ['ablaze', 'aglow', 'alight', 'bathed with light', 'bespangled', 'brightened', 'candlelit', 'enlightened', 'firelit', 'gaslit', 'illuminated', 'in a blaze'],
    'moonshine': ['bs', 'argument', 'argument by analogy', 'argumentum ad baculum', 'argumentum ad captandum', 'argumentum ad hominem', 'bad case', 'balderdash', 'balls', 'baloney', 'bathtub gin', 'begging the question'],
    'moonshiner': ['mafioso', 'barkeep', 'barkeeper', 'barmaid', 'barman', 'bartender', 'black marketeer', 'bootlegger', 'brewer', 'brewmaster', 'dealer', 'distiller'],
    'moor': ['affix', 'agricultural region', 'alight', 'alkali flat', 'alluvial plain', 'anchor', 'annex', 'anthill', 'arable land', 'attach', 'barrow', 'basin'],
    'moored': ['aground', 'anchored', 'caught', 'chained', 'fast', 'fastened', 'fixed', 'grounded', 'held', 'high and dry', 'impacted', 'inextricable'],
    'mooring': ['anchor', 'anchorage', 'anchorage ground', 'basin', 'berth', 'breakwater', 'bulkhead', 'colonization', 'debarkation', 'disembarkation', 'disembarkment', 'dock'],
    'moot': ['abstract', 'academic', 'advance', 'agitate', 'arguable', 'argue', 'argufy', 'armchair', 'at issue', 'bandy words', 'bicker', 'bring before'],
    'moot point': ['bone of contention', 'catechism', 'cross-interrogatory', 'cross-question', 'debating point', 'demand', 'feeler', 'inquiry', 'interrogation', 'interrogative', 'interrogatory', 'issue'],
    'mop': ['baptize', 'bath', 'bathe', 'crop', 'douche', 'fleece', 'flush', 'flush out', 'gargle', 'grimace', 'head', 'head of hair'],
    'mop up': ['baptize', 'bath', 'bathe', 'beat', 'button up', 'cap', 'carry to completion', 'clean up', 'climax', 'clobber', 'close out', 'close up'],
    'mope': ['ache', 'agonize', 'amble', 'bitch', 'bleed', 'brood', 'brood over', 'brooder', 'clock watcher', 'dallier', 'dawdle', 'dawdler'],
    'mopey': ['autistic', 'bad', 'bashful', 'beetle-browed', 'black', 'black-browed', 'blue', 'brooding', 'broody', 'cast down', 'chapfallen', 'close'],
    'moping': ['beetle-browed', 'black', 'black-browed', 'brooding', 'broody', 'chapfallen', 'crestfallen', 'dark', 'dejected', 'dour', 'dumpish', 'frowning'],
    'moral': ['christian', 'adage', 'admonishment', 'admonition', 'alarm', 'ana', 'analects', 'angelic', 'aphorism', 'apophthegm', 'apothegm', 'assignment'],
    'moral climate': ['ten commandments', 'weltanschauung', 'zeitgeist', 'axiology', 'behavioral norm', 'business ethics', 'climate', 'climate of opinion', 'code', 'code of ethics', 'code of morals', 'decalogue'],
    'moral code': ['ten commandments', 'zeitgeist', 'axiology', 'behavioral norm', 'business ethics', 'code', 'code of ethics', 'code of morals', 'decalogue', 'ethic', 'ethical system', 'ethics'],
    'moral support': ['aid', 'backing', 'carriage', 'carrying', 'maintenance', 'psychological support', 'reliance', 'security blanket', 'subsidy', 'subvention', 'support', 'supportive relationship'],
    'moral turpitude': ['abandon', 'abandonment', 'abjection', 'baseness', 'chicanery', 'corruptedness', 'corruption', 'corruptness', 'debasement', 'decadence', 'decadency', 'degeneracy'],
    'morale': ['angelicalness', 'assurance', 'attitude', 'bipartisanship', 'coaction', 'coadjuvancy', 'coadministration', 'coagency', 'cochairmanship', 'codirectorship', 'collaboration', 'collaborativeness'],
    'moralistic': ['admonitory', 'advisory', 'axiological', 'cautionary', 'consultative', 'consultatory', 'didactic', 'directive', 'ethical', 'ethological', 'exhortative', 'exhortatory'],
    'morality': ['grand guignol', 'passion play', 'tom show', 'angelicalness', 'antimasque', 'assignment', 'audience success', 'ballet', 'behavior', 'bomb', 'broadcast drama', 'burlesque show'],
    'moralize': ['annotate', 'censure', 'criticize', 'critique', 'discourse', 'explain', 'exposit', 'expound', 'harangue', 'hold forth', 'lecture', 'moralize upon'],
    'morals': ['ten commandments', 'zeitgeist', 'axiology', 'behavioral norm', 'business ethics', 'code', 'code of ethics', 'code of morals', 'conduct', 'decalogue', 'ethic', 'ethical system'],
    'morass': ['anarchy', 'baygall', 'bind', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'chaos', 'clutch', 'complication', 'confusion'],
    'moratorium': ['afterthought', 'bind', 'block', 'blockage', 'bureaucratic delay', 'cancellation', 'delay', 'delayage', 'delayed reaction', 'detention', 'double take', 'dragging'],
    'morbid': ['agape', 'agog', 'all agog', 'appalling', 'astounding', 'awe-inspiring', 'awesome', 'awful', 'bad', 'blue', 'burning with curiosity', 'cankered'],
    'morbidity': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'cachexia'],
    'morbific': ['bad', 'bad for', 'contaminated', 'foul', 'harmful', 'injurious', 'insalubrious', 'insanitary', 'noisome', 'noxious', 'pathogenic', 'peccant'],
    'morceau': ['article', 'causerie', 'chip', 'crumb', 'descant', 'discourse', 'discussion', 'disquisition', 'dissertation', 'essay', 'etude', 'examination'],
    'mordancy': ['acerbity', 'acidity', 'acidness', 'acidulousness', 'acridity', 'acrimony', 'asperity', 'astringency', 'bite', 'bitingness', 'bitterness', 'causticity'],
    'mordant': ['attic', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'actual cautery', 'asperous'],
    'more': ['a certain number', 'a few', 'above', 'accessory', 'added', 'additional', 'additionally', 'again', 'all included', 'along', 'also', 'altogether'],
    'more or less': ['about', 'all but', 'almost', 'approximately', 'approximatively', 'as good as', 'circa', 'fairly', 'for practical purposes', 'generally', 'generally speaking', 'in round numbers'],
    'more than enough': ['abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bellyful', 'beyond measure', 'bonanza', 'bountifulness', 'bountiousness', 'bumper crop'],
    'moreover': ['above', 'additionally', 'again', 'all included', 'also', 'altogether', 'among other things', 'and all', 'and also', 'and so', 'as well', 'au reste'],
    'mores': ['weltanschauung', 'acculturation', 'amenities', 'bon ton', 'civilities', 'civility', 'civilization', 'climate', 'climate of opinion', 'comity', 'complex', 'conformity'],
    'moribund': ['apathetic', 'bad', 'benumbed', 'blase', 'bored', 'cachectic', 'dead', 'debilitated', 'decadent', 'declining', 'despaired of', 'deteriorating'],
    'morn': ['am', 'ack emma', 'ante meridiem', 'aurora', 'cockcrow', 'dawning', 'daybreak', 'daylight', 'foreday', 'forenoon', 'grey-eyed morn', 'incense-breathing morn'],
    'moron': ['ament', 'born fool', 'clot', 'congenital idiot', 'cretin', 'defective', 'dullard', 'dullhead', 'dumbbell', 'dummkopf', 'dummy', 'golem'],
    'moronic': ['apish', 'arrested', 'asinine', 'babbling', 'backward', 'batty', 'befooled', 'beguiled', 'besotted', 'blithering', 'brainless', 'buffoonish'],
    'morose': ['autistic', 'bashful', 'beetle-browed', 'black', 'black-browed', 'brooding', 'broody', 'brusque', 'chapfallen', 'choleric', 'close', 'crabbed'],
    'morpheme': ['ic analysis', 'accidence', 'affix', 'affixation', 'allomorph', 'bound morpheme', 'conjugation', 'cutting', 'declension', 'derivation', 'difference of form', 'enclitic'],
    'morphine': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'morphological': ['affixal', 'anatomic', 'architectonic', 'architectural', 'constructional', 'derivational', 'descriptive', 'edificial', 'formal', 'glottochronological', 'grammatic', 'graphemic'],
    'morphologist': ['anatomist', 'anatomy', 'angiography', 'angiology', 'anthropotomy', 'geomorphology', 'histologist', 'histology', 'morphology', 'myography', 'myology', 'organography'],
    'morphology': ['ic analysis', 'accidence', 'affix', 'affixation', 'allomorph', 'anatomist', 'anatomy', 'angiography', 'angiology', 'anthropotomy', 'bound morpheme', 'bowwow theory'],
    'morsel': ['ambrosia', 'atom', 'bait', 'bit', 'bite', 'bolus', 'bonne bouche', 'butt', 'cate', 'champ', 'chaw', 'chew'],
    'mortal': ['adamite', 'adamitic', 'abject', 'anthropocentric', 'anthropological', 'awful', 'baneful', 'being', 'bitter', 'bodily', 'body', 'brittle'],
    'mortality': ['adam', 'hominidae', 'homo sapiens', 'banefulness', 'caducity', 'changeableness', 'clay', 'corruptibility', 'deadliness', 'death', 'death rate', 'death toll'],
    'mortar': ['adobe', 'aim at', 'alembic', 'anvil', 'ashlar', 'barrage', 'blast', 'blitz', 'bombard', 'brick', 'bricks and mortar', 'caldron'],
    'mortar and pestle': ['cheese grater', 'comminutor', 'crusher', 'granulator', 'grater', 'grinder', 'kominuter', 'levigator', 'masher', 'mill', 'millstone', 'nutmeg grater'],
    'mortgage': ['adjustment mortgage', 'antichresis', 'blanket mortgage', 'bond', 'bottomry', 'bottomry bond', 'chattel mortgage', 'closed mortgage', 'dead pledge', 'deed of trust', 'deposit', 'dip'],
    'mortgagee': ['shylock', 'banker', 'bill collector', 'collection agent', 'credit man', 'creditor', 'creditress', 'debtee', 'dun', 'dunner', 'godchild', 'goddaughter'],
    'mortification': ['albigensianism', 'catharism', 'day of atonement', 'franciscanism', 'sabbatarianism', 'trappism', 'waldensianism', 'yoga', 'yom kippur', 'abasement', 'abashment', 'abstinence'],
    'mortified': ['abashed', 'afflicted', 'agitated', 'annoyed', 'ascetic', 'ashamed', 'astringent', 'austere', 'bad', 'beset', 'blushing', 'bothered'],
    'mortify': ['abash', 'break up', 'bring down', 'canker', 'cast down', 'castigate', 'chagrin', 'chasten', 'confound', 'confuse', 'control', 'corrupt'],
    'mortise': ['ankle', 'articulate', 'articulation', 'batten', 'batten down', 'bolt', 'boundary', 'buckle', 'butt', 'button', 'cervix', 'clasp'],
    'mortuary': ['blue', 'burning ghat', 'cadaverous', 'charnel house', 'cinerary', 'corpselike', 'crematorium', 'crematory', 'deadhouse', 'deadly', 'deathlike', 'deathly'],
    'mosaic': ['biblical', 'gospel', 'new-testament', 'old-testament', 'apocalyptic', 'apostolic', 'canonical', 'evangelic', 'evangelistic', 'gospel', 'inspired', 'prophetic'],
    'moses': ['abraham', 'amos', 'daniel', 'ezekiel', 'haggai', 'hosea', 'isaac', 'isaiah', 'jacob', 'jeremiah', 'joel', 'jonah'],
    'mosey': ['amble', 'be getting along', 'buzz off', 'claudicate', 'come away', 'crawl', 'creep', 'depart', 'dogtrot', 'drag', 'drag along', 'drag out'],
    'moss': ['algae', 'autophyte', 'baygall', 'bean', 'bog', 'bottom', 'bottomland', 'bottoms', 'bracken', 'brown algae', 'buffalo wallow', 'climber'],
    'mossback': ['methuselah', 'antediluvian', 'antique', 'back number', 'backwoodsman', 'bumpkin', 'clodhopper', 'conservationist', 'conservatist', 'conservative', 'dad', 'diehard'],
    'mossbacked': ['anile', 'crabbed', 'debilitated', 'decrepit', 'doddered', 'doddering', 'doddery', 'feeble', 'fossilized', 'gerontal', 'gerontic', 'infirm'],
    'most': ['a per se', 'a outrance', 'about', 'absolutely', 'ace', 'acme', 'all but', 'all out', 'almost', 'approximately', 'at the height', 'at the limit'],
    'mostly': ['a fortiori', 'above all', 'all in all', 'all the more', 'all things considered', 'almost entirely', 'altogether', 'approximately', 'as a rule', 'as a whole', 'as an approximation', 'as per usual'],
    'mot': ['adage', 'ana', 'analects', 'aphorism', 'apothegm', 'axiom', 'bon mot', 'boutade', 'bright idea', 'bright thought', 'brilliant idea', 'byword'],
    'mote': ['ace', 'acropolis', 'air', 'atom', 'bastion', 'beachhead', 'bit', 'black sheep', 'blemish', 'blockhouse', 'bridgehead', 'bubble'],
    'moth eaten': ['anile', 'archaic', 'back-number', 'banal', 'bewhiskered', 'blasted', 'blighted', 'blown', 'bromidic', 'bygone', 'common', 'commonplace'],
    'mother': ['sob', 'agent', 'ancestorial', 'ancestors', 'ancestral', 'apprentice', 'architect', 'artificer', 'artist', 'attend to', 'aunt', 'auntie'],
    'mother of god': ['dei mater', 'deipara', 'holy mary', 'immaculate conception', 'mariolatry', 'mariology', 'notre dame', 'our lady', 'queen of angels', 'queen of heaven', 'regina angelorum', 'regina coeli'],
    'mother superior': ['abbess', 'canoness', 'chatelaine', 'clergywoman', 'conventual', 'dame', 'dowager', 'first lady', 'goodwife', 'governess', 'great lady', 'homemaker'],
    'motherhood': ['affiliation', 'agnation', 'alliance', 'ancestry', 'blood', 'blood relationship', 'brotherhood', 'brothership', 'cognation', 'common ancestry', 'common descent', 'connection'],
    'mothering': ['tlc', 'bread', 'care', 'daily bread', 'economic support', 'endowment', 'keep', 'livelihood', 'living', 'maintenance', 'manna', 'meat'],
    'motherless': ['abandoned', 'aidless', 'bereaved', 'bereft', 'defenseless', 'deprived', 'deserted', 'desolate', 'fatherless', 'forlorn', 'forsaken', 'friendless'],
    'motif': ['action', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'argument', 'atmosphere', 'background', 'background detail', 'basis', 'beading', 'binding'],
    'motion': ['zeitgeist', 'act', 'action', 'activeness', 'activism', 'activity', 'agitation', 'bearing', 'beck', 'beckon', 'bill', 'body language'],
    'motion picture': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'black-and-white film', 'boom shot', 'cartoon', 'chiller', 'cine', 'cinema', 'close-up'],
    'motion sickness': ['minamata disease', 'airsickness', 'altitude sickness', 'anoxemia', 'anoxia', 'anoxic anoxia', 'anthrax', 'black lung', 'caisson disease', 'car sickness', 'chilblain', 'decompression sickness'],
    'motionless': ['at a standstill', 'at anchor', 'contemplative', 'dead-still', 'do-nothing', 'dormant', 'fixed', 'idle', 'immobile', 'immotile', 'immotive', 'immovable'],
    'motivate': ['activate', 'actuate', 'animate', 'arouse', 'bring', 'bring about', 'bring on', 'cajole', 'call forth', 'cause', 'coax', 'compel'],
    'motivated': ['actuated', 'animated', 'apt', 'bright', 'clever', 'docile', 'educable', 'facile', 'formable', 'impelled', 'impressionable', 'inclined'],
    'motivation': ['activity', 'actuation', 'animation', 'aptitude', 'aptness', 'brightness', 'catalyst', 'cleverness', 'direction', 'docility', 'dynamics', 'educability'],
    'motivational': ['active', 'actuating', 'animating', 'causal', 'causative', 'compelling', 'directive', 'driving', 'impelling', 'impulsive', 'in motion', 'inducive'],
    'motive': ['activating', 'active', 'actuating', 'aim', 'ambition', 'angle', 'animating', 'animus', 'antecedent', 'argument', 'aspiration', 'attraction'],
    'motive power': ['activator', 'animator', 'appliance', 'arouser', 'bunt', 'butt', 'clout', 'compulsion', 'convenience', 'drive', 'driving force', 'energizer'],
    'motley': ['columbine', 'hanswurst', 'harlequin', 'pantalone', 'pantaloon', 'polichinelle', 'pulcinella', 'punch', 'punchinello', 'scaramouch', 'amalgamated', 'ambiguous'],
    'motor': ['active', 'aeromotor', 'alembic', 'anvil', 'appliance', 'arc-jet engine', 'auto', 'autocar', 'automobile', 'axial-flow turbojet', 'bicycle', 'bike'],
    'motor oil': ['avgas', 'crude', 'crude oil', 'ethyl', 'ethyl gas', 'fossil oil', 'gas', 'gasoline', 'high-octane gas', 'high-test', 'kerosene', 'lead-free gas'],
    'motor vehicle': ['auto', 'autocar', 'automobile', 'boat', 'buggy', 'bus', 'car', 'crate', 'heap', 'jalopy', 'machine', 'motor'],
    'motorboat': ['boat', 'cabin cruiser', 'canoe', 'carry sail', 'circumnavigate', 'coast', 'cross', 'cruise', 'cruiser', 'go by ship', 'go on shipboard', 'go to sea'],
    'motorcade': ['caravan', 'cavalcade', 'column', 'cortege', 'dress parade', 'flyover', 'funeral', 'line', 'march past', 'mule train', 'pack train', 'parade'],
    'motorcar': ['auto', 'autocar', 'automobile', 'boat', 'buggy', 'bus', 'car', 'crate', 'heap', 'jalopy', 'machine', 'motor'],
    'motorcycle': ['bicycle', 'bike', 'bus', 'catch a train', 'chauffeur', 'chopper', 'cycle', 'drive', 'entrain', 'go by rail', 'iron', 'joyride'],
    'motorist': ['sunday driver', 'backseat driver', 'bus driver', 'busman', 'cabby', 'cabdriver', 'chauffeur', 'driver', 'hack', 'hackdriver', 'hackman', 'hacky'],
    'mottle': ['band', 'bar', 'bespangle', 'bespeckle', 'bespot', 'birthmark', 'blaze', 'blaze a trail', 'blemish', 'blotch', 'brand', 'caste mark'],
    'mottled': ['blotched', 'blotchy', 'brindled', 'calico', 'clouded', 'dapple', 'dappled', 'flecked', 'freckled', 'marbled', 'motley', 'multicolored'],
    'motto': ['achievement', 'adage', 'alerion', 'ana', 'analects', 'animal charge', 'annulet', 'aphorism', 'apophthegm', 'apothegm', 'argent', 'armorial bearings'],
    'mould': ['ectocarpales', 'phaeophyceae', 'platonic form', 'platonic idea', 'accommodate', 'accommodate with', 'accord', 'acres', 'adapt', 'adapt to', 'adenovirus', 'adjust'],
    'moulder': ['ectocarpales', 'phaeophyceae', 'platonic form', 'platonic idea', 'accommodate', 'accommodate with', 'accord', 'acres', 'adapt', 'adapt to', 'adenovirus', 'adjust'],
    'mouldy': ['ectocarpales', 'phaeophyceae', 'platonic form', 'platonic idea', 'accommodate', 'accommodate with', 'accord', 'acres', 'adapt', 'adapt to', 'adenovirus', 'adjust'],
    'mound': ['abatis', 'advanced work', 'anthill', 'arch', 'arch dam', 'backstop', 'balistraria', 'bamboo curtain', 'bank', 'bank up', 'banquette', 'bar'],
    'mount': ['everest', 'houyhnhnm', 'olympus', 'accrue', 'accumulate', 'advance', 'aggravate', 'alp', 'amble', 'anabasis', 'appreciate', 'arise'],
    'mount up to': ['add up to', 'afford', 'aggregate', 'aggregate to', 'amount to', 'bring', 'bring in', 'come to', 'come up to', 'comprise', 'contain', 'cost'],
    'mountain': ['everest', 'olympus', 'abundance', 'accumulation', 'acres', 'alp', 'bags', 'bald', 'bank', 'bar', 'barrel', 'barrels'],
    'mountain lion': ['leo', 'siberian tiger', 'bobcat', 'cat-a-mountain', 'catamount', 'cheetah', 'cougar', 'jaguar', 'leopard', 'lion', 'lynx', 'ocelot'],
    'mountain man': ['backwoodsman', 'briar-hopper', 'brush ape', 'bushman', 'clam digger', 'cracker', 'desert rat', 'forester', 'frontiersman', 'hillbilly', 'hinterlander', 'mountaineer'],
    'mountaineer': ['adventurer', 'alpinist', 'ascender', 'astronaut', 'backwoodsman', 'briar-hopper', 'brush ape', 'bumpkin', 'bushman', 'camper', 'clam digger', 'climber'],
    'mountainous': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'alpen', 'alpestrine', 'alpigene', 'alpine', 'amplitudinous'],
    'mountaintop': ['acme', 'apex', 'apogee', 'brow', 'cap', 'climax', 'cloud nine', 'crest', 'crown', 'culmen', 'culmination', 'edge'],
    'mountebank': ['artist', 'artiste', 'belly dancer', 'blagueur', 'bluff', 'bluffer', 'burlesque queen', 'charlatan', 'cheat', 'chorine', 'chorus boy', 'chorus girl'],
    'mounted policeman': ['g-man', 'mp', 'bailiff', 'beadle', 'beagle', 'bound bailiff', 'broncobuster', 'buckaroo', 'caballero', 'captain', 'catchpole', 'cavalier'],
    'mounties': ['cheka', 'fbi', 'gestapo', 'interpol', 'mp', 'mvd', 'nkvd', 'ogpu', 'rcmp', 'sp', 'scotland yard', 'constabulary'],
    'mounting': ['brownian movement', 'olympian', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'aerial', 'aggrandizement'],
    'mourn': ['ache', 'agonize', 'bemoan', 'bewail', 'bleed', 'brood over', 'deplore', 'dirge', 'discomfort', 'dismay', 'distress', 'elegize'],
    'mournful': ['jeremianic', 'affecting', 'afflicted', 'afflictive', 'aggrieved', 'anguished', 'bitter', 'bleak', 'blue', 'calamitous', 'careworn', 'catastrophic'],
    'mournfulness': ['aggrievedness', 'bitterness', 'bleakness', 'cheerlessness', 'comfortlessness', 'depression', 'discomfort', 'dismalness', 'distress', 'distressfulness', 'dolorousness', 'dreariness'],
    'mourning': ['anguish', 'bemoaning', 'bereavement', 'bewailing', 'black', 'crape', 'cypress', 'cypress lawn', 'deep mourning', 'desolation', 'despair', 'despondency'],
    'mouse': ['milquetoast', 'baby', 'bantam', 'banty', 'big baby', 'black eye', 'black-and-blue mark', 'bruise', 'busybody', 'button', 'chick', 'chicken'],
    'mouse colored': ['quaker-colored', 'acier', 'ashen', 'ashy', 'canescent', 'cinereous', 'cinerous', 'dapple', 'dapple-gray', 'dappled', 'dappled-gray', 'dingy'],
    'mouser': ['cheshire cat', 'chinchilla cat', 'maltese cat', 'alley cat', 'blue cat', 'calico cat', 'cat', 'feline', 'gib', 'gib-cat', 'grimalkin', 'house cat'],
    'mousetrap': ['dionaea', 'mark', 'baited trap', 'bazooka', 'booby trap', 'calliope', 'deadfall', 'deathtrap', 'decoy', 'firetrap', 'flytrap', 'gin'],
    'mousse': ['charlotte', 'jell-o', 'blancmange', 'breakers', 'candy', 'carrot pudding', 'chocolate mousse', 'collar', 'comfit', 'compote', 'confection', 'confectionery'],
    'mousy': ['quaker-colored', 'acier', 'afraid', 'ashen', 'ashy', 'bashful', 'brown', 'brownish', 'canescent', 'chicken', 'chickenhearted', 'cinereous'],
    'mouth': ['brillat-savarin', 'lucullus', 'access', 'announce', 'aperture', 'arm', 'armlet', 'articulate', 'audacity', 'back talk', 'backchat', 'bay'],
    'mouth watering': ['acceptable', 'adorable', 'agreeable', 'alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating'],
    'mouthful': ['bellyful', 'bit', 'bite', 'bolus', 'bumper', 'capacity', 'champ', 'charge', 'chaw', 'chew', 'chomp', 'chunk'],
    'mouthing': ['pecksniffery', 'tartuffery', 'tartuffism', 'cant', 'drone', 'droning', 'empty gesture', 'face', 'false piety', 'gabble', 'gibber', 'gibbering'],
    'mouthpiece': ['ag', 'da', 'kc', 'qc', 'ssc', 'us attorney', 'adviser', 'advocate', 'aerophone', 'agent', 'amicus curiae', 'announcer'],
    'mouthwash': ['abstergent', 'cathartic', 'cleaner', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing cream', 'cold cream', 'cream', 'dentifrice', 'depurant', 'detergent'],
    'mouthy': ['bombastic', 'declamatory', 'euphuistic', 'flatulent', 'florid', 'flowery', 'fustian', 'gabby', 'garrulous', 'gassy', 'high-flown', 'inflated'],
    'movable': ['able to adapt', 'accessible', 'adaptable', 'adjustable', 'alterable', 'alterative', 'amenable', 'assignable', 'changeable', 'changeful', 'checkered', 'communicable'],
    'movables': ['accessories', 'appanages', 'appendages', 'appointments', 'appurtenances', 'belongings', 'chattels', 'choses', 'choses in action', 'choses in possession', 'choses local', 'choses transitory'],
    'move': ['accomplished fact', 'accomplishment', 'achievement', 'acquit', 'act', 'acta', 'action', 'activate', 'activity', 'actuate', 'actuation', 'ad hoc measure'],
    'move away': ['be getting along', 'buzz off', 'come away', 'decline', 'depart', 'die away', 'diminish', 'drift away', 'dwindle', 'ebb', 'exit', 'fade'],
    'move into': ['accept', 'assume', 'attack', 'attempt', 'buckle to', 'embark in', 'embark upon', 'endeavor', 'engage in', 'enter on', 'enter upon', 'fall into'],
    'move out': ['be getting along', 'buzz off', 'come away', 'depart', 'exit', 'gang along', 'get along', 'get away', 'get off', 'get on', 'get under way', 'go'],
    'moved': ['actuated', 'affected', 'agog', 'agonized', 'animated', 'aquiver', 'aroused', 'atingle', 'atwitter', 'bursting', 'carried away', 'devoured by'],
    'movement': ['alexandrine', 'american', 'art nouveau', 'ashcan school', 'bm', 'barbizon', 'bauhaus', 'bolognese', 'british', 'cobra', 'dutch', 'flemish'],
    'movements': ['act', 'acting', 'action', 'actions', 'activism', 'activity', 'acts', 'address', 'affectation', 'air', 'bearing', 'behavior'],
    'mover': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'abettor', 'actor', 'actuator'],
    'movie': ['cinemascope', 'cinerama', 'technicolor', 'western', 'actor-proof', 'all-star', 'animated cartoon', 'ballet', 'balletic', 'black-and-white film', 'cartoon', 'chiller'],
    'moving': ['active', 'activity', 'actuating', 'actuation', 'advancing', 'affecting', 'affective', 'afflictive', 'agitating', 'ambulant', 'ambulative', 'ambulatory'],
    'moving picture': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'black-and-white film', 'cartoon', 'chiller', 'cine', 'cinema', 'color film', 'creepie'],
    'moving spirit': ['abettor', 'actuator', 'afflatus', 'animating spirit', 'animation', 'animator', 'animus', 'cajoler', 'coax', 'coaxer', 'divine afflatus', 'encourager'],
    'mow': ['abbreviate', 'abridge', 'abstract', 'anthill', 'bank', 'bob', 'boil down', 'bring in', 'capsulize', 'clip', 'cock', 'compress'],
    'mow down': ['beat down', 'blow down', 'blow over', 'bowl down', 'bowl over', 'break down', 'bring down', 'bulldog', 'bulldoze', 'burn down', 'cast down', 'chop down'],
    'mowed': ['abbreviated', 'abridged', 'abstracted', 'bobbed', 'capsule', 'capsulized', 'clipped', 'compressed', 'condensed', 'cropped', 'curtailed', 'cut short'],
    'moxie': ['amperage', 'animation', 'armipotence', 'authority', 'backbone', 'beef', 'birr', 'black power', 'bottom', 'breeziness', 'briskness', 'brute force'],
    'mp': ['cheka', 'fbi', 'g-man', 'gestapo', 'interpol', 'mvd', 'member of congress', 'member of parliament', 'mounties', 'nkvd', 'ogpu', 'rcmp'],
    'ms': ['amyotrophic lateral sclerosis', 'article', 'autograph', 'brain disease', 'brainchild', 'cephalalgia', 'cerebral palsy', 'chorea', 'composition', 'computer printout', 'copy', 'document'],
    'much': ['a deal', 'a great deal', 'a lot', 'abounding', 'abundance', 'abundant', 'abundantly', 'acres', 'affluence', 'affluent', 'again and again', 'all-sufficing'],
    'mucilage': ['adherent', 'adhesive', 'albumen', 'antifriction', 'barnacle', 'batter', 'black lead', 'bonnyclabber', 'bramble', 'brier', 'bulldog', 'burr'],
    'mucilaginous': ['adhesive', 'amylaceous', 'clabbered', 'clammy', 'clotted', 'coagulated', 'curdled', 'doughy', 'gaumy', 'gelatinous', 'glairy', 'gluelike'],
    'muck': ['amble', 'ammonia', 'begrime', 'bemire', 'bemud', 'besmoke', 'bilge', 'bitch up', 'blow', 'blunder', 'bobble', 'bollix'],
    'muck up': ['ball up', 'begrime', 'bemire', 'bemud', 'besmoke', 'bloomer', 'blooper', 'blow', 'bobble', 'bollix', 'bollix up', 'bonehead play'],
    'mucked up': ['byzantine', 'anarchic', 'arsy-varsy', 'ass-backwards', 'balled up', 'bollixed up', 'buggered', 'buggered up', 'chaotic', 'complex', 'complicated', 'confounded'],
    'mucker': ['bitch up', 'blighter', 'blow', 'blunder', 'bobble', 'bollix', 'bullyboy', 'bungle', 'churl', 'clodhopper', 'clown', 'gum up'],
    'muckraker': ['thersites', 'annotator', 'backbiter', 'belittler', 'calumniator', 'captious critic', 'carper', 'caustic critic', 'caviler', 'censor', 'censurer', 'cognoscente'],
    'muckraking': ['attack', 'blackening', 'character assassination', 'defamation', 'defamation of character', 'defilement', 'denigration', 'dirty politics', 'last-minute lie', 'malicious defamation', 'mudslinging', 'mudslinging campaign'],
    'mucky': ['barfy', 'begrime', 'besoil', 'black', 'cloudy', 'crappy', 'dirty', 'disgusting', 'dungy', 'fecal', 'feculent', 'fetid'],
    'mucus': ['albumen', 'antifriction', 'autacoid', 'batter', 'bile', 'black lead', 'bonnyclabber', 'butter', 'carrion', 'chalone', 'chyle', 'clabber'],
    'mud': ['baygall', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'clay', 'dirt', 'dust', 'everglade', 'fen', 'fenland'],
    'mud flat': ['baygall', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'everglade', 'fen', 'fenland', 'glade', 'hog wallow', 'holm'],
    'muddle': ['addle', 'addle the wits', 'amaze', 'anarchy', 'ataxia', 'baffle', 'ball up', 'bamboozle', 'be all thumbs', 'beat', 'becloud', 'bedazzle'],
    'muddle through': ['clear', 'clear the hurdle', 'come along', 'come on', 'contrive', 'crowd', 'cut the mustard', 'do', 'drive on', 'engineer', 'fare', 'forge ahead'],
    'muddled': ['addlebrained', 'addled', 'addleheaded', 'addlepated', 'anarchic', 'arsy-varsy', 'ass-backwards', 'at a loss', 'baffled', 'balled up', 'bamboozled', 'beat'],
    'muddlehead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead'],
    'muddleheaded': ['addlebrained', 'addled', 'addleheaded', 'addlepated', 'beclouded', 'befuddled', 'blear-witted', 'cloudy', 'dizzy', 'fogged', 'foggy', 'fuddlebrained'],
    'muddy': ['achromatic', 'achromic', 'addled', 'amorphous', 'anemic', 'ashen', 'ashy', 'becloud', 'bedraggled', 'befog', 'befouled', 'begrime'],
    'mudlark': ['arab', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'dogie', 'gamin', 'gamine', 'guttersnipe', 'hobo'],
    'mudpack': ['base', 'clown white', 'cold cream', 'compact', 'cosmetics', 'drugstore complexion', 'eye shadow', 'eyebrow pencil', 'foundation', 'foundation cream', 'greasepaint', 'hand cream'],
    'mudslinger': ['thersites', 'backbiter', 'belittler', 'calumniator', 'caustic critic', 'cynic', 'debunker', 'decrier', 'defamer', 'deflater', 'depreciator', 'derogator'],
    'mudslinging': ['attack', 'blackening', 'character assassination', 'defamation', 'defamation of character', 'defilement', 'denigration', 'dirty politics', 'last-minute lie', 'malicious defamation', 'muckraking', 'mudslinging campaign'],
    'muff': ['bad job', 'be all thumbs', 'bevue', 'blow', 'blunder', 'blunder away', 'blunder into', 'blunder on', 'blunder upon', 'bobble', 'boggle', 'bollix'],
    'muffed': ['botched', 'bungled', 'butchered', 'fumbled', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-done', 'ill-executed', 'ill-managed', 'impolitic'],
    'muffin': ['danish', 'danish pastry', 'english muffin', 'parker house roll', 'yorkshire pudding', 'bagel', 'bialy', 'bialystoker', 'bun', 'clover-leaf roll', 'coffee cake', 'crescent roll'],
    'muffle': ['acoustic tile', 'antiknock', 'antlia', 'apply to', 'baffle', 'baffler', 'beak', 'beezer', 'bill', 'black out', 'blanket', 'block'],
    'muffle up': ['apparel', 'array', 'attire', 'bedeck', 'bedrape', 'bundle up', 'clothe', 'deck', 'dight', 'drape', 'dress', 'dud'],
    'muffled': ['armored', 'bated', 'between the lines', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'coped', 'covered', 'covert', 'cowled'],
    'muffler': ['pcv valve', 'roman collar', 'accelerator', 'acoustic tile', 'alternator', 'ammeter', 'antiknock', 'baffler', 'band', 'bandanna', 'bearings', 'bertha'],
    'mug': ['photostat', 'telephoto', 'wirephoto', 'x-ray', 'xerox', 'aerial photograph', 'ambush', 'assail', 'assault', 'attack', 'babe', 'barbarize'],
    'mug shot': ['telephoto', 'wirephoto', 'aerial photograph', 'black-and-white photograph', 'candid photograph', 'cheesecake', 'chronophotograph', 'color photograph', 'color print', 'diapositive', 'heliochrome', 'heliograph'],
    'mugger': ['mafioso', 'young turk', 'aggressor', 'assailant', 'assailer', 'assaulter', 'attacker', 'bank robber', 'beast', 'beldam', 'berserk', 'berserker'],
    'mugging': ['aggravated assault', 'aggression', 'amphibious attack', 'armed assault', 'armed robbery', 'asportation', 'assailing', 'assailment', 'assault', 'assault and robbery', 'attack', 'banditry'],
    'muggy': ['boggy', 'clammy', 'close', 'damp', 'dampish', 'dank', 'dewy', 'fenny', 'humid', 'marshy', 'moist', 'mucky'],
    'mugwump': ['fabian policy', 'micawberism', 'milquetoast', 'anythingarian', 'apostate', 'backslider', 'backwardness', 'big boy', 'big chief', 'big shot', 'bigwig', 'bolter'],
    'mugwumpery': ['abstention', 'ambitendency', 'ambivalence', 'anythingarianism', 'capriciousness', 'change of mind', 'changeableness', 'cop-out', 'double-mindedness', 'dubiety', 'dubiousness', 'evasion'],
    'mulatto': ['cape colored', 'eurasian', 'cattalo', 'citrange', 'cross', 'crossbreed', 'griffe', 'half blood', 'half-bred', 'half-breed', 'half-caste', 'high yellow'],
    'mulch': ['backset', 'cultivate', 'culture', 'cut', 'delve', 'dig', 'dress', 'fallow', 'fertilize', 'force', 'harrow', 'hoe'],
    'mulct': ['amerce', 'amercement', 'beat', 'beguile of', 'bilk', 'bleed', 'bunco', 'burn', 'cheat', 'chisel', 'chouse', 'chouse out of'],
    'mule': ['cape colored', 'eurasian', 'siberian husky', 'ass', 'bastard', 'beast of burden', 'bigot', 'bitter-ender', 'bullethead', 'camel', 'cattalo', 'citrange'],
    'mulish': ['asinine', 'balking', 'balky', 'bigoted', 'bovid', 'bovine', 'bulldogged', 'bulletheaded', 'bullheaded', 'caprid', 'caprine', 'case-hardened'],
    'mull': ['addle', 'ball up', 'befuddle', 'benumb', 'bewilder', 'blunt', 'botch', 'botchery', 'candy', 'chafe', 'chew over', 'con'],
    'mull over': ['brood over', 'chaw', 'chew over', 'con over', 'deliberate', 'deliberate over', 'deliberate upon', 'digest', 'meditate', 'meditate upon', 'muse', 'muse on'],
    'mullion': ['samson post', 'baluster', 'balustrade', 'banister', 'doorjamb', 'doorpost', 'gatepost', 'hitching post', 'jamb', 'king post', 'milepost', 'post'],
    'multicolored': ['bicolor', 'bicolored', 'colorful', 'colory', 'crazy', 'daedal', 'dappled', 'dichromatic', 'discolor', 'divers-colored', 'harlequin', 'kaleidoscopic'],
    'multifaceted': ['amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'blended', 'combined', 'complex', 'composite', 'compound', 'compounded', 'conglomerate', 'dappled'],
    'multifarious': ['byzantine', 'allotropic', 'assorted', 'at odds', 'at variance', 'balled up', 'billion', 'complex', 'complicated', 'confounded', 'confused', 'conglomerate'],
    'multifold': ['allotropic', 'billion', 'considerable', 'diverse', 'diversiform', 'ever so many', 'full many', 'heaped-up', 'heteromorphic', 'heteromorphous', 'increased', 'jillion'],
    'multilateral': ['bifacial', 'bilateral', 'dihedral', 'flanked', 'handed', 'lateral', 'many-sided', 'multiangular', 'one-sided', 'polygonal', 'polyhedral', 'prismatic'],
    'multimillionaire': ['daddy warbucks', 'billionaire', 'bloated plutocrat', 'capitalist', 'fat cat', 'man of means', 'man of substance', 'man of wealth', 'millionaire', 'moneybags', 'moneyed man', 'nabob'],
    'multinational': ['amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'blended', 'combined', 'complex', 'composite', 'compound', 'compounded', 'conglomerate', 'dappled'],
    'multiple': ['allotropic', 'billion', 'considerable', 'diversiform', 'ever so many', 'full many', 'heaped-up', 'heteromorphic', 'heteromorphous', 'increase', 'increased', 'jillion'],
    'multiple sclerosis': ['ms', 'amyotrophic lateral sclerosis', 'brain disease', 'cephalalgia', 'cerebral palsy', 'chorea', 'emotional disorder', 'epilepsy', 'falling sickness', 'glossopharyngeal neuralgia', 'headache', 'herpes zoster'],
    'multiplication': ['access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'aggrandizement', 'amplification', 'appreciation', 'approximation'],
    'multiplicity': ['proteus', 'abundance', 'allotropism', 'allotropy', 'barrel', 'countlessness', 'diversification', 'diversity', 'great deal', 'her infinite variety', 'heterogeneity', 'heteromorphism'],
    'multiplied': ['accelerated', 'aggrandized', 'amplified', 'augmented', 'beefed-up', 'bloated', 'boosted', 'broadened', 'deepened', 'elevated', 'enhanced', 'enlarged'],
    'multiply': ['abound with', 'accrue', 'accumulate', 'add', 'advance', 'aggrandize', 'algebraize', 'appreciate', 'army', 'augment', 'balloon', 'be alive with'],
    'multiplying': ['crescendoing', 'crescent', 'expanding', 'growing', 'increase', 'increasing', 'incremental', 'intensifying', 'lengthening', 'multiple', 'multiplication', 'multiplication table'],
    'multiracial': ['amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'blended', 'combined', 'complex', 'composite', 'compound', 'compounded', 'conglomerate', 'dappled'],
    'multitude': ['a mass of', 'a world of', 'abundance', 'acres', 'army', 'bags', 'barrels', 'bevy', 'bunch', 'bushel', 'cloud', 'cluster'],
    'multitudinous': ['abundant', 'ample', 'billion', 'considerable', 'copious', 'countless', 'ever so many', 'full many', 'generous', 'heaped-up', 'innumerable', 'jillion'],
    'mum': ['anaudic', 'aphasic', 'aphonic', 'breathless', 'brief', 'brusque', 'close', 'close-tongued', 'closemouthed', 'concise', 'curt', 'dumb'],
    'mumble': ['aspirate', 'aspiration', 'bark', 'bated breath', 'bawl', 'bellow', 'bite', 'blare', 'blat', 'blubber', 'boom', 'bray'],
    'mumbling': ['aspiration', 'bated breath', 'breath', 'breathy voice', 'drone', 'droning', 'exhalation', 'gabble', 'gibber', 'gibbering', 'jabber', 'jibber'],
    'mumbo jumbo': ['abracadabra', 'absurdity', 'amorphousness', 'amphigory', 'amulet', 'anagoge', 'anagogics', 'anthroposophy', 'argot', 'babble', 'babblement', 'balderdash'],
    'mumbo-jumbo': ['abracadabra', 'bilge', 'blather', 'blether', 'bosh', 'bull', 'bullshit', 'bunkum', 'chant', 'charm', 'claptrap', 'conjuration'],
    'mummer': ['roscius', 'actor', 'actress', 'antagonist', 'artist', 'artiste', 'bad guy', 'barnstormer', 'belly dancer', 'burlesque queen', 'character', 'character actor'],
    'mummery': ['pecksniffery', 'tartuffery', 'tartuffism', 'abracadabra', 'acting', 'affectation', 'baccalaureate service', 'buffoonery', 'business', 'camouflage', 'cant', 'celebration'],
    'mummification': ['air-drying', 'anhydration', 'ashes', 'blast-freezing', 'body', 'bones', 'bottling', 'brining', 'cadaver', 'canning', 'carcass', 'carrion'],
    'mummified': ['adust', 'baked', 'burnt', 'corky', 'dehydrated', 'desiccated', 'dried', 'dried-up', 'evaporated', 'exsiccated', 'parched', 'scorched'],
    'mummify': ['air-dry', 'anhydrate', 'bake', 'blast-freeze', 'blot', 'brine', 'brush', 'burn', 'corn', 'cure', 'dehumidify', 'dehydrate'],
    'mummy': ['ashes', 'biscuit', 'body', 'bone', 'bones', 'cadaver', 'carcass', 'carrion', 'clay', 'corpse', 'corpus delicti', 'cracker'],
    'mumps': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'munch': ['bite', 'bolus', 'champ', 'chaw', 'chew', 'chew the cud', 'chew up', 'chomp', 'chump', 'crunch', 'cud', 'gnash'],
    'munching': ['appetite', 'cannibalism', 'carnivorism', 'carnivority', 'carnivorousness', 'chewing', 'consumption', 'cropping', 'deglutition', 'devouring', 'devourment', 'dieting'],
    'mundane': ['philistine', 'animal', 'arid', 'banausic', 'barren', 'carnal', 'carnal-minded', 'common', 'commonplace', 'dry', 'dull', 'earthbound'],
    'municipal': ['borough', 'burghal', 'citified', 'city', 'civic', 'civil', 'council', 'downtown', 'home', 'inland', 'internal', 'interurban'],
    'municipality': ['stadt', 'bailiwick', 'banlieue', 'boom town', 'borough', 'bourg', 'bureau', 'burg', 'burgh', 'city', 'commissariat', 'constablery'],
    'munificence': ['bigheartedness', 'bounteousness', 'bountifulness', 'bounty', 'easy purse strings', 'free hand', 'freedom', 'freehandedness', 'freeheartedness', 'freeness', 'generosity', 'generousness'],
    'munificent': ['bighearted', 'bounteous', 'bountiful', 'free', 'freehanded', 'freehearted', 'generous', 'giving', 'gracious', 'greathearted', 'handsome', 'hospitable'],
    'munition': ['accouter', 'appoint', 'arm', 'dress', 'equip', 'fit', 'fit out', 'fit up', 'furnish', 'gear', 'heel', 'man'],
    'munitions': ['a-weapons', 'abundance', 'accouterments', 'accumulation', 'amassment', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'arms', 'backlog'],
    'mural': ['abstract', 'abstraction', 'altarpiece', 'block print', 'collage', 'color print', 'copy', 'cyclorama', 'daub', 'diptych', 'engraving', 'fresco'],
    'murder': ['abate', 'abolish', 'annihilate', 'asphyxiate', 'assassinate', 'assassination', 'be all thumbs', 'behead', 'blood', 'bloodshed', 'bloody murder', 'blot out'],
    'murdered': ['botched', 'bungled', 'butchered', 'fumbled', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-done', 'ill-executed', 'ill-managed', 'impolitic'],
    'murderer': ['cain', 'apache', 'assassin', 'assassinator', 'bloodletter', 'bloodshedder', 'bravo', 'burker', 'butcher', 'button man', 'cannibal', 'cutthroat'],
    'murderous': ['draconian', 'tartarean', 'animal', 'anthropophagous', 'arduous', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bestial', 'bloodthirsty', 'bloody'],
    'murk': ['amorphousness', 'bad light', 'becloud', 'bedarken', 'bedim', 'begloom', 'begrime', 'besmirch', 'besoil', 'black', 'black out', 'blacken'],
    'murky': ['ambiguous', 'amorphous', 'amphibological', 'besmirched', 'black', 'blackened', 'bleak', 'blind', 'blotchy', 'caliginous', 'clear as mud', 'clouded'],
    'murmur': ['air a grievance', 'aspirate', 'aspiration', 'bark', 'bated breath', 'bawl', 'beef', 'bellow', 'bellyache', 'bitch', 'blare', 'blat'],
    'murmured': ['barely audible', 'decrescendo', 'dim', 'distant', 'faint', 'faint-voiced', 'feeble', 'gentle', 'half-heard', 'indistinct', 'low', 'pianissimo'],
    'murmurer': ['bellyacher', 'complainant', 'complainer', 'crab', 'crank', 'croaker', 'faultfinder', 'frondeur', 'griper', 'grouch', 'grouser', 'growler'],
    'murmuring': ['aspiration', 'bated breath', 'beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'breath', 'breathy voice', 'complaining', 'complaint'],
    'muscle': ['adductor', 'arm', 'beef', 'beefiness', 'biceps', 'brawn', 'brawniness', 'buccinator', 'effort', 'elasticity', 'elbow grease', 'endeavor'],
    'muscle bound': ['able-bodied', 'athletic', 'brawny', 'broad-shouldered', 'burly', 'dour', 'firm', 'fundamentalist', 'hard', 'hidebound', 'impliable', 'inexorable'],
    'muscle man': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'goliath', 'hercules', 'polyphemus', 'samson', 'superman', 'tarzan'],
    'muscular': ['herculean', 'able-bodied', 'athletic', 'beefy', 'brawny', 'broad-shouldered', 'burly', 'elastic', 'fibrous', 'flexible', 'husky', 'mighty'],
    'muscularity': ['beef', 'beefiness', 'brawn', 'brawniness', 'elasticity', 'heftiness', 'huskiness', 'involuntary muscle', 'muscle', 'musculature', 'physique', 'sinew'],
    'musculature': ['beef', 'beefiness', 'brawn', 'brawniness', 'elasticity', 'heftiness', 'huskiness', 'involuntary muscle', 'muscle', 'muscularity', 'physique', 'sinew'],
    'muse': ['calliope', 'clio', 'erato', 'euterpe', 'melpomene', 'parnassian', 'polyhymnia', 'terpsichore', 'thalia', 'walter mitty', 'absence of mind', 'absentmindedness'],
    'museum': ['british museum', 'festschrift', 'guggenheim museum', 'hermitage', 'indian reservation', 'louvre', 'metropolitan museum', 'national gallery', 'prado', 'rijksmuseum', 'tate gallery', 'uffizi'],
    'museum piece': ['abnormality', 'anomaly', 'art object', 'brainchild', 'bric-a-brac', 'classic', 'composition', 'conversation piece', 'creation', 'curio', 'curiosity', 'design'],
    'mush': ['airing', 'amble', 'bathos', 'bazoo', 'bleeding heart', 'breakfast food', 'butter', 'cataplasm', 'cereal', 'chaps', 'chops', 'cloyingness'],
    'mushiness': ['bathos', 'bleeding heart', 'cloyingness', 'doughiness', 'flabbiness', 'fleshiness', 'goo', 'hearts-and-flowers', 'mashiness', 'maudlinness', 'mawkishness', 'mush'],
    'mushroom': ['ectocarpales', 'phaeophyceae', 'algae', 'autophyte', 'ball', 'balloon', 'bead', 'bean', 'blossom', 'blow up', 'bracken', 'brew'],
    'mushroom cloud': ['a-blast', 'a-bomb shelter', 'cloudcuckooland', 'h-blast', 'mach front', 'airborne radioactivity', 'alto-cumulus', 'alto-stratus', 'anvil cloud', 'atom blast', 'banner cloud', 'billowy cloud'],
    'mushy': ['baccate', 'bathetic', 'beery', 'bland', 'boggy', 'changeable', 'cloudy', 'cloying', 'corny', 'doughy', 'flabby', 'fleshy'],
    'music': ['apollo', 'apollo musagetes', 'erato', 'euterpe', 'orpheus', 'pierides', 'polyhymnia', 'polymnia', 'terpsichore', 'arrangement', 'babel', 'clamor'],
    'music hall': ['elizabethan theater', 'globe theatre', 'greek theater', 'amphitheater', 'arena', 'arena theater', 'assembly hall', 'auditorium', 'cabaret', 'chapel', 'circle theater', 'club'],
    'music roll': ['pianola', 'arrangement', 'copy', 'draft', 'edition', 'hymnal', 'hymnbook', 'instrumental score', 'libretto', 'lute tablature', 'mechanical piano', 'music'],
    'musical': ['broadway musical', 'singspiel', 'thalia', 'achingly sweet', 'agreeable', 'agreeable-sounding', 'appealing', 'ariose', 'arioso', 'arlequinade', 'ballad opera', 'ballet'],
    'musical comedy': ['broadway musical', 'singspiel', 'thalia', 'arlequinade', 'ballad opera', 'ballet', 'ballet divertissement', 'black comedy', 'broad comedy', 'burlesque', 'burletta', 'camp'],
    'musicality': ['dulcetness', 'ear for music', 'harmonics', 'harmony', 'mellifluence', 'mellifluousness', 'melodics', 'melodiousness', 'melody', 'music', 'music theory', 'musical ear'],
    'musician': ['artist', 'artiste', 'belly dancer', 'burlesque queen', 'chorine', 'chorus boy', 'chorus girl', 'conjurer', 'coryphee', 'dancer', 'dancing girl', 'ecdysiast'],
    'musicologist': ['arranger', 'ballad maker', 'balladeer', 'balladist', 'balladmonger', 'composer', 'contrapuntist', 'ethnomusicologist', 'harmonist', 'harmonizer', 'hymnist', 'hymnographer'],
    'musing': ['walter mitty', 'absence of mind', 'absent', 'absentminded', 'absentmindedness', 'absorbed', 'absorption', 'abstracted', 'abstractedness', 'abstraction', 'advisement', 'bemused'],
    'musk': ['ambergris', 'ambrosia', 'aromatic', 'aromatic gum', 'aromatic water', 'attar', 'attar of roses', 'balm', 'balm of gilead', 'balsam', 'bay oil', 'bergamot oil'],
    'musket': ['automatic', 'blowgun', 'blowpipe', 'firearm', 'flamethrower', 'gat', 'gun', 'handgun', 'heater', 'peashooter', 'piece', 'pistol'],
    'musketeer': ['nimrod', 'zouave', 'archer', 'artilleryman', 'bersagliere', 'bowman', 'cannoneer', 'carabineer', 'chasseur', 'crack shot', 'dead shot', 'deadeye'],
    'musketry': ['a-weapons', 'antiaircraft fire', 'archery', 'armament', 'arms', 'artillery', 'ballistics', 'biological weapons', 'casting', 'chucking', 'conventional weapons', 'cross fire'],
    'musky': ['ambrosial', 'aromatic', 'balmy', 'essenced', 'flowery', 'fragrant', 'fruity', 'incense-breathing', 'odorate', 'odoriferous', 'odorous', 'perfumed'],
    'muss': ['botch', 'botchery', 'broil', 'clutter', 'derange', 'disarrange', 'disarray', 'dishevel', 'dislocate', 'disorder', 'disorganize', 'donnybrook'],
    'mussy': ['beat-up', 'bedraggled', 'blowzy', 'careless', 'chintzy', 'dilapidated', 'disheveled', 'drabbletailed', 'draggled', 'draggletailed', 'frowzy', 'frumpish'],
    'must': ['absolute', 'allegiance', 'assigned task', 'bare necessities', 'be forced', 'be in for', 'be necessary', 'be obliged', 'binding', 'blast', 'blight', 'bounden duty'],
    'muster': ['accumulate', 'agenda', 'agglomerate', 'aggregate', 'aggregation', 'aggroup', 'amass', 'assemblage', 'assemble', 'assembly', 'batch', 'beadroll'],
    'muster out': ['break up', 'deactivate', 'debrief', 'demob', 'demobilize', 'detach', 'disband', 'discharge', 'disintegrate', 'dismiss', 'disorganize', 'disperse'],
    'muster roll': ['agenda', 'beadroll', 'cadastre', 'calendar', 'census', 'census report', 'checklist', 'checkroll', 'docket', 'dramatis personae', 'head count', 'honor roll'],
    'muster up': ['bid come', 'breed', 'bring about', 'call', 'call away', 'call back', 'call for', 'call forth', 'call in', 'call out', 'call together', 'call up'],
    'mustiness': ['banality', 'banalness', 'cliche', 'commonness', 'commonplaceness', 'corniness', 'familiarness', 'fetidity', 'fetidness', 'foulness', 'frowst', 'frowstiness'],
    'musty': ['ancient', 'antediluvian', 'antiquated', 'archaic', 'back-number', 'bad', 'bad-smelling', 'banal', 'bewhiskered', 'blasted', 'blighted', 'blown'],
    'mutability': ['adaptability', 'adjustability', 'alterability', 'caducity', 'capriciousness', 'changeability', 'changeableness', 'changefulness', 'choppiness', 'corruptibility', 'dappleness', 'death'],
    'mutable': ['able to adapt', 'adaptable', 'adjustable', 'alterable', 'alterative', 'ambitendent', 'ambivalent', 'at loose ends', 'brittle', 'capricious', 'changeable', 'changeful'],
    'mutant': ['altered', 'avatar', 'better', 'catabolism', 'catalysis', 'changeable', 'changed', 'consubstantiation', 'converted', 'degenerate', 'deviant', 'displacement'],
    'mutate': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'be changed', 'be converted into', 'be renewed', 'better', 'bottom out', 'break', 'break up'],
    'mutation': ['ablaut', 'acoustic phonetics', 'alteration', 'altering', 'anomaly', 'articulatory phonetics', 'avatar', 'betacism', 'catabolism', 'catalysis', 'change', 'changing'],
    'mute': ['abiotic', 'acoustic tile', 'allophone', 'alveolar', 'anaudic', 'antiknock', 'aphasic', 'aphonic', 'apico-alveolar', 'apico-dental', 'articulation', 'aspiration'],
    'muted': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bated', 'bilabial', 'blind'],
    'muteness': ['anaudia', 'aphasia', 'aphonia', 'aphrasia', 'brevity', 'briefness', 'brusqueness', 'conciseness', 'curtness', 'deaf-muteness', 'dumbness', 'economy of words'],
    'mutilate': ['abrade', 'abscind', 'alter', 'amputate', 'annihilate', 'ban', 'bar', 'bark', 'blemish', 'bloody', 'bob', 'break'],
    'mutilated': ['aggravated', 'bandy', 'bandy-legged', 'blemished', 'bloated', 'bowlegged', 'broken', 'burned', 'burst', 'busted', 'butchered', 'castrated'],
    'mutilation': ['abrasion', 'abscission', 'amputation', 'annihilation', 'bankruptcy', 'blemish', 'bowlegs', 'break', 'breakage', 'breakdown', 'burn', 'butchering'],
    'mutineer': ['agitator', 'anarch', 'anarchist', 'anarcho-syndicalist', 'antinomian', 'arise', 'brawler', 'extremist', 'frondeur', 'insubordinate', 'insurge', 'insurgent'],
    'mutinous': ['alienated', 'at odds', 'averse', 'breakaway', 'contumacious', 'cursory', 'defiant', 'differing', 'disaffected', 'disagreeing', 'disinclined', 'disobedient'],
    'mutiny': ['arise', 'civil disorder', 'disobedience', 'disobey', 'emeute', 'general uprising', 'indiscipline', 'insubordination', 'insurge', 'insurgence', 'insurgency', 'insurrect'],
    'mutt': ['asshole', 'blockhead', 'boob', 'booby', 'chump', 'cur', 'dimwit', 'ding-a-ling', 'dingbat', 'dingdong', 'dolt', 'dope'],
    'mutter': ['air a grievance', 'aspirate', 'aspiration', 'bark', 'bated breath', 'bawl', 'beef', 'bellow', 'bellyache', 'bitch', 'blare', 'blat'],
    'mutterer': ['bellyacher', 'complainant', 'complainer', 'crab', 'crank', 'croaker', 'faultfinder', 'frondeur', 'griper', 'grouch', 'grouser', 'growler'],
    'muttering': ['aspiration', 'bated breath', 'beefing', 'bellyaching', 'bitching', 'breath', 'breathy voice', 'complaining', 'complaintful', 'crabbing', 'crabby', 'cranky'],
    'mutton': ['agneau', 'bellwether', 'breast of lamb', 'ewe', 'ewe lamb', 'gigot', 'jambe de mouton', 'jumbuck', 'lamb', 'lambkin', 'leg of lamb', 'leg of mutton'],
    'muttonhead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead'],
    'muttonheaded': ['beetleheaded', 'blockheaded', 'blunderheaded', 'boneheaded', 'cabbageheaded', 'chowderheaded', 'chuckleheaded', 'clodpated', 'dumbheaded', 'dunderheaded', 'fatheaded', 'jolterheaded'],
    'mutual': ['accessory', 'accompanying', 'associated', 'attendant', 'attending', 'changeable', 'coacting', 'coactive', 'coadjutant', 'coadjuvant', 'coefficient', 'coincident'],
    'mutual attraction': ['accord', 'addition', 'adduction', 'adjunct', 'affairs', 'affiliation', 'affinity', 'alliance', 'allurement', 'approximation', 'assemblage', 'association'],
    'mutual company': ['accident insurance', 'actuary', 'annuity', 'assurance', 'aviation insurance', 'bail bond', 'bond', 'business life insurance', 'casualty insurance', 'certificate of insurance', 'court bond', 'credit insurance'],
    'mutual understanding': ['acclamation', 'accord', 'accordance', 'agreement', 'agreement of all', 'chorus', 'common assent', 'common consent', 'compact', 'concert', 'concord', 'concordance'],
    'mutuality': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'alternation', 'amity', 'balance', 'battledore and shuttlecock', 'bipartisanship', 'bonds of harmony', 'brotherly love'],
    'mutually': ['all at once', 'all together', 'as one', 'at once', 'au pair', 'by turns', 'collectively', 'commonly', 'communally', 'concurrently', 'conjointly', 'corporately'],
    'muzzle': ['oregon boat', 'acoustic tile', 'antiknock', 'antlia', 'asphyxiate', 'baffler', 'bazoo', 'beak', 'beezer', 'bilbo', 'bill', 'bond'],
    'muzzy': ['addlebrained', 'addled', 'addleheaded', 'addlepated', 'afflicted', 'beclouded', 'befuddled', 'bent', 'blear-witted', 'blurred', 'boiled', 'bombed'],
    'mycology': ['algology', 'aquiculture', 'botany', 'bryology', 'dendrology', 'fungology', 'hydroponics', 'paleobotany', 'phycology', 'physiological botany', 'phytobiology', 'phytochemistry'],
    'myelitis': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis'],
    'myriad': ['a billion', 'a crore', 'a lakh', 'a million', 'a myriad', 'a nonillion', 'a quadrillion', 'a thousand', 'a zillion', 'abundance', 'affluence', 'ample sufficiency'],
    'myrmidon': ['adherent', 'assistant', 'creature', 'dependent', 'disciple', 'dummy', 'employee', 'feudatory', 'figurehead', 'flunky', 'follower', 'gillie'],
    'myrrh': ['ambergris', 'ambrosia', 'aromatic', 'aromatic gum', 'aromatic water', 'attar', 'attar of roses', 'balm', 'balm of gilead', 'balsam', 'bay oil', 'bergamot oil'],
    'mysterious': ['able', 'abstruse', 'ambiguous', 'amphibological', 'amphibolous', 'anagogic', 'arcane', 'awe-inspiring', 'awesome', 'awful', 'awing', 'baffling'],
    'mysteriously': ['awe-inspiringly', 'awesomely', 'awfully', 'awingly', 'bizarrely', 'eerily', 'enigmatically', 'fancifully', 'fantastically', 'grotesquely', 'inexplicably', 'monstrously'],
    'mystery': ['chinese puzzle', 'grand guignol', 'marchen', 'passion play', 'tom show', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'ambiguity', 'ambiguousness'],
    'mystery play': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger', 'closet drama'],
    'mystery story': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'apologue', 'bedtime story', 'detective story', 'fable', 'fabliau', 'fairy tale'],
    'mystic': ['adept', 'allegorical', 'anthroposophist', 'arcane', 'cabalist', 'cabalistic', 'esoteric', 'imaginary', 'impenetrable', 'inscrutable', 'magian', 'magical'],
    'mystical': ['absolute', 'abysmal', 'allegorical', 'anagogic', 'arcane', 'between the lines', 'cabalic', 'cabalistic', 'cabbalistic', 'categorical', 'clandestine', 'concealed'],
    'mysticism': ['afflatus', 'anagoge', 'anagogics', 'anthroposophy', 'apocalypse', 'cabala', 'cabalism', 'direct communication', 'divine inspiration', 'divine revelation', 'epiphany', 'esotericism'],
    'mystification': ['chinese puzzle', 'amorphousness', 'anagoge', 'anagogics', 'anthroposophy', 'apparent soundness', 'burial', 'burying', 'cabala', 'cabalism', 'casuistry', 'circularity'],
    'mystified': ['addled', 'at a loss', 'at a nonplus', 'at a stand', 'at a standstill', 'at an impasse', 'baffled', 'bamboozled', 'beat', 'bewildered', 'buffaloed', 'confounded'],
    'mystify': ['addle', 'amaze', 'around the bush', 'baffle', 'bamboozle', 'beat', 'beat about', 'beg the question', 'bewilder', 'bicker', 'boggle', 'buffalo'],
    'mystifying': ['baffling', 'bewildering', 'bothering', 'confounding', 'confusing', 'dark', 'discomposing', 'disconcerting', 'dismaying', 'distracting', 'disturbing', 'embarrassing'],
    'mystique': ['assumption', 'attitude', 'aura', 'blaze of glory', 'brilliance', 'brilliancy', 'charisma', 'climate of opinion', 'common belief', 'community sentiment', 'conceit', 'concept'],
    'myth': ['marchen', 'mishnah', 'spiritus mundi', 'sunna', 'talmud', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'ancient wisdom', 'apologue'],
    'mythical': ['acclaimed', 'allegoric', 'allegorical', 'celebrated', 'chimerical', 'concocted', 'cooked-up', 'created', 'distinguished', 'exceptional', 'extraordinary', 'fabled'],
    'mythical monsters': ['argus', 'briareus', 'cerberus', 'charybdis', 'cyclops', 'echidna', 'gorgon', 'harpy', 'hydra', 'loch ness monster', 'medusa', 'minotaur'],
    'mythicize': ['allegorize', 'fable', 'fabulize', 'fictionalize', 'mythify', 'mythologize', 'narrate', 'novelize', 'recite', 'recount', 'rehearse', 'relate'],
    'mythmaker': ['anecdotist', 'creative artist', 'fableist', 'fabler', 'fabulist', 'fancier', 'fantasist', 'fantast', 'fictionist', 'imaginer', 'inventor', 'mythicizer'],
    'mythological': ['acknowledged', 'admitted', 'allegoric', 'conventional', 'customary', 'established', 'fabulous', 'fictional', 'fictitious', 'fictive', 'figmental', 'fixed'],
    'mythology': ['marchen', 'mishnah', 'spiritus mundi', 'sunna', 'talmud', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'ancient wisdom', 'apologue'],
    'mythos': ['marchen', 'western', 'western story', 'westerner', 'action', 'adventure story', 'allegory', 'anagnorisis', 'angle', 'apologue', 'architectonics', 'architecture'],
    'nab': ['apprehend', 'apprehension', 'arrest', 'arrestation', 'arrestment', 'bobby', 'bull', 'bust', 'cabbage', 'capture', 'catch', 'clout'],
    'nabbing': ['abduction', 'apprehension', 'arrest', 'arrestation', 'capture', 'catch', 'catching', 'collaring', 'coup', 'dragnet', 'forcible seizure', 'grab'],
    'nabob': ['daddy warbucks', 'establishment', 'vip', 'baron', 'beg', 'beglerbeg', 'bey', 'big chief', 'big gun', 'big man', 'big name', 'bigwig'],
    'nacre': ['dalmatian', 'antigorite', 'butterfly', 'candy cane', 'chameleon', 'cheetah', 'chrysotile', 'confetti', 'crazy quilt', 'firedog', 'harlequin', 'iridescence'],
    'nacreous': ['burele', 'chatoyant', 'creamy', 'delicate', 'eggshell', 'flat', 'gloss', 'iridal', 'iridescent', 'iridial', 'iridian', 'irisated'],
    'nada': ['aught', 'cipher', 'goose egg', 'naught', 'nichts', 'nihil', 'nihility', 'nil', 'nix', 'no such thing', 'nonexistence', 'nothing'],
    'nadir': ['base', 'baseboard', 'basement', 'bedrock', 'bottom', 'chassis', 'dado', 'foot', 'footing', 'foundation', 'frame', 'keel'],
    'nag': ['houyhnhnm', 'advocate', 'aggravate', 'annoy', 'annoyer', 'apply pressure', 'badger', 'badgerer', 'bait', 'balker', 'balky horse', 'be at'],
    'nagging': ['adverse criticism', 'animadversion', 'aspersion', 'bad notices', 'bad press', 'blandishment', 'buttonholing', 'cajolement', 'cajolery', 'cajoling', 'captious', 'captiousness'],
    'naiad': ['davy', 'davy jones', 'neptune', 'nereid', 'oceanid', 'oceanus', 'poseidon', 'thetis', 'triton', 'fresh-water nymph', 'kelpie', 'limniad'],
    'naif': ['babe', 'boob', 'child', 'child of nature', 'chump', 'cinch', 'credulous person', 'cull', 'dove', 'dupe', 'easy mark', 'easy pickings'],
    'nail': ['gibraltar', 'abduct', 'adamant', 'agonize', 'articulate', 'at once', 'attach', 'bag', 'batten', 'batten down', 'be correct', 'be precise'],
    'nail down': ['afford proof of', 'ascertain', 'assure', 'balance', 'ballast', 'bring home to', 'certify', 'cinch', 'clear up', 'clinch', 'counterbalance', 'decide'],
    'naive': ['artless', 'awkward', 'befoolable', 'blankminded', 'bluff', 'blunt', 'born yesterday', 'budding', 'callow', 'candid', 'childlike', 'confiding'],
    'naivete': ['artlessness', 'bluffness', 'bluntness', 'candor', 'childlikeness', 'cullibility', 'deceivability', 'directness', 'dupability', 'easiness', 'greenness', 'guilelessness'],
    'naked': ['absolute', 'apparent', 'au naturel', 'bald', 'bare', 'bare-ass', 'bared', 'barefaced', 'beholdable', 'blank', 'blatant', 'blunt'],
    'naked eye': ['baby blues', 'banjo eyes', 'bright eyes', 'clear eyes', 'command', 'cornea', 'domination', 'eye', 'eyeball', 'eyelid', 'eyereach', 'eyeshot'],
    'namby pamby': ['milquetoast', 'baby', 'banal', 'bathetic', 'bathos', 'beery', 'betwixt and between', 'big baby', 'bland', 'bleeding heart', 'breakable', 'brittle'],
    'name': ['christian name', 'establishment', 'vip', 'acclaim', 'advert to', 'advertise', 'alias', 'allude to', 'announce', 'appellation', 'appellative', 'appoint'],
    'name day': ['anniversary', 'annual holiday', 'bicentenary', 'bicentennial', 'biennial', 'birthday', 'bissextile day', 'centenary', 'centennial', 'commemoration', 'decennial', 'diamond jubilee'],
    'name dropper': ['brahmin', 'adventurer', 'bourgeois gentilhomme', 'egghead', 'elitist', 'highbrow', 'mandarin', 'newly-rich', 'nouveau riche', 'nouveau roturier', 'parvenu', 'pig in clover'],
    'named': ['accepted', 'adopted', 'aforementioned', 'aforenamed', 'aforesaid', 'appointed', 'approved', 'beforementioned', 'called', 'carried', 'chosen', 'christened'],
    'nameless': ['abominable', 'anonymous', 'cryptonymic', 'cryptonymous', 'horrible', 'ignotus', 'incognito', 'indefinable', 'indescribable', 'ineffable', 'inexpressible', 'inglorious'],
    'namely': ['as here defined', 'as here interpreted', 'especially', 'exempli gratia', 'for example', 'for instance', 'id est', 'in explanation', 'in other words', 'nominally', 'particularly', 'sc'],
    'namesake': ['appellation', 'appellative', 'binomen', 'binomial name', 'byword', 'cognomen', 'cryptonym', 'denomination', 'designation', 'empty title', 'epithet', 'eponym'],
    'naming': ['appellation', 'appointment', 'assignment', 'baptism', 'calling', 'characterization', 'christening', 'connotative', 'definition', 'demonstrative', 'denomination', 'denominative'],
    'nanny': ['partlet', 'amah', 'ayah', 'biddy', 'billy', 'billy goat', 'bitch', 'bossy', 'brood mare', 'buck', 'cow', 'doe'],
    'nap': ['blanket drill', 'break', 'cat nap', 'catnap', 'dover', 'doze', 'drowse', 'feel', 'finish', 'forty winks', 'grain', 'granular texture'],
    'napery': ['cloth', 'drapery', 'dry goods', 'etoffe', 'fabric', 'felt', 'goods', 'lace', 'leather goods', 'leatherware', 'linens', 'material'],
    'napping': ['a stranger to', 'absent', 'absentminded', 'absorbed', 'abstracted', 'anesthetized', 'asleep', 'bemused', 'blind to', 'castle-building', 'cataleptic', 'caught napping'],
    'nappy': ['addled', 'beery', 'bemused', 'besotted', 'blind drunk', 'crapulent', 'crapulous', 'dizzy', 'downy', 'drenched', 'drunk', 'drunken'],
    'narc': ['bow street runner', 'fbi', 'fbi agent', 'federal', 'g-man', 'mp', 'secret service', 'sherlock holmes', 't-man', 'bailiff', 'beadle', 'beagle'],
    'narcissism': ['acquisitiveness', 'active algolagnia', 'algolagnia', 'algolagny', 'amour propre', 'amour-propre', 'amphierotism', 'autism', 'autoeroticism', 'bisexuality', 'careerism', 'complacency'],
    'narcissist': ['narcissus', 'braggart', 'bugger', 'careerist', 'coprophiliac', 'egocentric', 'egoist', 'egotist', 'erotomaniac', 'exhibitionist', 'fetishist', 'fortune hunter'],
    'narcissistic': ['acquisitive', 'ambitious for self', 'autistic', 'careerist', 'complacent', 'conceited', 'consequential', 'egocentric', 'egocentristic', 'egoistic', 'egotistical', 'grasping'],
    'narcissus': ['adonis', 'aphrodite', 'apollo', 'apollo belvedere', 'astarte', 'balder', 'cleopatra', 'freya', 'hebe', 'hyperion', 'venus', 'venus de milo'],
    'narcohypnosis': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'animal hypnosis', 'assertiveness training', 'autohypnosis', 'behavior modification', 'behavior therapy', 'bioenergetics'],
    'narcolepsy': ['catalepsy', 'coma', 'encephalitis lethargica', 'high', 'lethargy', 'narcohypnosis', 'narcoma', 'narcosis', 'narcotic stupor', 'narcotization', 'nod', 'sedation'],
    'narcosis': ['analgesia', 'anesthesia', 'callousness', 'catalepsy', 'coma', 'deadness', 'dullness', 'electronarcosis', 'encephalitis lethargica', 'high', 'impassibility', 'imperception'],
    'narcotic': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'lethean', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill'],
    'narcotics addict': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser'],
    'narcotics traffic': ['cosa nostra', 'mafia', 'black market', 'bootlegging', 'gambling', 'gray market', 'illegal commerce', 'illegal operations', 'illegitimate business', 'illicit business', 'loan-sharking', 'moonshining'],
    'narcotize': ['ko', 'anesthetize', 'bedaze', 'benumb', 'besot', 'blunt', 'chloroform', 'coldcock', 'deaden', 'desensitize', 'dope', 'drug'],
    'narcotized': ['anesthetized', 'asleep', 'cataleptic', 'catatonic', 'cold', 'comatose', 'dead', 'doped', 'dozy', 'dreamy', 'drowsy', 'drugged'],
    'nares': ['antlia', 'beak', 'beezer', 'bill', 'bugle', 'conk', 'muffle', 'muzzle', 'neb', 'nib', 'nose', 'nostrils'],
    'narrate': ['allegorize', 'chronicle', 'descant', 'describe', 'detail', 'dilate', 'discourse', 'expatiate', 'fable', 'fabulize', 'fictionalize', 'mythicize'],
    'narration': ['account', 'anecdotage', 'anecdote', 'chronicle', 'chronicling', 'describing', 'description', 'detailing', 'epic', 'epos', 'narrative', 'portrayal'],
    'narrative': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'account', 'anecdotage', 'anecdotal', 'anecdote'],
    'narrator': ['anecdotalist', 'anecdotist', 'annalist', 'author', 'chronicler', 'describer', 'fableist', 'fabler', 'fabulist', 'fictionist', 'mythmaker', 'mythopoet'],
    'narrow': ['lenten', 'quakerish', 'spartan', 'victorian', 'abate', 'abbreviate', 'abstemious', 'accented', 'accurate', 'adjust to', 'alter', 'alveolar'],
    'narrow gauge': ['angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'authoritarian', 'bigot', 'bigoted', 'borne', 'circumscribed', 'close', 'close-fitting', 'closed'],
    'narrow margin': ['delicacy', 'delicate distinction', 'differentia', 'differential', 'distinction', 'fine point', 'hairline', 'margin', 'nice distinction', 'nicety', 'nuance', 'particle of difference'],
    'narrow minded': ['authoritarian', 'bigot', 'bigoted', 'borne', 'closed', 'constricted', 'cramped', 'creedbound', 'deaf', 'deaf to reason', 'fanatical', 'hidebound'],
    'narrow the gap': ['accost', 'advance', 'approach', 'appropinquate', 'approximate', 'bear down on', 'bear down upon', 'bear up', 'center', 'centralize', 'close', 'close in'],
    'narrow-minded': ['biased', 'bigoted', 'conservative', 'conventional', 'fundamentalist', 'hidebound', 'illiberal', 'intolerant', 'mean-minded', 'mean-spirited', 'narrow', 'narrow-spirited'],
    'narrowing': ['abbreviation', 'astriction', 'astringency', 'ban', 'bar', 'barring', 'blockade', 'bottleneck', 'boycott', 'cervix', 'circumscription', 'coarctation'],
    'narrows': ['arm', 'armlet', 'bay', 'bayou', 'belt', 'bight', 'boca', 'bottleneck', 'canal', 'channel', 'cove', 'creek'],
    'nasal': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation', 'asthmatic'],
    'nasalization': ['aphonia', 'artificial voice', 'broken speech', 'broken tones', 'broken voice', 'childish treble', 'choked voice', 'cracked voice', 'croak', 'crow', 'dysarthria', 'dyslalia'],
    'nasalized': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'nascency': ['accouchement', 'babyhood', 'beginnings', 'birth', 'birth throes', 'birthing', 'blessed event', 'childbearing', 'childbed', 'childbirth', 'childhood', 'confinement'],
    'nascent': ['abecedarian', 'aboriginal', 'antenatal', 'autochthonous', 'beginning', 'budding', 'creative', 'elemental', 'elementary', 'embryonic', 'fetal', 'formative'],
    'nasty': ['fescennine', 'rabelaisian', 'abhorrent', 'abominable', 'abusive', 'acute', 'annoying', 'arrant', 'atrocious', 'awful', 'awkward', 'bad'],
    'nasty crack': ['aphorism', 'apothegm', 'bon mot', 'boutade', 'bright idea', 'bright thought', 'brilliant idea', 'conceit', 'crack', 'epigram', 'facetiae', 'flash of wit'],
    'natal': ['abecedarian', 'aboriginal', 'antenatal', 'autochthonous', 'beginning', 'budding', 'creative', 'elemental', 'elementary', 'embryonic', 'endemic', 'fetal'],
    'natal day': ['anniversary', 'annual holiday', 'bicentenary', 'bicentennial', 'biennial', 'birthday', 'bissextile day', 'centenary', 'centennial', 'commemoration', 'decennial', 'diamond jubilee'],
    'nation': ['everyman', 'john doe', 'public', 'ally', 'animal kingdom', 'archduchy', 'archdukedom', 'blood', 'body politic', 'breed', 'brood', 'buffer state'],
    'national': ['all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'allover', 'catholic', 'chauvinistic'],
    'national anthem': ['brautlied', 'christmas carol', 'communist threat', 'kunstlied', 'liebeslied', 'volkslied', 'western imperialism', 'alba', 'anthem', 'art song', 'atrocity story', 'aubade'],
    'national assembly': ['assembly', 'bicameral legislature', 'board of aldermen', 'chamber of deputies', 'city board', 'city council', 'commission', 'common council', 'congress', 'court', 'diet', 'federal assembly'],
    'national debt': ['accounts payable', 'accounts receivable', 'amount due', 'bad debts', 'bill', 'bills', 'borrowing', 'charges', 'chits', 'debt', 'due', 'dues'],
    'national park': ['indian reservation', 'archives', 'bank', 'bird sanctuary', 'forest preserve', 'game reserve', 'library', 'museum', 'national forest', 'paradise', 'park', 'preserve'],
    'nationalism': ['americanism', 'anglicism', 'briticism', 'eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'appeasement', 'balance of power', 'brinkmanship', 'chauvinism', 'coexistence'],
    'nationality': ['americanism', 'anglicism', 'briticism', 'everyman', 'john doe', 'public', 'aboriginality', 'ally', 'archduchy', 'archdukedom', 'autochthonousness', 'bloodline'],
    'nationalization': ['americanization', 'fabian socialism', 'fabianism', 'marxian socialism', 'marxism', 'saint-simonism', 'acculturation', 'admission', 'adoption', 'affiliation', 'angary', 'annexation'],
    'nationalize': ['annex', 'attach', 'collectivize', 'commandeer', 'communalize', 'communize', 'confiscate', 'democratize', 'distrain', 'expropriate', 'garnish', 'impound'],
    'native': ['aboriginal', 'aborigine', 'agrarian', 'arcadian', 'artless', 'atavistic', 'autochthon', 'autochthonous', 'basic', 'best', 'bodily', 'born'],
    'nativity': ['aboriginality', 'accouchement', 'aspect', 'astrodiagnosis', 'astrology', 'astromancy', 'autochthonousness', 'babyhood', 'beginnings', 'birth', 'birth throes', 'birthing'],
    'nato': ['al', 'anzus council', 'aspac', 'arab league', 'bis', 'british commonwealth', 'cacm', 'cento', 'central treaty organization', 'colombo plan', 'common market', 'commonwealth of nations'],
    'natter': ['babble', 'babblement', 'bavardage', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather', 'blether', 'blethers', 'cackle', 'caquet'],
    'natty': ['bandbox', 'braw', 'chic', 'classy', 'clothes-conscious', 'cosmopolitan', 'dapper', 'dashing', 'doggy', 'dressed to advantage', 'dressed to kill', 'elegant'],
    'natural': ['afro', 'attic', 'bohemian', 'ciceronian', 'spartan', 'accepted', 'accidental', 'actual', 'affable', 'agrarian', 'alien', 'ament'],
    'natural gas': ['alcohol', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coke', 'combustible', 'dope', 'ethane'],
    'natural right': ['bill of rights', 'declaration of right', 'magna carta', 'magna charta', 'petition of right', 'appurtenance', 'authority', 'birthright', 'civil liberties', 'civil rights', 'claim', 'conjugal right'],
    'natural science': ['newtonian physics', 'academic discipline', 'academic specialty', 'acoustics', 'aerophysics', 'applied physics', 'applied science', 'area', 'arena', 'art', 'astrophysics', 'basic conductor physics'],
    'natural world': ['air', 'atom', 'atomic particles', 'brute matter', 'building block', 'chemical element', 'component', 'constituent', 'earth', 'element', 'elementary particle', 'elementary unit'],
    'naturalism': ['marxism', 'absolute realism', 'animalism', 'artlessness', 'atomism', 'authenticity', 'behaviorism', 'bona fideness', 'commonsense realism', 'dialectical materialism', 'earthliness', 'empiricism'],
    'naturalist': ['marxist', 'anatomist', 'bacteriologist', 'biochemist', 'biologist', 'biometrist', 'biophysicist', 'botanist', 'commonsense philosopher', 'cytologist', 'dialectical materialist', 'ecologist'],
    'naturalistic': ['cyrenaic', 'eleatic', 'epicurean', 'marxian', 'marxist', 'megarian', 'stoic', 'animist', 'animistic', 'atomistic', 'authentic', 'bona fide'],
    'naturalization': ['americanization', 'about-face', 'acclimation', 'acclimatization', 'accommodation', 'acculturation', 'accustoming', 'adaption', 'adjustment', 'admission', 'adoption', 'affiliation'],
    'naturalize': ['americanize', 'anglicize', 'acclimate', 'acclimatize', 'accommodate', 'acculturate', 'acculturize', 'accustom', 'adapt', 'adjust', 'admit', 'adopt'],
    'naturalized': ['americanized', 'anglicized', 'acclimated', 'acclimatized', 'accommodated', 'acculturated', 'acculturized', 'accustomed', 'adapted', 'adjusted', 'adopted', 'assimilated'],
    'naturally': ['ok', 'roger', 'absolutely', 'accordingly', 'actually', 'all right', 'alright', 'alrighty', 'amen', 'and so', 'artlessly', 'as a consequence'],
    'naturalness': ['atticism', 'bohemianism', 'abandon', 'absolute realism', 'affability', 'appropriateness', 'artlessness', 'austerity', 'authenticity', 'baldness', 'bareness', 'bona fideness'],
    'nature': ['copernican universe', 'einsteinian universe', 'newtonian universe', 'ptolemaic universe', 'air', 'all', 'all being', 'all creation', 'allness', 'anatomy', 'animus', 'aptitude'],
    'naturist': ['bareness', 'birthday suit', 'decollete', 'ecdysiast', 'gymnosophist', 'gymnosophy', 'nakedness', 'naturism', 'not a stitch', 'nudism', 'nudist', 'nudity'],
    'naturistic': ['bald', 'bare', 'bare-ass', 'general', 'gymnosophical', 'in native buff', 'in puris naturalibus', 'in the altogether', 'in the buff', 'in the raw', 'naked', 'natural'],
    'naught': ['a little thing', 'aught', 'cipher', 'collapse', 'destruction', 'disaster', 'failure', 'goose egg', 'hardly anything', 'inessential', 'insignificancy', 'marginal matter'],
    'naughty': ['abominable', 'arrant', 'atrocious', 'bad', 'base', 'bawdy', 'black', 'blamable', 'blameworthy', 'blue', 'contrary', 'criminal'],
    'nausea': ['abhorrence', 'abomination', 'abscess', 'ague', 'airsickness', 'allergy', 'anemia', 'angst', 'anguish', 'ankylosis', 'anoxia', 'antagonism'],
    'nauseant': ['abstergent', 'cathartic', 'cleaner', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing cream', 'cold cream', 'cream', 'dentifrice', 'depurant', 'detergent'],
    'nauseated': ['airsick', 'anguished', 'anxious', 'barfy', 'bored', 'carsick', 'cheerless', 'choking', 'depressed', 'disgusted', 'gagging', 'grim'],
    'nauseating': ['abhorrent', 'abominable', 'bad', 'barfy', 'base', 'beastly', 'below contempt', 'beneath contempt', 'brackish', 'cloying', 'contemptible', 'crappy'],
    'nauseous': ['abhorrent', 'airsick', 'anguished', 'anxious', 'bad', 'barfy', 'bored', 'brackish', 'carsick', 'cheerless', 'cloying', 'depressed'],
    'nautical': ['bathymetric', 'bathyorographical', 'boating', 'deep-sea', 'hydrographic', 'marine', 'maritime', 'naval', 'navigational', 'ocean-going', 'oceanic', 'oceanographic'],
    'naval officer': ['od', 'admiral', 'boatswain', 'captain', 'chief engineer', 'chief mate', 'chief petty officer', 'commander', 'commodore', 'deck officer', 'ensign', 'fleet admiral'],
    'navar': ['var', 'airborne radar', 'astronavigation', 'aviation radar', 'celestial navigation', 'consolan', 'electronic navigation', 'loran', 'navigation', 'omnidirectional range', 'omnirange', 'radar'],
    'nave': ['easter sepulcher', 'ambry', 'apse', 'arbor', 'axis', 'axle', 'axle bar', 'axle shaft', 'axle spindle', 'axle-tree', 'baptistery', 'blindstory'],
    'navel': ['axis', 'center', 'center of action', 'center of gravity', 'centroid', 'centrum', 'core', 'dead center', 'epicenter', 'heart', 'hub', 'kernel'],
    'navigate': ['aeroplane', 'airlift', 'airplane', 'allocate', 'assign', 'balloon', 'be airborne', 'boat', 'canoe', 'captain', 'carry sail', 'chart a course'],
    'navigation': ['var', 'aim', 'astronavigation', 'azimuth', 'bearing', 'bent', 'boating', 'canoeing', 'cartography', 'celestial navigation', 'chorography', 'circumnavigation'],
    'navigational': ['cartographic', 'chorographic', 'geodetic', 'geographic', 'locational', 'marine', 'maritime', 'nautical', 'naval', 'ocean-going', 'oceanic', 'pelagic'],
    'navigator': ['ab', 'ancient mariner', 'argonaut', 'dylan', 'flying dutchman', 'gyropilot', 'neptune', 'od', 'poseidon', 'varuna', 'able seaman', 'able-bodied seaman'],
    'navvy': ['blue-collar worker', 'breadwinner', 'casual', 'casual laborer', 'common laborer', 'day laborer', 'digger', 'dredge', 'dredger', 'driller', 'employee', 'excavator'],
    'navy': ['naval construction battalion', 'rn', 'royal navy', 'seabees', 'usn', 'united states navy', 'argosy', 'armada', 'bottoms', 'cavendish', 'chaw', 'chew'],
    'navy man': ['amazon', 'naval reservist', 'royal marine', 'seabee', 'air serviceman', 'bluejacket', 'boot', 'brave', 'cadet', 'cannon fodder', 'fighting man', 'food for powder'],
    'nay': ['australian ballot', 'hare system', 'no', 'abnegation', 'au contraire', 'aye', 'ballot', 'canvass', 'canvassing', 'casting vote', 'certainly not', 'con'],
    'naysayer': ['anomaly', 'bitter-ender', 'brawler', 'crosspatch', 'defeatist', 'defendant', 'denier', 'diehard', 'disputant', 'dissenter', 'dissentient', 'dissident'],
    'nazism': ['centralism', 'collectivism', 'communism', 'constitutionalism', 'democratism', 'fascism', 'federalism', 'feudalism', 'feudality', 'governmentalism', 'imperialism', 'monarchism'],
    'nco': ['acting corporal', 'acting sergeant', 'centurion', 'chief warrant officer', 'color sergeant', 'corporal', 'first sergeant', 'havildar', 'lance corporal', 'lance sergeant', 'master sergeant', 'mess sergeant'],
    'ne plus ultra': ['acme', 'acme of perfection', 'all', 'apex', 'apogee', 'authority', 'authorization', 'be-all and end-all', 'blue ribbon', 'brow', 'cap', 'capstone'],
    'neanderthal': ['goth', 'gothic', 'animal', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'brutal', 'brute', 'brutish', 'ill-bred', 'impolite'],
    'neap': ['couchant', 'crouched', 'dead low water', 'debased', 'depressed', 'direct tide', 'ebb', 'ebb and flow', 'ebb tide', 'flat', 'flood', 'flood tide'],
    'near': ['about', 'about to be', 'abutting', 'accost', 'adjacent', 'adjoining', 'advance', 'advancing', 'all but', 'almost', 'along toward', 'already in sight'],
    'near east': ['africa', 'america', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'east', 'eastern hemisphere', 'eurasia', 'europe', 'far east'],
    'near miss': ['close call', 'close shave', 'close squeak', 'collision', 'collision course', 'confrontation', 'crack-up', 'crash', 'encounter', 'error', 'hairbreadth escape', 'joining'],
    'near-sighted': ['biased', 'bigoted', 'dogmatic', 'heedless', 'illiberal', 'insular', 'intolerant', 'myopic', 'narrow', 'narrow-minded', 'one-sided', 'opinionated'],
    'nearby': ['about', 'accessible', 'adjacent', 'along toward', 'around', 'aside', 'at close quarters', 'at hand', 'away', 'beside', 'by', 'circa'],
    'nearing': ['about to be', 'access', 'accession', 'advance', 'advancing', 'advent', 'afflux', 'affluxion', 'already in sight', 'approach', 'approaching', 'appropinquation'],
    'nearly': ['about', 'all but', 'all in all', 'almost', 'almost entirely', 'approaching', 'approximately', 'around', 'as good as', 'barely', 'by and large', 'chiefly'],
    'nearness': ['access', 'accession', 'accord', 'accordance', 'addition', 'adjunct', 'advance', 'advent', 'affairs', 'affiliation', 'affinity', 'afflux'],
    'nearsighted': ['asquint', 'astigmatic', 'authoritarian', 'bigot', 'bigoted', 'blind', 'blindfold', 'blindfolded', 'blink-eyed', 'blinking', 'blinky', 'borne'],
    'nearsightedness': ['authoritarianism', 'bigotry', 'blind side', 'blind spot', 'blinders', 'blindness', 'closed mind', 'cramped ideas', 'dim-sightedness', 'fanaticism', 'hideboundness', 'illiberality'],
    'neat': ['attic', 'ciceronian', 'daedalian', 'ok', 'spartan', 'absolute', 'ace-high', 'adept', 'adroit', 'all ataunto', 'anal', 'apt'],
    'neaten': ['clean up', 'clear the decks', 'clear up', 'fix up', 'groom', 'police', 'police up', 'put in order', 'put in trim', 'spruce', 'spruce up', 'straighten out'],
    'neatly': ['ably', 'adeptly', 'adroitly', 'agilely', 'aptly', 'artfully', 'artistically', 'brilliantly', 'capably', 'chicly', 'cleverly', 'competently'],
    'neatness': ['atticism', 'anality', 'apple-pie order', 'appropriateness', 'chasteness', 'chastity', 'chic', 'clarity', 'classicalism', 'classicism', 'clearness', 'clothes-consciousness'],
    'neb': ['aculeus', 'acumination', 'antlia', 'auger', 'beak', 'beezer', 'bill', 'bit', 'borer', 'bugle', 'conk', 'cusp'],
    'nebbish': ['milquetoast', 'a nobody', 'a nothing', 'baby', 'big baby', 'chicken', 'cipher', 'common man', 'crybaby', 'doormat', 'dud', 'dull tool'],
    'nebula': ['black magellanic cloud', 'crab nebula', 'gegenschein', 'bright diffuse nebula', 'coalsack', 'counterglow', 'dark cloud', 'dark nebula', 'diffuse nebula', 'dust cloud', 'gaseous nebula', 'nebula of lyra'],
    'nebulous': ['cynthian', 'abstract', 'amorphous', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical', 'bland'],
    'necessaries': ['bare necessities', 'call for', 'demand', 'demand for', 'desideration', 'desideratum', 'essential', 'essentials', 'indispensable', 'must', 'must item', 'necessities'],
    'necessarily': ['accordingly', 'and so', 'as a consequence', 'as a result', 'certainly', 'come what may', 'compulsorily', 'consequently', 'fatefully', 'finally', 'from necessity', 'inconsequence'],
    'necessary': ['absolute', 'apodictic', 'backhouse', 'binding', 'bound', 'called for', 'cardinal', 'certain', 'choiceless', 'clear', 'clear and distinct', 'clear as day'],
    'necessity': ['absolute certainty', 'absoluteness', 'act of god', 'assurance', 'assuredness', 'bare cupboard', 'bare necessities', 'bare subsistence', 'beggarliness', 'beggary', 'call', 'call for'],
    'neck': ['abbreviation', 'advocate', 'alpenstock', 'and quarter', 'ankle', 'arm', 'articulation', 'astriction', 'astringency', 'athletic supporter', 'back', 'backbone'],
    'necklace': ['anklet', 'armlet', 'band', 'bangle', 'beads', 'belt', 'bijou', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet'],
    'neckwear': ['roman collar', 'band', 'bandanna', 'bertha', 'boa', 'bowtie', 'button-down collar', 'celluloid collar', 'choke', 'choker', 'clerical collar', 'collar'],
    'necrologic': ['archival', 'autobiographical', 'biographical', 'chronologic', 'cinerary', 'dirgelike', 'dismal', 'documental', 'documentary', 'documentational', 'epigraphic', 'epitaphic'],
    'necrological': ['archival', 'autobiographical', 'biographical', 'chronologic', 'cinerary', 'dirgelike', 'dismal', 'documental', 'documentary', 'documentational', 'epigraphic', 'epitaphic'],
    'necrology': ['clio', 'muse of history', 'adventures', 'annals', 'arch', 'autobiography', 'barrow', 'bill of mortality', 'biographical sketch', 'biography', 'body count', 'boundary stone'],
    'necromancer': ['comus', 'faust', 'automatist', 'charmer', 'conjurer', 'diabolist', 'diviner', 'dowser', 'ecstatic', 'enchanter', 'mage', 'magus'],
    'necromancy': ['alchemy', 'bewitchery', 'bewitchment', 'charm', 'divination', 'enchantment', 'fetishism', 'glamour', 'gramarye', 'hoodoo', 'juju', 'jujuism'],
    'necromantic': ['bewitched', 'cantrip', 'enchanted', 'hoodoo', 'incantational', 'incantatory', 'magian', 'magic', 'magical', 'miraculous', 'mystic', 'numinous'],
    'necrophilia': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'bisexuality', 'coprophilia', 'exhibitionism', 'fetishism', 'heterosexuality', 'homoeroticism', 'homosexualism'],
    'necrophiliac': ['bugger', 'coprophiliac', 'erotomaniac', 'exhibitionist', 'fetishist', 'masochist', 'narcissist', 'nymphomaniac', 'paraphiliac', 'pederast', 'pedophiliac', 'rapist'],
    'necrosis': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'bleeding'],
    'nectar': ['ambrosia', 'artificial sweetener', 'blackstrap', 'bonne bouche', 'calcium cyclamate', 'cane syrup', 'cate', 'choice morsel', 'clover honey', 'comb honey', 'corn syrup', 'cyclamates'],
    'nectarous': ['agreeable', 'ambrosial', 'bittersweet', 'candied', 'dainty', 'delectable', 'delicate', 'delicious', 'delightful', 'exquisite', 'good', 'good to eat'],
    'need': ['absence', 'ardor', 'arrearage', 'ask', 'bare cupboard', 'bare necessities', 'bare subsistence', 'basic', 'be forced', 'be hurting for', 'be in for', 'be in want'],
    'needful': ['called for', 'cardinal', 'essential', 'fundamental', 'imperative', 'indicated', 'indispensable', 'irreducible', 'irreductible', 'irreplaceable', 'mazuma', 'moolah'],
    'needing': ['appetitive', 'arrested', 'bankrupt in', 'bare of', 'bereft of', 'callow', 'defective', 'deficient', 'denuded of', 'deprived of', 'desiderative', 'desireful'],
    'needle': ['gramophone', 'gyrosin compass', 'pa', 'pa system', 'rdf', 'victrola', 'aculeus', 'acumination', 'aggravate', 'annoy', 'arrow', 'audio sound system'],
    'needled': ['badgered', 'baited', 'bedeviled', 'beset', 'bugged', 'bullyragged', 'chivied', 'deviled', 'dogged', 'harassed', 'harried', 'heckled'],
    'needless': ['de trop', 'dispensable', 'excess', 'excessive', 'expendable', 'expletive', 'gratuitous', 'in excess', 'inessential', 'naturally', 'nonessential', 'obviously'],
    'needlessly': ['aimlessly', 'beyond need', 'beyond reason', 'bootlessly', 'fecklessly', 'fruitlessly', 'futilely', 'overplus', 'pointlessly', 'purposelessly', 'redundantly', 'supererogatorily'],
    'needlework': ['applique', 'basting', 'binding', 'buttonholing', 'crochet', 'embroidery', 'fancywork', 'garment making', 'knitting', 'macrame', 'needlepoint', 'netting'],
    'needy': ['beggared', 'beggarly', 'bereaved', 'bereft', 'chronic poverty area', 'dead', 'depressed population', 'deprived', 'destitute', 'disadvantaged', 'down-and-out', 'flat'],
    'nefarious': ['abject', 'abominable', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beggarly', 'beneath contempt', 'black', 'blamable'],
    'negate': ['abate', 'abnegate', 'abolish', 'abrogate', 'agree to disagree', 'annihilate', 'annul', 'be at cross-purposes', 'be contrary to', 'be unmoved', 'be unwilling', 'beg off'],
    'negation': ['abnegation', 'abolishment', 'abolition', 'absence', 'annihilation', 'annulment', 'antagonism', 'argumentation', 'bucking', 'challenge', 'choking', 'choking off'],
    'negative': ['cassandra-like', 'cassandran', 'cassandrian', 'ditto copy', 'photostat', 'xerox', 'xerox copy', 'abjuratory', 'abnegate', 'abnegation', 'abnegative', 'abolish'],
    'negativism': ['abnegation', 'alienation', 'arrest', 'arrestation', 'arrestment', 'autism', 'autistic thinking', 'avoidance mechanism', 'blame-shifting', 'blockage', 'blocking', 'challenge'],
    'negativist': ['cassandra', 'eeyore', 'bitter-ender', 'brawler', 'calamity howler', 'cynic', 'defeatist', 'defendant', 'diehard', 'disputant', 'dissentient', 'dissident'],
    'neglect': ['sisyphean labor', 'abandon', 'bad policy', 'be caught napping', 'be neglectful', 'be negligent', 'blink at', 'brush off', 'carelessness', 'cold-shoulder', 'contemn', 'cut'],
    'neglected': ['abandoned', 'deserted', 'disregarded', 'forgotten', 'half-done', 'ignored', 'ill-requited', 'ill-rewarded', 'laid aside', 'left undone', 'missed', 'omitted'],
    'neglectful': ['behindhand', 'careless', 'culpably negligent', 'delinquent', 'derelict', 'disregardful', 'inadvertent', 'inattentive', 'laissez-faire', 'lax', 'loose', 'neglecting'],
    'negligence': ['absentmindedness', 'accidia', 'acedia', 'allowance', 'apathy', 'approximation', 'ataraxia', 'ataraxy', 'bad policy', 'blowziness', 'carelessness', 'casualness'],
    'negligent': ['apathetic', 'approximate', 'approximative', 'ataractic', 'beat-up', 'bedraggled', 'behindhand', 'blase', 'blowzy', 'botched', 'bungled', 'butchered'],
    'negligible': ['back-burner', 'cursory', 'depthless', 'dinky', 'dispensable', 'fat', 'few', 'footling', 'immaterial', 'inappreciable', 'inconsequential', 'inconsiderable'],
    'negotiable': ['achievable', 'actable', 'alienable', 'assignable', 'attainable', 'bequeathable', 'compassable', 'consignable', 'convertible', 'conveyable', 'devisable', 'doable'],
    'negotiable instrument': ['cd', 'iou', 'mo', 'acceptance', 'acceptance bill', 'bank acceptance', 'bank check', 'bill', 'bill of draft', 'bill of exchange', 'blank check', 'certificate'],
    'negotiate': ['abalienate', 'act between', 'adjust', 'advise with', 'agree', 'alien', 'alienate', 'amortize', 'arbitrate', 'arrange', 'assign', 'bargain'],
    'negotiation': ['audience', 'bargaining', 'bargaining session', 'business deal', 'chaffer', 'chaffering', 'collective bargaining', 'coming to terms', 'commercial transaction', 'conclave', 'confab', 'confabulation'],
    'negotiator': ['agent', 'arbitrator', 'bargainer', 'broker', 'business agent', 'cardholder', 'connection', 'contact', 'deputy', 'front', 'front man', 'go-between'],
    'negro': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'oriental'],
    'negro spiritual': ['anthem', 'cantata', 'canticle', 'chorale', 'church music', 'doxology', 'gospel', 'gospel music', 'hymn', 'hymn-tune', 'hymnody', 'hymnology'],
    'neigh': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'bray', 'call', 'caterwaul'],
    'neighbor': ['abut', 'abut on', 'abutter', 'acquaintance', 'adjacent', 'adjoin', 'adjoiner', 'adjoining', 'advocate', 'alter ego', 'appose', 'backer'],
    'neighborhood': ['airspace', 'alentours', 'ambience', 'ambit', 'approach', 'approximation', 'area', 'belt', 'borderlands', 'circle', 'circuit', 'circumambiencies'],
    'neighboring': ['abutting', 'adjacent', 'adjoining', 'ambient', 'bordering', 'circling', 'circumambient', 'circumferential', 'circumflex', 'circumfluent', 'circumfluous', 'circumjacent'],
    'neighborliness': ['amiability', 'amiableness', 'amicability', 'amicableness', 'amity', 'bonhomie', 'congeniality', 'cordiality', 'friendliness', 'friendship', 'generosity', 'geniality'],
    'neighborly': ['agreeable', 'amiable', 'amicable', 'beneficent', 'benevolent', 'benign', 'benignant', 'brotherly', 'congenial', 'cooperative', 'cordial', 'favorable'],
    'neighbourhood': ['about', 'almost', 'approximately', 'area', 'around', 'close to', 'confines', 'district', 'environs', 'locale', 'locality', 'more or less'],
    'neighbourly': ['affable', 'agreeable', 'amiable', 'civil', 'companionable', 'considerate', 'cordial', 'courteous', 'friendly', 'genial', 'gracious', 'harmonious'],
    'nembutal': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal', 'tuinal pill'],
    'nemesis': ['alecto', 'astraea', 'dike', 'jupiter fidius', 'justice', 'justitia', 'loki', 'megaera', 'minos', 'rhadamanthus', 'set', 'themis'],
    'neolith': ['ancient manuscript', 'antique', 'antiquity', 'archaism', 'artifact', 'cave painting', 'eolith', 'fossil', 'mezzolith', 'microlith', 'paleolith', 'petrification'],
    'neologism': ['young turk', 'arriviste', 'blend', 'breakthrough', 'bright young man', 'coinage', 'comer', 'discovery', 'fledgling', 'ghost word', 'innovation', 'introduction'],
    'neophyte': ['christian', 'god-fearing man', 'abecedarian', 'accepter', 'alphabetarian', 'apprentice', 'articled clerk', 'baby', 'beginner', 'believer', 'boot', 'catechumen'],
    'neoplasm': ['benign tumor', 'callosity', 'callus', 'cancer', 'carcinoma', 'corn', 'cyst', 'excrescence', 'fungosity', 'fungus', 'growth', 'intumescence'],
    'nephew': ['aunt', 'auntie', 'blood brother', 'brethren', 'brother', 'bub', 'bubba', 'bud', 'buddy', 'country cousin', 'cousin', 'cousin once removed'],
    'nephritis': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis'],
    'nepotism': ['bias', 'boodle', 'campaign contribution', 'campaign fund', 'discrimination', 'favoritism', 'graft', 'inclination', 'inequality', 'interest', 'involvement', 'leaning'],
    'neptune': ['ab', 'agdistis', 'amor', 'ancient mariner', 'aphrodite', 'apollo', 'apollon', 'ares', 'argonaut', 'artemis', 'ate', 'athena'],
    'nerve': ['afferent neuron', 'animate', 'annoy', 'anxiety', 'aplomb', 'apprehension', 'assurance', 'assure', 'audacity', 'autonomic nervous system', 'axon', 'backbone'],
    'nerve center': ['bosom', 'breast', 'center of activity', 'center of life', 'esoteric reality', 'focal point', 'focus', 'ganglion', 'heart', 'heart of hearts', 'hub', 'inmost heart'],
    'nerveless': ['anemic', 'asthenic', 'bloodless', 'calm', 'castrated', 'chicken', 'coolheaded', 'cowardly', 'debilitated', 'demasculinized', 'devitalized', 'drooping'],
    'nerves': ['agitation', 'apprehensiveness', 'attack of nerves', 'buck fever', 'case of nerves', 'excessive irritability', 'fear', 'fidgetiness', 'fidgets', 'morbid excitability', 'nervosity', 'nervous stomach'],
    'nervous': ['acid', 'agitable', 'agitated', 'all nerves', 'all-overish', 'allergic', 'anaphylactic', 'anxious', 'anxioused up', 'apprehensive', 'bashful', 'biting'],
    'nervous breakdown': ['brain disease', 'breakdown', 'circulatory collapse', 'collapse', 'crack-up', 'crackup', 'emotional disorder', 'emotional instability', 'exhaustion', 'frayed nerves', 'frazzled nerves', 'functional nervous disorder'],
    'nervous disorder': ['ms', 'amyotrophic lateral sclerosis', 'brain disease', 'cephalalgia', 'cerebral palsy', 'chorea', 'crack-up', 'emotional disorder', 'emotional instability', 'epilepsy', 'falling sickness', 'functional nervous disorder'],
    'nervous prostration': ['breakdown', 'circulatory collapse', 'collapse', 'crack-up', 'crackup', 'draining', 'exhaustedness', 'exhaustion', 'frayed nerves', 'frazzled nerves', 'jangled nerves', 'nervous breakdown'],
    'nervous system': ['afferent neuron', 'autonomic nervous system', 'axon', 'brain', 'central nervous system', 'cerebral cortex', 'craniosacral nervous system', 'dendrite', 'effector organ', 'efferent neuron', 'ganglion', 'gray matter'],
    'nervous tension': ['agitation', 'all-overs', 'angst', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat', 'anxiousness', 'apprehension', 'apprehensiveness'],
    'nervousness': ['agitability', 'agitation', 'all-overs', 'allergy', 'anaphylaxis', 'angst', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat'],
    'nervy': ['agitated', 'all nerves', 'apprehensive', 'beefy', 'biggety', 'bluff', 'bold', 'bouncing', 'brash', 'bulldoggish', 'cheeky', 'chutzpadik'],
    'nescience': ['agnosticism', 'blankmindedness', 'callowness', 'empty-headedness', 'greenhornism', 'greenness', 'hiatus of learning', 'ignorance', 'ignorantism', 'ignorantness', 'inanity', 'inexperience'],
    'nest': ['a mass of', 'a world of', 'abide', 'abiding place', 'abode', 'address', 'aerie', 'anchor', 'apiary', 'army', 'bee tree', 'beehive'],
    'nest egg': ['swiss bank account', 'assets', 'backlog', 'balance', 'bank account', 'bottom dollar', 'budget', 'cache', 'cash reserves', 'checking account', 'command of money', 'exchequer'],
    'nesting': ['abiding', 'abode', 'altricial', 'anserine', 'anserous', 'aquiline', 'avian', 'avicular', 'birdlike', 'birdy', 'cohabitation', 'columbine'],
    'nestle': ['arm', 'armor', 'bed', 'bless', 'bundle', 'burrow', 'champion', 'cloak', 'compass about', 'copyright', 'cover', 'cradle'],
    'nestling': ['amorous dalliance', 'apprentice', 'avifauna', 'baby', 'baby bird', 'beginner', 'billing and cooing', 'bird', 'bird of jove', 'bird of juno', 'bird of minerva', 'bird of night'],
    'nestor': ['dutch uncle', 'polonius', 'admonisher', 'adviser', 'backseat driver', 'buttinsky', 'confidant', 'consultant', 'counsel', 'counselor', 'expert', 'guide'],
    'net': ['acquire', 'afford', 'angle', 'apprehend', 'arabesque', 'arrest', 'asking price', 'avails', 'avoirdupois', 'bag', 'bait', 'bait the hook'],
    'net income': ['avails', 'base pay', 'box office', 'commissions', 'compensation', 'credit', 'credits', 'dismissal wage', 'disposable income', 'dividend', 'dividends', 'earned income'],
    'net worth': ['account', 'assessed valuation', 'assets', 'assets and liabilities', 'circumstances', 'conversion factor', 'current assets', 'deferred assets', 'face', 'face value', 'fixed assets', 'frozen assets'],
    'nether world': ['abaddon', 'aides', 'aidoneus', 'cerberus', 'charon', 'cora', 'despoina', 'dis', 'dis pater', 'erebus', 'gehenna', 'hades'],
    'netted': ['barred', 'cancellated', 'crossbarred', 'filigreed', 'grated', 'gridded', 'laced', 'lacelike', 'lacy', 'latticelike', 'meshed', 'meshy'],
    'netting': ['apprehension', 'arabesque', 'arrest', 'arrestation', 'arrestment', 'basketry', 'basketwork', 'bust', 'cancellation', 'capture', 'cross-hatching', 'crossing-out'],
    'nettle': ['aggravate', 'agitate', 'annoy', 'arouse', 'badger', 'bait', 'be at', 'bedevil', 'beset', 'blow the coals', 'bother', 'bramble'],
    'nettled': ['aggravated', 'angry', 'annoyed', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'chafed', 'disturbed', 'exasperated', 'galled', 'griped'],
    'network': ['arabesque', 'arrangement', 'basketry', 'basketwork', 'cancellation', 'circuit', 'coast-to-coast hookup', 'complex', 'cross-hatching', 'crossing-out', 'filigree', 'fret'],
    'neuralgia': ['ms', 'amyotrophic lateral sclerosis', 'brain disease', 'cephalalgia', 'cerebral palsy', 'chorea', 'emotional disorder', 'epilepsy', 'falling sickness', 'glossopharyngeal neuralgia', 'headache', 'herpes zoster'],
    'neuritis': ['ms', 'adenoiditis', 'adrenitis', 'amyotrophic lateral sclerosis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis'],
    'neurological': ['allopathic', 'chiropodic', 'chiropractic', 'clinical', 'dental', 'exodontic', 'homeopathic', 'hydropathic', 'iatric', 'medical', 'naturopathic', 'nerval'],
    'neurologist': ['anesthesiologist', 'cardiologist', 'chiropodist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'immunologist', 'internist', 'neurology', 'neurosurgeon'],
    'neuron': ['afferent neuron', 'autonomic nervous system', 'axon', 'brain', 'central nervous system', 'cerebral cortex', 'craniosacral nervous system', 'dendrite', 'effector organ', 'efferent neuron', 'ganglion', 'gray matter'],
    'neurosis': ['abulia', 'accident neurosis', 'anxiety hysteria', 'anxiety neurosis', 'arteriosclerotic psychosis', 'association neurosis', 'battle fatigue', 'blast neurosis', 'brain disease', 'certifiability', 'combat fatigue', 'compensation neurosis'],
    'neurotic': ['abnormal', 'alcoholic', 'alternating personality', 'antisocial personality', 'anxious', 'brain-damaged', 'brain-injured', 'catatonic', 'certifiable', 'confused', 'deviant', 'disordered'],
    'neuter': ['laodicean', 'alter', 'animate', 'anythingarian', 'apathetic', 'asexual', 'capon', 'castrate', 'castrated', 'centrist', 'change', 'cold'],
    'neutral': ['hydromatic', 'laodicean', 'olympian', 'abstract', 'achromatic', 'achromic', 'aloof', 'anemic', 'anythingarian', 'apathetic', 'asexual', 'ashen'],
    'neutrality': ['laodiceanism', 'olympian detachment', 'a wise passiveness', 'abnegation', 'abstinence', 'avoidance', 'avoiding reaction', 'calm', 'calmness', 'chill', 'chilliness', 'circumvention'],
    'neutralize': ['abrogate', 'absorb the shock', 'annul', 'balance', 'break the fall', 'bring to nothing', 'buffer', 'cancel', 'cancel out', 'come to nothing', 'compensate', 'compensate for'],
    'neutralizer': ['acid', 'acidity', 'agent', 'alkali', 'alkalinity', 'alloisomer', 'anion', 'antacid', 'antidote', 'atom', 'base', 'biochemical'],
    'neutron': ['k-meson', 'kern', 'nmr', 'alpha particle', 'antibaryon', 'antilepton', 'antimeson', 'atomic nucleus', 'atomic particle', 'baryon', 'beta particle', 'electron'],
    'never': ['god forbid', 'at no hand', 'at no time', 'au contraire', 'by no means', 'far from it', 'in no case', 'in no respect', 'in no way', 'in no wise', 'never on earth', 'nevermore'],
    'never ending': ['ageless', 'amaranthine', 'articulated', 'catenated', 'ceaseless', 'coeternal', 'concatenated', 'connected', 'constant', 'continual', 'continued', 'continuing'],
    'never say die': ['be determined', 'be hopeful', 'be in earnest', 'be resolved', 'bear up', 'buckle down', 'buckle to', 'catch at straws', 'come up fighting', 'cross the rubicon', 'die fighting', 'die hard'],
    'never-never land': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley'],
    'nevertheless': ['after all', 'again', 'albeit', 'all the same', 'although', 'anyhow', 'anyway', 'anywise', 'at all', 'at all events', 'at any rate', 'but'],
    'nevus': ['benign tumor', 'bilge', 'birthmark', 'blackhead', 'blain', 'blaze', 'bleb', 'blemish', 'blister', 'blob', 'blotch', 'boss'],
    'new': ['ab ovo', 'accessory', 'actual', 'added', 'additional', 'afresh', 'again', 'all the rage', 'all the thing', 'ancillary', 'anew', 'another'],
    'new birth': ['adoption', 'amendment', 'change of allegiance', 'change of heart', 'change of mind', 'circumcision', 'conversion', 'improvement', 'new life', 'palingenesis', 'palingenesy', 'reanimation'],
    'new england': ['dixie', 'dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'middle west', 'north', 'north central region', 'northeast', 'northwest', 'pacific northwest'],
    'new left': ['jacobinism', 'old left', 'anarchism', 'anarcho-syndicalism', 'criminal syndicalism', 'extreme left', 'extreme left wing', 'extremism', 'left-wing extremism', 'nihilism', 'radicalism', 'radicalization'],
    'new look': ['advance guard', 'avant-garde', 'bon ton', 'convention', 'custom', 'fashion', 'haute couture', 'high fashion', 'innovation', 'latest fad', 'latest fashion', 'latest wrinkle'],
    'new moon': ['artificial satellite', 'crescent', 'crescent moon', 'decrescent', 'decrescent moon', 'demilune', 'full moon', 'gibbous moon', 'half-moon', 'harvest moon', 'increscent', 'increscent moon'],
    'new to': ['a novice at', 'a stranger to', 'callow', 'disaccustomed', 'fresh', 'green', 'green as grass', 'ignorant', 'immature', 'inexperienced', 'raw', 'rusty'],
    'new world': ['africa', 'america', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'east', 'eastern hemisphere', 'eurasia', 'europe', 'far east'],
    'newborn': ['babe', 'babish', 'baby', 'babyish', 'bantling', 'bay', 'bearing', 'born', 'calved', 'cast', 'doll-like', 'dollish'],
    'newcomer': ['abecedarian', 'alien', 'alphabetarian', 'amateur', 'apprentice', 'arrival', 'arriviste', 'articled clerk', 'baby', 'beginner', 'boot', 'catechumen'],
    'newfashioned': ['a la mode', 'advanced', 'all the rage', 'all the thing', 'avant-garde', 'contemporary', 'current', 'far out', 'fashionable', 'forward-looking', 'hip', 'in'],
    'newly': ['ab ovo', 'afresh', 'again', 'anew', 'another time', 'as new', 'bis', 'de novo', 'encore', 'freshly', 'from scratch', 'lately'],
    'newness': ['authenticity', 'contemporaneity', 'contemporaneousness', 'creativeness', 'creativity', 'freshness', 'historical present', 'innovation', 'inventiveness', 'modernity', 'nonimitation', 'novelty'],
    'news': ['account', 'advice', 'announcement', 'bulletin', 'communication', 'communique', 'daily', 'daily newspaper', 'dirt', 'dispatch', 'dope', 'expose'],
    'news ticker': ['telautography', 'teletype', 'teletype network', 'teletyping', 'closed-circuit telegraphy', 'code', 'duplex telegraphy', 'electricity', 'facsimile telegraph', 'interrupter', 'key', 'multiplex telegraphy'],
    'newscast': ['beam', 'broadcast', 'canned show', 'commercial', 'commercial program', 'electrical transcription', 'network show', 'radiate', 'radio', 'radio fare', 'radiobroadcast', 'rebroadcast'],
    'newsletter': ['pastoral epistle', 'advice', 'aerogram', 'air letter', 'airgraph', 'billet-doux', 'broadcast journalism', 'bull', 'chain letter', 'dead letter', 'dimissorial', 'dimissory letter'],
    'newsman': ['city editor', 'columnist', 'copy chief', 'copy editor', 'copyman', 'copyreader', 'correspondent', 'cub reporter', 'diaskeuast', 'editor', 'editorial writer', 'feature editor'],
    'newsmonger': ['a tale-bearing animal', 'adviser', 'announcer', 'annunciator', 'authority', 'busybody', 'channel', 'communicant', 'communicator', 'enlightener', 'expert witness', 'gossip'],
    'newspaper': ['advice', 'broadcast journalism', 'daily', 'daily newspaper', 'extra', 'extra edition', 'gazette', 'information', 'intelligence', 'journalism', 'magazine', 'national newspaper'],
    'newspaperman': ['a tale-bearing animal', 'advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'busybody', 'city editor', 'coauthor', 'collaborator'],
    'newsreel': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'black-and-white film', 'cartoon', 'chiller', 'cinema', 'color film', 'creepie', 'documentary'],
    'newsy': ['accessible', 'all jaw', 'approachable', 'candid', 'chatty', 'communicative', 'conversable', 'conversational', 'demonstrative', 'effusive', 'expansive', 'extroverted'],
    'next': ['adjacent', 'adjoining', 'after', 'after all', 'after that', 'afterward', 'afterwards', 'appendant', 'behind', 'below', 'bordering', 'by'],
    'next of kin': ['agnate', 'ancestry', 'blood', 'blood relation', 'blood relative', 'clansman', 'cognate', 'collateral', 'collateral relative', 'connections', 'consanguinean', 'distaff side'],
    'next world': ['heaven', 'paradise', 'a better place', 'afterlife', 'afterworld', 'destiny', 'eternal home', 'fate', 'future state', 'home', 'life after death', 'life to come'],
    'nexus': ['indian file', 'array', 'articulation', 'bank', 'buzz', 'catena', 'catenation', 'chain', 'chain reaction', 'chaining', 'concatenation', 'connection'],
    'ng': ['cheap', 'good-for-naught', 'good-for-nothing', 'junk', 'junky', 'no-account', 'no-good', 'not worth having', 'not worth mentioning', 'not worthwhile', 'nugacious', 'nugatory'],
    'niacin': ['adermin', 'aneurin', 'antiberi-beri factor', 'ascorbic acid', 'axerophthol', 'biotin', 'carotene', 'cholecalciferol', 'choline', 'cobalamin', 'cryptoxanthin', 'cyanocobalamin'],
    'niagara': ['cascade', 'cataract', 'deluge', 'fall', 'falls', 'flood', 'force', 'fresh', 'freshet', 'linn', 'nappe', 'pour'],
    'nib': ['thule', 'ultima thule', 'aculeus', 'acumination', 'antlia', 'auger', 'beak', 'beezer', 'bill', 'bit', 'bitter end', 'borer'],
    'nibble': ['and sinker', 'be a sucker', 'be taken in', 'bite', 'bolus', 'champ', 'chaw', 'chew', 'chew the cud', 'chew up', 'chomp', 'cud'],
    'nibbling': ['appetite', 'cannibalism', 'carnivorism', 'carnivority', 'carnivorousness', 'chewing', 'consumption', 'cropping', 'deglutition', 'devouring', 'devourment', 'dieting'],
    'nice': ['christian', 'christlike', 'christly', 'according to hoyle', 'accurate', 'acute', 'advantageous', 'advertent', 'affable', 'affectionate', 'agog', 'agreeable'],
    'nicely': ['accurately', 'aright', 'benignantly', 'benignly', 'capitally', 'conscientiously', 'correctly', 'decently', 'decorously', 'exactingly', 'exactly', 'excellently'],
    'nicety': ['absoluteness', 'accuracy', 'acquired taste', 'appreciation', 'appreciation of differences', 'appreciation of excellence', 'appreciativeness', 'artistic judgment', 'attention to detail', 'attention to fact', 'care for truth', 'choiceness'],
    'niche': ['alcove', 'asylum', 'bay', 'bolt-hole', 'cache', 'carrel', 'concealment', 'corner', 'cove', 'cover', 'covert', 'coverture'],
    'nick': ['vandyke', 'appropriate', 'arrest', 'ascender', 'back', 'bastard type', 'beard', 'beat it', 'belly', 'bevel', 'birthmark', 'black letter'],
    'nicked': ['battlemented', 'chopped', 'crenate', 'crenated', 'crenellated', 'crenulate', 'dentate', 'dentated', 'embrasured', 'erose', 'gashed', 'incised'],
    'nickel': ['c-note', 'g-note', 'aureate', 'bar', 'brass', 'brassy', 'brazen', 'bronze', 'bronzy', 'buck', 'bullion', 'cartwheel'],
    'nickelodeon': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'nickname': ['affectionate name', 'agnomen', 'appellation', 'appellative', 'baptize', 'byname', 'byword', 'call', 'christen', 'cognomen', 'define', 'denominate'],
    'niece': ['aunt', 'auntie', 'blood brother', 'brethren', 'brother', 'bub', 'bubba', 'bud', 'buddy', 'country cousin', 'cousin', 'cousin once removed'],
    'nifty': ['ok', 'ace-high', 'agile', 'apt', 'bad', 'bang-up', 'bonzer', 'boss', 'braw', 'bully', 'but good', 'chic'],
    'niggard': ['silas marner', 'cheapskate', 'cheeseparing', 'churl', 'close', 'curmudgeon', 'grudging', 'mean', 'mingy', 'miser', 'miserly', 'muckworm'],
    'niggardly': ['lenten', 'spartan', 'abstemious', 'ascetic', 'austere', 'bountiful', 'cheeseparing', 'chinchy', 'chintzy', 'close', 'closefisted', 'closefistedly'],
    'nigger': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'niggle': ['adverse criticism', 'animadversion', 'aspersion', 'bad notices', 'bad press', 'bitch', 'bug', 'captiousness', 'carp', 'carp at', 'carping', 'cavil'],
    'niggling': ['mickey mouse', 'adverse criticism', 'advertent', 'agog', 'alert', 'all ears', 'all eyes', 'animadversion', 'annoying', 'aspersion', 'assiduous', 'attentive'],
    'nigh': ['about', 'all but', 'almost', 'along toward', 'approach', 'approaching', 'approximate', 'approximating', 'arm-in-arm', 'around', 'as good as', 'aside'],
    'night': ['egyptian darkness', 'erebus', 'all the time', 'all-night', 'blackness', 'ceaselessly', 'charcoal', 'coal', 'continually', 'continuously', 'crow', 'dark'],
    'night and day': ['north pole', 'south pole', 'always', 'antipodal points', 'antipodes', 'antipoints', 'antipoles', 'at all times', 'black and white', 'ceaselessly', 'consecutively', 'constantly'],
    'night blindness': ['lombardy leprosy', 'anemia', 'ariboflavinosis', 'beriberi', 'cachexia', 'chlorosis', 'day blindness', 'deficiency anemia', 'dermatitis', 'goiter', 'greensickness', 'hemeralopia'],
    'night spot': ['elizabethan theater', 'globe theatre', 'greek theater', 'amphitheater', 'amusement park', 'arena theater', 'auditorium', 'ballroom', 'cabaret', 'cafe', 'cafe chantant', 'cafe dansant'],
    'nightcap': ['mickey', 'mickey finn', 'anesthetic', 'aperitif', 'chaser', 'cocktail', 'doch-an-dorrach', 'drink', 'eye-opener', 'highball', 'hypnotic', 'knockout drops'],
    'nightclub': ['elizabethan theater', 'globe theatre', 'greek theater', 'alehouse', 'amphitheater', 'amusement park', 'arena theater', 'auditorium', 'ballroom', 'bar', 'barrel house', 'barroom'],
    'nightmare': ['dracula', 'frankenstein', 'wolf-man', 'bad dream', 'bogey', 'bogeyman', 'brown study', 'bugaboo', 'bugbear', 'clawing', 'cruciation', 'crucifixion'],
    'nightwalk': ['couch', 'crawl', 'creep', 'go on tiptoe', 'grovel', 'gumshoe', 'inch', 'inch along', 'lay wait', 'lie in wait', 'lurk', 'noctambulate'],
    'nightwalking': ['all fours', 'crawl', 'crawling', 'creep', 'creeping', 'gumshoeing', 'night-wandering', 'noctambulation', 'noctambulism', 'noctivagant', 'noctivagation', 'padding'],
    'nihilism': ['jacobinism', 'new left', 'old left', 'agnosia', 'anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism', 'block', 'blocking', 'chaos', 'confusion'],
    'nihilist': ['bolshevik', 'cassandra', 'eeyore', 'jacobin', 'wobbly', 'anarch', 'anarchist', 'anarcho-syndicalist', 'animal', 'annihilator', 'anthropophagite', 'antinomian'],
    'nihilistic': ['cassandra-like', 'cassandran', 'cassandrian', 'anarchial', 'anarchic', 'anarchistic', 'anarcho-syndicalist', 'antinomian', 'baneful', 'calamitous', 'cataclysmal', 'cataclysmic'],
    'nike': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'nimble': ['active', 'acute', 'adroit', 'agile', 'alacritous', 'alert', 'alive', 'apt', 'attentive', 'awake', 'brainy', 'breakneck'],
    'nimble footed': ['agile', 'breakneck', 'dashing', 'double-quick', 'eagle-winged', 'expeditious', 'express', 'fast', 'featly', 'fleet', 'flying', 'galloping'],
    'nimble witted': ['attic', 'adroit', 'apt', 'biting', 'brainy', 'bright', 'brilliant', 'canny', 'clever', 'dexterous', 'droll', 'facetious'],
    'nimbleness': ['acuity', 'acuteness', 'adroitness', 'agility', 'alacrity', 'alertness', 'aptitude', 'aptness', 'attention', 'attentiveness', 'braininess', 'brightness'],
    'nimbly': ['ably', 'adeptly', 'adroitly', 'agilely', 'aptly', 'artfully', 'artistically', 'brilliantly', 'capably', 'cleverly', 'competently', 'cunningly'],
    'nimbus': ['cloudcuckooland', 'alto-cumulus', 'alto-stratus', 'anthelion', 'antisun', 'anvil cloud', 'aura', 'aureole', 'banner cloud', 'billowy cloud', 'blaze of glory', 'brilliance'],
    'nimrod': ['archer', 'artilleryman', 'beater', 'big game hunter', 'bowman', 'cannoneer', 'carabineer', 'courser', 'crack shot', 'dead shot', 'deadeye', 'good shot'],
    'nincompoop': ['boeotian', 'ass', 'block', 'clod', 'dimwit', 'dolt', 'donkey', 'dope', 'dullard', 'dumb cluck', 'dumbbell', 'dummy'],
    'nine': ['nina from carolina', 'cast', 'company', 'complement', 'crew', 'eight', 'eleven', 'ennead', 'enneastyle', 'first string', 'first team', 'five'],
    'ninny': ['boeotian', 'ass', 'block', 'clod', 'dimwit', 'dolt', 'donkey', 'dope', 'dullard', 'dumb cluck', 'dumbbell', 'dummy'],
    'nip': ['abbreviate', 'abduct', 'abridge', 'abscind', 'absolute zero', 'abstract', 'acute pain', 'adhere to', 'afflict', 'agonize', 'ail', 'algidity'],
    'nip and tuck': ['alike', 'at par', 'au pair', 'commensurate', 'drawn', 'equal', 'equalized', 'even', 'even stephen', 'fifty-fifty', 'half-and-half', 'knotted'],
    'nipped': ['abbreviated', 'abridged', 'abstracted', 'bobbed', 'capsule', 'capsulized', 'clamped', 'clipped', 'compressed', 'concentrated', 'condensed', 'consolidated'],
    'nipper': ['bairn', 'bud', 'cherub', 'chick', 'chickabiddy', 'child', 'chit', 'claws', 'clutches', 'darling', 'digits', 'fangs'],
    'nipple': ['adjutage', 'bag', 'boobs', 'bosom', 'breast', 'breasts', 'brisket', 'bust', 'catheter', 'chest', 'crop', 'drainpipe'],
    'nippy': ['siberian', 'algid', 'arctic', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'boreal', 'brisk', 'brumal', 'burning'],
    'nirvana': ['buddha-field', 'canaan', 'civitas dei', 'ko', 'lethe', 'new jerusalem', 'zion', 'absentmindedness', 'anorexia', 'anorexia nervosa', 'ataraxia', 'ataraxy'],
    'nirvanic': ['asleep', 'blank', 'blankminded', 'calm', 'cataleptic', 'catatonic', 'cold', 'comatose', 'dead', 'desireless', 'doped', 'drugged'],
    'nit': ['adverse criticism', 'animadversion', 'aspersion', 'bad notices', 'bad press', 'captiousness', 'carping', 'cat flea', 'cavil', 'caviling', 'censoriousness', 'chigoe'],
    'nit picking': ['adverse criticism', 'animadversion', 'aspersion', 'bad notices', 'bad press', 'bickering', 'boggling', 'captiousness', 'carping', 'cavil', 'caviling', 'censoriousness'],
    'nitpick': ['around the bush', 'beat about', 'beg the question', 'bicker', 'boggle', 'carp', 'catch at straws', 'cavil', 'choplogic', 'cut up', 'dodge', 'equivocate'],
    'nitpicker': ['belittler', 'captious critic', 'carper', 'caviler', 'censor', 'censurer', 'common scold', 'critic', 'criticizer', 'equivocator', 'faultfinder', 'frondeur'],
    'nitrate': ['acetify', 'acidify', 'acidulate', 'alkalify', 'alkalize', 'ammonia', 'borate', 'carbonate', 'castor-bean meal', 'catalyze', 'chemical', 'chlorinate'],
    'nitration': ['acetification', 'acidification', 'acidulation', 'alkalization', 'carbonation', 'catalysis', 'chemicalization', 'electrolysis', 'ferment', 'fermentation', 'hydrogenation', 'isomerism'],
    'nitrogen': ['acetylene', 'ammonia', 'argon', 'asphyxiating gas', 'butane', 'carbon dioxide', 'carbon monoxide', 'castor-bean meal', 'chlorine', 'coal gas', 'commercial fertilizer', 'compost'],
    'nitty gritty': ['absolute fact', 'accepted fact', 'axiom', 'bald fact', 'bare fact', 'brutal fact', 'center', 'circumstance', 'cold fact', 'conceded fact', 'core', 'datum'],
    'nitwit': ['boeotian', 'block', 'clod', 'cluck', 'dimwit', 'dolt', 'donkey', 'dope', 'dullard', 'dumb cluck', 'dumbbell', 'dummy'],
    'nitwitted': ['beetleheaded', 'blockheaded', 'blunderheaded', 'boneheaded', 'brainless', 'cabbageheaded', 'chowderheaded', 'chuckleheaded', 'clodpated', 'dumbheaded', 'dunderheaded', 'fatheaded'],
    'nix': ['davy', 'davy jones', 'neptune', 'nereid', 'oceanid', 'oceanus', 'poseidon', 'thetis', 'triton', 'abnegation', 'aught', 'cipher'],
    'no': ['australian ballot', 'hare system', 'i refuse', 'i will not', 'abnegation', 'au contraire', 'aye', 'ballot', 'by no means', 'canvass', 'canvassing', 'casting vote'],
    'no account': ['ng', 'cheap', 'featherweight', 'forceless', 'good-for-naught', 'good-for-nothing', 'impotent', 'ineffective', 'ineffectual', 'inefficacious', 'junk', 'junky'],
    'no chance': ['absurdity', 'equivalent odds', 'even break', 'even chance', 'good chance', 'hopelessness', 'hundred-to-one shot', 'impossibility', 'impossible', 'impossibleness', 'inconceivability', 'long odds'],
    'no doubt': ['admittedly', 'beyond doubt', 'beyond question', 'by all odds', 'dollars to doughnuts', 'doubtless', 'doubtlessly', 'in all likelihood', 'in all probability', 'incontestably', 'indisputably', 'indubitably'],
    'no end': ['a deal', 'a fortiori', 'a great deal', 'a lot', 'above all', 'abundantly', 'acervatim', 'affluently', 'all the more', 'aplenty', 'as all creation', 'as all get-out'],
    'no go': ['aimless', 'bankruptcy', 'defeat', 'failure', 'feckless', 'futility', 'ill success', 'impossible', 'impotent', 'ineffective', 'ineffectual', 'losing game'],
    'no good': ['bowery bum', 'ng', 'beachcomber', 'beggar', 'beggarly fellow', 'blighter', 'budmash', 'bum', 'bummer', 'caitiff', 'cheap', 'derelict'],
    'no matter what': ['god forbid', 'anything soever which', 'au contraire', 'by no means', 'far from it', 'in no case', 'in no respect', 'in no wise', 'never', 'nohow', 'not at all', 'noway'],
    'no more': ['ago', 'all gone', 'annihilated', 'antiquated', 'antique', 'asleep', 'asleep in jesus', 'at rest', 'away', 'bereft of life', 'blown over', 'breathless'],
    'no no': ['eighteenth amendment', 'prohibition party', 'volstead act', 'ban', 'contraband', 'curse', 'cuss', 'cuss word', 'denial', 'dirty name', 'dirty word', 'disallowance'],
    'no way': ['acedia', 'apathy', 'cave of trophonius', 'cave of despair', 'despair', 'desperateness', 'desperation', 'despondency', 'disconsolateness', 'fat chance', 'forget it', 'forlornness'],
    'nobby': ['ok', 'ace-high', 'bad', 'bang-up', 'bonzer', 'boss', 'braw', 'bully', 'but good', 'chic', 'classy', 'clothes-conscious'],
    'nobility': ['babylonian splendor', 'ffvs', 'aedileship', 'ancienne noblesse', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'assured probity', 'augustness', 'authority', 'baronage'],
    'noble': ['babylonian', 'brahman', 'christian', 'corinthian', 'acclaimed', 'admirable', 'advantageous', 'archduke', 'aristocrat', 'aristocratic', 'armiger', 'august'],
    'noble minded': ['big', 'bighearted', 'chivalrous', 'elevated', 'exalted', 'generous', 'great', 'great of heart', 'greathearted', 'handsome', 'heroic', 'high'],
    'nobleman': ['brahman', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'blue blood', 'count', 'daimio', 'duke', 'earl', 'esquire'],
    'nobly': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'bigheartedly', 'blamelessly', 'chivalrously', 'conscientiously', 'conspicuously', 'copiously'],
    'nobody': ['a nobody', 'a nothing', 'cipher', 'common man', 'dud', 'dummy', 'figurehead', 'hollow man', 'insignificancy', 'jackstraw', 'lay figure', 'lightweight'],
    'nocturne': ['nachtmusik', 'absolute music', 'adaptation', 'air varie', 'aleatory', 'aleatory music', 'arrangement', 'chamber music', 'chamber orchestra', 'composition', 'descant', 'electronic music'],
    'nod': ['john hancock', 'ok', 'roman candle', 'abide by', 'accede', 'accede to', 'accept', 'acceptance', 'acclaim', 'accord to', 'accost', 'acquiesce'],
    'nodding': ['absent', 'absentminded', 'absorbed', 'abstracted', 'anesthetized', 'asleep', 'bagging', 'baggy', 'ballooning', 'bemused', 'castle-building', 'casual'],
    'noddle': ['bean', 'belfry', 'brain', 'brow', 'conk', 'crown', 'dome', 'encephalon', 'gray matter', 'head', 'headpiece', 'noggin'],
    'node': ['gordian knot', 'amplitude', 'antinode', 'block', 'body', 'cake', 'clump', 'cluster', 'concrete', 'concretion', 'conglomerate', 'conglomeration'],
    'nodular': ['burled', 'gnarled', 'gnarly', 'knobbed', 'knobbly', 'knobby', 'knoblike', 'knotted', 'knotty', 'knurled', 'knurly', 'lumpy'],
    'noel': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'nativity', 'volkslied', 'alba', 'anthem', 'art song', 'aubade', 'ballad', 'ballade'],
    'noetic': ['bright', 'cerebral', 'cogitative', 'cognitive', 'concentrating', 'concentrative', 'conceptive', 'conceptual', 'conceptualized', 'contemplating', 'contemplative', 'deliberating'],
    'noggin': ['bean', 'brain', 'brow', 'chump', 'conk', 'crown', 'dome', 'encephalon', 'gray matter', 'head', 'headpiece', 'noddle'],
    'nohow': ['god forbid', 'anyhow', 'anyway', 'anywise', 'at all', 'at any rate', 'at no hand', 'au contraire', 'by any means', 'by no means', 'far from it', 'however'],
    'noise': ['algol', 'aesopian language', 'babel', 'bedlam let loose', 'cobol', 'edp', 'fortran', 'greek', 'aimlessness', 'alphabetic data', 'alphanumeric code', 'amplitude'],
    'noiseless': ['damped', 'dampened', 'deadened', 'echoless', 'hush', 'hush as death', 'hushed', 'inaudible', 'mousy', 'muffled', 'mute', 'muted'],
    'noiseproof': ['airtight', 'ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'corrosionproof', 'dampproof', 'fire-resisting', 'fireproof', 'flameproof', 'foolproof', 'hermetic'],
    'noisome': ['abhorrent', 'abominable', 'arrant', 'atrocious', 'awful', 'bad', 'bad for', 'bad-smelling', 'baleful', 'baneful', 'barfy', 'base'],
    'noisy': ['bawling', 'blaring', 'blasting', 'blatant', 'blatting', 'blustering', 'blusterous', 'blustery', 'boanergean', 'boisterous', 'brassy', 'brawling'],
    'nomad': ['arab', 'bedouin', 'bohemian', 'romany', 'zigeuner', 'circumforaneous', 'discursive', 'divagatory', 'drifting', 'errant', 'flitting', 'floating'],
    'nomadism': ['wanderjahr', 'afoot and lighthearted', 'bumming', 'discursion', 'divagation', 'drifting', 'errantry', 'flitting', 'gadding', 'hoboism', 'itineracy', 'itinerancy'],
    'nomen': ['agnomen', 'appellation', 'appellative', 'binomen', 'binomial name', 'byword', 'cognomen', 'cryptonym', 'denomination', 'designation', 'empty title', 'epithet'],
    'nominal': ['abstract noun', 'adherent noun', 'adjectival', 'adverbial', 'alleged', 'apparent', 'attributive', 'budget', 'byname', 'cheap', 'cognominal', 'collective noun'],
    'nominalism': ['differentiation', 'differentness', 'distinctiveness', 'egohood', 'human factor', 'identity', 'individualism', 'individuality', 'integrity', 'nonconformity', 'oneness', 'particularism'],
    'nominally': ['apparently', 'artificially', 'at a bargain', 'at a sacrifice', 'at budget prices', 'at cost', 'at cost price', 'at piggy-bank prices', 'at prime cost', 'at reduced rates', 'at small cost', 'at wholesale'],
    'nominate': ['appoint', 'assign', 'back', 'back up', 'baptize', 'call', 'choose', 'christen', 'define', 'denominate', 'designate', 'dub'],
    'nominated': ['accepted', 'adopted', 'appointed', 'approved', 'carried', 'chosen', 'designated', 'elect', 'elected', 'elected by acclamation', 'embraced', 'espoused'],
    'nomination': ['acceptance speech', 'apostolic orders', 'appointment', 'assignment', 'calling', 'canonization', 'caucus nomination', 'conferment', 'consecration', 'designation', 'direct nomination', 'election'],
    'nominative': ['abessive', 'ablative', 'accusative', 'adessive', 'allative', 'appellative', 'approximative', 'byname', 'case', 'cognominal', 'common case', 'dative'],
    'non compos mentis': ['abnormal', 'bereft of reason', 'brainsick', 'crackbrained', 'cracked', 'crazed', 'crazy', 'daft', 'deluded', 'demented', 'deprived of reason', 'deranged'],
    'non sequitur': ['argument', 'argument by analogy', 'argumentum ad baculum', 'argumentum ad captandum', 'argumentum ad hominem', 'bad case', 'begging the question', 'broken thread', 'brokenness', 'circular argument', 'claptrap', 'crowd-pleasing argument'],
    'nonacceptance': ['abjuration', 'abjurement', 'abnegation', 'chucking', 'chucking out', 'contempt', 'contradiction', 'declension', 'declination', 'declinature', 'declining', 'denial'],
    'nonadherent': ['aloof', 'broken', 'detached', 'disconnected', 'discontinuous', 'discrete', 'disregardful', 'gapped', 'inattentive', 'incoherent', 'inconsistent', 'inconstant'],
    'nonadmission': ['ban', 'bar', 'barring', 'blockade', 'boycott', 'circumscription', 'debarment', 'debarring', 'demarcation', 'embargo', 'exception', 'exclusion'],
    'nonage': ['nina from carolina', 'callowness', 'dewiness', 'ennead', 'enneastyle', 'freshness', 'greenness', 'immaturity', 'inexperience', 'infancy', 'juiciness', 'juniority'],
    'nonagenarian': ['father time', 'methuselah', 'nestor', 'old paar', 'sexagesima', 'boxcar', 'boxcars', 'centenarian', 'dotard', 'dozen', 'duodecimo', 'eighty'],
    'nonaggressive': ['bone-lazy', 'cadging', 'civilian', 'conciliatory', 'dilatory', 'do-nothing', 'doless', 'dovish', 'dronish', 'drony', 'easy', 'ergophobic'],
    'nonaligned': ['laodicean', 'apathetic', 'autarchic', 'autarkic', 'autonomous', 'centrist', 'even', 'fifty-fifty', 'free-spirited', 'freewheeling', 'half-and-half', 'impartial'],
    'nonattendance': ['awol', 'french leave', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'cut', 'day off', 'default', 'departure'],
    'nonattendant': ['absconded', 'absent', 'away', 'deleted', 'departed', 'disappeared', 'gone', 'lacking', 'missing', 'no longer present', 'nonexistent', 'not found'],
    'nonce': ['contemporaneity', 'contemporaneousness', 'historical present', 'modernity', 'newness', 'now', 'nowadays', 'nowness', 'our times', 'present', 'present tense', 'presentness'],
    'nonchalance': ['accidia', 'acedia', 'aloofness', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'carelessness', 'casualness', 'comatoseness'],
    'nonchalant': ['laodicean', 'olympian', 'aloof', 'apathetic', 'at ease', 'ataractic', 'benumbed', 'blah', 'blase', 'calm', 'careless', 'casual'],
    'noncoherent': ['aloof', 'broken', 'detached', 'disconnected', 'discontinuous', 'discrete', 'gapped', 'incoherent', 'inconsistent', 'nonadherent', 'nonadhesive', 'noncohesive'],
    'noncohesive': ['aloof', 'apart', 'asunder', 'bipartite', 'broken', 'detached', 'dichotomous', 'disconnected', 'discontinuous', 'discrete', 'distinct', 'divergent'],
    'noncom': ['nco', 'acting corporal', 'acting sergeant', 'centurion', 'chief warrant officer', 'color sergeant', 'corporal', 'first sergeant', 'havildar', 'lance corporal', 'lance sergeant', 'master sergeant'],
    'noncombatant': ['citizen', 'civilian', 'conciliatory', 'dovish', 'irenic', 'nonaggressive', 'nonbelligerent', 'nonmilitant', 'nonresistant', 'nonresister', 'nonviolent', 'pacific'],
    'noncommissioned officer': ['big brother', 'nco', 'acting corporal', 'acting sergeant', 'auditor', 'boatswain', 'boss', 'buck private', 'centurion', 'chief', 'chief warrant officer', 'color sergeant'],
    'noncommittal': ['canny', 'careful', 'cautious', 'circumspect', 'constrained', 'cool', 'deliberate', 'discreet', 'gingerly', 'guarded', 'heedful', 'hesitant'],
    'noncommitted': ['laodicean', 'apathetic', 'centrist', 'even', 'fifty-fifty', 'half-and-half', 'impartial', 'independent', 'indifferent', 'midway', 'moderate', 'neuter'],
    'noncommunicable': ['inalienable', 'incommunicable', 'indefeasible', 'indefinable', 'indescribable', 'ineffable', 'inenarrable', 'inexpressible', 'innominable', 'noncontagious', 'noninfectious', 'undefinable'],
    'noncompetitive': ['coacting', 'coactive', 'coadjutant', 'coadjuvant', 'coefficient', 'collaborative', 'collective', 'collectivist', 'collectivistic', 'collusive', 'combined', 'commensal'],
    'noncompletion': ['sisyphean labor', 'endless task', 'failure', 'inexecution', 'loose ends', 'neglect', 'nonaccomplishment', 'nonachievement', 'nonconsummation', 'nondischarging', 'nonexecution', 'nonfeasance'],
    'noncompliance': ['abnegation', 'civil disobedience', 'contradiction', 'contrariety', 'declension', 'declination', 'declinature', 'declining', 'default', 'delinquency', 'denial', 'deprivation'],
    'nonconforming': ['alienated', 'antiestablishment', 'at odds with', 'at variance with', 'breakaway', 'contrary', 'counter-culture', 'deviant', 'differing', 'disagreeing', 'disobedient', 'disregardful'],
    'nonconformist': ['albigensian', 'arian', 'bohemian', 'cathar', 'donatist', 'ebionite', 'erastian', 'gnostic', 'jansenist', 'lollard', 'manichaean', 'monophysite'],
    'nonconformity': ['aberration', 'abnormality', 'agreement to disagree', 'alienage', 'alienation', 'alienism', 'ambiguity', 'ambivalence', 'anomaly', 'antagonism', 'antinomy', 'antipathy'],
    'nonconvergent': ['aligned', 'analogous', 'coextending', 'coextensive', 'collateral', 'concurrent', 'equal', 'equidistant', 'equispaced', 'even', 'lined up', 'nondivergent'],
    'noncooperative': ['adversary', 'adversative', 'adverse', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'clashing', 'competitive', 'complaining', 'con'],
    'nondenominational': ['all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'allover', 'catholic', 'cosmopolitan'],
    'nondescript': ['attic', 'amorphic', 'amorphous', 'anarchic', 'baggy', 'bland', 'blobby', 'blurred', 'blurry', 'chaotic', 'characterless', 'chaste'],
    'none': ['from scratch', 'in no way', 'nary one', 'never a one', 'nil', 'no', 'no man', 'no one', 'nobody', 'not a bit', 'not a hint', 'not a jot'],
    'nonelastic': ['adamant', 'adamantine', 'immovable', 'immutable', 'inductile', 'inelastic', 'inextensible', 'inextensile', 'inextensional', 'inflexible', 'intractable', 'intractile'],
    'nonemotional': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity', 'cold-blooded', 'coldhearted'],
    'nonentity': ['middle america', 'milquetoast', 'a nobody', 'a nothing', 'absence', 'baby', 'big baby', 'bourgeoisie', 'burgherdom', 'chicken', 'cipher', 'common man'],
    'nonessential': ['accessory', 'accident', 'accidental', 'addendum', 'addition', 'additional', 'adjunct', 'adrift', 'adscititious', 'adventitious', 'aleatory', 'appendage'],
    'nonesuch': ['abnormality', 'amazement', 'anomaly', 'astonishing thing', 'astonishment', 'champion', 'choice', 'chosen', 'conversation piece', 'cream', 'curio', 'curiosity'],
    'nonetheless': ['after all', 'again', 'albeit', 'all the same', 'although', 'anyhow', 'anyway', 'anywise', 'at all', 'at all events', 'at any rate', 'but'],
    'nonexistent': ['absconded', 'absent', 'away', 'deleted', 'departed', 'devoid', 'disappeared', 'existless', 'extinct', 'fancied', 'fictive', 'gone'],
    'nonfeasance': ['sisyphean labor', 'atrocity', 'bad policy', 'breach', 'crime', 'crime against humanity', 'culpa', 'culpable negligence', 'deadly sin', 'default', 'delinquency', 'dereliction'],
    'nonfertile': ['acarpous', 'arid', 'barren', 'celibate', 'childless', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'exhausted', 'fallow'],
    'nonfiction': ['article', 'autograph', 'brainchild', 'composition', 'computer printout', 'copy', 'document', 'draft', 'edited version', 'engrossment', 'essay', 'fair copy'],
    'nonfulfillment': ['sisyphean labor', 'default', 'delinquency', 'dereliction', 'disconformity', 'disregard', 'endless task', 'failure', 'falling short', 'inadequacy', 'inadequateness', 'inattention'],
    'nonfunctional': ['functionless', 'impractical', 'in disrepair', 'inapplicable', 'inoperable', 'inoperative', 'nonutilitarian', 'otiose', 'out of order', 'out of whack', 'unconducive', 'unemployable'],
    'nonintellectual': ['gothic', 'philistine', 'barbarous', 'bookless', 'deceived', 'functionally illiterate', 'grammarless', 'heathen', 'hoodwinked', 'ill-educated', 'illiterate', 'led astray'],
    'noninterference': ['autarky', 'bimetallism', 'capitalism', 'culpa', 'culpable negligence', 'default', 'dereliction', 'disregard', 'economic self-sufficiency', 'failure', 'free competition', 'free enterprise'],
    'noninterruption': ['ceaselessness', 'chattering', 'constancy', 'constant flow', 'continualness', 'continuity', 'incessancy', 'oscillation', 'perpetuity', 'pulsation', 'quick fire', 'rapid fire'],
    'nonintervention': ['autarky', 'avoidance', 'avoiding reaction', 'bimetallism', 'capitalism', 'circumvention', 'defense mechanism', 'dodge', 'duck', 'economic self-sufficiency', 'elusion', 'elusiveness'],
    'noninvolvement': ['a wise passiveness', 'abstention', 'anythingarianism', 'avoidance', 'avoiding reaction', 'circumvention', 'contemplation', 'contemplative life', 'cop-out', 'defense mechanism', 'do-nothing policy', 'do-nothingism'],
    'nonliving': ['abiotic', 'azoic', 'dumb', 'exanimate', 'inanimate', 'inanimated', 'inert', 'insensate', 'insensible', 'insentient', 'lifeless', 'mute'],
    'nonmandatory': ['arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'offered', 'optional', 'proffered'],
    'nonobjective': ['antiblack', 'biased', 'chauvinistic', 'colored', 'doctrinaire', 'dogmatic', 'influenced', 'interested', 'jaundiced', 'know-nothing', 'one-sided', 'opinionated'],
    'nonobservance': ['laodiceanism', 'abnegation', 'absentmindedness', 'carelessness', 'contradiction', 'contrariety', 'declension', 'declination', 'declinature', 'declining', 'denial', 'deprivation'],
    'nonobservant': ['laodicean', 'contrary', 'deviant', 'disregardful', 'dissenting', 'dissident', 'inattentive', 'inconstant', 'indevotional', 'indevout', 'indifferent', 'indifferentist'],
    'nonoccupancy': ['bareness', 'barrenness', 'blankness', 'bleakness', 'desertedness', 'desolateness', 'emptiness', 'hollowness', 'inanition', 'noninhabitance', 'nonoccupance', 'nonresidence'],
    'nonoccurrence': ['absence', 'awayness', 'blank', 'deprivation', 'emptiness', 'lack', 'negation', 'negativeness', 'negativity', 'neverness', 'nihility', 'nonbeing'],
    'nonopposing': ['abject', 'accepting', 'acquiescent', 'agreeable', 'assenting', 'complaisant', 'compliable', 'compliant', 'complying', 'consenting', 'nondissenting', 'nonresistant'],
    'nonopposition': ['acceptance', 'acquiescence', 'assent', 'complaisance', 'compliance', 'consent', 'deference', 'homage', 'kneeling', 'nonopposal', 'nonresistance', 'obedience'],
    'nonpareil': ['a per se', 'ace', 'beau ideal', 'boss', 'champion', 'chief', 'choice', 'chosen', 'commander', 'cream', 'dean', 'elect'],
    'nonparticipation': ['a wise passiveness', 'contemplation', 'contemplative life', 'do-nothing policy', 'do-nothingism', 'do-nothingness', 'dormancy', 'idleness', 'immobility', 'inaction', 'inactivity', 'indolence'],
    'nonpartisan': ['laodicean', 'anythingarian', 'apathetic', 'autarchic', 'autarkic', 'autonomous', 'centrist', 'equitable', 'even', 'fence-sitter', 'fifty-fifty', 'free lance'],
    'nonperformance': ['sisyphean labor', 'culpa', 'culpable negligence', 'default', 'delinquency', 'dereliction', 'disconformity', 'disregard', 'endless task', 'failure', 'inadvertence', 'inadvertency'],
    'nonperishable': ['deathless', 'immortal', 'imperishable', 'impregnable', 'incorruptible', 'indelible', 'indestructible', 'ineffaceable', 'ineradicable', 'inexpugnable', 'inextinguishable', 'invincible'],
    'nonpermanent': ['brittle', 'capricious', 'changeable', 'corruptible', 'deciduous', 'dying', 'ephemeral', 'evanescent', 'fading', 'fickle', 'fleeting', 'flitting'],
    'nonphysical': ['airy', 'asomatous', 'astral', 'bodiless', 'decarnate', 'decarnated', 'discarnate', 'disembodied', 'ethereal', 'extramundane', 'ghostly', 'immaterial'],
    'nonplus': ['gordian knot', 'abecedarian', 'addle', 'amaze', 'answer', 'answer conclusively', 'argue down', 'astonish', 'astound', 'baffle', 'bafflement', 'balk'],
    'nonplussed': ['addled', 'at a loss', 'at a nonplus', 'at a stand', 'at a standstill', 'at an impasse', 'baffled', 'bamboozled', 'beat', 'bewildered', 'buffaloed', 'confounded'],
    'nonpolluted': ['bleached', 'bright', 'clean', 'cleanly', 'dainty', 'dirt-free', 'fair', 'fastidious', 'fresh', 'immaculate', 'kosher', 'of cleanly habits'],
    'nonporous': ['close', 'close-knit', 'close-textured', 'close-woven', 'compact', 'compacted', 'compressed', 'concentrated', 'concrete', 'condensed', 'congested', 'consolidated'],
    'nonproductive': ['acarpous', 'arid', 'barren', 'celibate', 'childless', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'exhausted', 'fallow'],
    'nonrecognition': ['benefits forgot', 'blindness', 'deafness', 'grudging thanks', 'halfhearted thanks', 'incognizance', 'incomprehension', 'ingratitude', 'insensibility', 'mindlessness', 'nonacknowledgment', 'nonrealization'],
    'nonreligious': ['laodicean', 'civil', 'congregational', 'godless', 'indevotional', 'indevout', 'indifferent', 'indifferentist', 'laic', 'laical', 'lay', 'lukewarm'],
    'nonresistance': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'quakerism', 'truman doctrine', 'a wise passiveness', 'acceptance', 'acquiescence', 'amenability', 'appeasement', 'assent', 'balance of power'],
    'nonresistive': ['abject', 'accepting', 'acquiescent', 'agreeable', 'assenting', 'complaisant', 'compliable', 'compliant', 'complying', 'consenting', 'delicate', 'easy'],
    'nonrestrictive': ['broad-minded', 'culpably negligent', 'derelict', 'freethinking', 'inadvertent', 'inattentive', 'laissez-faire', 'latitudinarian', 'lax', 'liberal', 'libertarian', 'libertine'],
    'nonreturnable': ['changeless', 'constant', 'immutable', 'incommutable', 'inconvertible', 'indefeasible', 'inert', 'insusceptible of change', 'intransmutable', 'invariable', 'irretrievable', 'irreversible'],
    'nonsectarian': ['all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'allover', 'catholic', 'cosmopolitan'],
    'nonsense': ['greek', 'absurdity', 'absurdness', 'amphigory', 'antics', 'applesauce', 'babble', 'babblement', 'balderdash', 'baloney', 'bibble-babble', 'bilge'],
    'nonsense talk': ['babble', 'babblement', 'bavardage', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather', 'blether', 'blethers', 'cackle', 'caquet'],
    'nonsensical': ['pickwickian', 'absurd', 'asinine', 'askew', 'beyond belief', 'bizarre', 'cockamamie', 'crazy', 'dumb', 'extravagant', 'fantastic', 'fool'],
    'nonspecific': ['abstract', 'aleatoric', 'aleatory', 'amorphous', 'bland', 'blobby', 'blurred', 'blurry', 'broad', 'chance', 'chancy', 'chaotic'],
    'nonspiritual': ['adamic', 'circean', 'animal', 'animalistic', 'beastlike', 'beastly', 'bestial', 'bodily', 'brutal', 'brute', 'brutish', 'carnal'],
    'nonstop': ['ageless', 'articulated', 'catenated', 'ceaseless', 'coeternal', 'concatenated', 'connected', 'constant', 'continual', 'continued', 'continuing', 'continuous'],
    'nonuniform': ['able to adapt', 'adaptable', 'adjustable', 'aimless', 'alterable', 'alterative', 'amorphous', 'broken', 'broken off', 'capricious', 'careening', 'casual'],
    'nonuniformity': ['proteus', 'adaptability', 'adjustability', 'allotropism', 'allotropy', 'alterability', 'arrhythmia', 'asperity', 'asymmetry', 'bad copy', 'bad likeness', 'broken thread'],
    'nonunion': ['abstraction', 'alienation', 'detachment', 'disarticulation', 'disassociation', 'disconnectedness', 'disconnection', 'discontinuity', 'disengagement', 'disjointing', 'disjunction', 'dislocation'],
    'nonviable': ['bad', 'despaired of', 'done for', 'dying', 'expiring', 'facing death', 'given up', 'going', 'hopeless', 'in articulo mortis', 'in extremis', 'incapable of life'],
    'nonviolence': ['a wise passiveness', 'abnegation', 'abstinence', 'calm', 'calmness', 'conservatism', 'constraint', 'contemplation', 'contemplative life', 'continence', 'control', 'cool'],
    'nonviolent': ['bland', 'civilian', 'conciliatory', 'dovish', 'gentle', 'irenic', 'judicious', 'mild', 'mild as milk', 'moderate', 'nonaggressive', 'noncombatant'],
    'nonworker': ['beggar', 'bummer', 'cadger', 'coupon clippers', 'drone', 'freeloader', 'idle rich', 'leisure class', 'lounge lizard', 'lumpen proletariat', 'mendicant', 'moocher'],
    'noodle': ['italian paste', 'bean', 'belfry', 'brain', 'brow', 'chowderhead', 'chucklehead', 'chump', 'conk', 'crown', 'dome', 'dope'],
    'nook': ['alcove', 'angle', 'apex', 'asylum', 'bay', 'bend', 'bifurcation', 'bight', 'bolt-hole', 'cache', 'cant', 'carrel'],
    'noon': ['acme', 'apex', 'apogee', 'brow', 'cap', 'capstone', 'climax', 'cloud nine', 'crest', 'crown', 'culmen', 'culmination'],
    'noose': ['allure', 'and quarter', 'annular muscle', 'annulus', 'areola', 'aureole', 'ax', 'bag', 'bait', 'bait the hook', 'birdlime', 'block'],
    'noosphere': ['geistesgeschichte', 'hegelian idea', 'kantian idea', 'platonic form', 'platonic idea', 'aerosphere', 'all that lives', 'archetype', 'atmosphere', 'biochore', 'biocycle', 'biosphere'],
    'norm': ['procrustean law', 'ten commandments', 'weltanschauung', 'zeitgeist', 'average', 'axiology', 'balance', 'barometer', 'behavioral norm', 'benchmark', 'business ethics', 'canon'],
    'normal': ['academe', 'academia', 'accepted', 'according to hoyle', 'air line', 'all there', 'alma mater', 'appropriate', 'arranged', 'average', 'axis', 'azimuth circle'],
    'normal school': ['academe', 'academia', 'alma mater', 'college', 'college of engineering', 'community college', 'degree-granting institution', 'four-year college', 'graduate school', 'institute of technology', 'ivied halls', 'journalism school'],
    'normality': ['appropriateness', 'averageness', 'balance', 'commonality', 'commonness', 'commonplaceness', 'contact with reality', 'conventionality', 'correctitude', 'correctness', 'currency', 'decencies'],
    'normalize': ['adjust', 'arrange', 'array', 'assimilate to', 'balance', 'chart', 'codify', 'conform', 'control', 'cool off', 'coordinate', 'damp'],
    'normally': ['accustomedly', 'all in all', 'all things considered', 'altogether', 'as a rule', 'as a whole', 'as an approximation', 'as is usual', 'as per usual', 'as things go', 'as usual', 'at large'],
    'normative': ['according to hoyle', 'accustomed', 'appropriate', 'average', 'common', 'commonplace', 'condign', 'conventional', 'correct', 'current', 'customary', 'decent'],
    'north': ['dixie', 'dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'middle west', 'new england', 'north central region', 'northeast', 'northwest', 'pacific northwest'],
    'north pole': ['alaska', 'antarctic zone', 'antarctica', 'arctic circle', 'arctic zone', 'china', 'darkest africa', 'frigid zones', 'god knows where', 'greenland', 'iceland', 'lower slobbovia'],
    'north star': ['aldebaran', 'canicula', 'dog star', 'hesper', 'hesperus', 'lucifer', 'phosphor', 'phosphorus', 'polaris', 'sirius', 'venus', 'vesper'],
    'north wind': ['euroclydon', 'tehuantepec wind', 'tehuantepecer', 'bise', 'east wind', 'easter', 'easterly', 'gregale', 'levanter', 'mistral', 'northeaster', 'norther'],
    'northeast': ['dixie', 'dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'middle west', 'ne by n', 'nne', 'new england', 'north', 'north central region'],
    'norther': ['euroclydon', 'tehuantepec wind', 'tehuantepecer', 'bise', 'east wind', 'easter', 'easterly', 'gregale', 'levanter', 'mistral', 'north wind', 'northeaster'],
    'northerly': ['antarctic', 'arctic', 'austral', 'boreal', 'east', 'eastbound', 'easterly', 'eastermost', 'eastern', 'easternmost', 'hyperborean', 'meridional'],
    'northern': ['antarctic', 'arctic', 'austral', 'boreal', 'east', 'eastbound', 'easterly', 'eastermost', 'eastern', 'easternmost', 'hyperborean', 'meridional'],
    'northward': ['cardinal points', 'compass card', 'compass rose', 'degrees', 'east', 'eastward', 'half points', 'lubber line', 'north', 'north about', 'northeast', 'northerly'],
    'northwest': ['dixie', 'dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'middle west', 'nnw', 'nw', 'nw by n', 'nw by w', 'new england'],
    'northwesterly': ['nnw', 'nw', 'nw by n', 'nw by w', 'antarctic', 'arctic', 'austral', 'boreal', 'east', 'eastbound', 'easterly', 'eastermost'],
    'nose': ['adamite', 'paul pry', 'paul-pry', 'antlia', 'aptness', 'beak', 'beezer', 'being', 'bent', 'bib nozzle', 'bill', 'body'],
    'nose around': ['be curious', 'beat the bushes', 'burn with curiosity', 'burrow', 'delve', 'dig', 'dig around for', 'dig up', 'explore', 'forage', 'frisk', 'gape'],
    'nose count': ['account', 'accounts', 'agenda', 'beadroll', 'body count', 'cadastre', 'calendar', 'capitulation', 'census', 'census report', 'checklist', 'checkroll'],
    'nose dive': ['acrobatics', 'aerobatics', 'banking', 'beat down', 'belly buster', 'belly flop', 'belly whopper', 'break', 'breakdown', 'cannonball', 'chandelle', 'cheapen'],
    'nose ring': ['anklet', 'armlet', 'band', 'bangle', 'beads', 'belt', 'bijou', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet'],
    'nose tickling': ['acerbic', 'acid', 'acrid', 'asperous', 'astringent', 'biting', 'bitter', 'caustic', 'cutting', 'escharotic', 'harsh', 'irritating'],
    'nosegay': ['aroma', 'bale', 'balminess', 'bindle', 'bolt', 'boughpot', 'bouquet', 'boutonniere', 'budget', 'bundle', 'buttonhole', 'chaplet'],
    'nostalgia': ['heimweh', 'aching', 'bathos', 'bleeding heart', 'cloyingness', 'daydream', 'daydreaming', 'desiderium', 'goo', 'hankering', 'hearts-and-flowers', 'homesickness'],
    'nostalgic': ['bathetic', 'beery', 'cloying', 'gooey', 'gushing', 'hankering', 'homesick', 'honing', 'languishing', 'longing', 'maudlin', 'mawkish'],
    'nostril': ['air duct', 'air hole', 'air passage', 'air shaft', 'air tube', 'airway', 'antlia', 'beak', 'beezer', 'bill', 'blowhole', 'breathing hole'],
    'nosy': ['busy', 'busybody', 'curious', 'delving', 'digging', 'eavesdropping', 'fishing', 'forward', 'impertinent', 'in search of', 'inquisitive', 'inquisitorial'],
    'not a bit': ['at no hand', 'by no means', 'in no case', 'in no respect', 'in no wise', 'nary one', 'never', 'never a one', 'nohow', 'none', 'not a hint', 'not a jot'],
    'not accept': ['abjure', 'assert the contrary', 'be skeptical', 'belie', 'brook no', 'contest', 'contradict', 'contravene', 'controvert', 'counter', 'cross', 'deny'],
    'not admit': ['abjure', 'assert the contrary', 'belie', 'contest', 'contradict', 'contravene', 'controvert', 'counter', 'cross', 'deny', 'disaffirm', 'disallow'],
    'not all there': ['abnormal', 'arrested', 'babbling', 'backward', 'bereft of reason', 'blithering', 'brainsick', 'burbling', 'crackbrained', 'cracked', 'crazed', 'crazy'],
    'not at all': ['god forbid', 'at no hand', 'at no time', 'au contraire', 'by no means', 'far from it', 'from scratch', 'in no case', 'in no respect', 'in no way', 'in no wise', 'never'],
    'not bad': ['ok', 'acceptable', 'adequate', 'admissible', 'all right', 'better than nothing', 'decent', 'fair', 'fairish', 'good enough', 'goodish', 'moderate'],
    'not budge': ['balk', 'be a sideliner', 'be still', 'be unflappable', 'coast', 'delay', 'die hard', 'do nothing', 'drift', 'get home free', 'hang fire', 'hibernate'],
    'not buy': ['be unmoved', 'be unwilling', 'beg off', 'decline', 'decline to accept', 'deny', 'disagree', 'disallow', 'disbelieve', 'disclaim', 'discredit', 'dissent'],
    'not care for': ['abhor', 'be caught napping', 'be hostile to', 'be neglectful', 'be negligent', 'default', 'disapprove of', 'disfavor', 'dislike', 'disregard', 'disrelish', 'fail'],
    'not comparable': ['base', 'deficient', 'imperfect', 'inadequate', 'incommensurable', 'incommensurate', 'incomparable', 'incompetent', 'insufficient', 'little', 'maladroit', 'mean'],
    'not compare': ['be found wanting', 'be inferior', 'bear no resemblance', 'come short', 'differ', 'fail', 'fall short', 'follow', 'have nothing on', 'not approach', 'not come near', 'not compare with'],
    'not cricket': ['bohemian', 'beat', 'below the belt', 'breakaway', 'far out', 'foul', 'free and easy', 'fringy', 'heretical', 'heterodox', 'hippie', 'informal'],
    'not done': ['bohemian', 'aberrant', 'abnormal', 'abominable', 'atrocious', 'beat', 'breakaway', 'criminal', 'delinquent', 'deviant', 'disgraceful', 'evil'],
    'not easy': ['herculean', 'abstruse', 'adverse', 'antagonistic', 'arduous', 'brutal', 'complex', 'conflicting', 'contrary', 'counter', 'counteractive', 'critical'],
    'not guilty': ['angelic', 'blameless', 'childlike', 'clear', 'dovelike', 'faultless', 'guiltless', 'in the clear', 'incorrupt', 'innocent', 'lamblike', 'offenseless'],
    'not hesitate': ['acquiesce', 'agree', 'be agreeable to', 'be dying to', 'be eager', 'be game', 'be open to', 'be ready', 'be spoiling for', 'be willing', 'carry through', 'collaborate'],
    'not kosher': ['bohemian', 'amoral', 'beat', 'breakaway', 'conscienceless', 'corrupt', 'corrupted', 'criminal', 'crooked', 'dark', 'devious', 'dishonest'],
    'not listen': ['be blind to', 'be caught out', 'be inattentive', 'be unwary', 'blink at', 'break the law', 'care naught for', 'connive at', 'defy', 'disobey', 'disregard', 'flout'],
    'not mind': ['break the law', 'care naught for', 'care nothing for', 'defy', 'disobey', 'disregard', 'flout', 'go counter to', 'ignore', 'not care', 'not conform', 'not heed'],
    'not right': ['aberrant', 'abnormal', 'abroad', 'adrift', 'all abroad', 'all off', 'all wrong', 'amiss', 'askew', 'astray', 'at fault', 'awry'],
    'not surprised': ['agape', 'agog', 'all agog', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'awaiting', 'certain', 'confident', 'eager', 'expectant'],
    'not swallow': ['be skeptical', 'deny', 'disbelieve', 'discredit', 'gag on', 'misbelieve', 'negate', 'not accept', 'not admit', 'not believe', 'not buy', 'not fall for'],
    'not touch': ['abstain', 'abstain from', 'avoid', 'dispense with', 'do without', 'eschew', 'fight shy of', 'forbear', 'forgo', 'give place to', 'hold aloof', 'hold aloof from'],
    'not true': ['aberrant', 'abroad', 'adrift', 'all abroad', 'all off', 'all wrong', 'amiss', 'askew', 'astray', 'at fault', 'awry', 'beside the mark'],
    'not with it': ['a stranger to', 'asleep', 'blind to', 'caught napping', 'dead to', 'deaf to', 'impercipient', 'in ignorance of', 'incognizant', 'insensible', 'insensible to', 'mindless'],
    'notability': ['establishment', 'vip', 'baron', 'big gun', 'big man', 'big name', 'big shot', 'big-timer', 'bigwig', 'brass', 'brass hat', 'celebrity'],
    'notable': ['establishment', 'vip', 'acclaimed', 'appalling', 'arrant', 'astonishing', 'baron', 'big', 'big boy', 'big bug', 'big cheese', 'big chief'],
    'notably': ['abundantly', 'acutely', 'amazingly', 'amply', 'arrantly', 'astonishingly', 'awesomely', 'blatantly', 'boldly', 'celebratedly', 'clearly', 'consequentially'],
    'notarize': ['ok', 'accept', 'accredit', 'affirm', 'amen', 'approve', 'authenticate', 'authorize', 'autograph', 'certify', 'confirm', 'cosign'],
    'notarized': ['accepted', 'acknowledged', 'admitted', 'affirmed', 'allowed', 'approved', 'authenticated', 'avowed', 'certified', 'conceded', 'confessed', 'confirmed'],
    'notarized statement': ['affidavit', 'affirmation', 'attestation', 'authority', 'authorization', 'bill of health', 'certificate', 'certificate of proficiency', 'certification', 'credential', 'deposition', 'diploma'],
    'notary': ['accountant', 'amanuensis', 'approver', 'archivist', 'bookkeeper', 'certifier', 'clerk', 'confirmer', 'cosignatory', 'cosigner', 'documentalist', 'endorser'],
    'notate': ['catch a likeness', 'character', 'characterize', 'chart', 'delineate', 'depict', 'diagram', 'draw', 'hit off', 'limn', 'map', 'paint'],
    'notation': ['abstract', 'accent', 'accent mark', 'addition', 'adversaria', 'aide-memoire', 'alphabet', 'annotation', 'apparatus criticus', 'approximation', 'arrangement', 'art'],
    'notch': ['vandyke', 'abysm', 'abyss', 'accomplish', 'achieve', 'alveolation', 'alveolus', 'amount', 'arroyo', 'birthmark', 'blaze', 'blaze a trail'],
    'notched': ['alveolar', 'alveolate', 'battlemented', 'chopped', 'crenate', 'crenated', 'crenellated', 'crenulate', 'dentate', 'dentated', 'dented', 'dentiform'],
    'note': ['cd', 'federal reserve note', 'french pitch', 'iou', 'mo', 'parthian shot', 'accent', 'acceptance', 'acceptance bill', 'accidental', 'acknowledgment', 'address'],
    'notebook': ['domesday book', 'account book', 'address book', 'adversaria', 'album', 'annual', 'appointment calendar', 'appointment schedule', 'best seller', 'blankbook', 'blotter', 'book'],
    'noted': ['acclaimed', 'celebrated', 'distinguished', 'eminent', 'esteemed', 'fabled', 'famed', 'famous', 'far-famed', 'far-heard', 'honored', 'illustrious'],
    'noteworthy': ['absolute', 'appalling', 'astonishing', 'celebrated', 'certain', 'concrete', 'conspicuous', 'defined', 'definite', 'detailed', 'determinate', 'different'],
    'nothing': ['a little thing', 'a nobody', 'a nothing', 'aught', 'bagatelle', 'blank', 'cipher', 'clean slate', 'common man', 'dud', 'dummy', 'empty space'],
    'nothing special': ['middle america', 'bourgeoisie', 'burgherdom', 'fourth-rater', 'mediocrity', 'middle class', 'middle order', 'middle orders', 'no prize', 'nobody special', 'nonentity', 'second-rater'],
    'nothingness': ['ko', 'absence', 'acreage', 'area', 'blackout', 'blank', 'breadth', 'catalepsy', 'catatonia', 'catatony', 'clean slate', 'coma'],
    'notice': ['account', 'acknowledge', 'acquaintance', 'admonish', 'admonishment', 'admonition', 'advert', 'advertence', 'advertency', 'advice', 'advise', 'alarm'],
    'noticeable': ['acquaint', 'advise', 'appalling', 'apparent', 'appraisable', 'appreciable', 'apprise', 'arrant', 'arresting', 'assessable', 'astonishing', 'beholdable'],
    'noticeably': ['actually', 'apparently', 'appreciably', 'arrantly', 'assuredly', 'blatantly', 'boldly', 'certainly', 'clearly', 'conspicuously', 'decidedly', 'definitely'],
    'notification': ['account', 'acquaintance', 'admonishment', 'admonition', 'alarm', 'announcement', 'annunciation', 'bench warrant', 'blue book', 'briefing', 'bulletin', 'bulletin board'],
    'notify': ['acquaint', 'admonish', 'advertise', 'advertise of', 'advise', 'alert', 'announce', 'apprise', 'brief', 'bring word', 'caution', 'communicate'],
    'notion': ['apprehension', 'assumption', 'attitude', 'automatic response', 'bare suggestion', 'bee', 'blind impulse', 'boutade', 'brain wave', 'brainstorm', 'capriccio', 'caprice'],
    'notional': ['gothic', 'abstract', 'academic', 'arbitrary', 'armchair', 'baroque', 'bizarre', 'brain-born', 'capricious', 'conceptive', 'conceptual', 'conjectural'],
    'notoriety': ['pr', 'acclaim', 'arrantness', 'ballyhoo', 'blatancy', 'blot', 'blurb', 'boldness', 'bright light', 'celebrity', 'character', 'common knowledge'],
    'notorious': ['abominable', 'acclaimed', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beneath contempt', 'blackguardly', 'blameworthy', 'blatant', 'bold'],
    'notwithstanding': ['after all', 'again', 'albeit', 'all the same', 'although', 'at all events', 'at any rate', 'but', 'despite', 'even', 'even so', 'for all that'],
    'nought': ['a little thing', 'aught', 'cipher', 'goose egg', 'hardly anything', 'inessential', 'insignificancy', 'marginal matter', 'matter of indifference', 'mere nothing', 'minor matter', 'nada'],
    'nourish': ['abet', 'advance', 'aid', 'aid and abet', 'aliment', 'ask for', 'breast-feed', 'care for', 'cherish', 'coddle', 'cosset', 'countenance'],
    'nourishing': ['alimental', 'alimentary', 'assimilable', 'cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'digestible', 'dining', 'eating', 'feeding'],
    'nourishment': ['tlc', 'aliment', 'alimentation', 'bread', 'care', 'daily bread', 'economic support', 'endowment', 'food', 'food chain', 'keep', 'livelihood'],
    'nous': ['logos', 'vernunft', 'world reason', 'acuity', 'acuteness', 'adroitness', 'anima mundi', 'aptitude', 'aptness', 'archeus', 'brain', 'braininess'],
    'nouveau riche': ['babbitt', 'philistine', 'young turk', 'adventurer', 'arriviste', 'boor', 'bounder', 'bourgeois', 'bourgeois gentilhomme', 'bright young man', 'cad', 'churl'],
    'nova': ['beehive', 'cepheid variable', 'hertzsprung-russell diagram', 'hyades', 'messier catalog', 'ngc', 'pleiades', 'seven sisters', 'absolute magnitude', 'binary star', 'black hole', 'double star'],
    'novel': ['bildungsroman', 'gothic novel', 'authentic', 'avant-garde', 'bauble', 'best seller', 'bibelot', 'blockbuster', 'book', 'bound book', 'classic', 'coloring book'],
    'novelist': ['advertising writer', 'anecdotist', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'coauthor', 'collaborator', 'columnist', 'compiler'],
    'novelty': ['advance guard', 'authenticity', 'avant-garde', 'bauble', 'brand-newness', 'callowness', 'craze', 'creativeness', 'creativity', 'dewiness', 'fad', 'faddiness'],
    'novena': ['mass', 'nina from carolina', 'bedtime prayer', 'camp meeting', 'church', 'church service', 'compline', 'devotions', 'divine service', 'duty', 'ennead', 'enneastyle'],
    'novice': ['abbess', 'abecedarian', 'alphabetarian', 'amateur', 'apprentice', 'articled clerk', 'baby', 'beginner', 'boot', 'canoness', 'catechumen', 'clergywoman'],
    'now': ['a la mode', 'advanced', 'all at once', 'all together', 'as', 'as long as', 'as of now', 'as things are', 'at a blow', 'at a stroke', 'at once', 'at one blow'],
    'now and then': ['at infrequent intervals', 'at intervals', 'at odd times', 'at times', 'at various times', 'betimes', 'betweentimes', 'betweenwhiles', 'ever and again', 'ever and anon', 'every so often', 'here and there'],
    'noway': ['god forbid', 'at no hand', 'au contraire', 'by no means', 'far from it', 'in no case', 'in no respect', 'in no wise', 'never', 'no matter what', 'nohow', 'not a bit'],
    'nowhere': ['china', 'darkest africa', 'god knows where', 'greenland', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'siberia', 'south pole', 'thule', 'tierra del fuego'],
    'nowise': ['at no hand', 'by no means', 'in no case', 'in no respect', 'in no wise', 'never', 'nohow', 'not a bit', 'not a jot', 'not a speck', 'not a whit', 'not an iota'],
    'noxious': ['abhorrent', 'abominable', 'bad', 'bad for', 'bad-smelling', 'baleful', 'baneful', 'barfy', 'base', 'beastly', 'below contempt', 'beneath contempt'],
    'nozzle': ['aerosol', 'antlia', 'aspergil', 'aspergillum', 'atomizer', 'beak', 'beezer', 'bib nozzle', 'bill', 'bugle', 'clyster', 'concentrate sprayer'],
    'nth degree': ['acme', 'all', 'apogee', 'ceiling', 'climax', 'crown', 'end', 'extreme', 'extremity', 'highest degree', 'limit', 'maximum'],
    'nuance': ['allegory', 'allusion', 'amount', 'arcane meaning', 'assumption', 'caliber', 'coloration', 'compass', 'connotation', 'contradistinction', 'cut', 'dash'],
    'nub': ['axiom', 'axis', 'bench mark', 'bilge', 'blain', 'bleb', 'blister', 'blob', 'boss', 'bow', 'bubble', 'bulb'],
    'nubbin': ['bantam', 'banty', 'bilge', 'blain', 'bleb', 'blister', 'blob', 'boss', 'bow', 'bubble', 'bulb', 'bulge'],
    'nubby': ['burled', 'gnarled', 'gnarly', 'knobbed', 'knobby', 'knoblike', 'knotted', 'knotty', 'knurled', 'knurly', 'nappy', 'nodal'],
    'nuclear': ['amidships', 'average', 'central', 'chromatinic', 'chromosomal', 'core', 'diploid', 'equatorial', 'equidistant', 'extranuclear', 'halfway', 'haploid'],
    'nuclear fission': ['alpha decay', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction', 'atomization', 'beta decay', 'bombardment', 'breeding', 'bullet', 'chain reaction', 'cleavage'],
    'nuclear physics': ['newtonian physics', 'acoustics', 'aerophysics', 'applied physics', 'astrophysics', 'atomic science', 'atomics', 'atomistics', 'atomology', 'basic conductor physics', 'biophysics', 'chemical physics'],
    'nuclear power': ['aec', 'atomic energy commission', 'activation energy', 'atomic energy', 'atomic power', 'atomic project', 'atomic research', 'binding energy', 'electric power', 'electropower', 'energy level', 'horsepower'],
    'nucleus': ['anlage', 'kern', 'nmr', 'alpha particle', 'antibaryon', 'antilepton', 'antimeson', 'atomic nucleus', 'atomic particle', 'axiom', 'axis', 'baryon'],
    'nude': ['art object', 'au naturel', 'bald', 'bare', 'bare-ass', 'bareness', 'birthday suit', 'blank', 'brainchild', 'bric-a-brac', 'classic', 'composition'],
    'nudge': ['roman candle', 'actuate', 'aid to navigation', 'alarm', 'amber light', 'assault', 'attouchement', 'balefire', 'beacon', 'beacon fire', 'bear', 'bear upon'],
    'nudie': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'black-and-white film', 'cartoon', 'chiller', 'cinema', 'color film', 'creepie', 'documentary'],
    'nudist': ['bald', 'bare', 'bare-ass', 'bareness', 'birthday suit', 'decollete', 'ecdysiast', 'gymnosophical', 'gymnosophist', 'gymnosophy', 'in native buff', 'in puris naturalibus'],
    'nudity': ['baldness', 'bareness', 'beauty unadorned', 'birthday suit', 'decollete', 'ecdysiast', 'gymnosophist', 'gymnosophy', 'nakedness', 'naturism', 'naturist', 'not a stitch'],
    'nudzh': ['aggravate', 'annoy', 'annoyer', 'badger', 'badgerer', 'bait', 'be at', 'bedevil', 'beset', 'bother', 'bristle', 'brown off'],
    'nugatory': ['ng', 'airy', 'asinine', 'barren', 'bootless', 'catchpenny', 'cheap', 'counterproductive', 'effete', 'empty', 'etiolated', 'fatuitous'],
    'nugget': ['bar', 'batch', 'block', 'bulk', 'bullion', 'chunk', 'clod', 'clump', 'coin gold', 'coin silver', 'copper', 'gob'],
    'nuisance': ['aggravation', 'annoyance', 'ass', 'bad news', 'bedevilment', 'besetment', 'bore', 'bother', 'botheration', 'bothersomeness', 'burden', 'buttonholer'],
    'nuisance value': ['arrest', 'arrestation', 'arrestment', 'blockage', 'blocking', 'check', 'clogging', 'closing up', 'closure', 'constriction', 'cramp', 'delay'],
    'null': ['aimless', 'bad', 'bare', 'barren', 'bland', 'blank', 'bleached', 'characterless', 'clear', 'designless', 'devoid', 'empty'],
    'null and void': ['bad', 'bare', 'barren', 'bland', 'blank', 'bleached', 'characterless', 'clear', 'devoid', 'empty', 'featureless', 'hollow'],
    'nullification': ['abjuration', 'abjurement', 'abolishment', 'abolition', 'abrogation', 'absolute contradiction', 'annihilation', 'annulment', 'autarky', 'bimetallism', 'cancel', 'canceling'],
    'nullify': ['abate', 'abjure', 'abolish', 'abrogate', 'absolve', 'annihilate', 'annul', 'assert the contrary', 'belie', 'bring to naught', 'bring to nothing', 'buffer'],
    'nullity': ['a little thing', 'absence', 'aimlessness', 'cipher', 'dead letter', 'deprivation', 'dud', 'dummy', 'emptiness', 'empty sound', 'futility', 'hardly anything'],
    'numb': ['ko', 'laodicean', 'olympian', 'abate', 'allay', 'alleviate', 'aloof', 'anesthetize', 'anesthetized', 'apathetic', 'appease', 'asleep'],
    'number': ['a certain number', 'a few', 'a number', 'account', 'act', 'add up', 'add up to', 'afterpiece', 'aggregate', 'aggregate to', 'amount', 'amount to'],
    'number among': ['admit', 'assimilate', 'complete', 'comprehend', 'comprise', 'contain', 'count in', 'cover', 'embody', 'embrace', 'encircle', 'enclose'],
    'number one': ['al', 'grade a', 'alter', 'alter ego', 'alterum', 'better self', 'blue-ribbon', 'capital', 'cock', 'dominant', 'ego', 'ethical self'],
    'numbering': ['accounting', 'assimilating', 'census', 'comprising', 'containing', 'counting', 'covering', 'dactylonomy', 'embracing', 'encircling', 'enclosing', 'encompassing'],
    'numberless': ['countless', 'endless', 'immeasurable', 'incalculable', 'inexhaustible', 'infinite', 'innumerable', 'measureless', 'myriad', 'no end of', 'numerous', 'uncountable'],
    'numbers': ['alexandrine', 'stabreim', 'a mass of', 'a world of', 'accent', 'accentuation', 'algorism', 'algorithm', 'alliterative meter', 'amount', 'amphibrach', 'amphimacer'],
    'numbing': ['siberian', 'abatement', 'algid', 'allayment', 'alleviating', 'alleviation', 'alleviative', 'analgesia', 'analgesic', 'anesthesia', 'anesthetic', 'anesthetizing'],
    'numbness': ['acedia', 'aloofness', 'analgesia', 'anesthesia', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'callousness', 'comatoseness'],
    'numerable': ['appraisable', 'appreciable', 'assessable', 'calculable', 'computable', 'countable', 'determinable', 'estimable', 'fathomable', 'gaugeable', 'measurable', 'mensurable'],
    'numerate': ['call off', 'call over', 'call the roll', 'census', 'count', 'enumerate', 'foliate', 'list', 'measure', 'number', 'page', 'paginate'],
    'numerative': ['algorismic', 'algorithmic', 'aliquot', 'approximative', 'calculating', 'cardinal', 'chorographic', 'computational', 'computative', 'computing', 'decimal', 'differential'],
    'numeric': ['algebraic', 'algorismic', 'algorithmic', 'aliquot', 'analytic', 'cardinal', 'decimal', 'differential', 'digital', 'even', 'exponential', 'figural'],
    'numerical': ['algebraic', 'algorismic', 'algorithmic', 'aliquot', 'analytic', 'cardinal', 'decimal', 'differential', 'digital', 'even', 'exponential', 'figural'],
    'numerous': ['abounding', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'big', 'billion', 'bottomless', 'bounteous', 'bountiful', 'certain'],
    'numinous': ['greek to one', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'ambiguous', 'arcane', 'awe-inspiring', 'awesome', 'awful', 'awing'],
    'numskull': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead'],
    'nun': ['abbess', 'canoness', 'celibataire', 'celibate', 'clergywoman', 'conventual', 'lady superior', 'misogamist', 'misogynist', 'monastic', 'monk', 'mother superior'],
    'nuncio': ['hermes', 'iris', 'mercury', 'paul revere', 'pheidippides', 'ambassador', 'ambassadress', 'apostolic delegate', 'attache', 'career diplomat', 'carrier', 'chancellor'],
    'nuptial': ['amorous', 'bridal', 'carnal', 'conjugal', 'connubial', 'epithalamic', 'erogenic', 'erogenous', 'erotic', 'erotogenic', 'fleshly', 'gamic'],
    'nuptials': ['gretna green wedding', 'banns', 'bridal', 'bridal suite', 'bridechamber', 'chuppah', 'church wedding', 'civil ceremony', 'civil wedding', 'elopement', 'epithalamium', 'espousals'],
    'nurse': ['lpn', 'rn', 'advance', 'aliment', 'amah', 'apprentice', 'attend', 'attend to', 'ayah', 'baby', 'baby-sit', 'bandage'],
    'nursemaid': ['abigail', 'amah', 'au pair girl', 'ayah', 'betweenmaid', 'biddy', 'chambermaid', 'chaperon', 'companion', 'cook', 'dry nurse', 'duenna'],
    'nursery': ['x ray', 'bedchamber', 'bedroom', 'birthplace', 'blood bank', 'boudoir', 'breeding place', 'brooder', 'chamber', 'charity ward', 'clinic', 'cloche'],
    'nursery rhyme': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'nurseryman': ['floriculturist', 'florist', 'fruit-grower', 'gardener', 'horticulturist', 'landscape architect', 'landscape gardener', 'landscapist', 'market gardener', 'olericulturist', 'orchardist', 'orchardman'],
    'nursing home': ['va hospital', 'almshouse', 'asylum', 'base hospital', 'clinic', 'community hospital', 'convalescent home', 'convalescent hospital', 'evacuation hospital', 'field hospital', 'foster home', 'general hospital'],
    'nurture': ['tlc', 'abet', 'acculturate', 'advance', 'aid and abet', 'aliment', 'alimentation', 'ameliorate', 'amend', 'apprentice', 'apprenticeship', 'ask for'],
    'nut': ['brazil nut', 'english walnut', 'macadamia nut', 'acorn', 'addict', 'aficionado', 'alien', 'aliene', 'almond', 'almond paste', 'amande', 'amande douce'],
    'nutriment': ['aliment', 'alimentation', 'bread', 'bread and butter', 'growth regulator', 'keep', 'livelihood', 'living', 'maintenance', 'nourishment', 'nurture', 'nutrient'],
    'nutrition': ['appetite', 'baking', 'barbecuing', 'basting', 'boiling', 'braising', 'brewing', 'broil', 'broiling', 'cannibalism', 'carnivorism', 'carnivority'],
    'nutritious': ['alimental', 'alimentary', 'assimilable', 'balanced', 'beneficial', 'cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'digestible', 'dining'],
    'nuts': ['balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bonkers', 'buggy', 'bughouse', 'bugs', 'cracked', 'crackers'],
    'nuts about': ['ape about', 'attached to', 'bugs on', 'cracked on', 'crazy about', 'devoted to', 'enamored of', 'far gone on', 'fond of', 'freaked-out', 'gaga over', 'gone on'],
    'nutshell': ['abridge', 'ace', 'atom', 'bit', 'brief', 'capsule', 'capsulize', 'condense', 'dab', 'digest', 'dole', 'dot'],
    'nutty': ['abnormal', 'anomalous', 'apish', 'asinine', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bedlamite', 'befooled'],
    'nuzzle': ['bundle', 'burrow', 'caress', 'croodle', 'cuddle', 'feel up', 'fondle', 'knead', 'lap', 'massage', 'nestle', 'nose'],
    'nylon': ['aralac', 'avisco', 'axminster', 'celanese', 'chemstrand', 'dacron', 'dynel', 'georgette', 'harris tweed', 'lastex', 'leatherette', 'manila'],
    'nymph': ['anlage', 'atlantides', 'hyades', 'napaea', 'pleiades', 'arachnid', 'arthropod', 'aurelia', 'beetle', 'blastula', 'bug', 'caterpillar'],
    'nymphet': ['atlantides', 'hyades', 'jezebel', 'napaea', 'pleiades', 'babe', 'baby', 'bad woman', 'baggage', 'bitch', 'broad', 'chick'],
    'nymphomania': ['andromania', 'animality', 'aphrodisia', 'bawdiness', 'biological urge', 'bodily appetite', 'carnal desire', 'carnality', 'clitoromania', 'concupiscence', 'desire', 'dirtiness'],
    'nymphomaniac': ['jezebel', 'bad woman', 'baggage', 'bitch', 'broad', 'bugger', 'chippy', 'clitoromaniac', 'cocotte', 'coprophiliac', 'drab', 'easy lay'],
    'oaf': ['babe', 'baboon', 'beast', 'blockhead', 'blunderbuss', 'blunderer', 'blunderhead', 'boob', 'booby', 'boor', 'botcher', 'bruiser'],
    'oafish': ['boeotian', 'all thumbs', 'asinine', 'awkward', 'beef-brained', 'beef-witted', 'blockish', 'blunderheaded', 'blundering', 'boorish', 'bovine', 'bumbling'],
    'oak': ['gibraltar', 'acacia', 'adamant', 'ailanthus', 'alder', 'alligator pear', 'allspice', 'almond', 'apple', 'apricot', 'ash', 'aspen'],
    'oak leaf': ['hershey bar', 'aviation badge', 'badge', 'bar', 'chevron', 'chicken', 'eagle', 'epaulet', 'hash mark', 'insignia of branch', 'organization insignia', 'overseas bar'],
    'oar': ['bargee', 'bargeman', 'barger', 'boat-handler', 'boater', 'boatman', 'boatsman', 'ferrier', 'ferryman', 'galley slave', 'gondolier', 'lighterman'],
    'oarsman': ['bargee', 'bargeman', 'barger', 'boat-handler', 'boater', 'boatman', 'boatsman', 'ferrier', 'ferryman', 'galley slave', 'gondolier', 'lighterman'],
    'oath': ['bible oath', 'assurance', 'avouch', 'avouchment', 'avow', 'avowal', 'curse', 'cuss', 'cuss word', 'dirty name', 'dirty word', 'dysphemism'],
    'oatmeal': ['breakfast food', 'cereal', 'cornflakes', 'dry cereal', 'farina', 'frumenty', 'grits', 'gruel', 'hasty pudding', 'hominy grits', 'hot cereal', 'kasha'],
    'oats': ['bengal grass', 'english rye grass', 'italian rye grass', 'kentucky bluegrass', 'alfilaria', 'bamboo', 'barley', 'beach grass', 'beard grass', 'bent', 'bent grass', 'bird seed'],
    'obdurate': ['adamant', 'asleep', 'benumbed', 'bony', 'brazen', 'callous', 'calloused', 'case-hardened', 'cement', 'cemental', 'cold', 'cold of heart'],
    'obedience': ['quakerism', 'acceptance', 'accommodation', 'accord', 'accordance', 'acquiescence', 'adaptability', 'adaptation', 'adaption', 'adjustment', 'agreeability', 'agreeableness'],
    'obedient': ['abject', 'accepting', 'accommodating', 'acquiescent', 'adaptable', 'adapting', 'adaptive', 'adjustable', 'adjusting', 'agreeable', 'amenable', 'assenting'],
    'obediently': ['acquiescently', 'agreeably', 'anally', 'complaisantly', 'compliantly', 'compulsively', 'conformably', 'conformingly', 'conventionally', 'devotedly', 'duteously', 'dutifully'],
    'obeisance': ['acceptance', 'acquiescence', 'allegiance', 'apple-polishing', 'ass-kissing', 'assent', 'backscratching', 'bend', 'bending the knee', 'bob', 'bootlicking', 'bow'],
    'obeisant': ['abject', 'backscratching', 'beggarly', 'bootlicking', 'cowering', 'crawling', 'cringing', 'crouching', 'deferential', 'fawning', 'flattering', 'footlicking'],
    'obelisk': ['antenna tower', 'arch', 'barbican', 'barrow', 'belfry', 'bell tower', 'boundary stone', 'brass', 'bust', 'cairn', 'campanile', 'cenotaph'],
    'oberon': ['ariel', 'befind', 'corrigan', 'finnbeara', 'mab', 'titania', 'banshee', 'brownie', 'cluricaune', 'dwarf', 'elf', 'fairy'],
    'obese': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky', 'corpulent'],
    'obey': ['abide by', 'accede', 'accept', 'acquiesce', 'acquiesce in', 'act', 'adhere to', 'agree', 'agree to', 'assent', 'attend to orders', 'be agreeable'],
    'obfuscate': ['adumbrate', 'becloud', 'bedarken', 'bedim', 'befog', 'begloom', 'black', 'black out', 'blacken', 'blanket', 'blind', 'block the light'],
    'obituary': ['clio', 'muse of history', 'adventures', 'annals', 'arch', 'archival', 'autobiography', 'barrow', 'bill of mortality', 'biographical sketch', 'biography', 'body count'],
    'object': ['ic analysis', 'affair', 'agree to disagree', 'aim', 'an existence', 'appositive', 'article', 'artifact', 'attribute', 'attributive', 'balk', 'ban'],
    'object lesson': ['admonishment', 'admonition', 'alarm', 'assignment', 'case', 'case in point', 'caution', 'caveat', 'chalk talk', 'demonstration', 'deterrent example', 'discourse'],
    'objectify': ['actualize', 'call to mind', 'call up', 'conjure up', 'envisage', 'envision', 'exteriorize', 'externalize', 'extrapolate', 'image', 'incarnate', 'just see'],
    'objecting': ['complaining', 'disputatious', 'disputing', 'dissentient', 'dissenting', 'expostulative', 'expostulatory', 'fractious', 'noncooperative', 'obstructive', 'on the barricades', 'proof against'],
    'objection': ['answer', 'antipathy', 'argument', 'ban', 'bashfulness', 'beef', 'bitch', 'blackball', 'blackballing', 'block', 'blockade', 'boggle'],
    'objectionable': ['abhorrent', 'abominable', 'base', 'beastly', 'below contempt', 'beneath contempt', 'censurable', 'contemptible', 'crude', 'despicable', 'detestable', 'disagreeable'],
    'objective': ['achromatic lens', 'affectless', 'aim', 'ambition', 'anesthetized', 'animus', 'appetence', 'appetency', 'appetite', 'arctic', 'aspiration', 'astigmatic lens'],
    'objectivity': ['anesthesia', 'autism', 'catatonia', 'chill', 'chilliness', 'cold blood', 'cold heart', 'coldheartedness', 'coldness', 'coolness', 'deadpan', 'detachment'],
    'objector': ['apostate', 'bitter-ender', 'brawler', 'defendant', 'demurrer', 'diehard', 'disputant', 'dissenter', 'dissentient', 'dissident', 'intransigent', 'irreconcilable'],
    'oblation': ['christmas present', 'award', 'birthday present', 'box', 'burnt offering', 'cadeau', 'collection', 'drink offering', 'ex voto offering', 'fairing', 'gift', 'handsel'],
    'obligate': ['accept obligation', 'agree to', 'answer for', 'be answerable for', 'be responsible for', 'be security for', 'bind', 'commit', 'compel', 'constrain', 'contract', 'engage'],
    'obligated': ['affianced', 'answerable for', 'assured', 'beholden', 'beholden to', 'betrothed', 'bound', 'bounden', 'bounden to', 'chargeable', 'committed', 'compromised'],
    'obligation': ['accountability', 'accounts payable', 'accounts receivable', 'act of grace', 'act of kindness', 'affair', 'agreement', 'allegiance', 'amount due', 'appreciation', 'appreciativeness', 'aptitude'],
    'obligatory': ['absolute', 'binding', 'choiceless', 'compulsory', 'conclusive', 'de rigueur', 'decisive', 'decretory', 'demanded', 'dictated', 'entailed', 'essential'],
    'oblige': ['accommodate', 'aid', 'assist', 'avail', 'benefit', 'bind', 'brook no denial', 'call for', 'cater to', 'coddle', 'coerce', 'commit'],
    'obliged': ['acknowledging', 'appreciative', 'beholden', 'beholden to', 'bound', 'bounden', 'bounden to', 'cognizant of', 'committed', 'compelled', 'crediting', 'duty-bound'],
    'obliging': ['accommodating', 'accommodative', 'affable', 'agreeable', 'amenable', 'amiable', 'attentive', 'benevolent', 'benign', 'benignant', 'civil', 'complaisant'],
    'oblique': ['o-shaped', 'across', 'ambagious', 'angle', 'angle off', 'angling', 'askew', 'aslant', 'athwart', 'atilt', 'awry', 'backhand'],
    'obliterate': ['absolve', 'annihilate', 'black out', 'blot', 'blot out', 'cancel', 'consign to oblivion', 'cross out', 'declare a moratorium', 'dele', 'delete', 'destroy'],
    'obliteration': ['lethe', 'absentmindedness', 'blot', 'blotting', 'blotting out', 'cancel', 'cancellation', 'decay of memory', 'deletion', 'effacement', 'erasure', 'expunction'],
    'oblivion': ['ko', 'lethe', 'abandon', 'absentmindedness', 'anonymity', 'blackness', 'blackout', 'blank mind', 'blankmindedness', 'blankness', 'calm of mind', 'careless abandon'],
    'oblivious': ['lethean', 'absent', 'absent-minded', 'absentminded', 'absorbed', 'abstracted', 'airy', 'amnestic', 'asleep', 'bemused', 'blank', 'blankminded'],
    'oblong': ['cube-shaped', 'cubed', 'cubic', 'cubiform', 'cuboid', 'diced', 'elliptical', 'elongated', 'foursquare', 'oblongated', 'oblongitudinal', 'orthogonal'],
    'obloquy': ['abuse', 'adverse criticism', 'animadversion', 'aspersion', 'bad notices', 'bad press', 'billingsgate', 'calumny', 'captiousness', 'carping', 'cavil', 'caviling'],
    'obnoxious': ['abhorrent', 'abject', 'abominable', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beggarly', 'below contempt', 'beneath contempt', 'blameworthy'],
    'oboe': ['english horn', 'pandean pipe', 'aulos', 'basset horn', 'basset oboe', 'bassoon', 'block flute', 'bombard', 'bourdon', 'cello', 'claribel', 'clarinet'],
    'obscene': ['cyprian', 'fescennine', 'paphian', 'rabelaisian', 'abhorrent', 'abominable', 'abusive', 'amoral', 'animal', 'aphrodisiomaniacal', 'atrocious', 'awful'],
    'obscenity': ['rabelaisianism', 'x-rated movie', 'abominability', 'animality', 'bad language', 'baseness', 'bawdiness', 'bawdry', 'beastliness', 'billingsgate', 'blue language', 'blue movie'],
    'obscure': ['cimmerian', 'abstruse', 'adiaphanous', 'adumbrate', 'aleatoric', 'aleatory', 'ambiguous', 'amorphic', 'amorphous', 'amphibological', 'anarchic', 'anonymous'],
    'obscured': ['abstruse', 'armored', 'beamless', 'beclouded', 'bedazzled', 'between the lines', 'beyond one', 'black', 'black as night', 'blind', 'blindfold', 'blindfolded'],
    'obscurity': ['egyptian darkness', 'erebus', 'a nobody', 'a nothing', 'abstruseness', 'adiaphanousness', 'ambiguousness', 'amorphia', 'amorphism', 'amorphousness', 'anarchy', 'anonymity'],
    'obsequious': ['abject', 'adulatory', 'ass-kissing', 'backscratching', 'beggarly', 'bland', 'blandishing', 'blarneying', 'bootlicking', 'brown-nosing', 'buttery', 'cajoling'],
    'observable': ['apparent', 'appreciable', 'beholdable', 'clear', 'clear as crystal', 'crystal-clear', 'detectable', 'discernible', 'disclosed', 'distinct', 'evident', 'explicit'],
    'observance': ['accommodation', 'accord', 'accordance', 'acquiescence', 'adaptation', 'adaption', 'adherence', 'adhering', 'adjustment', 'adoration', 'advertence', 'advertency'],
    'observant': ['argus-eyed', 'active', 'advertent', 'agog', 'alert', 'all ears', 'all eyes', 'assiduous', 'attentive', 'aux aguets', 'awake', 'aware'],
    'observation': ['parthian shot', 'accordance', 'acquittal', 'acquittance', 'address', 'adherence', 'advertence', 'advertency', 'affirmation', 'alertness', 'allegation', 'announcement'],
    'observatory': ['cassegrainian telescope', 'newtonian telescope', 'oao', 'oso', 'texas tower', 'astronomical observatory', 'astronomical telescope', 'beacon', 'belvedere', 'bleachers', 'bridge', 'coelostat'],
    'observe': ['abide by', 'accommodate', 'accommodate with', 'accord', 'act up to', 'adapt', 'adapt to', 'adhere to', 'adjust', 'adjust to', 'administer', 'administer communion'],
    'observer': ['tv-viewer', 'ace', 'air force', 'beholder', 'bird-watcher', 'bomber pilot', 'bystander', 'combat pilot', 'drugstore cowboy', 'examinant', 'examiner', 'eyewitness'],
    'obsess': ['absorb', 'absorb the attention', 'arrest', 'be remembered', 'bedevil', 'beset', 'bewitch', 'burden', 'catch', 'charm', 'compel', 'control'],
    'obsessed': ['absorbed', 'absorbed in', 'affected', 'agonized', 'bedeviled', 'beset', 'besotted', 'bewitched', 'buried in', 'caught up in', 'contemplating', 'contemplative'],
    'obsession': ['absorbed attention', 'absorption', 'abstraction', 'abulia', 'alienation', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'application', 'bedevilment', 'bewitchery'],
    'obsessive': ['absorbing', 'all-encompassing', 'arresting', 'attractive', 'compelling', 'compulsive', 'consuming', 'controlling', 'dominating', 'driving', 'enchanting', 'engaging'],
    'obsolesce': ['age', 'antiquate', 'be superseded', 'become extinct', 'become obsolete', 'date', 'fade', 'fall into disuse', 'fossilize', 'fust', 'go out', 'grow old'],
    'obsolete': ['abandoned', 'abjured', 'ago', 'ancient', 'antediluvian', 'antiquate', 'antiquated', 'antique', 'archaic', 'behind the times', 'blown over', 'by'],
    'obstacle': ['bar', 'barrier', 'blank wall', 'blind alley', 'blind gut', 'block', 'blockade', 'blockage', 'bottleneck', 'catch', 'cecum', 'check'],
    'obstetrician': ['anesthesiologist', 'cardiologist', 'chiropodist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'immunologist', 'internist', 'neurologist', 'oculist'],
    'obstinacy': ['adhesiveness', 'antagonism', 'antipathy', 'application', 'assiduity', 'assiduousness', 'averseness', 'aversion', 'backwardness', 'bad blood', 'bloody-mindedness', 'bulldog tenacity'],
    'obstinate': ['adamant', 'adherent', 'adhesive', 'adversary', 'adversative', 'adverse', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'assiduous'],
    'obstreperous': ['bawling', 'beyond control', 'blaring', 'blatant', 'blatting', 'blustering', 'boanergean', 'boisterous', 'brassy', 'brawling', 'brazen', 'breachy'],
    'obstruct': ['arrest', 'backpedal', 'backwater', 'bar', 'barricade', 'beat off', 'bind', 'block', 'block out', 'block up', 'blockade', 'bolt'],
    'obstructed': ['arrested', 'back', 'backward', 'behindhand', 'belated', 'blocked', 'bound', 'choked', 'choked up', 'clogged', 'clogged up', 'congested'],
    'obstruction': ['afterthought', 'arrest', 'arrestation', 'arrestment', 'bar', 'barrier', 'bind', 'blank wall', 'blind alley', 'blind gut', 'block', 'blockade'],
    'obstructionist': ['bitter-ender', 'brawler', 'defendant', 'diehard', 'disputant', 'dissentient', 'dissident', 'filibuster', 'filibusterer', 'frustrater', 'hinderer', 'impeder'],
    'obstructive': ['choking', 'complaining', 'constrictive', 'contrary', 'counterproductive', 'crosswise', 'disputatious', 'disputing', 'dissentient', 'dissenting', 'fractious', 'hindering'],
    'obtain': ['accept', 'acquire', 'admit', 'annex', 'apply', 'arouse', 'assume', 'bag', 'be', 'be extant', 'be found', 'be in'],
    'obtainable': ['accessible', 'approachable', 'attainable', 'available', 'come-at-able', 'derivable', 'findable', 'getatable', 'gettable', 'open', 'open to', 'penetrable'],
    'obtrude': ['barge in', 'boot out', 'bounce', 'break in', 'break in upon', 'burst in', 'butt in', 'cast', 'cast out', 'charge in', 'chuck out', 'come between'],
    'obtrusive': ['aggressively self-confident', 'arrant', 'arrogant', 'audacious', 'biggety', 'blatant', 'bold', 'brazen', 'brazenfaced', 'bumptious', 'busy', 'chesty'],
    'obtuse': ['abrupt', 'affectless', 'anesthetized', 'arctic', 'asleep', 'autistic', 'benumbed', 'bluff', 'blunt', 'blunt-edged', 'blunt-ended', 'blunt-pointed'],
    'obverse': ['adversative', 'adverse', 'adversive', 'ally', 'alter ego', 'analogon', 'analogue', 'antagonistic', 'anteriority', 'anti', 'antipathetic', 'antipodal'],
    'obviate': ['anticipate', 'avert', 'bar', 'debar', 'deflect', 'deter', 'discourage', 'dishearten', 'estop', 'exclude', 'fend', 'fend off'],
    'obvious': ['apparent', 'bald', 'clean-cut', 'clear', 'clear as crystal', 'clear-cut', 'conspicuous', 'crystal-clear', 'defined', 'definite', 'direct', 'discernible'],
    'obviously': ['absolutely', 'actually', 'apparently', 'assuredly', 'certainly', 'clearly', 'conspicuously', 'de facto', 'decidedly', 'definitely', 'demonstrably', 'discernibly'],
    'ocarina': ['english horn', 'pandean pipe', 'aulos', 'basset horn', 'basset oboe', 'bassoon', 'bombard', 'clarinet', 'contrabassoon', 'contrafagotto', 'cromorne', 'double bassoon'],
    'occasion': ['a leg up', 'advantage', 'adventure', 'affair', 'antecedent', 'antecedents', 'author', 'bare necessities', 'base', 'basis', 'bear', 'beget'],
    'occasional': ['accessory', 'accidental', 'accompanying', 'additional', 'ado', 'adventitious', 'afloat', 'afoot', 'aleatory', 'auxiliary', 'behind the scenes', 'by-the-way'],
    'occasionally': ['at infrequent intervals', 'at intervals', 'at odd times', 'at times', 'at various times', 'betweentimes', 'betweenwhiles', 'brokenly', 'by catches', 'by fits', 'by jerks', 'by skips'],
    'occident': ['africa', 'america', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'east', 'eastern hemisphere', 'eurasia', 'europe', 'far east'],
    'occidental': ['antarctic', 'arctic', 'austral', 'boreal', 'east', 'eastbound', 'easterly', 'eastermost', 'eastern', 'easternmost', 'hyperborean', 'meridional'],
    'occlude': ['bang', 'bar', 'barricade', 'batten', 'batten down', 'block', 'block up', 'blockade', 'bolt', 'button', 'button up', 'chock'],
    'occlusion': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'akinetic epilepsy', 'apoplexy', 'arrest', 'arrestation', 'arrestment'],
    'occlusive': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'occult': ['abstract', 'abstruse', 'airy', 'anagogic', 'apply to', 'arcana', 'arcane', 'arcanum', 'asomatous', 'astral', 'baffling', 'becloud'],
    'occultation': ['annular eclipse', 'blackout', 'blanketing', 'blocking', 'blotting out', 'burial', 'burying', 'cementwork', 'central eclipse', 'cloaking', 'clouding', 'coating'],
    'occultism': ['bodilessness', 'ghostliness', 'immateriality', 'immaterialness', 'impalpability', 'imponderability', 'incorporeality', 'incorporeity', 'inextension', 'intangibility', 'nonexteriority', 'occult phenomena'],
    'occupancy': ['abiding', 'abode', 'adverse possession', 'alodium', 'burgage', 'claim', 'cohabitation', 'colony', 'commorancy', 'de facto', 'de jure', 'dependency'],
    'occupant': ['addressee', 'artist-in-residence', 'boarder', 'denizen', 'dweller', 'habitant', 'hirer', 'homesteader', 'house detective', 'householder', 'incumbent', 'inhabitant'],
    'occupation': ['abiding', 'abode', 'act', 'acting', 'action', 'activism', 'activities', 'activity', 'adoption', 'adverse possession', 'affair', 'affairs'],
    'occupational disease': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'cardiovascular disease'],
    'occupational therapy': ['arica movement', 'erhard seminars training', 'metrazol therapy', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'x-ray therapy', 'actinotherapy', 'aerosol therapy', 'aerotherapeutics', 'aerotherapy'],
    'occupied': ['absorbed', 'absorbed in', 'abstracted', 'at it', 'at work', 'buried in', 'buried in thought', 'busy', 'caught up in', 'colonized', 'contemplating', 'contemplative'],
    'occupy': ['abide', 'absorb', 'absorb the attention', 'admit', 'adopt', 'amuse', 'appropriate', 'arrest', 'arrogate', 'assimilate', 'assume', 'attend to business'],
    'occur': ['appear', 'arise', 'be', 'be extant', 'be found', 'be in existence', 'be located', 'be met with', 'be present', 'be realized', 'be situated', 'be the case'],
    'occurrence': ['accessibility', 'actual presence', 'adventure', 'affair', 'apparition', 'appearance', 'appearing', 'arising', 'availability', 'avatar', 'being', 'being here'],
    'ocean': ['abundance', 'acres', 'bags', 'barrels', 'blue', 'brine', 'briny', 'bushel', 'copiousness', 'countlessness', 'deep', 'drink'],
    'ocean depths': ['bassalia', 'abyss', 'abyssal zone', 'bathyal zone', 'benthos', 'big drink', 'blue water', 'bottom waters', 'bottomless depths', 'drink', 'ground', 'high sea'],
    'oceanic': ['aquatic', 'bathymetric', 'bathyorographical', 'deep-sea', 'deep-water', 'hydrographic', 'marine', 'maritime', 'nautical', 'naval', 'navigational', 'ocean'],
    'oceanographer': ['appraiser', 'assayer', 'assessor', 'cartographer', 'chorographer', 'estimator', 'evaluator', 'gauger', 'geodesist', 'hydrographer', 'land surveyor', 'measurer'],
    'oceanography': ['altimetry', 'aquiculture', 'bathometry', 'bathymetry', 'biometrics', 'biometry', 'cadastration', 'cartography', 'chorography', 'craniometry', 'depth sounding', 'echo sounding'],
    'oceanus': ['davy', 'davy jones', 'dylan', 'neptune', 'nereid', 'nereus', 'oceanid', 'poseidon', 'thetis', 'triton', 'varuna', 'fresh-water nymph'],
    'ocelot': ['dalmatian', 'leo', 'siberian tiger', 'antigorite', 'bobcat', 'butterfly', 'candy cane', 'cat-a-mountain', 'catamount', 'chameleon', 'cheetah', 'chrysotile'],
    'ocherous': ['apricot', 'aureate', 'auric', 'beige', 'buff', 'buff-yellow', 'canary', 'canary-yellow', 'carrot-colored', 'carroty', 'citron', 'citron-yellow'],
    'octagonal': ['decagonal', 'dodecagonal', 'dodecahedral', 'eightfold', 'eighth', 'heptagonal', 'hexagonal', 'hexahedral', 'icosahedral', 'octadic', 'octahedral', 'octal'],
    'octane': ['alcohol', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coke', 'combustible', 'dope', 'ethane'],
    'octave': ['english horn', 'octateuch', 'spenserian stanza', 'antistrophe', 'bassoon', 'block flute', 'bombard', 'book', 'bourdon', 'burden', 'canto', 'cello'],
    'octet': ['octateuch', 'spenserian stanza', 'antistrophe', 'beta particle', 'bipartisanship', 'book', 'burden', 'canto', 'cathode particle', 'chorus', 'coaction', 'coadjuvancy'],
    'octogenarian': ['father time', 'methuselah', 'nestor', 'old paar', 'sexagesima', 'boxcar', 'boxcars', 'centenarian', 'dotard', 'dozen', 'duodecimo', 'eighty'],
    'octoroon': ['cape colored', 'eurasian', 'cattalo', 'citrange', 'cross', 'crossbreed', 'griffe', 'half blood', 'half-bred', 'half-breed', 'half-caste', 'high yellow'],
    'ocular': ['achromatic lens', 'astigmatic lens', 'burning glass', 'camera', 'coated lens', 'concave lens', 'concavo-convex lens', 'condenser', 'convex lens', 'eye', 'eyeball', 'eyeglass'],
    'oculist': ['anesthesiologist', 'bonesetter', 'cardiologist', 'chiropodist', 'chiropractor', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'healer', 'homeopath'],
    'od': ['ab', 'adc', 'ancient mariner', 'argonaut', 'co', 'dylan', 'flying dutchman', 'neptune', 'poseidon', 'varuna', 'able seaman', 'able-bodied seaman'],
    'odalisque': ['aspasia', 'delilah', 'jezebel', 'messalina', 'phryne', 'thais', 'adventuress', 'bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman'],
    'odd': ['abnormal', 'absolute', 'absurd', 'algorismic', 'algorithmic', 'aliquot', 'alone', 'anomalous', 'asymmetric', 'azygous', 'bereft of reason', 'brainsick'],
    'odd job': ['assignment', 'busywork', 'chare', 'charge', 'chore', 'commission', 'duty', 'errand', 'exercise', 'fish to fry', 'homework', 'job'],
    'oddball': ['abnormal', 'absurd', 'alien', 'anomalous', 'anomaly', 'bizarre', 'black sheep', 'blemish', 'case', 'character', 'crackpot', 'crank'],
    'oddity': ['aberration', 'abnormality', 'absurdity', 'alien', 'anomalousness', 'anomaly', 'anticness', 'bizarreness', 'bizarrerie', 'card', 'case', 'character'],
    'odds': ['advantage', 'agreement to disagree', 'allowance', 'aptitude', 'asymmetry', 'at daggers drawn', 'at loggerheads', 'at odds', 'at variance', 'bulge', 'chance', 'chances'],
    'odds and ends': ['afterglow', 'afterimage', 'all sorts', 'assemblage', 'assortment', 'balance', 'broad spectrum', 'butt', 'butt end', 'candle ends', 'chaff', 'collectanea'],
    'ode': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'odin': ['aesir', 'ares', 'athena', 'balder', 'bellona', 'bor', 'bori', 'bragi', 'donar', 'enyo', 'forseti', 'frey'],
    'odious': ['abhorrent', 'abject', 'abominable', 'arrant', 'atrocious', 'awful', 'barfy', 'base', 'beastly', 'beggarly', 'below contempt', 'beneath contempt'],
    'odium': ['anglophobia', 'russophobia', 'abhorrence', 'abomination', 'anti-semitism', 'antipathy', 'aversion', 'bigotry', 'degradation', 'demotion', 'depluming', 'despitefulness'],
    'odor': ['air', 'aroma', 'atmosphere', 'attribute', 'aura', 'badge', 'balminess', 'bouquet', 'brand', 'breath', 'cachet', 'cast'],
    'odorizer': ['atomizer', 'censer', 'fumigator', 'incense burner', 'incensory', 'odorator', 'parfumoir', 'perfumer', 'pomander', 'potpourri', 'pouncet-box', 'purse atomizer'],
    'odorous': ['ambrosial', 'aromatic', 'bad', 'bad-smelling', 'balmy', 'effluvious', 'essenced', 'fecal', 'fetid', 'flowery', 'foul', 'fragrant'],
    'of': ['about', 'anent', 'apropos of', 'as for', 'as regards', 'as respects', 'as to', 'concerning', 'in connection with', 'in point of', 'in re', 'in reference to'],
    'of course': ['ok', 'roger', 'absolutely', 'accordingly', 'all right', 'alright', 'alrighty', 'amen', 'and no mistake', 'and so', 'as a consequence', 'as a result'],
    'off': ['aberrant', 'abnormal', 'abroad', 'absonant', 'absurd', 'adrift', 'adulterated', 'all abroad', 'all off', 'all wrong', 'aloof', 'amiss'],
    'off and on': ['alternately', 'at irregular intervals', 'at random', 'back and forth', 'backward and forward', 'backwards and forwards', 'brokenly', 'by catches', 'by fits', 'by jerks', 'by snatches', 'by turns'],
    'off balance': ['asymmetric', 'canted', 'disproportionate', 'eccentric', 'heeling', 'ill-balanced', 'irregular', 'leaning', 'listing', 'lopsided', 'nonsymmetrical', 'off-center'],
    'off base': ['aberrant', 'abnormal', 'abominable', 'atrocious', 'bad', 'criminal', 'delinquent', 'deviant', 'disgraceful', 'disorderly', 'disruptive', 'evil'],
    'off chance': ['bare possibility', 'chance', 'conceivability', 'conceivableness', 'contingency', 'dark horse', 'even chance', 'eventuality', 'fighting chance', 'gambling chance', 'good chance', 'good possibility'],
    'off color': ['aberrant', 'abnormal', 'abominable', 'ailing', 'atrocious', 'bad', 'below par', 'blue', 'broad', 'clashing', 'colliding', 'conflicting'],
    'off duty': ['at leisure', 'at liberty', 'at loose ends', 'available', 'disengaged', 'fallow', 'free', 'idle', 'jobless', 'leisure', 'leisured', 'lumpen'],
    'off guard': ['asleep', 'culpably negligent', 'derelict', 'goofing off', 'inadvertent', 'inattentive', 'incautious', 'laissez-faire', 'lax', 'loose', 'napping', 'neglectful'],
    'off key': ['abnormal', 'absonant', 'anomalous', 'atonal', 'cacophonous', 'cracked', 'deviant', 'diaphonic', 'disconsonant', 'discordant', 'disharmonic', 'disharmonious'],
    'off limits': ['banned', 'barred', 'contraband', 'forbade', 'forbid', 'forbidden', 'illegal', 'illicit', 'nonpermissible', 'not permitted', 'out of bounds', 'outlawed'],
    'off the wall': ['absurd', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bonkers', 'buggy', 'bughouse', 'bugs', 'crackers'],
    'offal': ['bilge', 'bilgewater', 'bones', 'carrion', 'chaff', 'culm', 'deadwood', 'debris', 'dishwater', 'ditchwater', 'draff', 'dregs'],
    'offbeat': ['bohemian', 'bar beat', 'beat', 'bizarre', 'breakaway', 'contrasting', 'counter', 'deviant', 'different', 'disparate', 'dissimilar', 'divergent'],
    'offence': ['breach', 'crime', 'dereliction', 'error', 'fault', 'felony', 'harm', 'hurt', 'infraction', 'infringement', 'injure', 'insult'],
    'offend': ['affront', 'aggrieve', 'anger', 'annoy', 'appall', 'blemish', 'blot', 'breach', 'break', 'call names', 'chagrin', 'commit sin'],
    'offender': ['criminal', 'crook', 'culprit', 'delinquent', 'evil man', 'evil person', 'evildoer', 'felon', 'lawbreaker', 'malefactor', 'malfeasor', 'miscreant'],
    'offense': ['affront', 'aggravated assault', 'aggression', 'amphibious attack', 'angry look', 'armed assault', 'aspersion', 'assailing', 'assailment', 'assault', 'atrocity', 'attack'],
    'offensive': ['fescennine', 'rabelaisian', 'abhorrent', 'abominable', 'abusive', 'aggravated assault', 'aggression', 'aggressive', 'amphibious attack', 'antagonistic', 'appalling', 'armed assault'],
    'offer': ['accommodation', 'accord', 'accordance', 'adduce', 'administer', 'advance', 'afford', 'allege', 'allot', 'allow', 'approach', 'array'],
    'offered': ['arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'nonmandatory', 'optional', 'proffered'],
    'offering': ['christmas present', 'advance', 'alms', 'alms fee', 'approach', 'asking price', 'award', 'benefaction', 'beneficence', 'bid', 'birthday present', 'box'],
    'offertory': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'negro spiritual', 'nunc dimittis', 'te deum', 'trisagion'],
    'offhand': ['bohemian', 'abrupt', 'ad lib', 'ad libitum', 'ad-lib', 'affable', 'airily', 'airy', 'aloof', 'any old way', 'any which way', 'anyhow'],
    'office': ['mass', 'act of grace', 'act of kindness', 'advice', 'advocacy', 'aegis', 'agency', 'agentship', 'aid', 'alerting', 'appointment', 'area'],
    'office boy': ['ganymede', 'hebe', 'airline hostess', 'airline stewardess', 'attendant', 'batman', 'bellboy', 'bellhop', 'bellman', 'bootblack', 'boots', 'cabin boy'],
    'officeholder': ['bureaucrat', 'civil servant', 'functionary', 'functionnaire', 'holdover', 'incumbent', 'ins', 'jack-in-office', 'lame duck', 'mandarin', 'new broom', 'office-bearer'],
    'officer': ['adc', 'co', 'g-man', 'john law', 'mp', 'od', 'administrator', 'aide', 'aide-de-camp', 'apparatchik', 'archon', 'bailiff'],
    'official': ['federal', 'absolute', 'accepted', 'accredited', 'administrative', 'administrator', 'agent', 'amanuensis', 'apparently', 'approved', 'archon', 'aristocratic'],
    'officialdom': ['bureaucracy', 'directorate', 'hierarchy', 'higher echelons', 'higher-ups', 'management', 'ministry', 'prelacy', 'ruling class', 'ruling classes', 'the establishment', 'the administration'],
    'officialese': ['varietyese', 'wall streetese', 'washingtonese', 'bunkum', 'business english', 'businessese', 'cinemese', 'collegese', 'commercialism', 'computerese', 'economese', 'federalese'],
    'officiate': ['act', 'act as', 'adjudicate', 'administer', 'administer the eucharist', 'administrate', 'anoint', 'arbitrate', 'chair', 'chairman', 'chrism', 'conduct'],
    'officious': ['aggressive', 'bold', 'busy', 'busybody', 'demanding', 'dictatorial', 'forward', 'impertinent', 'importunate', 'inquisitive', 'insistent', 'interfering'],
    'offing': ['aftertime', 'afteryears', 'background', 'by-and-by', 'course ahead', 'crystal ball', 'determinism', 'distant future', 'eventuality', 'expectation', 'foresight', 'forward look'],
    'offish': ['olympian', 'above all that', 'ailing', 'aloof', 'backward', 'bashful', 'blank', 'chilled', 'chilly', 'cold', 'constrained', 'cool'],
    'offscourings': ['afterglow', 'afterimage', 'balance', 'bilge', 'bilgewater', 'bones', 'butt', 'butt end', 'candle ends', 'carrion', 'cattle', 'chaff'],
    'offset': ['absorb the shock', 'albertype', 'analog process', 'annul', 'antacid', 'antidote', 'antipode', 'antipodes', 'antipole', 'antithesis', 'antonym', 'atone for'],
    'offsetting': ['amendatory', 'amends', 'annulling', 'annulment', 'antacid', 'atonement', 'balancing', 'buffering', 'canceling', 'cancellation', 'commutation', 'compensating'],
    'offshoot': ['accession', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct', 'adjuvant'],
    'offspring': ['aftermath', 'artifact', 'bairn', 'brainchild', 'breed', 'brood', 'by-product', 'cherub', 'child', 'children', 'chit', 'coinage'],
    'often': ['again and again', 'commonly', 'continually', 'day after day', 'day by day', 'frequently', 'habitually', 'in many instances', 'many a time', 'many times', 'many times over', 'most often'],
    'ogle': ['amorous looks', 'attend', 'bedroom eyes', 'cast coquettish glances', 'come-hither look', 'contemplate', 'coquet', 'coquetry', 'coquettish glances', 'coquettishness', 'coyness', 'crane'],
    'ogre': ['argus', 'briareus', 'cerberus', 'charybdis', 'cyclops', 'dracula', 'echidna', 'frankenstein', 'gorgon', 'harpy', 'hydra', 'loch ness monster'],
    'oil': ['barbados tar', 'haliver oil', 'macassar oil', 'absinthe', 'adipose tissue', 'adulation', 'aid', 'alcohol', 'animal oils', 'anoint', 'anthracene oil', 'aquarelle'],
    'oily': ['pecksniffian', 'adipose', 'adulatory', 'bland', 'blandishing', 'blarneying', 'blubbery', 'buttery', 'butyraceous', 'cajoling', 'canting', 'chrismal'],
    'ointment': ['balm', 'balsam', 'blunt', 'boodle', 'brass', 'bread', 'brilliantine', 'bucks', 'cabbage', 'cerate', 'chips', 'chrism'],
    'ok': ['john hancock', 'roger', 'absolute', 'absolutely', 'accede to', 'accept', 'acceptable', 'acceptance', 'accord', 'accord to', 'accredit', 'accurate'],
    'old': ['abandoned', 'abjured', 'adult', 'advanced', 'advanced in life', 'advanced in years', 'age-old', 'aged', 'ageless', 'along in years', 'ancient', 'antediluvian'],
    'old days': ['auld lang syne', 'days beyond recall', 'days of old', 'days of yore', 'early times', 'eld', 'good old times', 'lang syne', 'long ago', 'old story', 'old times', 'olden times'],
    'old fogy': ['methuselah', 'antediluvian', 'antique', 'back number', 'conservationist', 'conservatist', 'conservative', 'dad', 'diehard', 'dodo', 'dotard', 'elder'],
    'old hat': ['antique', 'archaic', 'back-number', 'banal', 'behind the times', 'bewhiskered', 'bromidic', 'common', 'commonplace', 'corny', 'cut-and-dried', 'dated'],
    'old lady': ['dulcinea', 'beldam', 'best girl', 'better half', 'common-law wife', 'concubine', 'crone', 'dame', 'dowager', 'dream girl', 'feme', 'feme covert'],
    'old line': ['backward', 'confirmed', 'conservative', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid', 'deep-rooted', 'deep-seated', 'deep-set', 'deep-settled'],
    'old maid': ['victorian', 'bachelor girl', 'bluenose', 'feme sole', 'fuddy-duddy', 'fuss', 'fuss-budget', 'fusser', 'fusspot', 'goody-goody', 'granny', 'lone woman'],
    'old man': ['casanova', 'don juan', 'father time', 'lothario', 'methuselah', 'nestor', 'old paar', 'romeo', 'abba', 'amoroso', 'antediluvian', 'antique'],
    'old master': ['art object', 'artisan', 'artist', 'artiste', 'brainchild', 'bric-a-brac', 'classic', 'composition', 'copyist', 'craftsman', 'creation', 'creator'],
    'old saw': ['banality', 'bromide', 'chestnut', 'cliche', 'commonplace', 'commonplace expression', 'corn', 'familiar tune', 'hackneyed saying', 'lieu commun', 'locus communis', 'old joke'],
    'old story': ['auld lang syne', 'banality', 'bromide', 'chestnut', 'cliche', 'commonplace', 'commonplace expression', 'corn', 'days beyond recall', 'days of old', 'days of yore', 'early times'],
    'old timer': ['father time', 'methuselah', 'nestor', 'old paar', 'ancient', 'antediluvian', 'antique', 'back number', 'centenarian', 'conservative', 'dad', 'dodo'],
    'old times': ['auld lang syne', 'days beyond recall', 'days of old', 'days of yore', 'early times', 'eld', 'good old times', 'lang syne', 'long ago', 'old days', 'old story', 'olden times'],
    'old woman': ['lord fauntleroy', 'methuselah', 'percy', 'antediluvian', 'antique', 'back number', 'beldam', 'better half', 'chicken', 'common-law wife', 'concubine', 'conservative'],
    'old world': ['gothic', 'victorian', 'antediluvian', 'antiquated', 'antique', 'archaic', 'ceremonious', 'chivalric', 'chivalrous', 'classical', 'courtly', 'formal'],
    'old-fashioned': ['victorian', 'abandoned', 'abjured', 'aged', 'ancient', 'antiquated', 'antique', 'archaic', 'back-number', 'backward', 'behind the times', 'belated'],
    'older': ['father time', 'methuselah', 'nestor', 'old paar', 'antecedent', 'anterior', 'anticipatory', 'centenarian', 'ci-devant', 'dean', 'dotard', 'doyen'],
    'oldness': ['advanced age', 'advanced years', 'age of retirement', 'an incurable disease', 'anility', 'caducity', 'debility', 'decline of life', 'declining years', 'decrepitude', 'dotage', 'eld'],
    'oleo': ['butter', 'buttermilk', 'certified milk', 'cheese', 'condensed milk', 'cream', 'dairy products', 'ghee', 'half-and-half', 'heavy cream', 'light cream', 'margarine'],
    'olio': ['irish stew', 'all sorts', 'assemblage', 'assortment', 'bouillabaisse', 'brew', 'broad spectrum', 'chowder', 'conglomeration', 'curry', 'etuvee', 'fricassee'],
    'olive': ['aestival', 'beryl-green', 'berylline', 'blue-green', 'bluish-green', 'chartreuse', 'chloranemic', 'chlorine', 'chlorotic', 'citrine', 'citrinous', 'emerald'],
    'ology': ['academic discipline', 'academic specialty', 'applied science', 'area', 'arena', 'art', 'concern', 'department of knowledge', 'discipline', 'domain', 'field', 'field of inquiry'],
    'olympian': ['elysian', 'laodicean', 'above all that', 'aerial', 'airy', 'aloof', 'altitudinous', 'apathetic', 'ascending', 'aspiring', 'backward', 'bashful'],
    'olympic gods': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'olympics': ['highland games', 'olympiad', 'olympic games', 'bout', 'carousel', 'concours', 'contest', 'derby', 'encounter', 'engagement', 'field day', 'fight'],
    'ombudsman': ['ja', 'agent', 'amicus curiae', 'assessor', 'barmaster', 'chancellor', 'circuit judge', 'connection', 'deputy', 'front', 'front man', 'go-between'],
    'omega': ['apodosis', 'catastrophe', 'ceasing', 'cessation', 'coda', 'conclusion', 'consummation', 'crack of doom', 'culmination', 'curtain', 'curtains', 'death'],
    'omen': ['actuarial prediction', 'adumbrate', 'adumbration', 'apocalypse', 'augur', 'augury', 'auspicate', 'auspice', 'betoken', 'betokening', 'betokenment', 'bode'],
    'ominous': ['abusive', 'admonitory', 'apocalyptic', 'augural', 'bad', 'badly off', 'baleful', 'baneful', 'black', 'bludgeoning', 'blustering', 'bodeful'],
    'omission': ['sisyphean labor', 'abbreviation', 'abridgment', 'absence', 'arrearage', 'atrocity', 'bad policy', 'balk', 'ban', 'bar', 'barring', 'beggary'],
    'omit': ['abandon', 'abbreviate', 'abridge', 'ban', 'bar', 'bar out', 'blink at', 'blockade', 'blot out', 'blue-pencil', 'bowdlerize', 'cancel'],
    'omitting': ['aside from', 'bar', 'barring', 'beside', 'besides', 'ex', 'except', 'except for', 'excepting', 'excluding', 'exclusive of', 'leaving out'],
    'omnibus': ['festschrift', 'absolute', 'across-the-board', 'aggregate', 'album', 'all', 'all-comprehensive', 'all-embracing', 'all-encompassing', 'all-inclusive', 'all-out', 'all-pervading'],
    'omnipotence': ['all-powerfulness', 'almightiness', 'eternity', 'glory', 'holiness', 'immutability', 'infinite goodness', 'infinite justice', 'infinite love', 'infinite mercy', 'infinite power', 'infinite wisdom'],
    'omnipotent': ['absolute', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'boundless', 'changeless', 'creating', 'creative', 'divine', 'eternal'],
    'omnipresence': ['completeness', 'comprehensiveness', 'entireness', 'entirety', 'eternity', 'everywhereness', 'exhaustiveness', 'glory', 'holiness', 'immutability', 'inclusiveness', 'infinite goodness'],
    'omnipresent': ['absolute', 'all-embracing', 'all-encompassing', 'all-knowing', 'all-out', 'all-pervading', 'all-powerful', 'all-present', 'all-seeing', 'all-wise', 'allover', 'almighty'],
    'omniscience': ['all-knowingness', 'cross-disciplinary knowledge', 'deep knowledge', 'encyclopedic knowledge', 'eternity', 'expertise', 'extensive knowledge', 'general knowledge', 'glory', 'holiness', 'immutability', 'infinite goodness'],
    'omniscient': ['all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'apperceptive', 'appercipient', 'apprehending', 'apprehensive', 'aware', 'boundless', 'changeless'],
    'omnivorous': ['apician', 'a hog for', 'acquisitive', 'all-devouring', 'avaricious', 'avid', 'bolting', 'bottomless', 'cannibal', 'cannibalistic', 'carnivorous', 'commensal'],
    'on': ['about', 'above', 'accidental', 'accompanying', 'across', 'ado', 'afloat', 'afoot', 'after which', 'against', 'ahead', 'along'],
    'on a par': ['alike', 'at par', 'au pair', 'commensurate', 'drawn', 'equal', 'equalized', 'even', 'even stephen', 'fifty-fifty', 'half-and-half', 'knotted'],
    'on account of': ['after', 'because of', 'by reason of', 'by virtue of', 'considering', 'due to', 'for', 'in aid of', 'in behalf of', 'in consideration of', 'in favor of', 'in furtherance of'],
    'on and on': ['ad infinitum', 'again and again', 'always', 'at a stretch', 'at all times', 'ceaselessly', 'connectedly', 'constantly', 'continually', 'continuously', 'cumulatively', 'cyclically'],
    'on board': ['aboard', 'accessible', 'afloat', 'all aboard', 'aloft', 'among us', 'at hand', 'athwart the hawse', 'athwarthawse', 'attendant', 'available', 'before the mast'],
    'on call': ['cod', 'accessible', 'adaptable', 'all-around', 'at demand', 'at hand', 'available', 'cash', 'cash down', 'cash on delivery', 'convenient', 'down'],
    'on duty': ['at it', 'at work', 'busy', 'employed', 'engaged', 'full of business', 'hard at it', 'hard at work', 'in harness', 'occupied', 'on the go', 'on the hop'],
    'on edge': ['all nerves', 'antsy', 'antsy-pantsy', 'anxious', 'apprehensive', 'breathless', 'chafing', 'eager', 'edgy', 'excitable', 'excited', 'fearful'],
    'on end': ['ad infinitum', 'again and again', 'at a stretch', 'at attention', 'bolt upright', 'ceaselessly', 'connectedly', 'constantly', 'continually', 'continuously', 'cumulatively', 'cyclically'],
    'on guard': ['argus-eyed', 'all ears', 'all eyes', 'at bay', 'aux abois', 'aux aguets', 'canny', 'careful', 'cautious', 'circumspect', 'custodial', 'defensively'],
    'on hand': ['accessible', 'adaptable', 'all-around', 'at hand', 'attendant', 'available', 'by one', 'convenient', 'free and clear', 'handy', 'held', 'immanent'],
    'on high': ['above', 'abovestairs', 'airward', 'aloft', 'aloof', 'among the blest', 'ethereally', 'high', 'high up', 'in glory', 'in heaven', 'in the air'],
    'on ice': ['ascertained', 'assured', 'attested', 'certified', 'cooked-up', 'cut out', 'cut-and-dried', 'cut-and-dry', 'decided', 'determinate', 'determined', 'established'],
    'on paper': ['autograph', 'autographic', 'calligraphic', 'chirographic', 'cursive', 'engrossed', 'flowing', 'graphic', 'graphoanalytic', 'graphologic', 'graphometric', 'holograph'],
    'on purpose': ['advisedly', 'by design', 'calculatedly', 'consciously', 'contemplatedly', 'deliberately', 'designedly', 'in cold blood', 'intentionally', 'knowingly', 'meditatedly', 'pointedly'],
    'on record': ['booked', 'documented', 'down', 'enrolled', 'entered', 'filed', 'indexed', 'inscribed', 'legal', 'logged', 'minuted', 'of record'],
    'on tenterhooks': ['addled', 'agitated', 'all-overish', 'anxious', 'anxioused up', 'apprehensive', 'at a loss', 'baffled', 'bamboozled', 'beat', 'bothered', 'buffaloed'],
    'on the ball': ['advertent', 'agile', 'agog', 'alert', 'alive', 'all ears', 'all eyes', 'assiduous', 'attentive', 'awake', 'aware', 'bright'],
    'on the beam': ['aside', 'askance', 'askant', 'asquint', 'broadside', 'broadside on', 'crabwise', 'directly', 'down the alley', 'edgeway', 'edgeways', 'edgewise'],
    'on the brink': ['about to', 'at next hand', 'at the limit', 'at the periphery', 'at the threshold', 'bordering on', 'close to', 'close upon', 'hard on', 'marginally', 'near', 'near to'],
    'on the double': ['amain', 'apace', 'at flank speed', 'at the double', 'crowded', 'double-quick', 'double-time', 'expeditiously', 'fast', 'hand over fist', 'hand over hand', 'hard-pressed'],
    'on the fence': ['laodicean', 'apathetic', 'centrist', 'even', 'fifty-fifty', 'half-and-half', 'impartial', 'independent', 'indifferent', 'midway', 'moderate', 'mugwumpian'],
    'on the fritz': ['amiss', 'askew', 'awry', 'broken', 'cockeyed', 'convulsed', 'deranged', 'disarranged', 'discomfited', 'discomposed', 'disconcerted', 'dislocated'],
    'on the go': ['astir', 'at it', 'at work', 'busy', 'employed', 'en route', 'engaged', 'full of business', 'hard at it', 'hard at work', 'in harness', 'in motion'],
    'on the house': ['as a gift', 'charitable', 'complimentary', 'costless', 'eleemosynary', 'expenseless', 'for free', 'for love', 'for nothing', 'free', 'free as air', 'free for nothing'],
    'on the job': ['advertent', 'agile', 'agog', 'alert', 'alive', 'all ears', 'all eyes', 'assiduous', 'at it', 'at work', 'attentive', 'awake'],
    'on the level': ['aboveboard', 'authentic', 'bona fide', 'fair and square', 'foursquare', 'genuine', 'good-faith', 'on the square', 'on the up-and-up', 'open', 'open and aboveboard', 'single-hearted'],
    'on the lookout': ['argus-eyed', 'all ears', 'all eyes', 'aux aguets', 'custodial', 'eagle-eyed', 'guarded', 'hawk-eyed', 'keen-eyed', 'lidless', 'observant', 'on guard'],
    'on the move': ['astir', 'at it', 'at work', 'busy', 'employed', 'en route', 'engaged', 'full of business', 'hard at it', 'hard at work', 'in harness', 'in motion'],
    'on the rocks': ['aground', 'bankrupt', 'broke', 'broken', 'busted', 'castaway', 'destitute', 'failed', 'foundered', 'grounded', 'hard and fast', 'high and dry'],
    'on the run': ['amain', 'apace', 'astir', 'at it', 'at once', 'at work', 'busy', 'by forced marches', 'cursorily', 'employed', 'en route', 'engaged'],
    'on the shelf': ['abandoned', 'abjured', 'antiquated', 'antique', 'archaic', 'deserted', 'discontinued', 'disused', 'done with', 'not worth saving', 'obsolescent', 'obsolete'],
    'on the side': ['above', 'additionally', 'again', 'all included', 'also', 'altogether', 'among other things', 'and all', 'and also', 'and so', 'as well', 'aside'],
    'on the spot': ['pdq', 'aboard', 'among us', 'apace', 'as of now', 'as things are', 'at once', 'at present', 'at this juncture', 'at this moment', 'at this point', 'at this time'],
    'on the verge': ['about to', 'at next hand', 'at the limit', 'at the periphery', 'at the threshold', 'bordering on', 'close to', 'close upon', 'hard on', 'marginally', 'near', 'near to'],
    'on the wagon': ['apostolic', 'encratic', 'lenten', 'pythagorean', 'rechabite', 'shaker', 'spartan', 'stoic', 'abstemious', 'abstinent', 'ascetic', 'celibate'],
    'on the wane': ['contractive', 'declining', 'decreasing', 'decrescendo', 'decrescent', 'deliquescent', 'diminishing', 'diminuendo', 'dwindling', 'languishing', 'lessening', 'on the decline'],
    'on the way': ['along the way', 'as one goes', 'brewing', 'en passant', 'en route', 'forthcoming', 'going on', 'in embryo', 'in hand', 'in mid-progress', 'in passing', 'in preparation'],
    'on the whole': ['after all', 'all in all', 'all things considered', 'almost entirely', 'altogether', 'approximately', 'as a rule', 'as a whole', 'as an approximation', 'at large', 'before the bench', 'before the court'],
    'on to': ['alive to', 'appreciative of', 'apprised of', 'awake to', 'aware of', 'behind the curtain', 'behind the scenes', 'cognizant of', 'conscious of', 'hep to', 'in the know', 'in the secret'],
    'on trust': ['believingly', 'devoutly', 'in installments', 'on account', 'on budget terms', 'on credit', 'on easy terms', 'on faith', 'on good terms', 'on terms', 'on the cuff', 'on tick'],
    'once': ['alone', 'already', 'ancient', 'anytime', 'anyway', 'anywise', 'apart', 'at a stroke', 'at all', 'at any time', 'at intervals', 'at once'],
    'oncoming': ['access', 'accession', 'advance', 'advancing', 'advent', 'afflux', 'affluxion', 'alpha', 'approach', 'approaching', 'appropinquation', 'approximate'],
    'one': ['adamite', 'a certain', 'ace', 'aggregate', 'alike', 'all', 'all one', 'all the same', 'all-embracing', 'all-inclusive', 'all-knowing', 'all-powerful'],
    'one and all': ['a to z', 'a to izzard', 'aggregate', 'all', 'all agreeing', 'all and some', 'all and sundry', 'all hands', 'all the world', 'all together', 'alpha and omega', 'altogether'],
    'one and only': ['absolute', 'ace', 'alone', 'atom', 'azygous', 'celibate', 'first and last', 'impair', 'lone', 'monad', 'no other', 'none else'],
    'one by one': ['adrift', 'alone', 'apart', 'apart from', 'apiece', 'aside from', 'asunder', 'away from', 'by itself', 'each', 'each to each', 'in the abstract'],
    'one horse': ['cramped', 'dinky', 'exiguous', 'half-pint', 'jerkwater', 'knee-high', 'limited', 'little', 'measly', 'niggling', 'petite', 'pettifogging'],
    'one piece': ['monadal', 'monadic', 'one-sided', 'uniangulate', 'unibivalent', 'unibranchiate', 'unicameral', 'unicellular', 'unicuspid', 'unidentate', 'unidigitate', 'unidimensional'],
    'one sided': ['anamorphous', 'antiblack', 'askew', 'asymmetric', 'bent', 'biased', 'bifacial', 'bilateral', 'bowed', 'chauvinistic', 'cockeyed', 'colored'],
    'one upmanship': ['italian hand', 'accomplishment', 'acuteness', 'art', 'artfulness', 'artifice', 'ascendancy', 'astuteness', 'cageyness', 'callidity', 'canniness', 'cleverness'],
    'oneness': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'allness', 'amity', 'assent', 'bill', 'bonds of harmony', 'bone', 'brotherly love'],
    'onerous': ['herculean', 'annoying', 'arduous', 'arduously', 'backbreaking', 'besetting', 'bothersome', 'burdensome', 'burdensomely', 'crushing', 'cumbersome', 'cumbrous'],
    'oneself': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'ego', 'ethical self', 'he', 'her', 'herself', 'him', 'himself'],
    'onetime': ['ancient', 'bygone', 'early', 'erstwhile', 'fore', 'former', 'immemorial', 'late', 'old', 'olden', 'once', 'past'],
    'ongoing': ['brownian movement', 'accidental', 'accompanying', 'acting', 'active', 'ado', 'advance', 'advancement', 'advancing', 'afloat', 'afoot', 'ameliorative'],
    'onlooker': ['tv-viewer', 'abutter', 'adjoiner', 'beholder', 'bird-watcher', 'borderer', 'bystander', 'drugstore cowboy', 'eyewitness', 'gaper', 'gazer', 'gazer-on'],
    'only': ['absolute', 'after a fashion', 'alone', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst'],
    'onomatopoeia': ['bowwow theory', 'copying', 'counterfeiting', 'echoic word', 'emulation', 'fakery', 'following', 'forgery', 'hit-off', 'imitation', 'impersonation', 'imposture'],
    'onomatopoeic': ['apish', 'conjugate', 'delineatory', 'depictive', 'derivative', 'echoic', 'embodying', 'emulative', 'etymologic', 'figurative', 'graphic', 'ideographic'],
    'onrush': ['brownian movement', 'advance', 'affluence', 'afflux', 'affluxion', 'angular motion', 'ascending', 'ascent', 'axial motion', 'backflowing', 'backing', 'backward motion'],
    'onset': ['aggravated assault', 'aggression', 'albertype', 'alpha', 'amphibious attack', 'appearance', 'armed assault', 'assailing', 'assailment', 'assault', 'attack', 'banzai attack'],
    'onslaught': ['abuse', 'aggravated assault', 'aggression', 'amphibious attack', 'appulse', 'armed assault', 'assailing', 'assailment', 'assault', 'attack', 'banzai attack', 'battering'],
    'ontology': ['aesthetics', 'axiology', 'casuistry', 'cosmology', 'epistemology', 'ethics', 'existentialism', 'first philosophy', 'gnosiology', 'logic', 'mental philosophy', 'metaphysics'],
    'onus': ['absolute indication', 'allegiance', 'arraignability', 'arraignableness', 'aspersion', 'assigned task', 'attaint', 'badge of infamy', 'bar sinister', 'baton', 'bend sinister', 'black eye'],
    'onward': ['advancing', 'ahead', 'alee', 'along', 'en route to', 'facing', 'for', 'forth', 'forward', 'forward-looking', 'forwards', 'frontward'],
    'oodles': ['batch', 'considerable', 'deal', 'gobs', 'good deal', 'great deal', 'heap', 'heaps', 'jillion', 'lashings', 'loads', 'lot'],
    'ooze': ['bleed', 'clay', 'discharge', 'drain', 'drip', 'effuse', 'effusion', 'emit', 'excrete', 'excretion', 'exfiltrate', 'exfiltration'],
    'opacity': ['abstruseness', 'adiaphanousness', 'ambiguity', 'amorphousness', 'asininity', 'blockishness', 'boobishness', 'boorishness', 'bovinity', 'cloddishness', 'cloudiness', 'crassness'],
    'opalescent': ['burele', 'chatoyant', 'creamy', 'delicate', 'eggshell', 'flat', 'gloss', 'iridal', 'iridescent', 'iridial', 'iridian', 'irisated'],
    'opaque': ['boeotian', 'abstruse', 'adiaphanous', 'ambiguous', 'amorphous', 'amphibological', 'arcane', 'asinine', 'backward', 'baffling', 'becloud', 'beef-brained'],
    'open': ['spartan', 'abandoned', 'aboveboard', 'absolute', 'accented', 'acceptable', 'accessible', 'activate', 'admissible', 'admissive', 'admissory', 'adumbrate'],
    'open air': ['aerial', 'aeriform', 'aery', 'airish', 'airlike', 'airy', 'alfresco', 'atmospheric', 'breezy', 'ethereal', 'exposed', 'light'],
    'open and aboveboard': ['aboveboard', 'authentic', 'bona fide', 'fair and square', 'foursquare', 'genuine', 'good-faith', 'on the level', 'on the square', 'on the up-and-up', 'open', 'single-hearted'],
    'open classroom school': ['alternate', 'alternative school', 'blab school', 'boarding school', 'central school', 'consolidated school', 'continuation school', 'correspondence school', 'country day school', 'dame school', 'day school', 'evening school'],
    'open door': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'access', 'amiability', 'appeasement', 'balance of power', 'bonhomie', 'brinkmanship', 'coexistence', 'colonialism'],
    'open eyed': ['argus-eyed', 'advertent', 'agape', 'aghast', 'agog', 'alert', 'all agog', 'all ears', 'all eyes', 'amazed', 'assiduous', 'astonished'],
    'open fire': ['aim at', 'barrage', 'blast', 'blitz', 'bombard', 'breach', 'cannon', 'cannonade', 'commence firing', 'enfilade', 'fire a volley', 'fire at'],
    'open forum': ['agora', 'airing', 'amphitheater', 'analysis', 'arena', 'athletic field', 'auditorium', 'background', 'bear garden', 'bowl', 'boxing ring', 'bull ring'],
    'open market': ['dow-jones industrial average', 'wall street', 'auto show', 'bazaar', 'boat show', 'commercial complex', 'competitive market', 'emporium', 'exposition', 'fair', 'flea fair', 'flea market'],
    'open minded': ['accessible', 'admissive', 'amenable', 'broad-minded', 'freethinking', 'impressionable', 'influenceable', 'latitudinarian', 'liberal', 'libertarian', 'libertine', 'malleable'],
    'open sesame': ['rasputin', 'svengali', 'vip', 'abracadabra', 'access', 'bad influence', 'big wheel', 'bottle opener', 'can opener', 'church key', 'clavis', 'conjuration'],
    'open to': ['accessible', 'answerable for', 'approachable', 'apt to', 'attainable', 'available', 'capable of', 'come-at-able', 'dependent on', 'exposed to', 'findable', 'getatable'],
    'open to question': ['arguable', 'at issue', 'confutable', 'conjectural', 'contestable', 'controversial', 'controvertible', 'debatable', 'deniable', 'disputable', 'doubtable', 'doubtful'],
    'open up': ['acknowledge', 'admit', 'admit everything', 'advance', 'aid', 'air', 'allow', 'appear', 'avow', 'bare', 'branch', 'branch out'],
    'open-and-shut': ['apparent', 'ascertained', 'assured', 'attested', 'certified', 'clear', 'clear as crystal', 'crystal-clear', 'decided', 'determinate', 'determined', 'discernible'],
    'opener': ['bottle opener', 'can opener', 'church key', 'clavis', 'coming out', 'corkscrew', 'curtain raiser', 'debut', 'embarkation', 'embarkment', 'first appearance', 'floating'],
    'openhanded': ['apparent', 'big', 'bighearted', 'bounteous', 'bountiful', 'chivalrous', 'distinct', 'elevated', 'evident', 'exalted', 'free', 'freehanded'],
    'openhearted': ['amiable', 'artless', 'bighearted', 'bluff', 'blunt', 'born yesterday', 'bounteous', 'bountiful', 'broad', 'brusque', 'candid', 'childlike'],
    'opening': ['a leg up', 'abysm', 'abyss', 'access', 'adit', 'air lock', 'aisle', 'alley', 'alpha', 'ambulatory', 'aperture', 'apparition'],
    'opening move': ['alpha', 'breaking-in', 'first', 'first blush', 'first glance', 'first impression', 'first inning', 'first lap', 'first move', 'first round', 'first sight', 'first stage'],
    'openly': ['abominably', 'aboveboard', 'agonizingly', 'all joking aside', 'apparently', 'artlessly', 'audaciously', 'awfully', 'baldly', 'balefully', 'before one', 'bitterly'],
    'openmouthed': ['advertent', 'agape', 'aghast', 'agog', 'ajar', 'alert', 'all agog', 'all ears', 'all eyes', 'amazed', 'assiduous', 'astonished'],
    'openness': ['access', 'accessibility', 'admissibility', 'admission', 'amenableness', 'apparentness', 'approachability', 'artlessness', 'assimilation', 'austerity', 'availability', 'baldness'],
    'opera': ['broadway musical', 'elizabethan theater', 'globe theatre', 'grand guignol', 'greek theater', 'passion play', 'singspiel', 'tom show', 'amphitheater', 'antimasque', 'arena theater', 'arrangement'],
    'opera house': ['elizabethan theater', 'globe theatre', 'greek theater', 'amphitheater', 'arena', 'arena theater', 'assembly hall', 'auditorium', 'cabaret', 'chapel', 'circle theater', 'club'],
    'opera singer': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso profundo', 'blues singer'],
    'operable': ['achievable', 'actable', 'appliable', 'applicable', 'attainable', 'banausic', 'compassable', 'compliant', 'doable', 'effective', 'effectual', 'efficient'],
    'operant': ['actor', 'agent', 'architect', 'author', 'conductor', 'creator', 'doer', 'driver', 'engineer', 'executant', 'executor', 'executrix'],
    'operate': ['act', 'angle', 'be caught short', 'be effective', 'be in action', 'be responsible for', 'be short', 'behave', 'belong', 'brew', 'bucket', 'bucketshop'],
    'operate on': ['act on', 'act upon', 'affect', 'bandage', 'bathe', 'care for', 'concentrate on', 'cure', 'diagnose', 'doctor', 'flux', 'focus on'],
    'operatic': ['actor-proof', 'all-star', 'alto', 'ballet', 'balletic', 'baritone', 'bass', 'bravura', 'choral', 'choric', 'cinematic', 'cinematographic'],
    'operating': ['acting', 'active', 'at work', 'behavioral', 'functional', 'functioning', 'going', 'going on', 'in exercise', 'in force', 'in hand', 'in operation'],
    'operating room': ['x ray', 'blood bank', 'charity ward', 'clinic', 'consultation room', 'delivery room', 'dispensary', 'emergency', 'examining room', 'fever ward', 'hospital room', 'intensive care'],
    'operation': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'acting', 'action', 'activism', 'activity', 'adventure', 'affair', 'amphibious operations'],
    'operational': ['acting', 'active', 'agential', 'agentival', 'agentive', 'at work', 'behavioral', 'effective', 'effectual', 'efficacious', 'efficient', 'functional'],
    'operative': ['bow street runner', 'cia man', 'fbi', 'fbi agent', 'federal', 'g-man', 'secret service', 'sherlock holmes', 't-man', 'accessible', 'active', 'actor'],
    'operator': ['machiavellian', 'pbx operator', 'activist', 'actor', 'administrator', 'adventurer', 'agent', 'architect', 'author', 'ball of fire', 'beaver', 'behind-the-scenes operator'],
    'operetta': ['broadway musical', 'singspiel', 'ballad opera', 'ballet', 'ballet divertissement', 'chorus show', 'comedy ballet', 'comic opera', 'dance drama', 'grand opera', 'light opera', 'lyric drama'],
    'operose': ['herculean', 'abstruse', 'arduous', 'assiduous', 'backbreaking', 'brutal', 'burdensome', 'complex', 'critical', 'crushing', 'delicate', 'demanding'],
    'ophthalmologist': ['anesthesiologist', 'cardiologist', 'chiropodist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'immunologist', 'internist', 'microscopist', 'neurologist'],
    'opiate': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'opine': ['account', 'account as', 'adjudge', 'adjudicate', 'allow', 'allude to', 'assume', 'be afraid', 'be judicious', 'believe', 'blurt', 'blurt out'],
    'opinion': ['admonition', 'advice', 'advising', 'advocacy', 'affect', 'affectivity', 'analyzing', 'appraisal', 'appraisement', 'appraising', 'appreciation', 'apprehension'],
    'opinionated': ['antiblack', 'balking', 'balky', 'biased', 'bigoted', 'bulldogged', 'bulletheaded', 'bullheaded', 'case-hardened', 'chauvinistic', 'cocksure', 'colored'],
    'opium': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'opossum': ['angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'cape polecat', 'indian buffalo', 'kodiak bear', 'virginia deer', 'aardvark', 'aardwolf', 'alpaca', 'anteater'],
    'opponent': ['adversary', 'adversative', 'adverse', 'alien', 'antagonist', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'assailant', 'clashing', 'combatant'],
    'opportune': ['a propos', 'ad rem', 'adapted', 'advantageous', 'advisable', 'applicable', 'apposite', 'appropriate', 'apropos', 'apt', 'auspicious', 'becoming'],
    'opportunity': ['a leg up', 'accidentality', 'actuarial calculation', 'adventitiousness', 'bout', 'break', 'casualness', 'chance', 'clear stage', 'destiny', 'fair field', 'fair game'],
    'oppose': ['abjure', 'agree to differ', 'agree to disagree', 'analogize', 'antagonize', 'array', 'arrest', 'assert the contrary', 'assimilate', 'attack', 'balance', 'ban'],
    'opposed': ['adversary', 'adversative', 'adverse', 'adversive', 'against', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'antonymous', 'at cross-purposes'],
    'opposer': ['adversary', 'antagonist', 'anti', 'bitter-ender', 'brawler', 'con', 'defendant', 'diehard', 'disputant', 'dissentient', 'dissident', 'intransigent'],
    'opposing': ['abjuratory', 'abnegative', 'adversary', 'adversative', 'adverse', 'adversive', 'against', 'alien', 'alienated', 'allegory', 'analogy', 'antagonistic'],
    'opposite': ['across', 'adversary', 'adversative', 'adverse', 'adversive', 'against', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antipodal', 'antipode'],
    'opposite number': ['antipode', 'antipodes', 'antipole', 'antithesis', 'antonym', 'coequal', 'compeer', 'complement', 'contra', 'converse', 'coordinate', 'counter'],
    'opposition': ['adversary', 'adversity', 'agreement to disagree', 'alienation', 'allegory', 'analogy', 'antagonism', 'antagonist', 'antagonistic', 'anteposition', 'antipathy', 'antithesis'],
    'opposition party': ['american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party', 'greenback party'],
    'oppositional': ['adversary', 'adversative', 'adverse', 'adversive', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'antonymous', 'at cross-purposes', 'balancing'],
    'oppress': ['abuse', 'addict', 'afflict', 'aggrieve', 'anguish', 'bear hard upon', 'beat down', 'beset', 'break', 'break down', 'bring to tears', 'browbeat'],
    'oppressed': ['abused', 'bond', 'browbeaten', 'burdened', 'captive', 'charged', 'cumbered', 'disenfranchised', 'downtrod', 'downtrodden', 'encumbered', 'enslaved'],
    'oppression': ['mccarthyism', 'schmerz', 'slough of despond', 'abuse', 'affliction', 'airlessness', 'anguish', 'argumentum baculinum', 'bale', 'big stick', 'bitter cup', 'bitter draft'],
    'oppressive': ['herculean', 'absolute', 'absolutist', 'absolutistic', 'agonizing', 'airless', 'annoying', 'arbitrary', 'arduous', 'aristocratic', 'arrogant', 'authoritarian'],
    'oppressor': ['simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'autocrat', 'bully', 'caesar', 'commissar', 'czar', 'despot'],
    'opprobrium': ['abuse', 'calumny', 'contumely', 'degradation', 'demotion', 'depluming', 'discredit', 'disesteem', 'dishonor', 'displuming', 'disrepute', 'ignobility'],
    'oppugn': ['antagonize', 'battle', 'be antipathetic', 'be at cross-purposes', 'be contrary to', 'be inimical', 'be opposed to', 'beat against', 'belie', 'call into question', 'challenge', 'clash'],
    'optic': ['baby blues', 'banjo eyes', 'bright eyes', 'clear eyes', 'cornea', 'eye', 'eyeball', 'eyelid', 'goggle eyes', 'iris', 'lens', 'lid'],
    'optics': ['newtonian physics', 'acoustics', 'actinology', 'actinometry', 'aerophysics', 'applied physics', 'astrophysics', 'basic conductor physics', 'biophysics', 'catoptrics', 'chemical physics', 'cryogenics'],
    'optimal': ['best', 'champion', 'choice', 'elect', 'elite', 'for the best', 'greatest', 'handpicked', 'matchless', 'optimum', 'paramount', 'peerless'],
    'optimism': ['leibnizian optimism', 'pollyannaism', 'blitheness', 'blithesomeness', 'bright outlook', 'bright side', 'brightness', 'buoyancy', 'cheer', 'cheerful expectation', 'cheerfulness', 'cheeriness'],
    'optimist': ['leibnizian optimist', 'pollyanna', 'aspirant', 'aspirer', 'chiliast', 'dreamer', 'hopeful', 'hoper', 'idealist', 'irrepressible optimist', 'millenarian', 'millennialist'],
    'optimistic': ['leibnizian', 'agape', 'agog', 'all agog', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'awaiting', 'beaming', 'blithe', 'blithesome'],
    'optimum': ['best', 'capital', 'champion', 'choice', 'chosen', 'cream', 'elect', 'elite', 'excellent', 'exceptional', 'exemplar', 'extraordinary'],
    'option': ['alternate choice', 'alternative', 'call', 'chance', 'choice', 'discretion', 'druthers', 'election', 'emption', 'first option', 'first refusal', 'free choice'],
    'optional': ['alternative', 'arbitrary', 'autonomous', 'discretional', 'discretionary', 'disjunctive', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'nonmandatory'],
    'opulence': ['abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'assets', 'avalanche', 'bonanza', 'bottomless purse', 'bountifulness', 'bountiousness', 'bulging purse'],
    'opulent': ['abounding', 'abounding in riches', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'big-rich', 'bottomless', 'bounteous', 'bountiful', 'comfortable'],
    'opus': ['nachtmusik', 'absolute music', 'adaptation', 'air varie', 'aleatory', 'aleatory music', 'arrangement', 'article', 'artifact', 'autograph', 'best seller', 'book'],
    'or': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'aureate', 'aureateness', 'auric', 'azure'],
    'oracle': ['cassandra', 'delphian oracle', 'delphic oracle', 'delphic tripod', 'dodona', 'pythian oracle', 'python', 'adage', 'advice', 'ana', 'analects', 'answer'],
    'oracular': ['apocalyptic', 'augural', 'auguring', 'bigoted', 'conceited', 'divinatory', 'doctrinaire', 'doctrinarian', 'dogmatic', 'dogmatizing', 'fatidic', 'forecasting'],
    'oral': ['acknowledged', 'admitted', 'answering', 'articulate', 'articulated', 'audition', 'blue book', 'communicating', 'communicational', 'communional', 'conventional', 'conversational'],
    'orange': ['catawba', 'persian melon', 'valencia orange', 'akee', 'alligator pear', 'ananas', 'apple', 'apricot', 'avocado', 'banana', 'bearberry', 'berry'],
    'orate': ['blah-blah', 'bombast', 'debate', 'declaim', 'demagogue', 'elocute', 'harangue', 'hold forth', 'mouth', 'out-herod herod', 'perorate', 'rabble-rouse'],
    'oration': ['address', 'after-dinner speech', 'allocution', 'chalk talk', 'debate', 'declamation', 'declaration', 'diatribe', 'discourse', 'eulogy', 'exhortation', 'filibuster'],
    'oratorio': ['negro spiritual', 'anthem', 'cantata', 'canticle', 'choral singing', 'chorale', 'chorus', 'church music', 'doxology', 'glee', 'gospel', 'gospel music'],
    'oratory': ['lady chapel', 'address', 'articulateness', 'articulation', 'chantry', 'chapel', 'chapel of ease', 'chapel royal', 'command of language', 'command of words', 'debating', 'declamation'],
    'orb': ['aldebaran', 'canicula', 'dog star', 'hesper', 'hesperus', 'lucifer', 'north star', 'phosphor', 'phosphorus', 'polaris', 'sirius', 'venus'],
    'orbit': ['earth insertion', 'lem', 'lm', 'air lane', 'ambit', 'annular muscle', 'annulus', 'aphelion', 'apogee', 'area', 'arena', 'areola'],
    'orbital': ['o-shaped', 'ambagious', 'backhanded', 'circuitous', 'circular', 'deviating', 'deviative', 'devious', 'digressive', 'discursive', 'excursive', 'helical'],
    'orbiting': ['circling', 'circuition', 'circuitousness', 'circuitry', 'circularity', 'circulation', 'circumambience', 'circumambiency', 'circumambulation', 'circumflexion', 'circumlocution', 'circummigration'],
    'orchard': ['arable land', 'barnyard', 'barton', 'bocage', 'bosk', 'cattle ranch', 'chicken farm', 'collective farm', 'coppice', 'copse', 'cotton plantation', 'croft'],
    'orchestra': ['german band', 'philharmonic', 'acting area', 'apron', 'apron stage', 'audience', 'auditorium', 'auditory', 'backstage', 'balcony', 'band', 'band shell'],
    'orchestrate': ['adapt', 'arrange', 'blend', 'compose', 'harmonize', 'instrument', 'instrumentate', 'integrate', 'make an adaptation', 'melodize', 'musicalize', 'put to music'],
    'orchestration': ['nachtmusik', 'absolute music', 'adaptation', 'air varie', 'aleatory', 'aleatory music', 'arrangement', 'chamber music', 'chamber orchestra', 'composition', 'descant', 'electronic music'],
    'orchestrator': ['arranger', 'ballad maker', 'balladeer', 'balladist', 'balladmonger', 'composer', 'contrapuntist', 'ethnomusicologist', 'harmonist', 'harmonizer', 'hymnist', 'hymnographer'],
    'ordain': ['allocate', 'allot', 'appoint', 'appropriate to', 'assign', 'assign to', 'authorize', 'bid', 'call on', 'call the signals', 'call upon', 'canonize'],
    'ordeal': ['sabbat', 'acid test', 'adversity', 'affliction', 'anguish', 'assay', 'blank determination', 'brouillon', 'calvary', 'criterion', 'cross', 'crucial test'],
    'order': ['bronze star medal', 'croix de guerre', 'distinguished conduct medal', 'distinguished flying cross', 'distinguished service cross', 'distinguished service medal', 'distinguished service order', 'distinguished unit citation', 'mo', 'medaille militaire', 'military cross', 'navy cross'],
    'ordered': ['accordant', 'aligned', 'alike', 'arranged', 'arrayed', 'assorted', 'automatic', 'balanced', 'businesslike', 'categorized', 'classified', 'composed'],
    'ordering': ['allocation', 'allotment', 'apportionment', 'arrangement', 'array', 'arraying', 'authority', 'collation', 'collocation', 'command', 'conduct', 'constitution'],
    'orderless': ['aimless', 'aleatoric', 'aleatory', 'amorphic', 'amorphous', 'anarchic', 'baggy', 'blobby', 'blurred', 'blurry', 'broad', 'capricious'],
    'orderly': ['ganymede', 'hebe', 'x-ray technician', 'accordant', 'accurate', 'adjutant', 'airline hostess', 'airline stewardess', 'aligned', 'alike', 'always', 'anesthetist'],
    'ordinal': ['gaussian integer', 'sefer torah', 'torah', 'torah scroll', 'virginal', 'algebraic number', 'algorismic', 'algorithmic', 'aliquot', 'breviary', 'canon', 'cardinal'],
    'ordinance': ['act', 'appointment', 'bill', 'brevet', 'bull', 'bylaw', 'canon', 'ceremonial', 'ceremony', 'code', 'commandment', 'convention'],
    'ordinarily': ['again and again', 'all in all', 'all things considered', 'altogether', 'as a rule', 'as a whole', 'as an approximation', 'as per usual', 'as things go', 'as usual', 'at large', 'broadly'],
    'ordinary': ['american plan', 'attic', 'babbittish', 'european plan', 'ja', 'philistine', 'a la carte', 'accepted', 'accustomed', 'achievement', 'alerion', 'amicus curiae'],
    'ordination': ['acceptance', 'adjustment', 'admission', 'admittance', 'apostolic orders', 'appointment', 'assignment', 'baptism', 'calling', 'canonization', 'charting', 'codification'],
    'ordnance': ['a-weapons', 'armament', 'arms', 'artillery', 'battery', 'biological weapons', 'cannon', 'cannonry', 'coast artillery', 'conventional weapons', 'deadly weapons', 'field artillery'],
    'ordure': ['bm', 'bowel movement', 'buffalo chips', 'ca-ca', 'carrion', 'coprolite', 'coprolith', 'corruption', 'cow chips', 'cow flops', 'cow pats', 'crap'],
    'ore': ['argentite', 'arsenopyrite', 'bauxite', 'chalcocite', 'cinnabar', 'crude', 'galena', 'iron ore', 'ironstone', 'limonite', 'lodestone', 'magnetite'],
    'organ': ['charlie mccarthy', 'hammond organ', 'affiliate', 'agency', 'agent', 'ancilla', 'annual', 'appendage', 'appliance', 'arm', 'baroque organ', 'bimonthly'],
    'organ stop': ['english horn', 'bassoon', 'block flute', 'bombard', 'bourdon', 'cello', 'claribel', 'clarinet', 'clarion', 'concert flute', 'cornet', 'cornopean'],
    'organic': ['anatomic', 'animate', 'architectonic', 'architectural', 'atavistic', 'basic', 'biological', 'biotic', 'bodily', 'born', 'breathing', 'coeval'],
    'organism': ['aerobic organism', 'an existence', 'anaerobic organism', 'anatomy', 'architectonics', 'architecture', 'arrangement', 'autotrophic organism', 'being', 'body', 'build', 'building'],
    'organization': ['kp', 'adjustment', 'aerobic organism', 'affiliation', 'agency', 'anaerobic organism', 'anatomy', 'approach', 'architectonics', 'architecture', 'army', 'army group'],
    'organization man': ['babbitt', 'middle american', 'philistine', 'anal character', 'bourgeois', 'burgher', 'compulsive character', 'conformer', 'conformist', 'conventionalist', 'formalist', 'methodologist'],
    'organize': ['adjust', 'affiliate', 'ally', 'arrange', 'array', 'assemble', 'associate', 'band together', 'be in cahoots', 'begin', 'build', 'build up'],
    'organized': ['afflicted', 'aligned', 'animate', 'arranged', 'arrayed', 'assorted', 'bent', 'biological', 'biotic', 'blueprinted', 'boiled', 'bombed'],
    'organized crime': ['black hand', 'cosa nostra', 'mafia', 'black market', 'bootlegging', 'gambling', 'gangdom', 'gangland', 'gray market', 'illegal commerce', 'illegal operations', 'illegitimate business'],
    'organizer': ['ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'bargainer', 'begetter', 'beginner', 'builder', 'business agent', 'cardholder'],
    'orgasm': ['abandon', 'access', 'act of love', 'adultery', 'aphrodisia', 'apoplexy', 'ass', 'attack', 'balling', 'carnal knowledge', 'climax', 'cohabitation'],
    'orgasmic': ['abandoned', 'amok', 'anarchic', 'angry', 'bellowing', 'berserk', 'blustering', 'blusterous', 'blustery', 'carried away', 'cataclysmic', 'chaotic'],
    'orgiastic': ['adamic', 'circean', 'abandoned', 'amok', 'animal', 'animalistic', 'beastlike', 'beastly', 'bellowing', 'berserk', 'bestial', 'bodily'],
    'orgy': ['saturnalia', 'abandon', 'bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'bender', 'binge', 'bout', 'bust', 'carousal', 'carouse'],
    'oriel': ['alcove', 'bay', 'bay window', 'bow window', 'carrel', 'casement', 'casement window', 'corner', 'cove', 'cranny', 'cubby', 'cubbyhole'],
    'orient': ['africa', 'america', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'east', 'eastern hemisphere', 'eurasia', 'europe', 'far east'],
    'oriental': ['antarctic', 'arctic', 'austral', 'boreal', 'east', 'eastbound', 'easterly', 'eastermost', 'eastern', 'easternmost', 'hyperborean', 'meridional'],
    'orientation': ['acclimation', 'acclimatization', 'accommodation', 'accustoming', 'adaptation', 'adaption', 'adjustment', 'aim', 'alignment', 'arrangement', 'aspect', 'assimilation'],
    'oriented': ['acclimated', 'acclimatized', 'accommodated', 'accustomed', 'adapted', 'adjusted', 'case-hardened', 'conditioned', 'experienced', 'familiarized', 'hardened', 'inured'],
    'orienter': ['dutch uncle', 'polonius', 'admonisher', 'adviser', 'backseat driver', 'buttinsky', 'confidant', 'consultant', 'counsel', 'counselor', 'expert', 'guide'],
    'orifice': ['aperture', 'broaching', 'cavity', 'chasm', 'check', 'clearing', 'cleft', 'crack', 'disclosure', 'fenestra', 'fistula', 'fontanel'],
    'origin': ['alpha', 'ancestry', 'babyhood', 'base', 'basis', 'beginning', 'beginnings', 'birth', 'birthplace', 'blast-off', 'blood', 'childhood'],
    'original': ['bohemian', 'ab ovo', 'abecedarian', 'aboriginal', 'actual', 'advanced', 'alien', 'antenatal', 'antetype', 'antitype', 'archetypal', 'archetype'],
    'originality': ['bohemianism', 'authenticity', 'beatnikism', 'brand-newness', 'callowness', 'cleverness', 'contrariety', 'creativeness', 'creativity', 'daring', 'deviation', 'dewiness'],
    'originally': ['ab initio', 'ab ovo', 'aborigine', 'at first', 'at the start', 'before everything', 'by birth', 'by nature', 'chiefly', 'congenitally', 'first', 'first and foremost'],
    'originate': ['arise', 'author', 'be born', 'bear', 'become', 'beget', 'begin', 'birth', 'break ground', 'break out', 'break the ice', 'breed'],
    'origination': ['alpha', 'artifact', 'authorship', 'babyhood', 'beginning', 'beginnings', 'birth', 'blast-off', 'brainchild', 'child', 'childhood', 'coinage'],
    'originative': ['behind the scenes', 'causal', 'causative', 'conceptive', 'conceptual', 'constitutive', 'constructive', 'creative', 'decisive', 'demiurgic', 'determinative', 'effectual'],
    'originator': ['agent', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner', 'builder', 'catalyst', 'causer'],
    'orison': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'aid prayer', 'appeal', 'application', 'beadroll', 'beads', 'beseechment'],
    'ornament': ['acciaccatura', 'add', 'adjoin', 'adjunct', 'adorn', 'adornment', 'affix', 'agglutinate', 'anacrusis', 'annex', 'append', 'appoggiatura'],
    'ornamented': ['adorned', 'allusive', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'decked out', 'decorated', 'embellished'],
    'ornate': ['adorned', 'arabesque', 'aureate', 'baroque', 'befrilled', 'busy', 'chichi', 'colored', 'decorated', 'elaborate', 'elegant', 'embellished'],
    'ornery': ['aureate', 'baleful', 'balky', 'base', 'bearish', 'bitchy', 'bombastic', 'breachy', 'cankered', 'cantankerous', 'churlish', 'common'],
    'ornithology': ['anatomy', 'animal physiology', 'anthropology', 'biology', 'comparative anatomy', 'conchology', 'ecology', 'entomology', 'ethology', 'helminthology', 'herpetology', 'ichthyology'],
    'orotund': ['gongoresque', 'johnsonian', 'affected', 'bedizened', 'big-sounding', 'convoluted', 'declamatory', 'elevated', 'euphuistic', 'flamboyant', 'flaming', 'flashy'],
    'orphan': ['abandoned', 'alone', 'bereave', 'cast-off', 'castaway', 'castoff', 'derelict', 'discard', 'disregarded', 'dogie', 'flotsam', 'flotsam and jetsam'],
    'orthodox': ['christian', 'orthodox jew', 'sunni muslim', 'accepted', 'accordant', 'accustomed', 'acknowledged', 'admitted', 'anal', 'approved', 'authentic', 'authoritative'],
    'orthodoxy': ['accommodation', 'accord', 'accordance', 'acquiescence', 'adaptation', 'adaption', 'adjustment', 'agreement', 'belief', 'compliance', 'conformance', 'conformation other-direction'],
    'orthogonal': ['cube-shaped', 'cubed', 'cubic', 'cubiform', 'cuboid', 'diced', 'foursquare', 'normal', 'oblong', 'orthodiagonal', 'orthometric', 'perpendicular'],
    'orthopedic': ['allopathic', 'chiropodic', 'chiropractic', 'clinical', 'dental', 'exodontic', 'homeopathic', 'hydropathic', 'iatric', 'medical', 'naturopathic', 'neurological'],
    'orthopedist': ['anesthesiologist', 'cardiologist', 'chiropodist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'immunologist', 'internist', 'neurologist', 'obstetrician'],
    'orts': ['afterglow', 'afterimage', 'balance', 'bones', 'butt', 'butt end', 'candle ends', 'chaff', 'culm', 'deadwood', 'debris', 'detritus'],
    'oscillate': ['alternate', 'back and fill', 'be here again', 'bob', 'bobble', 'careen', 'change', 'circle', 'coggle', 'come again', 'come and go', 'come around'],
    'oscillating': ['fluctuant', 'fluctuating', 'fluctuational', 'harmonic', 'libratory', 'nutational', 'oscillatory', 'pendular', 'pendulating', 'pendulous', 'periodic', 'resonant'],
    'oscillation': ['alternation', 'beat', 'cyclicalness', 'equivocation', 'fluctuation', 'intermittence', 'intermittency', 'meter', 'pendulation', 'pendulum motion', 'periodicalness', 'periodicity'],
    'oscillatory': ['alternate', 'beating', 'circling', 'cyclic', 'epochal', 'even', 'every other', 'fluctuant', 'fluctuating', 'fluctuational', 'harmonic', 'intermittent'],
    'oscilloscope': ['flexowriter typewriter', 'j-scope', 'teleplotter', 'alphabetical printer', 'digital graph plotter', 'hard copy', 'harmonograph', 'kymograph', 'magnetic recorder', 'magnetic tape', 'microcards', 'microfiche'],
    'osculate': ['blow a kiss', 'brush', 'brush by', 'bus', 'buss', 'caress', 'come in contact', 'contact', 'glance', 'graze', 'hit', 'impinge'],
    'osiris': ['aides', 'aidoneus', 'amen-ra', 'anubis', 'bast', 'cerberus', 'charon', 'cora', 'despoina', 'dis', 'dis pater', 'erebus'],
    'osmose': ['absorb', 'adsorb', 'assimilate', 'blot', 'blot up', 'chemisorb', 'chemosorb', 'digest', 'drink', 'drink in', 'drink up', 'engross'],
    'osmosis': ['absorbency', 'absorbent', 'absorption', 'adsorbent', 'adsorption', 'assimilation', 'blotter', 'blotting', 'blotting paper', 'chemisorption', 'chemosorption', 'communication'],
    'ossified': ['backed', 'bone', 'bony', 'calcified', 'callous', 'calloused', 'case-hardened', 'crusted', 'crusty', 'crystallized', 'fossilized', 'granulated'],
    'ossify': ['anneal', 'brutalize', 'calcify', 'callous', 'case harden', 'cornify', 'firm', 'fossilize', 'harden', 'indurate', 'inure', 'lapidify'],
    'ossuary': ['barrow', 'beehive tomb', 'bone house', 'bone pot', 'box grave', 'burial', 'burial chamber', 'burial mound', 'catacombs', 'cenotaph', 'charnel house', 'cinerary urn'],
    'ostensible': ['barmecidal', 'barmecide', 'airy', 'alleged', 'apparent', 'apparitional', 'appearing', 'arrant', 'autistic', 'avowed', 'blatant', 'bold'],
    'ostensibly': ['allegedly', 'apparently', 'arrantly', 'artificially', 'as a cover', 'as a pretext', 'as an excuse', 'as it seems', 'at first sight', 'avowedly', 'blatantly', 'boldly'],
    'ostentation': ['barnumism', 'acting', 'affectation', 'appearance', 'arabesque', 'arrantness', 'attitudinizing', 'baroque', 'baroqueness', 'bedizenment', 'big talk', 'blatancy'],
    'ostentatious': ['gongoresque', 'johnsonian', 'affected', 'ambitious', 'arabesque', 'baroque', 'bedizened', 'big-sounding', 'boastful', 'braggart', 'busy', 'chichi'],
    'ostracism': ['ban', 'banishment', 'blackball', 'blackballing', 'blacklist', 'boycott', 'boycottage', 'clearance', 'complaint', 'defrocking', 'degradation', 'demotion'],
    'ostracize': ['avoid', 'ban', 'banish', 'bar', 'bar out', 'blackball', 'blacklist', 'blockade', 'boycott', 'cast out', 'categorically reject', 'cold-shoulder'],
    'other': ['accessory', 'accident', 'accidental', 'added', 'addendum', 'addition', 'additional', 'adjunct', 'alien', 'ancillary', 'another', 'apart'],
    'other directed': ['acquiescent', 'actuated', 'adaptable', 'adaptive', 'adjustable', 'animated', 'complaisant', 'compliant', 'conformable', 'extroversive', 'extrovert', 'extroverted'],
    'other self': ['i myself', 'acquaintance', 'advocate', 'alter', 'alter ego', 'alterum', 'backer', 'best friend', 'better self', 'bosom friend', 'brother', 'casual acquaintance'],
    'other side': ['antipode', 'antipodes', 'antipole', 'antithesis', 'antonym', 'contra', 'converse', 'counter', 'counterbalance', 'countercheck', 'counterpoint', 'counterpoise'],
    'otherwise': ['a rebours', 'against the grain', 'alias', 'another', 'arsy-varsy', 'by contraries', 'contra', 'contrarily', 'contrariously', 'contrariwise', 'conversely', 'differently'],
    'otherworld': ['beulah', 'beulah land', 'heaven', 'land of beulah', 'paradise', 'a better place', 'afterlife', 'afterworld', 'better world', 'beyond', 'destiny', 'eternal home'],
    'otherworldly': ['christlike', 'christly', 'elysian', 'god-fearing', 'olympian', 'airy', 'alien', 'angelic', 'arcane', 'asomatous', 'astral', 'autistic'],
    'otiose': ['abortive', 'airy', 'asinine', 'at leisure', 'at liberty', 'at loose ends', 'available', 'barren', 'bootless', 'catchpenny', 'disengaged', 'empty'],
    'oui': ['ok', 'roger', 'absolutely', 'all right', 'alright', 'alrighty', 'amen', 'as you say', 'assuredly', 'aye', 'by all means', 'certainly'],
    'ounce': ['ace', 'atom', 'bit', 'crumb', 'dab', 'dole', 'dot', 'dram', 'dribble', 'driblet', 'drop', 'dwarf'],
    'oust': ['bereave', 'boot out', 'bounce', 'break', 'bust', 'cashier', 'cast', 'cast out', 'chuck out', 'deconsecrate', 'defenestrate', 'defrock'],
    'ouster': ['booting out', 'bouncer', 'chucker', 'chucker-out', 'defenestration', 'detrusion', 'discharge', 'dislodgment', 'dispossession', 'ejection', 'ejectment', 'ejector'],
    'out': ['abandoned', 'aberrant', 'abjured', 'abroad', 'absurd', 'adrift', 'alibi', 'all abroad', 'all off', 'all wrong', 'aloud', 'amiss'],
    'out cold': ['asleep', 'blind', 'blind drunk', 'blotto', 'cataleptic', 'catatonic', 'cold', 'comatose', 'dead', 'doped', 'drugged', 'half-conscious'],
    'out group': ['jim crow', 'age group', 'alien', 'apartheid', 'band', 'battalion', 'bevy', 'body', 'brigade', 'bunch', 'cabal', 'cast'],
    'out of': ['at large', 'away from', 'bankrupt in', 'bare of', 'bereaved', 'bereaved of', 'bereft', 'bereft of', 'cut off', 'denuded', 'denuded of', 'deprived of'],
    'out of bounds': ['a bit much', 'abandoned', 'banned', 'barred', 'boundless', 'contraband', 'cutthroat', 'egregious', 'enormous', 'exacting', 'exaggerated', 'excessive'],
    'out of character': ['ill-adapted', 'ill-assorted', 'ill-chosen', 'ill-fitted', 'ill-matched', 'ill-sorted', 'ill-suited', 'ill-timed', 'improper', 'inadmissible', 'inapplicable', 'inapposite'],
    'out of commission': ['at a standstill', 'at anchor', 'broken', 'dead-still', 'fixed', 'haywire', 'hors de combat', 'idle', 'immobile', 'immotive', 'in condition', 'in disrepair'],
    'out of control': ['abandoned', 'go-go', 'immoderate', 'incontinent', 'indulgent', 'intemperate', 'irrepressible', 'lax', 'licentious', 'loose', 'nonrestrictive', 'out of hand'],
    'out of date': ['abandoned', 'abjured', 'ahead of time', 'anachronistic', 'antedated', 'antiquated', 'antique', 'archaic', 'back-number', 'beforehand', 'behind the times', 'behind time'],
    'out of favor': ['at a discount', 'despised', 'discredited', 'disgraced', 'disliked', 'in dutch', 'in bad', 'in bad odor', 'in bad repute', 'in discredit', 'in disfavor', 'in disgrace'],
    'out of focus': ['blear', 'bleared', 'bleary', 'blurred', 'blurry', 'confused', 'dark', 'dim', 'faint', 'feeble', 'filmy', 'foggy'],
    'out of hand': ['abandoned', 'ad lib', 'at short notice', 'at sight', 'beyond control', 'breachy', 'by ear', 'contumacious', 'defiant', 'extemporaneously', 'extemporarily', 'extempore'],
    'out of humor': ['acid', 'angry', 'beefing', 'bellyaching', 'bitching', 'caustic', 'cheerless', 'complaining', 'complaintful', 'corrosive', 'crabbing', 'crabby'],
    'out of it': ['a stranger to', 'anesthetized', 'asleep', 'base', 'blind to', 'cataleptic', 'catatonic', 'caught napping', 'cold', 'comatose', 'dead', 'dead to'],
    'out of joint': ['amiss', 'askew', 'awry', 'broken', 'cockeyed', 'convulsed', 'deranged', 'disarranged', 'discomfited', 'discomposed', 'disconcerted', 'disjointed'],
    'out of keeping': ['ill-adapted', 'ill-assorted', 'ill-chosen', 'ill-fitted', 'ill-matched', 'ill-sorted', 'ill-suited', 'ill-timed', 'improper', 'inadmissible', 'inapplicable', 'inapposite'],
    'out of kilter': ['amiss', 'askew', 'awry', 'broken', 'cockeyed', 'convulsed', 'deranged', 'disarranged', 'discomfited', 'discomposed', 'disconcerted', 'dislocated'],
    'out of line': ['aberrant', 'abnormal', 'abominable', 'approximate', 'approximative', 'atrocious', 'bad', 'criminal', 'delinquent', 'deviant', 'disgraceful', 'disorderly'],
    'out of luck': ['badly off', 'depressed', 'dire', 'donsie', 'doomful', 'evil-starred', 'fatal', 'fortuneless', 'funest', 'hapless', 'ill off', 'ill-starred'],
    'out of order': ['amiss', 'askew', 'awry', 'bad', 'broken', 'cockeyed', 'convulsed', 'deranged', 'disarranged', 'discomfited', 'discomposed', 'disconcerted'],
    'out of phase': ['amplitude', 'antinode', 'crest', 'de broglie wave', 'diffraction', 'electromagnetic radiation', 'electromagnetic wave', 'frequency', 'frequency band', 'frequency spectrum', 'guided wave', 'ill-considered'],
    'out of place': ['amiss', 'askew', 'awry', 'bad', 'cockeyed', 'convulsed', 'deranged', 'disarranged', 'discomfited', 'discomposed', 'disconcerted', 'dislocated'],
    'out of pocket': ['at a loss', 'badly off', 'bankrupt in', 'bare of', 'bereft of', 'denuded of', 'deprived of', 'destitute of', 'devoid of', 'distressed', 'down to bedrock', 'embarrassed'],
    'out of proportion': ['abnormal', 'absurd', 'anomalous', 'asymmetric', 'disparate', 'disproportionate', 'ill-adapted', 'ill-assorted', 'ill-chosen', 'ill-fitted', 'ill-matched', 'ill-sorted'],
    'out of reach': ['antipodean', 'back of beyond', 'beyond reach', 'beyond the bounds', 'closed forever to', 'closed to', 'godforsaken', 'hyperborean', 'impenetrable', 'impervious', 'inaccessible', 'lost to'],
    'out of season': ['aestival', 'ahead of time', 'anachronistic', 'antedated', 'arctic', 'at a premium', 'autumn', 'autumnal', 'back-number', 'beforehand', 'behind the times', 'behind time'],
    'out of shape': ['bandy', 'bandy-legged', 'blemished', 'bloated', 'bowlegged', 'club-footed', 'defaced', 'deformed', 'disfigured', 'dwarfed', 'flatfooted', 'gone to seed'],
    'out of sight': ['ok', 'a bit much', 'abandoned', 'absconded', 'absent', 'ace-high', 'afar', 'afar off', 'away', 'bad', 'bang-up', 'behind the curtain'],
    'out of sorts': ['acid', 'ailing', 'angry', 'bad', 'below par', 'caustic', 'cheerless', 'corrosive', 'critically ill', 'discontented', 'down', 'faint'],
    'out of touch': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity', 'cold-blooded', 'coldhearted'],
    'out of whack': ['amiss', 'antagonistic', 'antipathetic', 'askew', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'awry', 'broken', 'clashing'],
    'out of work': ['at leisure', 'at liberty', 'at loose ends', 'available', 'disengaged', 'fallow', 'free', 'idle', 'jobless', 'leisure', 'leisured', 'lumpen'],
    'out-and-out': ['absolute', 'admitting no exception', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'arrant', 'born', 'broad-based', 'categorical', 'classical', 'clean'],
    'out-of-the-way': ['bohemian', 'o-shaped', 'aberrant', 'aberrative', 'adrift', 'ambagious', 'antipodean', 'apart', 'back of beyond', 'backhanded', 'beat', 'beside the mark'],
    'outage': ['arrearage', 'break', 'defalcation', 'defect', 'deficiency', 'deficit', 'discontinuity', 'gap', 'hiatus', 'interval', 'lack', 'lacuna'],
    'outback': ['arabia deserta', 'china', 'darkest africa', 'death valley', 'god knows where', 'greenland', 'lebensraum', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'sahara'],
    'outbreak': ['alpha', 'beginning', 'belch', 'blast-off', 'blaze', 'burst', 'cascade', 'civil disorder', 'commencement', 'convulsion', 'creation', 'cutting edge'],
    'outbuilding': ['nissen hut', 'quonset hut', 'booth', 'crib', 'gatehouse', 'hut', 'hutch', 'kiosk', 'lean-to', 'outhouse', 'pavilion', 'sentry box'],
    'outburst': ['access', 'attack', 'belch', 'blaze', 'blaze of temper', 'blowout', 'blowup', 'blurt', 'burst', 'cascade', 'convulsion', 'cyclone'],
    'outcast': ['dp', 'diogenes', 'hieronymian', 'hieronymite', 'ishmael', 'jim crow', 'timon of athens', 'abandoned', 'alien', 'anchoress', 'anchorite', 'apartheid'],
    'outclass': ['beat', 'beat all hollow', 'beat hollow', 'best', 'defeat', 'destroy', 'do in', 'drub', 'fix', 'hide', 'hors de combat', 'lambaste'],
    'outcome': ['accomplishment', 'aftermath', 'answer', 'artifact', 'ascertainment', 'avenue', 'blowhole', 'brainchild', 'by-product', 'channel', 'child', 'chute'],
    'outcrop': ['appear', 'arise', 'become manifest', 'become visible', 'come', 'come forth', 'come forward', 'come in sight', 'come out', 'come to hand', 'come to light', 'crop out'],
    'outcry': ['bedlam let loose', 'dutch auction', 'auction', 'auction block', 'auction sale', 'bawl', 'bedlam', 'blast', 'block', 'bobbery', 'boo', 'booing'],
    'outdated': ['abandoned', 'abjured', 'antiquated', 'antique', 'archaic', 'back-number', 'behind the times', 'dated', 'deserted', 'discontinued', 'disused', 'done with'],
    'outdistance': ['carry out', 'distance', 'extend out', 'get ahead of', 'go', 'go out', 'hold the field', 'leave behind', 'outlie', 'outrange', 'outstretch', 'overpass'],
    'outdo': ['beat', 'beat all hollow', 'beat hollow', 'best', 'cap', 'defeat', 'destroy', 'do in', 'drub', 'exceed', 'excel', 'fix'],
    'outdone': ['all up with', 'beat', 'beaten', 'bested', 'confounded', 'defeated', 'discomfited', 'done for', 'done in', 'down', 'fallen', 'fixed'],
    'outer': ['apparent', 'cortical', 'epidermic', 'exomorphic', 'exterior', 'external', 'extrinsic', 'fringe', 'open', 'out', 'outermost', 'outlying'],
    'outer space': ['china', 'darkest africa', 'god knows where', 'greenland', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'siberia', 'south pole', 'thule', 'tierra del fuego'],
    'outermost': ['apparent', 'cortical', 'epidermic', 'exomorphic', 'exterior', 'external', 'extrinsic', 'fringe', 'open', 'out', 'outer', 'outlying'],
    'outfield': ['amateur athlete', 'archer', 'archery ground', 'athlete', 'athletic field', 'badminton court', 'ballplayer', 'baseball field', 'baseballer', 'baseman', 'basketball court', 'batter'],
    'outfight': ['beat', 'beat all hollow', 'beat hollow', 'best', 'defeat', 'destroy', 'do in', 'drub', 'fix', 'hide', 'hors de combat', 'lambaste'],
    'outfit': ['kp', 'accouter', 'accouterments', 'age group', 'apparatus', 'appliances', 'appoint', 'appointments', 'appurtenances', 'arm', 'armament', 'army'],
    'outflank': ['circumvent', 'deceive', 'elude', 'evade', 'foil', 'frustrate', 'get around', 'get round', 'give the runaround', 'give the slip', 'go one better', 'outfigure'],
    'outflow': ['affluence', 'afflux', 'affluxion', 'blow out', 'concourse', 'confluence', 'conflux', 'course', 'crosscurrent', 'current', 'defluxion', 'discharge'],
    'outflowing': ['defluxion', 'discharge', 'drain', 'drainage', 'effluence', 'effluent', 'efflux', 'effluxion', 'effused', 'effusion', 'effusive', 'exhalation'],
    'outgoing': ['accessible', 'affable', 'amenable', 'amiable', 'amicable', 'approachable', 'candid', 'communicative', 'congenial', 'conversable', 'cordial', 'demonstrative'],
    'outgrow': ['blossom', 'brew', 'burgeon', 'develop', 'flourish', 'gather', 'germinate', 'grow', 'grow up', 'hypertrophy', 'increase', 'mature'],
    'outgrowth': ['artifact', 'benign tumor', 'brainchild', 'budding', 'burgeoning', 'by-product', 'callosity', 'callus', 'cancer', 'carcinoma', 'child', 'coinage'],
    'outguess': ['circumvent', 'deceive', 'elude', 'evade', 'foil', 'frustrate', 'get around', 'get round', 'give the runaround', 'give the slip', 'go one better', 'outfigure'],
    'outhouse': ['nissen hut', 'quonset hut', 'wc', 'backhouse', 'basement', 'bathroom', 'booth', 'can', 'closet', 'comfort station', 'convenience', 'crapper'],
    'outing': ['campaign', 'circuit', 'course', 'excursion', 'expedition', 'grand tour', 'jaunt', 'journey', 'junket', 'package tour', 'peregrination', 'pilgrimage'],
    'outlander': ['uitlander', 'alien', 'auslander', 'barbarian', 'deracine', 'displaced person', 'emigre', 'exile', 'foreign devil', 'foreigner', 'gringo', 'outlaw'],
    'outlandish': ['doric', 'gothic', 'neanderthal', 'absurd', 'alien', 'animal', 'apart', 'back', 'barbarian', 'barbaric', 'barbarous', 'baroque'],
    'outlaw': ['dp', 'ishmael', 'judas', 'uitlander', 'abstract', 'actionable', 'against the law', 'alien', 'anarchic', 'anarchistic', 'anomic', 'bad guy'],
    'outlawed': ['actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'banned', 'barred', 'black-market', 'bootleg', 'chargeable', 'contraband', 'contrary to law'],
    'outlawry': ['anarchy', 'anomie', 'banishment', 'blackballing', 'clearance', 'criminalism', 'criminality', 'defrocking', 'degradation', 'demotion', 'depluming', 'deportation'],
    'outlay': ['budget', 'cost', 'cost out', 'disburse', 'disbursement', 'expend', 'expenditure', 'expense', 'fork out', 'give', 'go through', 'incur costs'],
    'outlet': ['abreaction', 'access', 'acting-out', 'aisle', 'alley', 'ambulatory', 'aperture', 'arcade', 'artery', 'avenue', 'bill of sale', 'blowhole'],
    'outline': ['abbreviation', 'abbreviature', 'abrege', 'abridge', 'abridgment', 'abstract', 'adumbrate', 'adumbration', 'alphabet', 'article', 'basics', 'block in'],
    'outlook': ['anschauung', 'texas tower', 'aftertime', 'afteryears', 'airscape', 'angle', 'angle of vision', 'aptitude', 'attitude', 'basis', 'beacon', 'belvedere'],
    'outlying': ['apparent', 'cortical', 'distant', 'epidermic', 'exomorphic', 'exterior', 'external', 'extraneous', 'extraorganismal', 'extrinsic', 'far', 'far-flung'],
    'outmaneuver': ['bamboozle', 'beat', 'beat all hollow', 'beat hollow', 'beguile', 'best', 'betray', 'bluff', 'cajole', 'cheat on', 'circumvent', 'conjure'],
    'outmoded': ['abandoned', 'abjured', 'antiquated', 'antique', 'archaic', 'back-number', 'behind the times', 'dated', 'dead', 'demode', 'deserted', 'discontinued'],
    'outmost': ['apparent', 'cortical', 'epidermic', 'exomorphic', 'exterior', 'external', 'extrinsic', 'farthest', 'fringe', 'furthermost', 'furthest', 'open'],
    'outpatient': ['apoplectic', 'arthritic', 'case', 'consumptive', 'dyspeptic', 'epileptic', 'incurable', 'inpatient', 'invalid', 'patient', 'rheumatic', 'shut-in'],
    'outperform': ['outclass', 'outdo', 'outgo', 'outjump', 'outleap', 'outmaneuver', 'outmarch', 'outpace', 'outplay', 'outpoint', 'outrange', 'outreach'],
    'outpost': ['berlin wall', 'china', 'darkest africa', 'god knows where', 'greenland', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'siberia', 'south pole', 'thule'],
    'outpouring': ['niagara', 'abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bonanza', 'bountifulness', 'bountiousness', 'bumper crop', 'cascade'],
    'output': ['algol', 'cobol', 'fortran', 'achieve', 'achievement', 'aftermath', 'alphabetic data', 'alphanumeric code', 'angular data', 'assembler', 'avails', 'bearing'],
    'outrage': ['abomination', 'abuse', 'afflict', 'affront', 'aggrieve', 'anger', 'aspersion', 'atrocity', 'attack', 'bad', 'bane', 'barbarism'],
    'outrageous': ['fescennine', 'a bit much', 'abandoned', 'abominable', 'absurd', 'abusive', 'acute', 'appalling', 'arrant', 'atrocious', 'awful', 'backhand'],
    'outrageously': ['abominably', 'atrociously', 'awfully', 'basely', 'bestially', 'brutally', 'contemptibly', 'deplorably', 'despicably', 'detestably', 'disgracefully', 'disgustingly'],
    'outrank': ['antecede', 'come before', 'come first', 'front', 'go ahead of', 'go before', 'go in advance', 'have priority', 'head', 'head the table', 'head up', 'kick off'],
    'outre': ['absurd', 'beyond belief', 'bizarre', 'cockamamie', 'crazy', 'extravagant', 'fantastic', 'foolish', 'freakish', 'grotesque', 'high-flown', 'incredible'],
    'outreach': ['bamboozle', 'be lengthy', 'be prolonged', 'beguile', 'belong', 'betray', 'bluff', 'cajole', 'cheat on', 'circumvent', 'conjure', 'crane'],
    'outright': ['absolute', 'absolutely', 'admitting no exception', 'all', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'altogether', 'arrant', 'at once', 'bald'],
    'outrun': ['beat', 'beat all hollow', 'beat hollow', 'best', 'catch up with', 'come up to', 'come up with', 'defeat', 'destroy', 'distance', 'do in', 'drub'],
    'outset': ['alpha', 'beginning', 'birth', 'blast-off', 'commencement', 'creation', 'cutting edge', 'dawn', 'dawning', 'edge', 'establishment', 'first'],
    'outshine': ['beat', 'beat all hollow', 'beat hollow', 'best', 'better', 'defeat', 'destroy', 'do in', 'drub', 'exceed', 'excel', 'fix'],
    'outside': ['abroad', 'after', 'alfresco', 'alien', 'apart from', 'apparent', 'apparently', 'appearance', 'aside from', 'aspect', 'bar', 'barbarian'],
    'outside chance': ['bare possibility', 'chance', 'conceivability', 'conceivableness', 'contingency', 'dark horse', 'even chance', 'eventuality', 'fighting chance', 'gambling chance', 'good chance', 'good possibility'],
    'outside of': ['aside from', 'bar', 'barring', 'beside', 'besides', 'but', 'ex', 'except', 'except for', 'excepting', 'excluding', 'exclusive of'],
    'outsider': ['jim crow', 'uitlander', 'alien', 'apartheid', 'auslander', 'barbarian', 'case', 'character', 'color bar', 'crackpot', 'crank', 'deracine'],
    'outsize': ['gargantuan', 'amplitudinous', 'astronomical', 'awesome', 'boundless', 'bulky', 'colossal', 'cosmic', 'enormous', 'extensive', 'galactic', 'giantism'],
    'outskirts': ['berlin wall', 'bowery', 'china', 'chinatown', 'darkest africa', 'east end', 'east side', 'god knows where', 'greenland', 'little hungary', 'little italy', 'north pole'],
    'outsmart': ['bamboozle', 'beguile', 'betray', 'bluff', 'cajole', 'cheat', 'cheat on', 'circumvent', 'con', 'conjure', 'cozen', 'deceive'],
    'outspoken': ['accessible', 'approachable', 'articulate', 'artless', 'bluff', 'blunt', 'bold', 'born yesterday', 'brash', 'broad', 'brusque', 'candid'],
    'outstanding': ['a cut above', 'above', 'ahead', 'appalling', 'apparent', 'arrant', 'arresting', 'ascendant', 'astonishing', 'back', 'better', 'blatant'],
    'outstretched': ['deltoid', 'fan-shape', 'fan-shaped', 'fanlike', 'fanned', 'fanning', 'flabelliform', 'flared', 'flaring', 'open', 'outspread', 'patulous'],
    'outstrip': ['be the bellwether', 'beacon', 'beat', 'best', 'better', 'bulk', 'bulk large', 'cap', 'catch up with', 'come up to', 'come up with', 'distance'],
    'outtalk': ['argue into', 'bring over', 'bring round', 'bring to reason', 'captivate', 'charm', 'con', 'convince', 'draw over', 'filibuster', 'gain', 'gain over'],
    'outward': ['apparent', 'apparently', 'appearing', 'bodily', 'carnal', 'conventionalized', 'cortical', 'epidermic', 'evident', 'exomorphic', 'exterior', 'exteriorly'],
    'outwardly': ['apparently', 'as it seems', 'at first sight', 'evidently', 'exteriorly', 'externally', 'forth', 'officially', 'on the outside', 'on the surface', 'openly', 'ostensibly'],
    'outweigh': ['atone for', 'balance', 'best', 'better', 'cap', 'compensate for', 'counterbalance', 'counterpoise', 'countervail', 'exceed', 'excel', 'go one better'],
    'outwit': ['bamboozle', 'befool', 'beguile', 'betray', 'bluff', 'cajole', 'cheat on', 'circumvent', 'conjure', 'deceive', 'delude', 'diddle'],
    'outworn': ['abandoned', 'abjured', 'antiquated', 'antique', 'archaic', 'dated', 'dead', 'deserted', 'discontinued', 'disused', 'done with', 'extinct'],
    'oval': ['archery ground', 'athletic field', 'badminton court', 'baseball field', 'basketball court', 'billiard parlor', 'bowling alley', 'bowling green', 'course', 'court', 'cricket ground', 'croquet ground'],
    'ovarian': ['adrenal', 'cervical', 'clitoral', 'eccrine', 'endocrine', 'exocrine', 'genital', 'glandular', 'glandulous', 'gonadal', 'holocrine', 'humoral'],
    'ovary': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'ovation': ['acclaim', 'acclamation', 'anniversaries', 'applause', 'big hand', 'burst of applause', 'celebrating', 'celebration', 'ceremony', 'cheer', 'cheering', 'cheers'],
    'oven': ['seger cone', 'torrid zone', 'acid kiln', 'brickkiln', 'cement kiln', 'enamel kiln', 'equator', 'furnace', 'hell', 'inferno', 'kiln', 'limekiln'],
    'over': ['sol', 'a cut above', 'above', 'above and beyond', 'abovestairs', 'across', 'additionally', 'afresh', 'again', 'ago', 'ahead', 'airward'],
    'over and above': ['above', 'above and beyond', 'added to', 'along with', 'as a bonus', 'as well as', 'attended by', 'beside', 'beyond', 'coupled with', 'extra', 'for lagniappe'],
    'over and over': ['again and again', 'day after day', 'day by day', 'frequently', 'many a time', 'many times', 'many times over', 'much', 'oft', 'often', 'oftentimes', 'ofttimes'],
    'over-the-counter market': ['american stock exchange', 'amex', 'wall street', 'board', 'bourse', 'commodity exchange', 'corn pit', 'curb', 'curb exchange', 'curb market', 'exchange', 'exchange floor'],
    'overabundance': ['avalanche', 'deluge', 'embarras de richesses', 'enough', 'extravagance', 'extravagancy', 'flood', 'inundation', 'landslide', 'lavishness', 'money to burn', 'more than enough'],
    'overabundant': ['lavish', 'overbounteous', 'overcopious', 'overexuberant', 'overflowing', 'overgenerous', 'overlavish', 'overliberal', 'overluxuriant', 'overmuch', 'overnumerous', 'overplenteous'],
    'overact': ['act a part', 'affect', 'assume', 'carry too far', 'counterfeit', 'declaim', 'do a bit', 'dramatize', 'exaggerate', 'exhaust', 'fake', 'feign'],
    'overacted': ['actor-proof', 'affected', 'all-star', 'artificial', 'ballet', 'balletic', 'cinematic', 'cinematographic', 'dramatic', 'dramatical', 'dramaturgic', 'film'],
    'overage': ['balance', 'bonus', 'dividend', 'excess', 'extra', 'gratuity', 'lagniappe', 'leftover', 'margin', 'overmeasure', 'overplus', 'overrun'],
    'overall': ['accumulative', 'across-the-board', 'ad infinitum', 'all in all', 'all over', 'all round', 'all things considered', 'all-comprehensive', 'all-embracing', 'all-inclusive', 'altogether', 'as a rule'],
    'overambitious': ['at fever pitch', 'delirious', 'fanatical', 'febrile', 'feverish', 'frantic', 'frenetic', 'frenzied', 'furious', 'hectic', 'hysteric', 'infatuated'],
    'overanxious': ['agitated', 'all-overish', 'anxious', 'anxioused up', 'apprehensive', 'at fever pitch', 'bothered', 'concerned', 'delirious', 'disquieted', 'disturbed', 'fanatical'],
    'overawe': ['abash', 'awe', 'beat down', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'clamp down on', 'coerce', 'compel', 'cow'],
    'overbearing': ['absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'ascendant', 'assertive', 'authoritarian', 'authoritative', 'autocratic', 'big'],
    'overblown': ['arty', 'aureate', 'big', 'bloated', 'bombastic', 'bursting', 'choked', 'congested', 'corpulent', 'crammed', 'crowded', 'declamatory'],
    'overburden': ['bear hard upon', 'burden', 'burthen', 'charge', 'choke', 'congest', 'cram', 'crowd', 'cumber', 'drench', 'encumber', 'freight'],
    'overburdened': ['bloated', 'burdened', 'bursting', 'charged', 'choked', 'congested', 'crammed', 'crowded', 'cumbered', 'distended', 'drenched', 'encumbered'],
    'overcast': ['acheronian', 'acherontic', 'cat', 'cimmerian', 'stygian', 'adumbrate', 'aerospace', 'aerosphere', 'air hole', 'air pocket', 'airspace', 'becloud'],
    'overcharge': ['adorn', 'aggrandize', 'amplify', 'anticathexis', 'ballyhoo', 'bleed', 'bleed white', 'build up', 'burlesque', 'caricature', 'carry too far', 'cathectic energy'],
    'overclouded': ['castellatus', 'cirrose', 'cirrous', 'cloud-flecked', 'clouded', 'cloudy', 'cumuliform', 'cumulous', 'dark', 'dirty', 'dull', 'gloomy'],
    'overcoat': ['inverness', 'benjamin', 'capote', 'chesterfield', 'cloth coat', 'coat', 'dreadnought', 'duster', 'fur-lined coat', 'fur-trimmed coat', 'greatcoat', 'jacket'],
    'overcome': ['affected', 'all up with', 'beat', 'beaten', 'best', 'bested', 'better', 'blind', 'blind drunk', 'blotto', 'break', 'broken-down'],
    'overcompensation': ['alienation', 'autism', 'autistic thinking', 'avoidance mechanism', 'blame-shifting', 'compensation', 'decompensation', 'defense mechanism', 'dereism', 'dereistic thinking', 'displacement', 'dissociation'],
    'overconfidence': ['arrogance', 'assurance', 'assuredness', 'belief', 'brashness', 'brass', 'brazen boldness', 'certitude', 'cheek', 'chutzpah', 'cocksureness', 'confidence'],
    'overconfident': ['arrogant', 'assured', 'audacious', 'brash', 'brazen', 'brazenfaced', 'cocksure', 'cocky', 'confident', 'convinced', 'decided', 'determined'],
    'overconscientious': ['careful', 'conscientious', 'fastidious', 'hairsplitting', 'hypercritical', 'hypersensitive', 'meticulous', 'morbidly sensitive', 'nice', 'overcritical', 'overfastidious', 'overmeticulous'],
    'overcritical': ['captious', 'carping', 'caviling', 'cavilling', 'censorious', 'critic', 'critical', 'cynical', 'demanding', 'difficult', 'exacting', 'fastidious'],
    'overcrossing': ['bifrost', 'bascule bridge', 'bateau bridge', 'bridge', 'cantilever bridge', 'carrefour', 'catwalk', 'cloverleaf', 'crossing', 'crosspoint', 'crossroad', 'crosswalk'],
    'overdeveloped': ['a bit much', 'abandoned', 'blooming', 'blossoming', 'boundless', 'budding', 'burgeoning', 'crescent', 'developed', 'egregious', 'enormous', 'exaggerated'],
    'overdo': ['aggrandize', 'amplify', 'ballyhoo', 'build up', 'burlesque', 'caricature', 'carry to excess', 'carry too far', 'do to death', 'draw the longbow', 'exaggerate', 'exhaust'],
    'overdone': ['gongoresque', 'johnsonian', 'affected', 'aggrandized', 'amplified', 'artificial', 'ballyhooed', 'bedizened', 'bien cuit', 'big-sounding', 'convoluted', 'declamatory'],
    'overdose': ['od', 'allay', 'avalanche', 'bag', 'bang', 'be brought down', 'be felled', 'be prodigal with', 'be struck down', 'be traumatized', 'booster', 'booster dose'],
    'overdraft': ['arrear', 'arrearage', 'arrears', 'back debts', 'back payments', 'bankruptcy', 'bouncing check', 'bust', 'collapse', 'crash', 'default', 'deferred payments'],
    'overdraw': ['aggrandize', 'amplify', 'ballyhoo', 'belie', 'build up', 'burlesque', 'camouflage', 'caricature', 'carry too far', 'color', 'disguise', 'distort'],
    'overdrawn': ['aggrandized', 'amplified', 'ballyhooed', 'disproportionate', 'exaggerated', 'excessive', 'exorbitant', 'extravagant', 'extreme', 'grandiloquent', 'high-flown', 'hyperbolic'],
    'overdress': ['bedizen', 'deck out', 'dizen', 'doll up', 'dress up', 'fancy up', 'fig out', 'get up', 'gussy up', 'prank', 'pretty up', 'primp'],
    'overdrive': ['hydromatic', 'automatic transmission', 'burden', 'busy', 'carry too far', 'cogwheel', 'differential', 'differential gear', 'drive', 'exaggerate', 'exhaust', 'fag'],
    'overdue': ['ahead of time', 'anachronistic', 'antedated', 'anticipated', 'arrested', 'awaited', 'back', 'backward', 'beforehand', 'behind', 'behind time', 'behindhand'],
    'overeager': ['accident-prone', 'at fever pitch', 'breakneck', 'careless', 'delirious', 'desperate', 'devil-may-care', 'fanatical', 'febrile', 'feverish', 'frantic', 'frenetic'],
    'overelaborate': ['gongoresque', 'gongoristic', 'johnsonian', 'marinistic', 'affected', 'arabesque', 'artificial', 'baroque', 'bedizened', 'big-sounding', 'busy', 'chichi'],
    'overemphasis': ['aggrandizement', 'amplification', 'ballyhoo', 'big talk', 'blowing up', 'burlesque', 'caricature', 'dilatation', 'dilation', 'enhancement', 'enlargement', 'exaggerating'],
    'overemphasize': ['accent', 'accentuate', 'belabor', 'carry too far', 'dwell on', 'emphasize', 'exaggerate', 'exhaust', 'give emphasis to', 'go overboard', 'go to extremes', 'go too far'],
    'overenthusiastic': ['accident-prone', 'at fever pitch', 'bigoted', 'breakneck', 'careless', 'delirious', 'desperate', 'devil-may-care', 'extravagant', 'extreme', 'extremist', 'fanatic'],
    'overestimate': ['aggrandize', 'amplify', 'ballyhoo', 'build up', 'burlesque', 'caricature', 'carry too far', 'draw the longbow', 'exaggerate', 'exaggeration', 'go to extremes', 'hyperbolize'],
    'overestimated': ['aggrandized', 'amplified', 'ballyhooed', 'disproportionate', 'exaggerated', 'excessive', 'exorbitant', 'extravagant', 'extreme', 'grandiloquent', 'high-flown', 'hyperbolic'],
    'overexercise': ['carry too far', 'exaggerate', 'exhaust', 'go overboard', 'go to extremes', 'go too far', 'know no bounds', 'overact', 'overcarry', 'overdevelop', 'overdo', 'overdrive'],
    'overexert': ['carry too far', 'exaggerate', 'exhaust', 'go overboard', 'go to extremes', 'go too far', 'haul', 'heave', 'know no bounds', 'overact', 'overcarry', 'overdevelop'],
    'overexpansion': ['bloat', 'bloating', 'breaking point', 'distension', 'extreme tension', 'inflation', 'overdistension', 'overdrawing', 'overextension', 'overstrain', 'overstraining', 'overstretching'],
    'overextend': ['haul', 'heave', 'inflate', 'overdevelop', 'overdistend', 'overdraw', 'overexert', 'overexpand', 'overstrain', 'overstretch', 'overtax', 'press'],
    'overextension': ['bloat', 'bloating', 'breaking point', 'distension', 'extreme tension', 'franticness', 'frenziedness', 'haul', 'heave', 'hyperactivity', 'hyperkinesia', 'hyperkinesis'],
    'overexuberant': ['lavish', 'overabundant', 'overbounteous', 'overcopious', 'overgenerous', 'overlavish', 'overliberal', 'overluxuriant', 'overmuch', 'overnumerous', 'overplenteous', 'overplentiful'],
    'overfed': ['allayed', 'bloated', 'bursting', 'choked', 'cloyed', 'congested', 'crammed', 'crowded', 'disgusted', 'distended', 'drenched', 'engorged'],
    'overfill': ['allay', 'brim', 'charge', 'chock', 'choke', 'cloy', 'congest', 'cram', 'crowd', 'drench', 'engorge', 'fill'],
    'overflow': ['abound', 'abundance', 'affluence', 'alluvion', 'alluvium', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bonanza', 'bountifulness', 'bountiousness'],
    'overflowing': ['abounding', 'abundant', 'affluent', 'alive with', 'all-sufficing', 'ample', 'aplenty', 'bloated', 'bottomless', 'bounteous', 'bountiful', 'bristling'],
    'overfull': ['sro', 'allayed', 'bloated', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full', 'choked', 'chuck-full', 'cloyed'],
    'overgrow': ['bespread', 'blossom', 'branch', 'branch out', 'brew', 'bud', 'burgeon', 'burst forth', 'cover', 'deploy', 'develop', 'disperse'],
    'overgrown': ['gargantuan', 'a bit much', 'abandoned', 'abundant', 'amplitudinous', 'astronomical', 'awesome', 'blooming', 'blossoming', 'boundless', 'braky', 'brambly'],
    'overgrowth': ['abandon', 'boundlessness', 'egregiousness', 'enormousness', 'exaggeration', 'excess', 'excessiveness', 'exorbitance', 'exorbitancy', 'extravagance', 'extravagancy', 'extreme'],
    'overhang': ['approach', 'arch over', 'await', 'be imminent', 'be in store', 'beetle', 'beetling', 'bestraddle', 'bestride', 'brew', 'bridge', 'bulge'],
    'overhanging': ['about to be', 'already in sight', 'approaching', 'at hand', 'beetle', 'beetle-browed', 'beetling', 'brewing', 'close', 'close at hand', 'coming', 'forthcoming'],
    'overhaul': ['adjust', 'adjustment', 'amends', 'audit', 'autopsy', 'balance', 'balance the books', 'canvass', 'catch up with', 'check', 'check out', 'check over'],
    'overhead': ['above', 'abovestairs', 'airward', 'aloft', 'aloof', 'budget', 'budget items', 'burden of expenditure', 'carrying charge', 'ceiling', 'charges', 'cost'],
    'overheated': ['ardent', 'baking', 'blistering', 'boiling', 'broiling', 'burning', 'burning hot', 'canicular', 'ebullient', 'electric-heated', 'fervent', 'fervid'],
    'overindulge': ['carry to excess', 'carry too far', 'exaggerate', 'exhaust', 'go overboard', 'go the limit', 'go to extremes', 'go too far', 'go whole hog', 'know no bounds', 'overact', 'overcarry'],
    'overindulgent': ['accommodating', 'affable', 'agreeable', 'amiable', 'benevolent', 'benign', 'benignant', 'bibulous', 'careless', 'complaisant', 'compliant', 'crapulent'],
    'overjoyed': ['bursting with happiness', 'carried away', 'cock-a-hoop', 'delighted', 'ecstatic', 'elate', 'elated', 'enchanted', 'enraptured', 'enravished', 'entranced', 'euphoric'],
    'overkill': ['aggrandizement', 'aggravated assault', 'aggression', 'amphibious attack', 'amplification', 'armed assault', 'assailing', 'assailment', 'assault', 'attack', 'ballyhoo', 'banzai attack'],
    'overlap': ['accord', 'accordance', 'affinity', 'agree', 'agreement', 'answer to', 'applique', 'arch over', 'assent', 'assort with', 'be consistent', 'be of one'],
    'overlarge': ['a bit much', 'abandoned', 'aggrandized', 'amplified', 'ballyhooed', 'boundless', 'disproportionate', 'egregious', 'enormous', 'exaggerated', 'excessive', 'exorbitant'],
    'overlay': ['adorn', 'applique', 'apply to', 'blanket', 'block', 'canopy', 'cap', 'cloak', 'clothe', 'cloud', 'convolute', 'cope'],
    'overlie': ['arch over', 'bestraddle', 'bestride', 'bridge', 'extend over', 'hang over', 'imbricate', 'jut', 'lap', 'lap over', 'lie over', 'overarch'],
    'overload': ['adorn', 'bale', 'bear hard upon', 'burden', 'burdening', 'burthen', 'cargo', 'charge', 'charging', 'choke', 'congest', 'congestion'],
    'overloaded': ['adorned', 'befrilled', 'bloated', 'burdened', 'bursting', 'charged', 'choked', 'colored', 'congested', 'crammed', 'crowded', 'cumbered'],
    'overlong': ['dragging', 'drawn-out', 'extended', 'interminable', 'languishing', 'lasting', 'lengthened', 'lengthy', 'lingering', 'long', 'long-continuing', 'long-drawn'],
    'overlook': ['texas tower', 'abide with', 'accept', 'allow', 'allow for', 'autopsy', 'be big', 'be blind to', 'be caught napping', 'be caught out', 'be content with', 'be easy with'],
    'overlooked': ['abandoned', 'absolved', 'acquitted', 'blotted', 'canceled', 'condoned', 'deserted', 'disregarded', 'exculpated', 'excused', 'exonerated', 'forgiven'],
    'overlord': ['anointed king', 'boss', 'bwana', 'chef', 'chief', 'chieftain', 'church dignitary', 'crowned head', 'dynast', 'ecclesiarch', 'elder', 'emperor'],
    'overly': ['damned', 'disproportionately', 'exceedingly', 'excessively', 'exorbitantly', 'extraordinarily', 'extremely', 'immensely', 'immoderately', 'inordinately', 'intemperately', 'outrageously'],
    'overmaster': ['beat down', 'bend', 'break', 'break down', 'bring low', 'bring to terms', 'browbeat', 'bulldoze', 'bully', 'castrate', 'clamp down on', 'coerce'],
    'overmatched': ['all up with', 'beat', 'beaten', 'bested', 'confounded', 'defeated', 'discomfited', 'done for', 'done in', 'down', 'fallen', 'fixed'],
    'overmuch': ['a bit much', 'abandon', 'abandoned', 'boundless', 'boundlessness', 'egregious', 'egregiousness', 'enormous', 'enormousness', 'exaggerated', 'exaggeration', 'excess'],
    'overnice': ['gongoresque', 'gongoristic', 'marinistic', 'affected', 'artificial', 'chichi', 'elaborate', 'elaborated', 'elegant', 'euphemistic', 'euphuistic', 'exquisite'],
    'overpass': ['bifrost', 'access', 'aisle', 'alley', 'ambulatory', 'aperture', 'arcade', 'artery', 'avenue', 'bascule bridge', 'bateau bridge', 'best'],
    'overplay': ['accent', 'accentuate', 'carry too far', 'dramatize', 'exaggerate', 'exhaust', 'go overboard', 'go to extremes', 'go too far', 'hyperbolize', 'know no bounds', 'magnify'],
    'overplayed': ['actor-proof', 'all-star', 'ballet', 'balletic', 'cinematic', 'cinematographic', 'dramatic', 'dramatical', 'dramaturgic', 'film', 'filmic', 'ham'],
    'overplus': ['balance', 'bonus', 'dividend', 'excess', 'extra', 'gratuity', 'lagniappe', 'leftover', 'margin', 'overabundance', 'overage', 'overflow'],
    'overpopulation': ['avalanche', 'deluge', 'embarras de richesses', 'enough', 'extravagance', 'extravagancy', 'flood', 'inundation', 'landslide', 'lavishness', 'money to burn', 'more than enough'],
    'overpower': ['amaze', 'be strong', 'bear down', 'beat', 'best', 'conquer', 'crush', 'daze', 'deck', 'defeat', 'drown out', 'dumbfound'],
    'overpowered': ['all up with', 'beat', 'beaten', 'bested', 'confounded', 'defeated', 'discomfited', 'done for', 'done in', 'down', 'fallen', 'fixed'],
    'overpowering': ['agitating', 'breathtaking', 'charged', 'cliff-hanging', 'compelling', 'disquieting', 'distracting', 'disturbing', 'electric', 'exciting', 'exhilarating', 'galvanic'],
    'overprice': ['bleed', 'bleed white', 'clip', 'exploit', 'fleece', 'gouge', 'hold up', 'overcharge', 'overtax', 'profiteer', 'screw', 'skin'],
    'overpriced': ['cutthroat', 'exacting', 'excessive', 'exorbitant', 'extortionate', 'extravagant', 'fancy', 'gouging', 'grossly overpriced', 'immoderate', 'inflationary', 'inordinate'],
    'overprint': ['bring out', 'engrave', 'get out', 'hectograph', 'impress', 'imprint', 'issue', 'mimeograph', 'multigraph', 'print', 'proof', 'prove'],
    'overreach': ['aggrandize', 'amplify', 'ballyhoo', 'bamboozle', 'beat', 'beguile', 'betray', 'bilk', 'bluff', 'build up', 'burlesque', 'cajole'],
    'overreact': ['aggrandize', 'amplify', 'ballyhoo', 'build up', 'burlesque', 'caricature', 'carry too far', 'draw the longbow', 'exaggerate', 'exhaust', 'go overboard', 'go to extremes'],
    'overrefined': ['gongoresque', 'gongoristic', 'marinistic', 'affected', 'allergic', 'anaphylactic', 'apparently sound', 'artificial', 'casuistic', 'chichi', 'colorable', 'deceptive'],
    'overreligious': ['bigoted', 'extravagant', 'extreme', 'extremist', 'fanatic', 'fanatical', 'haggard', 'inordinate', 'irrational', 'overdevout', 'overenthusiastic', 'overrighteous'],
    'override': ['abolish', 'abrogate', 'annul', 'arch over', 'beat down', 'bend', 'bestraddle', 'bestride', 'break', 'bridge', 'browbeat', 'bulldoze'],
    'overriding': ['all-absorbing', 'capital', 'cardinal', 'chief', 'compelling', 'controlling', 'dominant', 'dominating', 'foremost', 'highest', 'leading', 'main'],
    'overripe': ['bad', 'barfy', 'brackish', 'cloying', 'fetid', 'foul', 'fulsome', 'high', 'icky', 'maggoty', 'mawkish', 'nasty'],
    'overrule': ['abolish', 'abrogate', 'annul', 'bear reign', 'cancel', 'countermand', 'counterorder', 'disannul', 'do away with', 'invalidate', 'make void', 'nullify'],
    'overruling': ['absolute', 'absolutist', 'absolutistic', 'all-absorbing', 'arbitrary', 'arch', 'aristocratic', 'arrogant', 'authoritarian', 'authoritative', 'autocratic', 'banner'],
    'overrun': ['adopt', 'appropriate', 'arrogate', 'assume', 'attack', 'balance', 'beat', 'beset', 'bespread', 'blitz', 'bonus', 'branch'],
    'overrunning': ['alluvion', 'alluvium', 'cataclysm', 'deluge', 'diffusion', 'engulfment', 'flood', 'imbuement', 'infestation', 'inundation', 'invasion', 'lousiness'],
    'overseas': ['abroad', 'across the sea', 'alien', 'away from home', 'beyond seas', 'exotic', 'foreign', 'in foreign parts', 'nonresident', 'not in residence', 'on leave', 'on sabbatical leave'],
    'oversee': ['administer', 'boss', 'chaperon', 'control', 'direct', 'handle', 'keep in order', 'manage', 'manipulate', 'operate', 'overlook', 'quarterback'],
    'overseer': ['big brother', 'auditor', 'boatswain', 'boss', 'chief', 'comptroller', 'controller', 'floor manager', 'floorman', 'floorwalker', 'foreman', 'gaffer'],
    'oversell': ['aggrandize', 'amplify', 'ballyhoo', 'be prodigal with', 'build up', 'burlesque', 'caricature', 'carry too far', 'deluge', 'draw the longbow', 'engulf', 'exaggerate'],
    'oversensitive': ['allergic', 'anaphylactic', 'delicate', 'empathetic', 'empathic', 'goosy', 'hairsplitting', 'high-strung', 'hypercritical', 'hyperesthetic', 'hyperpathic', 'hypersensitive'],
    'overset': ['balance', 'be lost', 'bonus', 'capsizal', 'capsize', 'careen', 'culbute', 'culbuter', 'deck', 'dividend', 'extra', 'floor'],
    'oversexed': ['amorous', 'carnal', 'erogenic', 'erogenous', 'erotic', 'erotogenic', 'fleshly', 'gamic', 'heterosexual', 'libidinal', 'nuptial', 'potent'],
    'overshadow': ['adumbrate', 'becloud', 'bedarken', 'bedim', 'befog', 'begloom', 'bemist', 'bestraddle', 'bestride', 'black', 'black out', 'blacken'],
    'overshoot': ['alight', 'come down', 'come in', 'crash-land', 'descend', 'ditch', 'downwind', 'exaggerate', 'exceed', 'go beyond', 'land', 'level off'],
    'oversight': ['accountability', 'administration', 'aegis', 'auspices', 'balk', 'bevue', 'blank', 'blunder', 'bossing', 'care', 'carelessness', 'charge'],
    'oversimplification': ['callowness', 'coarseness', 'conceptual crudity', 'crudeness', 'crudity', 'greenness', 'immatureness', 'immaturity', 'nondevelopment', 'oversimplicity', 'oversimplifying', 'rawness'],
    'oversleep': ['be behindhand', 'be late', 'be overdue', 'blow the chance', 'doze', 'drowse', 'get up late', 'keep everyone waiting', 'keep late hours', 'lose the chance', 'lose the opportunity', 'miss an opportunity'],
    'oversold': ['aggrandized', 'amplified', 'ballyhooed', 'disproportionate', 'exaggerated', 'excessive', 'exorbitant', 'extravagant', 'extreme', 'grandiloquent', 'high-flown', 'hyperbolic'],
    'overspend': ['be had', 'carry too far', 'exaggerate', 'exhaust', 'go overboard', 'go to extremes', 'go too far', 'know no bounds', 'overact', 'overcarry', 'overdevelop', 'overdo'],
    'overspread': ['apply to', 'beset', 'bespread', 'bestrew', 'blanket', 'block', 'broadcast', 'canopy', 'cap', 'circumfuse', 'cloak', 'clothe'],
    'overstate': ['aggrandize', 'amplify', 'ballyhoo', 'belie', 'blow up', 'build up', 'burlesque', 'camouflage', 'caricature', 'carry too far', 'color', 'disguise'],
    'overstated': ['aggrandized', 'amplified', 'ballyhooed', 'disproportionate', 'exaggerated', 'excessive', 'exorbitant', 'extravagant', 'extreme', 'grandiloquent', 'high-flown', 'hyperbolic'],
    'overstep': ['abuse a privilege', 'advance upon', 'bother', 'break bounds', 'encroach', 'encroach upon', 'exaggerate', 'exceed', 'go beyond', 'go too far', 'impose on', 'impose upon'],
    'overstrain': ['beat', 'burn out', 'carry too far', 'debilitate', 'do in', 'do up', 'enervate', 'exaggerate', 'exhaust', 'fag', 'fag out', 'fatigue'],
    'overstuffed': ['sro', 'allayed', 'bloated', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full', 'choked', 'chuck-full', 'cloyed'],
    'oversupply': ['avalanche', 'balance', 'be prodigal with', 'bonus', 'deluge', 'dividend', 'embarras de richesses', 'engulf', 'enough', 'extra', 'extravagance', 'extravagancy'],
    'overt': ['apparent', 'bald', 'bare', 'clear', 'clear-cut', 'disclosed', 'evident', 'exposed', 'manifest', 'naked', 'observable', 'obvious'],
    'overt act': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adventure', 'blow', 'coup', 'dealings', 'deed', 'doing'],
    'overtake': ['attend', 'befall', 'booze up', 'boozify', 'catch up with', 'come after', 'come up to', 'come up with', 'come upon', 'crock', 'displace', 'emanate'],
    'overtax': ['bear hard upon', 'bleed', 'bleed white', 'burden', 'burthen', 'busy', 'carry too far', 'charge', 'clip', 'cumber', 'drive', 'encumber'],
    'overthrow': ['waterloo', 'about-face', 'accommodate', 'accommodation', 'adapt', 'adaptation', 'adjust', 'adjustment', 'alter', 'alteration', 'ameliorate', 'amelioration'],
    'overthrown': ['all up with', 'ausgespielt', 'bankrupt', 'beat', 'beaten', 'belied', 'bested', 'blasted', 'blighted', 'broken', 'confounded', 'confuted'],
    'overtime': ['anchor watch', 'bit', 'day shift', 'dogwatch', 'full time', 'graveyard shift', 'half time', 'lobster trick', 'night shift', 'part time', 'relay', 'shift'],
    'overtire': ['beat', 'burn out', 'debilitate', 'do in', 'do up', 'enervate', 'exhaust', 'fag', 'fag out', 'fatigue', 'flag', 'frazzle'],
    'overtone': ['af', 'affective meaning', 'air', 'allegory', 'allusion', 'arcane meaning', 'assumption', 'atmosphere', 'audio frequency', 'aura', 'bearing', 'climate'],
    'overture': ['vorspiel', 'advance', 'approach', 'asking price', 'avant-propos', 'bid', 'breakthrough', 'concert overture', 'curtain raiser', 'descant', 'dramatic overture', 'exordium'],
    'overturn': ['waterloo', 'answer', 'answer conclusively', 'argue down', 'be lost', 'beating', 'bloodless revolution', 'bouleversement', 'breakdown', 'breakup', 'bring down', 'capsizal'],
    'overvalue': ['adore', 'cherish', 'exaggerate', 'idealize', 'idolize', 'overappraise', 'overassess', 'overcalculate', 'overcount', 'overesteem', 'overestimate', 'overmeasure'],
    'overview': ['abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'brief', 'capsule', 'compend', 'condensation', 'condensed version', 'conspectus', 'contemplation'],
    'overweening': ['a bit much', 'abandoned', 'arrogant', 'assuming', 'assured', 'audacious', 'boundless', 'brash', 'brazen', 'brazenfaced', 'bumptious', 'cocksure'],
    'overweight': ['adipose', 'avoirdupois', 'bear hard upon', 'beef', 'beefiness', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'burden'],
    'overwhelm': ['afflict', 'aggrieve', 'amaze', 'anguish', 'answer', 'answer conclusively', 'argue down', 'astonish', 'astound', 'awe', 'awestrike', 'baptize'],
    'overwhelmed': ['afloat', 'agape', 'aghast', 'agog', 'all agog', 'all up with', 'amazed', 'astonished', 'astounded', 'at flood', 'at gaze', 'awash'],
    'overwhelming': ['absolute', 'adducible', 'admissible', 'agitating', 'amazing', 'astonishing', 'astounding', 'attestative', 'attestive', 'authentic', 'awe-inspiring', 'awesome'],
    'overwork': ['burden', 'busy', 'carry too far', 'do double duty', 'drive', 'elucubrate', 'exaggerate', 'exhaust', 'fag', 'go overboard', 'go to extremes', 'go too far'],
    'overworked': ['arabesque', 'baroque', 'busy', 'chichi', 'commonplace', 'elaborate', 'elegant', 'fancy', 'fine', 'flamboyant', 'florid', 'flowery'],
    'overwrought': ['gongoresque', 'johnsonian', 'affected', 'aggrandized', 'amplified', 'arabesque', 'ballyhooed', 'baroque', 'bedizened', 'big-sounding', 'busy', 'chichi'],
    'overzealous': ['accident-prone', 'at fever pitch', 'balking', 'balky', 'bigoted', 'breakneck', 'bulldogged', 'bulletheaded', 'bullheaded', 'careless', 'case-hardened', 'delirious'],
    'ovine': ['asinine', 'bovid', 'bovine', 'caprid', 'caprine', 'cowish', 'cowlike', 'deerlike', 'equestrian', 'equine', 'goatish', 'goatlike'],
    'ovoid': ['bulblike', 'bulbous', 'egg-shaped', 'ellipse', 'ellipsoid', 'global', 'globate', 'globe-shaped', 'globed', 'globelike', 'globoid', 'globose'],
    'ovule': ['albumen', 'caviar', 'egg', 'egg cell', 'egg white', 'eggshell', 'ellipse', 'female gamete', 'fish eggs', 'glair', 'ooecium', 'oval'],
    'owing': ['accountable', 'alleged', 'ascribable', 'assignable', 'attributable', 'attributed', 'back', 'charged', 'coming', 'coming to', 'credited', 'derivable from'],
    'owing to': ['after', 'arising from', 'attributable to', 'because of', 'by reason of', 'by virtue of', 'caused by', 'coming from', 'considering', 'contingent on', 'dependent on', 'derivable from'],
    'owl': ['angry clouds', 'avifauna', 'baby bird', 'bird', 'bird of jove', 'bird of juno', 'bird of minerva', 'bird of night', 'bird of passage', 'bird of prey', 'birdie', 'birdlife'],
    'own': ['accept', 'acknowledge', 'admit', 'admit everything', 'agree provisionally', 'allow', 'assent grudgingly', 'avow', 'by one', 'come clean', 'concede', 'confess'],
    'own up': ['acknowledge', 'admit', 'admit everything', 'allow', 'avow', 'come clean', 'concede', 'confess', 'cop a plea', 'grant', 'let on', 'open up'],
    'owner': ['beneficiary', 'cestui', 'cestui que trust', 'cestui que use', 'deedholder', 'feoffee', 'feudatory', 'holder', 'householder', 'laird', 'landlady', 'landlord'],
    'ox': ['brahman', 'gibraltar', 'indian buffalo', 'siberian husky', 'ass', 'aurochs', 'beast of burden', 'beef', 'beef cattle', 'beeves', 'bison', 'blockhead'],
    'oxidation': ['acetification', 'acidification', 'acidulation', 'alkalization', 'biodegradability', 'biodegradation', 'blazing', 'blistering', 'branding', 'breakup', 'burning', 'calcination'],
    'oxidize': ['acetify', 'acidify', 'acidulate', 'alkalify', 'alkalize', 'blaze', 'blister', 'borate', 'brand', 'burn', 'burn in', 'burn off'],
    'oxygen': ['acetylene', 'ammonia', 'argon', 'asphyxiating gas', 'butane', 'carbon dioxide', 'carbon monoxide', 'chlorine', 'coal gas', 'ethane', 'ether', 'ethylene'],
    'oxygen tent': ['aqua-lung', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'breath', 'breath of air', 'breathing', 'broken wind', 'cough', 'exhalation', 'expiration', 'exsufflation'],
    'oxygenate': ['aerate', 'aerify', 'air', 'air out', 'air-condition', 'air-cool', 'airify', 'atomize', 'carbonate', 'chlorinate', 'cross-ventilate', 'distill'],
    'oxymoron': ['gordian knot', 'absurdity', 'ambiguity', 'ambivalence', 'antinomy', 'asymmetry', 'crux', 'dilemma', 'disproportion', 'disproportionateness', 'enigma', 'equivocality'],
    'oyster': ['dungeness crab', 'japanese crab', 'blue point', 'breast', 'chicken foot', 'clam', 'coquillage', 'crab', 'crawdad', 'crawfish', 'crayfish', 'dark meat'],
    'pa': ['gramophone', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer', 'crystal pickup'],
    'pa system': ['gramophone', 'pa', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer', 'crystal pickup'],
    'pace': ['amble', 'ambulate', 'ankle', 'antecede', 'antedate', 'appraise', 'appreciate', 'assay', 'assess', 'barge', 'bat', 'be the bellwether'],
    'pacesetter': ['mahdi', 'bell cow', 'bell mare', 'bellwether', 'born leader', 'charismatic leader', 'choirmaster', 'choragus', 'conductor', 'coryphaeus', 'duce', 'file leader'],
    'pacific': ['appeasing', 'at peace', 'at rest', 'bloodless', 'broken', 'calm', 'chastened', 'civilian', 'cloistered', 'conciliatory', 'concordant', 'cool'],
    'pacification': ['pax dei', 'pax romana', 'peace of god', 'abatement', 'allayment', 'alleviation', 'armistice', 'assuagement', 'blunting', 'breathing spell', 'buffer zone', 'calming'],
    'pacifier': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'pacifism': ['a wise passiveness', 'abnegation', 'abstinence', 'calm', 'calmness', 'conservatism', 'constraint', 'contemplation', 'contemplative life', 'continence', 'control', 'cool'],
    'pacifistic': ['bland', 'civilian', 'conciliatory', 'dovish', 'gentle', 'irenic', 'judicious', 'mild', 'mild as milk', 'moderate', 'nonaggressive', 'noncombatant'],
    'pacify': ['allay', 'alleviate', 'appease', 'arrange', 'array', 'assuage', 'calm', 'calm down', 'cease', 'compose', 'conciliate', 'cool'],
    'pacifying': ['appeasing', 'calming', 'conciliatory', 'cradling', 'dreamy', 'drowsy', 'gentling', 'hushing', 'irenic', 'lulling', 'mollifying', 'pacific'],
    'pack': ['a mass of', 'a world of', 'abound with', 'accumulation', 'ace', 'adulterate', 'age group', 'amassment', 'amount', 'army', 'assemblage', 'assembly'],
    'pack away': ['bag', 'bank', 'barrel', 'bottle', 'box', 'bundle away', 'burden', 'cache', 'can', 'coffer', 'crate', 'deposit'],
    'pack in': ['admit', 'barge in', 'be admitted', 'break in', 'breeze in', 'burst in', 'bust in', 'come barging in', 'come breezing in', 'come busting in', 'come in', 'cram in'],
    'pack of troubles': ['affliction', 'bitter cup', 'bitter draft', 'bitter draught', 'bitter pill', 'burden', 'burden of care', 'cankerworm of care', 'care', 'cross', 'crown of thorns', 'curse'],
    'pack off': ['beat back', 'bow out', 'brush off', 'bundle', 'bundle off', 'chase', 'chase away', 'chase off', 'cut', 'dismiss', 'drive away', 'drive back'],
    'package': ['a to z', 'a to izzard', 'anschluss', 'addition', 'affiliation', 'agglomeration', 'aggregate', 'aggregation', 'agreement', 'all', 'all and sundry', 'alliance'],
    'package deal': ['a to z', 'a to izzard', 'anschluss', 'addition', 'affiliation', 'agglomeration', 'aggregate', 'aggregation', 'agreement', 'all', 'all and sundry', 'alliance'],
    'package tour': ['campaign', 'circuit', 'course', 'excursion', 'expedition', 'grand tour', 'jaunt', 'journey', 'junket', 'outing', 'peregrination', 'pilgrimage'],
    'packaged': ['accumulated', 'agglomerate', 'aggregate', 'amassed', 'armored', 'assembled', 'bunched', 'bundled', 'cased', 'ceiled', 'cloaked', 'clouded'],
    'packed': ['sro', 'aground', 'alive with', 'anchored', 'awash', 'bloated', 'blocked', 'bound', 'brimful', 'brimming', 'bristling', 'bulging'],
    'packet': ['argosy', 'bale', 'bark', 'batch', 'bindle', 'boat', 'bolt', 'bomb', 'boodle', 'bottom', 'bouquet', 'bucket'],
    'packet boat': ['carrier', 'carrier pigeon', 'homer', 'homing pigeon', 'mail car', 'mail coach', 'mail packet', 'mail train', 'mail truck', 'mailer', 'mailplane', 'pigeon post'],
    'packing': ['air express', 'airfreight', 'airlift', 'allocation', 'asportation', 'assignment', 'bearing', 'bottling', 'boxing', 'bush', 'bushing', 'canning'],
    'packing house': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery', 'brewery', 'brickyard', 'cannery'],
    'pact': ['accord', 'agreement', 'alliance', 'arrangement', 'bargain', 'binding agreement', 'bond', 'cartel', 'collective agreement', 'compact', 'concord', 'concordat'],
    'pad': ['domesday book', 'abate', 'abiding place', 'abode', 'account book', 'address', 'address book', 'adversaria', 'aegis', 'air mattress', 'album', 'allay'],
    'padded': ['de longue haleine', 'endless', 'extended', 'filled out', 'lengthy', 'long', 'long-drawn-out', 'long-spun', 'long-winded', 'longiloquent', 'prolix', 'protracted'],
    'padding': ['aegis', 'all fours', 'arm guard', 'backstop', 'battology', 'bedizenment', 'bonus', 'buffer', 'bulwark', 'bumper', 'bush', 'bushing'],
    'paddle': ['agitate', 'agitator', 'amble', 'asperge', 'barge', 'beat', 'beat up', 'beater', 'bedew', 'bespatter', 'besprinkle', 'birch'],
    'paddy': ['bluebottle', 'bobby', 'bull', 'clearing', 'constable', 'copper', 'corn field', 'cultivated land', 'field', 'fit', 'fit of temper', 'flatfoot'],
    'padlock': ['bang', 'bar', 'barricade', 'barrier', 'batten', 'batten down', 'bolt', 'button', 'button up', 'choke', 'choke off', 'clap'],
    'padre': ['dd', 'doctor of divinity', 'holy joe', 'abbe', 'cassock', 'chaplain', 'churchman', 'clergyman', 'cleric', 'clerical', 'clerk', 'confessor'],
    'padrone': ['boss', 'bwana', 'chef', 'chief', 'church dignitary', 'ecclesiarch', 'elder', 'employer', 'goodman', 'guru', 'husband', 'liege'],
    'paean': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'negro spiritual', 'nunc dimittis', 'te deum', 'trisagion'],
    'pagan': ['gentile', 'gothic', 'philistine', 'allotheist', 'allotheistic', 'animist', 'animistic', 'atheist', 'atheistic', 'barbarous', 'bibliolatrous', 'bookless'],
    'paganism': ['druidism', 'gothicism', 'parsiism', 'sabaism', 'zoroastrianism', 'age of ignorance', 'allotheism', 'animal worship', 'animatism', 'animism', 'barbarism', 'benightedness'],
    'page': ['ganymede', 'hebe', 'acknowledgments', 'age', 'airline hostess', 'airline stewardess', 'announce', 'article', 'attendant', 'back', 'back matter', 'bastard title'],
    'pageant': ['grand guignol', 'passion play', 'tom show', 'affair', 'antimasque', 'audience success', 'ballet', 'blazon', 'bomb', 'bravura', 'brilliancy', 'broadcast drama'],
    'pageantry': ['blazon', 'bravura', 'brilliancy', 'ceremony', 'cosmorama', 'cyclorama', 'daring', 'dash', 'demonstration', 'diorama', 'display', 'dramatics'],
    'pagoda': ['alcove', 'antenna tower', 'barbican', 'belfry', 'bell tower', 'belvedere', 'campanile', 'colossus', 'column', 'cupola', 'derrick', 'dewal'],
    'paid': ['acquitted', 'chartered', 'discharged', 'employed', 'expended', 'hired', 'hireling', 'leased', 'let', 'liquidated', 'mercenary', 'paid in full'],
    'pain': ['abscess', 'ache', 'aching', 'afflict', 'affliction', 'aggrieve', 'agonize', 'agony', 'ague', 'ail', 'anemia', 'anguish'],
    'pain killer': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'pained': ['aching', 'afflicted', 'aggrieved', 'agonized', 'anguished', 'bleeding', 'bruised', 'convulsed', 'crucified', 'cut', 'distressed', 'grieved'],
    'painful': ['herculean', 'aching', 'achy', 'acute', 'affecting', 'afflictive', 'aggravating', 'agonizing', 'algetic', 'annoying', 'arduous', 'assiduous'],
    'painfully': ['abominably', 'agonizingly', 'arduously', 'awfully', 'badly', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly'],
    'painless': ['mickey mouse', 'casual', 'cinch', 'clear', 'comfortable', 'cushy', 'easy', 'easy as pie', 'effortless', 'facile', 'glib', 'light'],
    'pains': ['assiduity', 'assiduousness', 'diligence', 'effort', 'elbow grease', 'endeavor', 'energy', 'exertion', 'hard pull', 'industriousness', 'industry', 'long pull'],
    'painstaking': ['assiduity', 'assiduous', 'assiduousness', 'conscientious', 'conscionable', 'diligence', 'diligent', 'elaborate', 'exact', 'fussy', 'heedful', 'industrious'],
    'painstakingly': ['assiduously', 'carefully', 'cautiously', 'circumspectly', 'considerately', 'diligently', 'dingdong', 'earnestly', 'exhaustively', 'heedfully', 'industriously', 'intensely'],
    'paint': ['zanzibar copal', 'adorn', 'air brush', 'anime', 'apply', 'apply paint', 'array', 'art paper', 'base', 'bay', 'bayard', 'bead'],
    'paintbrush': ['air brush', 'art paper', 'brush', 'camera lucida', 'camera obscura', 'canvas', 'chalk', 'charcoal', 'crayon', 'drawing paper', 'drawing pencil', 'drier'],
    'painter': ['bacon', 'bellows', 'benton', 'botticelli', 'boucher', 'buffet', 'cassatt', 'chirico', 'constable', 'copley', 'corot', 'correggio'],
    'painting': ['acrylic painting', 'aquarelle', 'calcimining', 'canvas', 'coating', 'coloring', 'covering', 'drawing', 'easel-picture', 'enameling', 'encaustic cerography', 'encaustic painting'],
    'pair': ['gaussian integer', 'accouple', 'accumulate', 'ace', 'affiliate', 'agglomerate', 'agglutinate', 'aggregate', 'aggroup', 'algebraic number', 'ally', 'amass'],
    'pair off': ['affiliate', 'ally', 'associate', 'average', 'average out', 'avoid extremes', 'band together', 'be in cahoots', 'be made one', 'be spliced', 'become one', 'bracket'],
    'paired': ['accessory', 'accompanying', 'affiliate', 'affiliated', 'allied', 'assembled', 'associate', 'associated', 'attendant', 'attending', 'banded together', 'biconjugate'],
    'pairing': ['janus', 'agglomeration', 'agglutination', 'aggregation', 'ambiguity', 'ambivalence', 'articulation', 'biformity', 'bifurcation', 'bond', 'bracketing', 'clustering'],
    'pal': ['ace', 'amigo', 'associate', 'associate with', 'assort with', 'bedfellow', 'bedmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty'],
    'paladin': ['achilles', 'david', 'hector', 'roland', 'samson', 'a man', 'advocate', 'apologist', 'brave', 'bulldog', 'champion', 'chutzpanik'],
    'palaestra': ['rugby', 'acrobatics', 'agonistics', 'agora', 'amphitheater', 'arena', 'association football', 'athletic field', 'athletics', 'auditorium', 'background', 'bathing'],
    'palatable': ['agreeable', 'ambrosial', 'appetizing', 'comestible', 'dainty', 'delectable', 'delicate', 'delicious', 'delightful', 'eatable', 'edible', 'esculent'],
    'palatal': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation', 'back'],
    'palate': ['aftertaste', 'alveolar ridge', 'alveolus', 'apex', 'appreciation', 'appreciation of differences', 'appreciativeness', 'artistic judgment', 'arytenoid cartilages', 'back', 'bitter', 'blade'],
    'palatial': ['babylonian', 'corinthian', 'awe-inspiring', 'awful', 'barbaric', 'classy', 'deluxe', 'domal', 'domestic', 'domiciliary', 'elaborate', 'elegant'],
    'palaver': ['absurdity', 'accents', 'adulate', 'adulation', 'advise with', 'affair', 'amphigory', 'audience', 'babble', 'babblement', 'balderdash', 'bargain'],
    'pale': ['abate', 'abnormal', 'achievement', 'achromatic', 'achromatize', 'achromic', 'alabaster', 'alabastrine', 'albescent', 'alerion', 'ambit', 'anathema'],
    'paleface': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'paleness': ['hippocratic face', 'achroma', 'achromasia', 'achromatosis', 'albescence', 'albinism', 'albino', 'albinoism', 'anemia', 'aridity', 'ashiness', 'barrenness'],
    'paleography': ['ipa', 'ita', 'initial teaching alphabet', 'alphabet', 'alphabetics', 'autography', 'bowwow theory', 'calligraphy', 'chirography', 'comparative linguistics', 'criticism', 'cryptanalysis'],
    'paleolith': ['ancient manuscript', 'antique', 'antiquity', 'archaism', 'artifact', 'cave painting', 'eolith', 'fossil', 'mezzolith', 'microlith', 'neolith', 'petrification'],
    'paleontology': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology', 'biometrics'],
    'palette': ['air brush', 'art paper', 'brush', 'camera lucida', 'camera obscura', 'canvas', 'chalk', 'charcoal', 'crayon', 'drawing paper', 'drawing pencil', 'drier'],
    'palindrome': ['abuse of terms', 'acrostic', 'amphibologism', 'amphiboly', 'anagram', 'anastrophe', 'calembour', 'chiasmus', 'corruption', 'equivocality', 'equivoque', 'hypallage'],
    'palinode': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'abjuration', 'abjurement', 'alba', 'anacreontic', 'balada'],
    'palisade': ['abatis', 'advanced work', 'arm', 'armor', 'armor-plate', 'balistraria', 'bank', 'banquette', 'bar', 'barbed-wire entanglement', 'barbican', 'barricade'],
    'pall': ['allay', 'bamboo curtain', 'barrier of secrecy', 'be infinitely repetitive', 'be tedious', 'blackout', 'blanket', 'bore', 'censorship', 'cerecloth', 'cerements', 'cloak'],
    'palladium': ['aegis', 'arm guard', 'backstop', 'buffer', 'bulwark', 'bumper', 'contraceptive', 'copyright', 'crash helmet', 'cushion', 'dashboard', 'dodger'],
    'pallet': ['air mattress', 'bean', 'bedding', 'belfry', 'bolster', 'chump', 'cushion', 'head', 'headpiece', 'innerspring mattress', 'litter', 'mat'],
    'palliate': ['abate', 'adjust to', 'allay', 'alleviate', 'allow for', 'alter', 'anesthetize', 'appease', 'assuage', 'attemper', 'bank the fire', 'benumb'],
    'palliative': ['alleviating', 'alleviative', 'alleviator', 'allowance', 'altering', 'analgesic', 'anesthetic', 'anodyne', 'apologetic', 'assuager', 'assuasive', 'balm'],
    'pallid': ['achromatic', 'achromic', 'aghast', 'anemic', 'appalled', 'arid', 'ashen', 'ashy', 'astounded', 'awed', 'awestricken', 'awestruck'],
    'pallor': ['hippocratic face', 'achromatism', 'anemia', 'aridity', 'ashiness', 'barrenness', 'bloodlessness', 'cadaverousness', 'cast', 'characterlessness', 'chloranemia', 'chromatism'],
    'palm': ['old mug', 'abstract', 'acme', 'acquire', 'and', 'annex', 'appropriate', 'authority', 'authorization', 'bag', 'bays', 'be-all and end-all'],
    'palm oil': ['trinkgeld', 'bonus', 'bounty', 'bribe', 'consideration', 'donative', 'double time', 'fee', 'gratuity', 'gravy', 'grease', 'honorarium'],
    'palm sunday': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas'],
    'palmy': ['balmy', 'blooming', 'blossoming', 'booming', 'clear', 'exuberant', 'fair', 'fat', 'flourishing', 'flowering', 'fruiting', 'going strong'],
    'palooka': ['chinese boxer', 'bantamweight', 'black belt', 'boxer', 'brown belt', 'bruiser', 'featherweight', 'fighter', 'fisticuffer', 'flyweight', 'gawk', 'heavyweight'],
    'palpable': ['apparent', 'appreciable', 'arresting', 'believable', 'certain', 'clear', 'clear as crystal', 'colorable', 'concrete', 'credible', 'crystal-clear', 'detectable'],
    'palpitant': ['beating', 'clicking', 'drumming', 'fluttering', 'pitapat', 'pounding', 'pulsatile', 'pulsating', 'pulsative', 'pulsatory', 'pulsing', 'rhythmic'],
    'palpitate': ['beat', 'beat a ruffle', 'beat a tattoo', 'bicker', 'dance', 'drum', 'fidget', 'flap', 'flick', 'flicker', 'flip', 'flip out'],
    'palpitation': ['agitation', 'angina', 'angina pectoris', 'aortic insufficiency', 'aortic stenosis', 'apoplectic stroke', 'apoplexy', 'arrhythmia', 'arteriosclerosis', 'atherosclerosis', 'atrial fibrillation', 'auricular fibrillation'],
    'palsied': ['allergic', 'anemic', 'anile', 'apoplectic', 'arthritic', 'aspen', 'bilious', 'cancerous', 'chattering', 'chlorotic', 'colicky', 'consumptive'],
    'palsy': ['ms', 'ague', 'amyotrophic lateral sclerosis', 'apoplexy', 'brain disease', 'bumpiness', 'catalepsy', 'cataplexy', 'cephalalgia', 'cerebral palsy', 'chattering', 'chorea'],
    'palter': ['around the bush', 'back and fill', 'bargain', 'beat about', 'beg the question', 'bicker', 'boggle', 'cavil', 'chaffer', 'choplogic', 'dicker', 'dodge'],
    'paltry': ['lenten', 'mickey mouse', 'spartan', 'abject', 'abominable', 'abstemious', 'arrant', 'ascetic', 'atrocious', 'austere', 'base', 'beggarly'],
    'paludal': ['boggish', 'boggy', 'fenny', 'marish', 'marshy', 'mirish', 'miry', 'moorish', 'moory', 'muddy', 'paludous', 'poachy'],
    'pampas': ['alkali flat', 'alluvial plain', 'basin', 'bottomland', 'bushveld', 'campo', 'champaign', 'champaign country', 'coastal plain', 'delta', 'desert', 'down'],
    'pamper': ['baby', 'care for', 'caress', 'cater to', 'cherish', 'cocker', 'coddle', 'cosset', 'cradle', 'cultivate', 'dandle', 'dry-nurse'],
    'pamphlet': ['ad', 'advert', 'advertisement', 'bill', 'booklet', 'brochure', 'bulletin', 'chapbook', 'circular', 'comic book', 'essay', 'flyer'],
    'pan': ['photostat', 'x-ray', 'xerox', 'ashpan', 'bake', 'bakepan', 'barbecue', 'baste', 'blame', 'blanch', 'boil', 'boiler'],
    'pan out': ['attend', 'become of', 'click', 'come about', 'come of', 'come off', 'come out', 'develop', 'end', 'ensue', 'eventuate', 'fall out'],
    'pan shot': ['boom shot', 'close-up', 'deuce shot', 'follow-focus shot', 'full shot', 'group shot', 'kinescope', 'long shot', 'matte shot', 'medium shot', 'motion picture', 'panoramic shot'],
    'panache': ['animation', 'blatancy', 'boldness', 'brazenness', 'brio', 'chic', 'colorfulness', 'crest', 'crudeness', 'cultivation', 'dash', 'dazzle'],
    'pancake': ['alight', 'blintz', 'buckwheat cake', 'cheese blintz', 'come down', 'come in', 'crash-land', 'crepe', 'descend', 'ditch', 'downwind', 'flapcake'],
    'pandect': ['code napoleon', 'napoleonic code', 'abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'article', 'body of law', 'brief', 'capitulary', 'capsule'],
    'pandemic': ['ambulatory plague', 'average', 'besetting', 'black death', 'black plague', 'bubonic plague', 'catching', 'cellulocutaneous plague', 'common', 'communicable', 'contagious', 'current'],
    'pandemonium': ['babel', 'bedlam let loose', 'gehenna', 'sheol', 'sodom', 'tophet', 'abyss', 'agitation', 'babel', 'bedlam', 'blast', 'bluster'],
    'pander': ['bawd', 'bow to', 'bully', 'cadet', 'cater to', 'fancy', 'fancy man', 'gigolo', 'gratify', 'humor', 'indulge', 'madam'],
    'pander to': ['administer to', 'attend', 'attend on', 'care for', 'cater to', 'chore', 'dance attendance upon', 'do for', 'do service', 'do service to', 'drudge', 'fetch and carry'],
    'pandit': ['abecedarian', 'certified teacher', 'docent', 'doctor', 'dominie', 'don', 'educationist', 'educator', 'fellow', 'guide', 'guru', 'instructor'],
    'pandowdy': ['danish pastry', 'french pastry', 'baklava', 'blintz', 'chocolate eclair', 'cream puff', 'dowdy', 'eclair', 'pastry', 'pasty', 'patisserie', 'patty'],
    'pane': ['bay', 'bay window', 'bow window', 'casement', 'casement window', 'coat', 'coating', 'collop', 'covering', 'cut', 'deal', 'diaphane'],
    'panegyric': ['acclamatory', 'accolade', 'admiring', 'adulation', 'apotheosis', 'appreciative', 'approbatory', 'bepraisement', 'commendatory', 'complimentary', 'congratulation', 'deification'],
    'panel': ['accessory', 'assemblee', 'assembly', 'assignation', 'at home', 'ball', 'barrier', 'blue-ribbon jury', 'brattice', 'brawl', 'buffer', 'buffer state'],
    'panel show': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger', 'closet drama'],
    'paneling': ['formica', 'masonite', 'beam', 'billet', 'board', 'boarding', 'clapboard', 'cord', 'cordwood', 'deal', 'driftwood', 'firewood'],
    'panelist': ['debater', 'declaimer', 'demagogue', 'haranguer', 'jawsmith', 'public speaker', 'rabble-rouser', 'ranter', 'speaker', 'speecher', 'speechifier', 'speechmaker'],
    'pang': ['ache', 'aching', 'acute pain', 'anguish', 'bite', 'blow', 'boring pain', 'charley horse', 'contriteness', 'contrition', 'cramp', 'cramps'],
    'panhandler': ['beggar', 'bum', 'bummer', 'cadger', 'coupon clippers', 'drone', 'freeloader', 'hobo', 'idle rich', 'leisure class', 'loafer', 'lounge lizard'],
    'panic': ['abject fear', 'affright', 'agitation', 'alarm', 'anxiety', 'apprehension', 'apprehensiveness', 'attack of nerves', 'awe', 'bear panic', 'belly laugh', 'blue funk'],
    'panic-stricken': ['afraid', 'aghast', 'alarmed', 'appalled', 'distressed', 'fearful', 'frenzied', 'horrified', 'horror-struck', 'hysterical', 'in a tizzy', 'jittery'],
    'panicked': ['all up with', 'beat', 'beaten', 'bested', 'confounded', 'defeated', 'discomfited', 'done for', 'done in', 'down', 'fallen', 'fixed'],
    'panicky': ['afraid', 'all nerves', 'apprehensive', 'chicken', 'chickenhearted', 'coward', 'cowardly', 'cowed', 'daunted', 'dismayed', 'edgy', 'excitable'],
    'panning': ['banter', 'bantering', 'booing', 'catcalling', 'chaffing', 'derision', 'derisive', 'derisory', 'fleering', 'flippancy', 'flippant', 'fooling'],
    'panoply': ['armature', 'armor', 'armor plate', 'army', 'body armor', 'buckler', 'bulletproof vest', 'chain armor', 'chain mail', 'cluster', 'coat of mail', 'cohue'],
    'panorama': ['abstract', 'abstraction', 'airscape', 'altarpiece', 'block print', 'cityscape', 'cloudscape', 'collage', 'color print', 'compass', 'copy', 'cosmorama'],
    'panoramic': ['across-the-board', 'all-comprehensive', 'all-embracing', 'all-encompassing', 'all-inclusive', 'blanket', 'commanding', 'compendious', 'complete', 'comprehensive', 'encyclopedic', 'extensive'],
    'panpipe': ['english horn', 'pandean pipe', 'aulos', 'basset horn', 'basset oboe', 'bassoon', 'bombard', 'clarinet', 'contrabassoon', 'contrafagotto', 'cromorne', 'double bassoon'],
    'pansy': ['milquetoast', 'auntie', 'baby', 'bi-guy', 'big baby', 'bisexual', 'bull dyke', 'butch', 'catamite', 'chicken', 'crybaby', 'doormat'],
    'pant': ['aqua-lung', 'ache for', 'aim', 'artificial respiration', 'aspiration', 'aspire', 'asthmatic wheeze', 'bake', 'bark', 'bawl', 'be dying for', 'be hurting for'],
    'pantaloon': ['father time', 'methuselah', 'nestor', 'old paar', 'breeches', 'breeks', 'britches', 'centenarian', 'dotard', 'elder', 'gaffer', 'geezer'],
    'pantheism': ['albigensianism', 'arianism', 'catharism', 'ebionitism', 'erastianism', 'gnosticism', 'jovinianism', 'lollardy', 'manichaeanism', 'manichaeism', 'monophysism', 'monophysitism'],
    'pantheistic': ['albigensian', 'arian', 'catharist', 'cyrenaic', 'donatist', 'ebionitist', 'eleatic', 'epicurean', 'erastian', 'gnostic', 'jansenist', 'jansenistic'],
    'panther': ['leo', 'siberian tiger', 'bobcat', 'cat-a-mountain', 'catamount', 'cheetah', 'cougar', 'jaguar', 'leopard', 'lion', 'lynx', 'mountain lion'],
    'panting': ['abrupt', 'agog', 'alacritous', 'all agog', 'animated', 'anxious', 'asthmatic', 'avid', 'breakneck', 'breathing', 'breathless', 'breathlessness'],
    'pantomime': ['grand guignol', 'passion play', 'roscius', 'tom show', 'act', 'act a part', 'act as', 'act as foil', 'act out', 'acting', 'actor', 'actress'],
    'pants': ['bermuda shorts', 'capri pants', 'bags', 'bells', 'bloomers', 'blue jeans', 'breeches', 'breeks', 'briefs', 'britches', 'buckskins', 'chivarras'],
    'pantywaist': ['lord fauntleroy', 'milquetoast', 'percy', 'baby', 'big baby', 'chicken', 'cream puff', 'crybaby', 'doormat', 'dull tool', 'effeminate', 'goody-goody'],
    'pap': ['abba', 'acid-ash diet', 'albumen', 'aliment', 'alimentation', 'allergy diet', 'bag', 'batter', 'bland diet', 'bonnyclabber', 'boobs', 'bosom'],
    'papa': ['grand penitentiary', 'holy father', 'abba', 'abuna', 'antipope', 'archbishop', 'archdeacon', 'archpriest', 'bishop', 'bishop coadjutor', 'canon', 'cardinal'],
    'papacy': ['apostolic see', 'see of rome', 'aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'bishopric', 'chairmanship', 'chancellery', 'chancellorate', 'chancellorship'],
    'paper': ['bible paper', 'cd', 'iou', 'india paper', 'mo', 'ms', 'manila paper', 'acceptance', 'acceptance bill', 'alabaster', 'analysis', 'archives'],
    'paper profits': ['capital gains', 'cleanup', 'clear profit', 'dividends', 'earnings', 'filthy lucre', 'gain', 'gains', 'get', 'gettings', 'gleanings', 'gross'],
    'paperback': ['best seller', 'book', 'bound book', 'classic', 'coloring book', 'definitive work', 'folio', 'great work', 'hardback', 'juvenile', 'juvenile book', 'limp-cover book'],
    'papers': ['americanization', 'acculturation', 'admission', 'adoption', 'affiliation', 'ana', 'archives', 'assimilation', 'biographical material', 'biographical records', 'blank', 'chirograph'],
    'papery': ['airy', 'atrophied', 'attenuate', 'attenuated', 'boyish', 'breakable', 'brittle', 'cheap-jack', 'cobwebby', 'crumbly', 'dainty', 'delicate'],
    'papilla': ['bag', 'boobs', 'bosom', 'breast', 'breasts', 'brisket', 'bust', 'chest', 'crop', 'dug', 'knockers', 'mama'],
    'papilloma': ['bilge', 'blain', 'bleb', 'blister', 'blob', 'boss', 'bow', 'bubble', 'bulb', 'bulge', 'bulla', 'bump'],
    'papoose': ['babe', 'baby', 'baby bunting', 'bambino', 'incubator baby', 'infant', 'little angel', 'little darling', 'mewling infant', 'neonate', 'nursling', 'preemie'],
    'pappy': ['abba', 'dad', 'daddy', 'dead', 'dilute', 'diluted', 'fade', 'father', 'flat', 'flavorless', 'foster father', 'genitor'],
    'papule': ['abscess', 'aposteme', 'bed sore', 'blain', 'bleb', 'blister', 'boil', 'bubo', 'bulla', 'bunion', 'canker', 'canker sore'],
    'par': ['alike', 'asking price', 'at par', 'au pair', 'average', 'balance', 'bearish prices', 'bid price', 'book value', 'bullish prices', 'call price', 'center'],
    'par value': ['account', 'asking price', 'bearish prices', 'bid price', 'book value', 'bullish prices', 'call price', 'closing price', 'conversion factor', 'decline', 'face', 'face value'],
    'parable': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'apologue', 'bedtime story', 'comparison', 'detective story', 'fable', 'fabliau'],
    'parabola': ['arc', 'bow', 'catacaustic', 'catenary', 'caustic', 'circle', 'conchoid', 'crook', 'curl', 'curve', 'diacaustic', 'ellipse'],
    'parabolic': ['allegoric', 'bell-like', 'bell-shaped', 'campaniform', 'campanular', 'campanulate', 'ellipsoid', 'elliptic', 'fabulous', 'fictional', 'legendary', 'mythic'],
    'parachute': ['mae west', 'bail out', 'breeches buoy', 'brolly', 'buoy', 'cascade', 'cataract', 'chute', 'collapse', 'come down', 'cork jacket', 'crash'],
    'parachute jump': ['belly buster', 'belly flop', 'belly whopper', 'brolly', 'cannonball', 'chute', 'crash dive', 'dive', 'drogue chute', 'drop', 'fall', 'gainer'],
    'parade': ['advertise', 'affect', 'air', 'airing', 'alameda', 'amble', 'array', 'backpack', 'beaten path', 'beaten track', 'berm', 'betoken'],
    'parade ground': ['agora', 'amphitheater', 'arena', 'athletic field', 'auditorium', 'background', 'bear garden', 'bowl', 'boxing ring', 'bull ring', 'campus', 'canvas'],
    'paradiddle': ['barrage', 'beat', 'beating', 'drum', 'drum music', 'drumbeat', 'drumfire', 'drumming', 'flutter', 'palpitation', 'patter', 'pitapat'],
    'paradigm': ['ic analysis', 'accidence', 'affix', 'affixation', 'allomorph', 'antetype', 'antitype', 'archetype', 'beau ideal', 'biotype', 'bound morpheme', 'classic example'],
    'paradisal': ['arcadian', 'edenic', 'elysian', 'olympian', 'beatific', 'beatified', 'blessed', 'celestial', 'ethereal', 'extramundane', 'extraterrestrial', 'from on high'],
    'paradise': ['beulah', 'beulah land', 'heaven', 'land of beulah', 'a better place', 'afterlife', 'afterworld', 'better world', 'destiny', 'eternal home', 'eternity', 'fate'],
    'paradisiac': ['elysian', 'olympian', 'beatific', 'beatified', 'blessed', 'blissful', 'celestial', 'divine', 'empyreal', 'empyrean', 'ethereal', 'extramundane'],
    'paradox': ['gordian knot', 'absurdity', 'ambiguity', 'ambivalence', 'antinomy', 'asymmetry', 'contradiction', 'crux', 'dilemma', 'disproportion', 'disproportionateness', 'enigma'],
    'paradoxical': ['abnormal', 'absurd', 'ambiguous', 'ambivalent', 'anomalous', 'antinomic', 'baffling', 'barred', 'bewildering', 'closed-out', 'conflicting', 'confusing'],
    'paraffin': ['alcohol', 'avgas', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coal oil', 'coke', 'combustible'],
    'paragon': ['a per se', 'miss america', 'ace', 'acme', 'apotheosis', 'archetype', 'assimilate', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner'],
    'paragraph': ['adjectival phrase', 'article', 'back matter', 'book', 'causerie', 'chapter', 'clause', 'column', 'conceive', 'construction', 'couch', 'couch in terms'],
    'parallel': ['antarctic zone', 'arctic circle', 'arctic zone', 'frigid zones', 'lambert conformal projection', 'mercator projection', 'miller projection', 'torrid zone', 'tropic of cancer', 'tropic of capricorn', 'variable zones', 'abri'],
    'paralleling': ['aligned', 'analogous', 'coextending', 'coextensive', 'collateral', 'comparable', 'concurrent', 'correspondent', 'corresponding', 'duplicate', 'equal', 'equidistant'],
    'parallelism': ['accompaniment', 'accord', 'accordance', 'affinity', 'agreement', 'alikeness', 'allegory', 'alliance', 'analogy', 'aping', 'approach', 'approximation'],
    'paralogism': ['aristotelian sorites', 'goclenian sorites', 'argument', 'argument by analogy', 'argumentum ad baculum', 'argumentum ad captandum', 'argumentum ad hominem', 'bad case', 'begging the question', 'categorical syllogism', 'circular argument', 'claptrap'],
    'paralysis': ['a wise passiveness', 'abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'apoplexy', 'asphyxiation', 'asthma', 'ataxia', 'atrophy'],
    'paralytic': ['allergic', 'amputee', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'cancerous', 'chlorotic', 'colicky', 'consumptive', 'contemplative', 'cripple'],
    'paralyze': ['ko', 'amaze', 'anesthetize', 'appall', 'astonish', 'astound', 'awe', 'awestrike', 'bedaze', 'bedazzle', 'bemuse', 'benumb'],
    'paralyzed': ['aghast', 'appalled', 'ashen', 'astounded', 'awed', 'awestricken', 'awestruck', 'blanched', 'blind', 'blind drunk', 'blotto', 'contemplative'],
    'parameter': ['barometer', 'boundaries', 'boundary condition', 'bounds', 'bourns', 'canon', 'catch', 'check', 'circumference', 'circumscription', 'clause', 'compass'],
    'paramount': ['acmatic', 'all-absorbing', 'anointed king', 'apical', 'arch', 'ascendant', 'at the head', 'banner', 'basic', 'best', 'boss', 'bwana'],
    'paramountcy': ['accent', 'acme', 'authority', 'authorization', 'be-all and end-all', 'blue ribbon', 'championship', 'command', 'concern', 'concernment', 'consequence', 'consequentiality'],
    'paramour': ['casanova', 'admirer', 'adorer', 'amorist', 'concubine', 'doxy', 'follower', 'infatuate', 'kept mistress', 'kept woman', 'lover', 'mistress'],
    'paranoia': ['alternating personality', 'brain disease', 'catatonia', 'catatonic schizophrenia', 'crack-up', 'dementia praecox', 'depersonalization', 'disconnection', 'dissociation', 'dissociation of personality', 'double personality', 'dual personality'],
    'paranoid': ['brain-damaged', 'brain-injured', 'catatoniac', 'catatonic', 'certifiable', 'certifiable case', 'disturbed', 'manic-depressive', 'mental', 'mental case', 'mentally ill', 'mentally sick'],
    'paranymph': ['maecenas', 'abettor', 'acolyte', 'adjutant', 'admirer', 'advocate', 'aficionado', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider'],
    'parapet': ['abatis', 'advanced work', 'arch dam', 'backstop', 'balistraria', 'bamboo curtain', 'bank', 'banquette', 'bar', 'barbed-wire entanglement', 'barbican', 'barrage'],
    'paraphernalia': ['accessories', 'accouterments', 'appanages', 'apparatus', 'appendages', 'appliances', 'appointments', 'appurtenances', 'armament', 'baggage', 'belongings', 'chattels'],
    'paraphilia': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'bisexuality', 'coprophilia', 'exhibitionism', 'fetishism', 'heterosexuality', 'homoeroticism', 'homosexualism'],
    'paraphrase': ['amplification', 'bilingual text', 'burlesque', 'clavis', 'copy', 'crib', 'decipherment', 'decoding', 'dummy', 'duplication', 'explain', 'explicate'],
    'parapsychology': ['abnormal psychology', 'academic psychology', 'analytical psychology', 'animal psychology', 'applied psychology', 'clinical psychology', 'cognitive psychology', 'comparative psychology', 'constitutional psychology', 'criminal psychology', 'depth psychology', 'developmental psychology'],
    'parasite': ['adherent', 'algae', 'appendage', 'attendance', 'attendant', 'autophyte', 'barnacle', 'bean', 'beat', 'bedbug', 'beggar', 'bloodsucker'],
    'parasitic': ['abject', 'accompanying', 'accordant', 'agreeing', 'all-devouring', 'all-engulfing', 'associate', 'associated', 'at one with', 'backscratching', 'beggarly', 'bloodsucking'],
    'parasitism': ['accompaniment', 'accordance', 'agreement', 'alliance', 'apple-polishing', 'ass-kissing', 'association', 'backscratching', 'bootlicking', 'brown-nosing', 'cahoots', 'co-working'],
    'parasol': ['awning', 'beach umbrella', 'blind', 'brolly', 'bumbershoot', 'cover', 'curtain', 'drape', 'drapery', 'gamp', 'light shield', 'screen'],
    'paratroops': ['gurkhas', 'ss', 'special forces', 'waffen-ss', 'armed force', 'armed service', 'army', 'array', 'career soldiers', 'elite corps', 'elite troops', 'fighting machine'],
    'parboiled': ['baked', 'boiled', 'braised', 'broiled', 'browned', 'coddled', 'cooked', 'curried', 'deviled', 'fired', 'fricasseed', 'fried'],
    'parcae': ['atropos', 'clotho', 'dame fortune', 'decuma', 'fata', 'fates', 'fortuna', 'heaven', 'lachesis', 'moirai', 'morta', 'nona'],
    'parcel': ['a certain number', 'a few', 'a number', 'acres', 'adjunct', 'allocate', 'allot', 'amount', 'apportion', 'array', 'assign', 'bag'],
    'parcel of land': ['block', 'clearing', 'clos', 'close', 'corn field', 'croft', 'cultivated land', 'enclave', 'field', 'forty', 'hayfield', 'kraal'],
    'parcel out': ['administer', 'align', 'allocate', 'allot', 'apportion', 'array', 'collocate', 'compose', 'cut up', 'deal', 'deal out', 'disburse'],
    'parcel post': ['pp', 'rd', 'rfd', 'airmail', 'book post', 'correspondence', 'direct mail', 'direct-mail selling', 'express', 'fourth-class mail', 'frank', 'halfpenny post'],
    'parch': ['sanforize', 'air-dry', 'anhydrate', 'attenuate', 'bake', 'be in heat', 'blaze', 'blister', 'bloom', 'blot', 'boil', 'brand'],
    'parched': ['sanforized', 'adust', 'ashen', 'ashy', 'athirst', 'attenuated', 'baked', 'blistered', 'burned', 'burnt', 'burnt-up', 'consumed'],
    'parchment': ['article', 'autograph', 'biscuit', 'blank', 'bone', 'brainchild', 'bubble', 'china', 'chirograph', 'codex', 'composition', 'computer printout'],
    'pardner': ['ace', 'amigo', 'associate', 'bedfellow', 'bedmate', 'birthmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty', 'camarade'],
    'pardon': ['absolution', 'absolve', 'accept', 'acquit', 'acquittal', 'acquittance', 'allow', 'allowance', 'amnesty', 'benevolence', 'clear', 'clearance'],
    'pardonable': ['admissible', 'allowable', 'condonable', 'defensible', 'dispensable', 'excusable', 'exemptible', 'expiable', 'forgivable', 'inoffensive', 'justifiable', 'legitimate'],
    'pardoned': ['absolved', 'acquitted', 'blotted', 'canceled', 'condoned', 'disregarded', 'exculpated', 'excused', 'exonerated', 'forgiven', 'forgotten', 'indulged'],
    'pare': ['abridge', 'abscind', 'amputate', 'annihilate', 'ax', 'ban', 'bar', 'bark', 'beat down', 'bisect', 'bob', 'break'],
    'paregoric': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'parent': ['agent', 'ancestor', 'ancestorial', 'ancestral', 'ancestress', 'author', 'begetter', 'beginner', 'catalyst', 'causer', 'creator', 'effector'],
    'parentage': ['ancestry', 'birth', 'bloodline', 'descent', 'extraction', 'family', 'grandfatherhood', 'grandmotherhood', 'grandparentage', 'heritage', 'line', 'lineage'],
    'parental': ['adoring', 'affectionate', 'ancestorial', 'ancestral', 'conjugal', 'covering', 'custodial', 'defensive', 'demonstrative', 'devoted', 'faithful', 'fatherlike'],
    'parenthesis': ['anastrophe', 'aside', 'broken thread', 'brokenness', 'chiasmus', 'disconnectedness', 'disconnection', 'discontinuance', 'discontinuation', 'discontinuity', 'discontinuousness', 'discreteness'],
    'parenthetic': ['accidental', 'adrift', 'beside the mark', 'beside the point', 'beside the question', 'broken', 'broken off', 'by-the-way', 'casual', 'chopped-off', 'choppy', 'decousu'],
    'parenthetical': ['accidental', 'adrift', 'beside the mark', 'beside the point', 'beside the question', 'broken', 'broken off', 'by-the-way', 'casual', 'chopped-off', 'choppy', 'decousu'],
    'paresis': ['french disease', 'spanish pox', 'vd', 'acquired syphilis', 'apoplexy', 'balanitis gangrenosa', 'catalepsy', 'cataplexy', 'cerebral tabes', 'chancre', 'chancroid', 'clap'],
    'parfum': ['ambergris', 'ambrosia', 'aromatic', 'aromatic gum', 'aromatic water', 'attar', 'attar of roses', 'balm', 'balm of gilead', 'balsam', 'bay oil', 'bergamot oil'],
    'parget': ['apply paint', 'bedaub', 'bedizen', 'begild', 'besmear', 'brush on paint', 'calcimine', 'cement', 'coat', 'color', 'complexion', 'concrete'],
    'pariah': ['dp', 'diogenes', 'hieronymian', 'hieronymite', 'ishmael', 'timon of athens', 'alien', 'anchoress', 'anchorite', 'ascetic', 'bedridden invalid', 'case'],
    'paring': ['afterglow', 'afterimage', 'balance', 'bit', 'bones', 'butt', 'butt end', 'candle ends', 'chaff', 'chip', 'chunk', 'clip'],
    'parish': ['kreis', 'archbishopric', 'archdiocese', 'arrondissement', 'assembly', 'bailiwick', 'bishopric', 'borough', 'brethren', 'canton', 'churchgoers', 'city'],
    'parity': ['accordance', 'agreement', 'alikeness', 'alliance', 'analogy', 'aping', 'approach', 'approximation', 'asking price', 'assimilation', 'balance', 'bearish prices'],
    'park': ['astroturf', 'indian reservation', 'afforestation', 'ammo dump', 'anchor', 'arboretum', 'archives', 'arena', 'armory', 'arsenal', 'artificial turf', 'artillery park'],
    'parkway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'parlance': ['choice of words', 'composition', 'dialect', 'diction', 'expression', 'formulation', 'grammar', 'idiom', 'jargon', 'language', 'langue', 'lingo'],
    'parlay': ['add to', 'aggrandize', 'amplify', 'ante', 'ante up', 'augment', 'back', 'bet', 'bet on', 'book', 'boost', 'broaden'],
    'parley': ['admonition', 'advice', 'advise with', 'advising', 'advocacy', 'audience', 'bargain', 'bargaining', 'bargaining session', 'briefing', 'call in', 'calumet'],
    'parliament': ['assembly', 'bicameral legislature', 'board of aldermen', 'chamber of deputies', 'city board', 'city council', 'commission', 'common council', 'congress', 'council', 'court', 'diet'],
    'parliamentarianism': ['nazism', 'centralism', 'collectivism', 'communism', 'constitutionalism', 'democratism', 'fascism', 'federalism', 'feudalism', 'feudality', 'governmentalism', 'imperialism'],
    'parliamentary': ['absolute', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bicameral', 'bureaucratic', 'civic', 'civil', 'conforming', 'conformist', 'congressional'],
    'parlor': ['agency', 'atelier', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'best room', 'butcher shop', 'company', 'concern', 'corporation', 'desk'],
    'parlor car': ['pullman', 'pullman car', 'baggage car', 'boxcar', 'caboose', 'car', 'carriage', 'chair car', 'coach', 'coal car', 'covered waggon', 'day coach'],
    'parlous': ['alarming', 'awkward', 'bad', 'chancy', 'critical', 'dangerous', 'dangersome', 'difficult', 'explosive', 'fraught with danger', 'hairy', 'hazardous'],
    'parochial': ['authoritarian', 'biased', 'bigot', 'bigoted', 'borne', 'closed', 'confined', 'conservative', 'constricted', 'conventional', 'cramped', 'creedbound'],
    'parochialism': ['jim crow', 'alien', 'apartheid', 'authoritarianism', 'bigotry', 'blind side', 'blind spot', 'blinders', 'closed mind', 'color bar', 'cramped ideas', 'division'],
    'parody': ['atticism', 'agile wit', 'anamorphosis', 'ape', 'bad likeness', 'belie', 'black humor', 'botch', 'burlesque', 'camouflage', 'caricature', 'color'],
    'parol': ['articulated', 'enunciated', 'lingual', 'linguistic', 'linguistic act', 'locution', 'nuncupative', 'oral', 'parole', 'phonation', 'pronounced', 'said'],
    'parole': ['accents', 'assurance', 'avouch', 'avouchment', 'cast loose', 'chatter', 'comment', 'conversation', 'demobilization', 'demobilize', 'dialect', 'discharge'],
    'parolee': ['pow', 'cageling', 'captive', 'chain gang', 'con', 'convict', 'detenu', 'ex-convict', 'gaolbird', 'internee', 'jailbird', 'lifer'],
    'paroxysm': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'acute pain', 'affect epilepsy', 'akinetic epilepsy', 'amok', 'apoplexy', 'arrest'],
    'parquet': ['auditorium', 'balcony', 'box', 'box seat', 'carpet', 'check', 'checker', 'checkerboard', 'checkerwork', 'chessboard', 'colors in patches', 'cover'],
    'parricide': ['aborticide', 'fratricide', 'fungicide', 'genocide', 'germicide', 'herbicide', 'homicide', 'infanticide', 'insecticide', 'matricide', 'microbicide', 'patricide'],
    'parrot': ['babbitt', 'middle american', 'philistine', 'anal character', 'ape', 'bourgeois', 'burgher', 'come again', 'commit to memory', 'compulsive character', 'con', 'conformer'],
    'parrotlike': ['battological', 'duplicative', 'echoic', 'echoing', 'imitative', 'iterative', 'recapitulative', 'redundant', 'reduplicative', 'reechoing', 'reiterant', 'reiterative'],
    'parry': ['about the bush', 'answer', 'answer conclusively', 'argue down', 'around the bush', 'back and fill', 'beat about', 'beat around', 'beat off', 'beg the question', 'bicker', 'block'],
    'parrying': ['bickering', 'boggling', 'captiousness', 'caviling', 'chicane', 'chicanery', 'dodging', 'equivocation', 'evasion', 'fencing', 'hairsplitting', 'hedging'],
    'parse': ['analyze', 'block out', 'bracket', 'conjugate', 'decline', 'detail', 'enumerate', 'hyphenate', 'inflect', 'itemize', 'mark', 'number'],
    'parsimonious': ['lenten', 'scotch', 'spartan', 'abstemious', 'ascetic', 'austere', 'canny', 'careful', 'chary', 'cheeseparing', 'conserving', 'dwarfed'],
    'parsimony': ['lenten fare', 'austerity', 'austerity program', 'canniness', 'care', 'carefulness', 'chariness', 'economic planning', 'economicalness', 'economy', 'economy of means', 'exiguity'],
    'parsing': ['blocking', 'descriptive grammar', 'detailing', 'enumeration', 'generative grammar', 'glossematics', 'grammar', 'grammatical analysis', 'grammatical theory', 'grammaticality', 'itemization', 'morphology'],
    'parson': ['dd', 'doctor of divinity', 'holy joe', 'abbe', 'chaplain', 'churchman', 'clergyman', 'cleric', 'clerical', 'clerk', 'curate', 'cure'],
    'parsonage': ['dymaxion house', 'white house', 'adobe house', 'building', 'casa', 'church house', 'clergy house', 'cliff dwelling', 'consulate', 'country house', 'country seat', 'dacha'],
    'part': ['abrupt', 'absolute interest', 'accompaniment', 'actor', 'adjunct', 'after a fashion', 'airspace', 'alienate', 'allotment', 'allowance', 'alto', 'amount'],
    'part and parcel': ['adjunct', 'appurtenance', 'aspect', 'basic', 'circumstance', 'component', 'constituent', 'contents', 'detail', 'element', 'factor', 'feature'],
    'part company': ['agree to disagree', 'break up', 'break with', 'deactivate', 'debrief', 'demob', 'demobilize', 'detach', 'disband', 'discharge', 'disintegrate', 'dismiss'],
    'part music': ['duet', 'duettino', 'duo', 'ensemble music', 'ensemble singing', 'octet', 'part singing', 'part song', 'polyphonic music', 'quartet', 'quintet', 'septet'],
    'part of speech': ['adjectival', 'adjective', 'adverb', 'adverbial', 'adversative conjunction', 'attributive', 'conjunction', 'conjunctive adverb', 'coordinating conjunction', 'copulative', 'copulative conjunction', 'correlative conjunction'],
    'part time': ['anchor watch', 'bit', 'casual', 'day shift', 'dogwatch', 'extra', 'full time', 'graveyard shift', 'half time', 'incidental', 'lobster trick', 'night shift'],
    'part with': ['abandon', 'abjure', 'cast', 'cast aside', 'cast away', 'cast off', 'cede', 'chuck', 'deep-six', 'discard', 'disgorge', 'dispense with'],
    'partake': ['acquire', 'be enfranchised', 'be implicated in', 'bear a hand', 'break bread', 'catch up', 'chip in', 'claim', 'clap hands on', 'clasp', 'claw', 'clench'],
    'partaking': ['accessory', 'affiliation', 'association', 'cochairmanship', 'companionship', 'company', 'complicity', 'condominium', 'consociation', 'contribution', 'cooperation', 'copartnership'],
    'parterre': ['auditorium', 'balcony', 'billiard table', 'bowling green', 'box', 'box seat', 'dead flat', 'dead level', 'dress circle', 'earth', 'esplanade', 'fauteuil'],
    'parthenogenesis': ['abiogenesis', 'archigenesis', 'biogenesis', 'birth', 'blastogenesis', 'development', 'digenesis', 'epigenesis', 'eumerogenesis', 'generation', 'genesis', 'heterogenesis'],
    'parthian shot': ['ps', 'addendum', 'address', 'affirmation', 'afterthought', 'allegation', 'answer', 'apostrophe', 'appendix', 'assertion', 'averment', 'back answer'],
    'parti color': ['bicolor', 'bicolored', 'colorful', 'colory', 'crazy', 'daedal', 'dichroism', 'dichromatic', 'dichromatism', 'divers-colored', 'harlequin', 'kaleidoscopic'],
    'partial': ['af', 'adulterated', 'antiblack', 'arrested', 'audio frequency', 'biased', 'blemished', 'callow', 'chauvinistic', 'colored', 'damaged', 'defective'],
    'partial to': ['aching for', 'attached to', 'bent on', 'crazy about', 'crazy to', 'desirous of', 'devoted to', 'dying for', 'dying to', 'enamored of', 'fain of', 'far gone on'],
    'partiality': ['affinity', 'appreciation', 'bag', 'bent', 'bias', 'chosen kind', 'clannishness', 'clanship', 'cliqueyness', 'cliquishness', 'cliquism', 'cup of tea'],
    'partially': ['after a fashion', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst', 'by halves', 'comparatively'],
    'participant': ['a party to', 'accessory', 'accomplice', 'actor', 'aide', 'assistant', 'colleague', 'confrere', 'contributor', 'copartner', 'cotenant', 'engaged'],
    'participate': ['be enfranchised', 'be implicated in', 'bear a hand', 'chip in', 'contribute', 'contribute to', 'engage in', 'enter into', 'go into', 'have suffrage', 'help decide', 'join'],
    'participation': ['admissibility', 'admission', 'affiliation', 'assimilation', 'association', 'companionship', 'company', 'completeness', 'comprehension', 'comprehensiveness', 'comprisal', 'consociation'],
    'participial': ['adjectival', 'adverbial', 'attributive', 'conjunctive', 'copulative', 'correct', 'formal', 'functional', 'glossematic', 'grammatic', 'intransitive', 'linking'],
    'participle': ['adjectival', 'adjective', 'adverb', 'adverbial', 'adversative conjunction', 'attributive', 'conjunction', 'conjunctive adverb', 'coordinating conjunction', 'copulative', 'copulative conjunction', 'correlative conjunction'],
    'particle': ['k-meson', 'ace', 'adjectival', 'adjective', 'adverb', 'adverbial', 'adversative conjunction', 'atom', 'attributive', 'beta particle', 'bit', 'butt'],
    'particular': ['absolute', 'accurate', 'adjunct', 'adoptive', 'adventure', 'appointive', 'appropriate', 'article', 'aspect', 'attentive', 'blow-by-blow', 'brass tacks'],
    'particularity': ['accuracy', 'aroma', 'attention to detail', 'attribute', 'badge', 'brand', 'cachet', 'cast', 'censoriousness', 'character', 'characteristic', 'choosiness'],
    'particularization': ['baconian method', 'a fortiori reasoning', 'a posteriori reasoning', 'a priori reasoning', 'alteration', 'analysis', 'anatomization', 'atomization', 'cameo', 'catalog', 'cataloging', 'change'],
    'particularize': ['adduce', 'amplify', 'analyze', 'anatomize', 'atomize', 'be precise', 'call to mind', 'change', 'chop logic', 'circumstantiate', 'cite', 'cite a particular'],
    'particularly': ['a fortiori', 'above all', 'abundantly', 'acutely', 'all the more', 'alone', 'amazingly', 'amply', 'apart', 'astonishingly', 'at length', 'awesomely'],
    'parting': ['godspeed', 'abandonment', 'abstraction', 'adieu', 'alienation', 'aloha', 'annihilation', 'bane', 'biological death', 'breaking up', 'breakup', 'cessation of life'],
    'parting shot': ['ps', 'parthian shot', 'addendum', 'afterthought', 'appendix', 'back answer', 'back matter', 'caustic remark', 'chorus', 'coda', 'codicil', 'colophon'],
    'partisan': ['charley', 'conservative', 'democrat', 'labourite', 'maecenas', 'republican', 'tory', 'vc', 'vietcong', 'whig', 'abettor', 'acquaintance'],
    'partisan politics': ['machtpolitik', 'realpolitik', 'tammany hall', 'bossism', 'career politics', 'confrontation politics', 'consensus politics', 'economics in action', 'empirical politics', 'kid-glove politics', 'machine politics', 'partisanism'],
    'partisanism': ['conservatism', 'liberalism', 'machtpolitik', 'realpolitik', 'republicanism', 'tammany hall', 'toryism', 'whiggery', 'whiggism', 'bias', 'bossism', 'career politics'],
    'partition': ['abstraction', 'alienation', 'allotment', 'apportion', 'apportioning', 'apportionment', 'area', 'barrier', 'bisector', 'booth', 'boundary', 'brattice'],
    'partitioned': ['apart', 'asunder', 'bipartite', 'dichotomous', 'discontinuous', 'discrete', 'distinct', 'divergent', 'in two', 'incoherent', 'insular', 'mural'],
    'partly': ['after a fashion', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst', 'comparatively', 'detectably'],
    'partner': ['a party to', 'accessory', 'accompanier', 'accompanist', 'accompanyist', 'accomplice', 'accumulate', 'ace', 'act in concert', 'act together', 'affiliate', 'agglomerate'],
    'partnership': ['aktiengesellschaft', 'bund', 'rochdale cooperative', 'affiliation', 'aktiebolag', 'alignment', 'alliance', 'amalgamation', 'assemblage', 'association', 'axis', 'band'],
    'parts': ['af amplifier', 'afc', 'afc mixer', 'crt', 'cw oscillator', 'fm detector', 'pcv valve', 'rf amplifier', 'tr switch', 'tr unit', 'ability', 'accelerator'],
    'parturient': ['abecedarian', 'aboriginal', 'antenatal', 'anticipating', 'autochthonous', 'beginning', 'big', 'big with child', 'big-laden', 'breeding', 'budding', 'carrying'],
    'parturition': ['accouchement', 'babyhood', 'bearing', 'beginnings', 'birth', 'birth throes', 'birthing', 'blessed event', 'childbearing', 'childbed', 'childbirth', 'childhood'],
    'party': ['adamite', 'american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party'],
    'party hack': ['conservative', 'democrat', 'labourite', 'republican', 'tory', 'whig', 'hack', 'heeler', 'loyalist', 'partisan', 'party faithful', 'party man'],
    'party line': ['wats', 'wats line', 'autarky', 'bimetallism', 'cable', 'co-ax', 'coaxial cable', 'concentric cable', 'economic self-sufficiency', 'free enterprise', 'free trade', 'governmentalism'],
    'parvenu': ['babbitt', 'daddy warbucks', 'philistine', 'young turk', 'adventurer', 'arriviste', 'billionaire', 'bloated plutocrat', 'boor', 'bounder', 'bourgeois', 'bourgeois gentilhomme'],
    'pashadom': ['aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'baronetcy', 'barony', 'bishopric', 'chairmanship', 'chancellery', 'chancellorate', 'chancellorship'],
    'pass': ['ok', 'abalienate', 'abandon', 'abysm', 'abyss', 'accept', 'access', 'accredit', 'act like', 'administer', 'adopt', 'advance'],
    'pass away': ['be all over', 'be annihilated', 'be consumed', 'be destroyed', 'be done for', 'be gone', 'be lost', 'be no more', 'be superseded', 'be wiped out', 'become extinct', 'become void'],
    'pass by': ['abjure', 'advance', 'be blind to', 'be caught out', 'be inattentive', 'be unwary', 'bestride', 'blink at', 'brush aside', 'bypass', 'chuck', 'chuck out'],
    'pass for': ['act', 'act a part', 'act as', 'act out', 'answer for', 'ape', 'be accepted for', 'be regarded as', 'be taken as', 'copy', 'count for', 'do'],
    'pass muster': ['answer', 'avail', 'be equal to', 'bear', 'do', 'do it', 'fall in with', 'fall into line', 'fill the bill', 'find favor with', 'fit in', 'follow the crowd'],
    'pass on': ['ok', 'abalienate', 'accept', 'accredit', 'add a codicil', 'advance', 'affirm', 'alien', 'alienate', 'amen', 'amortize', 'approve'],
    'pass out': ['be consumed', 'be drunk', 'be gone', 'be intoxicated', 'black out', 'bow out', 'buy it', 'cash in', 'cease', 'cease to be', 'cease to exist', 'check in'],
    'pass over': ['abalienate', 'abandon', 'alien', 'alienate', 'allow for', 'amortize', 'assign', 'autopsy', 'ban', 'bar', 'bar out', 'barter'],
    'pass the buck': ['assign', 'be unfaithful', 'break faith', 'carry over', 'circumvent', 'communicate', 'consign', 'deceive', 'deliver', 'deport', 'desert', 'diffuse'],
    'pass through': ['be exposed to', 'be subjected to', 'course', 'cover', 'do', 'encounter', 'endure', 'experience', 'feel', 'gain entree', 'get into', 'get through'],
    'pass up': ['abandon', 'abjure', 'abstain', 'abstain from', 'avoid', 'brush aside', 'chuck', 'chuck out', 'contemn', 'contradict', 'cut', 'cut dead'],
    'passable': ['ok', 'acceptable', 'accessible', 'adequate', 'admissible', 'agreeable', 'all right', 'allowable', 'alright', 'attainable', 'average', 'better than nothing'],
    'passage': ['brownian movement', 'about-face', 'abysm', 'abyss', 'acceptance', 'access', 'acciaccatura', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta'],
    'passageway': ['access', 'adit', 'air lock', 'aisle', 'alley', 'ambulatory', 'aperture', 'approach', 'arcade', 'areaway', 'artery', 'avenue'],
    'passbook': ['account book', 'accounts payable ledger', 'accounts receivable ledger', 'balance sheet', 'bank ledger', 'bankbook', 'books', 'card ledger', 'cashbook', 'cost card', 'cost ledger', 'cost sheet'],
    'passe': ['ago', 'antiquated', 'antique', 'archaic', 'back number', 'behind the times', 'belated', 'blown over', 'by', 'bygone', 'bypast', 'dated'],
    'passed': ['accepted', 'adopted', 'ago', 'antiquated', 'antique', 'appointed', 'approved', 'blown over', 'by', 'bygone', 'bypast', 'carried'],
    'passenger': ['adventurer', 'alpinist', 'astronaut', 'camper', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser', 'excursionist', 'explorer', 'fare'],
    'passerby': ['tv-viewer', 'adventurer', 'alpinist', 'astronaut', 'attestant', 'attestator', 'attester', 'beholder', 'bird-watcher', 'bystander', 'camper', 'climber'],
    'passing': ['abandonment', 'abrupt', 'accidental', 'accompanying', 'act', 'ado', 'advance', 'advancement', 'afloat', 'afoot', 'aggrandizement', 'ambulant'],
    'passing by': ['abjuration', 'abjurement', 'all through', 'around', 'by', 'by way of', 'chucking', 'chucking out', 'contempt', 'contradiction', 'declination', 'declining'],
    'passing fancy': ['boutade', 'brainstorm', 'calf love', 'capriccio', 'caprice', 'case', 'conceit', 'crank', 'craze', 'crazy idea', 'crotchet', 'crush'],
    'passion': ['alecto', 'amor', 'christian love', 'eros', 'megaera', 'negro spiritual', 'nemesis', 'platonic love', 'tisiphone', 'abandon', 'ache', 'aching'],
    'passion play': ['grand guignol', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger', 'closet drama', 'comedy drama'],
    'passionate': ['abandoned', 'ablaze', 'afire', 'amative', 'amatory', 'amorous', 'animated', 'ardent', 'argumentative', 'aroused', 'atrabiliar', 'atrabilious'],
    'passionately': ['adoringly', 'affectionately', 'amorously', 'ardently', 'breathlessly', 'cordially', 'dearly', 'devotedly', 'devoutly', 'earnestly', 'effectively', 'eloquently'],
    'passionless': ['affectless', 'anesthetized', 'apathetic', 'arctic', 'autistic', 'blunt', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity', 'cold-blooded'],
    'passive': ['laodicean', 'olympian', 'abeyant', 'abject', 'accepting', 'accommodating', 'acquiescent', 'active', 'active voice', 'adapting', 'adaptive', 'adjusting'],
    'passive resistance': ['quakerism', 'a wise passiveness', 'acquiescence', 'amenability', 'challenge', 'civil disobedience', 'combative reaction', 'complaint', 'compliance', 'contemplation', 'contemplative life', 'counteraction'],
    'passivity': ['quakerism', 'a wise passiveness', 'abeyance', 'acceptance', 'acedia', 'acquiescence', 'aloofness', 'amenability', 'apathy', 'assent', 'ataraxia', 'ataraxy'],
    'past': ['above', 'above and beyond', 'across', 'after', 'ago', 'ancient', 'antecedent', 'anterior', 'antiquated', 'antique', 'antiquity', 'aorist'],
    'past due': ['ahead of time', 'anachronistic', 'antedated', 'beforehand', 'behind time', 'behindhand', 'dated', 'early', 'foredated', 'late', 'metachronistic', 'misdated'],
    'past master': ['ace', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'artiste', 'author', 'authority', 'begetter', 'beginner', 'builder'],
    'paste': ['italian paste', 'adherent', 'adhesive', 'admixture', 'agglutinate', 'albumen', 'alloy', 'amalgam', 'bang', 'barnacle', 'bash', 'baste'],
    'pastel': ['air brush', 'art paper', 'black and white', 'brouillon', 'brush', 'camera lucida', 'camera obscura', 'canvas', 'cartoon', 'chalk', 'charcoal', 'charcoal drawing'],
    'pastiche': ['adoption', 'all sorts', 'appropriation', 'art object', 'assemblage', 'assortment', 'assumption', 'blend', 'borrowed plumes', 'brainchild', 'bric-a-brac', 'broad spectrum'],
    'pastime': ['amusement', 'avocation', 'by-line', 'distraction', 'diversion', 'divertisement', 'divertissement', 'enjoyment', 'entertainment', 'fun', 'hobby', 'hobbyhorse'],
    'pastiness': ['adhesiveness', 'anemia', 'ashiness', 'bloodlessness', 'cadaverousness', 'chloranemia', 'clabbering', 'clamminess', 'clotting', 'coagulation', 'colloidality', 'curdling'],
    'pastor': ['dd', 'doctor of divinity', 'holy joe', 'abbe', 'bishop', 'canon', 'chaplain', 'churchman', 'churchwoman', 'clergyman', 'clergywoman', 'cleric'],
    'pastoral': ['alcaic', 'anacreontic', 'arcadian', 'castalian', 'edenic', 'english sonnet', 'grand guignol', 'homeric', 'horatian ode', 'hudibrastic', 'italian sonnet', 'passion play'],
    'pastoral staff': ['malacca cane', 'alpenstock', 'baton', 'cane', 'crook', 'crosier', 'cross', 'cross-staff', 'crutch', 'crutch-stick', 'handstaff', 'keys'],
    'pastorate': ['abbacy', 'administration', 'apostleship', 'archbishopric', 'archdeaconry', 'archiepiscopacy', 'archiepiscopate', 'auspices', 'bishopdom', 'bishopric', 'call', 'canonicate'],
    'pastry': ['danish pastry', 'french pastry', 'baklava', 'blintz', 'chocolate eclair', 'cream puff', 'dowdy', 'eclair', 'pandowdy', 'pasty', 'patisserie', 'patty'],
    'pasturage': ['barley', 'bird seed', 'bran', 'campo', 'cat food', 'chicken feed', 'chop', 'corn', 'dog food', 'eatage', 'ensilage', 'feed'],
    'pasture': ['appetite', 'arable land', 'barley', 'barnyard', 'barton', 'batten upon', 'bird seed', 'board', 'bran', 'bread', 'browse', 'campo'],
    'pasty': ['danish pastry', 'french pastry', 'achromatic', 'achromic', 'adhesive', 'amylaceous', 'anemic', 'ashen', 'ashy', 'baccate', 'baklava', 'bled white'],
    'pat': ['a propos', 'ad rem', 'adamant', 'adamantine', 'adapted', 'applicable', 'apposite', 'appreciated', 'apprehended', 'appropriate', 'apropos', 'apt'],
    'patch': ['hershey bar', 'x ray', 'actinic ray', 'actinism', 'area', 'atomic beam', 'atomic ray', 'aviation badge', 'badge', 'bailiwick', 'bar', 'bat out'],
    'patchwork': ['all sorts', 'assemblage', 'assortment', 'broad spectrum', 'check', 'checker', 'checkerboard', 'checkerwork', 'chessboard', 'colors in patches', 'confusion', 'conglomeration'],
    'patchy': ['adulterated', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'arrested', 'bespangled', 'blemished', 'blended', 'blotched', 'blotchy', 'broken'],
    'pate': ['danish pastry', 'french pastry', 'baklava', 'bean', 'belfry', 'blintz', 'brain', 'brow', 'chocolate eclair', 'chump', 'cream puff', 'crown'],
    'patent': ['ok', 'admission', 'aegis', 'allowance', 'apparent', 'arm', 'arm guard', 'armor', 'authorize', 'backstop', 'blank check', 'blatant'],
    'patent medicine': ['balm', 'balsam', 'drops', 'drug', 'electuary', 'elixir', 'ethical drug', 'generic name', 'herbs', 'inhalant', 'lincture', 'linctus'],
    'patented': ['armed', 'authorized', 'bound', 'bounded', 'chartered', 'cloaked', 'conditioned', 'confined', 'copyrighted', 'covered', 'cramped', 'defended'],
    'patently': ['actually', 'apparently', 'assuredly', 'certainly', 'clearly', 'conspicuously', 'decidedly', 'definitely', 'demonstrably', 'discernibly', 'distinctly', 'evidently'],
    'pater': ['abba', 'dad', 'daddy', 'father', 'foster father', 'genitor', 'governor', 'old', 'pa', 'pap', 'papa', 'pappy'],
    'paterfamilias': ['abba', 'boss', 'bwana', 'chef', 'chief', 'church dignitary', 'dad', 'daddy', 'ecclesiarch', 'elder', 'employer', 'father'],
    'paternal': ['adoring', 'affectionate', 'ancestorial', 'ancestral', 'concerned', 'conjugal', 'demonstrative', 'devoted', 'faithful', 'fatherlike', 'fatherly', 'filial'],
    'paternity': ['affiliation', 'agnation', 'alliance', 'ancestry', 'blood', 'blood relationship', 'brotherhood', 'brothership', 'cognation', 'common ancestry', 'common descent', 'connection'],
    'paternoster': ['agnus dei', 'alleluia', 'anamnesis', 'angelus', 'ave', 'ave maria', 'blessing', 'canon', 'collect', 'communion', 'consecration', 'credo'],
    'path': ['air lane', 'air line', 'air route', 'airway', 'alameda', 'approach', 'artery', 'avenue', 'beat', 'beaten path', 'beaten track', 'berm'],
    'pathetic': ['affecting', 'affective', 'afflictive', 'beggarly', 'beneath contempt', 'bitter', 'bleak', 'cheap', 'cheerless', 'cheesy', 'comfortless', 'common'],
    'pathfinder': ['adventurer', 'alpinist', 'ancestor', 'announcer', 'antecedent', 'astronaut', 'avant-garde', 'bellwether', 'buccinator', 'bushwhacker', 'camper', 'climber'],
    'pathogen': ['adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'bacillus', 'bacteria', 'bacterium', 'bug', 'coccus', 'echovirus'],
    'pathogenic': ['bad', 'bad for', 'contaminated', 'foul', 'harmful', 'injurious', 'insalubrious', 'insanitary', 'morbific', 'noisome', 'noxious', 'peccant'],
    'pathological': ['bad', 'cankered', 'contaminated', 'diseased', 'gangrened', 'gangrenous', 'infected', 'morbid', 'mortified', 'peccant', 'poisoned', 'septic'],
    'pathologist': ['anesthesiologist', 'cardiologist', 'chiropodist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'immunologist', 'internist', 'neurologist', 'obstetrician'],
    'pathology': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'cardiovascular disease'],
    'pathos': ['bathos', 'benevolence', 'bitterness', 'bleakness', 'caring', 'cheerlessness', 'chord', 'clemency', 'comfortlessness', 'commiseration', 'compassion', 'concern'],
    'pathway': ['alameda', 'beaten path', 'beaten track', 'berm', 'bicycle path', 'boardwalk', 'bridle path', 'catwalk', 'esplanade', 'fastwalk', 'foot pavement', 'footpath'],
    'patience': ['acceptance', 'application', 'assiduity', 'assiduousness', 'ataraxia', 'ataraxy', 'benevolence', 'bovinity', 'bulldog tenacity', 'calmness', 'charitableness', 'charity'],
    'patient': ['spartan', 'accepting', 'accommodating', 'acquiescent', 'apoplectic', 'armed with patience', 'arthritic', 'assiduous', 'benevolent', 'bovine', 'case', 'charitable'],
    'patiently': ['assiduously', 'devotedly', 'diligently', 'doggedly', 'enduringly', 'faithfully', 'forbearantly', 'forbearingly', 'indefatigably', 'indulgently', 'industriously', 'insistently'],
    'patina': ['burnish', 'coat', 'coating', 'collop', 'covering', 'cut', 'deal', 'disk', 'feuille', 'film', 'finish', 'flap'],
    'patisserie': ['danish pastry', 'french pastry', 'baklava', 'blintz', 'chocolate eclair', 'cream puff', 'dowdy', 'eclair', 'pandowdy', 'pastry', 'pasty', 'patty'],
    'patois': ['acadian', 'anglo-indian', 'brooklynese', 'cajun', 'canadian french', 'cockney', 'french canadian', 'gullah', 'midland', 'midland dialect', 'new england dialect', 'pennsylvania dutch'],
    'patriarch': ['aaronic priesthood', 'father time', 'grand penitentiary', 'holy father', 'melchizedek priesthood', 'methuselah', 'nestor', 'old paar', 'seventy', 'abba', 'abuna', 'ancestors'],
    'patriarchal': ['aboriginal', 'absolute', 'advanced', 'advanced in life', 'advanced in years', 'aged', 'along in years', 'ancestorial', 'ancestral', 'ancient', 'antepatriarchal', 'aristocratic'],
    'patrician': ['brahman', 'archduke', 'aristocrat', 'aristocratic', 'armiger', 'baron', 'baronet', 'blue blood', 'chivalrous', 'count', 'daimio', 'ducal'],
    'patricide': ['aborticide', 'fratricide', 'fungicide', 'genocide', 'germicide', 'herbicide', 'homicide', 'infanticide', 'insecticide', 'matricide', 'microbicide', 'parricide'],
    'patrilineage': ['affiliation', 'agnation', 'alliance', 'ancestry', 'blood', 'blood relationship', 'brotherhood', 'brothership', 'cognation', 'common ancestry', 'common descent', 'connection'],
    'patrilineal': ['affiliated', 'agnate', 'akin', 'allied', 'avuncular', 'closely related', 'cognate', 'collateral', 'congeneric', 'consanguine', 'consanguinean', 'consanguineous'],
    'patrimony': ['bequeathal', 'bequest', 'birthright', 'borough-english', 'coheirship', 'coparcenary', 'entail', 'gavelkind', 'heirloom', 'heirship', 'hereditament', 'heritable'],
    'patrol': ['argus', 'charley', 'airplane spotter', 'beat', 'course', 'cover', 'defend', 'defending', 'do', 'fire patrolman', 'fire warden', 'fireguard'],
    'patrolman': ['argus', 'charley', 'g-man', 'john law', 'mp', 'airplane spotter', 'bailiff', 'beadle', 'beagle', 'bound bailiff', 'captain', 'catchpole'],
    'patron': ['dionysus', 'maecenas', 'od', 'samaritan', 'santa claus', 'abettor', 'admirer', 'advocate', 'aficionado', 'aid', 'aider', 'almoner'],
    'patronage': ['abetment', 'administration', 'advocacy', 'advocating', 'advocation', 'aegis', 'aid', 'auspices', 'backing', 'benefaction', 'bias', 'boosting'],
    'patronize': ['aid', 'angel', 'assist', 'back', 'bankroll', 'boost', 'bridle', 'capitalize', 'condescend', 'contemn', 'contribute to', 'deal with'],
    'patronizing': ['olympian detachment', 'olympian loftiness', 'arrogance', 'arrogant', 'arrogantness', 'assumption of superiority', 'big', 'condescendence', 'condescending', 'condescension', 'domineering', 'domineeringness'],
    'patsy': ['babe', 'boob', 'chump', 'cinch', 'credulous person', 'cull', 'dupe', 'easy mark', 'easy pickings', 'fall guy', 'fish', 'fool'],
    'patter': ['scotch mist', 'act', 'act as foil', 'acting', 'appear', 'argot', 'babble', 'babbling', 'ballyhoo', 'bang', 'barnstorm', 'barrage'],
    'pattern': ['geistesgeschichte', 'hegelian idea', 'kantian idea', 'platonic form', 'platonic idea', 'action', 'actions', 'activity', 'acts', 'address', 'aesthetic form', 'affectation'],
    'paucity': ['chinchiness', 'chintziness', 'dearth', 'exiguity', 'fewness', 'infrequency', 'insufficiency', 'meagerness', 'miserliness', 'niggardliness', 'poverty', 'rareness'],
    'paul': ['ambrose of milan', 'athanasius', 'barnabas', 'basil', 'clement of alexandria', 'clement of rome', 'cyprian of carthage', 'cyril of jerusalem', 'gregory of nyssa', 'hermas', 'ignatius', 'irenaeus'],
    'paunch': ['abdomen', 'abomasum', 'bay window', 'beerbelly', 'belly', 'bowel', 'breadbasket', 'corporation', 'craw', 'crop', 'diaphragm', 'disembowel'],
    'paunchy': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky', 'corpulent'],
    'pauper': ['almsman', 'almswoman', 'bankrupt', 'beggar', 'break', 'bum', 'bust', 'casual', 'charity case', 'down-and-out', 'down-and-outer', 'fold up'],
    'pauperism': ['bare cupboard', 'bare subsistence', 'beggarliness', 'beggary', 'deprivation', 'destitution', 'empty purse', 'grinding poverty', 'gripe', 'hand-to-mouth existence', 'homelessness', 'impecuniousness'],
    'pauperized': ['bare-handed', 'beggared', 'beggarly', 'bereaved', 'bereft', 'deprived', 'disadvantaged', 'empty-handed', 'famished', 'fleeced', 'ghettoized', 'half-starved'],
    'pause': ['abeyance', 'accent', 'accent mark', 'afterthought', 'back down', 'balance', 'bar', 'bashfulness', 'bind', 'blench', 'block', 'blockage'],
    'pave': ['asphalt', 'blacktop', 'carpet', 'causeway', 'cement', 'cobblestone', 'concrete', 'cover', 'ease', 'facilitate', 'flag', 'floor'],
    'pave the way': ['aid', 'blaze the trail', 'break the ice', 'clear the way', 'cultivate the soil', 'ease', 'expedite', 'explain', 'facilitate', 'go in advance', 'grease', 'grease the ways'],
    'paved': ['armored', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'coped', 'covered', 'covert', 'cowled', 'curtained', 'eclipsed'],
    'pavement': ['tarmac', 'tarvia', 'adobe', 'ashlar', 'asphalt', 'base', 'basement', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock'],
    'pavilion': ['nissen hut', 'quonset hut', 'booth', 'crib', 'gatehouse', 'hut', 'hutch', 'kiosk', 'lean-to', 'outbuilding', 'outhouse', 'sentry box'],
    'paw': ['arch', 'bad', 'claws', 'clubfoot', 'clutches', 'coarse', 'come in contact', 'digit', 'digits', 'dirty', 'dog', 'extremity'],
    'paw print': ['boss', 'bump', 'colophon', 'concavity', 'convexity', 'dactylogram', 'dactylograph', 'dent', 'dint', 'embossment', 'excrescence', 'fingerprint'],
    'pawky': ['byzantine', 'machiavellian', 'machiavellic', 'acute', 'arch', 'artful', 'astute', 'cagey', 'calculating', 'canny', 'careful', 'cautious'],
    'pawn': ['charlie mccarthy', 'agent', 'ancilla', 'appliance', 'assurance', 'bail', 'bishop', 'bond', 'borrow', 'bottomry', 'castle', 'chance'],
    'pawnbroker': ['realtor', 'shylock', 'bank', 'banker', 'bill broker', 'broker', 'cambist', 'cotton broker', 'credit union', 'diamond broker', 'discount broker', 'estate agent'],
    'pax': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'accord', 'agape', 'ark', 'asperger', 'asperges', 'aspergillum'],
    'pay': ['accomplish', 'achieve', 'advantage', 'afford', 'angel', 'answer', 'attend to', 'avail', 'back', 'bankroll', 'base pay', 'be exposed to'],
    'pay attention': ['address', 'advert to', 'attend to', 'attend to business', 'be alert', 'be aware of', 'be concerned', 'be engrossed in', 'be obsessed with', 'beau', 'care', 'chase'],
    'pay back': ['alternate', 'atone', 'bandy', 'be quits with', 'change', 'commute', 'compensate', 'cooperate', 'counterchange', 'cover', 'do penance', 'exchange'],
    'pay off': ['advantage', 'afford', 'amortize', 'answer', 'approach', 'avail', 'be gainful', 'be handy', 'be of use', 'be profitable', 'be worthwhile', 'bear away'],
    'pay out': ['account with', 'administer', 'attend to', 'budget', 'clear the board', 'come down on', 'cost', 'cost out', 'deal', 'deal out', 'disburse', 'dispense'],
    'payee': ['accepter', 'acquirer', 'addressee', 'audience', 'auditor', 'beholder', 'consignee', 'getter', 'hearer', 'holder', 'listener', 'looker'],
    'paying': ['acquitment', 'acquittal', 'acquittance', 'advantageous', 'amortization', 'amortizement', 'banausic', 'binder', 'breadwinning', 'cash', 'cash payment', 'clearance'],
    'paying guest': ['board-and-roomer', 'boarder', 'hirer', 'homesteader', 'incumbent', 'leaseholder', 'lessee', 'lodger', 'occupant', 'occupier', 'renter', 'resident'],
    'payload': ['atomic warhead', 'baggage', 'bird', 'blast', 'burden', 'cargo', 'carload', 'cartload', 'charge', 'consignment', 'freight', 'freightage'],
    'paymaster': ['accountant', 'auditor', 'bookkeeper', 'bursar', 'cashier', 'cashkeeper', 'chamberlain', 'compensator', 'comptroller', 'controller', 'curator', 'defrayer'],
    'payment': ['bait', 'base pay', 'bribe', 'budgeting', 'carrot', 'castigation', 'charge', 'chastening', 'chastisement', 'compensation', 'condign punishment', 'contribution'],
    'payoff': ['acquitment', 'acquittal', 'acquittance', 'amortization', 'amortizement', 'apodosis', 'binder', 'bitter end', 'boodle', 'bribe', 'bribe money', 'cash'],
    'payroll': ['base pay', 'compensation', 'dismissal wage', 'earnings', 'escalator clause', 'escalator plan', 'financial remuneration', 'gross income', 'guaranteed annual wage', 'hire', 'income', 'living wage'],
    'pdq': ['apace', 'at once', 'away', 'decisively', 'directly', 'expeditiously', 'forthwith', 'immediately', 'in no time', 'instanter', 'instantly', 'on the instant'],
    'pea': ['algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'diatom', 'fern', 'fruits and vegetables'],
    'pea brained': ['brainless', 'foolish', 'headless', 'ignorant', 'inept', 'insensate', 'irrational', 'lackbrained', 'lean-minded', 'lean-witted', 'mindless', 'not bright'],
    'peabrain': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead'],
    'peace': ['pax dei', 'pax romana', 'peace of god', 'accord', 'accordance', 'affinity', 'agape', 'agreement', 'amity', 'armistice', 'arrangement', 'array'],
    'peace of mind': ['buddha-like composure', 'oriental calm', 'acceptance', 'calm disposition', 'calm of mind', 'calmness', 'comfort', 'composure', 'content', 'contentedness', 'contentment', 'cool'],
    'peace offering': ['christmas present', 'amends', 'atonement', 'award', 'birthday present', 'box', 'burnt offering', 'cadeau', 'calumet', 'collection', 'compensation', 'composition'],
    'peace officer': ['g-man', 'john law', 'mp', 'bailiff', 'beadle', 'beagle', 'bound bailiff', 'captain', 'catchpole', 'chief of police', 'commissioner', 'constable'],
    'peaceable': ['agreeable', 'amiable', 'amicable', 'at peace', 'at rest', 'bland', 'bloodless', 'broken', 'brotherly', 'calm', 'chastened', 'civil'],
    'peaceful': ['accordant', 'agreeable', 'agreeing', 'akin', 'amicable', 'at one', 'at peace', 'at rest', 'attuned', 'bland', 'bloodless', 'calm'],
    'peacefully': ['calmly', 'comfortably', 'commodiously', 'conveniently', 'cozily', 'easily', 'luxuriously', 'placidly', 'quiescently', 'quietly', 'reposefully', 'restfully'],
    'peacefulness': ['buddha-like composure', 'oriental calm', 'ataraxia', 'ataraxy', 'calm disposition', 'calm of mind', 'calmness', 'commodiousness', 'composure', 'contemplation', 'convenience', 'cool'],
    'peacemaker': ['adjudicator', 'alleviative', 'alleviator', 'anodyne', 'appeaser', 'arbitrator', 'assuager', 'balm', 'calmative', 'conchie', 'conciliator', 'conscientious objector'],
    'peacemongering': ['united nations troops', 'appeasement', 'calming', 'conciliation', 'detente', 'dulcification', 'easing of relations', 'mediation', 'mollification', 'pacification', 'peace-keeping force', 'peacemaking'],
    'peacetime': ['accord', 'at peace', 'bloodless', 'calm', 'cessation of combat', 'concordant', 'exemption from hostilities', 'freedom from war', 'halcyon', 'harmony', 'idyllic', 'liberty in tranquillity'],
    'peach': ['miss america', 'ace', 'apricot', 'babble', 'bathing beauty', 'be indiscreet', 'be unguarded', 'bear witness against', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner'],
    'peach fuzz': ['vandyke', 'beard', 'beaver', 'bristles', 'daintiness', 'delicacy', 'down', 'downiness', 'filminess', 'fine-grainedness', 'fineness', 'fluff'],
    'peachy': ['ok', 'ace-high', 'bad', 'bang-up', 'bonzer', 'boss', 'bully', 'but good', 'cool', 'corking', 'crackerjack', 'dandy'],
    'peacock': ['dalmatian', 'antigorite', 'attitudinize', 'avifauna', 'baby bird', 'billy', 'billy goat', 'bird', 'bird of jove', 'bird of juno', 'bird of minerva', 'bird of night'],
    'peacocky': ['aggressively self-confident', 'biggety', 'bumptious', 'chesty', 'chichi', 'cocky', 'conceited', 'flamboyant', 'immodest', 'know-it-all', 'obtrusive', 'ostentatious'],
    'peak': ['acme', 'acme of perfection', 'all', 'allophone', 'alp', 'alveolar', 'apex', 'apico-alveolar', 'apico-dental', 'apogee', 'articulation', 'aspiration'],
    'peaked': ['acicular', 'acuminate', 'acute', 'attenuated', 'cachectic', 'cadaverous', 'capped', 'corpselike', 'crested', 'crowned', 'cuspidate', 'debilitated'],
    'peaky': ['acicular', 'acuminate', 'acute', 'ailing', 'ashen', 'cuspidate', 'drained', 'drawn', 'emaciated', 'feeble', 'gaunt', 'haggard'],
    'peal': ['awake the dead', 'bay', 'beep', 'bell', 'blare', 'blast', 'blast the ear', 'blat', 'blow', 'blow the horn', 'bong', 'boom'],
    'pealing': ['booming', 'cannonading', 'change ringing', 'chime', 'chiming', 'chink', 'clang', 'clanging', 'clangor', 'clank', 'clanking', 'clink'],
    'peanut': ['brazil nut', 'mickey mouse', 'almond', 'almond paste', 'amande', 'amande douce', 'amandes mondees', 'bitter almond', 'blanched almonds', 'burnt almond', 'goober', 'goober pea'],
    'peanut gallery': ['texas tower', 'auditorium', 'balcony', 'beacon', 'belvedere', 'bleachers', 'box', 'box seat', 'bridge', 'conning tower', 'dress circle', 'fauteuil'],
    'pearl': ['quaker-colored', 'acceptable person', 'acier', 'alabaster', 'alabastrine', 'albescent', 'ashen', 'ashy', 'bead', 'boast', 'canescent', 'capital fellow'],
    'pearliness': ['achroma', 'achromasia', 'achromatosis', 'albescence', 'albinism', 'albino', 'albinoism', 'blondness', 'burelage', 'canescence', 'chalkiness', 'creaminess'],
    'pearly': ['quaker-colored', 'acier', 'alabaster', 'alabastrine', 'albescent', 'ashen', 'ashy', 'burele', 'canescent', 'chatoyant', 'cinereous', 'cinerous'],
    'peasant': ['babbitt', 'bauer', 'philistine', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'arriviste', 'boor', 'bounder', 'bourgeois', 'bucolic'],
    'peasantry': ['bourgeoisie', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty', 'commoners', 'commons', 'laborers', 'linendrapers', 'lower classes'],
    'peashooter': ['automatic', 'blowgun', 'blowpipe', 'firearm', 'flamethrower', 'gat', 'gun', 'handgun', 'heater', 'musket', 'piece', 'pistol'],
    'peat': ['alcohol', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coke', 'combustible', 'dope', 'ethane'],
    'pebble': ['ace', 'asphalt', 'atom', 'bit', 'blacktop', 'carpet', 'causeway', 'cement', 'checkstone', 'cobblestone', 'concrete', 'dab'],
    'pebbly': ['arenaceous', 'arenarious', 'breccial', 'brecciated', 'craggy', 'crystal', 'crystalline', 'grainy', 'granular', 'granulate', 'granulated', 'gravelly'],
    'peccadillo': ['atrocity', 'blunder', 'botch', 'breach', 'crime', 'crime against humanity', 'deadly sin', 'delinquency', 'dereliction', 'enormity', 'error', 'evil'],
    'peccant': ['aberrant', 'abominable', 'abroad', 'adrift', 'all abroad', 'all off', 'all wrong', 'amiss', 'arraignable', 'arrant', 'askew', 'astray'],
    'peck': ['abundance', 'acres', 'bags', 'barrel', 'barrels', 'batch', 'beak', 'brush', 'bug', 'bunt', 'bushel', 'buss'],
    'peculate': ['abuse', 'befoul', 'convert', 'debase', 'defalcate', 'defile', 'desecrate', 'divert', 'embezzle', 'foul', 'maladminister', 'misapply'],
    'peculiar': ['aberrant', 'abnormal', 'absurd', 'anomalous', 'another', 'appropriate', 'appropriate to', 'arbitrary', 'atypical', 'bizarre', 'categorical', 'characteristic'],
    'peculiarity': ['aberration', 'abnormality', 'absurdity', 'affectation', 'affection', 'anomaly', 'anticness', 'aroma', 'attribute', 'automatism', 'bad habit', 'badge'],
    'peculiarly': ['a fortiori', 'above all', 'abundantly', 'acutely', 'all the more', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'characteristically', 'chiefly', 'conspicuously'],
    'pedagogical': ['academic', 'cross-disciplinary', 'donnish', 'graduate', 'graduate-professional', 'interdisciplinary', 'pedagogic', 'pedantic', 'postgraduate', 'preceptorial', 'professional', 'professorial'],
    'pedagogue': ['abecedarian', 'certified teacher', 'docent', 'doctor', 'dominie', 'don', 'educationist', 'educator', 'fellow', 'guide', 'guru', 'instructor'],
    'pedagogy': ['catechization', 'coaching', 'didactics', 'direction', 'edification', 'education', 'enlightenment', 'guidance', 'illumination', 'information', 'instruction', 'pedagogics'],
    'pedal': ['advance', 'bar', 'beam', 'bicycle', 'bike', 'boom', 'bowl', 'bunt', 'bus', 'butt', 'cant hook', 'catch a train'],
    'pedant': ['babbitt', 'gongorist', 'marinist', 'middle american', 'philistine', 'anal character', 'bluestocking', 'bourgeois', 'burgher', 'compulsive character', 'conformer', 'conformist'],
    'pedantic': ['gongoresque', 'johnsonian', 'academic', 'accordant', 'affected', 'anal', 'arid', 'bedizened', 'bibliophagic', 'big-sounding', 'bluestocking', 'book-fed'],
    'pedantry': ['bibliolatry', 'bibliomania', 'bluestockingism', 'book learning', 'book madness', 'bookiness', 'bookishness', 'booklore', 'ceremonialism', 'classical scholarship', 'classicism', 'culture'],
    'peddler': ['arab', 'cadger', 'chapman', 'cheap-jack', 'cheap-john', 'cheapjack', 'colporteur', 'coster', 'costermonger', 'duffer', 'hawker', 'higgler'],
    'peddling': ['mickey mouse', 'consumer preference study', 'consumer research', 'consumer survey', 'direct-mail selling', 'hard sell', 'hawking', 'high-pressure salesmanship', 'huckstering', 'jobbing', 'low-pressure salesmanship', 'mail-order selling'],
    'pedestal': ['aggrandize', 'apotheosize', 'baluster', 'balustrade', 'banister', 'base', 'caryatid', 'colonnade', 'column', 'dado', 'deify', 'die'],
    'pedestrian': ['ambler', 'ambulant', 'ambulative', 'ambulator', 'ambulatory', 'arid', 'artless', 'backpacker', 'banal', 'banausic', 'barren', 'blah'],
    'pediatric': ['allopathic', 'chiropodic', 'chiropractic', 'clinical', 'dental', 'exodontic', 'homeopathic', 'hydropathic', 'iatric', 'medical', 'naturopathic', 'neurological'],
    'pediatrician': ['anesthesiologist', 'cardiologist', 'chiropodist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'immunologist', 'internist', 'neurologist', 'obstetrician'],
    'pedicel': ['anthrophore', 'axis', 'baluster', 'balustrade', 'banister', 'base', 'bole', 'cane', 'carpophore', 'caryatid', 'caudex', 'caulicle'],
    'pedigree': ['almanach de gotha', 'red book', 'royal kalendar', 'social register', 'stammbaum', 'ancestry', 'birth', 'blood', 'bloodline', 'blue book', 'derivation', 'descent'],
    'peek': ['bend the eyes', 'blink', 'cast', 'direct the eyes', 'flash', 'gander', 'glance', 'glimpse', 'half an eye', 'look', 'meddle', 'nose'],
    'peekaboo': ['clear', 'clear as crystal', 'crystal', 'crystal-clear', 'crystalline', 'diaphane', 'diaphanous', 'filmy', 'gauzy', 'gossamer', 'gossamery', 'light-pervious'],
    'peel': ['abscind', 'acropolis', 'amputate', 'annihilate', 'ban', 'bar', 'bark', 'bastion', 'beachhead', 'blockhouse', 'bob', 'bran'],
    'peel off': ['barnstorm', 'carry away', 'come apart', 'come off', 'come undone', 'come unstuck', 'control', 'copilot', 'crack up', 'disintegrate', 'drive', 'fall off'],
    'peeler': ['bluebottle', 'bobby', 'bull', 'constable', 'copper', 'dynamo', 'ecdysiast', 'flatfoot', 'gendarme', 'go-getter', 'live wire', 'officer'],
    'peep': ['bend the eyes', 'blink', 'bug', 'cackle', 'call', 'carol', 'case', 'cast', 'caw', 'chatter', 'cheep', 'chip'],
    'peepers': ['polaroid glasses', 'baby blues', 'banjo eyes', 'bifocals', 'blinkers', 'bright eyes', 'cheaters', 'clear eyes', 'colored glasses', 'contact lens', 'cornea', 'dark glasses'],
    'peephole': ['texas tower', 'air hole', 'armhole', 'beacon', 'belvedere', 'bleachers', 'blowhole', 'bridge', 'bullet-hole', 'bunghole', 'conning tower', 'cringle'],
    'peeping tom': ['paul pry', 'busybody', 'eavesdropper', 'gossip', 'inquirer', 'inquisitive', 'inquisitor', 'nosy parker', 'pry', 'querier', 'querist', 'questioner'],
    'peer': ['brahman', 'appear', 'archduke', 'aristocrat', 'armiger', 'associate', 'autopsy', 'baron', 'baroness', 'baronet', 'be curious', 'become visible'],
    'peerage': ['ffvs', 'ancienne noblesse', 'aristocracy', 'baronage', 'baronetage', 'chivalry', 'elect', 'elite', 'haut monde', 'high life', 'high society', 'knightage'],
    'peerless': ['absolute', 'best', 'beyond all praise', 'beyond compare', 'beyond comparison', 'champion', 'chaste', 'choice', 'consummate', 'defectless', 'easily first', 'elect'],
    'peeve': ['abhorrence', 'abomination', 'aggravate', 'anathema', 'annoy', 'antipathy', 'arouse', 'aversion', 'badger', 'bait', 'be at', 'bedevil'],
    'peeved': ['aggravated', 'angry', 'annoyed', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'chafed', 'disturbed', 'exasperated', 'galled', 'griped'],
    'peevish': ['jeremianic', 'acrimonious', 'bad-tempered', 'beefing', 'bellyaching', 'bilious', 'bitching', 'cantankerous', 'captious', 'carping', 'catty', 'caviling'],
    'peewee': ['lilliputian', 'tom thumb', 'bairn', 'bantam', 'banty', 'bitsy', 'bitty', 'brownie', 'button', 'cherub', 'child', 'chit'],
    'peg': ['amble', 'amount', 'anchor', 'articulate', 'baby tooth', 'barge', 'batten', 'batten down', 'beverage', 'bicuspid', 'bilge', 'bind'],
    'pejorative': ['abusive', 'back-biting', 'belittling', 'bitchy', 'calumniatory', 'calumnious', 'catty', 'censorious', 'contemptuous', 'contumelious', 'defamatory', 'deprecatory'],
    'pelagic': ['bathymetric', 'bathyorographical', 'deep-sea', 'hydrographic', 'marine', 'maritime', 'nautical', 'naval', 'navigational', 'ocean-going', 'oceanic', 'oceanographic'],
    'pelf': ['affluence', 'and pence', 'assets', 'bottomless purse', 'bulging purse', 'capital gains', 'cash', 'circulating medium', 'cleanup', 'clear profit', 'coinage', 'coined liberty'],
    'pell mell': ['ado', 'agitation', 'amain', 'apace', 'at once', 'bother', 'brawl', 'broil', 'brouhaha', 'bustle', 'by forced marches', 'commotion'],
    'pell-mell': ['bedlam', 'brouhaha', 'chaos', 'chaotic', 'chaotically', 'commotion', 'confused', 'confusedly', 'confusion', 'disorder', 'disordered', 'disorderly'],
    'pellagra': ['lombardy leprosy', 'anemia', 'ariboflavinosis', 'beriberi', 'cachexia', 'chlorosis', 'deficiency anemia', 'dermatitis', 'goiter', 'greensickness', 'keratomalacia', 'kwashiorkor'],
    'pellet': ['ball', 'balloon', 'bar shot', 'bead', 'bird shot', 'bladder', 'blob', 'boll', 'bolus', 'brickbat', 'bubble', 'buckshot'],
    'pellicle': ['allantoic membrane', 'amnion', 'amniotic sac', 'arachnoid membrane', 'basement membrane', 'coat', 'coating', 'collop', 'conjuctiva', 'covering', 'cut', 'deal'],
    'pellucid': ['attic', 'ciceronian', 'chaste', 'classic', 'clean-cut', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'cloudless', 'coherent', 'connected'],
    'pelt': ['australian seal', 'leatherette', 'leatheroid', 'assail', 'assault', 'attack', 'bang', 'barrel', 'bash', 'baste', 'bat', 'batter'],
    'pen': ['pow camp', 'amanuensis', 'arable land', 'arena', 'artistry', 'authorcraft', 'authorship', 'automatic writing', 'barnyard', 'barton', 'bastille', 'beleaguer'],
    'pen yan': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'penal colony': ['pow camp', 'bastille', 'black hole', 'borstal', 'borstal institution', 'bridewell', 'brig', 'cell', 'concentration camp', 'condemned cell', 'death cell', 'death house'],
    'penalize': ['acquit', 'amerce', 'anathematize', 'attaint', 'blacklist', 'bring home to', 'bring to account', 'bring to book', 'call to account', 'castigate', 'censure', 'chasten'],
    'penalty': ['abatement', 'acquittal', 'agio', 'allowance', 'amercement', 'bank discount', 'breakage', 'burden', 'burthen', 'cargo', 'cash discount', 'castigation'],
    'penance': ['day of atonement', 'yom kippur', 'abject apology', 'amends', 'apology', 'asceticism', 'atone', 'atonement', 'attrition', 'baptism', 'change of heart', 'cold purgatorial fires'],
    'penates': ['hestia', 'vesta', 'ancestral spirits', 'angel', 'attendant godling', 'control', 'daemon', 'demon', 'fairy godmother', 'familiar', 'familiar spirit', 'genius'],
    'pence': ['bawbee', 'crown', 'dollar', 'farthing', 'fiver', 'florin', 'fourpence', 'fourpenny', 'groat', 'guinea', 'half crown', 'half dollar'],
    'penchant': ['a thing for', 'affinity', 'aptitude', 'aptness', 'bent', 'bias', 'cast', 'conatus', 'conduciveness', 'delight', 'diathesis', 'disposition'],
    'pencil': ['x ray', 'actinic ray', 'actinism', 'air brush', 'art paper', 'atomic beam', 'atomic ray', 'beam', 'beam of light', 'blaze', 'blaze a trail', 'blemish'],
    'penciled': ['autograph', 'autographic', 'calligraphic', 'chirographic', 'cursive', 'engrossed', 'flowing', 'graphic', 'graphoanalytic', 'graphologic', 'graphometric', 'holograph'],
    'pencraft': ['artistry', 'authorcraft', 'authorship', 'autography', 'automatic writing', 'cacoethes scribendi', 'calligraphy', 'chirography', 'composition', 'creative writing', 'drama-writing', 'editorial-writing'],
    'pend': ['all depend', 'bag', 'be contingent on', 'cascade', 'daggle', 'dangle', 'depend', 'drabble', 'drag', 'draggle', 'drape', 'droop'],
    'pendant': ['accession', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct', 'adjuvant'],
    'pendent': ['at issue', 'cascading', 'conditional', 'conditioned', 'contingent', 'dangling', 'dependent', 'depending', 'falling', 'falling loosely', 'flowing', 'hanging'],
    'pending': ['at issue', 'awaiting', 'beetle', 'beetle-browed', 'beetling', 'cascading', 'conditional', 'conditioned', 'contingent', 'dangling', 'dependent', 'depending'],
    'pendulous': ['cascading', 'dangling', 'dependent', 'depending', 'drooping', 'falling', 'falling loosely', 'faltering', 'flowing', 'fluctuant', 'fluctuating', 'fluctuational'],
    'pendulum': ['indian file', 'array', 'articulation', 'bank', 'buzz', 'catena', 'catenation', 'chain', 'chain reaction', 'chaining', 'concatenation', 'connection'],
    'penetrable': ['accessible', 'apprehensible', 'approachable', 'articulate', 'assailable', 'attackable', 'attainable', 'available', 'beatable', 'cognizable', 'come-at-able', 'comprehensible'],
    'penetrate': ['affect', 'auger', 'be glimpsed', 'be hep to', 'be on to', 'be realized', 'be remembered', 'be wise to', 'benumb', 'bespread', 'besprinkle', 'bite'],
    'penetrating': ['siberian', 'absorbing', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'acute'],
    'penetration': ['access', 'acuity', 'acumen', 'acupunctuation', 'acupuncture', 'acuteness', 'admission', 'apperception', 'astuteness', 'bore', 'boring', 'broach'],
    'penicillin': ['chloromycetin', 'terramycin', 'actinomycin', 'amphotericin', 'bacitracin', 'carbomycin', 'chlortetracycline', 'cloxacillin', 'dihydrostreptomycin', 'erythromycin', 'fradicin', 'gramicidin'],
    'peninsula': ['africa', 'antarctica', 'asia', 'australia', 'eurasia', 'eurasian landmass', 'europe', 'north america', 'south america', 'bill', 'breakwater', 'cape'],
    'penis': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'penitence': ['day of atonement', 'yom kippur', 'abject apology', 'acknowledgment', 'anguish', 'apology', 'asceticism', 'attrition', 'breast-beating', 'change of heart', 'cold purgatorial fires', 'compunction'],
    'penitent': ['magdalen', 'abject', 'apologetic', 'compunctious', 'confessor', 'conscience-stricken', 'contrite', 'grief-stricken', 'humbled', 'melted', 'penitential', 'penitentiary'],
    'penitential': ['abject', 'amendatory', 'apologetic', 'ascetic', 'atoning', 'balancing', 'cleansing', 'compensating', 'compensational', 'compensatory', 'compunctious', 'contrite'],
    'penitentiary': ['grand penitentiary', 'holy father', 'pow camp', 'abuna', 'antipope', 'archbishop', 'archdeacon', 'archpriest', 'bail', 'bastille', 'bishop', 'bishop coadjutor'],
    'penmanship': ['autography', 'calligraphy', 'chirography', 'fist', 'graphanalysis', 'graphology', 'graphometry', 'hand', 'handwriting', 'longhand', 'manuscript', 'paleography'],
    'pennant': ['dannebrog', 'jolly roger', 'old glory', 'star-spangled banner', 'stars and stripes', 'union flag', 'union jack', 'and blue', 'banderole', 'banner', 'banneret', 'black flag'],
    'penned': ['autograph', 'autographic', 'barred', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'cabined', 'caged', 'calligraphic', 'chirographic'],
    'penny': ['c-note', 'g-note', 'bawbee', 'buck', 'cartwheel', 'cent', 'century', 'copper', 'crown', 'dime', 'dollar', 'dollar bill'],
    'penny pinching': ['avarice', 'avaricious', 'cheap', 'cheapness', 'cheeseparing', 'close', 'closefisted', 'closefistedness', 'closeness', 'hardfisted', 'hardfistedness', 'hoarding'],
    'penology': ['castigation', 'chastening', 'chastisement', 'condign punishment', 'correction', 'deserts', 'disciplinary measures', 'discipline', 'ferule', 'infliction', 'judgment', 'judicial punishment'],
    'penscript': ['article', 'autograph', 'autography', 'brainchild', 'calligraphy', 'chirography', 'composition', 'computer printout', 'copy', 'document', 'draft', 'edited version'],
    'pension': ['aid', 'alimony', 'allotment', 'allowance', 'annuity', 'assistance', 'benefit', 'boardinghouse', 'bounty', 'depletion allowance', 'dismiss', 'dole'],
    'pension off': ['abdicate', 'aid', 'assist', 'be pensioned', 'be superannuated', 'boot', 'bounce', 'break', 'bump', 'bust', 'can', 'cashier'],
    'pensioner': ['allottee', 'almsman', 'almswoman', 'annuitant', 'assign', 'assignee', 'assistant', 'beneficiary', 'charge', 'client', 'commoner', 'dependent'],
    'pensive': ['absent', 'absentminded', 'absorbed', 'abstracted', 'atrabiliar', 'atrabilious', 'bemused', 'blue', 'brooding', 'castle-building', 'cogitative', 'cognitive'],
    'pensiveness': ['absorption', 'abstraction', 'brown study', 'castle-building', 'close study', 'concentration', 'contemplativeness', 'daydreaming', 'deep thought', 'dreamery', 'dreamfulness', 'dreaminess'],
    'penstock': ['aboideau', 'air lock', 'chute', 'dock gate', 'eaves trough', 'flood-hatch', 'floodgate', 'gate', 'guide', 'gutter', 'head gate', 'lock'],
    'pent up': ['arrested', 'barred', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'bridled', 'cabined', 'caged', 'cloistered', 'closed-in'],
    'pentagonese': ['varietyese', 'wall streetese', 'washingtonese', 'business english', 'businessese', 'cinemese', 'collegese', 'commercialism', 'computerese', 'economese', 'federalese', 'journalese'],
    'pentane': ['alcohol', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coke', 'combustible', 'dope', 'ethane'],
    'pentecost': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas'],
    'penthouse': ['dymaxion house', 'white house', 'adobe house', 'apartment', 'building', 'casa', 'ceiling', 'chambers', 'cliff dwelling', 'cold-water flat', 'consulate', 'country house'],
    'penurious': ['bankrupt', 'beggared', 'beggarly', 'begrudging', 'cheap', 'chintzy', 'destitute', 'dirt', 'flat broke', 'grudging', 'hard up', 'impecunious'],
    'penury': ['bare cupboard', 'bare subsistence', 'beggarliness', 'beggary', 'deprivation', 'destitution', 'empty purse', 'grinding poverty', 'gripe', 'hand-to-mouth existence', 'homelessness', 'impecuniousness'],
    'peon': ['apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'bootlick', 'bootlicker', 'brown-nose'],
    'peonage': ['abjectness', 'absolutism', 'attendance', 'baseness', 'bond service', 'bondage', 'captivity', 'control', 'debt slavery', 'deprivation of freedom', 'disenfranchisement', 'disfranchisement'],
    'people': ['everyman', 'john doe', 'public', 'richard roe', 'agnate', 'ancestors', 'ancestry', 'anchor', 'animal kingdom', 'assembly', 'billet at', 'bivouac'],
    'peopling': ['anchorage', 'colonization', 'empeoplement', 'establishment', 'fixation', 'foundation', 'inauguration', 'inhabiting', 'initiation', 'installation', 'installment', 'investiture'],
    'pep': ['aggressiveness', 'animation', 'bang', 'birr', 'breeziness', 'briskness', 'bubbliness', 'dash', 'drive', 'ebullience', 'effervescence', 'energy'],
    'pep pill': ['benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'methedrine', 'amphetamine', 'amphetamine sulfate', 'cocaine', 'coke', 'crystal'],
    'pep rally': ['agitation', 'arousal', 'exasperation', 'excitation', 'excitement', 'firing', 'fomentation', 'incitation', 'incitement', 'inflammation', 'instigation', 'irritation'],
    'pep talk': ['address', 'after-dinner speech', 'agitation', 'allocution', 'arousal', 'chalk talk', 'debate', 'declamation', 'diatribe', 'eulogy', 'exasperation', 'excitation'],
    'pep up': ['animate', 'arouse', 'dynamize', 'electrify', 'energize', 'enliven', 'exhilarate', 'fire', 'galvanize', 'hearten', 'inflame', 'invigorate'],
    'pepless': ['apathetic', 'benumbed', 'blase', 'bored', 'dead', 'debilitated', 'dopey', 'dormant', 'droopy', 'drugged', 'dull', 'enervated'],
    'pepper': ['tabasco', 'worcestershire sauce', 'aggressiveness', 'aim at', 'allspice', 'anchovies', 'angelica', 'applesauce', 'band', 'bang', 'bar', 'barrage'],
    'peppered': ['apertured', 'bespangled', 'blotched', 'blotchy', 'crible', 'dotted', 'dotty', 'dusted', 'fenestrated', 'flea-bitten', 'flecked', 'fleckered'],
    'peppery': ['alert', 'beany', 'brisk', 'burning', 'choleric', 'combustible', 'cranky', 'cross', 'curried', 'explosive', 'fiery', 'hasty'],
    'peppy': ['active', 'activist', 'activistic', 'acute', 'aggressive', 'alert', 'alive', 'animate', 'animated', 'bouncing', 'bouncy', 'breezy'],
    'per': ['accommodated to', 'according to', 'adapted to', 'adjusted to', 'after', 'agreeable to', 'agreeably to', 'all', 'answerable to', 'aside', 'by', 'by dint of'],
    'per capita': ['all', 'apiece', 'aside', 'distributional', 'distributive', 'each', 'each to each', 'equal', 'even stephen', 'fifty-fifty', 'half', 'half-and-half'],
    'per se': ['alone', 'apart', 'at bottom', 'at heart', 'at the core', 'au fond', 'basically', 'by itself', 'essentially', 'fundamentally', 'in essence', 'in itself'],
    'perambulate': ['ambulate', 'ankle', 'circumambulate', 'course', 'cover', 'do', 'foot', 'foot it', 'go over', 'hoof it', 'jaywalk', 'jog on'],
    'perceivable': ['apparent', 'beholdable', 'clear', 'clear as crystal', 'crystal-clear', 'detectable', 'discernible', 'disclosed', 'distinct', 'evident', 'explicit', 'exposed'],
    'perceive': ['appreciate', 'apprehend', 'ascertain', 'be acquainted with', 'be apprised of', 'be aware of', 'be cognizant of', 'be conscious of', 'be conversant with', 'be informed', 'be sensible of', 'behold'],
    'percentage': ['abatement', 'absolute interest', 'adjunct', 'advantage', 'advantageousness', 'advisability', 'agio', 'allotment', 'allowance', 'appropriateness', 'arithmetical proportion', 'avail'],
    'perceptible': ['apparent', 'appraisable', 'appreciable', 'apprehensible', 'ascertainable', 'assessable', 'beholdable', 'calculable', 'clear', 'clear as crystal', 'cognizable', 'comprehensible'],
    'perceptibly': ['apparently', 'appreciably', 'clearly', 'conspicuously', 'definitely', 'discernibly', 'distinctly', 'evidently', 'explicitly', 'expressly', 'glaringly', 'manifestly'],
    'perception': ['acuity', 'acumen', 'acuteness', 'apperception', 'appreciation', 'appreciativeness', 'apprehension', 'astuteness', 'awareness', 'clear sight', 'cogency', 'cognition'],
    'perceptive': ['acute', 'alert', 'alive', 'alive to', 'all-knowing', 'apperceptive', 'appercipient', 'apprehending', 'apprehensive', 'argute', 'astute', 'attentive'],
    'perch': ['abide', 'abut on', 'alight', 'anchor', 'aviary', 'be based on', 'be seated', 'bear on', 'berth', 'bestraddle', 'bestride', 'billet at'],
    'perchance': ['accidentally', 'as it chanced', 'by a fluke', 'by accident', 'by chance', 'by good fortune', 'by hazard', 'casually', 'conceivably', 'feasibly', 'for some reason', 'fortuitously'],
    'percipient': ['acute', 'all-knowing', 'apperceptive', 'appercipient', 'apprehending', 'apprehensive', 'argute', 'astute', 'aware', 'cogent', 'cognizant', 'comprehending'],
    'percolate': ['absorb', 'act', 'adsorb', 'assimilate', 'bathe', 'be effective', 'be in action', 'bleed', 'blot', 'blot up', 'bolt', 'brew'],
    'percolation': ['absorbency', 'absorbent', 'absorption', 'access', 'admission', 'adsorbent', 'adsorption', 'assimilation', 'blotter', 'blotting', 'blotting paper', 'bolting'],
    'percolator': ['clarifier', 'colander', 'cradle', 'cribble', 'filter', 'lixiviator', 'purifier', 'refiner', 'refinery', 'riddle', 'rocker', 'screen'],
    'percussion': ['appulse', 'battery', 'bells', 'bones', 'brunt', 'bulldozing', 'bulling', 'bump', 'cannon', 'carambole', 'carom', 'castanets'],
    'percussive': ['battery', 'bells', 'bones', 'castanets', 'celesta', 'chime', 'chimes', 'clappers', 'concussive', 'crash cymbal', 'crashing', 'cymbals'],
    'perdition': ['abaddon', 'gehenna', 'hades', 'naraka', 'pandemonium', 'sheol', 'tophet', 'abyss', 'avichi', 'bereavement', 'bloodbath', 'blue ruin'],
    'perdurable': ['abiding', 'age-long', 'aged', 'ageless', 'ancient', 'antique', 'ceaseless', 'chronic', 'coeternal', 'constant', 'continual', 'continuing'],
    'perdure': ['abide', 'bide', 'carry on', 'carry through', 'continue', 'continue to be', 'defeat time', 'defy time', 'dwell', 'endure', 'exist', 'extend'],
    'peregrinate': ['bat around', 'bum', 'campaign', 'count ties', 'course', 'cover', 'cruise', 'divagate', 'do', 'drift', 'fare', 'flit'],
    'peregrine': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'ambulant', 'ambulative', 'ambulatory'],
    'peremptory': ['absolute', 'absolutist', 'absolutistic', 'admitting no exception', 'all-out', 'arbitrary', 'aristocratic', 'arrogant', 'authoritarian', 'authoritative', 'autocratic', 'bigoted'],
    'perennial': ['abiding', 'age-long', 'aged', 'amphibian', 'ancient', 'angiosperm', 'annual', 'antique', 'aquatic plant', 'articulated', 'biennial', 'catenated'],
    'perennially': ['ad infinitum', 'again and again', 'always', 'at a stretch', 'at all times', 'ceaselessly', 'connectedly', 'constantly', 'continually', 'continuously', 'cumulatively', 'cyclically'],
    'perfect': ['ko', 'ok', 'absolute', 'accomplish', 'accomplished', 'accurate', 'achieve', 'adept', 'admitting no exception', 'adroit', 'all right', 'all-embracing'],
    'perfected': ['sol', 'accomplished', 'advanced', 'all bets off', 'all off', 'all over', 'all up', 'ameliorated', 'archetypical', 'at an end', 'beautified', 'bettered'],
    'perfection': ['absoluteness', 'accomplishment', 'accuracy', 'achievement', 'acme', 'acme of perfection', 'aesthetic proportions', 'archetype', 'arete', 'attainment', 'attention to fact', 'beauties'],
    'perfectionist': ['babbitt', 'leibnizian', 'leibnizian optimist', 'middle american', 'philistine', 'pollyanna', 'anal character', 'aspirant', 'aspirer', 'bourgeois', 'bright', 'burgher'],
    'perfectly': ['a outrance', 'absolutely', 'accurately', 'admirably', 'all out', 'altogether', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure', 'bloody', 'clean'],
    'perfervid': ['abandoned', 'afire', 'ardent', 'at fever pitch', 'bigoted', 'blazing', 'burning', 'committed', 'dedicated', 'delirious', 'devoted', 'devout'],
    'perfidious': ['machiavellian', 'alienated', 'ambidextrous', 'artful', 'corrupt', 'crafty', 'crooked', 'cunning', 'deceitful', 'disaffected', 'dishonest', 'disloyal'],
    'perfidy': ['betrayal', 'deceit', 'dirty pool', 'dirty trick', 'dirty work', 'disloyalty', 'double-dealing', 'duplicity', 'faithlessness', 'falseheartedness', 'falseness', 'falsity'],
    'perforate': ['auger', 'bite', 'bore', 'broach', 'countersink', 'drill', 'drive', 'empierce', 'enter', 'fix', 'gore', 'gouge'],
    'perforation': ['acupunctuation', 'acupuncture', 'bore', 'boring', 'broach', 'drill hole', 'empiercement', 'fixing', 'goring', 'impalement', 'lancing', 'penetration'],
    'perform': ['accompany', 'accomplish', 'achieve', 'act', 'act a part', 'act as', 'act as foil', 'act out', 'affect', 'ape', 'appear', 'attain'],
    'performable': ['achievable', 'actable', 'attainable', 'compassable', 'doable', 'feasible', 'manageable', 'maneuverable', 'manipulatable', 'negotiable', 'operable', 'operatable'],
    'performance': ['philharmonic concert', 'accomplished fact', 'accomplishment', 'accordance', 'achievement', 'acquittal', 'acquittance', 'act', 'acta', 'acting', 'action', 'adherence'],
    'performer': ['actor', 'actress', 'affecter', 'agent', 'architect', 'artist', 'artiste', 'author', 'belly dancer', 'burlesque queen', 'chorine', 'chorus boy'],
    'performing': ['acting', 'action', 'agency', 'aping', 'behavioral', 'buffoonery', 'business', 'characterization', 'conduct', 'direction', 'driving', 'dumb show'],
    'perfume': ['aerate', 'aerify', 'ambergris', 'ambrosia', 'aroma', 'aromatic', 'aromatic gum', 'aromatic water', 'aromatize', 'atomize', 'attar', 'attar of roses'],
    'perfumed': ['ambrosial', 'aromatic', 'balmy', 'essenced', 'flowery', 'fragrant', 'fruity', 'incense-breathing', 'musky', 'odorate', 'odoriferous', 'odorous'],
    'perfumer': ['atomizer', 'baker', 'bookdealer', 'bookseller', 'butcher', 'censer', 'censing', 'chandler', 'clothing merchant', 'confectioner', 'draper', 'drysalter'],
    'perfunctory': ['laodicean', 'airy', 'apathetic', 'at odds', 'ataractic', 'automatic', 'averse', 'backward', 'balking', 'balky', 'blase', 'businesslike'],
    'perfuse': ['assign', 'bleed', 'carry over', 'communicate', 'consign', 'cup', 'deliver', 'deport', 'diffuse', 'disseminate', 'ease in', 'expel'],
    'perfusion': ['arterial transfusion', 'blood bank', 'blood donor', 'blood donor center', 'blood transfusion', 'bloodmobile', 'communication', 'conduction', 'contagion', 'convection', 'delivery', 'deportation'],
    'pergola': ['alcove', 'arbor', 'arcade', 'areaway', 'bower', 'breezeway', 'cloister', 'colonnade', 'conservatory', 'corridor', 'gallery', 'gazebo'],
    'perhaps': ['blind guess', 'bold conjecture', 'conceivably', 'conjecture', 'feasibly', 'guess', 'haply', 'hunch', 'imaginably', 'it may be', 'maybe', 'perchance'],
    'perigee': ['earth insertion', 'lem', 'lm', 'abutment', 'abuttal', 'adjacency', 'adjoiningness', 'aphelion', 'apogee', 'apposition', 'appulse', 'astronomical longitude'],
    'peril': ['breakers ahead', 'cardhouse', 'cause for alarm', 'compromise', 'crisis', 'danger', 'dangerous ground', 'desultoriness', 'emergency', 'encounter danger', 'endanger', 'endangerment'],
    'perilous': ['alarming', 'bad', 'chancy', 'critical', 'dangerous', 'dangersome', 'delicate', 'desultory', 'explosive', 'fraught with danger', 'hairy', 'hazardous'],
    'perimeter': ['alentours', 'ambience', 'ambit', 'border', 'borderlands', 'borderline', 'boundaries', 'boundary', 'bounds', 'bourn', 'bourns', 'brim'],
    'period': ['alexandrine', 'archean', 'archeozoic', 'cambrian', 'carboniferous', 'cenozoic', 'comanchean', 'cretaceous', 'devonian', 'eocene', 'glacial', 'holocene'],
    'period style': ['background', 'background detail', 'decorative composition', 'decorative style', 'design', 'detail', 'figure', 'foil', 'foreground detail', 'form', 'motif', 'national style'],
    'periodic': ['alternate', 'articulated', 'beating', 'catenated', 'ceaseless', 'circling', 'concatenated', 'connected', 'constant', 'continual', 'continued', 'continuing'],
    'periodical': ['airing', 'almanac', 'alternate', 'annual', 'bandying', 'bimonthly', 'biweekly', 'book', 'broadcast', 'broadcasting', 'bruiting', 'bruiting about'],
    'periodicity': ['indian file', 'alternation', 'annual period', 'array', 'articulation', 'bank', 'baseball season', 'basketball season', 'beat', 'buzz', 'catena', 'catenation'],
    'periodontic': ['allopathic', 'chiropodic', 'chiropractic', 'clinical', 'dental', 'exodontic', 'homeopathic', 'hydropathic', 'iatric', 'medical', 'naturopathic', 'neurological'],
    'peripatetic': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'ambulant', 'ambulative', 'ambulator'],
    'peripheral': ['ambient', 'apparent', 'beside the point', 'circling', 'circumambient', 'circumferential', 'circumflex', 'circumfluent', 'circumfluous', 'circumjacent', 'cortical', 'delineatory'],
    'periphery': ['alentours', 'ambience', 'ambit', 'border', 'borderlands', 'bound', 'boundaries', 'boundary', 'bounds', 'bourns', 'brim', 'circle'],
    'periscope': ['aqua-lung', 'air cylinder', 'aquascope', 'bathyscaphe', 'bathysphere', 'benthoscope', 'diving bell', 'diving boat', 'diving chamber', 'diving goggles', 'diving helmet', 'diving hood'],
    'perish': ['age', 'antiquate', 'be annihilated', 'be consumed', 'be destroyed', 'be done for', 'be gone', 'be killed', 'be lost', 'be no more', 'be wiped out', 'become extinct'],
    'perishable': ['brittle', 'capricious', 'changeable', 'corruptible', 'deciduous', 'dying', 'ephemeral', 'evanescent', 'fading', 'fickle', 'fleeting', 'flitting'],
    'peritonitis': ['abdominal hernia', 'adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever'],
    'perjured': ['artful', 'calculating', 'crafty', 'deceitful', 'dishonest', 'disingenuous', 'equivocal', 'falsehearted', 'forsworn', 'insincere', 'lying', 'mendacious'],
    'perjurer': ['ananias', 'baron munchausen', 'father of lies', 'satan', 'sir john mandeville', 'consummate liar', 'dirty liar', 'equivocator', 'fabricator', 'fabulist', 'false witness', 'falsifier'],
    'perjury': ['artfulness', 'coloring', 'confabulation', 'craftiness', 'credibility gap', 'deceitfulness', 'disingenuousness', 'distortion', 'equivocation', 'exaggeration', 'false coloring', 'false swearing'],
    'perk up': ['advance', 'ameliorate', 'amend', 'animate', 'arouse', 'boost', 'brace', 'brace up', 'brighten', 'brighten up', 'brisk', 'brisken'],
    'perks': ['trinkgeld', 'blackmail', 'bonus', 'bonus system', 'boodle', 'booty', 'bounty', 'bribe', 'capital gains', 'cleanup', 'clear profit', 'consideration'],
    'perky': ['active', 'activist', 'activistic', 'aggressively self-confident', 'airy', 'alive', 'animated', 'biggety', 'bouncing', 'bouncy', 'breezy', 'bright'],
    'permanence': ['abidingness', 'age', 'antiquity', 'application', 'assiduity', 'assiduousness', 'bulldog tenacity', 'ceaselessness', 'changelessness', 'coeternity', 'concentration', 'constancy'],
    'permanent': ['afro', 'abiding', 'age-long', 'aged', 'ageless', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'ancient', 'antique'],
    'permanently': ['abidingly', 'ad infinitum', 'always', 'ceaselessly', 'changelessly', 'constantly', 'continually', 'continuously', 'endlessly', 'enduringly', 'eternally', 'everlastingly'],
    'permeate': ['bathe', 'bespread', 'besprinkle', 'breathe', 'brew', 'charge', 'color', 'crawl with', 'creep with', 'decoct', 'diffuse', 'douche'],
    'permeated': ['awash', 'bathed', 'crawling', 'creeping', 'deluged', 'dipped', 'drenched', 'dribbling', 'dripping', 'dripping wet', 'drowned', 'engulfed'],
    'permeation': ['brewing', 'decoction', 'diffusion', 'drench', 'drenching', 'ducking', 'dunking', 'imbruement', 'imbuement', 'impregnation', 'infiltration', 'infusion'],
    'permissible': ['ok', 'acceptable', 'admissible', 'all right', 'allowable', 'allowed', 'approved', 'authorized', 'bearable', 'endorsed', 'excusable', 'justifiable'],
    'permission': ['john hancock', 'ok', 'acceptance', 'accord', 'acquiescence', 'affirmance', 'affirmation', 'affirmative', 'affirmative voice', 'agreement', 'allowance', 'approbation'],
    'permissive': ['accommodating', 'accordant', 'acquiescent', 'admissive', 'affable', 'affirmative', 'agreeable', 'agreeing', 'allowing', 'amiable', 'approving', 'assenting'],
    'permissiveness': ['abandon', 'abandonment', 'carelessness', 'charitableness', 'charity', 'coddling', 'condonation', 'connivance', 'cosseting', 'culpa', 'culpable negligence', 'default'],
    'permit': ['ok', 'accede to', 'accept', 'accord', 'accord to', 'accredit', 'admit', 'affirm', 'agree to', 'allow', 'allowance', 'amen'],
    'permitted': ['admitted', 'allowed', 'chartered', 'excepted', 'excused', 'exempt', 'exempted', 'favored', 'immune', 'irresponsible', 'let off', 'licensed'],
    'permutable': ['able to adapt', 'adaptable', 'adjustable', 'alterable', 'alterative', 'changeable', 'checkered', 'commutable', 'commutative', 'convertible', 'equal', 'equalizing'],
    'permutation': ['alteration', 'alternation', 'avatar', 'battledore and shuttlecock', 'catabolism', 'catalysis', 'commutation', 'consubstantiation', 'cooperation', 'counterchange', 'cross fire', 'displacement'],
    'pernicious': ['baleful', 'baneful', 'brutal', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'counterproductive', 'damaging', 'deadly', 'death-bringing', 'deathful'],
    'perorate': ['abort', 'cease', 'chatter', 'close', 'conclude', 'debate', 'declaim', 'demagogue', 'determine', 'drag out', 'draw out', 'elocute'],
    'peroration': ['ps', 'parthian shot', 'addendum', 'address', 'after-dinner speech', 'afterthought', 'allocution', 'apodosis', 'appendix', 'back matter', 'catastrophe', 'ceasing'],
    'peroxide': ['achromatize', 'blanch', 'bleach', 'bleaching powder', 'chlorine', 'decolor', 'decolorize', 'dim', 'discolor', 'drain', 'drain of color', 'dull'],
    'perpend': ['be abstracted', 'brood', 'chew the cud', 'consider', 'contemplate', 'debate', 'deliberate', 'digest', 'excogitate', 'introspect', 'meditate', 'mind'],
    'perpendicular': ['air line', 'axis', 'azimuth circle', 'beeline', 'chord', 'diagonal', 'diameter', 'direct line', 'directrix', 'edge', 'erect', 'great-circle course'],
    'perpetrate': ['accomplish', 'achieve', 'be responsible for', 'bring about', 'bring off', 'bring to pass', 'carry out', 'carry through', 'commit', 'do', 'do to', 'effect'],
    'perpetual': ['abiding', 'age-long', 'aged', 'ageless', 'all-comprehensive', 'all-inclusive', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'ancient'],
    'perpetually': ['abidingly', 'ad infinitum', 'always', 'at all times', 'ceaselessly', 'changelessly', 'constantly', 'continually', 'continuously', 'daily', 'daily and hourly', 'day after day'],
    'perpetuate': ['bolster', 'conserve', 'continue', 'embalm', 'eternalize', 'eternize', 'extend', 'freeze', 'hold', 'immortalize', 'keep', 'keep alive'],
    'perpetuation': ['continualness', 'continuance', 'continuation', 'continuity', 'endurance', 'eternal re-creation', 'eternal return', 'eternalization', 'extension', 'immortalization', 'lengthening', 'maintenance'],
    'perpetuity': ['abidingness', 'age', 'all-comprehensiveness', 'all-inclusiveness', 'antiquity', 'boundlessness', 'ceaselessness', 'chattering', 'constancy', 'constant flow', 'continualness', 'continuance'],
    'perplex': ['addle', 'addle the wits', 'ail', 'amaze', 'appanage', 'astonish', 'astound', 'awe', 'awestrike', 'babble', 'baffle', 'balk'],
    'perplexed': ['byzantine', 'addled', 'at a loss', 'at a nonplus', 'at a stand', 'at a standstill', 'at an impasse', 'baffled', 'balled up', 'balled-up', 'bamboozled', 'beat'],
    'perplexing': ['byzantine', 'arcane', 'baffling', 'bewildering', 'bothering', 'complex', 'complicated', 'confounding', 'confusing', 'convoluted', 'cryptic', 'discomposing'],
    'perplexity': ['chinese puzzle', 'gordian knot', 'amorphousness', 'baffle', 'bafflement', 'baffling problem', 'befuddlement', 'bewilderment', 'bind', 'bother', 'botheration', 'brain twister'],
    'perquisite': ['trinkgeld', 'accessories', 'appanages', 'appendages', 'appointments', 'appurtenances', 'belongings', 'blackmail', 'bonus', 'bonus system', 'boodle', 'booty'],
    'persecute': ['abuse', 'afflict', 'aggravate', 'aggrieve', 'annoy', 'badger', 'bait', 'be at', 'bedevil', 'befoul', 'beset', 'bewitch'],
    'persecuted': ['badgered', 'baited', 'bedeviled', 'beset', 'bugged', 'bullyragged', 'chivied', 'deviled', 'dogged', 'fretted', 'harassed', 'harried'],
    'persecution': ['mccarthyism', 'abuse', 'affliction', 'aggravation', 'annoyance', 'bad news', 'bedevilment', 'bore', 'bother', 'botheration', 'bothersomeness', 'bullying'],
    'persephone': ['agdistis', 'aides', 'aidoneus', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus'],
    'perseverance': ['acceptance', 'assiduity', 'balkiness', 'bigotry', 'bullheadedness', 'commitment', 'continualness', 'continuance', 'continuation', 'continuity', 'decidedness', 'decision'],
    'persevere': ['abide', 'abide with', 'balk', 'bear', 'bear with', 'beat the game', 'beat the system', 'bide', 'brave', 'brook', 'carry on', 'carry through'],
    'persevering': ['spartan', 'accepting', 'armed with patience', 'assiduous', 'balking', 'balky', 'bigoted', 'bound', 'bound and determined', 'bulldogged', 'bulletheaded', 'bullheaded'],
    'persiflage': ['aphorism', 'apothegm', 'backchat', 'badinage', 'banter', 'bon mot', 'boutade', 'bright idea', 'bright thought', 'brilliant idea', 'chaff', 'conceit'],
    'persist': ['abide', 'adhere', 'agglomerate', 'assert', 'be spared', 'bide', 'bottle up', 'brook no denial', 'bunch', 'carry on', 'carry through', 'cheat death'],
    'persistence': ['abidingness', 'accordance', 'adhesiveness', 'age', 'antiquity', 'application', 'assiduity', 'assiduousness', 'bulldog tenacity', 'bullheadedness', 'calm', 'changelessness'],
    'persistent': ['abiding', 'accordant', 'adherent', 'adhesive', 'age-long', 'aged', 'alike', 'ancient', 'antique', 'archaic', 'assiduous', 'automatic'],
    'persistently': ['and night', 'assiduously', 'bec et ongles', 'chronically', 'committedly', 'day after day', 'decidedly', 'decisively', 'determinedly', 'devotedly', 'diligently', 'doggedly'],
    'person': ['adamite', 'actor', 'actually', 'an existence', 'anatomy', 'antagonist', 'antihero', 'article', 'being', 'bit', 'bit part', 'bodily'],
    'persona': ['an existence', 'anima', 'article', 'being', 'body', 'character', 'coconscious', 'collective unconscious', 'conscience', 'conscious self', 'creature', 'critter'],
    'persona grata': ['acceptable person', 'capital fellow', 'diamond', 'gem', 'gentleman', 'good fellow', 'good lot', 'good man', 'good person', 'good sort', 'good woman', 'honest man'],
    'persona non grata': ['dp', 'ishmael', 'jim crow', 'alien', 'apartheid', 'bad child', 'bad example', 'bad man', 'bad news', 'bad person', 'bad woman', 'castaway'],
    'personable': ['junoesque', 'agreeable', 'amply endowed', 'authoritative', 'becoming', 'bonny', 'braw', 'built', 'built for comfort', 'buxom', 'callipygian', 'callipygous'],
    'personage': ['adamite', 'establishment', 'vip', 'actor', 'antagonist', 'antihero', 'baron', 'being', 'big gun', 'big man', 'big name', 'big noise'],
    'personal': ['absolute', 'actual', 'adverse', 'anonymous', 'belittling', 'bodily', 'bosom', 'certain', 'close', 'closet', 'concrete', 'critical'],
    'personality': ['adamite', 'establishment', 'vip', 'an existence', 'anima', 'ascendancy', 'aspersion', 'authority', 'baron', 'being', 'big gun', 'big man'],
    'personalization': ['alteration', 'analysis', 'anatomization', 'atomization', 'change', 'demarcation', 'desynonymization', 'differencing', 'differentiation', 'discrimination', 'disequalization', 'disjunction'],
    'personalize': ['analyze', 'anatomize', 'anthropomorphize', 'atomize', 'change', 'chop logic', 'descend to particulars', 'desynonymize', 'detail', 'difference', 'differentiate', 'discriminate'],
    'personate': ['act', 'act a part', 'act as', 'act out', 'adumbrate', 'ape', 'body forth', 'copy', 'create a role', 'demonstrate', 'depict', 'do'],
    'personation': ['acting', 'aping', 'buffoonery', 'business', 'characterization', 'dumb show', 'embodiment', 'enacting', 'enactment', 'gag', 'ham', 'hammy acting'],
    'personification': ['acting', 'aping', 'characterization', 'corporealization', 'dumb show', 'embodiment', 'enacting', 'enactment', 'imitation', 'impersonation', 'incarnation', 'incorporation'],
    'personify': ['adumbrate', 'body', 'body forth', 'corporealize', 'corporify', 'demonstrate', 'emblematize', 'embody', 'epitomize', 'exemplify', 'exteriorize', 'externalize'],
    'personnel': ['agent', 'alternate', 'alternative', 'analogy', 'backup', 'change', 'changeling', 'comparison', 'copy', 'counterfeit', 'crew', 'deputy'],
    'persons': ['everyman', 'john doe', 'public', 'body politic', 'citizenry', 'common man', 'commonwealth', 'community', 'community at large', 'estate', 'everybody', 'everyman'],
    'perspective': ['aesthetic distance', 'airscape', 'angle', 'approach', 'arrangement', 'atmosphere', 'attitude', 'balance', 'base', 'brushwork', 'cityscape', 'clearance'],
    'perspicacious': ['acute', 'all-knowing', 'apperceptive', 'appercipient', 'apprehending', 'apprehensive', 'argute', 'astute', 'aware', 'cagey', 'cogent', 'cognizant'],
    'perspicacity': ['acuity', 'acumen', 'acuteness', 'apperception', 'astuteness', 'clear sight', 'cogency', 'color vision', 'cone vision', 'critical discernment', 'day vision', 'daylight vision'],
    'perspicuity': ['atticism', 'acuity', 'acumen', 'acuteness', 'apparentness', 'apperception', 'appropriateness', 'astuteness', 'chasteness', 'chastity', 'clarity', 'classicalism'],
    'perspicuous': ['attic', 'ciceronian', 'acute', 'apparent', 'apperceptive', 'appercipient', 'argute', 'astute', 'chaste', 'classic', 'clean-cut', 'clear'],
    'perspiration': ['bo', 'beaded brow', 'beads of sweat', 'body odor', 'cold sweat', 'dampness', 'diaphoresis', 'exudate', 'exudation', 'honest sweat', 'lather', 'perspiration odor'],
    'persuadable': ['accessible', 'admissive', 'amenable', 'cullible', 'deceivable', 'deludable', 'dupable', 'easy', 'exploitable', 'foolable', 'green', 'gullible'],
    'persuade': ['admonish', 'affect', 'argue into', 'assure', 'be convincing', 'bend', 'bias', 'bring', 'bring home to', 'bring over', 'bring round', 'bring to reason'],
    'persuaded': ['arrogant', 'assured', 'believing', 'certain', 'cocksure', 'confident', 'convinced', 'decided', 'determined', 'devout', 'dogmatic', 'doubtless'],
    'persuasion': ['adherents', 'affiliation', 'allurement', 'ascendancy', 'authority', 'belief', 'bias', 'blandishment', 'blood', 'body', 'branch', 'brand'],
    'persuasive': ['absolute', 'assuring', 'authoritative', 'bait', 'bribe', 'cajoling', 'carrot', 'charismatic', 'charming', 'cogent', 'compelling', 'conclusive'],
    'pert': ['active', 'activist', 'activistic', 'aggressively self-confident', 'alert', 'alive', 'animate', 'animated', 'arch', 'arrogant', 'audacious', 'bantam'],
    'pertain': ['affect', 'appertain', 'appertain to', 'apply', 'apply to', 'associate', 'bear', 'bear on', 'befit', 'combine', 'concern', 'connect'],
    'pertain to': ['affect', 'answer to', 'appertain to', 'apply to', 'bear on', 'bear upon', 'belong to', 'concern', 'connect', 'correspond to', 'deal with', 'have connection with'],
    'pertaining': ['a propos', 'ad rem', 'admissible', 'affinitive', 'appertaining', 'applicable', 'applying', 'apposite', 'appropriate', 'apropos', 'associative', 'belonging'],
    'pertinacious': ['assiduous', 'balking', 'balky', 'bigoted', 'bulldogged', 'bulldoggish', 'bulletheaded', 'bullheaded', 'case-hardened', 'clamant', 'clamorous', 'constant'],
    'pertinacity': ['application', 'assiduity', 'assiduousness', 'balkiness', 'bigotry', 'bulldog courage', 'bulldog tenacity', 'bullheadedness', 'concentration', 'constancy', 'demandingness', 'determination'],
    'pertinence': ['affective meaning', 'applicability', 'application', 'appositeness', 'bearing', 'coloring', 'concern', 'concernment', 'connection', 'connotation', 'consequence', 'denotation'],
    'pertinent': ['a propos', 'ad rem', 'admissible', 'affinitive', 'appertaining', 'applicable', 'applying', 'apposite', 'appropriate', 'apropos', 'apt', 'associative'],
    'pertness': ['activity', 'aggressive self-confidence', 'airiness', 'animation', 'ardor', 'arrogance', 'audacity', 'bold front', 'boldness', 'bounce', 'brash bearing', 'brashness'],
    'perturb': ['abash', 'addle', 'addle the wits', 'afflict', 'agitate', 'ail', 'alarm', 'ball up', 'be the matter', 'beat', 'beat up', 'becloud'],
    'perturbation': ['ado', 'aggravation', 'agitation', 'all-overs', 'angst', 'animation', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat'],
    'perturbed': ['abashed', 'abroad', 'adrift', 'afflicted', 'agitated', 'all-overish', 'amiss', 'annoyed', 'anxious', 'anxioused up', 'apprehensive', 'askew'],
    'perturbing': ['agitating', 'baffling', 'bewildering', 'bothering', 'breathtaking', 'charged', 'cliff-hanging', 'confounding', 'confusing', 'discomposing', 'disconcerting', 'dismaying'],
    'perusal': ['application', 'boning', 'brainwork', 'check', 'conning', 'contemplation', 'cram', 'cramming', 'drill', 'engrossment', 'examination', 'exercise'],
    'peruse': ['autopsy', 'bone', 'browse', 'canvass', 'check', 'check out', 'check over', 'check up on', 'con', 'contemplate', 'dig', 'drill'],
    'pervade': ['bespread', 'besprinkle', 'breathe', 'brew', 'charge', 'color', 'crawl with', 'creep with', 'decoct', 'diffuse', 'dredge', 'dye'],
    'pervasion': ['decoction', 'diffusion', 'imbuement', 'impregnation', 'infiltration', 'infusion', 'instillation', 'instillment', 'interpenetration', 'marination', 'overrunning', 'overspreading'],
    'pervasive': ['absolute', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'born', 'broad-based', 'clean', 'clear', 'comprehensive', 'congenital', 'consummate'],
    'perverse': ['aberrant', 'abroad', 'adamant', 'adrift', 'adversary', 'adversative', 'adverse', 'adversive', 'alien', 'all abroad', 'all off', 'all wrong'],
    'perversely': ['bearishly', 'cantankerously', 'churlishly', 'contrarily', 'contrariwise', 'crabbedly', 'crankily', 'crossly', 'crustily', 'fractiously', 'frowardly', 'huffily'],
    'perversion': ['aberrancy', 'aberration', 'abnormality', 'abstractionism', 'abuse', 'abuse of office', 'abuse of terms', 'adulteration', 'apparent soundness', 'befouling', 'befoulment', 'casuistry'],
    'perversity': ['antagonism', 'antipathy', 'antithesis', 'bearishness', 'bitchiness', 'cantankerousness', 'churlishness', 'clashing', 'collision', 'conflict', 'confrontation', 'contradiction'],
    'pervert': ['abuse', 'adulterate', 'alloy', 'argue insincerely', 'backslider', 'bad egg', 'bad lot', 'bastardize', 'befoul', 'belie', 'bias', 'black sheep'],
    'perverted': ['ac-dc', 'abandoned', 'aberrant', 'abnormal', 'abroad', 'abused', 'adrift', 'affected', 'all abroad', 'all off', 'all wrong', 'amiss'],
    'pervious': ['accessible', 'amenable', 'approachable', 'attainable', 'available', 'come-at-able', 'excretory', 'exudative', 'findable', 'getatable', 'gettable', 'impressionable'],
    'pes': ['arch', 'clubfoot', 'digit', 'dog', 'extremity', 'fetlock', 'foot', 'forefoot', 'forepaw', 'harefoot', 'heel', 'hoof'],
    'pesky': ['aggravating', 'annoying', 'awful', 'awfully', 'bothering', 'bothersome', 'damned', 'disturbing', 'dreadful', 'dreadfully', 'exasperating', 'extremely'],
    'pessimism': ['schmerz', 'slough of despond', 'anxiety', 'apprehension', 'blank despondency', 'cliff-hanging', 'cynicism', 'death wish', 'defeatism', 'dejectedness', 'dejection', 'depression'],
    'pessimist': ['cassandra', 'eeyore', 'calamity howler', 'crepehanger', 'cynic', 'damp', 'damper', 'defeatist', 'fussbudget', 'killjoy', 'malist', 'misanthrope'],
    'pessimistic': ['cassandra-like', 'cassandran', 'cassandrian', 'bleak', 'blue', 'bowed-down', 'cast down', 'cheerless', 'cynical', 'dashed', 'defeatist', 'dejected'],
    'pest': ['affliction', 'aggravation', 'ambulatory plague', 'annoyance', 'annoyer', 'bad news', 'badgerer', 'bane', 'bedevilment', 'besetment', 'black death', 'black plague'],
    'pester': ['aggravate', 'annoy', 'apply pressure', 'badger', 'bait', 'be at', 'bedevil', 'beleaguer', 'beset', 'besetment', 'besiege', 'blandish'],
    'pestered': ['badgered', 'baited', 'bedeviled', 'beset', 'bugged', 'bullyragged', 'chivied', 'deviled', 'dogged', 'harassed', 'harried', 'heckled'],
    'pestering': ['adverse criticism', 'aggravating', 'animadversion', 'annoying', 'aspersion', 'bad notices', 'bad press', 'blandishment', 'bothering', 'bothersome', 'buttonholing', 'cajolement'],
    'pesthole': ['augean stables', 'ambulatory plague', 'black death', 'black plague', 'bubonic plague', 'cellulocutaneous plague', 'defervescing plague', 'dump', 'epidemic', 'epiphytotic', 'epizootic', 'glandular plague'],
    'pesticide': ['cain', 'aborticide', 'acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'apache', 'assassin', 'assassinator', 'bactericide', 'bloodletter', 'bloodshedder'],
    'pestiferous': ['aggravating', 'annoying', 'bad', 'bad for', 'baneful', 'bothering', 'bothersome', 'catching', 'communicable', 'contagious', 'contaminated', 'deadly'],
    'pestilence': ['black death', 'affliction', 'ambulatory plague', 'bane', 'black death', 'black plague', 'blight', 'bubonic plague', 'bugbear', 'burden', 'calamity', 'cancer'],
    'pestle': ['abrade', 'atomize', 'beat', 'bray', 'brecciate', 'cheese grater', 'comminute', 'comminutor', 'contriturate', 'crumb', 'crumble', 'crush'],
    'pet': ['admired', 'adored', 'angel', 'babe', 'baby', 'baby-doll', 'beloved', 'bill and coo', 'buttercup', 'caress', 'cherished', 'cherub'],
    'pet peeve': ['abhorrence', 'abomination', 'anathema', 'antipathy', 'aversion', 'beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'bone to pick'],
    'petal': ['androecium', 'anther', 'blade', 'bract', 'bracteole', 'bractlet', 'calyx', 'carpel', 'corolla', 'corolla tube', 'corona', 'cotyledon'],
    'peter out': ['abate', 'bate', 'be annihilated', 'be consumed', 'be destroyed', 'be disappointing', 'be no more', 'be unproductive', 'be used up', 'be wiped out', 'blow', 'break'],
    'petit mal': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'akinetic epilepsy', 'apoplexy', 'arrest', 'attack', 'autonomic epilepsy'],
    'petite': ['bantam', 'cramped', 'dainty', 'delicate', 'diminutive', 'dinky', 'dwarf', 'exiguous', 'half-pint', 'knee-high', 'lilliputian', 'limited'],
    'petition': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'address', 'aid prayer', 'appeal', 'appeal to', 'application', 'apply for'],
    'petitioner': ['accusant', 'accuser', 'adorer', 'allegator', 'appellant', 'applicant', 'asker', 'aspirant', 'beadsman', 'beggar', 'bidder', 'candidate'],
    'petrification': ['ancient manuscript', 'antique', 'antiquity', 'archaism', 'arteriosclerosis', 'artifact', 'atherosclerosis', 'calcification', 'callusing', 'case hardening', 'cave painting', 'concretion'],
    'petrified': ['gothic', 'victorian', 'adamant', 'adamantine', 'afraid', 'aghast', 'alabastrine', 'antediluvian', 'antiquated', 'antique', 'appalled', 'archaic'],
    'petrified forest': ['ancient manuscript', 'antique', 'antiquity', 'archaism', 'artifact', 'cave painting', 'eolith', 'fossil', 'mezzolith', 'microlith', 'neolith', 'paleolith'],
    'petrify': ['alarm', 'amaze', 'anneal', 'appall', 'astonish', 'astound', 'awe', 'awestrike', 'bedaze', 'bedazzle', 'bemuse', 'benumb'],
    'petrifying': ['bloodcurdling', 'hair-raising', 'hardening', 'indurative', 'paralyzing', 'petrifactive', 'stunning', 'stupefying', 'terrifying', 'terror', 'terror-bearing', 'terror-breathing'],
    'petrol': ['avgas', 'benzine', 'coal oil', 'crude', 'crude oil', 'electricity', 'ethyl', 'ethyl gas', 'fossil oil', 'gas', 'gasoline', 'high-octane gas'],
    'petroleum': ['avgas', 'benzine', 'coal oil', 'crude', 'crude oil', 'electricity', 'ethyl', 'ethyl gas', 'fossil oil', 'gas', 'gasoline', 'high-octane gas'],
    'petticoat': ['balmoral', 'skivvies', 'bloomers', 'body stocking', 'brassiere', 'briefs', 'bustle', 'camisole', 'chemise', 'combination', 'corset', 'crinoline'],
    'pettifog': ['argue', 'argufy', 'bandy words', 'bicker', 'carp', 'catch at straws', 'cavil', 'choplogic', 'contend', 'contest', 'cross swords', 'cut and thrust'],
    'pettifogger': ['philadelphia lawyer', 'ambulance chaser', 'belittler', 'bunco artist', 'bunco steerer', 'captious critic', 'cardsharp', 'cardsharper', 'carper', 'carpetbagger', 'caviler', 'censor'],
    'pettifoggery': ['artifice', 'bickering', 'boggling', 'captiousness', 'caviling', 'chicane', 'chicanery', 'collusion', 'connivance', 'connivery', 'conspiracy', 'covin'],
    'pettiness': ['abjectness', 'abominableness', 'atrociousness', 'authoritarianism', 'baseness', 'beggarliness', 'bigotry', 'blind side', 'blind spot', 'blinders', 'closed mind', 'contemptibility'],
    'petting': ['amorous dalliance', 'billing and cooing', 'bundling', 'caressing', 'cuddling', 'dalliance', 'feeling', 'fingering', 'fondling', 'friction', 'frottage', 'handling'],
    'petty': ['mickey mouse', 'abject', 'abominable', 'arrant', 'atrocious', 'authoritarian', 'base', 'beggarly', 'bickering', 'bigot', 'bigoted', 'borne'],
    'petulance': ['faustianism', 'arbitrariness', 'beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'caprice', 'capriciousness', 'cold comfort', 'complaining'],
    'petulant': ['jeremianic', 'arbitrary', 'bad-tempered', 'beefing', 'bellyaching', 'bilious', 'bitching', 'cantankerous', 'capricious', 'captious', 'catty', 'choleric'],
    'pew': ['amen corner', 'anxious bench', 'anxious seat', 'booth', 'box', 'cavity', 'cell', 'cellule', 'chamber', 'compartment', 'crib', 'crypt'],
    'pewter': ['aureate', 'brass', 'brassy', 'brazen', 'bronze', 'bronzy', 'copper', 'coppery', 'cupreous', 'cuprous', 'ferrous', 'ferruginous'],
    'peyote': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'diethyltryptamine', 'dimethyltryptamine', 'gage'],
    'phaethon': ['agdistis', 'amen-ra', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres'],
    'phalanx': ['kp', 'age group', 'army', 'army group', 'band', 'battalion', 'battery', 'battle group', 'bevy', 'body', 'brigade', 'bunch'],
    'phallus': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'phantasm': ['masan', 'apparition', 'appearance', 'astral', 'astral spirit', 'bamboozlement', 'banshee', 'befooling', 'bluffing', 'brainchild', 'bubble', 'calculated deception'],
    'phantasmagoria': ['apparition', 'appearance', 'cosmorama', 'cyclorama', 'diorama', 'display', 'eidolon', 'exhibit', 'exhibition', 'exposition', 'fantasy', 'figure'],
    'phantasmagoric': ['barmecidal', 'barmecide', 'airy', 'apparent', 'apparitional', 'autistic', 'chimeric', 'deceptive', 'delusional', 'delusionary', 'delusive', 'delusory'],
    'phantasmal': ['barmecidal', 'barmecide', 'aerial', 'air-built', 'airy', 'apparent', 'apparitional', 'astral', 'autistic', 'chimeric', 'cloud-born', 'cloud-built'],
    'phantom': ['barmecidal', 'barmecide', 'dracula', 'frankenstein', 'masan', 'wolf-man', 'air', 'airy', 'airy nothing', 'apparent', 'apparition', 'apparitional'],
    'phantomlike': ['air-built', 'airy', 'astral', 'chimerical', 'cloud-built', 'dreamlike', 'ectoplasmic', 'ethereal', 'etheric', 'fanciful', 'fatuitous', 'fatuous'],
    'pharaoh': ['dalai lama', 'holy roman emperor', 'inca', 'kaiser', 'simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'ardri', 'arrogator', 'autarch', 'autocrat'],
    'pharisaic': ['pecksniffian', 'tartuffian', 'tartuffish', 'affected', 'canting', 'false', 'goody', 'goody-goody', 'holier-than-thou', 'hypocritic', 'hypocritical', 'insincere'],
    'pharisaical': ['pecksniffian', 'tartuffian', 'tartuffish', 'affected', 'canting', 'false', 'goody', 'goody-goody', 'holier-than-thou', 'hypocritic', 'hypocritical', 'insincere'],
    'pharisee': ['holy willie', 'joseph surface', 'mawworm', 'pecksniff', 'tartuffe', 'affecter', 'canter', 'canting hypocrite', 'dissembler', 'dissimulator', 'fair-weather friend', 'false friend'],
    'pharmacology': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology', 'biometrics'],
    'pharmacy': ['x ray', 'antique store', 'apothecary', 'automobile showroom', 'blood bank', 'bookstore', 'bootery', 'candy store', 'charity ward', 'chemist', 'cigar store', 'clinic'],
    'pharos': ['texas tower', 'beacon', 'belvedere', 'bench mark', 'bleachers', 'bookmark', 'bridge', 'cairn', 'catstone', 'conning tower', 'gallery', 'gazebo'],
    'pharyngeal': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation', 'back'],
    'pharynx': ['alveolar ridge', 'alveolus', 'apex', 'arytenoid cartilages', 'back', 'blade', 'dorsum', 'esophagus', 'fauces', 'goozle', 'gorge', 'gullet'],
    'phase': ['angle', 'appearance', 'aspect', 'color', 'complexion', 'condition', 'configuration', 'development', 'discontinue', 'ease off', 'effect', 'eidolon'],
    'phenobarbital': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'phenomenal': ['amazing', 'astonishing', 'astounding', 'beguiling', 'bewildering', 'bustling', 'corporeal', 'enigmatic', 'eventful', 'exceptional', 'extraordinary', 'fabulous'],
    'phenomenology': ['aesthetics', 'axiology', 'casuistry', 'cosmology', 'epistemology', 'ethics', 'first philosophy', 'gnosiology', 'logic', 'mental philosophy', 'metaphysics', 'moral philosophy'],
    'phenomenon': ['abnormality', 'actuality', 'adventure', 'amazement', 'anomaly', 'apparition', 'appearance', 'astonishing thing', 'astonishment', 'circumstance', 'curiosity', 'episode'],
    'philadelphia lawyer': ['artful dodger', 'yankee horse trader', 'ambulance chaser', 'apologist', 'arguer', 'argufier', 'casuist', 'charmer', 'controversialist', 'crafty rascal', 'debater', 'disceptator'],
    'philander': ['casanova', 'don juan', 'be promiscuous', 'cast coquettish glances', 'chase', 'chase women', 'chaser', 'commit adultery', 'coquet', 'dally', 'debauch', 'dissipate'],
    'philanderer': ['casanova', 'don juan', 'lothario', 'romeo', 'amoroso', 'beau', 'boyfriend', 'caballero', 'cavalier', 'cavaliere servente', 'chaser', 'debauchee'],
    'philanthropic': ['almsgiving', 'altruistic', 'beneficent', 'benevolent', 'bighearted', 'charitable', 'contributing', 'donating', 'eleemosynary', 'freehanded', 'freehearted', 'generous'],
    'philanthropist': ['maecenas', 'robin hood', 'santa claus', 'almoner', 'almsgiver', 'angel', 'assignor', 'awarder', 'backer', 'benefactor', 'benefactress', 'benevolist'],
    'philanthropy': ['bomfog', 'benthamism', 'christian charity', 'christian love', 'agape', 'aid', 'almsgiving', 'altruism', 'assistance', 'beneficence', 'benevolence', 'benevolent disposition'],
    'philharmonic': ['german band', 'band', 'big band', 'brass', 'brass band', 'brass choir', 'brass quintet', 'brass section', 'brasses', 'callithumpian band', 'chamber orchestra', 'combo'],
    'philippic': ['abuse', 'address', 'after-dinner speech', 'allocution', 'assailing', 'assault', 'attack', 'berating', 'bitter words', 'blackening', 'chalk talk', 'contumely'],
    'philistine': ['babbitt', 'boeotian', 'barbarian', 'boeotian', 'boob', 'boor', 'boorish', 'boring', 'bourgeois', 'capitalist', 'clown', 'commercial'],
    'philological': ['descriptive', 'glottochronological', 'grammatic', 'graphemic', 'lexicographic', 'lexicological', 'lexicostatistical', 'lingual', 'linguistic', 'metalinguistic', 'morphological', 'morphophonemic'],
    'philologist': ['academician', 'bookman', 'classicist', 'clerk', 'colossus of knowledge', 'dialectician', 'etymologer', 'etymologist', 'genius', 'giant of learning', 'glossarist', 'glossographer'],
    'philology': ['bowwow theory', 'comparative linguistics', 'derivation', 'descriptive linguistics', 'dialectology', 'dingdong theory', 'etymology', 'glossematics', 'glossology', 'glottochronology', 'glottology', 'grammar'],
    'philosopher': ['abelard', 'albertus magnus', 'albinus', 'alexander', 'anaxagoras', 'anselm', 'averroist', 'bacon', 'berkeleian', 'berkeley', 'boethius', 'bonaventure'],
    'philosophical': ['spartan', 'abstract', 'accepting', 'armed with patience', 'balanced', 'calm', 'cogitative', 'commonsense', 'composed', 'contemplative', 'cool', 'coolheaded'],
    'philosophy': ['aristotelianism', 'berkeleianism', 'bradleianism', 'buddha-like composure', 'cynicism', 'cyrenaic hedonism', 'cyrenaicism', 'epicureanism', 'fichteanism', 'hegelianism', 'heideggerianism', 'heracliteanism'],
    'phlebitis': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis'],
    'phlebotomy': ['aspiration', 'bleeding', 'bloodletting', 'broaching', 'cupping', 'drafting', 'drainage', 'draining', 'drawing', 'emptying', 'leeching', 'milking'],
    'phlegm': ['acedia', 'aloofness', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'boredom', 'calmness', 'chyle', 'colostrum'],
    'phlegmatic': ['laodicean', 'olympian', 'abeyant', 'aloof', 'ambivert', 'apathetic', 'benumbed', 'blah', 'blase', 'bored', 'calm', 'careless'],
    'phobia': ['abhorrence', 'abject fear', 'abomination', 'accident neurosis', 'affright', 'alarm', 'anathema', 'antipathy', 'anxiety hysteria', 'anxiety neurosis', 'apprehension', 'association neurosis'],
    'phoebe': ['artemis', 'ashtoreth', 'astarte', 'cynthia', 'diana', 'hecate', 'hekate', 'little phoebe', 'luna', 'pentateuch', 'selene', 'cinque'],
    'phoebus': ['agdistis', 'amen-ra', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres'],
    'phonate': ['articulate', 'breathe', 'chime', 'chorus', 'come out with', 'communicate', 'convey', 'deliver', 'disclose', 'emit', 'enunciate', 'express'],
    'phone': ['allophone', 'alveolar', 'amplitude', 'apico-alveolar', 'apico-dental', 'articulation', 'aspiration', 'assimilation', 'auditory effect', 'auditory phenomenon', 'bilabial', 'buzz'],
    'phone book': ['baedeker', 'yellow pages', 'area code', 'atlas', 'bibliography', 'business directory', 'calendar', 'casebook', 'catalog', 'catalogue raisonne', 'checklist', 'city directory'],
    'phoneme': ['allophone', 'alveolar', 'apico-alveolar', 'apico-dental', 'articulation', 'aspiration', 'assimilation', 'bilabial', 'cacuminal', 'cerebral', 'check', 'consonant'],
    'phonemic': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'phonetic': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'arrowhead', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad'],
    'phonetician': ['dialectician', 'etymologer', 'etymologist', 'glossarist', 'glossographer', 'grammarian', 'grammaticaster', 'grammatist', 'lexicographer', 'lexicologist', 'linguist', 'linguistic scholar'],
    'phonetics': ['ablaut', 'acoustic phonetics', 'articulatory phonetics', 'audiometer', 'auriscope', 'auriscopy', 'betacism', 'bowwow theory', 'cacography', 'comparative linguistics', 'derivation', 'descriptive linguistics'],
    'phoney': ['artificial', 'bogus', 'charlatan', 'counterfeit', 'counterfeiter', 'deceitful', 'deceiver', 'dishonest', 'double-dealer', 'ersatz', 'factitious', 'fake'],
    'phonic': ['accented', 'acoustic', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'audible', 'audile', 'audio', 'auditory'],
    'phonograph': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'phonograph record': ['bulletin board', 'card', 'cartridge', 'cassette', 'catalog card', 'disc', 'electrical transcription', 'file', 'filing card', 'film', 'index card', 'library catalog'],
    'phonology': ['ablaut', 'acoustic phonetics', 'articulatory phonetics', 'betacism', 'bowwow theory', 'comparative linguistics', 'derivation', 'descriptive grammar', 'descriptive linguistics', 'dialectology', 'dingdong theory', 'etymology'],
    'phony': ['joseph surface', 'pecksniff', 'tartuffe', 'actor', 'affected', 'affecter', 'agent', 'alike', 'alternate', 'alternative', 'analogy', 'ape'],
    'phosphor': ['autoluminescence', 'bioluminescence', 'candle fly', 'cathode luminescence', 'chemicoluminescence', 'chemiluminescence', 'corposant', 'crystalloluminescence', 'double corposant', 'electroluminescence', 'fata morgana', 'fire beetle'],
    'phosphorescence': ['autoluminescence', 'bioluminescence', 'cathode luminescence', 'chemicoluminescence', 'chemiluminescence', 'corposant', 'crystalloluminescence', 'double corposant', 'electroluminescence', 'fata morgana', 'fluorescence', 'fox fire'],
    'photo': ['telephoto', 'wirephoto', 'aerial photograph', 'black-and-white photograph', 'candid photograph', 'cheesecake', 'chronophotograph', 'color photograph', 'color print', 'diapositive', 'heliochrome', 'heliograph'],
    'photo offset': ['albertype', 'book printing', 'chromotypography', 'chromotypy', 'chromoxylography', 'collotype', 'color printing', 'electronography', 'electrostatic printing', 'graphic arts', 'gravure', 'halftone engraving'],
    'photocopy': ['ditto copy', 'photostat', 'xerox', 'xerox copy', 'blowup', 'blueprint', 'contact print', 'contact printing', 'cyanotype', 'enlargement', 'glossy', 'hectograph copy'],
    'photoelectric': ['battery-powered', 'cathodic', 'dynamoelectric', 'electric', 'electric-powered', 'electrified', 'electrifying', 'electrochemical', 'electrodynamic', 'electrokinetic', 'electromechanical', 'electrometric'],
    'photoemission': ['if video signal', 'tv band', 'anode ray', 'audio signal', 'beam', 'canal ray', 'cathode glow', 'cathode ray', 'collision emission', 'electron beam', 'electron emission', 'electron ray'],
    'photoengraving': ['albertype', 'aquatint', 'book printing', 'cerography', 'chalcography', 'chromotypography', 'chromotypy', 'chromoxylography', 'collotype', 'color printing', 'crayon engraving', 'cribbling'],
    'photogenic': ['autoluminescent', 'bioluminescent', 'chemicoluminescent', 'chemiluminescent', 'electroluminescent', 'fluorescent', 'luminal', 'luminescent', 'noctilucent', 'panchromatic', 'phosphorescent', 'photo'],
    'photograph': ['ditto copy', 'photostat', 'telephoto', 'wirephoto', 'x-ray', 'xerox', 'xerox copy', 'abstract', 'abstraction', 'aerial photograph', 'altarpiece', 'black-and-white photograph'],
    'photographic': ['accurate', 'cinematic', 'detailed', 'exact', 'faithful', 'filmic', 'freehand', 'graphic', 'lifelike', 'monochrome', 'natural', 'painty'],
    'photographic equipment': ['burning-in tool', 'changing bag', 'closeup lens', 'darkroom', 'developing tank', 'diaphragm', 'dodging tool', 'dryer', 'drying blotter', 'easel', 'electronic-flash unit', 'enlarger'],
    'photography': ['x-ray photography', 'abstract art', 'aerial photography', 'aerophotography', 'albertype', 'art', 'art form', 'artist', 'arts and crafts', 'arts of design', 'astrophotography', 'book printing'],
    'photometry': ['actinology', 'actinometry', 'aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology'],
    'photon': ['asa scale', 'british candle', 'hefner candle', 'kern', 'nmr', 'scheiner scale', 'x ray', 'actinic ray', 'actinism', 'alpha particle', 'antibaryon', 'antilepton'],
    'photoplay': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'black-and-white film', 'cartoon', 'chiller', 'cine', 'cinema', 'color film', 'creepie'],
    'photostat': ['ditto copy', 'x-ray', 'xerox', 'xerox copy', 'blowup', 'blueprint', 'calotype', 'capture on film', 'clone', 'contact print', 'contact printing', 'copy'],
    'phrase': ['parthian shot', 'adage', 'address', 'adjectival phrase', 'affirmation', 'allegation', 'ana', 'anacrusis', 'analects', 'answer', 'aphorism', 'apostrophe'],
    'phraseology': ['argot', 'cant', 'choice of words', 'composition', 'dialect', 'diction', 'expression', 'formulation', 'gibberish', 'gobbledygook', 'grammar', 'idiom'],
    'phrasing': ['adaptation', 'arrangement', 'choice of words', 'composition', 'dialect', 'diction', 'expression', 'formulation', 'grammar', 'harmonization', 'idiom', 'instrumentation'],
    'phrenetic': ['dionysiac', 'amok', 'at fever pitch', 'bacchic', 'berserk', 'corybantic', 'delirious', 'desperate', 'fanatical', 'febrile', 'feverish', 'frantic'],
    'phylactery': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'amulet', 'ark', 'asperger', 'asperges', 'aspergillum', 'bambino'],
    'phylogenetic': ['advancing', 'bradytelic', 'clannish', 'developing', 'diphyletic', 'direct', 'ethnic', 'evolutional', 'evolutionist', 'evolutionistic', 'evolving', 'family'],
    'phylum': ['affiliation', 'antonomasia', 'apparentation', 'binomial nomenclature', 'biological classification', 'biosystematics', 'biosystematy', 'biotype', 'birth', 'blood', 'bloodline', 'branch'],
    'physic': ['medicaid', 'medicare', 'newtonian physics', 'acoustics', 'aerophysics', 'aerospace medicine', 'aperient', 'applied physics', 'astrophysics', 'balm', 'balsam', 'basic conductor physics'],
    'physical': ['adamic', 'circean', 'actual', 'aerophysical', 'animal', 'animalistic', 'astrophysical', 'atavistic', 'beastlike', 'beastly', 'bestial', 'bodily'],
    'physical education': ['athletics', 'breather', 'calisthenics', 'constitutional', 'daily dozen', 'drill', 'eurythmics', 'exercise', 'exercising', 'gymnastic exercises', 'gymnastics', 'isometrics'],
    'physician': ['doctor of medicine', 'gp', 'md', 'md', 'allopath', 'allopathist', 'attending physician', 'bones', 'coroner', 'country doctor', 'croaker', 'doc'],
    'physiography': ['cosmical geology', 'dynamic geology', 'geodesy', 'geodetics', 'geodynamics', 'geognosy', 'geographics', 'geography', 'geological chemistry', 'geological engineering', 'geology', 'geomorphogeny'],
    'physiology': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology', 'biometrics'],
    'physiotherapy': ['metrazol therapy', 'x-ray therapy', 'actinotherapy', 'aerosol therapy', 'aerotherapeutics', 'aerotherapy', 'arsenotherapy', 'autoserum therapy', 'bacterial therapy', 'bacteriotherapy', 'bibliotherapy', 'biotherapy'],
    'physique': ['anatomy', 'architectonics', 'architecture', 'arrangement', 'beef', 'beefiness', 'bod', 'body', 'body-build', 'bones', 'brand', 'brawn'],
    'phytology': ['algology', 'aquiculture', 'botany', 'bryology', 'dendrology', 'fungology', 'hydroponics', 'mycology', 'paleobotany', 'phycology', 'physiological botany', 'phytobiology'],
    'pi': ['ascender', 'back', 'ball up', 'bastard type', 'beard', 'belly', 'bevel', 'black letter', 'body', 'bollix up', 'cap', 'capital'],
    'pianissimo': ['a cappella', 'a la sourdine', 'abbandono', 'accrescendo', 'adagietto', 'adagio', 'affettuoso', 'agilmente', 'agitato', 'allegretto', 'allegro', 'amabile'],
    'piano': ['klavier', 'steinway', 'a cappella', 'a la sourdine', 'abbandono', 'accrescendo', 'adagietto', 'adagio', 'affettuoso', 'agilmente', 'agitato', 'allegretto'],
    'pianoforte': ['klavier', 'steinway', 'baby grand', 'cembalo', 'clarichord', 'clavicembalo', 'clavichord', 'clavicittern', 'clavicymbal', 'clavicytherium', 'clavier', 'concert grand'],
    'piazza': ['agora', 'campo', 'forum', 'gallery', 'lanai', 'market', 'market cross', 'marketplace', 'mart', 'patio', 'place', 'plaza'],
    'pica': ['analgesia', 'anesthesia', 'anxiety equivalent', 'ascender', 'back', 'bastard type', 'beard', 'belly', 'bevel', 'black letter', 'body', 'cap'],
    'picayune': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'bagatelle', 'bauble', 'bean', 'bibelot', 'bickering', 'bit', 'brass farthing'],
    'piccolo': ['english horn', 'pandean pipe', 'aulos', 'basset horn', 'basset oboe', 'bassoon', 'block flute', 'bombard', 'bourdon', 'cello', 'claribel', 'clarinet'],
    'pick': ['abuse', 'accelerate', 'accost', 'accumulate', 'acquire', 'adz', 'aggravate', 'alternativity', 'amass', 'annoy', 'apprehend', 'arrest'],
    'pick off': ['charge', 'cock', 'detonate', 'discharge', 'drop', 'eject', 'fell', 'fire', 'fire off', 'gun', 'gun for', 'hit'],
    'pick out': ['abscind', 'abstract', 'address to', 'advert to', 'allude to', 'amputate', 'analyze', 'annihilate', 'assign', 'avulse', 'ban', 'bar'],
    'pick to pieces': ['atomize', 'break to pieces', 'carp', 'catch at straws', 'cavil', 'cleave', 'cut up', 'defoliate', 'demolish', 'denude', 'disassemble', 'disintegrate'],
    'pick up': ['accumulate', 'acquire', 'advance', 'amass', 'ameliorate', 'amend', 'animate', 'annex', 'apprehend', 'arrest', 'assemble', 'book'],
    'picked': ['accepted', 'adopted', 'appointed', 'approved', 'best', 'carried', 'champion', 'choice', 'chosen', 'designated', 'elect', 'elected'],
    'picker': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'banjoist', 'coffee-planter', 'collective farm worker', 'crofter', 'cropper', 'cultivator', 'dirt farmer'],
    'picket': ['argus', 'charley', 'advance guard', 'airplane spotter', 'anchor', 'armed guard', 'bank guard', 'bar', 'beef', 'bind', 'bitch', 'blockade'],
    'picketing': ['beef', 'bitch', 'boycott', 'challenge', 'complaint', 'compunction', 'confinement', 'demonstration', 'demur', 'demurrer', 'dismemberment', 'estrapade'],
    'pickings': ['blackmail', 'boodle', 'booty', 'capital gains', 'cleanup', 'clear profit', 'dividends', 'earnings', 'filthy lucre', 'gain', 'gains', 'get'],
    'pickle': ['acid', 'acidulant', 'anhydrate', 'baffle', 'bafflement', 'bearings', 'bewilderment', 'bind', 'blast-freeze', 'booze up', 'boozify', 'bother'],
    'pickled': ['acerb', 'acerbate', 'acerbic', 'acescent', 'afflicted', 'bent', 'boiled', 'bombed', 'boozy', 'brackish', 'briny', 'canned'],
    'pickling': ['anhydration', 'blast-freezing', 'bottling', 'brining', 'canning', 'corning', 'curing', 'dehydration', 'desiccation', 'dry-curing', 'drying', 'embalming'],
    'pickup': ['gramophone', 'great leap forward', 'jezebel', 'pa', 'pa system', 'sunday drive', 'victrola', 'accelerando', 'acceleration', 'acquaintance', 'advance', 'advancement'],
    'picky': ['censorious', 'choicy', 'choosy', 'conscientious', 'critical', 'dainty', 'discriminating', 'discriminative', 'exacting', 'fastidious', 'finical', 'finicking'],
    'picnic': ['cadmean victory', 'ko', 'mardi gras', 'pyrrhic victory', 'saturnalia', 'tv dinner', 'action', 'agonizing', 'agony', 'alfresco meal', 'arduous', 'ascendancy'],
    'picot': ['vandyke', 'blaze', 'chop', 'crenellate', 'crenulate', 'crimp', 'cut', 'gash', 'incise', 'indent', 'jag', 'knurl'],
    'pictogram': ['allegory', 'alphabet', 'arrowhead', 'art', 'blueprint', 'character', 'charactering', 'characterization', 'charactery', 'chart', 'choreography', 'cipher'],
    'pictograph': ['arrowhead', 'character', 'cuneiform', 'demotic character', 'determinative', 'grammalogue', 'hieratic symbol', 'hieroglyph', 'hieroglyphic', 'hieroglyphics', 'hiragana', 'ideogram'],
    'pictographic': ['abecedarian', 'allographic', 'alphabetic', 'apish', 'capital', 'delineatory', 'depictive', 'echoic', 'embodying', 'figurative', 'graphemic', 'graphic'],
    'pictorial': ['annual', 'apish', 'bimonthly', 'biweekly', 'clear', 'daily', 'daybook', 'delineatory', 'depictive', 'diary', 'echoic', 'embodying'],
    'picture': ['crt spot', 'cinemascope', 'cinerama', 'dm display', 'doppler signal', 'if signal', 'im display', 'rf echoes', 'technicolor', 'telephoto', 'vorstellung', 'western'],
    'picture show': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'black-and-white film', 'cartoon', 'chiller', 'cine', 'cinema', 'color film', 'creepie'],
    'picturesque': ['arabesque', 'attractive', 'baroque', 'busy', 'charming', 'chichi', 'colorful', 'delightful', 'elaborate', 'elegant', 'fancy', 'fetching'],
    'picturing': ['vorstellung', 'concept', 'conception', 'conceptualization', 'eidetic image', 'envisaging', 'envisioning', 'image', 'imagery', 'imagery study', 'imaging', 'imagism'],
    'picturization': ['acrylic painting', 'alphabet', 'art', 'blueprint', 'charactering', 'characterization', 'chart', 'choreography', 'coloring', 'conventional representation', 'dance notation', 'delineation'],
    'piddle': ['beguile the time', 'burn daylight', 'consume time', 'coquet', 'dabble', 'dally', 'dawdle', 'diddle', 'dillydally', 'doodle', 'fiddle', 'fiddle with'],
    'piddling': ['mickey mouse', 'cheeseparing', 'chinchy', 'chintzy', 'cramped', 'dinky', 'exiguous', 'half-pint', 'infrequent', 'jerkwater', 'knee-high', 'limited'],
    'pie': ['danish pastry', 'deutschmark', 'french pastry', 'mark', 'reichsmark', 'afghani', 'anna', 'baht', 'baklava', 'blintz', 'breeze', 'cent'],
    'pie eyed': ['afflicted', 'bent', 'boiled', 'bombed', 'boozy', 'canned', 'cockeyed', 'cockeyed drunk', 'crocked', 'crocko', 'elevated', 'fried'],
    'piebald': ['bay', 'bayard', 'buckskin', 'calico', 'calico pony', 'chestnut', 'clouded', 'dapple', 'dapple-gray', 'dappled', 'dun', 'gray'],
    'piece': ['grand guignol', 'nachtmusik', 'passion play', 'tom show', 'absolute music', 'actor', 'adaptation', 'aesthetic distance', 'air', 'air varie', 'aleatory', 'aleatory music'],
    'piece de resistance': ['boil', 'broil', 'casserole', 'champion', 'choice', 'chosen', 'course', 'cover', 'cream', 'culinary masterpiece', 'culinary preparation', 'dish'],
    'piece together': ['accouple', 'accumulate', 'agglutinate', 'amass', 'articulate', 'assemble', 'associate', 'band', 'bond', 'bracket', 'bridge', 'bridge over'],
    'piecemeal': ['adrift', 'apart', 'apart from', 'aside from', 'asunder', 'away from', 'bit by bit', 'by degrees', 'by inches', 'by inchmeal', 'by snatches', 'disjointed'],
    'pier': ['abutment', 'anchorage', 'anchorage ground', 'arc-boutant', 'arcade', 'atlas', 'baluster', 'balustrade', 'banister', 'bank', 'base', 'basin'],
    'pierce': ['abrade', 'affect', 'afflict', 'aggrieve', 'agonize', 'ail', 'anguish', 'auger', 'barb the dart', 'bark', 'bayonet', 'benumb'],
    'piercing': ['siberian', 'absorbing', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'acupunctuation'],
    'pierian': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pindaric', 'theocritean', 'bardic', 'bucolic', 'didactic', 'dithyrambic', 'dramatic'],
    'pietistic': ['christian', 'christianlike', 'christianly', 'tartuffian', 'tartuffish', 'adoring', 'affected', 'assured', 'believing', 'canting', 'certain', 'confident'],
    'piety': ['tartuffery', 'tartuffism', 'affectation', 'affection', 'allegiance', 'ardor', 'cant', 'dedication', 'deference', 'devotedness', 'devotion', 'devoutness'],
    'piffle': ['babble', 'balderdash', 'baloney', 'bilge', 'blabber', 'blah', 'blah-blah', 'blather', 'blatherskite', 'bop', 'bosh', 'bull'],
    'piffling': ['mickey mouse', 'jerkwater', 'measly', 'niggling', 'one-horse', 'peddling', 'pettifogging', 'petty', 'picayune', 'picayunish', 'piddling', 'pimping'],
    'pig': ['angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'dogberry', 'indian buffalo', 'john law', 'kodiak bear', 'virginia deer', 'aardvark', 'aardwolf', 'alpaca'],
    'pigeon': ['cornish hen', 'avifauna', 'babe', 'baby bird', 'bamboozle', 'beat', 'beguile', 'beguile of', 'betray', 'bilk', 'bird', 'bird of jove'],
    'pigeon toed': ['bandy', 'bandy-legged', 'blemished', 'bloated', 'bowlegged', 'club-footed', 'defaced', 'deformed', 'disfigured', 'dwarfed', 'flatfooted', 'grotesque'],
    'pigeonhearted': ['afraid', 'chicken', 'chickenhearted', 'coward', 'cowardly', 'cowed', 'daunted', 'dismayed', 'fainthearted', 'fearful', 'funking', 'funky'],
    'pigeonhole': ['adjourn', 'air hole', 'alphabetize', 'analyze', 'armhole', 'arrange', 'assort', 'bibliography', 'blood', 'blowhole', 'book', 'bracket'],
    'pigeonholed': ['abandoned', 'assorted', 'cataloged', 'classified', 'deserted', 'disregarded', 'filed', 'graded', 'grouped', 'half-done', 'hierarchic', 'ignored'],
    'pigeonholing': ['analysis', 'arrangement', 'cataloging', 'categorization', 'classification', 'codification', 'division', 'filing', 'grading', 'grouping', 'indexing', 'placement'],
    'piggish': ['apician', 'a hog for', 'acquisitive', 'all-devouring', 'asinine', 'avaricious', 'avid', 'beastly', 'bolting', 'bottomless', 'bovid', 'bovine'],
    'piggy bank': ['fort knox', 'bank', 'bursary', 'cash register', 'cashbox', 'chest', 'coffer', 'coin box', 'depository', 'exchequer', 'fisc', 'gold depository'],
    'pigheaded': ['balking', 'balky', 'bigoted', 'bulldogged', 'bulletheaded', 'bullheaded', 'case-hardened', 'dogged', 'dogmatic', 'fanatic', 'hardheaded', 'headstrong'],
    'piglet': ['barrow', 'birdling', 'boar', 'calf', 'catling', 'chick', 'chickling', 'chicky', 'colt', 'cub', 'dogie', 'duckling'],
    'pigment': ['adrianople red', 'alice blue', 'arabian red', 'argos brown', 'bordeaux', 'brunswick black', 'brunswick blue', 'burgundy', 'capri blue', 'cassel yellow', 'chinese blue', 'chinese white'],
    'pigtail': ['braid', 'brush', 'bun', 'cauda', 'caudal appendage', 'caudation', 'cavendish', 'chaw', 'chew', 'chewing tobacco', 'chignon', 'coil'],
    'pike': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'piker': ['arab', 'adventurer', 'beach bum', 'beachcomber', 'beggar', 'betting ring', 'bettor', 'bo', 'boneshaker', 'bum', 'bummer', 'cardshark'],
    'pilaster': ['antenna tower', 'arcade', 'atlas', 'baluster', 'balustrade', 'banister', 'barbican', 'base', 'belfry', 'bell tower', 'campanile', 'caryatid'],
    'pile': ['abscess', 'abundance', 'accumulate', 'accumulation', 'agglomeration', 'aggregate', 'aggregation', 'amass', 'amassment', 'angina', 'angina pectoris', 'anthill'],
    'pile drive': ['assault', 'bear', 'bear upon', 'boost', 'buck', 'bull', 'bulldoze', 'bump', 'bump against', 'bunt', 'butt', 'butt against'],
    'pile it on': ['barnumize', 'aggrandize', 'amplify', 'ballyhoo', 'blow', 'bombast', 'build up', 'burlesque', 'caricature', 'carry too far', 'draw the longbow', 'exaggerate'],
    'pile up': ['accumulate', 'amass', 'backlog', 'bank', 'bank up', 'beach', 'cast away', 'collect', 'cumulate', 'drift', 'garner', 'garner up'],
    'pileup': ['accident', 'blow', 'calamity', 'casualty', 'cataclysm', 'catastrophe', 'collision', 'contretemps', 'crack-up', 'crash', 'disaster', 'grief'],
    'pilfer': ['abstract', 'abuse', 'and', 'annex', 'appropriate', 'bag', 'befoul', 'boost', 'borrow', 'convert', 'cop', 'crib'],
    'pilfering': ['abstraction', 'abuse', 'abuse of office', 'annexation', 'appropriation', 'befoulment', 'boosting', 'conversion', 'conveyance', 'corrupt administration', 'debasement', 'defalcation'],
    'pilgrim': ['abbacomes', 'abbot', 'adventurer', 'alpinist', 'ascetic', 'astronaut', 'beadsman', 'brother', 'caloyer', 'camper', 'celibate', 'cenobite'],
    'pilgrimage': ['adventure', 'campaign', 'circuit', 'course', 'cruise', 'crusade', 'emprise', 'excursion', 'expedition', 'exploration', 'fare', 'globe-trot'],
    'pill': ['iud', 'sob', 'bag', 'bastard', 'birth control device', 'bolus', 'bore', 'bugger', 'butt', 'buttonholer', 'capsule', 'condom'],
    'pillage': ['abduct', 'appropriate', 'arrogate', 'assault', 'attack', 'banditry', 'barbarize', 'batter', 'booty', 'brigandage', 'brigandism', 'brutalize'],
    'pillaging': ['assault', 'attack', 'banditry', 'battering', 'brigandage', 'brigandism', 'butchery', 'depredation', 'despoiling', 'despoilment', 'despoliation', 'direption'],
    'pillar': ['antenna tower', 'arcade', 'arch', 'atlas', 'backbone', 'baluster', 'balustrade', 'banister', 'barbican', 'barrel', 'barrow', 'base'],
    'pillar of society': ['christian', 'establishment', 'vip', 'baron', 'big gun', 'big man', 'big name', 'bigwig', 'brass', 'brass hat', 'burgher', 'celebrity'],
    'pillbox': ['acropolis', 'bastion', 'beachhead', 'blockhouse', 'bridgehead', 'bunker', 'castle', 'citadel', 'donjon', 'fasthold', 'fastness', 'fort'],
    'pillhead': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser'],
    'pillory': ['oregon boat', 'attaint', 'bespatter', 'bilbo', 'blacken', 'blot', 'blow upon', 'bond', 'bonds', 'brand', 'branks', 'bridle'],
    'pillow': ['afford support', 'air mattress', 'back', 'back up', 'bear', 'bear up', 'bedding', 'blubber', 'bolster', 'bolster up', 'brace', 'breeze'],
    'pillowcase': ['afghan', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedsheet', 'bedspread', 'blanket', 'buffalo robe', 'case', 'clothes', 'comfort'],
    'pilose': ['bristly', 'bushy', 'cirrose', 'fleecy', 'flocculent', 'furry', 'fuzzy', 'hairy', 'hirsute', 'hispid', 'lanate', 'matted'],
    'pilot': ['gyropilot', 'aegis', 'aerialist', 'aeronaut', 'aeroplaner', 'aeroplanist', 'agent', 'air pilot', 'airman', 'airplanist', 'arm guard', 'astronaut'],
    'pilotage': ['admission', 'admission fee', 'aeronautics', 'air service', 'airline', 'anchorage', 'aspect', 'astronautics', 'astronavigation', 'attitude', 'authority', 'aviation'],
    'pimp': ['backslider', 'bad egg', 'bad lot', 'bawd', 'betrayer', 'black sheep', 'bully', 'cadet', 'canary', 'degenerate', 'fallen angel', 'fancy man'],
    'pimping': ['mickey mouse', 'harlotry', 'measly', 'niggling', 'paltry', 'pandering', 'peddling', 'piddling', 'piffling', 'prostitution', 'solicitation', 'soliciting'],
    'pimple': ['abscess', 'aposteme', 'bed sore', 'birthmark', 'blackhead', 'blain', 'bleb', 'blemish', 'blister', 'boil', 'boss', 'bubo'],
    'pimply': ['blemished', 'broken', 'bumpy', 'checked', 'choppy', 'cicatrized', 'coarse', 'coarse-grained', 'corrugated', 'cracked', 'crazed', 'cross-grained'],
    'pin': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'ankle', 'anklet', 'arbor', 'armlet', 'armory', 'articulate', 'axis'],
    'pin down': ['allocate', 'anchor', 'assign', 'balance', 'ballast', 'bind', 'bridle', 'chain', 'collocate', 'counterbalance', 'denominate', 'deploy'],
    'pin on': ['account for', 'accredit with', 'accrete to', 'accuse', 'acknowledge', 'allege', 'apply to', 'arraign', 'article', 'ascribe to', 'assign to', 'attach to'],
    'pinball': ['bingo', 'card games', 'chuck and toss', 'chuck farthing', 'chuck-a-luck', 'crack-loo', 'crap game', 'crap shooting', 'craps', 'fan-tan', 'hazard', 'horse racing'],
    'pincers': ['alum', 'aspirator', 'astringent', 'clamp', 'claws', 'clutches', 'compressor', 'constrictor', 'contractor', 'corkscrew', 'crowbar', 'digits'],
    'pinch': ['abstract', 'ace', 'acute pain', 'afflict', 'agonize', 'ail', 'alternate', 'alternative', 'and', 'annex', 'apprehend', 'apprehension'],
    'pinch bar': ['bar', 'beam', 'boom', 'cant hook', 'claw bar', 'crank', 'crow', 'crowbar', 'handspike', 'iron crow', 'jimmy', 'lever'],
    'pinch hit': ['act for', 'answer for', 'appear for', 'back up', 'change places with', 'commission', 'crowd out', 'cut out', 'deputize', 'displace', 'double for', 'fill in for'],
    'pinch hitter': ['advocate', 'agent', 'alter ego', 'alternate', 'alternative', 'amicus curiae', 'analogy', 'attorney', 'backup', 'backup man', 'champion', 'change'],
    'pinchbeck': ['affected', 'apocryphal', 'artificial', 'assumed', 'bastard', 'bogus', 'bravery', 'brummagem', 'cheat', 'chiffon', 'clinquant', 'colorable'],
    'pinched': ['attenuated', 'badly off', 'cadaverous', 'careworn', 'clamped', 'compressed', 'concentrated', 'condensed', 'consolidated', 'constricted', 'contracted', 'corpselike'],
    'pinching': ['siberian', 'abstraction', 'algid', 'annexation', 'appropriation', 'arctic', 'avaricious', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak'],
    'pindling': ['cramped', 'dinky', 'exiguous', 'fretful', 'half-pint', 'huffy', 'knee-high', 'limited', 'little', 'one-horse', 'peevish', 'petite'],
    'pine': ['ache', 'ache for', 'agonize', 'be dying for', 'be hurting for', 'bleed', 'break', 'brood', 'brood over', 'cave in', 'clamor for', 'collapse'],
    'pine barrens': ['afforestation', 'arboretum', 'boondocks', 'bush', 'bushveld', 'chase', 'climax forest', 'cloud forest', 'dendrology', 'forest', 'forest land', 'forest preserve'],
    'pine cone': ['ament', 'capitulum', 'catkin', 'complex cone', 'cone', 'conelet', 'conoid', 'cop', 'cornet', 'corymb', 'cyme', 'funnel'],
    'pinhead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'beetleheaded', 'blockhead', 'blockheaded', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead'],
    'pinhole': ['air hole', 'armhole', 'blowhole', 'bullet-hole', 'bunghole', 'cringle', 'deadeye', 'eye', 'eyelet', 'gasket', 'grommet', 'guide'],
    'pining': ['heimweh', 'aching', 'agony', 'anguish', 'bowed-down', 'care', 'carking care', 'cast down', 'coming apart', 'cracking', 'crumbling', 'dashed'],
    'pinion': ['anchor', 'appendage', 'arm', 'bind', 'bough', 'branch', 'bridle', 'chain', 'crest', 'enchain', 'entrammel', 'fasten'],
    'pink': ['bolshevik', 'india pink', 'jacobin', 'vandyke', 'wobbly', 'acme', 'acme of perfection', 'anarchist', 'anarchistic', 'anarcho-syndicalist', 'annatto', 'auger'],
    'pink eye': ['amaurosis', 'blepharitis', 'cataract', 'choroiditis', 'conjunctivitis', 'cross-eye', 'defective vision', 'detached retina', 'esotropia', 'eye defect', 'glaucoma', 'gutta serena'],
    'pink slip': ['cashiering', 'conge', 'deposal', 'discharge', 'disemployment', 'dismissal', 'displacing', 'drumming out', 'firing', 'forced separation', 'furloughing', 'layoff'],
    'pinko': ['bolshevik', 'jacobin', 'wobbly', 'anarchist', 'anarcho-syndicalist', 'extreme left-winger', 'extremist', 'left-wing extremist', 'lunatic fringe', 'mild radical', 'nihilist', 'parlor bolshevik'],
    'pinnacle': ['acme', 'acme of perfection', 'all', 'antenna tower', 'apex', 'apogee', 'barbican', 'belfry', 'bell tower', 'brow', 'campanile', 'cap'],
    'pinpoint': ['abode', 'account for', 'accredit with', 'accrete to', 'acknowledge', 'allocate', 'apply to', 'area', 'ascribe to', 'assign', 'assign to', 'attach to'],
    'pinpointing': ['allocation', 'assignment', 'automatic tracking', 'collocation', 'data transmission', 'deployment', 'deposit', 'deposition', 'disposition', 'emplacement', 'flector tuning', 'lading'],
    'pinprick': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'bagatelle', 'bauble', 'bean', 'bibelot', 'bit', 'brass farthing', 'button'],
    'pins and needles': ['agitation', 'all-overs', 'analgesia', 'anesthesia', 'angst', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat', 'anxiousness'],
    'pint sized': ['cramped', 'dinky', 'exiguous', 'half-pint', 'knee-high', 'limited', 'little', 'one-horse', 'petite', 'piddling', 'pindling', 'poky'],
    'pintle': ['arbor', 'axis', 'axle', 'axle bar', 'axle shaft', 'axle spindle', 'axle-tree', 'distaff', 'fulcrum', 'gimbal', 'gudgeon', 'hinge'],
    'pinto': ['bay', 'bayard', 'buckskin', 'calico', 'calico pony', 'chestnut', 'clouded', 'dapple', 'dapple-gray', 'dappled', 'dun', 'gray'],
    'pinup': ['miss america', 'telephoto', 'wirephoto', 'aerial photograph', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'beauty queen', 'belle', 'black-and-white photograph'],
    'pinwheel': ['agate', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble', 'blocks', 'checkerboard', 'chessboard', 'club', 'cockhorse', 'cricket bat'],
    'piny': ['arborary', 'arboreal', 'arboreous', 'arborescent', 'arboresque', 'arborical', 'arboriform', 'backwoodsman', 'briar-hopper', 'brush ape', 'bushlike', 'bushman'],
    'pioneer': ['seabee', 'actuate', 'advance guard', 'adventurer', 'airhead', 'alpinist', 'ancestor', 'announcer', 'antecedent', 'astronaut', 'avant-garde', 'battle line'],
    'pious': ['christian', 'christianlike', 'christianly', 'god-fearing', 'tartuffian', 'tartuffish', 'adoring', 'affected', 'angelic', 'assured', 'believing', 'canting'],
    'piousness': ['tartuffery', 'tartuffism', 'adoration', 'affectation', 'cant', 'churchgoing', 'conformity', 'cultism', 'devotedness', 'devotion', 'devoutness', 'dutifulness'],
    'pip': ['crt spot', 'dm display', 'doppler signal', 'hershey bar', 'if signal', 'im display', 'rf echoes', 'texas fever', 'abnormality', 'ace', 'acorn', 'acute disease'],
    'pip squeak': ['lilliputian', 'tom thumb', 'a nobody', 'a nothing', 'brownie', 'cipher', 'common man', 'dummy', 'dwarf', 'elf', 'figurehead', 'gnome'],
    'pipe': ['english horn', 'missouri meerschaum', 'pandean pipe', 'adjutage', 'aerophone', 'anthem', 'aulos', 'bagpipe', 'ballad', 'bark', 'barrel', 'basset horn'],
    'pipe dream': ['walter mitty', 'absence of mind', 'absentmindedness', 'absorption', 'abstractedness', 'abstraction', 'airy hope', 'airy nothing', 'autism', 'bad dream', 'be absent', 'bemusement'],
    'pipe roll': ['account', 'annals', 'catalog', 'chronicle', 'correspondence', 'documentation', 'history', 'inventory', 'letters', 'list', 'memorial', 'record'],
    'pipe up': ['bellow out', 'blast', 'blow', 'blow a hurricane', 'blow great guns', 'blow over', 'blow up', 'bluster', 'break into music', 'break silence', 'breeze', 'breeze up'],
    'pipeline': ['adjutage', 'bush telegraph', 'catheter', 'channel', 'coming', 'conduit', 'confidential information', 'connection', 'contact', 'conveyor', 'cooking', 'drainpipe'],
    'pipes': ['od', 'bagpipe', 'bagpipes', 'boatswain', 'captain', 'chanter', 'chief engineer', 'chief mate', 'commander', 'cornemuse', 'deck officer', 'doodlesack'],
    'pipette': ['adjutage', 'aspirator', 'bleed', 'broach', 'catheter', 'corkscrew', 'crowbar', 'decant', 'draft', 'draft off', 'drain', 'drainpipe'],
    'piping': ['acute', 'adjutage', 'argute', 'at peace', 'balmy', 'bloodless', 'blooming', 'blossoming', 'booming', 'calm', 'catheter', 'clear'],
    'pippin': ['ace', 'beaut', 'corker', 'crackerjack', 'daisy', 'dandy', 'darb', 'dilly', 'dream', 'honey', 'humdinger', 'killer-diller'],
    'piquant': ['acerbic', 'acid', 'acrid', 'agitating', 'alluring', 'appealing', 'appetizing', 'asperous', 'astringent', 'attractive', 'beguiling', 'bewitching'],
    'pique': ['affect the interest', 'aggravate', 'agitate', 'angry look', 'animate', 'annoy', 'annoyance', 'arouse', 'attract', 'awaken', 'badger', 'bait'],
    'piqued': ['aggravated', 'angry', 'annoyed', 'attracted', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'cathectic', 'chafed', 'concerned', 'curious'],
    'pirate': ['ab', 'ancient mariner', 'argonaut', 'blackbeard', 'captain hook', 'captain kidd', 'dylan', 'flying dutchman', 'henry morgan', 'jean lafitte', 'neptune', 'od'],
    'pirouette': ['charybdis', 'circle', 'circulate', 'circumrotate', 'circumvolute', 'crank', 'dizzy round', 'eddy', 'go around', 'go round', 'gurge', 'gyrate'],
    'piscatory': ['cynegetic', 'eellike', 'fishing', 'fishy', 'following', 'halieutic', 'hunting', 'in full cry', 'in hot pursuit', 'in pursuit', 'piscatorial', 'pisciform'],
    'piss and vinegar': ['aggressiveness', 'animal spirits', 'animation', 'bang', 'breeziness', 'briskness', 'bubbliness', 'capersomeness', 'coltishness', 'dash', 'drive', 'ebullience'],
    'pissed': ['afflicted', 'angered', 'angry', 'bent', 'boiled', 'bombed', 'boozy', 'browned-off', 'canned', 'choleric', 'cockeyed', 'cockeyed drunk'],
    'pissed off': ['angered', 'angry', 'browned-off', 'choleric', 'cross', 'heated', 'incensed', 'indignant', 'irate', 'ireful', 'livid', 'mad'],
    'pistil': ['androecium', 'anther', 'calyx', 'carpel', 'corolla', 'corolla tube', 'corona', 'epicalyx', 'gynoecium', 'megasporophyll', 'microsporophyll', 'perianth'],
    'pistol': ['automatic', 'blow to pieces', 'blow up', 'blowgun', 'blowpipe', 'brain', 'bring down', 'burn to death', 'charge', 'cock', 'cut down', 'cut to pieces'],
    'pistol whip': ['baste', 'bastinado', 'beat', 'belabor', 'belt', 'birch', 'buffet', 'cane', 'club', 'cowhide', 'cudgel', 'cut'],
    'pit': ['american stock exchange', 'amex', 'wall street', 'abysm', 'abyss', 'acorn', 'acting area', 'agora', 'alveolation', 'alveolus', 'amphitheater', 'antrum'],
    'pit against': ['aggravate', 'alienate', 'bump heads', 'come between', 'confront', 'contend', 'contrapose', 'contraposit', 'contrast', 'counteract', 'disaffect', 'disunite'],
    'pitapat': ['arrhythmia', 'barrage', 'beat', 'beating', 'bump', 'chink', 'click', 'clink', 'clop', 'clump', 'clunk', 'crump'],
    'pitch': ['af', 'french pitch', 'abuse', 'acme', 'address', 'after-dinner speech', 'allocution', 'amount', 'angularity', 'apex', 'apogee', 'ascend'],
    'pitch black': ['atramentous', 'beamless', 'black', 'black as coal', 'black as ebony', 'black as ink', 'black as midnight', 'black as night', 'caliginous', 'coal-black', 'coaly', 'dark'],
    'pitch in': ['attack', 'begin', 'blast away', 'blast off', 'break bread', 'buckle down', 'commence', 'count calories', 'diet', 'dive in', 'dive into', 'eat'],
    'pitch into': ['accept', 'ambush', 'assail', 'assault', 'assume', 'attack', 'attempt', 'blitz', 'buckle to', 'bushwhack', 'come at', 'come down on'],
    'pitched': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'arranged', 'articulated', 'aslant', 'aslope', 'assimilated', 'atilt', 'back'],
    'pitching': ['archery', 'careening', 'casting', 'chucking', 'dangling', 'firing', 'flinging', 'gunnery', 'heaving', 'hurling', 'inclining', 'jaculation'],
    'pitchman': ['ballyhoo man', 'ballyhooer', 'barker', 'bunco artist', 'bunco steerer', 'canvasser', 'cardsharp', 'cardsharper', 'carpetbagger', 'con artist', 'con man', 'confidence man'],
    'pitchy': ['atramentous', 'beamless', 'black', 'black as coal', 'black as ebony', 'black as ink', 'black as midnight', 'black as night', 'caliginous', 'coal-black', 'coaly', 'dark'],
    'piteous': ['affecting', 'afflictive', 'beseeching', 'bitter', 'bleak', 'cheerless', 'comfortless', 'deplorable', 'depressing', 'depressive', 'discomforting', 'dismal'],
    'pitfall': ['dionaea', 'bait', 'baited trap', 'booby trap', 'catch', 'cobweb', 'coral heads', 'danger', 'deadfall', 'deathtrap', 'decoy', 'difficulty'],
    'pith': ['affective meaning', 'axiom', 'axis', 'backbone', 'bearing', 'bench mark', 'bottom', 'burden', 'butter', 'cardinal point', 'cataplasm', 'center'],
    'pithy': ['spartan', 'abbreviated', 'abridged', 'allegorical', 'aphoristic', 'aposiopestic', 'associational', 'axiomatic', 'baccate', 'brief', 'brusque', 'clipped'],
    'pitiful': ['abominable', 'affecting', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beggarly', 'beneath contempt', 'beneath one', 'blameworthy', 'brutal'],
    'pitiless': ['atrocious', 'barbaric', 'barbarous', 'bestial', 'bloody', 'bowelless', 'brutal', 'brutish', 'coldhearted', 'cruel', 'cutthroat', 'dog-eat-dog'],
    'pitilessness': ['acuteness', 'animality', 'atrocity', 'barbarity', 'bloodlust', 'brutality', 'callosity', 'callousness', 'coldbloodedness', 'coldheartedness', 'coldness', 'destructiveness'],
    'pittance': ['ace', 'alms', 'alms fee', 'atom', 'bit', 'charity', 'collection', 'contribution', 'dab', 'dole', 'donation', 'donative'],
    'pitted': ['alveolar', 'alveolate', 'broken', 'bumpy', 'choppy', 'coarse', 'coarse-grained', 'corroded', 'corrugated', 'cross-grained', 'defaced', 'dented'],
    'pitter patter': ['scotch mist', 'alliteration', 'arrhythmia', 'assonance', 'barrage', 'beat', 'beat a ruffle', 'beat a tattoo', 'beating', 'bicker', 'blood rain', 'bump'],
    'pity': ['abomination', 'acceptance', 'ache', 'atrocity', 'be sorry for', 'bleed', 'bleed for', 'chanty', 'clemency', 'clementness', 'commiserate', 'commiseration'],
    'pitying': ['bleeding', 'charitable', 'clement', 'commiserative', 'compassionate', 'condolent', 'forbearant', 'gentle', 'human', 'humane', 'lenient', 'melting'],
    'pivot': ['ankle', 'arbor', 'articulation', 'avert', 'axis', 'axle', 'axle bar', 'axle shaft', 'axle spindle', 'axle-tree', 'bearing', 'bench mark'],
    'pivotal': ['acute', 'axial', 'behind the scenes', 'capital', 'cardinal', 'causal', 'causative', 'centermost', 'central', 'centralized', 'centric', 'centroidal'],
    'pivoting': ['angular momentum', 'angular motion', 'angular velocity', 'axial motion', 'bowling', 'centrifugation', 'circulation', 'circumgyration', 'circumrotation', 'full circle', 'gyration', 'reeling'],
    'pixie': ['ariel', 'befind', 'corrigan', 'dingbelle', 'fifinella', 'finnbeara', 'hob', 'hobgoblin', 'mab', 'oberon', 'puck', 'titania'],
    'pixieish': ['antic', 'elfin', 'elfish', 'elflike', 'elvish', 'faery', 'fairy', 'fairyish', 'fairylike', 'fay', 'frisky', 'gnomelike'],
    'pixilated': ['bedeviled', 'boozy', 'canned', 'demonized', 'devil-ridden', 'disguised', 'drunk', 'elvish', 'frolicsome', 'inebriated', 'larkish', 'muddled'],
    'pizzazz': ['aggressiveness', 'amperage', 'animation', 'armipotence', 'authority', 'bang', 'beef', 'black power', 'breeziness', 'briskness', 'brute force', 'bubbliness'],
    'pizzeria': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop'],
    'pizzicato': ['a cappella', 'abbandono', 'accrescendo', 'adagietto', 'adagio', 'affettuoso', 'agilmente', 'agitato', 'allegretto', 'allegro', 'amabile', 'amoroso'],
    'placard': ['advertise', 'affiche', 'ballyhoo', 'bark', 'bill', 'boost', 'build up', 'bulletin', 'circularize', 'cry up', 'establish', 'give a write-up'],
    'placate': ['allay', 'appease', 'assuage', 'calm', 'comfort', 'conciliate', 'cool', 'defuse', 'dulcify', 'lay', 'lay the dust', 'mollify'],
    'placation': ['united nations troops', 'appeasement', 'calming', 'conciliation', 'detente', 'dulcification', 'easing of relations', 'mediation', 'mollification', 'pacification', 'peace-keeping force', 'peacemaking'],
    'place': ['anschauung', 'autobahn', 'ok', 'us highway', 'a leg up', 'abiding place', 'abode', 'address', 'advance', 'agora', 'airspace', 'align'],
    'placed': ['aligned', 'arranged', 'arrayed', 'assigned', 'assorted', 'cataloged', 'categorized', 'classified', 'composed', 'constituted', 'deployed', 'disposed'],
    'placement': ['abode', 'accedence', 'accession', 'accounting for', 'allocation', 'allotment', 'analysis', 'answerability', 'application', 'appointment', 'apportionment', 'area'],
    'placid': ['affliction', 'at rest', 'bane', 'besetment', 'bother', 'botheration', 'calm', 'cloistered', 'collected', 'composed', 'cool', 'coolheaded'],
    'placidly': ['calmly', 'composedly', 'coolly', 'dispassionately', 'impassively', 'imperturbably', 'inexcitably', 'inirritably', 'levelheadedly', 'peacefully', 'quiescently', 'quietly'],
    'placket': ['air hole', 'armhole', 'blowhole', 'bullet-hole', 'bunghole', 'cringle', 'deadeye', 'eye', 'eyelet', 'gasket', 'grommet', 'guide'],
    'plage': ['bank', 'beach', 'berm', 'coast', 'coastland', 'coastline', 'embankment', 'foreshore', 'ironbound coast', 'lido', 'littoral', 'playa'],
    'plagiarism': ['adoption', 'appropriation', 'assumption', 'autoplagiarism', 'borrowed plumes', 'borrowing', 'copying', 'counterfeiting', 'cribbing', 'derivation', 'deriving', 'doubling'],
    'plagiarist': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'actor', 'ape', 'bamboozler', 'befuddler', 'beguiler', 'charmer'],
    'plagiarize': ['act like', 'adopt', 'affect', 'appropriate', 'assume', 'borrow', 'chorus', 'come again', 'copy', 'counterfeit', 'crib', 'derive from'],
    'plagiarized': ['counterfeit', 'doubled', 'duplicated', 'echoed', 'ersatz', 'fake', 'forged', 'hokey', 'hot', 'imitation', 'mock', 'phony'],
    'plague': ['afflict', 'affliction', 'aggravate', 'aggravation', 'ail', 'ambulatory plague', 'anguish', 'annoy', 'annoyance', 'apply pressure', 'badger', 'bait'],
    'plagued': ['annoyed', 'anxious', 'badgered', 'baited', 'bedeviled', 'beset', 'bothered', 'bugged', 'bullyragged', 'chivied', 'deviled', 'distressed'],
    'plaguing': ['aggravating', 'annoying', 'blandishment', 'bothering', 'bothersome', 'buttonholing', 'cajolement', 'cajolery', 'cajoling', 'chafing', 'coaxing', 'demanding'],
    'plaid': ['check', 'checked', 'checker', 'checkerboard', 'checkered', 'checkerwork', 'chessboard', 'colors in patches', 'crazy-work', 'harlequin', 'marquetry', 'mosaic'],
    'plain': ['attic', 'bohemian', 'ciceronian', 'lebensraum', 'mickey mouse', 'spartan', 'abrupt', 'absolute', 'absolutely', 'affable', 'agricultural region', 'air space'],
    'plain english': ['austerity', 'baldness', 'bareness', 'candor', 'clarity', 'clear-cutness', 'clearness', 'coherence', 'common speech', 'connectedness', 'consistency', 'crystallinity'],
    'plain folks': ['bourgeoisie', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty', 'commoners', 'commons', 'laborers', 'linendrapers', 'lower classes'],
    'plain speech': ['clarity', 'clear-cutness', 'clearness', 'coherence', 'connectedness', 'consistency', 'crystallinity', 'definition', 'directness', 'distinctness', 'explicitness', 'limpidity'],
    'plain spoken': ['spartan', 'articulate', 'artless', 'ascetic', 'austere', 'bald', 'bare', 'bluff', 'blunt', 'broad', 'brusque', 'candid'],
    'plainclothesman': ['bow street runner', 'fbi', 'fbi agent', 'federal', 'g-man', 'secret service', 'sherlock', 'sherlock holmes', 't-man', 'detective', 'dick', 'fed'],
    'plainly': ['all joking aside', 'alone', 'aloud', 'apparently', 'apprehensibly', 'articulately', 'artlessly', 'audibly', 'barely', 'bluffly', 'bluntly', 'broadly'],
    'plainness': ['atticism', 'bohemianism', 'accessibility', 'affability', 'apparentness', 'approachability', 'appropriateness', 'artlessness', 'atmospheric visibility', 'austerity', 'baldness', 'bareness'],
    'plaint': ['accusal', 'accusation', 'accusing', 'allegation', 'allegement', 'arraignment', 'bawl', 'bill of particulars', 'blame', 'bringing of charges', 'bringing to book', 'charge'],
    'plaintiff': ['accessory', 'accusant', 'accuser', 'allegator', 'appellant', 'bitter-ender', 'brawler', 'claimant', 'complainant', 'defendant', 'delator', 'diehard'],
    'plaintive': ['jeremianic', 'aggrieved', 'anguished', 'careworn', 'complaining', 'doleful', 'dolorous', 'dumb with grief', 'faultfinding', 'fretful', 'grief-stricken', 'griefful'],
    'plaintively': ['brokenheartedly', 'complainingly', 'dolefully', 'dolorously', 'fretfully', 'grieffully', 'grievously', 'groaningly', 'lamentingly', 'moanfully', 'mournfully', 'peevishly'],
    'plait': ['accordion pleat', 'box pleat', 'braid', 'bun', 'chignon', 'coat', 'coating', 'coil', 'collop', 'covering', 'crease', 'crimp'],
    'plaited': ['braided', 'creased', 'crimped', 'dog-eared', 'doubled', 'enlaced', 'entwined', 'flexible', 'flounced', 'fluted', 'foldable', 'folded'],
    'plan': ['action', 'adjust', 'affair', 'aim', 'aim at', 'alphabet', 'ambition', 'anagnorisis', 'anatomy', 'angle', 'animus', 'anticipate'],
    'plane': ['aeroplane', 'aircraft', 'airliner', 'airplane', 'alabaster', 'amount', 'aspire', 'avion', 'beading plane', 'become airborne', 'bench plane', 'billiard table'],
    'planet': ['earth', 'jupiter', 'mars', 'mercury', 'neptune', 'pluto', 'saturn', 'uranus', 'venus', 'asteroid', 'globe', 'inferior planet'],
    'planetarium': ['cassegrainian telescope', 'newtonian telescope', 'oao', 'oso', 'astronomical observatory', 'astronomical telescope', 'coelostat', 'coronagraph', 'coronograph', 'heliostat', 'observatory', 'orrery'],
    'planetary': ['antaean', 'cynthian', 'aberrant', 'aberrative', 'all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive'],
    'plangent': ['jeremianic', 'aggrieved', 'anguished', 'booming', 'careworn', 'complaining', 'consonant', 'deafening', 'doleful', 'dolorous', 'dumb with grief', 'ear-piercing'],
    'planimetry': ['altimetry', 'bathymetry', 'biometrics', 'biometry', 'cadastration', 'cartography', 'chorography', 'craniometry', 'geodesy', 'geodetics', 'goniometry', 'hypsography'],
    'plank': ['mystik tape', 'scotch tape', 'adhesive tape', 'band', 'bandage', 'batten', 'beam', 'belt', 'billet', 'board', 'boarding', 'brick'],
    'planking': ['bank', 'beam', 'billet', 'board', 'boarding', 'border', 'broadside', 'cheek', 'chop', 'clapboard', 'coast', 'cord'],
    'plankton': ['iceland moss', 'irish moss', 'loch ness monster', 'alevin', 'benthon', 'benthos', 'brown algae', 'cetacean', 'conferva', 'dolphin', 'dulse', 'fingerling'],
    'planless': ['aimless', 'amorphous', 'capricious', 'casual', 'desultory', 'disarticulated', 'discontinuous', 'disjunct', 'disordered', 'dispersed', 'disproportionate', 'erratic'],
    'planned': ['advised', 'aimed', 'aimed at', 'all ready', 'all set', 'approaching', 'armed', 'armed and ready', 'arranged', 'blueprinted', 'booted and spurred', 'briefed'],
    'planner': ['ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner', 'builder', 'conceiver', 'constructor', 'contriver'],
    'planning': ['adjustment', 'approach', 'arrangement', 'attack', 'basic training', 'blueprint', 'blueprinting', 'briefing', 'calculation', 'charting', 'clearing the decks', 'codification'],
    'plant': ['accouterments', 'adulterate', 'agent provocateur', 'amphibian', 'angiosperm', 'annual', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'aquatic plant', 'armament'],
    'plant eater': ['brillat-savarin', 'lucullus', 'board-and-roomer', 'boarder', 'bon vivant', 'cannibal', 'carnivore', 'connoisseur of food', 'consumer', 'diner', 'diner-out', 'eater'],
    'plantation': ['anchorage', 'arable land', 'barnyard', 'barton', 'cattle ranch', 'chicken farm', 'clump', 'collective farm', 'colonization', 'cotton plantation', 'croft', 'crop'],
    'planted': ['assigned', 'deployed', 'embosomed', 'emplaced', 'ensconced', 'established', 'fixed', 'installed', 'located', 'placed', 'positioned', 'posted'],
    'planter': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'coffee-planter', 'collective farm worker', 'colonial', 'colonist', 'colonizer', 'crofter', 'cropper'],
    'planting': ['broadcast', 'broadcasting', 'clump', 'crop', 'dissemination', 'growth', 'hassock', 'insemination', 'plantation', 'reforestation', 'resetting', 'retimbering'],
    'plantlike': ['botanic', 'bulbous', 'cereal', 'farinaceous', 'fruitlike', 'fruity', 'herbaceous', 'herbal', 'herbose', 'herbous', 'herby', 'leguminose'],
    'plaque': ['arch', 'award', 'badge', 'barrow', 'boundary stone', 'brass', 'brooch', 'bust', 'cairn', 'cenotaph', 'column', 'cromlech'],
    'plash': ['artificial lake', 'babble', 'bayou lake', 'brash', 'bubble', 'burble', 'burst of rain', 'cistern', 'cloudburst', 'dam', 'dead water', 'deluge'],
    'plashy': ['aquatic', 'aqueous', 'dirty', 'hydrated', 'hydraulic', 'hydrous', 'liquid', 'miry', 'mucky', 'muddy', 'oozy', 'slabby'],
    'plasma': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'antibody', 'antigen', 'arterial blood', 'blood', 'blood bank', 'blood cell', 'blood count'],
    'plaster': ['ace bandage', 'band-aid', 'portland cement', 'spackle', 'adherent', 'adhesive', 'adhesive tape', 'adobe', 'application', 'ashlar', 'band', 'bandage'],
    'plastered': ['afflicted', 'bent', 'boiled', 'bombed', 'boozy', 'canned', 'cockeyed', 'cockeyed drunk', 'crocked', 'crocko', 'disguised', 'drunk'],
    'plastic': ['bakelite', 'buna', 'celluloid', 'formica', 'lucite', 'mylar', 'pvc', 'perspex', 'plexiglas', 'styrofoam', 'teflon', 'able to adapt'],
    'plastic person': ['babbitt', 'middle american', 'philistine', 'anal character', 'bourgeois', 'burgher', 'compulsive character', 'conformer', 'conformist', 'conventionalist', 'formalist', 'methodologist'],
    'plastic surgery': ['antiseptic surgery', 'aseptic surgery', 'balanoplasty', 'batrachoplasty', 'blepharoplasty', 'bronchoplasty', 'canthoplasty', 'chiroplasty', 'colpoplasty', 'cosmetic operation', 'cryosurgery', 'cystoplasty'],
    'plasticity': ['adaptability', 'adjustability', 'agreeability', 'agreeableness', 'alterability', 'amenability', 'aptitude', 'aptness', 'bendability', 'biddability', 'brightness', 'changeability'],
    'plat': ['accordion pleat', 'acres', 'block', 'box pleat', 'chattels real', 'clearing', 'clos', 'close', 'corn field', 'crease', 'crimp', 'crisp'],
    'plate': ['chateaubriand', 'alveolar ridge', 'anodized aluminum', 'antepast', 'armor', 'backing', 'bibliofilm', 'billhead', 'bipack', 'black-and-white film', 'blade roast', 'book stamp'],
    'plateau': ['alkali flat', 'alluvial plain', 'amount', 'basin', 'bench', 'bottomland', 'break', 'bushveld', 'caliber', 'campo', 'champaign', 'champaign country'],
    'platform': ['address', 'agora', 'amphitheater', 'arena', 'athletic field', 'auditorium', 'background', 'balcony', 'bear garden', 'bench mark', 'billiard table', 'bookmark'],
    'plating': ['anodized aluminum', 'chromium plate', 'coat', 'coating', 'collop', 'copperplate', 'covering', 'cut', 'deal', 'disk', 'electrocoating', 'electroplating'],
    'platinum blond': ['ash blond', 'ash-blond', 'bleached blond', 'bleached-blond', 'blond', 'blond-haired', 'blond-headed', 'brunet', 'carrottop', 'flaxen-haired', 'golden-haired', 'goldilocks'],
    'platitude': ['abstraction', 'banality', 'bromide', 'chestnut', 'cliche', 'commonplace', 'commonplace expression', 'corn', 'familiar tune', 'general idea', 'generalization', 'generalized proposition'],
    'platitudinous': ['aphoristic', 'axiomatic', 'back-number', 'banal', 'bewhiskered', 'bromidic', 'common', 'commonly known', 'commonplace', 'corny', 'crisp', 'current'],
    'platonic': ['augustinian', 'averroist', 'berkeleian', 'cartesian', 'hegelian', 'heideggerian', 'heraclitean', 'humean', 'husserlian', 'kantian', 'leibnizian', 'neo-hegelian'],
    'platonic love': ['amor', 'christian love', 'eros', 'abstinence', 'admiration', 'adoration', 'affection', 'agape', 'ardency', 'ardor', 'attachment', 'bodily love'],
    'platoon': ['kp', 'age group', 'army', 'army group', 'array', 'band', 'batch', 'battalion', 'battery', 'battle group', 'bevy', 'body'],
    'platter': ['bulletin board', 'card', 'catalog card', 'disc', 'dish', 'file', 'filing card', 'film', 'index card', 'library catalog', 'magnetic tape', 'microcard'],
    'platypus': ['angora goat', 'arctic fox', 'belgian hare', 'caffre cat', 'indian buffalo', 'kodiak bear', 'virginia deer', 'aardvark', 'aardwolf', 'alpaca', 'anteater', 'antelope'],
    'plaudit': ['acclaim', 'acclamation', 'applause', 'big hand', 'burst of applause', 'cheer', 'clap', 'clapping', 'clapping of hands', 'eclat', 'encore', 'hand'],
    'plausibility': ['acceptability', 'admissibility', 'apparent soundness', 'believability', 'believableness', 'casuistry', 'circularity', 'color', 'common sense', 'conceivability', 'credibility', 'credit'],
    'plausible': ['acceptable', 'admissible', 'apparent', 'apparently sound', 'believable', 'casuistic', 'cogent', 'cogitable', 'colorable', 'colored', 'conceivable', 'conceivably possible'],
    'play': ['algol', 'cobol', 'fortran', 'grand guignol', 'passion play', 'tom show', 'abuse', 'accentuate', 'accompany', 'act', 'act a part', 'act as'],
    'play around': ['cast coquettish glances', 'coquet', 'dabble', 'dally', 'eye', 'fiddle', 'fiddle with', 'fiddle-faddle', 'fidget with', 'finger with', 'flirt', 'fool'],
    'play around with': ['assay', 'be abstracted', 'bring to test', 'brood', 'chew the cud', 'confirm', 'consider', 'contemplate', 'cut and try', 'debate', 'deliberate', 'digest'],
    'play ball': ['act in concert', 'act together', 'affiliate', 'ally', 'amalgamate', 'associate', 'band', 'band together', 'be in league', 'club together', 'coact', 'coalesce'],
    'play by ear': ['accompany', 'ad-lib', 'be caught napping', 'be surprised', 'be taken unawares', 'be unprepared', 'chord', 'concertize', 'cook up', 'dash off', 'do', 'do offhand'],
    'play down': ['abate', 'allay', 'alleviate', 'assuage', 'attemper', 'bank the fire', 'bedwarf', 'belittle', 'blunt', 'chasten', 'constrain', 'control'],
    'play dumb': ['be mute', 'be silent', 'bosom', 'classify', 'conceal', 'file and forget', 'forswear speech', 'hold out on', 'in petto', 'keep', 'keep back', 'keep between us'],
    'play havoc with': ['abuse', 'afflict', 'aggrieve', 'be all thumbs', 'befoul', 'bewitch', 'blight', 'blunder', 'blunder away', 'blunder into', 'blunder on', 'blunder upon'],
    'play off': ['bout', 'contest', 'decathlon', 'double-header', 'doubles', 'event', 'foursome', 'game', 'games of chance', 'go', 'match', 'meet'],
    'play on': ['abuse', 'bleed', 'bleed white', 'deceive', 'drain', 'exploit', 'foist on', 'ill-use', 'impose on', 'impose upon', 'make use of', 'manipulate'],
    'play on words': ['abuse of terms', 'acrostic', 'amphibologism', 'amphiboly', 'anagram', 'be merry with', 'calembour', 'corruption', 'crack a joke', 'crack wise', 'equivocality', 'equivoque'],
    'play out': ['blow', 'break down', 'burn out', 'collapse', 'crack up', 'droop', 'drop', 'faint', 'fatigue', 'flag', 'gasp', 'get tired'],
    'play safe': ['clear the decks', 'consider every angle', 'forearm', 'guard against', 'hedge', 'leave out nothing', 'make sure', 'make sure against', 'overlook no possibility', 'prepare for', 'protect', 'provide a hedge'],
    'play the game': ['act well', 'be good', 'be nice', 'behave', 'conform', 'do right', 'fall in with', 'fall into line', 'fit in', 'follow the crowd', 'follow the fashion', 'follow the rule'],
    'play the market': ['be caught short', 'be short', 'belong', 'bucket', 'bucketshop', 'deposit margin', 'go long', 'hold on', 'make a killing', 'make a scoop', 'margin up', 'miss the market'],
    'play up to': ['act up to', 'agree to anything', 'approach', 'blarney', 'break the ice', 'brown-nose', 'butter', 'butter up', 'court', 'cultivate', 'curry favor', 'dance attendance on'],
    'play with fire': ['bell the cat', 'brave', 'chance', 'court danger', 'court destruction', 'dare', 'defy danger', 'face up to', 'flirt with death', 'forget the odds', 'gamble', 'go for broke'],
    'playa': ['alkali flat', 'alluvial plain', 'bank', 'basin', 'beach', 'berm', 'bottomland', 'bushveld', 'campo', 'champaign', 'champaign country', 'coast'],
    'playacting': ['acting', 'affectation', 'appearance', 'attitudinizing', 'bluff', 'bluffing', 'buffoonery', 'business', 'characterization', 'cheating', 'color', 'coloring'],
    'playactor': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'roscius', 'actor', 'actress', 'affecter', 'antagonist', 'bad guy'],
    'playbill': ['agenda', 'batting order', 'bill', 'bill of fare', 'blueprint', 'budget', 'calendar', 'card', 'carte du jour', 'docket', 'lineup', 'list of agenda'],
    'playbook': ['best seller', 'book', 'bound book', 'classic', 'coloring book', 'continuity', 'cue', 'definitive work', 'folio', 'great work', 'hardback', 'juvenile'],
    'playboy': ['casanova', 'don juan', 'lothario', 'romeo', 'bon vivant', 'carouser', 'clubman', 'clubwoman', 'contestant', 'cutup', 'debauchee', 'excellent companion'],
    'played out': ['all in', 'ausgespielt', 'beat', 'beat up', 'beaten', 'bone-weary', 'burned-out', 'bushed', 'dead', 'dead-and-alive', 'dead-tired', 'deadbeat'],
    'player': ['roscius', 'actor', 'actress', 'adventurer', 'amateur athlete', 'antagonist', 'archer', 'artist', 'artiste', 'athlete', 'bad guy', 'ballplayer'],
    'playful': ['animated', 'antic', 'arch', 'blithe', 'capersome', 'cheerful', 'coltish', 'dashing', 'devilish', 'elfish', 'elvish', 'exuberant'],
    'playfulness': ['animal spirits', 'animation', 'capersomeness', 'coltishness', 'devilishness', 'devilment', 'devilry', 'deviltry', 'elan', 'elfishness', 'esprit', 'exuberance'],
    'playground': ['archery ground', 'athletic field', 'badminton court', 'baseball field', 'basketball court', 'billiard parlor', 'bowling alley', 'bowling green', 'course', 'court', 'cricket ground', 'croquet ground'],
    'playhouse': ['elizabethan theater', 'globe theatre', 'greek theater', 'amphitheater', 'arena theater', 'auditorium', 'cabaret', 'circle theater', 'club', 'concert hall', 'cubby', 'cubbyhole'],
    'playing': ['acting', 'aflicker', 'aping', 'betting', 'bickering', 'blinking', 'buffoonery', 'business', 'cardsharping', 'casting lots', 'characterization', 'coquetry'],
    'playing cards': ['ace', 'best bower', 'bower', 'cards', 'clubs', 'deck', 'deuce', 'diamonds', 'dummy', 'face cards', 'flush', 'full house'],
    'playing field': ['archery ground', 'athletic field', 'badminton court', 'baseball field', 'basketball court', 'billiard parlor', 'bowling alley', 'bowling green', 'course', 'court', 'cricket ground', 'croquet ground'],
    'playmate': ['ace', 'amigo', 'associate', 'bedfellow', 'bedmate', 'birthmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty', 'camarade'],
    'playroom': ['archery ground', 'athletic field', 'badminton court', 'baseball field', 'basketball court', 'billiard parlor', 'bowling alley', 'bowling green', 'course', 'court', 'cricket ground', 'croquet ground'],
    'plaything': ['charlie mccarthy', 'agate', 'agent', 'ancilla', 'appliance', 'babe', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble', 'blocks'],
    'playwright': ['choreographer', 'comedian', 'dramatist', 'dramatizer', 'dramaturge', 'farcer', 'farceur', 'farceuse', 'farcist', 'gagman', 'joke writer', 'jokesmith'],
    'plaza': ['agora', 'auto show', 'bazaar', 'boat show', 'campo', 'commercial complex', 'emporium', 'exposition', 'fair', 'flea fair', 'flea market', 'forum'],
    'plea': ['adjuration', 'alibi', 'answer', 'apology', 'appeal', 'application', 'argument', 'argumentum', 'beseechment', 'bid', 'call', 'case'],
    'pleach': ['braid', 'enlace', 'entwine', 'interknit', 'interlace', 'intertie', 'intertissue', 'intertwine', 'intertwist', 'interweave', 'intort', 'knit'],
    'plead': ['adduce', 'adjure', 'advance', 'advocate', 'affirm', 'allege', 'appeal', 'appeal to', 'apply to', 'argue', 'argufy', 'array'],
    'plead guilty': ['acknowledge', 'admit', 'admit everything', 'allow', 'apologize', 'avow', 'beg pardon', 'come clean', 'concede', 'confess', 'cop a plea', 'do penance'],
    'pleader': ['abettor', 'actuator', 'advocate', 'agent', 'alter ego', 'alternate', 'amicus curiae', 'animator', 'apologete', 'apologist', 'apologizer', 'attorney'],
    'pleading': ['adjuratory', 'answer', 'appealing', 'argument', 'argumentum', 'bar', 'begging', 'beseeching', 'case', 'cons', 'consideration', 'counsel'],
    'pleasance': ['affability', 'agreeability', 'agreeableness', 'amenity', 'amiability', 'amicability', 'bliss', 'blissfulness', 'common', 'commons', 'compatibility', 'complaisance'],
    'pleasant': ['achingly sweet', 'advantageous', 'affable', 'agreeable', 'agreeable-sounding', 'alluring', 'amiable', 'amicable', 'appealing', 'approachable', 'appropriate', 'ariose'],
    'pleasantly': ['affably', 'agreeably', 'airily', 'amiably', 'amicably', 'ardently', 'arm in arm', 'blissfully', 'blithely', 'cheerfully', 'cheerily', 'congenially'],
    'pleasantness': ['advantageousness', 'agreeability', 'agreeableness', 'amiability', 'auspiciousness', 'beneficialness', 'benevolence', 'benignity', 'blitheness', 'blithesomeness', 'brightness', 'cheer'],
    'pleasantry': ['atticism', 'affability', 'agile wit', 'agreeability', 'agreeableness', 'amenity', 'amiability', 'amicability', 'aphorism', 'apothegm', 'badinage', 'banter'],
    'please': ['i beg you', 'amuse', 'be good enough', 'cater to', 'cheer', 'choose', 'choose rather', 'coddle', 'content', 'cosset', 'delectate', 'delight'],
    'pleased': ['accepting', 'at ease', 'charmed', 'chuffed', 'comfortable', 'composed', 'content', 'contented', 'cozy', 'delighted', 'easy', 'easygoing'],
    'pleasing': ['attic', 'junoesque', 'acceptable', 'adorable', 'aesthetic', 'affable', 'agreeable', 'ambrosial', 'amiable', 'amicable', 'amply endowed', 'appetizing'],
    'pleasurable': ['affable', 'agreeable', 'amiable', 'amicable', 'blissful', 'cheerful', 'compatible', 'complaisant', 'congenial', 'cordial', 'desirable', 'dulcet'],
    'pleasure': ['affability', 'agreeability', 'agreeableness', 'alternate choice', 'alternative', 'amenity', 'amiability', 'amicability', 'amusement', 'animus', 'appetence', 'appetency'],
    'pleasure principle': ['cyrenaic hedonism', 'cyrenaicism', 'anima', 'appetite', 'appetitiveness', 'ardor', 'coconscious', 'collective unconscious', 'concupiscence', 'conscience', 'conscious self', 'curiosity'],
    'pleasure seeker': ['cyrenaic', 'heliogabalus', 'sardanapalus', 'bon vivant', 'carouser', 'carpet knight', 'contestant', 'cutup', 'epicure', 'epicurean', 'frisker', 'frolicker'],
    'pleasure seeking': ['cyrenaic', 'cyrenaic hedonism', 'cyrenaicism', 'appetite', 'appetitive', 'appetitiveness', 'bent on pleasure', 'epicurean', 'epicureanism', 'epicurism', 'ethical hedonism', 'eudaemonic'],
    'pleasureless': ['anguished', 'anxious', 'bored', 'cheerless', 'depressed', 'discontented', 'disgusted', 'grim', 'humorless', 'in bad humor', 'infestive', 'joyless'],
    'pleat': ['accordion pleat', 'aqueduct', 'box pleat', 'canal', 'canalization', 'canalize', 'carve', 'chamfer', 'channel', 'chisel', 'corrugate', 'crack'],
    'pleated': ['canaliculate', 'canaliculated', 'chamfered', 'channeled', 'corduroy', 'corduroyed', 'corrugate', 'corrugated', 'costate', 'creased', 'crimped', 'cut'],
    'plebeian': ['babbittish', 'cockney', 'everyman', 'john smith', 'philistine', 'average man', 'base', 'baseborn', 'below the salt', 'bourgeois', 'brutish', 'campy'],
    'plebiscite': ['australian ballot', 'hare system', 'aye', 'ballot', 'canvass', 'canvassing', 'casting vote', 'constitutional referendum', 'counting heads', 'cumulative voting', 'deciding vote', 'direct initiative'],
    'pledge': ['bible oath', 'greek', 'accounts payable', 'accounts receivable', 'affiliate', 'agree', 'amount due', 'associate', 'assurance', 'assure', 'avouch', 'avouchment'],
    'pledged': ['affianced', 'affirmed', 'alleged', 'announced', 'answerable for', 'as earnest', 'asserted', 'asseverated', 'assured', 'at stake', 'attested', 'averred'],
    'pledget': ['ace bandage', 'band-aid', 'adhesive tape', 'application', 'band', 'bandage', 'bandaging', 'binder', 'brace', 'cast', 'cataplasm', 'compress'],
    'pleiad': ['big name', 'celebrity', 'constellation', 'cynosure', 'figure', 'folk hero', 'galaxy', 'great man', 'hero', 'heroine', 'idol', 'immortal'],
    'pleiades': ['atlantides', 'beehive', 'cepheid variable', 'hertzsprung-russell diagram', 'hyades', 'messier catalog', 'ngc', 'napaea', 'seven sisters', 'absolute magnitude', 'binary star', 'black hole'],
    'plenary': ['sro', 'absolute', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full', 'chuck-full', 'comprehensive', 'congested', 'consequential'],
    'plenipotentiary': ['absolute', 'all-powerful', 'almighty', 'ambassador', 'ambassadorial', 'ambassadress', 'apostolic delegate', 'attache', 'career diplomat', 'chancellor', 'charge', 'commercial attache'],
    'plenitude': ['abundance', 'accumulation', 'acres', 'affluence', 'amassment', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'backlog', 'bags', 'barrels'],
    'plenteous': ['abundant', 'ample', 'bounteous', 'bountiful', 'copious', 'fruitful', 'full', 'galore', 'generous', 'hearty', 'lavish', 'liberal'],
    'plentiful': ['abounding', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'blooming', 'bottomless', 'bounteous', 'bountiful', 'bumper', 'bursting'],
    'plenty': ['a deal', 'a great deal', 'a lot', 'abounding', 'abundance', 'abundant', 'abundantly', 'accumulation', 'acres', 'adequate', 'affluence', 'affluent'],
    'plenum': ['copernican universe', 'einsteinian universe', 'indian file', 'newtonian universe', 'ptolemaic universe', 'air', 'all', 'all being', 'all creation', 'allness', 'array', 'articulation'],
    'plethora': ['amplitude', 'avalanche', 'congestion', 'deluge', 'embarras de richesses', 'engorgement', 'enough', 'extravagance', 'extravagancy', 'flood', 'flood tide', 'full'],
    'pleura': ['allantoic membrane', 'amnion', 'amniotic sac', 'arachnoid membrane', 'basement membrane', 'conjuctiva', 'eardrum', 'hymen', 'maidenhead', 'membrana serosa', 'membrana tympana', 'membrane'],
    'pleurisy': ['asiatic flu', 'hong kong flu', 'acute bronchitis', 'adenoiditis', 'aluminosis', 'amygdalitis', 'anthracosilicosis', 'anthracosis', 'asbestosis', 'asthma', 'atypical pneumonia', 'bituminosis'],
    'plexiform': ['barred', 'cancellated', 'crossbarred', 'filigreed', 'grated', 'gridded', 'laced', 'lacelike', 'lacy', 'latticelike', 'meshed', 'meshy'],
    'plexus': ['afferent neuron', 'arabesque', 'autonomic nervous system', 'axon', 'basketry', 'basketwork', 'brain', 'cancellation', 'central nervous system', 'cerebral cortex', 'craniosacral nervous system', 'cross-hatching'],
    'pliability': ['abulia', 'acquiescence', 'adaptability', 'agreeability', 'agreeableness', 'alacrity', 'amenability', 'aptitude', 'aptness', 'ardor', 'bendability', 'biddability'],
    'pliable': ['abulic', 'accessible', 'adaptable', 'afraid', 'amenable', 'appliable', 'applicable', 'apt', 'bendable', 'bending', 'bendy', 'biddable'],
    'pliant': ['accessible', 'acquiescent', 'adaptable', 'adaptive', 'adjustable', 'agreeable', 'alacritous', 'amenable', 'ardent', 'bendable', 'bending', 'biddable'],
    'plicate': ['crease', 'creased', 'crimp', 'crimped', 'crisp', 'dog-ear', 'dog-eared', 'double', 'double over', 'doubled', 'enfold', 'flexible'],
    'plight': ['adverse circumstances', 'adversity', 'affiance', 'affliction', 'aggravation', 'annoyance', 'assurance', 'assure', 'avouch', 'avouchment', 'baffle', 'bafflement'],
    'plinth': ['baluster', 'balustrade', 'banister', 'base', 'caryatid', 'colonnade', 'column', 'dado', 'die', 'footstalk', 'jack', 'newel-post'],
    'plod': ['amble', 'andante', 'barge', 'bowl along', 'bundle', 'chug on', 'claudication', 'clump', 'crawl', 'creep', 'dead march', 'dig'],
    'plodder': ['beast of burden', 'dawdle', 'dawdler', 'drone', 'drudge', 'fag', 'foot-dragger', 'galley slave', 'goldbrick', 'goof-off', 'greasy grind', 'grind'],
    'plodding': ['application', 'arid', 'assiduity', 'assiduous', 'assiduousness', 'banausic', 'barren', 'blah', 'blank', 'bloodless', 'bulldog tenacity', 'characterless'],
    'plop': ['abruptly', 'bang', 'blubber', 'boil', 'boil over', 'bubble', 'bubble over', 'bubble up', 'burble', 'cast', 'cave', 'cave in'],
    'plot': ['acreage', 'acres', 'action', 'allotment', 'anagnorisis', 'angle', 'anticipate', 'approach', 'architectonics', 'architecture', 'area', 'argument'],
    'plotted': ['admeasured', 'appraised', 'approaching', 'arranged', 'assessed', 'blueprinted', 'calculated', 'charted', 'coming', 'contrived', 'cooked-up', 'cut out'],
    'plotter': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'machiavellian', 'quisling', 'archtraitor', 'betrayer', 'cockatrice', 'coconspirator', 'conniver', 'conspirator'],
    'plotting': ['byzantine', 'machiavellian', 'artifice', 'cabal', 'calculating', 'collusion', 'collusive', 'complicity', 'complot', 'confederacy', 'connivance', 'connivent'],
    'plow': ['all-crop harvester', 'backset', 'baler', 'bank', 'bean harvester', 'beet harvester', 'binder', 'break', 'breaker', 'canal', 'canalize', 'carve'],
    'plowman': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'coffee-planter', 'collective farm worker', 'crofter', 'cropper', 'cultivator', 'dirt farmer', 'dry farmer'],
    'ploy': ['byzantine intrigues', 'art', 'artful dodge', 'artifice', 'backstairs influence', 'bag of tricks', 'bat', 'bender', 'binge', 'blind', 'bluff', 'bosey'],
    'pluck': ['accumulate', 'amass', 'assemble', 'avulse', 'backbone', 'bare', 'bleed', 'bleed white', 'bob', 'boldness', 'bottle', 'bottom'],
    'plucky': ['bold', 'bulldoggish', 'courageous', 'dauntless', 'doughty', 'fearless', 'game', 'gamy', 'gritty', 'gutsy', 'gutty', 'mettlesome'],
    'plug': ['pr', 'acknowledgment', 'advert', 'advertise', 'advertisement', 'advocate', 'appreciation', 'back', 'bait', 'balker', 'balky horse', 'ballyhoo'],
    'plug away': ['carry on', 'dig', 'drudge', 'fag', 'grind', 'grub', 'hammer', 'hammer away', 'keep at it', 'keep busy', 'keep doggedly at', 'keep driving'],
    'plug ugly': ['battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'bravo', 'brawler', 'bruiser', 'bully', 'bullyboy', 'combatant', 'competitor'],
    'plugged': ['blocked', 'bound', 'choked', 'choked up', 'clogged', 'clogged up', 'congested', 'constipated', 'costive', 'foul', 'fouled', 'full'],
    'plugging': ['application', 'assiduity', 'assiduous', 'assiduousness', 'bulldog tenacity', 'concentration', 'constancy', 'constant', 'continuing', 'diligence', 'diligent', 'dogged'],
    'plum': ['mars violet', 'tyrian purple', 'accrued dividends', 'accumulated dividends', 'ambition', 'amethyst', 'bawbee', 'boast', 'bonus', 'carrot', 'cash dividend', 'catch'],
    'plumb': ['t square', 'absolute', 'absolutely', 'accurately', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'answer', 'aplomb', 'appraise', 'appreciate'],
    'plumbing': ['accouterments', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'conveniences', 'duffel', 'equipage', 'equipment', 'facilities', 'facility'],
    'plume': ['bead', 'bejewel', 'beribbon', 'bespangle', 'brush up', 'crest', 'diamond', 'dress', 'engrave', 'feather', 'fettle', 'figure'],
    'plumed': ['adorned', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'capped', 'crested', 'crowned', 'decked out'],
    'plummet': ['t square', 'abate', 'ablate', 'bate', 'be eaten away', 'beat down', 'bob', 'break', 'cascade', 'cataract', 'cheapen', 'cheapening'],
    'plummeting': ['break', 'cascade', 'cataract', 'cheapening', 'chute', 'collapse', 'collapsing', 'comedown', 'crash', 'cut', 'debacle', 'deciduous'],
    'plump': ['abruptly', 'adipose', 'ample', 'at once', 'back', 'ballot', 'bang', 'beamy', 'become overweight', 'beefy', 'big-bellied', 'bloated'],
    'plunder': ['banditry', 'blackmail', 'boodle', 'booty', 'brigandage', 'brigandism', 'capture', 'depredate', 'depredation', 'desolate', 'despoil', 'despoiling'],
    'plunderer': ['depredator', 'despoiler', 'forager', 'forayer', 'freebooter', 'looter', 'marauder', 'pillager', 'raider', 'rapparee', 'ravager', 'ravisher'],
    'plundering': ['banditry', 'brigandage', 'brigandism', 'depredation', 'despoiling', 'despoilment', 'despoliation', 'direption', 'foraging', 'foray', 'freebooting', 'looting'],
    'plunge': ['abate', 'ablate', 'advance', 'agiotage', 'ante', 'ante up', 'arbitrage', 'ascend', 'back', 'back up', 'bate', 'be caught short'],
    'plunge into': ['accept', 'acquiesce', 'agree', 'assume', 'attack', 'attempt', 'bayonet', 'be agreeable to', 'be dying to', 'be eager', 'be game', 'be open to'],
    'plunger': ['adventurer', 'betting ring', 'bettor', 'big operator', 'boneshaker', 'cardshark', 'cardsharp', 'cardsharper', 'compulsive gambler', 'crap shooter', 'deep-sea diver', 'diver'],
    'plunging': ['brownian movement', 'abrupt', 'abysmal', 'abyssal', 'advance', 'angular motion', 'ascending', 'ascent', 'axial', 'axial motion', 'back', 'back-flowing'],
    'plunk': ['abruptly', 'bang', 'bash', 'bat', 'beating', 'belt', 'biff', 'blow', 'bonk', 'bump', 'cast', 'chink'],
    'plural': ['a certain number', 'a few', 'certain', 'composite', 'dual', 'more', 'more than one', 'nonuniqueness', 'not singular', 'number', 'numerous', 'numerousness'],
    'pluralism': ['nazism', 'a certain number', 'a few', 'admixture', 'alloyage', 'amalgamation', 'blending', 'capriciousness', 'centralism', 'changeability', 'changeableness', 'choppiness'],
    'pluralistic': ['absolute', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'blended', 'bureaucratic', 'capricious'],
    'plurality': ['a mass of', 'a world of', 'army', 'best part', 'better part', 'bevy', 'body', 'bulk', 'bunch', 'cloud', 'clutter', 'covey'],
    'plus': ['above', 'accessory', 'add', 'added', 'added to', 'addend', 'addition', 'additional', 'additionally', 'adjoin', 'advantage', 'affix'],
    'plush': ['babylonian', 'corinthian', 'awe-inspiring', 'awful', 'barbaric', 'blubber', 'breeze', 'butter', 'classy', 'clay', 'costly', 'cottony'],
    'pluto': ['agdistis', 'aides', 'aidoneus', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus'],
    'plutocrat': ['daddy warbucks', 'billionaire', 'bloated plutocrat', 'capitalist', 'fat cat', 'man of means', 'man of substance', 'man of wealth', 'millionaire', 'moneybags', 'moneyed man', 'multimillionaire'],
    'ply': ['about ship', 'apply pressure', 'back and fill', 'bear away', 'bear off', 'bear to starboard', 'beat', 'beat about', 'beat to windward', 'beset', 'besiege', 'blandish'],
    'plywood': ['beam', 'billet', 'board', 'boarding', 'clapboard', 'coat', 'coating', 'collop', 'cord', 'cordwood', 'covering', 'cut'],
    'pneuma': ['anima', 'anima humana', 'animating force', 'animus', 'atman', 'ba', 'bathmism', 'beating heart', 'biological clock', 'biorhythm', 'blood', 'breath'],
    'pneumatic': ['junoesque', 'aerial', 'aeriform', 'aerodynamic', 'aerographic', 'aerologic', 'aeromechanical', 'aerophysical', 'aerostatic', 'aerotechnical', 'aery', 'agreeable'],
    'pneumatics': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics'],
    'pneumonia': ['african lethargy', 'asiatic cholera', 'asiatic flu', 'chagres fever', 'german measles', 'haverhill fever', 'hong kong flu', 'acute articular rheumatism', 'acute bronchitis', 'adenoiditis', 'ague', 'alkali disease'],
    'poach': ['abstract', 'and', 'annex', 'appropriate', 'bag', 'bake', 'barbecue', 'baste', 'blanch', 'boil', 'boost', 'borrow'],
    'poacher': ['body snatcher', 'booster', 'chicken thief', 'con man', 'crook', 'den of thieves', 'embezzler', 'filcher', 'ganef', 'ghoul', 'grafter', 'grave robber'],
    'poaching': ['abstraction', 'annexation', 'appropriation', 'baking', 'barbecuing', 'basting', 'boiling', 'boosting', 'braising', 'brewing', 'broil', 'broiling'],
    'pock': ['abscess', 'alveolation', 'alveolus', 'aposteme', 'bed sore', 'birthmark', 'blackhead', 'blain', 'bleb', 'blemish', 'blister', 'boil'],
    'pocked': ['alveolar', 'alveolate', 'bespangled', 'blotched', 'blotchy', 'dented', 'depressed', 'dimpled', 'dotted', 'dotty', 'engraved', 'faveolate'],
    'pocket': ['cat', 'swiss bank account', 'abstract', 'acquire', 'aerospace', 'aerosphere', 'air hole', 'air pocket', 'airspace', 'alveolation', 'alveolus', 'antrum'],
    'pocketbook': ['domesday book', 'account book', 'address book', 'adversaria', 'album', 'annual', 'appointment calendar', 'appointment schedule', 'bag', 'billfold', 'blankbook', 'blotter'],
    'pockmark': ['alveolation', 'alveolus', 'birthmark', 'blackhead', 'bleb', 'blemish', 'blister', 'bulla', 'check', 'cicatrix', 'comedo', 'crack'],
    'pockmarked': ['alveolar', 'alveolate', 'bespangled', 'blotched', 'blotchy', 'dented', 'depressed', 'dimpled', 'dotted', 'dotty', 'engraved', 'faveolate'],
    'pocky': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bespangled', 'bilious', 'blotched', 'blotchy', 'broken', 'bumpy', 'cancerous', 'chlorotic'],
    'pod': ['army', 'bark', 'bay window', 'boll', 'bran', 'bunch', 'burr', 'capsule', 'case', 'chaff', 'cod', 'colony'],
    'podgy': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blocky', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky'],
    'podiatrist': ['anesthesiologist', 'cardiologist', 'chiropodist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'immunologist', 'internist', 'neurologist', 'obstetrician'],
    'podium': ['balcony', 'catafalque', 'dais', 'emplacement', 'estrade', 'floor', 'gallery', 'heliport', 'hustings', 'landing', 'landing pad', 'landing stage'],
    'poem': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'article', 'autograph', 'balada'],
    'poesy': ['apollo', 'apollo musagetes', 'bragi', 'calliope', 'castilian spring', 'erato', 'euterpe', 'helicon', 'hippocrene', 'muse', 'parnassus', 'pierian spring'],
    'poet': ['meistersinger', 'parnassian', 'advertising writer', 'annalist', 'arch-poet', 'art critic', 'author', 'authoress', 'ballad maker', 'balladist', 'balladmonger', 'bard'],
    'poetic': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'parnassian', 'pierian', 'pindaric', 'theocritean', 'aesthetic', 'airy', 'artistic'],
    'poetic justice': ['ars poetica', 'defensibility', 'drumhead justice', 'dueness', 'equitableness', 'equity', 'evenhandedness', 'give-and-take', 'justice', 'justifiability', 'justifiableness', 'justification'],
    'poetry': ['apollo', 'apollo musagetes', 'bragi', 'calliope', 'castilian spring', 'erato', 'euterpe', 'helicon', 'hippocrene', 'muse', 'parnassus', 'pierian spring'],
    'poignancy': ['acerbity', 'acidity', 'acidulousness', 'acridity', 'acrimony', 'asperity', 'astringency', 'bite', 'bitingness', 'bitterness', 'bleakness', 'causticity'],
    'poignant': ['absorbing', 'acerbic', 'acid', 'acidulous', 'acrid', 'acrimonious', 'acute', 'affecting', 'afflictive', 'agitating', 'agonizing', 'asperous'],
    'point': ['thule', 'ultima thule', 'abode', 'accent', 'accentuate', 'ace', 'acerbity', 'acidity', 'acme', 'acridity', 'acrimony', 'aculeate'],
    'point at': ['address to', 'advert to', 'aim', 'aim at', 'allude to', 'be taken as', 'bend', 'bring to attention', 'bring to notice', 'call attention to', 'cite', 'denominate'],
    'point blank': ['absolutely', 'dead', 'definitely', 'directly', 'even', 'exactly', 'expressly', 'faithfully', 'flush', 'full', 'in all respects', 'in every respect'],
    'point of view': ['anschauung', 'angle', 'angle of vision', 'approach', 'assumption', 'attitude', 'basis', 'belief', 'climate of opinion', 'coign of vantage', 'common belief', 'community sentiment'],
    'point out': ['address to', 'advert', 'advert to', 'allude', 'allude to', 'assign', 'be taken as', 'bring to attention', 'bring to notice', 'bring up', 'call attention to', 'cite'],
    'point to': ['account for', 'accredit with', 'accrete to', 'acknowledge', 'address to', 'advert to', 'aim', 'aim at', 'allude to', 'apply to', 'approve', 'argue'],
    'point up': ['accent', 'accentuate', 'belabor', 'dwell on', 'emphasize', 'give emphasis to', 'harp on', 'highlight', 'italicize', 'overaccentuate', 'overemphasize', 'overstress'],
    'point-blank': ['abrupt', 'abruptly', 'blunt', 'bluntly', 'candidly', 'categorical', 'categorically', 'close', 'direct', 'directly', 'downright', 'explicit'],
    'pointed': ['attic', 'spartan', 'v-shaped', 'y-shaped', 'abbreviated', 'abridged', 'acanthoid', 'acanthous', 'accented', 'accentuated', 'acicular', 'aciform'],
    'pointedly': ['abundantly', 'acutely', 'advisedly', 'amazingly', 'amply', 'aphoristically', 'astonishingly', 'awesomely', 'briefly', 'brusquely', 'by design', 'calculatedly'],
    'pointer': ['gyropilot', 'advice', 'alerting', 'arrow', 'automatic pilot', 'blaze', 'boatheader', 'boatsteerer', 'caution', 'cicerone', 'clue', 'compass needle'],
    'pointless': ['abrupt', 'absurd', 'aimless', 'arid', 'asinine', 'barren', 'blah', 'blank', 'bloodless', 'bluff', 'blunt', 'blunt-edged'],
    'pointlessly': ['aimlessly', 'aridly', 'barrenly', 'bloodlessly', 'bootlessly', 'colorlessly', 'dismally', 'draggily', 'drearily', 'drearisomely', 'dryly', 'dully'],
    'pointlessness': ['absurdity', 'aimlessness', 'aridity', 'barrenness', 'bloodlessness', 'bootlessness', 'characterlessness', 'colorlessness', 'deadness', 'dismalness', 'dragginess', 'dreariness'],
    'poise': ['accommodate', 'action', 'actions', 'activity', 'acts', 'address', 'adjust', 'affectation', 'air', 'aplomb', 'arrogance', 'aspire'],
    'poised': ['apoise', 'arrogant', 'assured', 'balanced', 'calm', 'cocksure', 'collected', 'composed', 'confident', 'controlled', 'convinced', 'cool'],
    'poison': ['cain', 'ddd', 'ddt', 'paris green', 'abomination', 'abuse', 'acaricide', 'activate', 'adulterate', 'adulteration', 'afflict', 'aggrieve'],
    'poisoned': ['activated', 'autoluminescent', 'bad', 'cankered', 'charged', 'contaminated', 'diseased', 'gangrened', 'gangrenous', 'hot', 'infected', 'irradiated'],
    'poisoner': ['cain', 'apache', 'assassin', 'assassinator', 'bloodletter', 'bloodshedder', 'bravo', 'burker', 'butcher', 'button man', 'cannibal', 'cutthroat'],
    'poisoning': ['adulteration', 'autointoxication', 'bane', 'befouling', 'beheading', 'blood', 'blood poisoning', 'bloodletting', 'bloodshed', 'braining', 'burning', 'capital punishment'],
    'poisonous': ['bad', 'baleful', 'baneful', 'barfy', 'brackish', 'catching', 'cloying', 'communicable', 'contagious', 'corroding', 'corrosive', 'corrupting'],
    'poke': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'amble', 'arouse', 'assault', 'awaken', 'bag', 'balefire', 'balloon', 'bang'],
    'poke around': ['beat about', 'beat the bushes', 'burrow', 'delve', 'dig', 'explore', 'feel around', 'feel for', 'forage', 'frisk', 'fumble', 'go through'],
    'poker': ['andiron', 'chain', 'coal tongs', 'crane', 'crook', 'damper', 'fire hook', 'fire tongs', 'firedog', 'grate', 'grating', 'grid'],
    'poker face': ['anesthesia', 'autism', 'catatonia', 'chill', 'chilliness', 'cold blood', 'cold heart', 'coldheartedness', 'coldness', 'coolness', 'deadpan', 'dispassion'],
    'poker faced': ['abstract', 'blank', 'colorless', 'deadpan', 'detached', 'disinterested', 'dispassionate', 'earnest', 'empty', 'expressionless', 'fishy', 'glassy'],
    'poking': ['ambling', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'deliberate', 'delving', 'digging', 'easy', 'faltering'],
    'poky': ['abject', 'abominable', 'ambling', 'arid', 'arrant', 'atrocious', 'banausic', 'barren', 'base', 'beat-up', 'bedraggled', 'beggarly'],
    'polar': ['antarctic', 'arctic', 'siberian', 'antagonistic', 'antipodal', 'antipodean', 'antithetic', 'antithetical', 'boundary', 'brumal', 'caudal', 'conclusive'],
    'polaris': ['aldebaran', 'canicula', 'dog star', 'hesper', 'hesperus', 'lucifer', 'north star', 'phosphor', 'phosphorus', 'sirius', 'venus', 'vesper'],
    'polarity': ['janus', 'n pole', 's pole', 'ambiguity', 'ambivalence', 'antagonism', 'anteposition', 'antipathy', 'antithesis', 'balance', 'biformity', 'bifurcation'],
    'polarization': ['n pole', 's pole', 'agreement to disagree', 'anteposition', 'antigravity', 'antithesis', 'centrifugal force', 'confrontation', 'confrontment', 'contention', 'contraposition', 'contrariety'],
    'polarize': ['bump heads', 'confront', 'contend', 'contrapose', 'contraposit', 'contrast', 'counteract', 'face', 'front', 'lie opposite', 'match', 'meet head-on'],
    'polarizing': ['aggressive', 'bellicose', 'belligerent', 'bickering', 'combative', 'disputatious', 'divisive', 'eristic', 'factional', 'factious', 'irascible', 'irritable'],
    'pole': ['china', 'darkest africa', 'god knows where', 'greenland', 'maypole', 'n pole', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 's pole', 'siberia'],
    'pole vault': ['highland fling', 'and jump', 'bounce', 'bound', 'broad jump', 'buck', 'buckjump', 'capriole', 'curvet', 'demivolt', 'flying jump', 'galliard'],
    'polecat': ['cape polecat', 'animal', 'ape', 'bar', 'bear', 'beast', 'cavy', 'chimp', 'chimpanzee', 'coon', 'cur', 'dog'],
    'polemic': ['kilkenny cats', 'philadelphia lawyer', 'altercation', 'apologetics', 'apologia', 'apologist', 'apology', 'arguer', 'argufier', 'argument', 'argumentation', 'bicker'],
    'polemical': ['aggressive', 'argumental', 'argumentative', 'bellicose', 'belligerent', 'bickering', 'cat-and-dog', 'cat-and-doggish', 'combative', 'contentious', 'controversial', 'dialectic'],
    'poles apart': ['assorted', 'at odds', 'at opposite extremes', 'at variance', 'back to back', 'contrariwise', 'contrary', 'contrasted', 'contrasting', 'counter', 'departing', 'deviating'],
    'polestar': ['aldebaran', 'canicula', 'dog star', 'hesper', 'hesperus', 'lucifer', 'north star', 'phosphor', 'phosphorus', 'polaris', 'sirius', 'venus'],
    'police': ['cheka', 'fbi', 'gestapo', 'interpol', 'mp', 'mvd', 'mounties', 'nkvd', 'ogpu', 'rcmp', 'sp', 'scotland yard'],
    'police officer': ['bobby', 'bull', 'constable', 'cop', 'copper', 'flatfoot', 'fuzz', 'gendarme', 'heat', 'man', 'officer', 'patrolman'],
    'police state': ['absolute monarchy', 'aristocracy', 'autarchy', 'autocracy', 'autonomy', 'coalition government', 'colonialism', 'commonwealth', 'constitutional government', 'constitutional monarchy', 'democracy', 'dictatorship'],
    'police whistle': ['klaxon', 'mayday', 'roman candle', 'sos', 'aid to navigation', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert'],
    'policeman': ['dogberry', 'g-man', 'john law', 'mp', 'bailiff', 'beadle', 'beagle', 'bluebottle', 'bluecoat', 'bobby', 'bound bailiff', 'bull'],
    'policy': ['accident insurance', 'action', 'actuary', 'annuity', 'approach', 'arrangement', 'assurance', 'autarky', 'aviation insurance', 'bail bond', 'behavior', 'bimetallism'],
    'polio': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'apoplexy'],
    'polis': ['stadt', 'ally', 'archduchy', 'archdukedom', 'banlieue', 'body politic', 'boom town', 'borough', 'bourg', 'buffer state', 'burg', 'burgh'],
    'polish': ['atticism', 'abradant', 'abrasive', 'acculturation', 'acquired taste', 'aluminum oxide', 'ameliorate', 'appreciation of excellence', 'appropriateness', 'auto polish', 'beautify', 'better'],
    'polish off': ['ko', 'accomplish', 'achieve', 'attain', 'blast', 'blot out', 'bump off', 'call off', 'cancel', 'compass', 'complete', 'consummate'],
    'polished': ['attic', 'ciceronian', 'accomplished', 'adept', 'advanced', 'ameliorated', 'archetypical', 'beautified', 'bettered', 'buffed', 'burnished', 'chaste'],
    'polite': ['accommodating', 'affable', 'agreeable', 'attentive', 'civil', 'complaisant', 'considerate', 'cordial', 'courteous', 'deferential', 'diplomatic', 'fair'],
    'politeness': ['affability', 'agreeableness', 'amenities', 'amenity', 'civilities', 'civility', 'comity', 'complaisance', 'considerateness', 'convention', 'courteousness', 'courtesy'],
    'politic': ['daedalian', 'machiavellian', 'machiavellic', 'acute', 'adept', 'adroit', 'advantageous', 'advisable', 'appropriate', 'apt', 'arch', 'artful'],
    'political': ['absolute', 'administrative', 'aristocratic', 'authoritarian', 'autocratic', 'autonomous', 'bureaucratic', 'civic', 'civil', 'constitutional', 'democratic', 'despotic'],
    'political party': ['american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party', 'greenback party'],
    'politician': ['admirable crichton', 'mp', 'machiavel', 'machiavellian', 'machiavellianist', 'member of parliament', 'adept', 'administrator', 'artisan', 'artist', 'attache', 'authority'],
    'politics': ['geopolitik', 'machiavellianism', 'machiavellism', 'civics', 'diplomacy', 'diplomatics', 'geopolitics', 'government', 'international relations', 'jobbery', 'jobbing', 'machination'],
    'polity': ['everyman', 'john doe', 'machtpolitik', 'public', 'realpolitik', 'tammany hall', 'administration', 'ally', 'archduchy', 'archdukedom', 'autarky', 'bimetallism'],
    'polka dot': ['bespangled', 'birthmark', 'blaze', 'blemish', 'blotch', 'blotched', 'blotchy', 'brand', 'caste mark', 'check', 'checkmark', 'cicatrix'],
    'poll': ['australian ballot', 'hare system', 'vat', 'abbreviate', 'abridge', 'abstract', 'ad valorem duty', 'agenda', 'alcohol tax', 'amusement tax', 'ask', 'assessment on default'],
    'pollen': ['androcyte', 'antheridium', 'antherozoid', 'male gamete', 'milt', 'protein', 'scum', 'seed', 'semen', 'seminal fluid', 'sperm', 'sperm cell'],
    'polliwog': ['amphibian', 'batrachian', 'birdling', 'bullfrog', 'calf', 'catling', 'chick', 'chickling', 'chicky', 'colt', 'croaker', 'cub'],
    'pollster': ['asker', 'catechist', 'cross-interrogator', 'cross-questioner', 'detective', 'examiner', 'inquirer', 'inquisitionist', 'inquisitor', 'interlocutor', 'interpellator', 'interrogator'],
    'pollute': ['abuse', 'adulterate', 'afflict', 'aggrieve', 'alloy', 'bastardize', 'befoul', 'benasty', 'bewitch', 'blight', 'booze up', 'boozify'],
    'polluted': ['abandoned', 'afflicted', 'bad', 'bad for', 'bent', 'boiled', 'bombed', 'boozy', 'canned', 'cockeyed', 'cockeyed drunk', 'common'],
    'pollution': ['abomination', 'abuse', 'abuse of office', 'adulteration', 'air', 'atrocity', 'bad', 'badness', 'bane', 'bastardizing', 'befouling', 'befoulment'],
    'pollyanna': ['leibnizian optimist', 'aspirant', 'aspirer', 'chiliast', 'daydreamer', 'hopeful', 'hoper', 'irrepressible optimist', 'millenarian', 'millennialist', 'millennian', 'optimist'],
    'poltergeist': ['dingbelle', 'fifinella', 'hob', 'hobgoblin', 'masan', 'ouija', 'puck', 'apparition', 'appearance', 'astral', 'astral spirit', 'automatic writing'],
    'poltroon': ['arrant coward', 'base', 'caitiff', 'chicken', 'coward', 'craven', 'dastard', 'dastardly', 'dunghill', 'dunghilly', 'funk', 'funker'],
    'polyandry': ['beena marriage', 'bigamy', 'common-law marriage', 'companionate marriage', 'concubinage', 'deuterogamy', 'left-handed marriage', 'levirate', 'leviration', 'love match', 'marriage of convenience', 'monandry'],
    'polychromatic': ['bicolor', 'bicolored', 'chromatic', 'cold', 'colorful', 'colorific', 'coloring', 'colory', 'cool', 'crazy', 'daedal', 'dichromatic'],
    'polychrome': ['bicolor', 'bicolored', 'colorful', 'colory', 'crazy', 'daedal', 'dichroism', 'dichromatic', 'dichromatism', 'discolor', 'divers-colored', 'freehand'],
    'polygamy': ['beena marriage', 'bigamy', 'common-law marriage', 'companionate marriage', 'concubinage', 'deuterogamy', 'left-handed marriage', 'levirate', 'leviration', 'love match', 'marriage of convenience', 'monandry'],
    'polyglot': ['atlas', 'bilingual', 'calendar', 'casebook', 'catalog', 'catalogue raisonne', 'city directory', 'classified catalog', 'concordance', 'cyclopedia', 'diatesseron', 'dictionary catalog'],
    'polyhedral': ['bifacial', 'bilateral', 'dihedral', 'flanked', 'handed', 'lateral', 'many-sided', 'multiangular', 'multilateral', 'one-sided', 'polygonal', 'prismatic'],
    'polyhymnia': ['apollo', 'apollo musagetes', 'bragi', 'calliope', 'castilian spring', 'clio', 'erato', 'euterpe', 'helicon', 'hippocrene', 'melpomene', 'muse'],
    'polymer': ['acid', 'acidity', 'adhesive', 'agent', 'alkali', 'alkalinity', 'alloisomer', 'anion', 'antacid', 'atom', 'base', 'biochemical'],
    'polymerization': ['acetification', 'acidification', 'acidulation', 'alkalization', 'carbonation', 'catalysis', 'chemicalization', 'electrolysis', 'ferment', 'fermentation', 'hydrogenation', 'isomerism'],
    'polymerize': ['acetify', 'acidify', 'acidulate', 'alkalify', 'alkalize', 'borate', 'carbonate', 'catalyze', 'chemical', 'chlorinate', 'electrolyze', 'ferment'],
    'polyp': ['abdominal hernia', 'abscess', 'aposteme', 'bed sore', 'blain', 'bleb', 'blister', 'boil', 'bubo', 'bulla', 'bunion', 'canker'],
    'polyphonic prose': ['goliardic verse', 'hudibrastic verse', 'amoebean verse', 'concrete poetry', 'cubist poetry', 'dramatic poetry', 'elegiac poetry', 'epic poetry', 'epopee', 'epos', 'erotic poetry', 'expository prose'],
    'polysyllable': ['antonym', 'articulation', 'expression', 'free form', 'grandiloquence', 'hard word', 'homograph', 'homonym', 'homophone', 'jawbreaker', 'lexeme', 'lexiphanicism'],
    'polytheism': ['acosmism', 'allotheism', 'anthropolatry', 'anthropomorphism', 'anthropotheism', 'autotheism', 'cosmotheism', 'deism', 'ditheism', 'dualism', 'dyotheism', 'henotheism'],
    'polytheist': ['allotheist', 'anthropolater', 'anthropotheist', 'autotheist', 'cosmotheist', 'deist', 'ditheist', 'dualist', 'henotheist', 'hylotheist', 'monotheist', 'multitheist'],
    'pomade': ['anoint', 'balm', 'balsam', 'beeswax', 'brilliantine', 'chrism', 'cold cream', 'collyrium', 'cream', 'daub', 'demulcent', 'dress'],
    'pomander': ['atomizer', 'censer', 'fumigator', 'incense burner', 'incensory', 'odorator', 'odorizer', 'parfumoir', 'perfumer', 'potpourri', 'pouncet-box', 'purse atomizer'],
    'pommel': ['bang', 'baste', 'bastinado', 'batter', 'beat', 'belabor', 'bellyband', 'belt', 'birch', 'buffet', 'cane', 'cinch'],
    'pomp': ['array', 'brilliance', 'buckram', 'caravan', 'cavalcade', 'ceremonial', 'ceremoniousness', 'ceremony', 'circumstance', 'column', 'cortege', 'cosmorama'],
    'pomposity': ['barnumism', 'affectation', 'arrogance', 'assurance', 'assuredness', 'bedizenment', 'belief', 'big talk', 'buckram', 'ceremonial', 'ceremoniousness', 'ceremony'],
    'pompous': ['gongoresque', 'johnsonian', 'latinate', 'affected', 'arrogant', 'assured', 'aureate', 'awkward', 'bedizened', 'big-sounding', 'bloated', 'boastful'],
    'pond': ['artificial lake', 'bayou lake', 'cistern', 'dam', 'dead water', 'dike', 'etang', 'farm pond', 'fishpond', 'freshwater lake', 'glacial lake', 'inland sea'],
    'ponder': ['appraise', 'back down', 'balance', 'be abstracted', 'brood', 'brood over', 'chaw', 'chew over', 'chew the cud', 'cogitate', 'con over', 'consider'],
    'ponderous': ['latinate', 'all thumbs', 'arid', 'awkward', 'barren', 'big', 'blah', 'blank', 'bloodless', 'blunderheaded', 'blundering', 'bombastic'],
    'ponderousness': ['gothicism', 'aridity', 'avoirdupois', 'awkwardness', 'bad taste', 'barbarism', 'barbarousness', 'barrenness', 'beef', 'beefiness', 'bloodlessness', 'bombasticness'],
    'pontiff': ['grand penitentiary', 'holy father', 'abuna', 'antipope', 'archbishop', 'archdeacon', 'archpriest', 'bishop', 'bishop coadjutor', 'canon', 'cardinal', 'cardinal bishop'],
    'pontifical': ['apostolic', 'arrogant', 'bigoted', 'bloated', 'bombastic', 'conceited', 'doctrinaire', 'doctrinarian', 'dogmatic', 'dogmatizing', 'flatulent', 'formal'],
    'pontificate': ['apostolic see', 'barnumize', 'see of rome', 'aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'bishopric', 'blow', 'bombast', 'chairmanship'],
    'pony': ['galloway', 'iceland pony', 'shetland', 'shetland pony', 'amplification', 'bantam', 'banty', 'bawbee', 'bilingual text', 'button', 'chit', 'clavis'],
    'pooch': ['seeing eye dog', 'bandog', 'bitch', 'bowwow', 'canine', 'dog', 'fancy dog', 'guide dog', 'gyp', 'hound', 'kennel', 'lap dog'],
    'pooh pooh': ['barrack', 'bird', 'boo', 'chaff', 'cut', 'cut at', 'cut dead', 'dig at', 'dismiss', 'disregard', 'dump on', 'fleer'],
    'pool': ['aktiengesellschaft', 'swiss bank account', 'accumulate', 'aktiebolag', 'amalgamate', 'artificial lake', 'assets', 'balance', 'bank', 'bank account', 'bayou lake', 'bear pool'],
    'pooling': ['bipartisanship', 'centering', 'centralism', 'centralization', 'coaction', 'coadjuvancy', 'coadministration', 'coagency', 'cochairmanship', 'codirectorship', 'collaboration', 'collaborativeness'],
    'poolroom': ['archery ground', 'athletic field', 'badminton court', 'baseball field', 'basketball court', 'betting house', 'betting parlor', 'billiard parlor', 'bowling alley', 'bowling green', 'casino', 'course'],
    'poop out': ['beat', 'blow', 'blow up', 'break', 'break down', 'burn out', 'cave in', 'collapse', 'come apart', 'come to naught', 'come to nothing', 'come unstuck'],
    'pooped': ['all in', 'anemic', 'apathetic', 'asthenic', 'ausgespielt', 'beat', 'beat up', 'beaten', 'benumbed', 'blase', 'bloodless', 'bone-weary'],
    'poor': ['dp', 'lenten', 'mickey mouse', 'spartan', 'abject', 'abominable', 'abstemious', 'against', 'amateurish', 'arrant', 'artless', 'ascetic'],
    'poor devil': ['bowery bum', 'almsman', 'almswoman', 'bankrupt', 'beachcomber', 'beggar', 'beggarly fellow', 'blighter', 'budmash', 'bum', 'bummer', 'caitiff'],
    'poor taste': ['babbittry', 'bad taste', 'bourgeois taste', 'camp', 'campiness', 'high camp', 'impropriety', 'inappropriateness', 'indecency', 'indecorousness', 'indecorum', 'indelicacy'],
    'poorly': ['abjectly', 'abominably', 'ailing', 'arrantly', 'atrociously', 'badly', 'basely', 'below par', 'commonly', 'contemptibly', 'crudely', 'despicably'],
    'pop': ['babbittish', 'babbittry', 'methuselah', 'philistine', 'abba', 'abruptly', 'alcoholic drink', 'antediluvian', 'antique', 'back number', 'bad taste', 'bag'],
    'pop culture': ['babbittry', 'bad taste', 'bourgeois taste', 'camp', 'campiness', 'high camp', 'impropriety', 'inappropriateness', 'indecency', 'indecorousness', 'indecorum', 'indelicacy'],
    'pop in': ['admit', 'barge in', 'be admitted', 'break in', 'breeze in', 'burst in', 'bust in', 'call', 'come barging in', 'come breezing in', 'come busting in', 'come by'],
    'pop off': ['blow', 'buy it', 'cash in', 'check in', 'check out', 'croak', 'die', 'drop off', 'exit', 'get away', 'get off', 'go'],
    'pop up': ['accomplish', 'achieve', 'appear', 'appear unexpectedly', 'approach', 'arise', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be received'],
    'pope': ['grand penitentiary', 'holy father', 'abuna', 'antipope', 'archbishop', 'archdeacon', 'archpriest', 'bishop', 'bishop coadjutor', 'canon', 'cardinal', 'cardinal bishop'],
    'popeyed': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled', 'bellied'],
    'popeyes': ['baby blues', 'banjo eyes', 'bright eyes', 'bug-eyes', 'clear eyes', 'cockeyes', 'cornea', 'cross-eyes', 'eye', 'eyeball', 'eyelid', 'goggle eyes'],
    'popover': ['danish', 'danish pastry', 'english muffin', 'parker house roll', 'yorkshire pudding', 'bagel', 'bialy', 'bialystoker', 'bun', 'clover-leaf roll', 'coffee cake', 'crescent roll'],
    'popping': ['banging', 'blasting', 'bursting', 'busy', 'cracking', 'crashing', 'exploding', 'explosive', 'flapping', 'fussy', 'hopping', 'humming'],
    'poppycock': ['baloney', 'bilge', 'blah', 'blah-blah', 'bop', 'bosh', 'bull', 'bullshit', 'bunk', 'bunkum', 'chick', 'crap'],
    'populace': ['everyman', 'john doe', 'public', 'body politic', 'bourgeoisie', 'canaille', 'citizenry', 'common man', 'commonage', 'commonalty', 'commoners', 'commonwealth'],
    'popular': ['babbittish', 'philistine', 'accepted', 'accessible', 'acclaimed', 'accustomed', 'admired', 'admitted', 'adored', 'advocated', 'all the rage', 'all the thing'],
    'popular prices': ['bargain prices', 'budget prices', 'cut price', 'easy prices', 'economy prices', 'low price', 'low tariff', 'manageable price', 'moderate price', 'nominal price', 'reasonable charge', 'reasonable price'],
    'popularity': ['amor', 'christian love', 'eros', 'platonic love', 'acceptance', 'acclaim', 'acclamation', 'admiration', 'adoration', 'affection', 'agape', 'applause'],
    'popularize': ['account for', 'allegorize', 'clarify', 'clear up', 'coarsen', 'crack', 'decipher', 'demonstrate', 'demythologize', 'elucidate', 'enlighten', 'euhemerize'],
    'populate': ['anchor', 'billet at', 'bivouac', 'burrow', 'camp', 'colonize', 'come to anchor', 'denizen', 'domesticate', 'drop anchor', 'dwell in', 'empeople'],
    'population': ['beehive', 'cepheid variable', 'everyman', 'hertzsprung-russell diagram', 'hyades', 'john doe', 'messier catalog', 'ngc', 'pleiades', 'public', 'seven sisters', 'absolute magnitude'],
    'populous': ['alive with', 'bristling', 'bursting', 'close', 'colonized', 'compact', 'crammed', 'crawling', 'crowded', 'crowding', 'dense', 'empeopled'],
    'porcelain': ['adobe', 'biscuit', 'bisque', 'bowl', 'brick', 'cement', 'ceramic ware', 'ceramics', 'china', 'clay', 'crock', 'crockery'],
    'porch': ['easter sepulcher', 'french door', 'ambry', 'apse', 'archway', 'back door', 'baptistery', 'barway', 'blindstory', 'bulkhead', 'carriage entrance', 'cellar door'],
    'porcupine': ['cape polecat', 'ape', 'bar', 'bear', 'cavy', 'chimp', 'chimpanzee', 'coon', 'ferret', 'foumart', 'glutton', 'groundhog'],
    'pore': ['eustachian tube', 'fallopian tube', 'aperture', 'avenue', 'blowhole', 'broaching', 'canal', 'cavity', 'channel', 'chasm', 'check', 'chute'],
    'pore over': ['autopsy', 'bone', 'canvass', 'check', 'check out', 'check over', 'check up on', 'con', 'contemplate', 'dig', 'drill', 'elucubrate'],
    'pork': ['bacon', 'butt', 'chitterlings', 'cochon de lait', 'cracklings', 'fat back', 'favors of office', 'flitch', 'gammon', 'ham', 'ham steak', 'haslet'],
    'pork barrel': ['fort knox', 'backscratching', 'bank', 'barter', 'blackmail', 'boodle', 'booty', 'bursary', 'cash register', 'cashbox', 'chest', 'coffer'],
    'pornographic': ['fescennine', 'rabelaisian', 'bawdy', 'blue', 'dirty', 'filthy', 'foul', 'foul-mouthed', 'foul-spoken', 'foul-tongued', 'fulsome', 'impure'],
    'pornography': ['french literature', 'rabelaisianism', 'renaissance literature', 'x-rated movie', 'ancient literature', 'bawdiness', 'bawdry', 'belles lettres', 'blue movie', 'classics', 'contemporary literature', 'dirt'],
    'porous': ['cribriform', 'excretory', 'exudative', 'leachy', 'leaky', 'oozy', 'penetrable', 'percolating', 'percolative', 'permeable', 'pervious', 'porose'],
    'porpoise': ['loch ness monster', 'alevin', 'benthon', 'benthos', 'cetacean', 'dolphin', 'fingerling', 'fish', 'fry', 'game fish', 'grilse', 'kipper'],
    'porridge': ['albumen', 'batter', 'bonnyclabber', 'breakfast food', 'butter', 'cataplasm', 'cereal', 'clabber', 'cornflakes', 'cornstarch', 'cream', 'crush'],
    'port': ['gospel side', 'action', 'actions', 'activity', 'acts', 'address', 'aerodrome', 'affectation', 'air', 'air base', 'airdrome', 'airfield'],
    'portable': ['assignable', 'carriable', 'communicable', 'compact', 'conductive', 'consignable', 'contagious', 'convenient', 'conveyable', 'expressable', 'handy', 'impartable'],
    'portage': ['admission', 'admission fee', 'air express', 'airfreight', 'airlift', 'anchorage', 'asportation', 'bearing', 'brokerage', 'carfare', 'carriage', 'carry'],
    'portal': ['french door', 'archway', 'back door', 'barway', 'bulkhead', 'carriage entrance', 'cellar door', 'cellarway', 'door', 'doorjamb', 'doorpost', 'doorway'],
    'portend': ['adumbrate', 'apprehend', 'augur', 'betoken', 'bode', 'call', 'croak', 'forebode', 'forecast', 'foreshadow', 'foreshow', 'foretoken'],
    'portent': ['adumbration', 'advance notice', 'augury', 'auspice', 'balefulness', 'banefulness', 'betokening', 'betokenment', 'bodefulness', 'boding', 'direness', 'doomfulness'],
    'portentous': ['alarming', 'amazing', 'apocalyptic', 'astonishing', 'astounding', 'awe-inspiring', 'awesome', 'bad', 'baleful', 'baneful', 'black', 'bodeful'],
    'porter': ['aquarius', 'ganymede', 'hebe', 'baggage man', 'bakehead', 'bearer', 'bheesty', 'brakeman', 'brakie', 'busboy', 'butcher', 'caddie'],
    'portfolio': ['baton', 'book end', 'book support', 'book table', 'book tray', 'book truck', 'bookcase', 'bookholder', 'bookrack', 'bookrest', 'bookshelf', 'bookstack'],
    'porthole': ['air hole', 'armhole', 'bay', 'bay window', 'blowhole', 'bow window', 'bullet-hole', 'bunghole', 'casement', 'casement window', 'cringle', 'deadeye'],
    'portico': ['access', 'aisle', 'alley', 'ambulatory', 'aperture', 'arcade', 'artery', 'atlas', 'avenue', 'caryatid', 'channel', 'cloister'],
    'portion': ['friday', 'friday the thirteenth', 'adjunct', 'administer', 'allocate', 'allocation', 'allot', 'allotment', 'allowance', 'amount', 'antepast', 'appanage'],
    'portly': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky', 'corpulent'],
    'portmanteau word': ['ambiguity', 'amphibology', 'blend', 'contamination', 'counterword', 'double entendre', 'equivocal', 'equivocality', 'equivocation', 'equivoque', 'hybrid', 'hybrid word'],
    'portrait': ['telephoto', 'wirephoto', 'account', 'aerial photograph', 'black-and-white photograph', 'cameo', 'candid photograph', 'catalog', 'cataloging', 'certified copy', 'character', 'character sketch'],
    'portraitist': ['aquarellist', 'colorist', 'historical painter', 'landscapist', 'luminarist', 'luminist', 'marine painter', 'miniaturist', 'monochromist', 'oil-colorist', 'painter', 'pavement artist'],
    'portraiture': ['acrylic painting', 'alphabet', 'art', 'blueprint', 'cameo', 'catalog', 'cataloging', 'character', 'character sketch', 'charactering', 'characterization', 'chart'],
    'portray': ['act a part', 'act out', 'bring to life', 'cartoon', 'catch a likeness', 'chalk', 'character', 'characterize', 'charcoal', 'chart', 'color', 'copy'],
    'portrayal': ['acting', 'alphabet', 'aping', 'art', 'blueprint', 'buffoonery', 'business', 'cameo', 'catalog', 'cataloging', 'character', 'character sketch'],
    'portraying': ['apish', 'delineatory', 'depictive', 'echoic', 'embodying', 'figurative', 'graphic', 'ideographic', 'illustrational', 'illustrative', 'imitative', 'incarnating'],
    'pose': ['act', 'acting', 'action', 'actions', 'activity', 'acts', 'address', 'advance', 'affectation', 'affectedness', 'air', 'airs'],
    'pose as': ['act', 'act a part', 'act as', 'act out', 'ape', 'copy', 'do', 'enact', 'impersonate', 'make false pretenses', 'masquerade as', 'mime'],
    'poseidon': ['ab', 'agdistis', 'amor', 'ancient mariner', 'aphrodite', 'apollo', 'apollon', 'ares', 'argonaut', 'artemis', 'ate', 'athena'],
    'poser': ['chinese puzzle', 'gordian knot', 'holy willie', 'joseph surface', 'mawworm', 'pecksniff', 'pharisee', 'tartuffe', 'affecter', 'attitudinarian', 'attitudinizer', 'baffling problem'],
    'poseur': ['ape', 'attitudinarian', 'attitudinizer', 'blagueur', 'bluff', 'bluffer', 'charlatan', 'conformist', 'copier', 'copycat', 'copyist', 'counterfeiter'],
    'posh': ['babylonian', 'corinthian', 'a la mode', 'awe-inspiring', 'awful', 'barbaric', 'braw', 'chic', 'classy', 'clothes-conscious', 'cosmopolitan', 'dapper'],
    'posing': ['acting', 'affectation', 'aping', 'appearance', 'attitudinarianism', 'attitudinizing', 'bluff', 'bluffing', 'characterization', 'cheating', 'color', 'coloring'],
    'posit': ['advance', 'apriorism', 'assert', 'assume', 'hypothesize', 'lay', 'lay down', 'offer', 'park', 'place', 'pose', 'post'],
    'position': ['anschauung', 'parthian shot', 'a priori principle', 'abode', 'address', 'affect', 'affectivity', 'affirmance', 'affirmation', 'allegation', 'allocate', 'angle'],
    'position paper': ['affidavit', 'affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'assertion', 'asseveration', 'averment', 'avouchment', 'avowal', 'bulletin board'],
    'positioned': ['assigned', 'deployed', 'embosomed', 'emplaced', 'ensconced', 'established', 'fixed', 'installed', 'located', 'placed', 'planted', 'posted'],
    'positioning': ['allocation', 'assignment', 'collocation', 'deployment', 'deposit', 'deposition', 'disposition', 'emplacement', 'lading', 'loading', 'localization', 'locating'],
    'positive': ['ditto copy', 'photostat', 'xerox', 'xerox copy', 'absolute', 'accented', 'accentuated', 'accordant', 'actual', 'admitting no exception', 'affirmative', 'affirmatory'],
    'positively': ['ok', 'roger', 'absolutely', 'actually', 'affirmatively', 'all right', 'alright', 'alrighty', 'amen', 'and no mistake', 'as you say', 'assertively'],
    'positivism': ['marxism', 'animalism', 'atomism', 'behaviorism', 'bigotry', 'commonsense realism', 'dialectical materialism', 'dogmaticalness', 'dogmatism', 'down-to-earthness', 'earthiness', 'earthliness'],
    'positivist': ['ass', 'bigot', 'bitter-ender', 'bullethead', 'diehard', 'doctrinaire', 'dogmatist', 'dogmatizer', 'donkey', 'fanatic', 'hardnose', 'infallibilist'],
    'positivistic': ['cyrenaic', 'eleatic', 'epicurean', 'marxian', 'marxist', 'megarian', 'stoic', 'animist', 'animistic', 'atomistic', 'bigoted', 'commonsense'],
    'posse': ['cheka', 'fbi', 'gestapo', 'interpol', 'kp', 'mp', 'mvd', 'mounties', 'nkvd', 'ogpu', 'rcmp', 'sp'],
    'possess': ['achieve', 'acquire', 'appreciate', 'apprehend', 'be acquainted with', 'be apprised of', 'be aware of', 'be cognizant of', 'be conscious of', 'be conversant with', 'be enfeoffed of', 'be informed'],
    'possessed': ['abandoned', 'amok', 'bedeviled', 'bellowing', 'berserk', 'besotted', 'bewitched', 'bursting with happiness', 'by one', 'carried away', 'collected', 'composed'],
    'possession': ['aberration', 'abnormality', 'accessories', 'acquest', 'acquire', 'acquisition', 'affluence', 'alienation', 'ally', 'aplomb', 'appointments', 'appurtenances'],
    'possessive': ['acquisitive', 'ambitious for self', 'autistic', 'careerist', 'controlling', 'covetous', 'dominating', 'domineering', 'egotistical', 'grasping', 'greedy', 'individualistic'],
    'possibility': ['admissibility', 'aptitude', 'aptness', 'best bet', 'capacity', 'chance', 'conceivability', 'contingency', 'delitescence', 'dormancy', 'eventuality', 'favorable prospect'],
    'possible': ['accomplishable', 'achievable', 'admissible', 'advisable', 'algorismic', 'algorithmic', 'aliquot', 'attainable', 'available', 'between the lines', 'cardinal', 'cogitable'],
    'possum': ['cape polecat', 'ape', 'bar', 'bear', 'cavy', 'chimp', 'chimpanzee', 'coon', 'ferret', 'foumart', 'glutton', 'groundhog'],
    'post': ['hermes', 'iris', 'mercury', 'pp', 'paul revere', 'pheidippides', 'rd', 'rfd', 'samson post', 'accredit', 'acquaint', 'acropolis'],
    'postdate': ['international date line', 'afterlife', 'antedate', 'backdate', 'be dated', 'bear date', 'date', 'date at', 'date line', 'date-stamp', 'dateline', 'datemark'],
    'postdated': ['ahead of time', 'anachronistic', 'antedated', 'beforehand', 'behind time', 'behindhand', 'dated', 'early', 'foredated', 'late', 'metachronistic', 'misdated'],
    'posted': ['abreast of', 'as earnest', 'assigned', 'at stake', 'au courant', 'booked', 'briefed', 'deployed', 'deposited', 'documented', 'down', 'educated'],
    'poster': ['advertisement', 'affiche', 'announcement', 'banner', 'bill', 'billboard', 'broadside', 'carrier', 'carrier pigeon', 'circular', 'flier', 'handbill'],
    'posterior': ['aft', 'after', 'aftermost', 'afterpart', 'afterpiece', 'appendant', 'arse', 'ass', 'attendant', 'back', 'back door', 'back seat'],
    'posteriority': ['aftertime', 'afteryears', 'by-and-by', 'coming after', 'consecution', 'consecutiveness', 'continuation', 'continuity', 'course ahead', 'crystal ball', 'descent', 'determinism'],
    'posterity': ['aftermath', 'agnate', 'ancestry', 'backup man', 'blood', 'blood relation', 'blood relative', 'brood', 'children', 'clansman', 'cognate', 'collateral'],
    'postern': ['french door', 'aft', 'after', 'aftermost', 'afterpart', 'afterpiece', 'archway', 'back', 'back door', 'back seat', 'back side', 'backward'],
    'postgraduate': ['academic', 'alumna', 'alumnae', 'alumni', 'alumnus', 'autodidactic', 'bookish', 'college graduate', 'college man', 'college-bred', 'collegiate', 'cross-disciplinary'],
    'posthaste': ['amain', 'apace', 'at flank speed', 'breakneck', 'by airmail', 'by cable', 'by express', 'by return mail', 'by telegraph', 'double-quick', 'expeditious', 'expeditiously'],
    'posthumous': ['after the fall', 'after the flood', 'after the war', 'after-dinner', 'afterdeath', 'delayed', 'late', 'post-obit', 'postbellum', 'postcenal', 'postcibal', 'postdiluvial'],
    'posting': ['allocation', 'appointment', 'assignment', 'booking', 'cataloging', 'chronicling', 'collocation', 'deployment', 'deposit', 'deposition', 'designation', 'disposition'],
    'postmortem': ['autopsy', 'canvass', 'check', 'check out', 'check over', 'check up on', 'coroner', 'examine', 'give an examination', 'go over', 'inquest', 'inspect'],
    'postpone': ['adjourn', 'continue', 'dally', 'defer', 'delay', 'drag out', 'extend', 'hang fire', 'hang up', 'hold off', 'hold over', 'hold up'],
    'postprandial': ['after the fall', 'after the flood', 'after the war', 'after-dinner', 'afterdeath', 'cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'dining', 'eating'],
    'postscript': ['ps', 'parthian shot', 'addendum', 'affix', 'afterthought', 'allonge', 'appendix', 'back matter', 'chorus', 'coda', 'codicil', 'colophon'],
    'postulant': ['abbess', 'abecedarian', 'alphabetarian', 'applicant', 'apprentice', 'articled clerk', 'aspirant', 'beginner', 'bidder', 'boot', 'candidate', 'canoness'],
    'postulate': ['a priori principle', 'a priori truth', 'absolute fact', 'accepted fact', 'actual fact', 'admitted fact', 'advance', 'affirm', 'affirmation', 'apriorism', 'assert', 'assertion'],
    'posture': ['acting', 'action', 'actions', 'activity', 'acts', 'address', 'affect', 'affectation', 'affectivity', 'air', 'appearance', 'arrangement'],
    'posy': ['tl', 'album', 'ana', 'analects', 'bale', 'bindle', 'bloom', 'blossom', 'blow', 'bolt', 'boughpot', 'bouquet'],
    'pot': ['det', 'dmt', 'dutch oven', 'lsd', 'mary jane', 'old mug', 'stp', 'thc', 'abdomen', 'abomasum', 'acid', 'adobe'],
    'potable': ['john barleycorn', 'alcohol', 'alcoholic beverage', 'alcoholic drink', 'aqua vitae', 'ardent spirits', 'beverage', 'booze', 'brew', 'drink', 'drinkable', 'frosted'],
    'potage': ['bisque', 'borscht', 'bouillabaisse', 'bouillon', 'broth', 'burgoo', 'chicken soup', 'chowder', 'clam chowder', 'clear soup', 'consomme', 'egg drop soup'],
    'potation': ['john barleycorn', 'alcohol', 'alcoholic beverage', 'alcoholic drink', 'aqua vitae', 'ardent spirits', 'bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'bender', 'beverage'],
    'potato': ['irish potato', 'kraut', 'aubergine', 'beans', 'cabbage', 'eggplant', 'greens', 'legumes', 'love apple', 'mad apple', 'pieplant', 'potherbs'],
    'potbellied': ['adipose', 'bagging', 'baggy', 'ballooning', 'beefy', 'bellying', 'big-bellied', 'billowing', 'billowy', 'bloated', 'blowzy', 'bosomy'],
    'potbelly': ['abdomen', 'abomasum', 'bay window', 'beerbelly', 'belly', 'blimp', 'breadbasket', 'corporation', 'craw', 'crop', 'diaphragm', 'embonpoint'],
    'potency': ['amperage', 'armipotence', 'ascendancy', 'authoritativeness', 'authority', 'beef', 'birr', 'black power', 'brute force', 'capability', 'carnality', 'charge'],
    'potent': ['absolute', 'amorous', 'armipotent', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'beefy', 'bouncing', 'broad-shouldered', 'carnal'],
    'potentate': ['anointed king', 'chief', 'chieftain', 'crowned head', 'dynast', 'emperor', 'grand duke', 'high chief', 'imperator', 'king', 'king-emperor', 'kinglet'],
    'potential': ['emf', 'ability', 'aptitude', 'bare possibility', 'between the lines', 'budding', 'bump', 'caliber', 'capability', 'capacity', 'chance', 'cogitable'],
    'potentiality': ['amperage', 'armipotence', 'authority', 'bare possibility', 'beef', 'black power', 'brute force', 'chance', 'charge', 'charisma', 'clout', 'cogence'],
    'pothead': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser'],
    'pother': ['abash', 'addle', 'addle the wits', 'ado', 'aggravate', 'aggravation', 'agitation', 'ail', 'annoy', 'badger', 'baffle', 'bafflement'],
    'potholed': ['broken', 'bumpy', 'choppy', 'coarse', 'coarse-grained', 'corrugated', 'cross-grained', 'grainy', 'granulated', 'homespun', 'horripilant', 'inequal'],
    'potion': ['bag', 'bang', 'beverage', 'booster', 'booster dose', 'booster shot', 'brew', 'concoction', 'cup', 'deck', 'decoction', 'dose'],
    'potpourri': ['all sorts', 'assemblage', 'assortment', 'atomizer', 'broad spectrum', 'capriccio', 'caprice', 'censer', 'conglomeration', 'divertissement', 'fantasia', 'fumigator'],
    'potshot': ['aspersion', 'blind bargain', 'bowshot', 'bullet', 'cannon', 'chance at odds', 'charge', 'cock', 'crack', 'criticism', 'cut', 'detonate'],
    'potted': ['afflicted', 'bent', 'boiled', 'bombed', 'boozy', 'canned', 'capsule', 'cockeyed', 'cockeyed drunk', 'crocked', 'crocko', 'elevated'],
    'potter': ['beguile the time', 'burn daylight', 'ceramicist', 'ceramist', 'consume time', 'coquet', 'dabble', 'dally', 'dally away', 'diddle', 'diddle away', 'doodle'],
    'pottery': ['adobe', 'armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'biscuit', 'bisque', 'boatyard', 'boilery', 'bookbindery'],
    'potty': ['absurd', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bedpan', 'bonkers', 'buggy', 'bughouse', 'bugs'],
    'pouch': ['bag', 'balloon', 'beetle', 'belly', 'belly out', 'bilge', 'billow', 'bouge', 'bug', 'bulge', 'dilate', 'distend'],
    'poultice': ['ace bandage', 'band-aid', 'abate', 'adhesive tape', 'allay', 'alleviate', 'anesthetize', 'appease', 'application', 'assuage', 'band', 'bandage'],
    'poultry': ['bantam', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'broiler', 'brooder', 'broody hen', 'capon', 'chanticleer', 'chick', 'chickabiddy'],
    'pounce': ['highland fling', 'ambush', 'and jump', 'attack', 'belly buster', 'belly flop', 'belly whopper', 'bounce', 'bound', 'broad jump', 'buck', 'buckjump'],
    'pounce upon': ['ambush', 'appear unexpectedly', 'assail', 'assault', 'astonish', 'attack', 'be unexpected', 'blitz', 'bob up', 'bounce', 'bound', 'buck'],
    'pound': ['deutschmark', 'mark', 'reichsmark', 'abrade', 'ache', 'afghani', 'agonize', 'ail', 'ambush', 'anguish', 'anna', 'assail'],
    'pound away': ['dig', 'drudge', 'fag', 'grind', 'grub', 'hammer', 'hammer away', 'keep doggedly at', 'moil', 'peg', 'peg away', 'plod'],
    'poundage': ['accommodation', 'avoirdupois', 'beef', 'beefiness', 'burden', 'capacity', 'carriage', 'cartage', 'content', 'cordage', 'deadweight', 'drayage'],
    'pounding': ['abrasion', 'atomization', 'attrition', 'barrage', 'beat', 'beating', 'brecciation', 'clicking', 'comminution', 'crumbling', 'crushing', 'detrition'],
    'pour': ['niagara', 'abound', 'accord', 'administer', 'afford', 'allot', 'allow', 'award', 'bail', 'beat', 'bestow', 'bestow on'],
    'pour forth': ['articulate', 'babble', 'blab', 'blabber', 'blather', 'blether', 'blow out', 'breathe', 'cast forth', 'chat', 'chatter', 'chime'],
    'pour it on': ['ball the jack', 'barrel', 'boom', 'bowl along', 'breeze', 'breeze along', 'brush', 'clip', 'cut along', 'do double duty', 'elucubrate', 'fleet'],
    'pouring': ['affluent', 'blinding', 'cat-and-doggish', 'confluent', 'coursing', 'decurrent', 'defluent', 'diffluent', 'drippy', 'driving', 'drizzling', 'drizzly'],
    'pout': ['bag', 'balloon', 'beetle', 'belly', 'belly out', 'bilge', 'billow', 'bouge', 'brood', 'bug', 'bulge', 'dilate'],
    'poverty': ['beggary', 'dearth', 'destitution', 'difficulty', 'distress', 'embarrassment', 'exigency', 'hand-to-mouth existence', 'hardship', 'impecuniousness', 'impoverishment', 'inadequacy'],
    'poverty stricken': ['beggared', 'beggarly', 'bereaved', 'bereft', 'deprived', 'disadvantaged', 'fleeced', 'ghettoized', 'impoverished', 'in need', 'in rags', 'in want'],
    'pow': ['cageling', 'captive', 'chain gang', 'con', 'convict', 'detenu', 'ex-convict', 'gaolbird', 'internee', 'jailbird', 'lifer', 'parolee'],
    'powder': ['ballistite', 'tnt', 'abrade', 'abscond', 'absquatulate', 'air pollution', 'atomize', 'attritus', 'balm', 'balsam', 'base', 'beat'],
    'powdered': ['branny', 'chalklike', 'chalky', 'comminute', 'comminuted', 'crushed', 'detrital', 'detrited', 'disintegrated', 'dotted', 'dusted', 'dusty'],
    'powdery': ['branny', 'chalklike', 'chalky', 'comminute', 'comminuted', 'crushed', 'detrital', 'detrited', 'disintegrated', 'dusty', 'efflorescent', 'farinaceous'],
    'power': ['establishment', 'vip', 'ability', 'able', 'absolute power', 'absolutism', 'acme', 'activity', 'actuate', 'administration', 'ally', 'ampleness'],
    'power elite': ['establishment', 'vip', 'aristocracy', 'baron', 'barons', 'big gun', 'big man', 'big name', 'bigwig', 'brass', 'brass hat', 'bureaucracy'],
    'power of attorney': ['agency', 'agentship', 'assignment', 'authority', 'authorization', 'brevet', 'care', 'change', 'charge', 'commission', 'commissioning', 'commitment'],
    'power plant': ['action and reaction', 'aeromotor', 'appliance', 'armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'atomic power plant', 'bindery', 'boatyard', 'boilery'],
    'power reactor': ['atomic pile', 'breeder reactor', 'bricks', 'chain reactor', 'chain-reacting pile', 'fast pile', 'furnace', 'heterogeneous reactor', 'homogeneous reactor', 'intermediate pile', 'lattice', 'neutron factory'],
    'power structure': ['amperage', 'animal kingdom', 'aristocracy', 'armipotence', 'authority', 'barons', 'beef', 'black power', 'brute force', 'bureaucracy', 'caste', 'chain of being'],
    'powerful': ['absolute', 'acid', 'armipotent', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'beefy', 'biting', 'bouncing', 'charismatic'],
    'powerfully': ['almighty', 'ardently', 'authoritatively', 'awfully', 'cogently', 'commandingly', 'consequentially', 'deafeningly', 'dynamically', 'effectively', 'effectually', 'eloquently'],
    'powerhouse': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'goliath', 'hercules', 'polyphemus', 'samson', 'superman', 'tarzan'],
    'powerless': ['anemic', 'asthenic', 'bloodless', 'chicken', 'cowardly', 'crippled', 'debilitated', 'decrepit', 'disabled', 'drooping', 'droopy', 'dull'],
    'powers that be': ['john bull', 'rasputin', 'svengali', 'uncle sam', 'vip', 'washington', 'whitehall', 'access', 'bad influence', 'big wheel', 'bureaucracy', 'court'],
    'powwow': ['advise', 'advise with', 'audience', 'bargain', 'bargaining', 'bargaining session', 'call in', 'collogue', 'compare notes', 'conclave', 'confab', 'confabulate'],
    'pox': ['french disease', 'spanish pox', 'vd', 'acquired syphilis', 'balanitis gangrenosa', 'cerebral tabes', 'chancre', 'chancroid', 'clap', 'claps', 'climatic bubo', 'congenital syphilis'],
    'practicability': ['achievability', 'actability', 'applicability', 'attainability', 'availability', 'compassability', 'effectiveness', 'efficacy', 'efficiency', 'feasibility', 'functionality', 'helpfulness'],
    'practicable': ['accessible', 'accomplishable', 'achievable', 'actable', 'attainable', 'banausic', 'compassable', 'doable', 'effective', 'effectual', 'efficient', 'employable'],
    'practical': ['achievable', 'actable', 'adaptable', 'advantageous', 'appliable', 'applicable', 'applied', 'appropriate', 'attainable', 'balanced', 'banausic', 'beneficial'],
    'practical joker': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'actor', 'bad boy', 'bamboozler', 'befuddler', 'beguiler', 'booger'],
    'practicality': ['achievability', 'actability', 'adaptability', 'applicability', 'attainability', 'availability', 'balance', 'common sense', 'compassability', 'convenience', 'cool head', 'coolheadedness'],
    'practically': ['about', 'advantageously', 'advisably', 'all but', 'almost', 'appropriately', 'approximately', 'approximatively', 'as good as', 'as much as', 'at bottom', 'basically'],
    'practice': ['gedankenexperiment', 'mo', 'accordance', 'acquittal', 'acquittance', 'act', 'acting', 'action', 'actions', 'activism', 'activity', 'acts'],
    'practiced': ['accomplished', 'at concert pitch', 'blase', 'career', 'coached', 'conversant', 'cosmopolitan', 'cosmopolite', 'experienced', 'finished', 'initiate', 'initiated'],
    'practicing': ['acting', 'active', 'behavioral', 'compliant', 'conforming', 'conscientious', 'constant', 'devoted', 'devout', 'duteous', 'dutiful', 'faithful'],
    'practised': ['able', 'accomplished', 'adept', 'capable', 'consummate', 'cultivated', 'experienced', 'expert', 'finished', 'gifted', 'masterful', 'perfected'],
    'practitioner': ['actor', 'agent', 'architect', 'author', 'creator', 'doer', 'executant', 'executor', 'executrix', 'fabricator', 'maker', 'medium'],
    'pragmatic': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'advantageous', 'animist', 'animistic', 'appropriate', 'atomistic', 'balanced', 'banausic'],
    'pragmatical': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'advantageous', 'animist', 'animistic', 'appropriate', 'atomistic', 'balanced', 'banausic'],
    'pragmatism': ['marxism', 'r and d', 'animalism', 'atomism', 'behaviorism', 'commonsense realism', 'control', 'control experiment', 'controlled experiment', 'cut and try', 'dialectical materialism', 'down-to-earthness'],
    'prairie': ['lebensraum', 'agricultural region', 'air space', 'alkali flat', 'alluvial plain', 'arable land', 'back country', 'basin', 'billiard table', 'black belt', 'bottomland', 'bowling green'],
    'praise': ['acclaim', 'acclamation', 'accolade', 'acknowledgment', 'adoration', 'adore', 'adulate', 'adulation', 'aggrandize', 'apotheosis', 'apotheosize', 'applaud'],
    'prana': ['anima', 'animating force', 'astral body', 'atman', 'bathmism', 'beating heart', 'biological clock', 'biorhythm', 'blood', 'breath', 'breath of life', 'buddhi'],
    'prance': ['amble', 'barge', 'bob', 'bounce', 'bound', 'bowl along', 'bundle', 'canter', 'caper', 'capriole', 'caracole', 'cavort'],
    'prancing': ['bouncing', 'bounding', 'capering', 'hopping', 'hurdle race', 'hurdling', 'jumping', 'leaping', 'pole vaulting', 'saltant', 'saltation', 'saltatorial'],
    'prandial': ['cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'dining', 'eating', 'feeding', 'flesh-eating', 'fruitarian', 'gastronomic', 'gluttonous'],
    'prank': ['adorn', 'antic', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'caper', 'caprice', 'color', 'conceit', 'dandify'],
    'prankish': ['arch', 'devilish', 'elfish', 'elvish', 'foolish', 'full of mischief', 'high-spirited', 'impish', 'knavish', 'mischief-loving', 'mischievous', 'playful'],
    'prankster': ['bad boy', 'banana', 'booger', 'buffoon', 'bugger', 'burlesquer', 'caricaturist', 'clown', 'comedian', 'comic', 'cutup', 'devil'],
    'prat': ['arse', 'artifice', 'ass', 'backside', 'behind', 'bottom', 'bum', 'can', 'gimmick', 'maneuver', 'play', 'ploy'],
    'prate': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bavardage', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather', 'blether'],
    'pratfall': ['bloomer', 'blooper', 'bobble', 'bonehead play', 'boner', 'boo-boo', 'boob stunt', 'boot', 'breakdown', 'collapse', 'comedown', 'crash'],
    'prattle': ['absurdity', 'accents', 'amphigory', 'babble', 'babblement', 'babbling', 'balderdash', 'bavardage', 'be closeted with', 'bibble-babble', 'blab', 'blabber'],
    'prattler': ['agreeable rattle', 'babbler', 'big talker', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'blatherer', 'chatterbox', 'chatterer', 'gabber', 'gabbler'],
    'prawn': ['dungeness crab', 'japanese crab', 'blue point', 'clam', 'coquillage', 'crab', 'crawdad', 'crawfish', 'crayfish', 'langouste', 'limpet', 'littleneck clam'],
    'praxis': ['act', 'acting', 'action', 'actions', 'activism', 'activity', 'acts', 'address', 'affectation', 'air', 'automatism', 'bad habit'],
    'pray': ['i beg you', 'adjure', 'appeal', 'appeal to', 'apply to', 'ask', 'be good enough', 'beg', 'beseech', 'brace', 'call for help', 'call on'],
    'prayer': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'mass', 'paternoster', 'adjuration', 'adoration', 'aid prayer', 'appeal', 'application'],
    'prayer book': ['sefer torah', 'torah', 'torah scroll', 'virginal', 'best seller', 'book', 'bound book', 'breviary', 'canon', 'church book', 'classic', 'coloring book'],
    'prayerful': ['christian', 'christianlike', 'christianly', 'adorant', 'adoring', 'begging', 'believing', 'cadging', 'cultish', 'cultist', 'cultistic', 'devoted'],
    'preach': ['address', 'admonish', 'advise', 'advocate', 'catechize', 'caution', 'charge', 'counsel', 'deliver a lecture', 'discourse', 'encourage', 'enjoin'],
    'preacher': ['boanerges', 'chalk talker', 'churchman', 'circuit rider', 'clergyman', 'clergywoman', 'cleric', 'clerical', 'clerk', 'discourser', 'divine', 'ecclesiastic'],
    'preaching': ['allurement', 'blandishment', 'cajolement', 'cajolery', 'coaxing', 'conning', 'discourse', 'engagement', 'enlistment', 'exhortation', 'homily', 'hortation'],
    'preachy': ['admonitory', 'advisory', 'cautionary', 'consultative', 'consultatory', 'didactic', 'directive', 'exhortative', 'exhortatory', 'expostulative', 'expostulatory', 'hortative'],
    'preamble': ['avant-propos', 'breakthrough', 'exordium', 'foreword', 'front matter', 'frontispiece', 'innovation', 'introduce', 'introduction', 'leap', 'overture', 'postulate'],
    'prearrange': ['arrange', 'calculate', 'cast', 'clear for action', 'clear the decks', 'concert', 'contrive', 'cook up', 'cure', 'cut out', 'deploy', 'design'],
    'prearranged': ['all ready', 'all set', 'armed', 'armed and ready', 'booted and spurred', 'briefed', 'coached', 'cocked', 'cooked-up', 'cut out', 'cut-and-dried', 'cut-and-dry'],
    'prearrangement': ['approach', 'arrangement', 'attack', 'basic training', 'blueprint', 'blueprinting', 'briefing', 'calculation', 'charting', 'clearing the decks', 'conception', 'contrivance'],
    'precarious': ['ambiguous', 'borderline', 'chancy', 'critical', 'dangerous', 'delicate', 'desultory', 'dicey', 'difficult', 'doubtful', 'dubious', 'equivocal'],
    'precative': ['adjuratory', 'adorant', 'adoring', 'appealing', 'begging', 'beseeching', 'cadging', 'devotional', 'devout', 'entreating', 'imploring', 'in the dust'],
    'precaution': ['alertness', 'anticipation', 'apprehension', 'attention', 'canniness', 'care', 'caution', 'cautiousness', 'chariness', 'circumspection', 'cover', 'discreetness'],
    'precautionary': ['foreboding', 'forehanded', 'forerunning', 'foreseeing', 'foresighted', 'forethoughted', 'forethoughtful', 'forewarning', 'portentous', 'precautional', 'precautious', 'precursive'],
    'precede': ['announce', 'antecede', 'antedate', 'anticipate', 'be before', 'be early', 'be the bellwether', 'beacon', 'blaze the trail', 'break ground', 'break the ice', 'break the trail'],
    'precedence': ['accent', 'accomplishment', 'antecedence', 'antecedency', 'antedate', 'antedating', 'anteposition', 'anteriority', 'anticipation', 'ascendancy', 'authority', 'caste'],
    'precedent': ['action', 'ancestor', 'announcer', 'antecedent', 'anterior', 'antetype', 'antitype', 'archetype', 'avant-garde', 'award', 'bellwether', 'biotype'],
    'preceding': ['above', 'advanced', 'aforegoing', 'aforementioned', 'ante', 'antecedence', 'antecedency', 'antecedent', 'anteposition', 'anterior', 'anteriority', 'anticipatory'],
    'precept': ['a belief', 'adage', 'ana', 'analects', 'aphorism', 'apophthegm', 'apothegm', 'article of faith', 'axiom', 'behest', 'bench warrant', 'bidding'],
    'preceptive': ['authoritative', 'autodidactic', 'binding', 'canonical', 'coeducational', 'commanding', 'compelling', 'cultural', 'decretal', 'decretive', 'decretory', 'dictated'],
    'precinct': ['kreis', 'agora', 'ambit', 'amphitheater', 'approach', 'approximation', 'archbishopric', 'archdiocese', 'area', 'arena', 'arrondissement', 'athletic field'],
    'precincts': ['airspace', 'alentours', 'ambience', 'ambit', 'area', 'belt', 'borderlands', 'circle', 'circuit', 'circumambiencies', 'circumjacencies', 'circumstances'],
    'preciosity': ['gongorism', 'affectation', 'affectedness', 'artfulness', 'artifice', 'artificiality', 'ceremonialism', 'elegance', 'euphemism', 'euphuism', 'exquisiteness', 'formalism'],
    'precious': ['gongoresque', 'gongoristic', 'marinistic', 'absolute', 'admired', 'adored', 'affected', 'alembicated', 'angel', 'arrant', 'artful', 'artificial'],
    'precious stone': ['anklet', 'armlet', 'bangle', 'beads', 'bijou', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet', 'charm', 'chatelaine'],
    'precipice': ['bluff', 'cliff', 'crag', 'crest', 'escarpment', 'face', 'hilltop', 'knoll', 'lofty peak', 'mountaintop', 'palisade', 'palisades'],
    'precipitant': ['abrupt', 'accident-prone', 'breakneck', 'breathless', 'careless', 'desperate', 'devil-may-care', 'electrifying', 'furious', 'harum-scarum', 'hasty', 'headlong'],
    'precipitate': ['a bit previous', 'abrupt', 'accelerate', 'accident-prone', 'ad-lib', 'advance', 'advanced', 'aftereffect', 'aftermath', 'agile', 'alluvion', 'alluvium'],
    'precipitation': ['scotch mist', 'abruptness', 'air speed', 'alacrity', 'alluvion', 'alluvium', 'ash', 'blood rain', 'carelessness', 'celerity', 'cinder', 'clinker'],
    'precipitous': ['abrupt', 'accident-prone', 'acclivitous', 'arduous', 'bluff', 'bold', 'breakneck', 'breathless', 'careless', 'declivitous', 'desperate', 'devil-may-care'],
    'precis': ['abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'apocope', 'brief', 'capsule', 'compend', 'compression', 'condensation', 'condensed version'],
    'precise': ['absolute', 'accurate', 'appreciative', 'attentive', 'authentic', 'be precise', 'careful', 'censorious', 'certain', 'choicy', 'choosy', 'circumscribed'],
    'precisely': ['ok', 'roger', 'absolutely', 'accurately', 'all right', 'alright', 'alrighty', 'amen', 'as well', 'as you say', 'assuredly', 'at the gun'],
    'precisian': ['babbitt', 'middle american', 'philistine', 'anal character', 'bluestocking', 'bourgeois', 'burgher', 'captious critic', 'compulsive character', 'conformer', 'conformist', 'conventionalist'],
    'precision': ['absoluteness', 'accuracy', 'allocation', 'assignment', 'attention', 'attention to detail', 'attention to fact', 'attribution', 'care', 'care for truth', 'carefulness', 'censoriousness'],
    'preclude': ['anticipate', 'avert', 'avoid', 'ban', 'bar', 'bar out', 'block', 'blockade', 'cease', 'check', 'count out', 'cut off'],
    'precluding': ['aside from', 'bar', 'barring', 'beside', 'besides', 'ex', 'except', 'except for', 'excepting', 'excluding', 'exclusive of', 'leaving out'],
    'preclusive': ['deterrent', 'deterring', 'discouraging', 'ethnocentric', 'exceptional', 'excluding', 'exclusive', 'exclusory', 'forbidding', 'forestalling', 'inadmissible', 'inhibitive'],
    'precocious': ['a bit previous', 'advanced', 'ahead', 'bright', 'developed', 'early', 'far ahead', 'forward', 'gifted', 'half-baked', 'half-cocked', 'hasty'],
    'precognition': ['a priori knowledge', 'anticipation', 'apprehension', 'buddhi', 'clairvoyance', 'command', 'comprehension', 'conception', 'conceptualization', 'direct apprehension', 'foreboding', 'foreknowing'],
    'precognitive': ['anticipant', 'anticipatory', 'clairvoyant', 'divinatory', 'farseeing', 'farsighted', 'feeling', 'forehanded', 'foreknowing', 'foreseeing', 'foresighted', 'forethoughted'],
    'preconceived': ['anticipatory', 'beforehand', 'biased', 'forejudged', 'judged beforehand', 'preconceptual', 'preconcluded', 'predecided', 'predetermined', 'predisposed', 'predispositional', 'prejudged'],
    'preconception': ['assumption', 'bent', 'bias', 'delusion', 'favoritism', 'forejudgment', 'idee fixe', 'illusion', 'inclination', 'jaundice', 'jaundiced eye', 'leaning'],
    'preconscious': ['anima', 'coconscious', 'collective unconscious', 'conscience', 'conscious self', 'death instinct', 'ego', 'ego ideal', 'ego-id conflict', 'ethical self', 'foreconscious', 'id'],
    'preconsideration': ['aforethought', 'calculatedness', 'calculation', 'caution', 'deliberateness', 'deliberation', 'express intention', 'expressness', 'forejudgment', 'forethought', 'intentionality', 'parti pris'],
    'precursor': ['advance guard', 'agent', 'airhead', 'alterant', 'alterative', 'alterer', 'ancestor', 'ancestors', 'announcer', 'antecedence', 'antecedency', 'antecedent'],
    'precursory': ['antecedent', 'anterior', 'augural', 'chief', 'exordial', 'first', 'foreboding', 'foregoing', 'foremost', 'forerunning', 'foreshadowing', 'foreshowing'],
    'predacious': ['all-devouring', 'all-engulfing', 'bloodsucking', 'cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'dining', 'eating', 'extortionate', 'feeding'],
    'predate': ['announce', 'antecede', 'antedate', 'anticipate', 'backdate', 'be before', 'be dated', 'be early', 'bear date', 'come before', 'date', 'date at'],
    'predatory': ['all-devouring', 'all-engulfing', 'avaricious', 'bloodsucking', 'carnivorous', 'despoiling', 'extortionate', 'grabby', 'grasping', 'greedy', 'larcenous', 'looting'],
    'predecessor': ['ancestor', 'ancestors', 'announcer', 'antecedent', 'antecedents', 'ascendants', 'avant-garde', 'bellwether', 'buccinator', 'bushwhacker', 'elders', 'explorer'],
    'predestination': ['absolute certainty', 'absoluteness', 'assurance', 'assuredness', 'certain knowledge', 'certainness', 'certainty', 'certitude', 'dead certainty', 'decree', 'definiteness', 'destiny'],
    'predestined': ['absolute', 'apodictic', 'bound', 'certain', 'clear', 'clear and distinct', 'clear as day', 'conclusive', 'decisive', 'definite', 'determinate', 'foreordained'],
    'predetermination': ['absolute certainty', 'absoluteness', 'act of god', 'aforethought', 'assurance', 'assuredness', 'calculatedness', 'calculation', 'certain knowledge', 'certainness', 'certainty', 'certitude'],
    'predetermine': ['be predisposed', 'calculate', 'destine', 'determine', 'fate', 'forejudge', 'foreordain', 'forethink', 'go off half-cocked', 'judge beforehand', 'jump the gun', 'plan'],
    'predetermined': ['absolute', 'aforethought', 'apodictic', 'bound', 'certain', 'clear', 'clear and distinct', 'clear as day', 'conclusive', 'decisive', 'definite', 'destined'],
    'predicament': ['adverse circumstances', 'adversity', 'affliction', 'aggravation', 'annoyance', 'baffle', 'bafflement', 'bearings', 'bewilderment', 'bind', 'blight', 'blood'],
    'predicate': ['ic analysis', 'advance', 'affirm', 'affirmance', 'affirmation', 'allegation', 'allege', 'announce', 'announcement', 'annunciate', 'annunciation', 'appositive'],
    'predicated': ['affirmed', 'alleged', 'announced', 'asserted', 'asseverated', 'attested', 'averred', 'avouched', 'avowed', 'based on', 'boxed in', 'certified'],
    'predication': ['affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'assertion', 'asseveration', 'averment', 'avouchment', 'avowal', 'conclusion', 'creed'],
    'predict': ['adumbrate', 'anticipate', 'approach', 'augur', 'auspicate', 'await', 'be destined', 'be fated', 'be imminent', 'be to be', 'be to come', 'bet'],
    'predictability': ['authenticity', 'authoritativeness', 'calculability', 'dependability', 'divinability', 'faithworthiness', 'firmness', 'foreknowableness', 'foreseeability', 'foretellableness', 'frequency curve', 'frequency distribution'],
    'predictable': ['anticipatable', 'anticipated', 'apt', 'balanced', 'calculable', 'cool', 'dependable', 'divinable', 'expected', 'fair', 'faithful', 'faithworthy'],
    'predicted': ['approaching', 'augured', 'coming', 'desired', 'destinal', 'destined', 'determined', 'emergent', 'eventual', 'extrapolated', 'fatal', 'fated'],
    'prediction': ['aftertime', 'afteryears', 'anticipation', 'augury', 'by-and-by', 'cast', 'conjecture', 'contemplation', 'course ahead', 'crystal ball', 'determinism', 'discretion'],
    'predictive': ['apocalyptic', 'augural', 'auguring', 'divinatory', 'fatidic', 'forecasting', 'forerunning', 'foreseeing', 'foreshadowing', 'foreshowing', 'foretelling', 'foretokening'],
    'predictor': ['cassandra', 'druid', 'astrologer', 'augur', 'calamity howler', 'crystal gazer', 'divinator', 'diviner', 'divineress', 'forecaster', 'foreknower', 'foreseer'],
    'predilection': ['a thing for', 'affinity', 'animus', 'aptitude', 'aptness', 'bag', 'bent', 'bias', 'cast', 'character', 'chosen kind', 'conatus'],
    'predispose': ['affect', 'bend', 'bias', 'color', 'dispose', 'impress', 'incline', 'induce', 'influence', 'lead', 'move', 'persuade'],
    'predisposed': ['acquiescent', 'agreeable', 'alacritous', 'amenable', 'apt', 'apt to', 'ardent', 'bent', 'calculated to', 'compliant', 'consenting', 'content'],
    'predisposition': ['a thing for', 'affinity', 'animus', 'aptitude', 'aptness', 'bag', 'bent', 'bias', 'cast', 'character', 'chosen kind', 'conatus'],
    'predominance': ['accomplishment', 'advantage', 'ascendance', 'ascendancy', 'authority', 'balance of power', 'charisma', 'charm', 'clout', 'consequence', 'control', 'credit'],
    'predominant': ['all-absorbing', 'arch', 'ascendant', 'at the head', 'average', 'banner', 'besetting', 'boss', 'capital', 'cardinal', 'central', 'champion'],
    'predominantly': ['a fortiori', 'above all', 'all in all', 'all the more', 'all things considered', 'altogether', 'as a rule', 'as a whole', 'as an approximation', 'at large', 'broadly', 'broadly speaking'],
    'predominate': ['ascendant', 'be in', 'be in force', 'be the rage', 'be the rule', 'be the thing', 'best', 'bestride', 'better', 'cap', 'control', 'dictate'],
    'predominating': ['accustomed', 'average', 'besetting', 'common', 'commonplace', 'conventional', 'current', 'customary', 'dominant', 'epidemic', 'everyday', 'familiar'],
    'preeminence': ['accent', 'accomplishment', 'ascendance', 'ascendancy', 'balance of power', 'concern', 'concernment', 'consequence', 'consequentiality', 'consideration', 'deanship', 'distinction'],
    'preeminent': ['absolute', 'acmatic', 'all-absorbing', 'apical', 'arch', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'banner', 'capital'],
    'preeminently': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'conspicuously', 'copiously', 'egregiously', 'eminently', 'emphatically', 'exceedingly'],
    'preempt': ['accroach', 'adopt', 'annex', 'appropriate', 'arrogate', 'assume', 'colonize', 'commandeer', 'confiscate', 'conquer', 'enslave', 'expropriate'],
    'preemption': ['adoption', 'appropriation', 'arrogation', 'assumption', 'colonization', 'conquest', 'emption', 'enslavement', 'first option', 'first refusal', 'indent', 'occupation'],
    'preen': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'brush up', 'clean', 'color', 'dandify', 'deck', 'deck out'],
    'prefabricate': ['assemble', 'build', 'cast', 'compose', 'compound', 'concoct', 'construct', 'create', 'devise', 'elaborate', 'erect', 'evolve'],
    'prefabricated': ['assembled', 'built', 'cast', 'constructed', 'crafted', 'created', 'custom', 'custom-built', 'custom-made', 'cut-and-dried', 'cut-and-dry', 'extracted'],
    'prefabrication': ['architecture', 'assembly', 'building', 'casting', 'composition', 'construct', 'construction', 'conversion', 'crafting', 'craftsmanship', 'creation', 'cultivation'],
    'preface': ['acknowledgments', 'anteriority', 'avant-propos', 'back', 'back matter', 'bastard title', 'begin', 'bibliography', 'bold front', 'brave face', 'brave front', 'breakthrough'],
    'prefatory': ['antecedent', 'anterior', 'chief', 'exordial', 'first', 'foremost', 'headmost', 'inaugural', 'inductive', 'initiatory', 'introductory', 'leading'],
    'prefect': ['apprentice teacher', 'archon', 'auditor', 'autodidact', 'chancellor', 'chief executive', 'chief executive officer', 'dean', 'educatee', 'executive', 'executive director', 'executive officer'],
    'prefecture': ['aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'bishopric', 'chairmanship', 'chancellery', 'chancellorate', 'chancellorship', 'chiefery', 'chiefry'],
    'prefer': ['advance', 'aggrandize', 'aim at', 'approve', 'be desirous of', 'be disposed to', 'be partial to', 'bring before', 'bring forward', 'bring up', 'broach', 'choose'],
    'prefer charges': ['accuse', 'allege', 'arraign', 'article', 'book', 'bring accusation', 'bring charges', 'bring to book', 'charge', 'cite', 'complain', 'denounce'],
    'preference': ['affinity', 'alternative', 'alternativity', 'animus', 'antecedence', 'antecedency', 'anteposition', 'anteriority', 'aptitude', 'bag', 'bent', 'bias'],
    'preferment': ['great leap forward', 'advance', 'advancement', 'aggrandizement', 'amelioration', 'amendment', 'apostolic orders', 'appointment', 'ascent', 'bettering', 'betterment', 'boost'],
    'prefiguration': ['actuarial prediction', 'adumbration', 'apocalypse', 'augury', 'auspice', 'betokening', 'betokenment', 'foreboding', 'forecast', 'forecasting', 'foreshadow', 'foreshadowing'],
    'prefigurative': ['apocalyptic', 'augural', 'auguring', 'divinatory', 'fatidic', 'forecasting', 'forerunning', 'foreseeing', 'foreshadowing', 'foreshowing', 'foretelling', 'foretokening'],
    'prefigure': ['adumbrate', 'assume', 'augur', 'be afraid', 'believe', 'betoken', 'body forth', 'cast a horoscope', 'cast a nativity', 'conceive', 'conclude', 'consider'],
    'prefix': ['ic analysis', 'accidence', 'add', 'adjoin', 'affix', 'affixation', 'agglutinate', 'allomorph', 'allonge', 'annex', 'anteriority', 'append'],
    'pregnable': ['aidless', 'assailable', 'attackable', 'beatable', 'conquerable', 'defenseless', 'expugnable', 'fatherless', 'friendless', 'guideless', 'helpless', 'leaderless'],
    'pregnancy': ['abundance', 'appropriateness', 'auspiciousness', 'babyhood', 'beginnings', 'bigness', 'birth', 'bountifulness', 'brooding', 'chargedness', 'childhood', 'convenience'],
    'pregnant': ['abecedarian', 'aboriginal', 'abounding', 'abundant', 'allegorical', 'antenatal', 'anticipating', 'associational', 'autochthonous', 'basal', 'basic', 'beginning'],
    'preheat': ['chafe', 'cook', 'electric-heat', 'fire', 'fire up', 'foment', 'gas-heat', 'heat', 'hot', 'hot up', 'hot-air-heat', 'hot-water-heat'],
    'prehensile': ['acquisitive', 'all-knowing', 'apperceptive', 'appercipient', 'apprehending', 'apprehensive', 'aware', 'clawed', 'cognizant', 'comprehending', 'conscious', 'dentate'],
    'prehension': ['abduction', 'apprehension', 'arrest', 'arrestation', 'bottling up', 'capture', 'catch', 'catching', 'clairvoyance', 'collaring', 'command', 'comprehension'],
    'prehistoric': ['aboriginal', 'ancestral', 'ancient', 'antediluvian', 'antepatriarchal', 'antiquated', 'atavistic', 'autochthonous', 'earliest', 'early', 'erstwhile', 'fore'],
    'prehistoric man': ['australanthropus', 'australopithecus', 'bronze age man', 'cro-magnon man', 'galley hill man', 'gigantopithecus', 'grimaldi man', 'heidelberg man', 'hominidae', 'iron age man', 'neanderthal man', 'oreopithecus'],
    'prejudgment': ['bent', 'bias', 'favoritism', 'forejudgment', 'inclination', 'jaundice', 'jaundiced eye', 'leaning', 'one-sidedness', 'partialism', 'partiality', 'partisanship'],
    'prejudice': ['a thing for', 'abuse', 'affinity', 'afflict', 'aggrieve', 'angle', 'apartheid', 'aptitude', 'aptness', 'bag', 'befoul', 'bend'],
    'prejudiced': ['antiblack', 'biased', 'bigoted', 'chauvinistic', 'closed-minded', 'colored', 'doctrinaire', 'dogmatic', 'influenced', 'interested', 'intolerant', 'jaundiced'],
    'prejudicial': ['bad', 'baleful', 'baneful', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'counterproductive', 'damaging', 'deadly', 'deleterious', 'detrimental'],
    'prelapsarian': ['angelic', 'ante-bellum', 'antediluvian', 'antemundane', 'before the fall', 'before the flood', 'before the war', 'blameless', 'childlike', 'clear', 'dovelike', 'faultless'],
    'prelate': ['grand penitentiary', 'holy father', 'abuna', 'antipope', 'archbishop', 'archdeacon', 'archpriest', 'bishop', 'bishop coadjutor', 'canon', 'cardinal', 'cardinal bishop'],
    'preliminary': ['advance', 'advanced', 'antecedent', 'anterior', 'arrangement', 'avant-garde', 'avant-propos', 'basic training', 'beginning', 'breakthrough', 'briefing', 'chief'],
    'prelude': ['vorspiel', 'antecedence', 'antecedency', 'anteposition', 'anteriority', 'avant-propos', 'breakthrough', 'concert overture', 'curtain raiser', 'descant', 'dominion', 'dramatic overture'],
    'preludial': ['antecedent', 'anterior', 'chief', 'exordial', 'first', 'foremost', 'headmost', 'inaugural', 'inductive', 'initiatory', 'introductory', 'leading'],
    'premature': ['a bit previous', 'advanced', 'beforehand', 'early', 'far ahead', 'forward', 'green', 'half-baked', 'half-cocked', 'hasty', 'ill-considered', 'ill-seasoned'],
    'prematurity': ['forwardness', 'haste', 'hastiness', 'impropriety', 'impulse', 'impulsiveness', 'inappropriateness', 'inauspiciousness', 'inconvenience', 'inexpedience', 'infelicity', 'inopportuneness'],
    'premeditate': ['calculate', 'cook up', 'fix', 'forethink', 'frame', 'frame up', 'pack', 'pack the deal', 'plan', 'plot', 'prearrange', 'preconcert'],
    'premeditated': ['advised', 'aforethought', 'calculated', 'conscious', 'considered', 'contrived', 'cooked-up', 'cut out', 'cut-and-dried', 'cut-and-dry', 'deliberate', 'designed'],
    'premeditation': ['aforethought', 'calculatedness', 'calculation', 'caution', 'deliberateness', 'deliberation', 'express intention', 'expressness', 'forethought', 'frame-up', 'intentionality', 'packed deal'],
    'premier': ['pm', 'all-absorbing', 'arch', 'capital', 'cardinal', 'champion', 'chancellor', 'chief', 'chief executive', 'chief of state', 'controlling', 'dewan'],
    'premiere': ['be a gas', 'be a hit', 'benefit', 'bill', 'bomb', 'debut', 'dramatize', 'entertainment', 'exhibit', 'exhibition', 'fail', 'farewell performance'],
    'premise': ['a priori principle', 'affirmation', 'ancestor', 'antecedent', 'apriorism', 'argue', 'assert', 'assertion', 'assume', 'assumed position', 'assumption', 'avant-propos'],
    'premises': ['airspace', 'area', 'belt', 'confines', 'continental shelf', 'corridor', 'country', 'department', 'district', 'division', 'environs', 'ground'],
    'premium': ['trinkgeld', 'abatement', 'agio', 'allowance', 'appreciation', 'at a premium', 'award', 'bait', 'bank discount', 'bank rate', 'bonus', 'bonus system'],
    'premonition': ['esp', 'advance notice', 'apprehensiveness', 'clairsentience', 'clairvoyance', 'extrasensory perception', 'feeling', 'foreboding', 'forefeeling', 'foresight', 'forewarning', 'funny feeling'],
    'premonitory': ['augural', 'foreboding', 'forerunning', 'foreshadowing', 'foreshowing', 'foretokening', 'forewarning', 'heavy with meaning', 'indicative', 'intuitive', 'meaningful', 'monitory'],
    'prenatal': ['abecedarian', 'aboriginal', 'antenatal', 'autochthonous', 'beginning', 'budding', 'creative', 'elemental', 'elementary', 'embryonic', 'fetal', 'formative'],
    'preoccupation': ['walter mitty', 'absence of mind', 'absentmindedness', 'absorbed attention', 'absorption', 'abstractedness', 'abstraction', 'abulia', 'adoption', 'adverse possession', 'alienation', 'alodium'],
    'preoccupied': ['absent', 'absentminded', 'absorbed', 'absorbed in', 'abstracted', 'assiduous', 'bemused', 'besotted', 'blind', 'buried in', 'buried in thought', 'castle-building'],
    'preoccupy': ['absorb', 'absorb the attention', 'adopt', 'appropriate', 'arrest', 'arrogate', 'assume', 'beset', 'catch', 'charm', 'colonize', 'come uppermost'],
    'prep': ['arrange', 'arrangement', 'basic training', 'briefing', 'clear for action', 'clear the decks', 'clearing the decks', 'cure', 'deploy', 'dress', 'equipment', 'familiarization'],
    'preparation': ['accouterment', 'adaptation', 'anticipation', 'apprenticeship', 'architecture', 'armament', 'arrangement', 'arrangements', 'assembly', 'balm', 'balsam', 'basic training'],
    'preparatory': ['antecedent', 'anterior', 'basic', 'before', 'chief', 'elementary', 'essential', 'exordial', 'first', 'foremost', 'fundamental', 'headmost'],
    'preparatory school': ['gymnasium', 'latin school', 'realgymnasium', 'realschule', 'academy', 'grammar school', 'high', 'high school', 'intermediate school', 'junior high', 'junior high school', 'middle school'],
    'prepare': ['accommodate', 'accouter', 'adapt', 'afford', 'appoint', 'apprentice', 'arm', 'arrange', 'arrange for', 'assemble', 'author', 'bake'],
    'prepared': ['able', 'accomplished', 'accoutered', 'advance', 'agape', 'agog', 'all agog', 'all ready', 'all set', 'anticipant', 'anticipating', 'anticipative'],
    'preparedness': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'tlc', 'truman doctrine', 'ability', 'alertness', 'anticipation', 'appeasement', 'attention', 'balance of power', 'brinkmanship'],
    'preponderance': ['accomplishment', 'advantage', 'ascendance', 'ascendancy', 'ascendant', 'authority', 'balance of power', 'bulk', 'charisma', 'charm', 'clout', 'consequence'],
    'preponderant': ['arch', 'ascendant', 'at the head', 'banner', 'boss', 'capital', 'cardinal', 'central', 'champion', 'chief', 'commanding', 'controlling'],
    'preponderate': ['best', 'bestride', 'better', 'cap', 'dictate', 'dominate', 'domineer', 'exceed', 'excel', 'go one better', 'have the ascendancy', 'improve on'],
    'preposition': ['adjectival', 'adjective', 'adverb', 'adverbial', 'adversative conjunction', 'attributive', 'conjunction', 'conjunctive adverb', 'coordinating conjunction', 'copulative', 'copulative conjunction', 'correlative conjunction'],
    'prepositional': ['abessive', 'ablative', 'accusative', 'adessive', 'adjectival', 'adverbial', 'allative', 'approximative', 'attributive', 'case', 'common case', 'conjunctive'],
    'prepossess': ['absorb', 'adopt', 'appropriate', 'arrogate', 'assume', 'bend', 'bias', 'busy', 'colonize', 'conquer', 'distort', 'engage'],
    'prepossessed': ['antiblack', 'besotted', 'biased', 'bicolored', 'chauvinistic', 'colored', 'doctrinaire', 'dogmatic', 'fixated', 'gripped', 'held', 'hung-up'],
    'prepossessing': ['alluring', 'appealing', 'appetizing', 'attracting', 'attractive', 'beautiful', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching'],
    'prepossession': ['adoption', 'adverse possession', 'affinity', 'alodium', 'appropriation', 'arrogation', 'assumption', 'bag', 'bent', 'bias', 'burgage', 'chosen kind'],
    'preposterous': ['gothic', 'a bit thick', 'a bit thin', 'absurd', 'asinine', 'balmy', 'barmy', 'baroque', 'barred', 'batty', 'beyond belief', 'bizarre'],
    'prepotency': ['accomplishment', 'amperage', 'armipotence', 'ascendance', 'ascendancy', 'authority', 'balance of power', 'beef', 'black power', 'brute force', 'charge', 'charisma'],
    'prepotent': ['armipotent', 'ascendant', 'at the head', 'authoritative', 'boss', 'chief', 'cogent', 'commanding', 'controlling', 'dominant', 'dynamic', 'effective'],
    'preprandial': ['cannibal', 'cannibalistic', 'carnivorous', 'commensal', 'dietetic', 'dining', 'eating', 'feeding', 'flesh-eating', 'fruitarian', 'gastronomic', 'gluttonous'],
    'prepublication': ['anticipation', 'contemplation', 'discretion', 'envisagement', 'envisionment', 'farseeingness', 'farsightedness', 'forecast', 'foreglance', 'foregleam', 'foreglimpse', 'forehandedness'],
    'prerequisite': ['arrangement', 'bare necessities', 'basic training', 'boundary condition', 'briefing', 'call for', 'called for', 'catch', 'clause', 'clearing the decks', 'condition', 'demand'],
    'prerogative': ['absolute power', 'absolutism', 'accomplishment', 'advantage', 'appanage', 'appurtenance', 'ascendancy', 'authority', 'authorization', 'birthright', 'claim', 'competence'],
    'presage': ['actuarial prediction', 'adumbrate', 'apocalypse', 'apprehensiveness', 'augur', 'augury', 'auspicate', 'bespeak', 'betoken', 'bode', 'boding', 'cast a horoscope'],
    'presaged': ['augured', 'forecast', 'foreknown', 'foreseen', 'foreshadowed', 'foreshown', 'foretokened', 'foretold', 'indicated', 'predicted', 'prefigured', 'preindicated'],
    'presbytery': ['council of nicaea', 'council of trent', 'easter sepulcher', 'lateran council', 'sacred college', 'vatican council', 'abbacy', 'ambry', 'apse', 'archbishopric', 'archdeaconry', 'archiepiscopacy'],
    'preschooler': ['babe', 'baby', 'baby bunting', 'bambino', 'classmate', 'fellow student', 'grade schooler', 'high schooler', 'incubator baby', 'infant', 'intermediate schooler', 'kindergartner'],
    'prescribe': ['administer', 'advise', 'advocate', 'apply', 'appoint', 'assign', 'authorize', 'be responsible for', 'bestow', 'brief', 'call the signals', 'captain'],
    'prescribed': ['accepted', 'authoritative', 'binding', 'bound', 'bounded', 'canonical', 'conditioned', 'confined', 'conformable', 'consuetudinary', 'conventional', 'copyrighted'],
    'prescript': ['act', 'adage', 'ana', 'analects', 'aphorism', 'apothegm', 'axiom', 'bill', 'bylaw', 'byword', 'canon', 'catchword'],
    'prescription': ['procrustean law', 'act', 'adverse possession', 'aid', 'alodium', 'alterative', 'analeptic', 'appurtenance', 'assistance', 'authority', 'balm', 'balsam'],
    'prescriptive': ['absolute', 'accepted', 'accustomed', 'acknowledged', 'admitted', 'authoritarian', 'authoritative', 'autocratic', 'average', 'binding', 'canonical', 'commanding'],
    'presence': ['masan', 'action', 'actions', 'activity', 'acts', 'address', 'adjacency', 'affectation', 'air', 'alertness', 'aplomb', 'apparition'],
    'present': ['christmas present', 'accessible', 'accommodate', 'accord', 'acquaint', 'actual', 'adduce', 'adjacent', 'administer', 'advance', 'affect', 'afford'],
    'present day': ['a la mode', 'actual', 'advanced', 'as is', 'avant-garde', 'being', 'contemporaneous', 'contemporary', 'current', 'existent', 'existing', 'extant'],
    'presentable': ['junoesque', 'ok', 'acceptable', 'adequate', 'admissible', 'agreeable', 'all right', 'allowable', 'amply endowed', 'becoming', 'bequeathable', 'bestowable'],
    'presentation': ['christmas present', 'accommodation', 'accordance', 'account', 'acquaintance', 'acquaintedness', 'advance', 'announcement', 'apostolic orders', 'apparition', 'appearance', 'appearing'],
    'presentiment': ['actuarial prediction', 'advance notice', 'affect', 'affection', 'apocalypse', 'apprehensiveness', 'clairvoyance', 'discomposing', 'discomposure', 'disquietude', 'disturbance', 'emotion'],
    'presently': ['after a while', 'anon', 'at present', 'before long', 'betimes', 'by and by', 'directly', 'ere long', 'in a jiffy', 'in a moment', 'in a while', 'in due course'],
    'presentment': ['accommodation', 'accordance', 'alphabet', 'arraignment', 'art', 'award', 'awarding', 'bail', 'benefit', 'bestowal', 'bestowment', 'bill'],
    'preservation': ['bottling up', 'care', 'cold storage', 'conservancy', 'conservation', 'continuation', 'corking up', 'cover', 'creation', 'custody', 'dead storage', 'defense'],
    'preservative': ['backward', 'brine', 'conservational', 'conservationist', 'conservative', 'conservatory', 'conserving', 'die-hard', 'embalming fluid', 'fogyish', 'formaldehyde', 'keeping'],
    'preserve': ['indian reservation', 'jell-o', 'anhydrate', 'archives', 'asylum', 'attend to', 'baby-sit', 'bank', 'bird sanctuary', 'blancmange', 'blast-freeze', 'bottle up'],
    'preserved': ['conserved', 'held', 'held back', 'held in reserve', 'intact', 'kept', 'protected', 'put by', 'reserved', 'retained', 'saved', 'spare'],
    'preshrunk': ['sanforized', 'attenuated', 'consumed', 'corky', 'dried-up', 'emacerated', 'emaciated', 'parched', 'sear', 'shriveled', 'shriveled up', 'shrunk'],
    'preside': ['administer', 'administer justice', 'administrate', 'be master', 'captain', 'carry on', 'chair', 'chairman', 'command', 'conduct', 'control', 'direct'],
    'presidency': ['acme', 'aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'authority', 'authorization', 'be-all and end-all', 'bishopric', 'blue ribbon', 'captainship'],
    'president': ['academic dean', 'administration', 'administrator', 'archon', 'chancellor', 'chief executive', 'chief executive officer', 'chief of state', 'dean', 'dean of men', 'dean of women', 'dewan'],
    'press': ['ap', 'associated press', 'fleet street', 'reuters', 'upi', 'united press international', 'accelerate', 'advice', 'adviser', 'advocate', 'annex', 'announcer'],
    'press agent': ['federal', 'advertise', 'agent', 'amanuensis', 'baggage agent', 'build up', 'business agent', 'claim agent', 'clerk', 'commercial agent', 'commission agent', 'consignee'],
    'press charges': ['accuse', 'allege', 'arraign', 'article', 'book', 'bring accusation', 'bring charges', 'bring to book', 'charge', 'cite', 'complain', 'denounce'],
    'press notice': ['pr', 'ballyhoo', 'blurb', 'bright light', 'celebrity', 'common knowledge', 'cry', 'currency', 'daylight', 'eclat', 'exposure', 'fame'],
    'press on': ['advance', 'bundle', 'bustle', 'chase', 'continue', 'crowd', 'dash', 'dash off', 'dash on', 'double-time', 'drive', 'drive on'],
    'pressing': ['abetment', 'actuating', 'acute', 'animating', 'blandishment', 'burning', 'buttonholing', 'cajolement', 'cajolery', 'causal', 'causative', 'clamant'],
    'pressure': ['abetment', 'adverse circumstances', 'adversity', 'advocate', 'affliction', 'aggravation', 'albatross', 'annoyance', 'apply pressure', 'argumentum baculinum', 'ascendancy', 'authority'],
    'pressure group': ['black power', 'italian vote', 'jewish vote', 'polish power', 'rasputin', 'svengali', 'vip', 'white power', 'access', 'bad influence', 'big wheel', 'black vote'],
    'prestidigitation': ['prospero', 'airiness', 'appearance', 'conjuration', 'delusiveness', 'escamotage', 'fallaciousness', 'false appearance', 'false light', 'false show', 'falseness', 'hanky-panky'],
    'prestidigitator': ['artist', 'artiste', 'belly dancer', 'burlesque queen', 'chorine', 'chorus boy', 'chorus girl', 'conjurer', 'coryphee', 'dancer', 'dancing girl', 'ecdysiast'],
    'prestige': ['accomplishment', 'admiration', 'adoration', 'apotheosis', 'appreciation', 'approbation', 'approval', 'ascendancy', 'authority', 'awe', 'breathless adoration', 'cachet'],
    'prestigious': ['absolute', 'acclaimed', 'admired', 'adored', 'appreciated', 'ascendant', 'august', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'celebrated'],
    'presto': ['accelerando', 'adagietto', 'adagio', 'affrettando', 'allegretto', 'allegro', 'andante', 'andante tempo', 'andantino', 'beat', 'compound time', 'con anima'],
    'presumable': ['apt', 'assumable', 'conjecturable', 'fair', 'foreseeable', 'hopeful', 'imaginable', 'in the cards', 'liable', 'likely', 'odds-on', 'predictable'],
    'presumably': ['all things considered', 'as it were', 'assumably', 'assumedly', 'assumptively', 'by all odds', 'certainly', 'dollars to doughnuts', 'doubtless', 'doubtlessly', 'in all likelihood', 'in all probability'],
    'presume': ['account', 'account as', 'adjudge', 'adjudicate', 'affect', 'allegorize', 'allow', 'allude to', 'anticipate', 'aspire to', 'assume', 'attempt'],
    'presume upon': ['abuse', 'abuse a privilege', 'bleed', 'bleed white', 'bother', 'deceive', 'drain', 'encroach upon', 'exploit', 'foist on', 'ill-use', 'impose on'],
    'presumed': ['accounted as', 'alleged', 'anticipated', 'assumed', 'assumptive', 'awaited', 'conjectured', 'deemed', 'due', 'expected', 'forejudged', 'foreseen'],
    'presumption': ['adventurousness', 'allegory', 'allusion', 'apriorism', 'aptitude', 'arcane meaning', 'arrogance', 'aspiration', 'assumption', 'assurance', 'assured faith', 'attitude'],
    'presumptive': ['absolute', 'acceptable', 'accounted as', 'adducible', 'admissible', 'alleged', 'apt', 'assumed', 'assumptive', 'attestative', 'attestive', 'authentic'],
    'presumptuous': ['acceptable', 'adventurous', 'arrogant', 'assuming', 'audacious', 'bold', 'brash', 'brazen', 'bumptious', 'busy', 'busybody', 'cheeky'],
    'presuppose': ['affect', 'allegorize', 'allude to', 'assume', 'be afraid', 'be predisposed', 'believe', 'bring', 'bring to mind', 'call for', 'comprise', 'conceive'],
    'presupposed': ['assumed', 'forejudged', 'hinted', 'implicated', 'implied', 'indicated', 'inferred', 'intimated', 'involved', 'judged beforehand', 'meant', 'preconceived'],
    'presupposition': ['a priori principle', 'act', 'affect', 'affirmation', 'allegory', 'allusion', 'apriorism', 'arcane meaning', 'assertion', 'assumed position', 'assumption', 'avant-propos'],
    'pretence': ['airs', 'appearance', 'artifice', 'blind', 'camouflage', 'cloak', 'cover', 'cover-up', 'deception', 'disguise', 'display', 'dodge'],
    'pretend': ['act', 'act a part', 'adopt', 'affect', 'aim to', 'allege', 'appropriate', 'arrogate', 'assume', 'attempt', 'attempt to', 'avow'],
    'pretended': ['affected', 'alleged', 'apocryphal', 'artificial', 'asserted', 'assumed', 'avowed', 'bastard', 'bogus', 'brummagem', 'claimed', 'colorable'],
    'pretender': ['actor', 'affecter', 'arrogator', 'aspirant', 'blagueur', 'bluff', 'bluffer', 'candidate', 'charlatan', 'claimant', 'deceiver', 'fake'],
    'pretense': ['acting', 'affectation', 'affectedness', 'air', 'airs', 'airs and graces', 'alibi', 'apology', 'appearance', 'appurtenance', 'artificiality', 'attitudinizing'],
    'pretension': ['barnumism', 'acting', 'affectation', 'affectedness', 'airs', 'airs and graces', 'alibi', 'ambitions', 'ambitiousness', 'apology', 'appearance', 'appurtenance'],
    'pretentious': ['gongoresque', 'gongoristic', 'johnsonian', 'marinistic', 'affected', 'ambitious', 'arrogant', 'artificial', 'arty', 'aureate', 'bedizened', 'big'],
    'preternatural': ['aberrant', 'anomalous', 'arcane', 'atypical', 'deviant', 'deviative', 'eerie', 'esoteric', 'extramundane', 'extraterrestrial', 'fey', 'heteroclite'],
    'preternaturalism': ['eeriness', 'elfdom', 'faerie', 'miraculousness', 'mysteriousness', 'mystery', 'numinousness', 'otherworldliness', 'superhumanity', 'supernaturalism', 'supernaturality', 'supernaturalness'],
    'pretext': ['acting', 'affectation', 'alibi', 'allege', 'alternative', 'appearance', 'attitudinizing', 'avow', 'bluff', 'bluffing', 'camouflage', 'cheating'],
    'pretreat': ['arrange', 'clear for action', 'clear the decks', 'cure', 'deploy', 'dress', 'fix', 'fix up', 'get ready', 'make arrangements', 'make preparations', 'make ready'],
    'prettify': ['adorn', 'array', 'beautify', 'become one', 'bedeck', 'bedizen', 'blazon', 'color', 'dandify', 'deck', 'deck out', 'decorate'],
    'pretty': ['a bit', 'a little', 'acceptably', 'adequately', 'adroit', 'aesthetic', 'aesthetically appealing', 'almighty', 'appealing', 'attractive', 'awfully', 'beauteous'],
    'pretty up': ['adorn', 'beautify', 'become one', 'bedizen', 'deck out', 'decorate', 'dizen', 'doll up', 'dress up', 'fancy up', 'fig out', 'get up'],
    'prevail': ['abide', 'affect', 'argue into', 'be', 'be blooded', 'be extant', 'be found', 'be in', 'be in existence', 'be in force', 'be met with', 'be present'],
    'prevail upon': ['argue into', 'bring over', 'bring round', 'bring to reason', 'captivate', 'charm', 'con', 'convince', 'draw over', 'gain', 'gain over', 'hook'],
    'prevailing': ['abounding', 'abundant', 'accidental', 'accompanying', 'accustomed', 'ado', 'affecting', 'affluent', 'afloat', 'afoot', 'all-sufficing', 'ample'],
    'prevalence': ['abundance', 'acceptance', 'accustomedness', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'ascendancy', 'avalanche', 'averageness', 'bon ton', 'bonanza'],
    'prevalent': ['abounding', 'abundant', 'accepted', 'accidental', 'accompanying', 'ado', 'affluent', 'afloat', 'afoot', 'all the rage', 'all the thing', 'all-sufficing'],
    'prevaricate': ['around the bush', 'back and fill', 'be untruthful', 'beat about', 'beg the question', 'belie', 'bicker', 'boggle', 'cavil', 'choplogic', 'deceive', 'dodge'],
    'prevarication': ['bickering', 'blague', 'boggling', 'bouncer', 'canard', 'captiousness', 'caviling', 'chicane', 'chicanery', 'cock-and-bull story', 'coloring', 'confabulation'],
    'prevaricator': ['ananias', 'baron munchausen', 'father of lies', 'satan', 'sir john mandeville', 'captious critic', 'caviler', 'consummate liar', 'dirty liar', 'equivocator', 'fabricator', 'fabulist'],
    'prevent': ['abort', 'anticipate', 'arrest', 'avert', 'avoid', 'baffle', 'balk', 'ban', 'bar', 'block', 'check', 'control'],
    'prevention': ['eighteenth amendment', 'prohibition party', 'volstead act', 'abortion', 'anticipation', 'arrest', 'arrestation', 'arresting', 'avoidance', 'avoiding', 'avoiding reaction', 'balk'],
    'preventive': ['aegis', 'antacid', 'anticipative', 'anticipatory', 'antidote', 'arm guard', 'backstop', 'barrier', 'block', 'buffer', 'bulwark', 'bumper'],
    'preview': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'anticipation', 'be a gas', 'be a hit', 'bill', 'black-and-white film', 'bomb', 'cartoon'],
    'previous': ['a bit previous', 'above', 'advanced', 'aforementioned', 'aforesaid', 'ahead', 'ancient', 'ante', 'antecedent', 'anterior', 'anticipatory', 'before'],
    'previously': ['aforetime', 'already', 'at one time', 'before', 'before all', 'before now', 'beforehand', 'beforetime', 'earlier', 'early', 'ere', 'ere then'],
    'prewar': ['ante-bellum', 'antediluvian', 'antemundane', 'before the fall', 'before the flood', 'before the war', 'pre-aryan', 'pre-christian', 'pre-renaissance', 'pre-roman', 'preclassical', 'precultural'],
    'prey': ['aim', 'bamboozle', 'beasts of venery', 'big game', 'bully', 'burden', 'butt', 'by-end', 'by-purpose', 'casualty', 'chase', 'cheat'],
    'priapus': ['ashtoreth', 'astarte', 'baal', 'cailleac', 'ceres', 'demeter', 'dionysus', 'faunus', 'frey', 'isis', 'pan', 'vidar'],
    'price': ['amends', 'amount', 'appraisal', 'appraise', 'asking price', 'assay', 'assess', 'atonement', 'bank rate', 'bearish prices', 'bid price', 'blood money'],
    'price cut': ['abatement', 'agio', 'allowance', 'bank discount', 'break', 'breakage', 'cash discount', 'chain discount', 'charge-off', 'cheapening', 'concession', 'cut'],
    'price support': ['tlc', 'aid', 'alimony', 'allotment', 'allowance', 'annuity', 'assistance', 'autarky', 'bimetallism', 'bounty', 'bread', 'care'],
    'price tag': ['amount', 'billhead', 'book stamp', 'bookplate', 'brand', 'broad arrow', 'cachet', 'charge', 'check', 'colophon', 'cost', 'counterfoil'],
    'priceless': ['absurd', 'amusing', 'beyond price', 'bizarre', 'cherished', 'comical', 'costly', 'dear', 'droll', 'eccentric', 'expensive', 'funny'],
    'pricey': ['costly', 'dear', 'dear-bought', 'excessive', 'exorbitant', 'expensive', 'extortionate', 'fancy', 'high', 'high-priced', 'luxurious', 'not affordable'],
    'prick': ['aculeus', 'acuminate', 'acumination', 'acute pain', 'afflict', 'aggrieve', 'agonize', 'ail', 'anguish', 'auger', 'barb the dart', 'be keen'],
    'prickle': ['aculeus', 'acumination', 'adherent', 'adhesive', 'auger', 'barb', 'barnacle', 'bit', 'borer', 'bramble', 'brier', 'bristle'],
    'prickly': ['acanaceous', 'acanthoid', 'aciculate', 'aculeate', 'aculeolate', 'agitable', 'allergic', 'anaphylactic', 'annoying', 'atingle', 'bad-tempered', 'barbed'],
    'prickly heat': ['acne', 'acne vulgaris', 'breaking out', 'dermamycosis', 'dermatitis', 'dermatosis', 'diaper rash', 'drug rash', 'eczema', 'efflorescence', 'elephantiasis', 'epithelioma'],
    'pride': ['olympian detachment', 'olympian loftiness', 'acedia', 'anger', 'army', 'arrogance', 'arrogantness', 'assumption of superiority', 'assurance', 'assuredness', 'avarice', 'avaritia'],
    'prideful': ['erect', 'house-proud', 'independent', 'proud', 'proud as lucifer', 'proud-blooded', 'proud-looking', 'proud-minded', 'proud-spirited', 'proudful', 'proudhearted', 'purse-proud'],
    'priest': ['aaronic priesthood', 'levite', 'melchizedek priesthood', 'seventy', 'abbe', 'abbess', 'abbot', 'acolyte', 'acolytus', 'apostle', 'baal kore', 'bishop'],
    'priesthood': ['sacred college', 'apostleship', 'call', 'care of souls', 'clergy', 'clerical order', 'clericalism', 'clericals', 'episcopalianism', 'holy orders', 'ministry', 'pastorage'],
    'priestly': ['abbatial', 'abbatical', 'archiepiscopal', 'canonical', 'capitular', 'capitulary', 'churchly', 'clerical', 'ecclesiastic', 'episcopal', 'episcopalian', 'evangelistic'],
    'prig': ['brahmin', 'grundy', 'victorian', 'bluenose', 'clout', 'conformist', 'cop', 'egghead', 'elitist', 'filch', 'filcher', 'formalist'],
    'priggish': ['quakerish', 'victorian', 'abusive', 'blackening', 'blameful', 'censorious', 'choicy', 'choosy', 'condemnatory', 'condescending', 'conformist', 'conscientious'],
    'prim': ['quakerish', 'victorian', 'bluenosed', 'buckram', 'censorious', 'ceremonial', 'ceremonious', 'chipper', 'conventional', 'correct', 'decorous', 'demure'],
    'prima ballerina': ['danseur noble', 'diva', 'feature attraction', 'first tragedian', 'headliner', 'heavy lead', 'hero', 'heroine', 'jeune premier', 'lead', 'leading lady', 'leading man'],
    'prima donna': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso profundo', 'blues singer'],
    'prima facie': ['apparently', 'as it seems', 'as seen', 'at a glance', 'at first sight', 'at sight', 'by eyeball', 'by sight', 'on the surface', 'ostensibly', 'outwardly', 'seemingly'],
    'primacy': ['abbacy', 'accent', 'acme', 'archbishopric', 'archdeaconry', 'archiepiscopacy', 'archiepiscopate', 'ascendance', 'ascendancy', 'authority', 'authorization', 'balance of power'],
    'primal': ['ab ovo', 'abecedarian', 'aboriginal', 'antenatal', 'arch', 'atavistic', 'austere', 'autochthonous', 'banner', 'bare', 'basal', 'basic'],
    'primarily': ['a fortiori', 'ab initio', 'ab ovo', 'aborigine', 'above all', 'all the more', 'at bottom', 'at first', 'at heart', 'at the core', 'at the start', 'au fond'],
    'primary': ['maxwell triangle', 'munsell scale', 'ab ovo', 'abecedarian', 'aboriginal', 'all-absorbing', 'antenatal', 'anterior', 'arch', 'austere', 'autochthonous', 'banner'],
    'primate': ['australanthropus', 'australopithecus', 'barbary ape', 'bronze age man', 'cro-magnon man', 'galley hill man', 'gigantopithecus', 'grand penitentiary', 'grimaldi man', 'heidelberg man', 'holy father', 'hominidae'],
    'prime': ['eastertide', 'mass', 'maytime', 'abecedarian', 'aboriginal', 'acme', 'admirable', 'adolescence', 'adulthood', 'adultness', 'advise', 'age of consent'],
    'prime mover': ['abettor', 'actor', 'actuator', 'agent', 'ancestors', 'animator', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter'],
    'prime of life': ['adulthood', 'adultness', 'age of consent', 'bloom', 'budtime', 'driving age', 'early years', 'florescence', 'flower of age', 'flowering time', 'full age', 'full bloom'],
    'primed': ['abreast of', 'accomplished', 'all ready', 'all set', 'armed', 'armed and ready', 'at concert pitch', 'au courant', 'booted and spurred', 'briefed', 'career', 'coached'],
    'primer': ['abecedarium', 'abecedary', 'alphabet', 'alphabet book', 'and arithmetic', 'basics', 'battledore', 'blasting cap', 'cap', 'casebook', 'chromogen', 'coat'],
    'primeval': ['abecedarian', 'aboriginal', 'ancestral', 'ancient', 'antenatal', 'antepatriarchal', 'atavistic', 'autochthonous', 'basal', 'basic', 'beginning', 'budding'],
    'priming': ['blasting cap', 'calcimining', 'cap', 'chromogen', 'coat', 'coat of paint', 'coating', 'color', 'color filter', 'color gelatin', 'colorant', 'coloring'],
    'primitive': ['bronze age man', 'gothic', 'hominidae', 'iron age man', 'neanderthal', 'stone age man', 'ab ovo', 'abecedarian', 'aboriginal', 'aborigine', 'ancestral', 'ancient'],
    'primness': ['quakerishness', 'buckram', 'censoriousness', 'ceremonial', 'ceremoniousness', 'ceremony', 'demureness', 'demurity', 'dignity', 'extrinsicality', 'false modesty', 'form'],
    'primogeniture': ['aboriginality', 'age', 'ancien regime', 'ancientness', 'antiquity', 'atavism', 'bequeathal', 'bequest', 'birthright', 'borough-english', 'cobwebs of antiquity', 'coheirship'],
    'primordial': ['aboriginal', 'ancestral', 'antepatriarchal', 'atavistic', 'autochthonous', 'basal', 'basic', 'central', 'crucial', 'elemental', 'elementary', 'embryonic'],
    'primp': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'color', 'dandify', 'deck', 'deck out', 'decorate', 'dizen'],
    'primrose': ['aureate', 'auric', 'beige', 'buff', 'buff-yellow', 'canary', 'canary-yellow', 'choice', 'citron', 'citron-yellow', 'coral', 'cream'],
    'primrose path': ['air lane', 'beat', 'circuit', 'course', 'flight path', 'itinerary', 'line', 'orbit', 'path', 'road', 'round', 'route'],
    'prince': ['muslim rulers', 'prinz', 'acceptable person', 'anointed king', 'atheling', 'baron', 'capital fellow', 'chief', 'chieftain', 'crown prince', 'crowned head', 'czar'],
    'princely': ['babylonian', 'corinthian', 'ample', 'aristocratic', 'august', 'awe-inspiring', 'awful', 'barbaric', 'baronial', 'big', 'bighearted', 'bounteous'],
    'princess': ['kaiserin', 'begum', 'crown princess', 'czarina', 'empress', 'grand duchess', 'infanta', 'kumari', 'kunwari', 'maharani', 'malikzadi', 'princesse'],
    'principal': ['a per se', 'english horn', 'academic dean', 'ace', 'administration', 'administrator', 'all-absorbing', 'arch', 'assets', 'backing', 'banner', 'bassoon'],
    'principality': ['kreis', 'aedileship', 'ally', 'angel', 'angel of light', 'angel of love', 'archangel', 'archbishopric', 'archdiocese', 'archduchy', 'archdukedom', 'archiepiscopacy'],
    'principally': ['above all', 'at bottom', 'basically', 'chiefly', 'especially', 'essentially', 'first and foremost', 'fundamentally', 'in essence', 'in the main', 'largely', 'mainly'],
    'principle': ['procrustean law', 'a belief', 'a priori truth', 'activity', 'ambition', 'antecedents', 'article of faith', 'aspiration', 'at bottom', 'attitude', 'axiom', 'base'],
    'principled': ['christian', 'blameless', 'clean', 'correct', 'creditable', 'decent', 'erect', 'estimable', 'ethical', 'fair', 'full of integrity', 'good'],
    'principles': ['ten commandments', 'zeitgeist', 'alphabet', 'assured probity', 'axiology', 'basics', 'behavioral norm', 'blamelessness', 'business ethics', 'character', 'cleanness', 'code'],
    'print': ['ditto copy', 'photostat', 'xerox', 'xerox copy', 'abstract', 'abstraction', 'altarpiece', 'alveolation', 'alveolus', 'aquatint', 'ascender', 'autolithograph'],
    'printed': ['autograph', 'autographic', 'calligraphic', 'carved', 'chirographic', 'creased', 'cursive', 'cut', 'enchased', 'engraved', 'engrossed', 'flowing'],
    'printed circuit': ['amplifier circuit', 'astable circuit', 'break', 'broken circuit', 'circuit', 'circuital field', 'circuitry', 'closed circuit', 'complete circuit', 'coupling circuit', 'dead circuit', 'equivalent circuit'],
    'printed matter': ['advance sheets', 'advertising matter', 'article', 'autograph', 'brainchild', 'composition', 'computer printout', 'copy', 'document', 'draft', 'edited version', 'engrossment'],
    'printer': ['linotyper', 'apprentice printer', 'bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliomane', 'bibliomaniac', 'bibliopegist', 'bibliophage', 'bibliophile', 'bibliopole'],
    'printing': ['italian hand', 'spencerian writing', 'airing', 'alphabet', 'art', 'back number', 'bandying', 'block letter', 'blueprint', 'bold hand', 'book', 'book hand'],
    'printing equipment': ['bearer', 'bed', 'bevel', 'blanket', 'boss', 'box', 'burr', 'case', 'chase', 'composing stick', 'drawsheet', 'footstick'],
    'printmaking': ['albertype', 'book printing', 'chromotypography', 'chromotypy', 'chromoxylography', 'collotype', 'color printing', 'drawing', 'electronography', 'electrostatic printing', 'graphic artist', 'graphic arts'],
    'printout': ['flexowriter typewriter', 'teleplotter', 'alphabetical printer', 'article', 'autograph', 'brainchild', 'composition', 'computer printout', 'copy', 'digital graph plotter', 'document', 'draft'],
    'prior': ['ahead', 'ancient', 'antecedent', 'anterior', 'anticipatory', 'before', 'chief', 'ci-devant', 'earlier', 'early', 'elder', 'erstwhile'],
    'priority': ['accent', 'accomplishment', 'antecedence', 'antecedency', 'anteposition', 'anteriority', 'arrangement', 'ascendancy', 'authority', 'bold front', 'brave face', 'brave front'],
    'prism': ['achromatic lens', 'astigmatic lens', 'burning glass', 'camera', 'coated lens', 'concave lens', 'concavo-convex lens', 'condenser', 'convex lens', 'eyeglass', 'eyepiece', 'glass'],
    'prismatic': ['bicolor', 'bicolored', 'chromatic', 'cold', 'colorful', 'colorific', 'coloring', 'colory', 'cool', 'crazy', 'daedal', 'dichromatic'],
    'prison': ['pow camp', 'bastille', 'big house', 'black hole', 'borstal', 'borstal institution', 'bridewell', 'brig', 'calaboose', 'can', 'cell', 'chokey'],
    'prisonbreak': ['break', 'breakout', 'deliverance', 'delivery', 'emergence', 'escape', 'escapism', 'evasion', 'extrication', 'flight', 'freeing', 'getaway'],
    'prisoner': ['pow', 'accused', 'cageling', 'captive', 'chain gang', 'con', 'convict', 'correspondent', 'defendant', 'detainee', 'detenu', 'ex-convict'],
    'prissy': ['victorian', 'chicken', 'effeminate', 'epicene', 'fastidious', 'finical', 'finicky', 'fussy', 'genteel', 'muliebrous', 'old-maidish', 'old-womanish'],
    'pristine': ['aboriginal', 'ancestral', 'angelic', 'antepatriarchal', 'artless', 'atavistic', 'autochthonous', 'basal', 'basic', 'blameless', 'bright', 'callow'],
    'prittle prattle': ['babble', 'babblement', 'bavardage', 'be closeted with', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather', 'blether', 'blethers', 'cackle'],
    'privacy': ['jim crow', 'adytum', 'alienation', 'aloneness', 'aloofness', 'anonymity', 'apartheid', 'apartness', 'ashram', 'celibacy', 'cell', 'clandestineness'],
    'private': ['tommy', 'tommy atkins', 'absolute', 'anonymous', 'antisocial', 'behind closed doors', 'buck private', 'certain', 'clandestine', 'closet', 'common soldier', 'concealed'],
    'private parts': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'privateer': ['ab', 'ancient mariner', 'argonaut', 'blackbeard', 'captain hook', 'captain kidd', 'dylan', 'flying dutchman', 'henry morgan', 'jean lafitte', 'neptune', 'od'],
    'privately': ['a huis clos', 'apart', 'aside', 'behind closed doors', 'by stealth', 'covertly', 'furtively', 'hugger-mugger', 'in camera', 'in chambers', 'in executive session', 'in person'],
    'privation': ['abridgment', 'bare cupboard', 'bare subsistence', 'beggarliness', 'beggary', 'bereavement', 'cost', 'curtailment', 'damage', 'dead loss', 'dearth', 'debit'],
    'privilege': ['accomplishment', 'advantage', 'allowance', 'appanage', 'ascendancy', 'authority', 'authorization', 'authorize', 'benefit', 'birthright', 'blank check', 'boon'],
    'privileged': ['admitted', 'advantaged', 'auricular', 'authorized', 'between us', 'chartered', 'confidential', 'elite', 'empowered', 'enfranchised', 'entitled', 'esoteric'],
    'privy': ['wc', 'alive to', 'anonymous', 'appreciative of', 'apprised of', 'awake to', 'aware of', 'back-door', 'backhouse', 'backstairs', 'basement', 'bathroom'],
    'privy council': ['british cabinet', 'sanhedrin', 'us cabinet', 'advisory body', 'advisory council', 'assembly', 'association', 'bench', 'board', 'body of advisers', 'borough council', 'brain trust'],
    'prize': ['academy award', 'nobel prize', 'oscar', 'accolade', 'accord respect to', 'admire', 'adore', 'aim', 'ambition', 'apotheosize', 'appraise', 'appreciate'],
    'prized': ['ad valorem', 'admired', 'adored', 'appraised', 'appreciated', 'assessed', 'beloved', 'cherished', 'darling', 'dear', 'dearly beloved', 'esteemed'],
    'prizefighter': ['chinese boxer', 'bantamweight', 'black belt', 'boxer', 'brown belt', 'bruiser', 'featherweight', 'fighter', 'fisticuffer', 'flyweight', 'heavyweight', 'karate expert'],
    'pro': ['admirable crichton', 'adept', 'advocating', 'all for', 'approving', 'argument', 'argumentum', 'artisan', 'artist', 'attache', 'authority', 'aye'],
    'pro and con': ['agitate', 'argue', 'argumental', 'argumentative', 'canvass', 'combative', 'contentious', 'controversial', 'debate', 'dialectic', 'discept', 'disputatious'],
    'pro rata': ['ad valorem', 'appraised', 'assessed', 'distributional', 'distributive', 'distributively', 'each to each', 'equal', 'evaluated', 'even stephen', 'fifty-fifty', 'good for'],
    'probability': ['a thing for', 'accidentality', 'actuarial calculation', 'actuarial prediction', 'adventitiousness', 'affinity', 'aftertime', 'afteryears', 'anticipation', 'apocalypse', 'aptitude', 'aptness'],
    'probable': ['anticipatable', 'anticipated', 'apparent', 'approaching', 'apt', 'awaited', 'believable', 'calculable', 'cogitable', 'colorable', 'coming', 'conceivable'],
    'probably': ['after a time', 'after a while', 'afterward', 'afterwards', 'all things considered', 'anon', 'assumably', 'before long', 'by all odds', 'by and by', 'by destiny', 'dollars to doughnuts'],
    'probate': ['affirm', 'attest', 'attested copy', 'authenticate', 'back', 'back up', 'bear out', 'bequeathal', 'bequest', 'bolster', 'buttress', 'certify'],
    'probation': ['acid test', 'assay', 'blank determination', 'brouillon', 'criterion', 'crucial test', 'crucible', 'determination', 'docimasy', 'essay', 'feeling out', 'first draft'],
    'probationary': ['cut-and-try', 'empirical', 'experimental', 'heuristic', 'hit-or-miss', 'on probation', 'pilot', 'probational', 'probative', 'probatory', 'proving', 'provisional'],
    'probationer': ['lpn', 'rn', 'abecedarian', 'alphabetarian', 'apprentice', 'articled clerk', 'baby', 'beginner', 'boot', 'catechumen', 'charge nurse', 'deb'],
    'probe': ['atda', 'ats', 'alouette', 'anna', 'apollo', 'ariel', 'atlas-score', 'biosatellite', 'comsat', 'cosmos', 'courier', 'diapason'],
    'probing': ['socratic method', 'asking', 'bringing into question', 'catechetical method', 'catechization', 'catechizing', 'challenge', 'deepening', 'delving', 'depression', 'digging', 'dispute'],
    'probity': ['angelicalness', 'decency', 'equity', 'fairness', 'godliness', 'goodness', 'honesty', 'honor', 'integrity', 'justice', 'justness', 'moral rectitude'],
    'problem': ['chinese puzzle', 'ado', 'aggravation', 'annoyance', 'anxiety', 'bad news', 'baffle', 'bafflement', 'baffling problem', 'basis', 'bedevilment', 'besetment'],
    'problematic': ['a bit thick', 'a bit thin', 'absurd', 'ambiguous', 'arguable', 'at issue', 'baffling', 'bewildering', 'beyond belief', 'bothering', 'confounding', 'confusing'],
    'problematical': ['a bit thick', 'a bit thin', 'absurd', 'arguable', 'at issue', 'baffling', 'bewildering', 'beyond belief', 'bothering', 'confounding', 'confusing', 'confutable'],
    'proboscis': ['antlia', 'beak', 'beezer', 'bill', 'bugle', 'conk', 'muffle', 'muzzle', 'nares', 'neb', 'nib', 'nose'],
    'procedure': ['mo', 'sop', 'act', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'algorithm', 'approach'],
    'proceed': ['accept', 'accrue from', 'act', 'act on', 'act upon', 'advance', 'arise', 'arise from', 'assume', 'attack', 'attempt', 'be contingent on'],
    'proceeding': ['mo', 'accomplished fact', 'accomplishment', 'accounts', 'achievement', 'act', 'acta', 'action', 'actions', 'activity', 'acts', 'address'],
    'proceedings': ['account', 'account rendered', 'accounting', 'acta', 'action', 'activeness', 'activism', 'activity', 'affairs', 'annual', 'brief', 'bulletin'],
    'proceeds': ['aftermath', 'avails', 'bearing', 'box office', 'bumper crop', 'capital gains', 'cleanup', 'clear profit', 'commissions', 'credit', 'credits', 'crop'],
    'process': ['afro', 'mo', 'act', 'activity', 'algorithm', 'alter', 'analog process', 'answer', 'approach', 'arrange', 'attack', 'barber'],
    'processed': ['assembled', 'built', 'cast', 'constructed', 'crafted', 'created', 'custom', 'custom-built', 'custom-made', 'extracted', 'fabricated', 'fashioned'],
    'processing': ['accounting', 'analysis', 'architecture', 'arrangement', 'assembly', 'basic training', 'braking', 'briefing', 'building', 'casting', 'clearing the decks', 'composition'],
    'procession': ['caravan', 'cavalcade', 'chain', 'column', 'coming after', 'consecution', 'consecutiveness', 'continuation', 'continuity', 'cortege', 'course', 'cycle'],
    'processional': ['agape', 'asperges', 'aspersion', 'auricular confession', 'bar mitzvah', 'bas mitzvah', 'celebration', 'circumcision', 'confession', 'confirmation', 'high celebration', 'incense'],
    'proclaim': ['advertise', 'affirm', 'allege', 'announce', 'annunciate', 'antecede', 'antedate', 'anticipate', 'argue', 'articulate', 'assert', 'assever'],
    'proclamation': ['advertisement', 'advertising', 'affirmance', 'affirmation', 'allegation', 'announcement', 'announcing', 'annunciation', 'appointment', 'assertion', 'asseveration', 'averment'],
    'proclivity': ['a thing for', 'affinity', 'animus', 'aptitude', 'aptness', 'bag', 'bent', 'bias', 'cast', 'character', 'chosen kind', 'conatus'],
    'proconsul': ['beg', 'beglerbeg', 'bey', 'burgrave', 'collector', 'dey', 'eparch', 'exarch', 'gauleiter', 'governor', 'governor-general', 'khedive'],
    'procrastinate': ['abandon', 'be dilatory', 'continue', 'cut', 'dally', 'dawdle', 'defer', 'delay', 'drag', 'drag out', 'draw out', 'dwell on'],
    'procrastinating': ['micawberish', 'backward', 'contemplative', 'culpably negligent', 'dallying', 'delaying', 'derelict', 'dilatory', 'dillydallying', 'do-nothing', 'dormant', 'easygoing'],
    'procrastination': ['fabian policy', 'micawberism', 'a wise passiveness', 'backwardness', 'contemplation', 'contemplative life', 'continuation', 'culpa', 'culpable negligence', 'dalliance', 'dallying', 'dawdling'],
    'procrastinative': ['micawberish', 'backward', 'bone-lazy', 'cadging', 'dallying', 'dawdling', 'delaying', 'dilatory', 'dillydallying', 'do-nothing', 'doless', 'dragging'],
    'procrastinator': ['bungler', 'dawdle', 'dawdler', 'disregarder', 'dodger', 'drone', 'foot-dragger', 'goldbrick', 'goof-off', 'idler', 'ignorer', 'laggard'],
    'procreate': ['bear', 'beget', 'birth', 'blossom', 'breed', 'breed true', 'brew', 'bring forth', 'bring into being', 'bring to birth', 'burgeon', 'call into being'],
    'procreation': ['abiogenesis', 'act of love', 'adultery', 'aphrodisia', 'archigenesis', 'ass', 'balling', 'begetting', 'biogenesis', 'birth', 'blastogenesis', 'breeding'],
    'procreative': ['abecedarian', 'aboriginal', 'amorous', 'antenatal', 'autochthonous', 'beginning', 'budding', 'carnal', 'creative', 'elemental', 'elementary', 'embryonic'],
    'procrustean': ['dour', 'firm', 'fundamentalist', 'hard', 'hidebound', 'impliable', 'inexorable', 'inflexible', 'iron', 'ironbound', 'ironclad', 'ironhanded'],
    'proctor': ['big brother', 'mc', 'advocate', 'agent', 'amicus curiae', 'apprentice teacher', 'attorney', 'attorney-at-law', 'auditor', 'bailiff', 'barrister', 'barrister-at-law'],
    'procurator': ['mc', 'advocate', 'agent', 'alter ego', 'alternate', 'amicus curiae', 'attorney', 'attorney-at-law', 'backup', 'backup man', 'bailiff', 'barrister'],
    'procure': ['accomplish', 'acquire', 'annex', 'appropriate', 'argue into', 'arouse', 'bag', 'be seized of', 'bring', 'bring about', 'bring around', 'bring back'],
    'procurement': ['accession', 'accouterment', 'acquirement', 'acquisition', 'addition', 'armament', 'attainment', 'catering', 'chandlery', 'coming by', 'dragging down', 'earnings'],
    'procurer': ['accepter', 'acquirer', 'addressee', 'audience', 'auditor', 'bawd', 'beholder', 'consignee', 'fancy man', 'getter', 'gigolo', 'hearer'],
    'prod': ['activate', 'actuate', 'annoy', 'assault', 'badger', 'bear', 'bear upon', 'bearing', 'boost', 'buck', 'bull', 'bulldoze'],
    'prodigal': ['adamic', 'abounding', 'abundant', 'affluent', 'aggrandized', 'alive with', 'all-sufficing', 'ample', 'amplified', 'aplenty', 'backsliding', 'ballyhooed'],
    'prodigal son': ['magdalen', 'backslider', 'big-time spender', 'confessor', 'lost lamb', 'penitent', 'prodigal', 'prodigal returned', 'recidivist', 'repeater', 'returnee', 'reversioner'],
    'prodigality': ['abundance', 'affluence', 'aggrandizement', 'amorality', 'ample sufficiency', 'ampleness', 'amplification', 'amplitude', 'avalanche', 'backsliding', 'ballyhoo', 'big talk'],
    'prodigious': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'amazing', 'amplitudinous', 'astonishing', 'astounding', 'astronomic'],
    'prodigiousness': ['ampleness', 'amplitude', 'awesomeness', 'beguilingness', 'boundlessness', 'bulk', 'enchantingness', 'enormity', 'enormousness', 'enticingness', 'exceptionality', 'expanse'],
    'prodigy': ['a per se', 'abnormality', 'ace', 'amazement', 'anomaly', 'astonishing thing', 'astonishment', 'boss', 'brain', 'champion', 'chief', 'child prodigy'],
    'produce': ['irish potato', 'kraut', 'accomplish', 'achieve', 'act', 'adduce', 'advance', 'affect', 'aftermath', 'allege', 'array', 'assemble'],
    'producer': ['mc', 'actor', 'administrator', 'agent', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'auteur', 'author', 'ballyhoo man'],
    'product': ['account', 'aftermath', 'aggregate', 'amount', 'article', 'article of commerce', 'article of merchandise', 'bearing', 'box score', 'bumper crop', 'by-product', 'cast'],
    'production': ['nachtmusik', 'absolute music', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adaptation', 'adventure', 'aftermath', 'air varie'],
    'production line': ['armory', 'arsenal', 'assemblage', 'assembly', 'assembly line', 'assembly plant', 'assembly-line production', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery'],
    'productive': ['able', 'abounding', 'abundant', 'adequate', 'advantageous', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'banausic', 'blooming', 'bottomless'],
    'productiveness': ['abundance', 'access', 'accession', 'accomplishment', 'accretion', 'accrual', 'accruement', 'accumulation', 'achievement', 'addition', 'advance', 'affluence'],
    'productivity': ['abundance', 'amperage', 'amplitude', 'armipotence', 'authority', 'beef', 'black power', 'bountifulness', 'brute force', 'charge', 'charisma', 'cloud of words'],
    'profanation': ['abomination', 'abuse', 'abuse of office', 'atrocity', 'befoulment', 'blasphemousness', 'blasphemy', 'conversion', 'corrupt administration', 'debasement', 'defalcation', 'defilement'],
    'profane': ['fescennine', 'philistine', 'rabelaisian', 'abuse', 'abusive', 'apostate', 'atheistic', 'backsliding', 'bad', 'bawdy', 'befoul', 'blasphemous'],
    'profanity': ['bad language', 'billingsgate', 'blasphemousness', 'blasphemy', 'blue language', 'colorful language', 'cursing', 'cussing', 'desecration', 'dirty language', 'dirty talk', 'dysphemism'],
    'profess': ['act', 'act a part', 'affect', 'affirm', 'allege', 'announce', 'annunciate', 'argue', 'assert', 'assever', 'asseverate', 'assume'],
    'professed': ['accepted', 'acknowledged', 'admitted', 'affirmed', 'alleged', 'allowed', 'announced', 'apparent', 'approved', 'asserted', 'asseverated', 'attested'],
    'profession': ['acceptance', 'acknowledgment', 'admission', 'affidavit', 'affirmance', 'affirmation', 'allegation', 'allowance', 'announcement', 'annunciation', 'appreciation', 'art'],
    'professional': ['admirable crichton', 'daedalian', 'able', 'academic', 'accomplished', 'adept', 'adroit', 'apt', 'artisan', 'artist', 'artiste', 'artistic'],
    'professorial': ['academic', 'bookish', 'devoted to studies', 'diligent', 'donnish', 'dryasdust', 'mandarin', 'owlish', 'pedagogic', 'pedantic', 'preceptorial', 'professorlike'],
    'proffer': ['accord', 'administer', 'advance', 'afford', 'allot', 'allow', 'approach', 'asking price', 'award', 'bestow', 'bestow on', 'bid'],
    'proffered': ['arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'nonmandatory', 'offered', 'optional'],
    'proficiency': ['ability', 'ableness', 'address', 'adeptness', 'adequacy', 'adroitness', 'advancement', 'airmanship', 'all-knowingness', 'anabasis', 'aptitude', 'artfulness'],
    'proficient': ['daedalian', 'able', 'accomplished', 'ace', 'adapted', 'adept', 'adequate', 'adjusted', 'adroit', 'apt', 'archetypical', 'artist'],
    'profile': ['clio', 'muse of history', 'adventures', 'analysis', 'annals', 'autobiography', 'bank', 'beam', 'biographical sketch', 'biography', 'blueprint', 'border'],
    'profit': ['advance', 'advantage', 'advantageousness', 'advisability', 'aid', 'answer', 'appropriateness', 'avail', 'avails', 'bait', 'be handy', 'be of use'],
    'profit by': ['benefit from', 'capitalize on', 'carpe diem', 'cash in', 'cash in on', 'exploit', 'improve', 'improve the occasion', 'make capital of', 'make hay', 'not be behindhand', 'put to advantage'],
    'profit sharing': ['collective farm', 'collectivism', 'collectivity', 'collegiality', 'common ownership', 'communal effort', 'communion', 'communism', 'community', 'cooperation', 'cooperative society', 'democracy'],
    'profitable': ['advantageous', 'advisable', 'aidful', 'appropriate', 'auspicious', 'banausic', 'becoming', 'befitting', 'beneficial', 'benevolent', 'bon', 'bonny'],
    'profiteer': ['blackmailer', 'bleed', 'bleed white', 'bloodsucker', 'clip', 'exploit', 'exploiter', 'extort', 'extortionist', 'fleece', 'gouge', 'harpy'],
    'profligacy': ['carnality', 'corruption', 'debauchery', 'degeneracy', 'depravity', 'dissipation', 'dissoluteness', 'eroticism', 'evil', 'excess', 'exorbitance', 'extravagance'],
    'profligate': ['casanova', 'don juan', 'lothario', 'abandoned', 'backslider', 'bad egg', 'bad lot', 'black sheep', 'carnal', 'contaminated', 'corrupt', 'corrupted'],
    'profound': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'absolute', 'absorbing', 'abstract', 'abstruse', 'abysmal', 'acute'],
    'profundity': ['sophia', 'abstruseness', 'abyss', 'acumen', 'ampleness', 'astuteness', 'bigness', 'bottomlessness', 'broad-mindedness', 'broadness', 'capaciousness', 'complexity'],
    'profuse': ['abounding', 'abundant', 'affluent', 'aggrandized', 'alive with', 'all-sufficing', 'ample', 'amplified', 'aplenty', 'ballyhooed', 'bighearted', 'bottomless'],
    'profusely': ['abundantly', 'acervatim', 'acutely', 'affluently', 'amazingly', 'amply', 'aplenty', 'astonishingly', 'awesomely', 'bigheartedly', 'bottomlessly', 'bounteously'],
    'profusion': ['abundance', 'accumulation', 'acres', 'affluence', 'agglomeration', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bags', 'barrels', 'bonanza'],
    'progenitor': ['ancestor', 'ancestors', 'ancestress', 'antecedent', 'antecedents', 'archetype', 'ascendant', 'ascendants', 'begetter', 'elders', 'fathers', 'forebear'],
    'progeny': ['breed', 'brood', 'children', 'descendants', 'descent', 'family', 'fruit', 'fry', 'grandchildren', 'great-grandchildren', 'heirs', 'hostages to fortune'],
    'prognosis': ['action', 'actuarial prediction', 'apocalypse', 'award', 'cast', 'condemnation', 'consideration', 'decision', 'decree', 'deliverance', 'determination', 'diagnosis'],
    'prognostic': ['apocalyptic', 'augural', 'auguring', 'augury', 'boding', 'divinatory', 'fatidic', 'forecasting', 'forerunning', 'foreseeing', 'foreshadowing', 'foreshowing'],
    'prognosticate': ['adumbrate', 'announce', 'augur', 'bet', 'betoken', 'cast a horoscope', 'cast a nativity', 'divine', 'dope', 'dope out', 'dowse for water', 'forebode'],
    'prognosticator': ['cassandra', 'druid', 'astrologer', 'augur', 'calamity howler', 'crystal gazer', 'divinator', 'diviner', 'divineress', 'forecaster', 'foreknower', 'foreseer'],
    'program': ['beveridge plan', 'cultural revolution', 'fair deal', 'great society', 'marshall plan', 'new deal', 'new frontier', 'philharmonic concert', 'point four', 'square deal', 'affair', 'agenda'],
    'programme': ['abstract', 'activities', 'affairs', 'agenda', 'arrange', 'bill of fare', 'book', 'broadcast', 'calendar', 'concert', 'curriculum', 'description'],
    'programmer': ['aftra', 'dj', 'mc', 'anchor man', 'announcer', 'automatic technician', 'broadcaster', 'commentator', 'computer engineer', 'computer programmer', 'computer technician', 'computer technologist'],
    'progress': ['brownian movement', 'great leap forward', 'about-face', 'accomplishment', 'achieve success', 'advance', 'advancement', 'advancing', 'alchemy', 'ameliorate', 'amelioration', 'amend'],
    'progressing': ['advancing', 'ambulant', 'ambulative', 'ambulatory', 'ameliorative', 'bettering', 'bradytelic', 'circuit-riding', 'developing', 'evolutional', 'evolutionist', 'evolutionistic'],
    'progression': ['great leap forward', 'indian file', 'accomplishment', 'advance', 'advancement', 'alternation', 'amelioration', 'amendment', 'amplification', 'array', 'articulation', 'ascension'],
    'progressive': ['fabian', 'a la mode', 'advanced', 'advancing', 'ameliorative', 'ascending', 'avant-garde', 'axial', 'back', 'back-flowing', 'backward', 'bettering'],
    'progressivism': ['fabianism', 'conversion', 'extremism', 'gradualism', 'left', 'left wing', 'leftism', 'liberalism', 'meliorism', 'radical reform', 'radicalism', 'reform'],
    'prohibit': ['anticipate', 'arrest', 'avert', 'ban', 'bar', 'bar out', 'block', 'blockade', 'bridle', 'check', 'close out', 'constrain'],
    'prohibited': ['absurd', 'banned', 'barred', 'closed-out', 'contraband', 'contrary to reason', 'debarred', 'deported', 'ejected', 'excluded', 'exiled', 'expelled'],
    'prohibition': ['eighteenth amendment', 'volstead act', 'arrest', 'arrestation', 'ban', 'banning', 'bar', 'barring', 'blockade', 'boycott', 'check', 'circumscription'],
    'prohibitive': ['abusive', 'criminal', 'cutthroat', 'dear', 'deterrent', 'deterring', 'discouraging', 'ethnocentric', 'exacting', 'exceptional', 'excessive', 'excluding'],
    'project': ['activity', 'actualize', 'adumbrate', 'adventure', 'affair', 'aftertime', 'afteryears', 'aim', 'aim at', 'aller sans dire', 'ambition', 'animus'],
    'projected': ['advised', 'aimed', 'aimed at', 'approaching', 'arranged', 'blueprinted', 'calculated', 'charted', 'coming', 'conscious', 'considered', 'contemplated'],
    'projectile': ['irish confetti', 'ball', 'ballistic', 'bola', 'bolt', 'boomerang', 'brickbat', 'bullet', 'countermissile', 'discus', 'ejecta', 'ejectamenta'],
    'projecting': ['beetle', 'beetle-browed', 'beetling', 'bold', 'eminent', 'emissile', 'excrescent', 'excrescential', 'extruding', 'impendent', 'impending', 'incumbent'],
    'projection': ['lambert conformal projection', 'mercator projection', 'miller projection', 'acting', 'actualization', 'aeronautical chart', 'alienation', 'alphabet', 'archery', 'art', 'astronomical chart', 'atlas'],
    'projector': ['mark', 'architect', 'bazooka', 'calliope', 'cinematograph', 'contriver', 'designer', 'developer', 'deviser', 'enterpriser', 'entrepreneur', 'framer'],
    'proletarian': ['cockney', 'everyman', 'john smith', 'average man', 'blue-collar worker', 'bourgeois', 'breadwinner', 'casual', 'casual laborer', 'common laborer', 'common man', 'commoner'],
    'proletariat': ['bourgeoisie', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty', 'commoners', 'commons', 'laborers', 'linendrapers', 'lower classes'],
    'proliferate': ['abound', 'accrue', 'accumulate', 'advance', 'appreciate', 'balloon', 'be fruitful', 'be productive', 'beget', 'bloat', 'boom', 'breed'],
    'proliferation': ['access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'aggrandizement', 'amplification', 'appreciation', 'ascent'],
    'prolific': ['abounding', 'abundant', 'alive with', 'blooming', 'bounteous', 'bountiful', 'breeding', 'bristling', 'bursting', 'bursting out', 'conceptive', 'conceptual'],
    'prolix': ['all jaw', 'blah', 'broken-record', 'candid', 'chatty', 'communicative', 'conversational', 'de longue haleine', 'de trop', 'diffuse', 'dispensable', 'drearisome'],
    'prolixity': ['bedizenment', 'big mouth', 'boringness', 'candor', 'cloud of words', 'communicativeness', 'conversableness', 'dullness', 'duplication', 'duplication of effort', 'effusion', 'effusiveness'],
    'prologue': ['act', 'afterpiece', 'avant-propos', 'bit', 'breakthrough', 'chaser', 'curtain', 'curtain call', 'curtain raiser', 'divertimento', 'divertissement', 'epilogue'],
    'prolong': ['adjourn', 'continue', 'dawdle', 'defer', 'delay', 'drag on', 'drag out', 'draw', 'draw out', 'dwell on', 'elongate', 'endure'],
    'prolongation': ['adjournal', 'adjournment', 'coming after', 'consecution', 'consecutiveness', 'continualness', 'continuance', 'continuation', 'continuity', 'deferment', 'deferral', 'descent'],
    'prolonged': ['dragged out', 'dragging', 'drawn', 'drawn out', 'drawn-out', 'elongated', 'extended', 'interminable', 'languishing', 'lasting', 'lengthened', 'lengthy'],
    'prom': ['philharmonic concert', 'assemblee', 'assembly', 'assignation', 'at home', 'bal', 'bal costume', 'bal masque', 'ball', 'band concert', 'barn dance', 'brawl'],
    'promenade': ['airing', 'alameda', 'amble', 'bal', 'bal costume', 'bal masque', 'ball', 'barn dance', 'beaten path', 'beaten track', 'berm', 'bicycle path'],
    'prominence': ['account', 'altitude', 'arete', 'arrantness', 'atmospheric visibility', 'authority', 'bas-relief', 'bellying', 'blatancy', 'boldness', 'bulge', 'bulging'],
    'prominent': ['olympian', 'absolute', 'acclaimed', 'aerial', 'airy', 'altitudinous', 'apparent', 'arrant', 'arresting', 'ascendant', 'ascending', 'aspiring'],
    'prominently': ['abundantly', 'acutely', 'amazingly', 'amply', 'apparently', 'arrantly', 'astonishingly', 'awesomely', 'blatantly', 'boldly', 'celebratedly', 'clearly'],
    'promiscuity': ['casualness', 'chambering', 'crudity of intellect', 'derangement', 'disarrangement', 'disarray', 'disarticulation', 'discomfiture', 'discomposure', 'disconcertedness', 'disharmony', 'dishevelment'],
    'promiscuous': ['paphian', 'abandoned', 'aimless', 'amalgamated', 'ambiguous', 'ambivalent', 'amoral', 'amorphous', 'amphibious', 'assorted', 'blanket', 'blended'],
    'promise': ['accede', 'accord', 'actuarial prediction', 'adumbration', 'afford hope', 'agree', 'agree to', 'agreement', 'apocalypse', 'arrangement', 'aspiration', 'assent'],
    'promised': ['affianced', 'agreed', 'anticipated', 'arranged', 'assured', 'augured', 'awaited', 'betrothed', 'bound', 'committed', 'compacted', 'compromised'],
    'promised land': ['agapemone', 'arcadia', 'beulah', 'beulah land', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden'],
    'promising': ['apt', 'auspicious', 'benign', 'benignant', 'bright', 'bright with promise', 'cheering', 'couleur de rose', 'encouraging', 'fair', 'favorable', 'favoring'],
    'promissory note': ['cd', 'iou', 'mo', 'acceptance', 'acceptance bill', 'arrangement', 'bank acceptance', 'bank check', 'bill', 'bill of draft', 'bill of exchange', 'blank check'],
    'promontory': ['beak', 'bill', 'breakwater', 'cape', 'chersonese', 'coral reef', 'delta', 'foreland', 'head', 'headland', 'hook', 'mull'],
    'promote': ['abet', 'acculturate', 'act for', 'actuate', 'advance', 'advantage', 'advertise', 'advocate', 'aggrandize', 'aid', 'ameliorate', 'amend'],
    'promoter': ['maecenas', 'abettor', 'adherent', 'admirer', 'advocate', 'aficionado', 'angel', 'apologist', 'applauder', 'appreciator', 'architect', 'backer'],
    'promotion': ['great leap forward', 'abetting', 'acknowledgment', 'advance', 'advancement', 'advancing', 'advertisement', 'advertising', 'advocacy', 'advocating', 'affiche', 'aiding'],
    'prompt': ['accordant', 'acquiescent', 'admonish', 'adumbrate', 'affect', 'affirmative', 'agile', 'agog', 'agreeable', 'agreeing', 'aide-memoire', 'alacritous'],
    'prompter': ['mc', 'abettor', 'actuator', 'aide-memoire', 'animator', 'auteur', 'ballyhoo man', 'barker', 'cajoler', 'callboy', 'coax', 'coaxer'],
    'prompting': ['actuation', 'aide-memoire', 'animation', 'cue', 'direction', 'flapper', 'hint', 'influence', 'inner-direction', 'jogger', 'memorandum', 'motivation'],
    'promptly': ['pdq', 'agilely', 'amain', 'animatedly', 'anxiously', 'apace', 'ardently', 'at flank speed', 'at once', 'avidly', 'breathlessly', 'by forced marches'],
    'promptness': ['ok', 'abruptness', 'acceptance', 'accord', 'acquiescence', 'acuity', 'acuteness', 'affirmation', 'affirmative', 'affirmative voice', 'agility', 'agreeability'],
    'promulgate': ['abide by', 'adhere to', 'administer', 'advertise', 'announce', 'annunciate', 'bid', 'blare', 'blare forth', 'blaze', 'blaze abroad', 'blazon'],
    'prone': ['accumbent', 'acquiescent', 'agreeable', 'alacritous', 'amenable', 'answerable for', 'apt', 'apt to', 'ardent', 'bent', 'calculated to', 'capable of'],
    'prong': ['affluent', 'bayou', 'billabong', 'branch', 'confluent', 'confluent stream', 'crotch', 'crutch', 'delta', 'dendritic drainage pattern', 'effluent', 'fan'],
    'pronged': ['v-shaped', 'y-shaped', 'acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'arboreal', 'arborescent'],
    'pronounce': ['act on', 'affirm', 'allege', 'announce', 'annunciate', 'argue', 'articulate', 'assert', 'assever', 'asseverate', 'aver', 'avouch'],
    'pronounced': ['absolute', 'affirmed', 'alleged', 'announced', 'arrant', 'articulated', 'asserted', 'asseverated', 'assured', 'attested', 'averred', 'avouched'],
    'pronouncement': ['parthian shot', 'action', 'address', 'advertisement', 'affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'answer', 'apostrophe', 'appointment'],
    'pronto': ['pdq', 'all at once', 'all together', 'apace', 'at a blow', 'at a stroke', 'at once', 'at one blow', 'at one jump', 'at one stroke', 'at one swoop', 'at one time'],
    'proof': ['christophany', 'ditto copy', 'photostat', 'satanophany', 'xerox', 'xerox copy', 'absolute indication', 'account', 'acid test', 'acquaintance', 'affirmation', 'airtight'],
    'prop': ['advocate', 'afford support', 'airscrew', 'alpenstock', 'arm', 'athletic supporter', 'back', 'back up', 'backbone', 'backing', 'bandeau', 'bear'],
    'propagate': ['bear', 'beget', 'bestrew', 'breed', 'breed true', 'bring forth', 'broadcast', 'bruit about', 'circulate', 'circumfuse', 'copulate', 'crossbreed'],
    'propagation': ['airing', 'attenuation', 'bandying', 'begetting', 'book', 'breeding', 'broadcast', 'broadcasting', 'bruiting', 'bruiting about', 'circulation', 'circumfusion'],
    'propane': ['alcohol', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'charcoal', 'coal', 'coke', 'combustible', 'dope', 'ethane'],
    'propel': ['actuate', 'advance', 'animate', 'bowl', 'bunt', 'butt', 'compel', 'drive', 'drive on', 'egg on', 'energize', 'exhort'],
    'propellant': ['active', 'airscrew', 'alcohol', 'benzine', 'briquette', 'burnable', 'butane', 'carbon', 'catalyst', 'charcoal', 'charge', 'coal'],
    'propelling': ['active', 'bunt', 'butt', 'drive', 'driving', 'driving force', 'impelling', 'impulsion', 'in motion', 'mobile', 'motile', 'motivational'],
    'propensity': ['a thing for', 'affinity', 'an ear for', 'an eye for', 'animus', 'aptitude', 'aptness', 'bent', 'bias', 'capacity for', 'cast', 'character'],
    'proper': ['christian', 'ok', 'absolute', 'accepted', 'accommodated to', 'according to', 'according to hoyle', 'accurate', 'acknowledged', 'adapted', 'adapted to', 'adjusted to'],
    'proper thing': ['bon ton', 'candor', 'conformity', 'consuetude', 'convention', 'cricket', 'custom', 'established way', 'etiquette', 'fair play', 'fair shake', 'fair-mindedness'],
    'properly': ['acceptably', 'according to use', 'accurately', 'adequately', 'advantageously', 'advisably', 'aesthetically', 'amply', 'appropriately', 'aptly', 'artistically', 'as is proper'],
    'propertied': ['blessed with', 'enfeoffed', 'having', 'having and holding', 'holding', 'in possession of', 'landed', 'landholding', 'landowning', 'master of', 'occupying', 'owning'],
    'property': ['acreage', 'acres', 'adverse possession', 'affection', 'affluence', 'alodium', 'aroma', 'assets', 'attribute', 'available means', 'badge', 'balance'],
    'prophecy': ['actuarial prediction', 'afflatus', 'aftertime', 'afteryears', 'apocalypse', 'augury', 'by-and-by', 'cast', 'course ahead', 'crystal ball', 'determinism', 'direct communication'],
    'prophesied': ['approaching', 'coming', 'desired', 'destinal', 'destined', 'determined', 'emergent', 'eventual', 'extrapolated', 'fatal', 'fated', 'fatidic'],
    'prophesy': ['adumbrate', 'anticipate', 'approach', 'augur', 'await', 'be destined', 'be fated', 'be imminent', 'be to be', 'be to come', 'bode', 'cast a horoscope'],
    'prophet': ['cassandra', 'don quixote', 'druid', 'quixote', 'astrologer', 'augur', 'calamity howler', 'clairvoyant', 'crystal gazer', 'daydreamer', 'divinator', 'diviner'],
    'prophet of doom': ['cassandra', 'druid', 'eeyore', 'jeremiah', 'admonisher', 'astrologer', 'augur', 'calamity howler', 'cautioner', 'crystal gazer', 'cynic', 'defeatist'],
    'prophetic': ['biblical', 'gospel', 'mosaic', 'new-testament', 'old-testament', 'apocalyptic', 'apostolic', 'augural', 'auguring', 'canonical', 'divinatory', 'evangelic'],
    'prophylactic': ['iud', 'aegis', 'antacid', 'antidote', 'antiseptic', 'arm guard', 'aseptic', 'backstop', 'bag', 'birth control device', 'boiled', 'buffer'],
    'prophylaxis': ['active treatment', 'adjuvant treatment', 'antigen treatment', 'causal treatment', 'conservative treatment', 'cross-firing', 'diathermic treatment', 'dietetic treatment', 'drip treatment', 'drug treatment', 'empiric treatment', 'epidemiology'],
    'propinquity': ['accord', 'addition', 'adjunct', 'affairs', 'affiliation', 'affinity', 'agnation', 'alliance', 'ancestry', 'approach', 'approximation', 'assemblage'],
    'propitiate': ['adapt', 'adjust', 'allay', 'appease', 'assuage', 'atone', 'atone for', 'calm', 'compensate', 'conciliate', 'conform', 'content'],
    'propitiation': ['united nations troops', 'amends', 'appeasement', 'atonement', 'calming', 'compensation', 'composition', 'compromise', 'conciliation', 'detente', 'dulcification', 'easing of relations'],
    'propitiatory': ['christlike', 'christly', 'acquiescent', 'apologetic', 'appeasing', 'ascetic', 'atoning', 'celestial', 'cleansing', 'compensational', 'compensatory', 'compliant'],
    'propitious': ['advantageous', 'amicable', 'appropriate', 'auspicious', 'befitting', 'beneficent', 'beneficial', 'benevolent', 'benign', 'benignant', 'brave', 'bright'],
    'proponent': ['adherent', 'advocate', 'apologete', 'apologist', 'apologizer', 'backer', 'champion', 'defender', 'enthusiast', 'exponent', 'expounder', 'friend'],
    'proportion': ['accommodate', 'accord', 'acreage', 'adapt', 'addition', 'adjust', 'adjust to', 'agreement', 'allegory', 'allotment', 'allowance', 'amount'],
    'proportional': ['affinitive', 'analogical', 'analogous', 'appertaining', 'associative', 'balanced', 'commensurable', 'commensurate', 'comparable', 'comparative', 'compatible', 'congenial'],
    'proportional representation': ['australian ballot', 'hare system', 'pr', 'absentee voting', 'aye', 'ballot', 'ballot-box stuffing', 'canvass', 'canvassing', 'card voting', 'casting vote', 'colonization'],
    'proportionate': ['accordant', 'adequate', 'affinitive', 'affirmative', 'agreeable', 'agreeing', 'alike', 'ample', 'answerable', 'appertaining', 'associative', 'at one'],
    'proportionately': ['ad eundem', 'appositely', 'as', 'as well', 'ceteris paribus', 'comparatively', 'correspondingly', 'distributively', 'each to each', 'equally', 'equivalently', 'even stephen'],
    'proposal': ['admonition', 'advice', 'advising', 'advocacy', 'aim', 'ambition', 'animus', 'aspiration', 'bid', 'briefing', 'caution', 'caveat'],
    'propose': ['advance', 'advise', 'advocate', 'aim', 'aim at', 'ask', 'aspire after', 'aspire to', 'assert', 'be after', 'become engaged', 'bid'],
    'proposed': ['advised', 'aimed', 'aimed at', 'calculated', 'conscious', 'considered', 'contemplated', 'deliberate', 'deliberated', 'designed', 'envisaged', 'envisioned'],
    'proposition': ['a priori principle', 'a priori truth', 'accost', 'advance', 'affair', 'affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'approach', 'apriorism'],
    'propound': ['advance', 'assert', 'bring before', 'bring forward', 'bring up', 'broach', 'commend to attention', 'introduce', 'launch', 'lay before', 'lay down', 'make a motion'],
    'proprietary': ['balm', 'balsam', 'beneficiary', 'cestui', 'cestui que trust', 'cestui que use', 'deedholder', 'dominion', 'dominium', 'drops', 'drug', 'electuary'],
    'proprieties': ['amenities', 'civilities', 'civility', 'comity', 'convention', 'courtliness', 'decencies', 'decorum', 'dictates of society', 'diplomatic code', 'elegance', 'elegancies'],
    'proprietor': ['beneficiary', 'cestui', 'cestui que trust', 'cestui que use', 'deedholder', 'feoffee', 'feudatory', 'holder', 'householder', 'innkeeper', 'laird', 'landholder'],
    'propriety': ['atticism', 'admissibility', 'advantage', 'advantageousness', 'advisability', 'amenities', 'applicability', 'appositeness', 'appropriateness', 'aptitude', 'aptness', 'auspiciousness'],
    'propulsion': ['action and reaction', 'aeromotor', 'atomic power', 'bunt', 'butt', 'clout', 'compulsion', 'drive', 'driving force', 'electric power', 'electropower', 'horsepower'],
    'prorate': ['ask', 'assess', 'charge', 'charge for', 'demand', 'divide', 'divvy', 'exact', 'impose', 'levy', 'make dutiable', 'parcel'],
    'prosaic': ['attic', 'spartan', 'actual', 'arid', 'ascetic', 'austere', 'bald', 'banal', 'banausic', 'bare', 'barren', 'bland'],
    'prosaicism': ['aridity', 'aridness', 'banality', 'barrenness', 'bromide', 'chestnut', 'cliche', 'commonness', 'commonplace', 'commonplace expression', 'commonplaceness', 'corn'],
    'proscenium': ['acting area', 'anteriority', 'apron', 'apron stage', 'backstage', 'band shell', 'bandstand', 'board', 'bold front', 'brave face', 'brave front', 'bridge'],
    'proscribe': ['anathematize', 'attaint', 'ban', 'banish', 'bar', 'blackball', 'blacklist', 'boycott', 'bring home to', 'cast out', 'censure', 'condemn'],
    'proscription': ['eighteenth amendment', 'prohibition party', 'volstead act', 'anathema', 'anathematizing', 'ban', 'banishment', 'blackball', 'blacklist', 'blasphemy', 'boundary', 'bounds'],
    'prose': ['banality', 'bromide', 'causerie', 'chat', 'chestnut', 'chin', 'cliche', 'commonplace', 'commonplace expression', 'corn', 'expository writing', 'familiar tune'],
    'prosecute': ['abide by', 'accuse', 'adhere to', 'administer', 'arraign', 'bring action against', 'bring into court', 'bring suit', 'bring to justice', 'bring to trial', 'carry on', 'carry out'],
    'prosecution': ['accusal', 'accusation', 'accusing', 'action', 'allegation', 'allegement', 'arraignment', 'bill of particulars', 'blame', 'bringing of charges', 'bringing to book', 'carrying out'],
    'prosecutor': ['ag', 'da', 'kc', 'qc', 'ssc', 'us attorney', 'accusant', 'accuser', 'allegator', 'appellant', 'attorney general', 'civilian'],
    'proselyte': ['christian', 'god-fearing man', 'accepter', 'apostate', 'apostle', 'backslider', 'believer', 'bolter', 'catechumen', 'churchgoer', 'churchite', 'churchman'],
    'prosody': ['stabreim', 'accent', 'accentuation', 'alliterative meter', 'beat', 'cadence', 'emphasis', 'ictus', 'level of stress', 'lilt', 'measure', 'meter'],
    'prospect': ['aftertime', 'afteryears', 'airscape', 'anticipation', 'aptitude', 'aspect', 'aspiration', 'assumption', 'assurance', 'assured faith', 'bare possibility', 'by-and-by'],
    'prospective': ['anticipated', 'approaching', 'awaited', 'coming', 'desired', 'destinal', 'destined', 'determined', 'due', 'emergent', 'eventual', 'expected'],
    'prospectus': ['actuarial prediction', 'agenda', 'aim', 'ambition', 'animus', 'announcement', 'apocalypse', 'aspiration', 'batting order', 'bill', 'bill of fare', 'blueprint'],
    'prosper': ['advance', 'arrive', 'be blooded', 'be successful', 'catch on', 'click', 'come along', 'come off', 'come on', 'connect', 'develop', 'do well'],
    'prosperity': ['saturnia regna', 'saturnian age', 'abundance', 'accomplishment', 'advantage', 'affluence', 'age of aquarius', 'arrival', 'assets', 'bed of roses', 'benefit', 'boom'],
    'prosperous': ['abounding in riches', 'affluent', 'appropriate', 'assured of success', 'auspicious', 'benign', 'benignant', 'booming', 'comfortable', 'comfortably situated', 'coming', 'convenient'],
    'prosthetics': ['antiseptic surgery', 'aseptic surgery', 'chiroplasty', 'cryosurgery', 'dental surgery', 'electrosurgery', 'general surgery', 'heart surgery', 'major surgery', 'minor surgery', 'neurosurgery', 'open-heart surgery'],
    'prostitute': ['b-girl', 'cyprian', 'paphian', 'abuse', 'adulterate', 'alloy', 'bawd', 'befoul', 'bimbo', 'brass', 'call girl', 'canker'],
    'prostitution': ['cosa nostra', 'mafia', 'abuse', 'abuse of office', 'adulteration', 'befouling', 'befoulment', 'black market', 'bootlegging', 'contamination', 'conversion', 'corrupt administration'],
    'prostrate': ['abject', 'accumbent', 'adorant', 'adoring', 'afflict', 'aggrieve', 'all in', 'anguish', 'backscratching', 'beat', 'beat down', 'beat up'],
    'prostration': ['accubation', 'accumbency', 'aching heart', 'adoration', 'adulation', 'adynamia', 'agony', 'agony of mind', 'anemia', 'anguish', 'apple-polishing', 'ass-kissing'],
    'prosy': ['attic', 'spartan', 'arid', 'ascetic', 'austere', 'bald', 'bare', 'barren', 'candid', 'chaste', 'classic', 'classical'],
    'protagonist': ['maecenas', 'abettor', 'actor', 'admirer', 'advocate', 'aficionado', 'angel', 'antagonist', 'antihero', 'apologist', 'backer', 'bit'],
    'protean': ['able to adapt', 'adaptable', 'adjustable', 'allotropic', 'alterable', 'alterative', 'changeable', 'changeful', 'checkered', 'diversiform', 'ever-changing', 'flexible'],
    'protect': ['abet', 'advocate', 'aid', 'arm', 'armor', 'assist', 'avail', 'bail out', 'bear a hand', 'befriend', 'benefit', 'bless'],
    'protected': ['armed', 'cloaked', 'conserved', 'copyrighted', 'covered', 'defended', 'guarded', 'immune', 'immunized', 'insured', 'intact', 'invulnerable'],
    'protection': ['aegis', 'aid', 'armament', 'armor', 'arrest', 'arrestation', 'assistance', 'assurance', 'autarky', 'avoidance reaction', 'barrier', 'benefit'],
    'protection racket': ['cosa nostra', 'mafia', 'badger game', 'black market', 'blackmail', 'bloodsucking', 'bootlegging', 'extortion', 'gambling', 'gray market', 'illegal commerce', 'illegal operations'],
    'protective': ['careful', 'conservational', 'conservationist', 'conservative', 'conservatory', 'conserving', 'covering', 'custodial', 'defending', 'defensive', 'fostering', 'guardian'],
    'protective coloration': ['aggressive mimicry', 'apery', 'camouflage', 'cryptic mimicry', 'disguise', 'domino', 'false colors', 'false face', 'false front', 'incognito', 'mask', 'masque'],
    'protector': ['advocate', 'apologist', 'benefactor', 'benefactress', 'bodyguard', 'champion', 'defender', 'guard', 'guardian angel', 'paladin', 'patron', 'patroness'],
    'protectorate': ['aedileship', 'ally', 'archbishopric', 'archduchy', 'archdukedom', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'bishopric', 'body politic', 'buffer state', 'captive nation'],
    'protein': ['albumin', 'albuminoid', 'amino acid', 'androcyte', 'antheridium', 'antherozoid', 'casein', 'chlorophyll', 'chromoprotein', 'collagen', 'dipeptide', 'edestin'],
    'protest': ['affirm', 'affirmance', 'affirmation', 'allegation', 'allege', 'announce', 'announcement', 'annunciate', 'annunciation', 'argue', 'assert', 'assertion'],
    'protestation': ['affirmance', 'affirmation', 'alibi', 'allegation', 'announcement', 'annunciation', 'apology', 'assertion', 'asseveration', 'averment', 'avouchment', 'avowal'],
    'protester': ['apostate', 'bitter-ender', 'brawler', 'defendant', 'demurrer', 'diehard', 'disputant', 'dissenter', 'dissentient', 'dissident', 'intransigent', 'irreconcilable'],
    'protesting': ['complaining', 'disputatious', 'disputing', 'dissentient', 'dissenting', 'expostulative', 'expostulatory', 'fractious', 'noncooperative', 'objecting', 'obstructive', 'on the barricades'],
    'protocol': ['accord', 'agenda', 'agreement', 'amenities', 'arrangement', 'authority', 'bargain', 'batting order', 'bill', 'bill of fare', 'binding agreement', 'blueprint'],
    'protohistoric': ['aboriginal', 'ancestral', 'antepatriarchal', 'atavistic', 'autochthonous', 'humanoid', 'patriarchal', 'preadamite', 'preglacial', 'prehistoric', 'prehuman', 'prime'],
    'protohuman': ['bronze age man', 'hominidae', 'iron age man', 'stone age man', 'aboriginal', 'aborigine', 'ancestral', 'ancient', 'antediluvian', 'antepatriarchal', 'anthropoid', 'ape-man'],
    'proton': ['kern', 'nmr', 'alpha particle', 'antibaryon', 'antilepton', 'antimeson', 'atom', 'atomic nucleus', 'atomic particle', 'baryon', 'beta particle', 'electron'],
    'protoplasm': ['animal cell', 'bioplast', 'cell', 'cellular tissue', 'cellule', 'chromatoplasm', 'coenocyte', 'corpuscle', 'cytoplasm', 'ectoplasm', 'endoplasm', 'energid'],
    'prototypal': ['antitypic', 'archetypal', 'archetypic', 'classic', 'classical', 'exemplary', 'ideal', 'model', 'paradigmatic', 'primary', 'prototypic', 'quintessential'],
    'prototype': ['geistesgeschichte', 'hegelian idea', 'kantian idea', 'platonic form', 'platonic idea', 'aesthetic form', 'analogue', 'ancestor', 'antecedent', 'antetype', 'antitype', 'archetype'],
    'protract': ['adjourn', 'chatter', 'continue', 'dawdle', 'defer', 'delay', 'drag out', 'draw', 'draw out', 'dwell on', 'elongate', 'extend'],
    'protracted': ['de longue haleine', 'dragged out', 'dragging', 'drawn', 'drawn out', 'drawn-out', 'elongated', 'endless', 'everlasting', 'extended', 'filled out', 'interminable'],
    'protraction': ['adjournal', 'adjournment', 'continualness', 'continuance', 'continuation', 'continuity', 'dallying', 'deferment', 'deferral', 'delay', 'elongation', 'endurance'],
    'protractor': ['astrolabe', 'azimuth circle', 'azimuth compass', 'bevel', 'bevel protractor', 'bevel square', 'clinometer', 'goniometer', 'graphometer', 'pantometer', 'quadrant', 'radiogoniometer'],
    'protrude': ['arise', 'bail out', 'balloon', 'beetle', 'belly out', 'break cover', 'break forth', 'bristle up', 'bulge', 'burst forth', 'cock up', 'come'],
    'protrusion': ['bas-relief', 'bellying', 'boldness', 'bulge', 'bulging', 'bump', 'embossment', 'eminence', 'excrescence', 'excrescency', 'extrusion', 'gibbosity'],
    'protuberance': ['bas-relief', 'bellying', 'boldness', 'bulge', 'bulging', 'embossment', 'eminence', 'excrescence', 'excrescency', 'extrusion', 'feel', 'finish'],
    'protuberant': ['beetling', 'bold', 'bulbous', 'bulging', 'distended', 'eminent', 'emissile', 'excrescent', 'excrescential', 'extruding', 'extrusive', 'gibbous'],
    'proud': ['babylonian', 'corinthian', 'arrogant', 'assured', 'august', 'awe-inspiring', 'awful', 'barbaric', 'big', 'bloated', 'boastful', 'braggart'],
    'proudly': ['olympianly', 'aloofly', 'arrogantly', 'condescendingly', 'contemptuously', 'contumeliously', 'disdainfully', 'elaborately', 'elegantly', 'en grand seigneur', 'erectly', 'extravagantly'],
    'provable': ['absolute', 'actual', 'admitting no question', 'apodictic', 'attestable', 'authenticatable', 'checkable', 'confirmable', 'demonstrable', 'demonstratable', 'evincible', 'factual'],
    'prove': ['affirm', 'afford proof of', 'argue', 'ascertain', 'assay', 'attend', 'attest', 'audit', 'authenticate', 'back', 'back up', 'balance'],
    'proved': ['actual', 'ascertained', 'assured', 'attested', 'authenticated', 'borne out', 'categorically true', 'certain', 'certified', 'circumstantiated', 'confirmed', 'corroborated'],
    'proven': ['ascertained', 'attested', 'authenticated', 'borne out', 'certified', 'circumstantiated', 'confirmed', 'corroborated', 'demonstrated', 'dependable', 'determined', 'established'],
    'provenance': ['beginning', 'commencement', 'conception', 'derivation', 'fountain', 'genesis', 'grass roots', 'head', 'inception', 'origin', 'original', 'origination'],
    'provender': ['aliment', 'barley', 'bird seed', 'board', 'bran', 'bread', 'bread and butter', 'canned foods', 'cat food', 'cheer', 'chicken feed', 'chop'],
    'provenience': ['afterlife', 'beginning', 'commencement', 'conception', 'derivation', 'following', 'fountain', 'future time', 'genesis', 'grass roots', 'hangover', 'head'],
    'proverb': ['adage', 'ana', 'analects', 'aphorism', 'apophthegm', 'apothegm', 'axiom', 'bromide', 'byword', 'catchword', 'cliche', 'coin a phrase'],
    'proverbial': ['accepted', 'acknowledged', 'aphoristic', 'apophthegmatic', 'apothegmatic', 'archetypal', 'axiomatic', 'common', 'commonly known', 'commonplace', 'crisp', 'current'],
    'provide': ['accommodate', 'accommodate with', 'accord', 'afford', 'anticipate', 'arrange', 'arrange for', 'attend to', 'care for', 'cater', 'clear for action', 'clear the decks'],
    'provide for': ['accommodate', 'accommodate with', 'admit', 'admit exceptions', 'afford', 'allow', 'allow for', 'angel', 'arrange for', 'attend to', 'baby-sit', 'back'],
    'provided': ['according as', 'accoutered', 'all ready', 'all set', 'armed', 'armed and ready', 'booted and spurred', 'briefed', 'catered', 'coached', 'cocked', 'endowed'],
    'providence': ['almighty god', 'alpha and omega', 'atropos', 'clotho', 'dame fortune', 'decuma', 'demiourgos', 'demiurge', 'fata', 'fates', 'fortuna', 'god'],
    'provident': ['scotch', 'acute', 'anticipant', 'anticipatory', 'apperceptive', 'appercipient', 'argute', 'astute', 'canny', 'careful', 'cautious', 'chary'],
    'providential': ['god-given', 'accorded', 'allowed', 'anticipant', 'anticipatory', 'appropriate', 'auspicious', 'befitting', 'benignant', 'bestowed', 'blessed', 'blessed with luck'],
    'provider': ['caterer', 'chandler', 'commissariat', 'commissary', 'donor', 'furnisher', 'manciple', 'merchant', 'patron', 'provisioner', 'purveyor', 'quartermaster'],
    'province': ['kreis', 'academic discipline', 'academic specialty', 'agricultural region', 'ally', 'ambit', 'applied science', 'arable land', 'archbishopric', 'archdiocese', 'archduchy', 'archdukedom'],
    'provincial': ['arcadian', 'agrarian', 'agrestic', 'agricultural', 'authoritarian', 'awkward', 'backwoods', 'backwoodsman', 'beg', 'beglerbeg', 'bey', 'bigot'],
    'provincialism': ['acadian', 'anglo-indian', 'brooklynese', 'cajun', 'canadian french', 'cockney', 'french canadian', 'gullah', 'midland', 'midland dialect', 'new england dialect', 'pennsylvania dutch'],
    'provision': ['tlc', 'abundance', 'accommodation', 'accordance', 'accumulation', 'amassment', 'anticipation', 'arrangement', 'award', 'awarding', 'backlog', 'basic training'],
    'provisional': ['accidental', 'ad hoc', 'adventitious', 'aleatory', 'alternate', 'alternative', 'backup', 'band-aid', 'casual', 'circumstantial', 'conditional', 'contingent'],
    'proviso': ['bill', 'boundary condition', 'calendar', 'catch', 'clause', 'companion bills amendment', 'condition', 'donnee', 'dragnet clause', 'enacting clause', 'escalator clause', 'escape clause'],
    'provocateur': ['agent provocateur', 'agitator', 'agitprop', 'catalyst', 'demagogue', 'exciter', 'firebrand', 'fomenter', 'incendiary', 'inciter', 'inflamer', 'instigator'],
    'provocation': ['bothering', 'cause', 'grounds', 'harassment', 'incentive', 'incitement', 'inducement', 'initiation', 'instigation', 'insult', 'irking', 'irritation'],
    'provocative': ['acceptable', 'adorable', 'aggravating', 'aggravative', 'agitating', 'agreeable', 'alluring', 'annoying', 'appealing', 'appetizing', 'arousing', 'attractive'],
    'provoke': ['abet', 'abrade', 'activate', 'affect the interest', 'affront', 'agent provocateur', 'aggravate', 'agitate', 'alienate', 'amplify', 'anger', 'animate'],
    'provoked': ['aggravated', 'amplified', 'angry', 'annoyed', 'augmented', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'chafed', 'deliberately provoked', 'disturbed'],
    'provoking': ['aggravating', 'agitating', 'alluring', 'annoying', 'ardent', 'bothering', 'bothersome', 'breathtaking', 'burning', 'challenging', 'charged', 'cliff-hanging'],
    'provost': ['academic dean', 'administration', 'administrator', 'archon', 'chancellor', 'chief executive', 'chief executive officer', 'dean', 'dean of men', 'dean of women', 'executive', 'executive director'],
    'prowess': ['dutch courage', 'ability', 'address', 'adeptness', 'adroitness', 'airmanship', 'aptitude', 'artfulness', 'artisanship', 'artistry', 'boldness', 'braveness'],
    'prowl': ['bat around', 'bum', 'clandestine behavior', 'clandestinity', 'couch', 'count ties', 'cover', 'covertness', 'crawl', 'creep', 'cruise', 'divagate'],
    'prowler': ['body snatcher', 'booster', 'chicken thief', 'con man', 'crook', 'den of thieves', 'embezzler', 'filcher', 'ganef', 'ghoul', 'grafter', 'grave robber'],
    'proximate': ['advancing', 'appendant', 'approaching', 'approximate', 'approximating', 'approximative', 'arm-in-arm', 'attracted to', 'burning', 'cheek-by-jowl', 'close', 'coming'],
    'proximity': ['accord', 'addition', 'adjacency', 'adjunct', 'affairs', 'affiliation', 'affinity', 'alliance', 'approach', 'approximation', 'assemblage', 'association'],
    'proxy': ['australian ballot', 'hare system', 'indiana ballot', 'massachusetts ballot', 'absentee ballot', 'advocate', 'agency', 'agent', 'agentship', 'alter ego', 'alternate', 'alternative'],
    'prudence': ['abnegation', 'abstinence', 'acumen', 'advantage', 'advantageousness', 'advisability', 'anticipation', 'appropriateness', 'astuteness', 'austerity', 'austerity program', 'awareness'],
    'prudent': ['argus-eyed', 'scotch', 'advisable', 'alert', 'all ears', 'all eyes', 'anticipant', 'anticipatory', 'attentive', 'aux aguets', 'bland', 'canny'],
    'prudish': ['quakerish', 'victorian', 'austere', 'censorious', 'choicy', 'choosy', 'conscientious', 'critical', 'decorous', 'demure', 'discriminating', 'discriminative'],
    'prune': ['abbreviate', 'abridge', 'abscind', 'abstract', 'amputate', 'annihilate', 'ax', 'backset', 'ban', 'bar', 'bisect', 'blockhead'],
    'pruned': ['spartan', 'abbreviated', 'abridged', 'abstracted', 'aposiopestic', 'bobbed', 'brief', 'brusque', 'capsule', 'capsulized', 'clipped', 'close'],
    'prurience': ['an universal wolf', 'andromania', 'animality', 'aphrodisia', 'appetence', 'appetency', 'appetite', 'appetition', 'bawdiness', 'biological urge', 'bodily appetite', 'carnal desire'],
    'prurient': ['cyprian', 'fescennine', 'paphian', 'agape', 'agog', 'all agog', 'animal', 'aphrodisiomaniacal', 'athirst', 'bawdy', 'blue', 'burning with curiosity'],
    'pry': ['paul pry', 'paul-pry', 'peeping tom', 'backseat driver', 'bar', 'beam', 'beat the bushes', 'bend the eyes', 'boom', 'burrow', 'busybody', 'cant hook'],
    'pry loose from': ['badger', 'blackmail', 'exact', 'extort', 'force from', 'levy blackmail', 'rend', 'rend from', 'rip', 'rip from', 'screw', 'shake down'],
    'pry out': ['cross-examine', 'cross-interrogate', 'cross-question', 'dig out', 'extract information', 'ferret out', 'fish out', 'go over', 'grill', 'grub up', 'hunt out', 'inquisition'],
    'prying': ['busy', 'busybody', 'curious', 'delving', 'digging', 'fishing', 'forward', 'impertinent', 'in search of', 'inquisitive', 'inquisitorial', 'loaded for bear'],
    'ps': ['parthian shot', 'addendum', 'afterthought', 'appendix', 'back matter', 'chorus', 'coda', 'codicil', 'colophon', 'conclusion', 'consequence', 'continuance'],
    'psalm': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'negro spiritual', 'nunc dimittis', 'te deum', 'trisagion'],
    'psalmbook': ['book of psalms', 'psalm book', 'best seller', 'book', 'bound book', 'classic', 'coloring book', 'definitive work', 'folio', 'great work', 'hardback', 'juvenile'],
    'psalter': ['book of psalms', 'psalm book', 'best seller', 'book', 'bound book', 'classic', 'coloring book', 'definitive work', 'folio', 'great work', 'hardback', 'juvenile'],
    'pseudo': ['affected', 'apocryphal', 'artificial', 'assumed', 'bastard', 'bogus', 'brummagem', 'colorable', 'colored', 'counterfeit', 'counterfeited', 'distorted'],
    'psych': ['agitate', 'answer', 'bottom', 'bug', 'clear up', 'convulse', 'crack', 'debug', 'decipher', 'decode', 'discompose', 'disentangle'],
    'psych out': ['answer', 'bottom', 'clear up', 'crack', 'crush', 'dash', 'debug', 'decipher', 'decode', 'demoralize', 'disentangle', 'divine'],
    'psyche': ['vernunft', 'anima', 'anima humana', 'animus', 'atman', 'ba', 'brain', 'brains', 'breath', 'breath of life', 'buddhi', 'coconscious'],
    'psyched up': ['all ready', 'all set', 'armed', 'armed and ready', 'booted and spurred', 'briefed', 'coached', 'cocked', 'equipped', 'familiarized', 'good and ready', 'groomed'],
    'psychedelic': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic', 'consciousness-expanding', 'diethyltryptamine', 'dimethyltryptamine'],
    'psychiatrist': ['adler', 'freud', 'horney', 'pavlov', 'reich', 'skinner', 'watson', 'alienist', 'analyst', 'anesthesiologist', 'behavior therapist', 'cardiologist'],
    'psychic': ['cassandra', 'druid', 'astrologer', 'augur', 'automatist', 'calamity howler', 'cerebral', 'clairvoyant', 'cognitive', 'crystal gazer', 'divinator', 'diviner'],
    'psychical': ['airy', 'arcane', 'asomatous', 'astral', 'automatist', 'bodiless', 'cerebral', 'clairaudient', 'clairsentient', 'clairvoyant', 'conceptive', 'conceptual'],
    'psychics': ['bodilessness', 'ghostliness', 'immateriality', 'immaterialness', 'impalpability', 'imponderability', 'incorporeality', 'incorporeity', 'inextension', 'intangibility', 'metapsychics', 'metapsychism'],
    'psycho': ['abnormal', 'bereft of reason', 'brainsick', 'catatoniac', 'certifiable case', 'crackbrained', 'cracked', 'crazed', 'crazy', 'daft', 'deluded', 'demented'],
    'psychoanalysis': ['adlerian psychology', 'freudian psychology', 'freudianism', 'gestalt psychology', 'horneyan psychology', 'jungian psychology', 'pavlovian psychology', 'reichian psychology', 'skinnerian psychology', 'watsonian psychology', 'analysis', 'analytical psychology'],
    'psychodrama': ['arica movement', 'erhard seminars training', 'grand guignol', 'new consciousness', 'passion play', 'pentothal interview', 'sat', 't-group', 'tom show', 'abreaction', 'acting-out', 'antimasque'],
    'psychological': ['cerebral', 'cognitive', 'conceptive', 'conceptual', 'endopsychic', 'functional', 'intellectual', 'intelligent', 'internal', 'mental', 'neuropsychiatric', 'noetic'],
    'psychological block': ['agnosia', 'block', 'blockage', 'blocking', 'censorship', 'delirium', 'delusion', 'delusion of persecution', 'disorientation', 'flight of ideas', 'hallucination', 'hallucinosis'],
    'psychological moment': ['a-day', 'd day', 'h hour', 'charged moment', 'critical moment', 'crucial moment', 'day', 'deadline', 'decisive moment', 'eleventh hour', 'fateful moment', 'hour'],
    'psychological test': ['binet-simon test', 'brown personality inventory', 'goldstein-sheerer test', 'iq', 'iq test', 'kent mental test', 'minnesota preschool scale', 'oseretsky test', 'rorschach test', 'stanford revision', 'stanford-binet test', 'szondi test'],
    'psychological warfare': ['a-war', 'h-war', 'abnormal psychology', 'academic psychology', 'aerial warfare', 'amphibious warfare', 'analytical psychology', 'animal psychology', 'applied psychology', 'armed neutrality', 'association psychology', 'atom war'],
    'psychologist': ['adler', 'freud', 'horney', 'pavlov', 'reich', 'skinner', 'watson', 'alienist', 'clinical psychologist', 'industrial psychologist', 'neuropsychiatrist', 'psychiatrist'],
    'psychology': ['affect', 'affectivity', 'anatomy', 'anthropography', 'anthropologist', 'anthropology', 'anthropometry', 'attitude', 'behavior', 'behavioral science', 'constitution', 'craniology'],
    'psychometrics': ['iq meter', 'abnormal psychology', 'academic psychology', 'altimetry', 'analytical psychology', 'animal psychology', 'applied psychology', 'association psychology', 'bathymetry', 'biometrics', 'biometry', 'cadastration'],
    'psychoneurosis': ['accident neurosis', 'anxiety hysteria', 'anxiety neurosis', 'association neurosis', 'battle fatigue', 'blast neurosis', 'combat fatigue', 'compensation neurosis', 'compulsion neurosis', 'conversion hysteria', 'conversion neurosis', 'expectation neurosis'],
    'psychoneurotic': ['alcoholic', 'alternating personality', 'antisocial personality', 'disordered', 'disordered personality', 'disturbed', 'disturbed personality', 'double personality', 'drug user', 'dual personality', 'escapist', 'hostile personality'],
    'psychopath': ['alcoholic', 'alternating personality', 'antisocial personality', 'catatoniac', 'certifiable case', 'disordered personality', 'disturbed personality', 'double personality', 'drug user', 'dual personality', 'escapist', 'hostile personality'],
    'psychopathic': ['brain-damaged', 'brain-injured', 'catatonic', 'certifiable', 'disturbed', 'functional', 'manic-depressive', 'mentally ill', 'mentally sick', 'neuropsychiatric', 'neurotic', 'paranoiac'],
    'psychopathy': ['aberration', 'abulia', 'alienation', 'arteriosclerotic psychosis', 'certifiability', 'character disorder', 'dementia paralytica', 'derangement', 'dipsomania', 'distraction', 'drug addiction', 'folie du doute'],
    'psychosis': ['abulia', 'arteriosclerotic psychosis', 'brain disease', 'certifiability', 'crack-up', 'dementia paralytica', 'dipsomania', 'drug addiction', 'emotional disorder', 'emotional instability', 'folie du doute', 'functional nervous disorder'],
    'psychotherapy': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'assertiveness training', 'behavior modification', 'behavior therapy', 'bioenergetics', 'biofeedback', 'confrontation therapy'],
    'psychotic': ['abnormal', 'alcoholic', 'alternating personality', 'antisocial personality', 'bats', 'batty', 'bedlamite', 'bonkers', 'brain-damaged', 'brain-injured', 'catatoniac', 'catatonic'],
    'pub': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'boardinghouse', 'cabaret', 'cafe', 'cocktail lounge'],
    'pubescent': ['adolescent', 'attenuate', 'attenuated', 'bristly', 'bushy', 'cirrose', 'dainty', 'delicate', 'downy', 'feathery', 'filmy', 'fine'],
    'public': ['babbittish', 'everyman', 'john doe', 'philistine', 'accessible', 'acknowledged', 'adherent', 'admitted', 'affirmed', 'alehouse', 'announced', 'apparent'],
    'public address system': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'public assistance': ['adc', 'medicaid', 'medicare', 'aid', 'alimony', 'allotment', 'allowance', 'annuity', 'assistance', 'bounty', 'cradle-to-grave security', 'depletion allowance'],
    'public enemy': ['judas', 'adversary', 'antagonist', 'archenemy', 'bad person', 'betrayer', 'bitter enemy', 'convict', 'criminal', 'crook', 'deceiver', 'delinquent'],
    'public house': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'boardinghouse', 'cabaret', 'cafe', 'cocktail lounge'],
    'public image': ['affectation', 'affectedness', 'airs', 'airs and graces', 'apparent character', 'appearances', 'artificiality', 'display', 'exteriors', 'external appearance', 'externals', 'facade'],
    'public knowledge': ['pr', 'ballyhoo', 'blurb', 'bright light', 'celebrity', 'common knowledge', 'cry', 'currency', 'daylight', 'eclat', 'exposure', 'fame'],
    'public opinion': ['assumption', 'attitude', 'backscratching', 'climate of opinion', 'common belief', 'community sentiment', 'conceit', 'concept', 'conception', 'conclusion', 'consensus gentium', 'consideration'],
    'public relations': ['pr', 'ballyhoo', 'blurb', 'bright light', 'celebrity', 'common knowledge', 'cry', 'currency', 'daylight', 'eclat', 'exposure', 'fame'],
    'public school': ['gymnasium', 'latin school', 'realgymnasium', 'realschule', 'academy', 'alternate', 'alternative school', 'blab school', 'boarding school', 'central school', 'consolidated school', 'continuation school'],
    'public servant': ['bureaucrat', 'civil servant', 'functionary', 'functionnaire', 'holdover', 'incumbent', 'ins', 'jack-in-office', 'lame duck', 'mandarin', 'new broom', 'office-bearer'],
    'public speaker': ['cicero', 'demosthenes', 'william jennings bryan', 'winston churchill', 'debater', 'declaimer', 'demagogue', 'haranguer', 'jawsmith', 'orator', 'panelist', 'platform orator'],
    'public trough': ['fort knox', 'bank', 'blackmail', 'boodle', 'booty', 'bursary', 'campaign contribution', 'campaign fund', 'cash register', 'cashbox', 'chest', 'coffer'],
    'public utility': ['aktiengesellschaft', 'aktiebolag', 'body corporate', 'business', 'business establishment', 'cartel', 'chamber of commerce', 'combine', 'commercial enterprise', 'compagnie', 'company', 'concern'],
    'publican': ['internal revenue service', 'assessor', 'barkeep', 'barkeeper', 'barmaid', 'barman', 'bartender', 'bootlegger', 'brewer', 'brewmaster', 'customhouse', 'customs'],
    'publication': ['christophany', 'satanophany', 'account', 'acquaintance', 'advertisement', 'advertising', 'airing', 'albertype', 'angelophany', 'announcement', 'annual', 'appearance'],
    'publicist': ['ag', 'da', 'kc', 'qc', 'ssc', 'us attorney', 'annotator', 'attorney general', 'book reviewer', 'city editor', 'civilian', 'columnist'],
    'publicity': ['pr', 'acclaim', 'account', 'acquaintance', 'advertising', 'announcement', 'ballyhoo', 'blue book', 'blurb', 'briefing', 'bright light', 'broadcasting'],
    'publicize': ['advance', 'advertise', 'announce', 'ballyhoo', 'bark', 'bill', 'boost', 'broadcast', 'bruit', 'build up', 'bulletin', 'circularize'],
    'publish': ['advertise', 'air', 'announce', 'annunciate', 'bestrew', 'break it to', 'break the news', 'breathe', 'bring out', 'broach', 'broadcast', 'bruit about'],
    'published': ['accessible', 'affirmed', 'announced', 'broadcast', 'brought to notice', 'circulated', 'common knowledge', 'common property', 'current', 'declared', 'diffused', 'disseminated'],
    'publisher': ['adviser', 'announcer', 'annunciator', 'authority', 'bibliognost', 'bibliographer', 'biblioklept', 'bibliolater', 'bibliomane', 'bibliomaniac', 'bibliopegist', 'bibliophage'],
    'publishing': ['ap', 'associated press', 'fleet street', 'reuters', 'upi', 'united press international', 'airing', 'albertype', 'bandying', 'book', 'book printing', 'book publishing'],
    'puce': ['titian', 'titian-red', 'bricky', 'cardinal', 'carmine', 'carnation', 'carnelian', 'cerise', 'cherry', 'cherry-colored', 'cherry-red', 'crimson'],
    'puck': ['dingbelle', 'fifinella', 'hob', 'hobgoblin', 'jd', 'bad boy', 'bad fairy', 'bad peri', 'booger', 'brat', 'buffoon', 'bugger'],
    'pucker': ['abbreviate', 'agitation', 'all-overs', 'angst', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat', 'anxiousness', 'apprehension'],
    'puckered': ['clamped', 'cockled', 'cockly', 'compressed', 'concentrated', 'condensed', 'consolidated', 'constricted', 'contracted', 'corrugate', 'corrugated', 'cramped'],
    'puckering': ['abbreviation', 'astriction', 'astringency', 'bottleneck', 'cervix', 'circumscription', 'coarctation', 'compactedness', 'compaction', 'compression', 'compressure', 'concentration'],
    'puckish': ['antic', 'arch', 'devilish', 'elfish', 'elvish', 'foolish', 'full of mischief', 'high-spirited', 'impish', 'knavish', 'larkish', 'mischief-loving'],
    'pudding': ['charlotte', 'albumen', 'batter', 'blubber', 'bonnyclabber', 'breeze', 'butter', 'carrot pudding', 'cataplasm', 'chocolate mousse', 'clabber', 'clay'],
    'puddinghead': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead'],
    'puddle': ['artificial lake', 'bayou lake', 'chuckhole', 'cistern', 'dam', 'dead water', 'dike', 'doodle', 'etang', 'farm pond', 'fishpond', 'freshwater lake'],
    'pudency': ['blush', 'blushing', 'coloring', 'crimsoning', 'decency', 'decorousness', 'decorum', 'delicacy', 'elegance', 'flush', 'flushing', 'mantling'],
    'pudenda': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'pudgy': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blocky', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky'],
    'puerile': ['asinine', 'babish', 'babyish', 'beardless', 'boyish', 'boylike', 'calflike', 'childish', 'childlike', 'coltish', 'foolish', 'girlish'],
    'puerility': ['babyishness', 'boylikeness', 'callowness', 'childishness', 'childlikeness', 'girlishness', 'immaturity', 'imprudence', 'inadvisability', 'inattention', 'inconsideration', 'indiscreetness'],
    'puff': ['aqua-lung', 'danish pastry', 'french pastry', 'pr', 'acknowledgment', 'add to', 'adulate', 'advertise', 'advertisement', 'advocate', 'aggrandize', 'amplify'],
    'puff up': ['add to', 'adulate', 'aggrandize', 'amplify', 'apotheosize', 'augment', 'balloon', 'belaud', 'bepraise', 'bless', 'bloat', 'blow up'],
    'puffball': ['algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'diatom', 'fern', 'fruits and vegetables'],
    'puffed up': ['aggrandized', 'aggressively self-confident', 'amplified', 'ballyhooed', 'biggety', 'bloated', 'bloated with pride', 'blown up', 'bumptious', 'chesty', 'cocky', 'conceited'],
    'puffing': ['asthmatic', 'blurb', 'breathing', 'breathless', 'errhine', 'expiratory', 'heaving', 'huffing', 'inspiratory', 'nasal', 'out of breath', 'panting'],
    'puffy': ['adipose', 'aeolian', 'airish', 'airy', 'arrogant', 'beefy', 'big-bellied', 'blasty', 'bloated', 'blown up', 'blowy', 'blowzy'],
    'pug': ['chinese boxer', 'arch', 'bantamweight', 'black belt', 'blocky', 'boss', 'boxer', 'brown belt', 'bruiser', 'bump', 'chubby', 'chunky'],
    'pug nosed': ['bandy', 'bandy-legged', 'blemished', 'bloated', 'bowlegged', 'club-footed', 'defaced', 'deformed', 'disfigured', 'dwarfed', 'flatfooted', 'grotesque'],
    'pugilist': ['chinese boxer', 'amateur athlete', 'archer', 'athlete', 'ballplayer', 'bantamweight', 'baseballer', 'baseman', 'batter', 'battery', 'battler', 'black belt'],
    'pugnacious': ['aggressive', 'antagonistic', 'battling', 'bellicose', 'belligerent', 'bickering', 'bloodthirsty', 'bloody', 'bloody-minded', 'brawling', 'chauvinist', 'chauvinistic'],
    'puissant': ['absolute', 'armipotent', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'beefy', 'bouncing', 'clothed with authority', 'cogent', 'commanding'],
    'puke': ['barf', 'be nauseated', 'be seasick', 'be sick', 'bring up', 'cascade', 'cast', 'cat', 'choke on', 'chuck up', 'disgorge', 'disgorgement'],
    'pukka': ['authentic', 'bona fide', 'fair', 'first class', 'genuine', 'good', 'honorable', 'indubitable', 'out-and-out', 'proper', 'questionless', 'real'],
    'puky': ['airsick', 'barfy', 'carsick', 'crappy', 'disgusting', 'fecal', 'feculent', 'fetid', 'filthy', 'flyblown', 'foul', 'gloppy'],
    'pule': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'bray', 'call', 'caterwaul'],
    'puling': ['jeremianic', 'bawling', 'blatant', 'complaining', 'crying', 'faultfinding', 'fretful', 'howling', 'lamentive', 'lowing', 'moanful', 'mournful'],
    'pull': ['abandon', 'accomplish', 'adduct', 'adduction', 'affinity', 'allure', 'allurement', 'amperage', 'appeal', 'apprehend', 'armipotence', 'arrest'],
    'pull back': ['about the bush', 'abrupt', 'alienate', 'avoid', 'back down', 'back out', 'backslide', 'balance', 'beat a retreat', 'beat around', 'beg the question', 'blench'],
    'pull down': ['accept', 'acquire', 'admit', 'annihilate', 'assume', 'bag', 'be paid', 'be remunerated', 'be salaried', 'be seized of', 'bear down', 'beat down'],
    'pull in': ['accomplish', 'achieve', 'apprehend', 'approach', 'arrest', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be received', 'bit'],
    'pull off': ['accomplish', 'achieve', 'bring about', 'bring off', 'bring through', 'bring to effect', 'bring to pass', 'carry into execution', 'carry off', 'carry out', 'carry through', 'come through with'],
    'pull out': ['abandon', 'abrupt', 'alienate', 'apostatize', 'avulse', 'back down', 'back out', 'bank', 'be getting along', 'beat a retreat', 'beg off', 'betray'],
    'pull strings': ['act on', 'angle', 'approach', 'bear upon', 'contrive', 'draw', 'draw on', 'engineer', 'exert influence', 'finagle', 'gerrymander', 'get cozy with'],
    'pull together': ['act in concert', 'act together', 'affiliate', 'ally', 'amalgamate', 'associate', 'band', 'band together', 'be in league', 'club together', 'coact', 'coalesce'],
    'pull up': ['arraign', 'arrest', 'avulse', 'bank', 'block', 'brake', 'bring to', 'bring up', 'bring up short', 'cease fire', 'check', 'checkmate'],
    'pullback': ['avoidance', 'bitter-ender', 'conservative', 'cringe', 'curtailment', 'cut', 'cutback', 'disengagement', 'dodge', 'duck', 'evasion', 'fallback'],
    'pullet': ['bantam', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'birdling', 'broiler', 'brooder', 'broody hen', 'calf', 'capon', 'catling'],
    'pulling': ['adductive', 'alluring', 'attracting', 'attractive', 'attrahent', 'avulsion', 'compotation', 'cutting out', 'deracination', 'disentanglement', 'draft', 'dragging'],
    'pulling power': ['adduction', 'affinity', 'allurement', 'attractance', 'attraction', 'attractiveness', 'attractivity', 'capillarity', 'capillary attraction', 'centripetal force', 'draft', 'drag'],
    'pullman car': ['pullman', 'baggage car', 'boxcar', 'caboose', 'car', 'carriage', 'chair car', 'coach', 'coal car', 'covered waggon', 'day coach', 'diner'],
    'pullout': ['acrobatics', 'aerobatics', 'avoidance', 'banking', 'chandelle', 'crabbing', 'cringe', 'disengagement', 'dive', 'diving', 'dodge', 'duck'],
    'pullulate': ['abound', 'abound with', 'be alive with', 'be fruitful', 'be productive', 'beget', 'blossom', 'brew', 'bristle with', 'bud', 'burgeon', 'burst forth'],
    'pulmonary': ['asthmatic', 'breathing', 'errhine', 'expiratory', 'heaving', 'huffing', 'inspiratory', 'nasal', 'panting', 'pneumonic', 'puffing', 'pulmonic'],
    'pulp': ['albumen', 'batter', 'bonnyclabber', 'bruise', 'butter', 'cataplasm', 'cheap', 'chew', 'clabber', 'cornstarch', 'cream', 'crush'],
    'pulpiness': ['butteriness', 'creaminess', 'delicacy', 'downiness', 'easiness', 'featheriness', 'flossiness', 'fluffiness', 'gentleness', 'insolidity', 'leniency', 'mellowness'],
    'pulpit': ['ambo', 'apostleship', 'balcony', 'call', 'care of souls', 'catafalque', 'dais', 'desk', 'emplacement', 'estrade', 'floor', 'gallery'],
    'pulpy': ['baccate', 'buttery', 'creamy', 'dead', 'dilute', 'diluted', 'doughy', 'edematous', 'emulsive', 'fade', 'flabby', 'flat'],
    'pulsar': ['beehive', 'cepheid variable', 'hertzsprung-russell diagram', 'hyades', 'messier catalog', 'ngc', 'pleiades', 'seven sisters', 'absolute magnitude', 'binary star', 'black hole', 'double star'],
    'pulsate': ['alternate', 'be here again', 'beat', 'beat a ruffle', 'beat a tattoo', 'circle', 'come again', 'come and go', 'come around', 'come round', 'come round again', 'come up again'],
    'pulsating': ['beating', 'cadenced', 'cadent', 'ceaseless', 'chattering', 'constant', 'continual', 'in numbers', 'in rhythm', 'incessant', 'machine gun', 'measured'],
    'pulsation': ['alternation', 'arrhythmia', 'bar beat', 'barrage', 'beat', 'beating', 'ceaselessness', 'chattering', 'constancy', 'constant flow', 'continualness', 'continuity'],
    'pulse': ['algae', 'alternate', 'arrhythmia', 'arsis', 'autophyte', 'bar beat', 'be here again', 'bean', 'beat', 'beating', 'bicker', 'bout'],
    'pulsing': ['alternate', 'beating', 'cadenced', 'cadent', 'circling', 'cyclic', 'epochal', 'even', 'every other', 'full', 'in numbers', 'in rhythm'],
    'pulverize': ['abrade', 'annihilate', 'atomize', 'bang', 'baste', 'batter', 'beat', 'bray', 'break into pieces', 'break to pieces', 'break up', 'brecciate'],
    'pulverized': ['branny', 'chalklike', 'chalky', 'comminute', 'comminuted', 'crushed', 'detrital', 'detrited', 'disintegrated', 'dusty', 'efflorescent', 'farinaceous'],
    'pulverizer': ['cheese grater', 'comminutor', 'crusher', 'granulator', 'grater', 'grinder', 'kominuter', 'levigator', 'masher', 'mill', 'millstone', 'mortar and pestle'],
    'puma': ['leo', 'siberian tiger', 'bobcat', 'cat-a-mountain', 'catamount', 'cheetah', 'cougar', 'jaguar', 'leopard', 'lion', 'lynx', 'mountain lion'],
    'pumice stone': ['abstergent', 'cathartic', 'cleaner', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing cream', 'cold cream', 'cream', 'dentifrice', 'depurant', 'detergent'],
    'pummel': ['bang', 'baste', 'bastinado', 'batter', 'beat', 'belabor', 'belt', 'birch', 'buffet', 'cane', 'club', 'cowhide'],
    'pump': ['abdomen', 'add to', 'aggrandize', 'air pump', 'amplify', 'animate', 'anus', 'appendix', 'aspirator', 'augment', 'bail out', 'beer pump'],
    'pumpkin head': ['addlebrain', 'addlehead', 'addlepate', 'beefhead', 'blockhead', 'blubberhead', 'blunderhead', 'bonehead', 'bufflehead', 'cabbagehead', 'chowderhead', 'chucklehead'],
    'pun': ['abuse of terms', 'acrostic', 'alliterate', 'alliteration', 'ambiguity', 'amphibologism', 'amphibology', 'amphiboly', 'anagram', 'assonance', 'assonate', 'be merry with'],
    'punch': ['mickey', 'mickey finn', 'aggressiveness', 'amperage', 'aperitif', 'armipotence', 'assault', 'auger', 'authority', 'awl', 'bang', 'bash'],
    'punch bowl': ['john barleycorn', 'alcohol', 'alcoholic beverage', 'alcoholic drink', 'alveolation', 'alveolus', 'antrum', 'aqua vitae', 'ardent spirits', 'armpit', 'basin', 'beverage'],
    'punch in': ['accomplish', 'achieve', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be received', 'blow in', 'bob up', 'check in'],
    'puncher': ['broncobuster', 'buckaroo', 'caballero', 'cattleman', 'cavalier', 'cavalryman', 'chevalier', 'circus rider', 'cowboy', 'cowgirl', 'cowhand', 'cowherd'],
    'punchy': ['acid', 'bedazzled', 'biting', 'corrosive', 'cutting', 'dazed', 'dazzled', 'dopey', 'driving', 'effective', 'forceful', 'forcible'],
    'punctilious': ['accurate', 'active', 'attentive', 'careful', 'censorious', 'choicy', 'choosy', 'close', 'compliant', 'conforming', 'conscientious', 'conscionable'],
    'punctual': ['accurate', 'active', 'alert', 'apt', 'attentive', 'careful', 'close', 'compliant', 'conforming', 'conscientious', 'conscionable', 'constant'],
    'punctuality': ['accuracy', 'acuity', 'acuteness', 'agility', 'alacrity', 'alertness', 'attention', 'attention to detail', 'attentiveness', 'brightness', 'circumstantiality', 'clockwork regularity'],
    'punctuate': ['accent', 'accentuate', 'analyze', 'belabor', 'blaze', 'blaze a trail', 'blemish', 'blotch', 'bracket', 'brand', 'break', 'chalk'],
    'punctuation': ['alphabet', 'ampersand', 'angle brackets', 'apostrophe', 'braces', 'colon', 'comma', 'dash', 'decimal point', 'diacritical mark', 'diagonal', 'dot'],
    'puncture': ['abrade', 'abrasion', 'acupunctuation', 'acupuncture', 'auger', 'bark', 'belie', 'birthmark', 'bite', 'blaze', 'blaze a trail', 'blemish'],
    'punctureproof': ['airtight', 'ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'corrosionproof', 'dampproof', 'fire-resisting', 'fireproof', 'flameproof', 'foolproof', 'hermetic'],
    'pundit': ['brahman', 'ramwat', 'abecedarian', 'academician', 'aficionado', 'amateur', 'authority', 'bairagi', 'bashara', 'bhikhari', 'bhikshu', 'bookman'],
    'pungency': ['acerbity', 'acescency', 'acidity', 'acidulousness', 'acridity', 'acridness', 'astringence', 'astringency', 'bitter pill', 'bitterness', 'brilliance', 'causticity'],
    'pungent': ['attic', 'acerb', 'acerbate', 'acerbic', 'acescent', 'acid', 'acrid', 'acrimonious', 'acute', 'afflictive', 'agonizing', 'amaroidal'],
    'punish': ['abuse', 'admonish', 'agonize', 'amerce', 'avenge', 'banish', 'batter', 'be quits', 'beat', 'beat up', 'birch', 'bloody'],
    'punishable': ['actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'black-market', 'bootleg', 'chargeable', 'contraband', 'contrary to law', 'criminal', 'felonious'],
    'punishing': ['herculean', 'arduous', 'backbreaking', 'burdensome', 'castigatory', 'chastening', 'chastising', 'corrective', 'crushing', 'demanding', 'disciplinary', 'draining'],
    'punishment': ['abuse', 'admonishment', 'admonition', 'amercement', 'avengement', 'banishment', 'battering', 'beating', 'caning', 'cashiering', 'castigating', 'castigation'],
    'punitive': ['avenging', 'castigating', 'castigatory', 'chastening', 'chastising', 'compensatory', 'correctional', 'corrective', 'disciplinary', 'grudgeful', 'grueling', 'implacable'],
    'punk': ['german tinder', 'jd', 'mickey mouse', 'a nobody', 'a nothing', 'amadou', 'amiss', 'auntie', 'awful', 'bad', 'balderdash', 'baloney'],
    'punster': ['banana', 'burlesquer', 'caricaturist', 'clown', 'comedian', 'comic', 'cutup', 'epigrammatist', 'funnyman', 'gag writer', 'gagman', 'gagster'],
    'punt': ['ante', 'ante up', 'back', 'bet', 'bet on', 'boot', 'calcitration', 'call', 'catch a crab', 'cover', 'cut a crab', 'drop kick'],
    'puny': ['lenten', 'spartan', 'abstemious', 'ascetic', 'attenuated', 'austere', 'breakable', 'brittle', 'cadaverous', 'cheap-jack', 'cobwebby', 'corpselike'],
    'pup': ['seeing eye dog', 'bandog', 'be confined', 'bear', 'bear a child', 'bear young', 'birdling', 'bitch', 'boldface', 'bowwow', 'boy', 'brazenface'],
    'pupil': ['apprentice', 'auditor', 'autodidact', 'baby blues', 'banjo eyes', 'beginner', 'bright eyes', 'catechumen', 'clear eyes', 'cornea', 'disciple', 'educatee'],
    'puppet': ['charlie mccarthy', 'elzevir', 'federal', 'adherent', 'agate', 'agent', 'amanuensis', 'ancilla', 'apple-polisher', 'appliance', 'ass-licker', 'baby'],
    'puppet show': ['burlesque show', 'carnival', 'circus', 'coochie show', 'fantoccini', 'floor show', 'galanty show', 'girly show', 'hootchy-kootchy show', 'leg show', 'light show', 'magic show'],
    'puppy': ['beau brummel', 'seeing eye dog', 'bandog', 'beau', 'birdling', 'bitch', 'blade', 'blood', 'boldface', 'boulevardier', 'bowwow', 'boy'],
    'purblind': ['authoritarian', 'bigot', 'bigoted', 'blear-eyed', 'bleary-eyed', 'blind', 'blindfold', 'blindfolded', 'borne', 'closed', 'constricted', 'cramped'],
    'purchasable': ['approachable', 'available', 'bribable', 'buyable', 'corrupt', 'corruptible', 'fixable', 'hireling', 'marketable', 'mercenary', 'obtainable', 'on the market'],
    'purchase': ['achieve', 'acquire', 'acquiring', 'acquisition', 'advantage', 'approach', 'ascendancy', 'attain', 'authority', 'bear hug', 'bite', 'bribe'],
    'purchasing power': ['base pay', 'buy', 'buying', 'buying power', 'buying up', 'catalog buying', 'coemption', 'compensation', 'consumer power', 'consumer sovereignty', 'consumerism', 'cornering'],
    'pure': ['attic', 'christian', 'christlike', 'christly', 'ciceronian', 'god-fearing', 'spartan', 'above suspicion', 'absolute', 'abstract', 'academical', 'aesthetic'],
    'puree': ['albumen', 'batter', 'bisque', 'bonnyclabber', 'borscht', 'bouillabaisse', 'bouillon', 'broth', 'burgoo', 'butter', 'chicken soup', 'chowder'],
    'purehearted': ['christlike', 'christly', 'god-fearing', 'angelic', 'blotless', 'chaste', 'clean', 'cleanly', 'godlike', 'godly', 'godly-minded', 'good'],
    'purely': ['a outrance', 'absolutely', 'after a fashion', 'all', 'all in all', 'all out', 'alone', 'altogether', 'appreciably', 'at any rate', 'at best', 'at least'],
    'purgation': ['bm', 'day of atonement', 'yom kippur', 'abreaction', 'absolution', 'abstersion', 'acquittal', 'acquittance', 'acting-out', 'asceticism', 'bloody flux', 'bowdlerization'],
    'purgative': ['abstergent', 'alleviating', 'alleviative', 'analgesic', 'anesthetic', 'anodyne', 'aperient', 'apologetic', 'ascetic', 'assuasive', 'atoning', 'balmy'],
    'purgatorial': ['acherontic', 'lethean', 'plutonian', 'plutonic', 'stygian', 'tartarean', 'apologetic', 'ascetic', 'atoning', 'chthonian', 'chthonic', 'cleansing'],
    'purgatory': ['abaddon', 'day of atonement', 'gehenna', 'hades', 'naraka', 'pandemonium', 'sheol', 'tophet', 'yom kippur', 'asceticism', 'avichi', 'bog'],
    'purge': ['bm', 'abolishment', 'abolition', 'absolve', 'abstergent', 'abstersion', 'abstract', 'account for', 'acquit', 'amnesty', 'annihilate', 'annihilation'],
    'purged': ['banned', 'barred', 'bowdlerized', 'cleaned', 'cleaned up', 'cleansed', 'debarred', 'deported', 'ejected', 'excluded', 'exiled', 'expelled'],
    'purging': ['absolution', 'abstergent', 'abstersion', 'acquittal', 'acquittance', 'assassination', 'bloody murder', 'bowdlerization', 'bumping-off', 'catharsis', 'cathartic', 'cleaning'],
    'purification': ['ablation', 'abrasion', 'absolution', 'abstersion', 'abstraction', 'atonement', 'beatification', 'beatitude', 'blessedness', 'blessing', 'bolting', 'bowdlerization'],
    'purified': ['absolute', 'bare', 'bowdlerized', 'clarified', 'cleaned', 'cleaned up', 'cleansed', 'clear', 'distilled', 'expurgated', 'naked', 'neat'],
    'purifier': ['abstergent', 'cathartic', 'clarifier', 'cleaner', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing cream', 'colander', 'cold cream', 'cradle', 'cream'],
    'purify': ['abate', 'abrade', 'absolve', 'abstract', 'acquit', 'atone', 'bate', 'beatify', 'bleach', 'bless', 'bolt', 'bowdlerize'],
    'purifying': ['abstergent', 'apologetic', 'ascetic', 'atoning', 'cathartic', 'cleaning', 'cleansing', 'compensational', 'compensatory', 'depurative', 'detergent', 'diuretic'],
    'purist': ['pharisee', 'ass', 'bigot', 'bitter-ender', 'bluestocking', 'bullethead', 'classicist', 'conservative', 'die-hard', 'diehard', 'dogmatist', 'donkey'],
    'puristic': ['sabbatarian', 'bigoted', 'censorious', 'choicy', 'choosy', 'conscientious', 'creedbound', 'critical', 'discriminating', 'discriminative', 'dogmatic', 'dour'],
    'puritan': ['albigensian', 'catharist', 'franciscan', 'grundy', 'sabbatarian', 'trappist', 'victorian', 'waldensian', 'abstainer', 'anchorite', 'ascetic', 'austere'],
    'puritanical': ['albigensian', 'catharist', 'franciscan', 'quakerish', 'sabbatarian', 'trappist', 'victorian', 'waldensian', 'abstinent', 'anchoritic', 'ascetic', 'austere'],
    'purity': ['attic simplicity', 'atticism', 'christianity', 'christlikeness', 'christliness', 'munsell chroma', 'absoluteness', 'angelicalness', 'appropriateness', 'asepsis', 'assured probity', 'beauty of holiness'],
    'purl': ['adjoin', 'babble', 'befringe', 'bind', 'border', 'bound', 'bubble', 'burble', 'eddy', 'edge', 'enframe', 'frame'],
    'purlieu': ['agora', 'amphitheater', 'arena', 'athletic field', 'auditorium', 'background', 'baths', 'bear garden', 'boundary', 'bounds', 'bowl', 'boxing ring'],
    'purlieus': ['airspace', 'alentours', 'ambience', 'ambit', 'approach', 'approximation', 'area', 'belt', 'borderlands', 'circle', 'circuit', 'circumambiencies'],
    'purloin': ['abstract', 'and', 'annex', 'appropriate', 'bag', 'boost', 'borrow', 'cabbage', 'cop', 'crib', 'defraud', 'embezzle'],
    'purple': ['mars violet', 'tyrian purple', 'adorned', 'amethyst', 'amethystine', 'befrilled', 'blue', 'bombastic', 'broad', 'cap of dignity', 'cap of maintenance', 'clematis'],
    'purple passage': ['adornment', 'asiaticism', 'beauties', 'colors', 'colors of rhetoric', 'device', 'elegant variation', 'embellishment', 'embroidery', 'euphuism', 'figurative language', 'figurativeness'],
    'purport': ['academic', 'acceptation', 'affective meaning', 'aim', 'aim at', 'allege', 'aspire after', 'aspire to', 'avow', 'be after', 'bearing', 'burden'],
    'purpose': ['advantage', 'aim', 'aim at', 'ambition', 'animus', 'aspiration', 'aspire', 'aspire after', 'aspire to', 'avail', 'be after', 'benefit'],
    'purposeful': ['advised', 'affirmed', 'aimed', 'aimed at', 'bound', 'bound and determined', 'calculated', 'certain', 'committed', 'confirmed', 'conscious', 'considered'],
    'purposeless': ['aimless', 'bootless', 'casual', 'causeless', 'designless', 'desultory', 'discursive', 'disorganized', 'driftless', 'dysteleological', 'empty', 'feckless'],
    'purposely': ['advisedly', 'by design', 'calculatedly', 'consciously', 'contemplatedly', 'deliberately', 'designedly', 'explicitly', 'expressly', 'in cold blood', 'intentionally', 'knowingly'],
    'purr': ['be in heaven', 'be pleased', 'beam', 'birr', 'bombilate', 'bombinate', 'boom', 'bum', 'burr', 'buzz', 'delight', 'die with delight'],
    'purring': ['beaming', 'beatific', 'beatified', 'birring', 'blessed', 'blissful', 'bombilation', 'bombinating', 'bombination', 'booming', 'burring', 'buzzing'],
    'purse': ['swiss bank account', 'abbreviate', 'and pence', 'assets', 'award', 'bag', 'balance', 'bank account', 'billfold', 'bottom dollar', 'bucks', 'budget'],
    'pursed': ['clamped', 'cockled', 'cockly', 'compressed', 'concentrated', 'condensed', 'consolidated', 'constricted', 'contracted', 'corrugate', 'corrugated', 'cramped'],
    'purser': ['accountant', 'auditor', 'bakehead', 'black gang', 'boilerman', 'bookkeeper', 'bungs', 'bursar', 'cabin boy', 'cashier', 'cashkeeper', 'chamberlain'],
    'pursuance': ['chase', 'chasing', 'continualness', 'continuance', 'continuation', 'continuity', 'dogging', 'endurance', 'extension', 'follow', 'follow-up', 'following'],
    'pursue': ['address', 'adhere to', 'angle for', 'ask for', 'aspire to', 'badger', 'bait', 'be into', 'be strong in', 'beat about for', 'beau', 'bedog'],
    'pursuer': ['addict', 'adherent', 'admirer', 'adorer', 'amorist', 'appendage', 'attendant', 'buff', 'bug', 'cavaliere servente', 'chaser', 'collector'],
    'pursuit': ['accomplishment', 'activity', 'aim', 'area', 'art', 'avocation', 'bag', 'business', 'butt', 'by-end', 'by-purpose', 'calling'],
    'purulence': ['chyle', 'colostrum', 'discharge', 'festering', 'gleet', 'humor', 'ichor', 'lachryma', 'lactation', 'leukorrhea', 'lymph', 'matter'],
    'purulent': ['bloody', 'chylifactive', 'chylifactory', 'chylific', 'festering', 'humoral', 'ichorous', 'lachrymal', 'lacrimatory', 'mattering', 'phlegmy', 'pussy'],
    'purveyor': ['caterer', 'chandler', 'commissariat', 'commissary', 'donor', 'furnisher', 'manciple', 'merchant', 'patron', 'provider', 'provisioner', 'quartermaster'],
    'purview': ['agency', 'agentship', 'ambit', 'assignment', 'authority', 'authorization', 'brevet', 'care', 'charge', 'clear sight', 'color vision', 'commission'],
    'pus': ['carrion', 'chyle', 'colostrum', 'corruption', 'dandruff', 'decay', 'discharge', 'excrement', 'festering', 'filth', 'foul matter', 'furfur'],
    'push': ['accelerate', 'actuate', 'advance', 'advance against', 'advance upon', 'adventuresomeness', 'adventurousness', 'advertise', 'advocate', 'aggrandize', 'aggravated assault', 'aggression'],
    'push aside': ['abandon', 'abjure', 'adjourn', 'brush aside', 'brush off', 'chuck', 'chuck out', 'contemn', 'continue', 'contradict', 'decline', 'defer'],
    'push back': ['beat back', 'beat off', 'block', 'brush off', 'chase', 'chase away', 'chase off', 'check', 'counter', 'cut', 'dismiss', 'drive away'],
    'push down': ['bank', 'bear down', 'bring low', 'couch', 'crab', 'debase', 'depress', 'detrude', 'dip', 'downbear', 'feather', 'fishtail'],
    'push forward': ['advance', 'advantage', 'boost', 'conduce to', 'contribute to', 'crowd', 'drive on', 'encourage', 'expedite', 'facilitate', 'favor', 'forge ahead'],
    'push in': ['admit', 'barge in', 'be admitted', 'break in', 'break in upon', 'breeze in', 'burst in', 'bust in', 'butt in', 'charge in', 'come barging in', 'come between'],
    'push on': ['accelerate', 'bundle', 'bustle', 'chase', 'crowd', 'dash', 'dash off', 'dash on', 'dispatch', 'double-time', 'drive on', 'expedite'],
    'pusher': ['mafioso', 'black marketeer', 'bootlegger', 'dealer', 'double-prop', 'drug pusher', 'gray marketeer', 'moonshiner', 'multi-prop', 'piston plane', 'propeller plane', 'propjet'],
    'pushful': ['assertive', 'assured', 'brash', 'confident', 'forward', 'imposing', 'intrusive', 'militant', 'obtrusive', 'officious', 'overweening', 'presuming'],
    'pushing': ['adventuresome', 'adventurous', 'aggressive', 'ambitious', 'assertive', 'brash', 'busy', 'busybody', 'driving', 'dynamic', 'enterprising', 'forceful'],
    'pushover': ['cadmean victory', 'ko', 'milquetoast', 'pyrrhic victory', 'ascendancy', 'babe', 'baby', 'big baby', 'boob', 'breeze', 'championship', 'chicken'],
    'pushy': ['adventuresome', 'adventurous', 'aggressive', 'ambitious', 'arrogant', 'assertive', 'audacious', 'bold', 'brash', 'brassy', 'brazen', 'bumptious'],
    'puss': ['cheshire cat', 'chinchilla cat', 'maltese cat', 'alley cat', 'blue cat', 'bud', 'calico cat', 'cat', 'chick', 'chickabiddy', 'child', 'countenance'],
    'pussycat': ['cheshire cat', 'chinchilla cat', 'maltese cat', 'miss america', 'alley cat', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'beauty queen', 'belle'],
    'pussyfoot': ['about the bush', 'around the bush', 'be careful', 'be cautious', 'beat about', 'beat around', 'beg the question', 'bicker', 'boggle', 'cavil', 'choplogic', 'couch'],
    'pussyfooting': ['washingtonese', 'all fours', 'bickering', 'boggling', 'bunkum', 'captious', 'captiousness', 'caviling', 'chicane', 'chicanery', 'choplogic', 'crawl'],
    'pustule': ['abscess', 'aposteme', 'bed sore', 'birthmark', 'blackhead', 'blain', 'bleb', 'blemish', 'blister', 'boil', 'bubo', 'bulla'],
    'put': ['boeotian', 'affirm', 'air', 'allege', 'announce', 'annunciate', 'apply', 'approximate', 'argue', 'ascribe', 'assert', 'assess'],
    'put about': ['about ship', 'back and fill', 'bear away', 'bear off', 'bear to starboard', 'beat', 'beat about', 'box off', 'break', 'bring about', 'bring round', 'cant'],
    'put across': ['accomplish', 'achieve', 'bring about', 'bring off', 'bring through', 'bring to effect', 'bring to pass', 'carry into execution', 'carry off', 'carry out', 'carry through', 'clarify'],
    'put aside': ['abandon', 'adjourn', 'bolt', 'brush aside', 'brush off', 'carry away', 'carry off', 'cart away', 'conserve', 'continue', 'cordon', 'cordon off'],
    'put away': ['accomplish', 'achieve', 'annihilate', 'assassinate', 'attain', 'bank', 'bereave of life', 'bosom', 'bottle up', 'bump off', 'bundle away', 'bury'],
    'put back': ['about ship', 'aggravate', 'back and fill', 'bear away', 'bear off', 'bear to starboard', 'beat', 'beat about', 'beat back', 'beat off', 'block', 'box off'],
    'put down': ['parthian shot', 'abase', 'abasement', 'abash', 'account for', 'accredit with', 'accrete to', 'acknowledge', 'affront', 'annihilate', 'ante', 'ante up'],
    'put forth': ['advance', 'advertise', 'air', 'articulate', 'be off', 'blazon forth', 'brandish', 'breathe', 'bring before', 'bring forward', 'bring out', 'bring up'],
    'put in': ['admit', 'alight', 'anoint', 'approach anchorage', 'barge in', 'base', 'be admitted', 'bear down on', 'bear down upon', 'bear up for', 'bear up to', 'bed'],
    'put it to': ['advance', 'affront', 'brave', 'breast', 'bring before', 'bring forward', 'bring up', 'broach', 'challenge', 'commend to attention', 'confront', 'confront with'],
    'put off': ['about the bush', 'adjourn', 'appall', 'bear off', 'beat around', 'beg the question', 'blind', 'blunt', 'cast off', 'chill', 'cloak', 'color'],
    'put on': ['parthian shot', 'accelerate', 'act', 'act a part', 'administer', 'affect', 'affectation', 'affected', 'affectedness', 'airs', 'airs and graces', 'apocryphal'],
    'put out': ['abash', 'abashed', 'abroad', 'addle', 'addle the wits', 'adrift', 'afflicted', 'aggravate', 'aggravated', 'agitated', 'ail', 'air'],
    'put over': ['accomplish', 'achieve', 'bring about', 'bring off', 'bring through', 'bring to effect', 'bring to pass', 'carry into execution', 'carry off', 'carry out', 'carry through', 'clarify'],
    'put right': ['amend', 'compensate', 'conduct to', 'correct', 'direct to', 'emend', 'give satisfaction', 'lead to', 'make all square', 'make good', 'make right', 'pay reparations'],
    'put something over': ['bamboozle', 'beguile', 'betray', 'bluff', 'cajole', 'cheat on', 'circumvent', 'conjure', 'deceive', 'delude', 'diddle', 'double-cross'],
    'put straight': ['amend', 'awaken', 'break the spell', 'burst the bubble', 'compensate', 'correct', 'debunk', 'disabuse', 'disappoint', 'disenchant', 'disentangle', 'disillude'],
    'put through': ['abide by', 'accomplish', 'achieve', 'adhere to', 'administer', 'bring about', 'bring off', 'bring through', 'bring to effect', 'bring to pass', 'canalize', 'carry into effect'],
    'put to rights': ['amend', 'arrange', 'compensate', 'correct', 'emend', 'give satisfaction', 'make all square', 'make good', 'make right', 'order', 'pay reparations', 'put in order'],
    'put together': ['accouple', 'accumulate', 'add', 'agglomerate', 'agglutinate', 'aggregate', 'aggroup', 'amalgamate', 'amass', 'articulate', 'assemble', 'assimilate'],
    'put up': ['accommodate', 'accumulate', 'add to', 'aggrandize', 'amass', 'amplify', 'ante', 'ante up', 'as earnest', 'assemble', 'at stake', 'augment'],
    'put up job': ['cheat', 'clinquant', 'counterfeit', 'dummy', 'fake', 'fakement', 'false witness', 'forgery', 'frame', 'frame-up', 'fraud', 'hoax'],
    'put up to': ['agitate', 'arouse', 'blow the coals', 'excite', 'fan', 'fan the flame', 'feed the fire', 'ferment', 'fire', 'foment', 'heat', 'heat up'],
    'put up with': ['abide', 'abide with', 'accede', 'accept', 'acquiesce', 'assent', 'be agreeable', 'bear', 'bear with', 'bide', 'blink at', 'brave'],
    'put upon': ['abashed', 'administer', 'afflicted', 'agitated', 'apply', 'barge in', 'beset', 'bestow', 'bothered', 'break in', 'break in upon', 'burden with'],
    'putative': ['accountable', 'accounted as', 'alleged', 'ascribable', 'assignable', 'assumed', 'assumptive', 'attributable', 'attributed', 'charged', 'conjectural', 'conjectured'],
    'putrefaction': ['caries', 'carrion', 'decay', 'decomposition', 'dry rot', 'foulness', 'gangrene', 'mortification', 'necrosis', 'putrescence', 'putridity', 'putridness'],
    'putrefied': ['bad', 'cankered', 'carious', 'corrupt', 'decayed', 'decomposed', 'festering', 'foul', 'gangrened', 'gangrenous', 'gone bad', 'mortified'],
    'putrefy': ['break down', 'break up', 'canker', 'corrupt', 'crumble', 'crumble into dust', 'decay', 'decompose', 'deteriorate', 'disintegrate', 'fall into decay', 'fall to pieces'],
    'putrid': ['bad', 'bad-smelling', 'barfy', 'bum', 'cankered', 'carious', 'cheesy', 'corrupt', 'crappy', 'creepy', 'crummy', 'decayed'],
    'putter': ['beguile the time', 'burn daylight', 'consume time', 'coquet', 'dabble', 'dally', 'diddle', 'doodle', 'fiddle', 'fiddle with', 'fiddle-faddle', 'fidget with'],
    'putterer': ['sunday painter', 'amateur', 'clock watcher', 'coquet', 'dabbler', 'dallier', 'dawdle', 'dawdler', 'diddler', 'dilettante', 'dillydallier', 'do-nothing'],
    'puttering': ['coquetry', 'dabbling', 'dalliance', 'dallying', 'fiddling', 'flirtation', 'fooling', 'fooling around', 'idling', 'jerking off', 'kidding around', 'loitering'],
    'puzzle': ['chinese puzzle', 'gordian knot', 'addle', 'ail', 'amaze', 'apply the mind', 'baffle', 'bafflement', 'baffling problem', 'bamboozle', 'be the matter', 'beat'],
    'puzzle over': ['agonize over', 'apply the mind', 'be at sea', 'be uncertain', 'beat about', 'doubt', 'feel unsure', 'flounder', 'grope', 'hammer at', 'hammer away at', 'puzzle'],
    'puzzled': ['addled', 'agape', 'aghast', 'agog', 'all agog', 'amazed', 'annoyed', 'anxious', 'astonished', 'astounded', 'at a loss', 'at gaze'],
    'puzzler': ['chinese puzzle', 'baffling problem', 'brain twister', 'crossword puzzle', 'crux', 'enigma', 'enigmatic question', 'floorer', 'jigsaw puzzle', 'knot', 'knotty point', 'mind-boggler'],
    'puzzling': ['able', 'abstruse', 'ambiguous', 'baffling', 'beguiling', 'bewildering', 'bothering', 'confounding', 'confusing', 'contradictory', 'cryptic', 'discomposing'],
    'pygmy': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'lilliputian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito'],
    'pylon': ['french door', 'antenna tower', 'archway', 'back door', 'barbican', 'barway', 'beacon', 'beam', 'belfry', 'bell tower', 'bulkhead', 'campanile'],
    'pyloric': ['abdominal', 'anal', 'appendical', 'cardiac', 'cecal', 'colic', 'colonic', 'coronary', 'duodenal', 'enteric', 'gastric', 'ileac'],
    'pyorrhea': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis'],
    'pyramid': ['add to', 'aggrandize', 'amplify', 'animal kingdom', 'antenna tower', 'anthill', 'arch', 'architecture', 'augment', 'bank', 'bank up', 'barbican'],
    'pyre': ['backfire', 'balefire', 'beacon', 'beacon fire', 'blaze', 'bonfire', 'burning', 'burning ghat', 'campfire', 'cheerful fire', 'combustion', 'conflagration'],
    'pyrotechnics': ['calorimetry', 'debating', 'declamation', 'demagogism', 'elocution', 'eloquence', 'firework', 'fireworks', 'forensics', 'homiletics', 'lecturing', 'oratory'],
    'pyrrhic': ['alexandrine', 'accent', 'accentuation', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antispast', 'antispastic', 'arsis', 'bacchius', 'beat'],
    'pyrrhic victory': ['cadmean victory', 'ko', 'ascendancy', 'championship', 'conquest', 'easy victory', 'grand slam', 'knockout', 'landslide', 'landslide victory', 'mastery', 'moral victory'],
    'quack': ['blagueur', 'bluff', 'bluffer', 'cackle', 'call', 'carol', 'caw', 'charlatan', 'charlatanic', 'charlatanish', 'chatter', 'cheep'],
    'quadrangle': ['little joe', 'arena', 'biquadrate', 'block', 'cincture', 'clos', 'close', 'confine', 'container', 'coop', 'court', 'courtyard'],
    'quadrant': ['adjunct', 'astrolabe', 'azimuth circle', 'azimuth compass', 'bevel', 'bevel protractor', 'bevel square', 'clinometer', 'component', 'contingent', 'crescent', 'cross section'],
    'quadrat': ['acres', 'chattels real', 'demesne', 'domain', 'em', 'em quad', 'en', 'en quad', 'five-em space', 'four-em space', 'grounds', 'hair space'],
    'quadrate': ['accommodate', 'accord', 'adjust', 'check', 'comport', 'conform', 'correspond', 'cube', 'cube-shaped', 'cubed', 'cubic', 'cubiform'],
    'quadrilateral': ['bifacial', 'bilateral', 'biquadratic', 'cube-shaped', 'cubed', 'cubic', 'cubiform', 'cuboid', 'diced', 'dihedral', 'flanked', 'four'],
    'quadrillion': ['a billion', 'a crore', 'a lakh', 'a million', 'a myriad', 'a nonillion', 'a quadrillion', 'a thousand', 'a zillion', 'decillion', 'duodecillion', 'googol'],
    'quadroon': ['cape colored', 'eurasian', 'cattalo', 'citrange', 'cross', 'crossbreed', 'griffe', 'half blood', 'half-bred', 'half-breed', 'half-caste', 'high yellow'],
    'quadruped': ['amphibian', 'aquatic', 'biped', 'biquadratic', 'canine', 'cannibal', 'carnivore', 'cosmopolite', 'feline', 'four', 'four-legged', 'four-rayed'],
    'quadruplicate': ['photostat', 'xerox', 'biquadrate', 'biquadratic', 'clone', 'copy', 'counterpart', 'ditto', 'double', 'dupe', 'duplicate', 'duplication'],
    'quaff': ['beverage', 'bib', 'booze', 'bumper', 'draft', 'drain the cup', 'dram', 'drench', 'drink', 'drink bottoms-up', 'drink deep', 'drink hard'],
    'quagmire': ['baygall', 'bind', 'bog', 'bottom', 'bottomland', 'bottoms', 'box', 'buffalo wallow', 'cesspool', 'cloaca', 'cloaca maxima', 'clutch'],
    'quail': ['cornish hen', 'avoid', 'blanch', 'blench', 'blink', 'boggle', 'broiler', 'caille', 'canard', 'caneton', 'capon', 'chapon'],
    'quaint': ['absurd', 'acquaint', 'amusing', 'antiquated', 'antique', 'archaic', 'bizarre', 'curious', 'droll', 'eccentric', 'fanciful', 'fantastic'],
    'quake': ['apoplexy', 'be cold', 'bob', 'bobble', 'bounce', 'breakup', 'bump', 'cataclysm', 'chatter', 'chill', 'climax', 'convulsion'],
    'quaking': ['agitation', 'ague', 'aquiver', 'aspen', 'bumpiness', 'chattering', 'chills of fear', 'chorea', 'cold creeps', 'cold shivers', 'cold sweat', 'creeps'],
    'qualification': ['ability', 'ableness', 'about-face', 'acceptability', 'accommodation', 'adaptation', 'adequacy', 'adjustment', 'admissibility', 'allowance', 'alteration', 'amelioration'],
    'qualified': ['a propos', 'able', 'acceptable', 'accomplished', 'ad rem', 'adapted', 'adept', 'adjusted', 'admissible', 'altered', 'applicable', 'apposite'],
    'qualifier': ['ic analysis', 'appositive', 'attribute', 'attributive', 'complement', 'construction modifier', 'cutting', 'deep structure', 'direct object', 'filler', 'form-function unit', 'function'],
    'qualify': ['abate', 'accommodate', 'adapt', 'adjust', 'adjust to', 'alter', 'ameliorate', 'answer', 'ascribe', 'assign', 'assuage', 'attribute'],
    'qualifying': ['altering', 'assuasive', 'bounding', 'extenuating', 'extenuatory', 'lenitive', 'limitative', 'limiting', 'mitigating', 'mitigative', 'mitigatory', 'modificatory'],
    'quality': ['al', 'grade a', 'acquired taste', 'advantageousness', 'affection', 'affirmation', 'agreeableness', 'air', 'ancestry', 'appreciation of excellence', 'arete', 'aristocracy'],
    'quality control': ['bit-weight control', 'color control', 'density control', 'dimension control', 'diverse control', 'end-point control', 'examination', 'flavor control', 'flow control', 'fragrance control', 'hold control', 'humidity control'],
    'qualm': ['agitation', 'airsickness', 'all-overs', 'anxiety', 'apprehension', 'apprehensiveness', 'bashfulness', 'beef', 'better self', 'bitch', 'boggle', 'boggling'],
    'qualmish': ['airsick', 'all-overish', 'anxious', 'apprehensive', 'barfy', 'bashful', 'boggling', 'carsick', 'demurring', 'diffident', 'faltering', 'hesitant'],
    'quandary': ['gordian knot', 'baffle', 'bafflement', 'bewilderment', 'bother', 'confoundment', 'confusion', 'crux', 'difficulty', 'dilemma', 'discomposure', 'disconcert'],
    'quantification': ['accounting', 'appraisal', 'appraisement', 'approximation', 'assessment', 'assize', 'assizement', 'calculation', 'census', 'computation', 'correction', 'counting'],
    'quantified': ['admeasured', 'an', 'any', 'appraised', 'assessed', 'certain', 'gauged', 'known by measurement', 'mapped', 'measured', 'metered', 'one'],
    'quantify': ['apportion', 'appraise', 'appreciate', 'assay', 'assess', 'calculate', 'calibrate', 'caliper', 'call off', 'call over', 'call the roll', 'census'],
    'quantitative': ['an', 'any', 'approximative', 'certain', 'chorographic', 'estimative', 'hypsographic', 'measured', 'measuring', 'mensural', 'mensurational', 'mensurative'],
    'quantity': ['alexandrine', 'a mass of', 'a world of', 'abundance', 'accent', 'accentuation', 'accommodation', 'account', 'acres', 'affluence', 'aggregate', 'amount'],
    'quantum': ['asa scale', 'british candle', 'hefner candle', 'scheiner scale', 'aggregate', 'allotment', 'allowance', 'amount', 'amplitude', 'apportionment', 'atomerg', 'big end'],
    'quantum mechanics': ['aeromechanics', 'animal mechanics', 'atomic science', 'atomics', 'atomistics', 'atomology', 'biomechanics', 'celestial mechanics', 'electromechanics', 'fluid mechanics', 'frequency curve', 'frequency distribution'],
    'quarantine': ['jim crow', 'alien', 'apartheid', 'apartness', 'beleaguer', 'beleaguerment', 'beset', 'besetment', 'besiege', 'blockade', 'blockading', 'bolt'],
    'quarantined': ['apart', 'barred', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'cabined', 'caged', 'cloistered', 'closed-in', 'confined'],
    'quarrel': ['kilkenny cats', 'action', 'aerial combat', 'affray', 'altercate', 'altercation', 'argue', 'argument', 'armored combat', 'arrow', 'arrowhead', 'barb'],
    'quarreler': ['battler', 'belligerent', 'belted knight', 'bickerer', 'bitter-ender', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'combatant', 'competitor'],
    'quarrelsome': ['acrid', 'adverse', 'aggressive', 'antagonistic', 'antipathetic', 'argumental', 'argumentative', 'battling', 'bellicose', 'belligerent', 'bickering', 'bitter'],
    'quarry': ['abysm', 'abyss', 'aim', 'avulse', 'bank', 'beasts of venery', 'big game', 'bonanza', 'bore', 'burrow', 'butt', 'by-end'],
    'quart': ['barrel', 'bushel', 'cord', 'cubic foot', 'cubic meter', 'cup', 'decaliter', 'decastere', 'deciliter', 'dkl', 'drop', 'dry pint'],
    'quarter': ['c-note', 'g-note', 'abode', 'abundant year', 'academic year', 'accommodate', 'accommodations', 'achievement', 'adjunct', 'aim', 'airspace', 'alerion'],
    'quarter note': ['accidental', 'breve', 'crotchet', 'demisemiquaver', 'dominant', 'dominant note', 'double whole note', 'eighth note', 'enharmonic', 'enharmonic note', 'flat', 'half note'],
    'quarterback': ['amateur athlete', 'archer', 'athlete', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'be responsible for', 'blocking back', 'boss', 'bowman'],
    'quartered': ['billeted', 'cleft', 'cloven', 'cracked', 'cut', 'domiciled', 'domiciliated', 'housed', 'in pieces', 'in shreds', 'lacerate', 'lacerated'],
    'quartering': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'assembly-line housing', 'azure', 'bandeau', 'bar'],
    'quarterly': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'daybook', 'decennial', 'diary'],
    'quartermaster': ['od', 'boatswain', 'captain', 'caterer', 'chandler', 'chief engineer', 'chief mate', 'commander', 'commissariat', 'commissary', 'deck officer', 'donor'],
    'quartet': ['german band', 'little joe', 'philharmonic', 'band', 'big band', 'bipartisanship', 'biquadrate', 'brass', 'brass band', 'brass choir', 'brass quintet', 'brass section'],
    'quarto': ['crown', 'duodecimo', 'eighteenmo', 'farthing', 'folio', 'fourth', 'fourth part', 'imperial', 'medium', 'octavo', 'octodecimo', 'one-fourth'],
    'quasar': ['beehive', 'cepheid variable', 'hertzsprung-russell diagram', 'hyades', 'messier catalog', 'ngc', 'pleiades', 'seven sisters', 'absolute magnitude', 'binary star', 'black hole', 'double star'],
    'quash': ['abate', 'abrogate', 'annihilate', 'annul', 'asphyxiate', 'black out', 'bottle up', 'cancel', 'censor', 'choke', 'choke off', 'clamp down on'],
    'quasi': ['affected', 'apishly', 'apocryphal', 'approximate', 'approximating', 'approximative', 'artificial', 'as it were', 'assumably', 'assumed', 'assumedly', 'assumptively'],
    'quaternary': ['little joe', 'biquadrate', 'biquadratic', 'four', 'four-legged', 'four-part diaphony', 'four-rayed', 'foursome', 'foursquare', 'quad', 'quadrangle', 'quadrature'],
    'quatrain': ['spenserian stanza', 'antistrophe', 'book', 'burden', 'canto', 'chorus', 'couplet', 'distich', 'envoi', 'epode', 'heptastich', 'hexastich'],
    'quaver': ['bebung', 'accidental', 'anthem', 'aphonia', 'artificial voice', 'ballad', 'bob', 'bobble', 'bounce', 'break', 'breve', 'broken speech'],
    'quavering': ['ague', 'aspen', 'blurred', 'breathy', 'bumpiness', 'chattering', 'choked', 'choking', 'chorea', 'cold shivers', 'croaking', 'didder'],
    'quay': ['anchorage', 'anchorage ground', 'basin', 'berth', 'breakwater', 'bulkhead', 'dock', 'dockage', 'dockyard', 'dry dock', 'embankment', 'groin'],
    'queasy': ['airsick', 'apprehensive', 'barfy', 'bilious', 'carsick', 'difficult', 'discomfited', 'doubtable', 'doubtful', 'dubious', 'finical', 'finicking'],
    'queen': ['kaiserin', 'ace', 'ant', 'army ant', 'auntie', 'beauty queen', 'bee', 'begum', 'best bower', 'bi-guy', 'bisexual', 'bishop'],
    'queenly': ['aristocratic', 'august', 'chivalrous', 'courtly', 'dignified', 'ducal', 'dynastic', 'exalted', 'genteel', 'gentle', 'gentlemanlike', 'gentlemanly'],
    'queenship': ['baronetcy', 'barony', 'caliphate', 'czardom', 'dukedom', 'earldom', 'emperorship', 'empery', 'empire', 'imperialism', 'kaiserdom', 'kaisership'],
    'queer': ['ac-dc', 'abnormal', 'absurd', 'affected', 'amphierotic', 'anomalous', 'apocryphal', 'artificial', 'assumed', 'atypical', 'auntie', 'autoerotic'],
    'queer duck': ['alien', 'case', 'character', 'crackpot', 'crank', 'eccentric', 'fanatic', 'hermit', 'hobo', 'kook', 'lone wolf', 'loner'],
    'quell': ['allay', 'alleviate', 'annihilate', 'appease', 'asphyxiate', 'assuage', 'beat down', 'bend', 'bottle up', 'break', 'break down', 'bring low'],
    'quelled': ['broken', 'brought low', 'chastened', 'conquered', 'constrained', 'controlled', 'crushed', 'domesticated', 'felled', 'flattened', 'housebroke', 'housebroken'],
    'quench': ['allay', 'appease', 'asphyxiate', 'assuage', 'blow out', 'blunt', 'bottle up', 'censor', 'chill', 'choke', 'choke off', 'clamp down on'],
    'querulous': ['jeremianic', 'annoyed', 'bad-tempered', 'beefing', 'bellyaching', 'bemoaning', 'bitching', 'blubbering', 'cantankerous', 'carping', 'catty', 'censorious'],
    'query': ['ask', 'ask a question', 'ask about', 'ask questions', 'awake a doubt', 'be curious', 'be diffident', 'be doubtful', 'be dubious', 'be skeptical', 'be uncertain', 'bone of contention'],
    'quest': ['adventure', 'angle for', 'ask for', 'bay', 'beat about for', 'cast about', 'chase', 'chivy', 'crusade', 'delve for', 'delving', 'dig for'],
    'question': ['chinese puzzle', 'parthian shot', 'pyrrhonism', 'absurd', 'address', 'affirmation', 'agonize over', 'allegation', 'answer', 'apostrophe', 'apprehension', 'approach'],
    'question mark': ['chinese puzzle', 'baffling problem', 'bone of contention', 'brain twister', 'catechism', 'cross-interrogatory', 'cross-question', 'crossword puzzle', 'crux', 'debating point', 'demand', 'enigma'],
    'questionable': ['a bit thick', 'a bit thin', 'absurd', 'ambiguous', 'amoral', 'arguable', 'at issue', 'beguiling', 'beyond belief', 'borderline', 'catchy', 'confutable'],
    'questioner': ['paul pry', 'peeping tom', 'asker', 'busybody', 'catechist', 'cross-interrogator', 'cross-questioner', 'detective', 'eavesdropper', 'examiner', 'gossip', 'inquirer'],
    'questioning': ['pyrrhonic', 'socratic method', 'agnostic', 'answering', 'asking', 'bringing into question', 'catechetical method', 'catechistic', 'catechization', 'catechizing', 'challenge', 'communicating'],
    'questionnaire': ['agenda', 'beadroll', 'cadastre', 'calendar', 'canvass', 'census', 'census report', 'checklist', 'checkroll', 'conduct a poll', 'consumer research', 'consumer-preference survey'],
    'queue': ['indian file', 'afterpart', 'afterpiece', 'array', 'articulation', 'bank', 'braid', 'brush', 'bun', 'buzz', 'catena', 'catenation'],
    'quibble': ['adverse criticism', 'animadversion', 'argue', 'argufy', 'around the bush', 'aspersion', 'bad notices', 'bad press', 'bandy words', 'beat about', 'beg the question', 'bicker'],
    'quibbler': ['belittler', 'captious critic', 'carper', 'caviler', 'censor', 'censurer', 'common scold', 'critic', 'criticizer', 'equivocator', 'faultfinder', 'frondeur'],
    'quibbling': ['adverse criticism', 'animadversion', 'aspersion', 'bad notices', 'bad press', 'bickering', 'boggling', 'captious', 'captiousness', 'carping', 'cavil', 'caviling'],
    'quiche': ['danish pastry', 'french pastry', 'baklava', 'blintz', 'chocolate eclair', 'cream puff', 'dowdy', 'eclair', 'pandowdy', 'pastry', 'pasty', 'patisserie'],
    'quick': ['daedalian', 'able', 'aboveground', 'abrupt', 'acquiescent', 'acute', 'adept', 'adroit', 'agile', 'agog', 'agreeable', 'alacritous'],
    'quick witted': ['attic', 'adroit', 'apt', 'biting', 'brainy', 'bright', 'brilliant', 'clever', 'dexterous', 'droll', 'facetious', 'funny'],
    'quick-tempered': ['abrupt', 'bad-tempered', 'choleric', 'churlish', 'excitable', 'hot-blooded', 'hot-tempered', 'ill-tempered', 'impatient', 'impulsive', 'irascible', 'irritable'],
    'quicken': ['accelerate', 'activate', 'actuate', 'advance', 'advantage', 'aid', 'animate', 'arouse', 'awake', 'awaken', 'be begotten', 'be born'],
    'quickening': ['acceleration', 'activating', 'animating', 'animation', 'animative', 'bracing', 'clarification', 'double time', 'double-quick', 'double-quick time', 'drive', 'easing'],
    'quickly': ['pdq', 'agilely', 'amain', 'animatedly', 'anxiously', 'apace', 'at flank speed', 'at once', 'at the double', 'avidly', 'breathlessly', 'briefly'],
    'quickness': ['ability', 'abruptness', 'acuity', 'acuteness', 'address', 'adeptness', 'adroitness', 'agility', 'air speed', 'airmanship', 'alacrity', 'alertness'],
    'quicksand': ['baygall', 'bind', 'bog', 'bottom', 'bottomland', 'bottoms', 'breakers ahead', 'buffalo wallow', 'cardhouse', 'cause for alarm', 'clutch', 'complication'],
    'quicksilver': ['april showers', 'proteus', 'active', 'activist', 'activistic', 'alive', 'animated', 'antelope', 'arrow', 'aureate', 'blue darter', 'blue streak'],
    'quid': ['axiom', 'bawbee', 'bite', 'bolus', 'cavendish', 'center', 'champ', 'chaw', 'chew', 'chewing tobacco', 'chomp', 'core'],
    'quid pro quo': ['agency', 'alternation', 'balance', 'ballast', 'battledore and shuttlecock', 'blow for blow', 'change', 'coaction', 'commutation', 'complementary distribution', 'concurrence', 'consideration'],
    'quiddity': ['axiom', 'cavil', 'center', 'core', 'dodge', 'elixir', 'essence', 'essential', 'flower', 'focus', 'fundamental', 'gist'],
    'quiescence': ['a wise passiveness', 'abidingness', 'awful silence', 'changelessness', 'cold storage', 'constancy', 'contemplation', 'contemplative life', 'dead', 'dead of night', 'deathlike silence', 'do-nothing policy'],
    'quiescent': ['abeyant', 'abiding', 'at a standstill', 'at rest', 'calm', 'changeless', 'cloistered', 'constant', 'contemplative', 'continuing', 'cool', 'do-nothing'],
    'quiet': ['attic', 'buddha-like composure', 'oriental calm', 'abate', 'aesthetic', 'allay', 'appease', 'arrange', 'arrangement', 'array', 'artistic', 'asleep'],
    'quiet spell': ['break', 'coffee break', 'downtime', 'half time', 'half-time intermission', 'holiday', 'interim', 'interlude', 'intermezzo', 'intermission', 'intermittence', 'interregnum'],
    'quietening': ['analgesic', 'anodyne', 'appeasing', 'calmant', 'calmative', 'calming', 'cradling', 'depressant', 'dreamy', 'drowsy', 'gentling', 'hushing'],
    'quietism': ['quakerism', 'a wise passiveness', 'acquiescence', 'amenability', 'ataraxia', 'ataraxy', 'blank mind', 'blankmindedness', 'blankness', 'calm of mind', 'calmness', 'compliance'],
    'quietly': ['aesthetically', 'artistically', 'becomingly', 'calmly', 'composedly', 'coolly', 'decently', 'decorously', 'demurely', 'dispassionately', 'elegantly', 'genteelly'],
    'quietude': ['buddha-like composure', 'oriental calm', 'arrangement', 'array', 'ataraxia', 'ataraxy', 'awful silence', 'brevity', 'briefness', 'brusqueness', 'calm disposition', 'calm of mind'],
    'quietus': ['ko', 'waterloo', 'absolution', 'acquittal', 'acquittance', 'annihilation', 'apodosis', 'bane', 'beating', 'biological death', 'catastrophe', 'ceasing'],
    'quill': ['barb', 'barbule', 'barrel', 'bramble', 'brier', 'bristle', 'burr', 'cactus', 'catchweed', 'cilium', 'cleavers', 'crest'],
    'quilt': ['afghan', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedsheet', 'bedspread', 'blanket', 'buffalo robe', 'case', 'clothes', 'comfort'],
    'quinsy': ['asiatic flu', 'hong kong flu', 'acute bronchitis', 'adenoiditis', 'aluminosis', 'amygdalitis', 'anthracosilicosis', 'anthracosis', 'asbestosis', 'asthma', 'atypical pneumonia', 'bituminosis'],
    'quintessence': ['archetype', 'axiom', 'beau ideal', 'bottom', 'center', 'champion', 'choice', 'chosen', 'classic', 'concentrate', 'concentration', 'core'],
    'quintessential': ['appropriate', 'archetypal', 'archetypical', 'best', 'bottom', 'champion', 'characteristic', 'choice', 'classic', 'classical', 'consummate', 'developed'],
    'quintet': ['pentateuch', 'philharmonic', 'phoebe', 'band', 'big band', 'bipartisanship', 'brass', 'brass band', 'brass choir', 'brass quintet', 'brass section', 'brasses'],
    'quintuplet': ['little phoebe', 'pentateuch', 'phoebe', 'cinque', 'fin', 'five', 'five bucks', 'five dollars', 'fiver', 'fivesome', 'mullet', 'pentachord'],
    'quip': ['parthian shot', 'ad lib', 'aphorism', 'apophthegm', 'apothegm', 'back answer', 'barb', 'be merry with', 'bon mot', 'boutade', 'bright idea', 'bright thought'],
    'quipster': ['banana', 'burlesquer', 'caricaturist', 'clown', 'comedian', 'comic', 'cutup', 'droll', 'epigrammatist', 'funnyman', 'gag writer', 'gagman'],
    'quirk': ['aberration', 'anamorphism', 'anamorphosis', 'aroma', 'asymmetry', 'attribute', 'badge', 'boutade', 'brainstorm', 'brand', 'buckle', 'cachet'],
    'quirky': ['abnormal', 'anomalous', 'arbitrary', 'capricious', 'crank', 'crankish', 'cranky', 'crotchety', 'deviant', 'deviative', 'different', 'divergent'],
    'quisling': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'judas-like', 'trojan-horse', 'apostate', 'archtraitor', 'backslider', 'betrayer', 'betraying', 'bolter'],
    'quit': ['abandon', 'abdicate', 'abjure', 'abort', 'abscond', 'acquit', 'act', 'atone', 'back out', 'be pensioned', 'be superannuated', 'bear'],
    'quitclaim': ['abandon', 'abjure', 'cede', 'deed of release', 'disgorge', 'dispense with', 'dispose of', 'do without', 'drop', 'dump', 'forgo', 'forswear'],
    'quite': ['ok', 'roger', 'a bit', 'a little', 'absolutely', 'actually', 'all', 'all in all', 'all right', 'all told', 'almighty', 'alright'],
    'quits': ['alike', 'at par', 'au pair', 'commensurate', 'drawn', 'equal', 'equalized', 'even', 'even stephen', 'fifty-fifty', 'half-and-half', 'knotted'],
    'quittance': ['absolution', 'acknowledgment', 'acquitment', 'acquittal', 'acquittance', 'amends', 'amortization', 'amortizement', 'atonement', 'binder', 'blood money', 'canceled check'],
    'quiver': ['bebung', 'all-overs', 'bale', 'bang', 'be cold', 'beat', 'beating', 'bicker', 'bindle', 'bob', 'bobble', 'bolt'],
    'quivering': ['aflicker', 'agitated', 'ague', 'all shook up', 'all-overish', 'anxious', 'apprehensive', 'aquiver', 'aspen', 'bickering', 'blinking', 'bumpiness'],
    'quixotic': ['absurd', 'airy', 'autistic', 'chimerical', 'dereistic', 'dreamlike', 'dreamy', 'fanciful', 'fantastic', 'foolhardy', 'idealistic', 'impracticable'],
    'quiz': ['socratic method', 'ask', 'asking', 'audition', 'be curious', 'blue book', 'bringing into question', 'burn with curiosity', 'case', 'catechetical method', 'catechization', 'catechize'],
    'quizzical': ['absurd', 'agape', 'agog', 'all agog', 'amusing', 'bantering', 'bizarre', 'booing', 'burning with curiosity', 'catcalling', 'catechistic', 'chaffing'],
    'quoin': ['intertype', 'linotype', 'monotype', 'angle', 'apex', 'bend', 'bifurcation', 'bight', 'cant', 'chevron', 'coin', 'cold-type typesetting'],
    'quoit': ['anklet', 'armlet', 'ball', 'band', 'belt', 'bracelet', 'cincture', 'cingulum', 'collar', 'collarband', 'discus', 'earring'],
    'quondam': ['ancient', 'bygone', 'early', 'erstwhile', 'fore', 'former', 'immemorial', 'late', 'old', 'olden', 'once', 'onetime'],
    'quorum': ['assemblee', 'assembly', 'assignation', 'at home', 'ball', 'brawl', 'caucus', 'colloquium', 'commission', 'committee', 'conclave', 'concourse'],
    'quota': ['adjunct', 'allocation', 'allotment', 'allowance', 'apportionment', 'arithmetical proportion', 'big end', 'bigger half', 'bit', 'bite', 'budget', 'chunk'],
    'quotation': ['allusion', 'asking price', 'bargain price', 'bearish prices', 'bid', 'bid price', 'book value', 'bullish prices', 'call price', 'case', 'cash price', 'charge'],
    'quote': ['affirm', 'allege', 'assert', 'asseverate', 'aver', 'bring in', 'bring up', 'call to mind', 'call up', 'cite', 'cite a particular', 'come again'],
    'r and d': ['control', 'control experiment', 'controlled experiment', 'cut and try', 'empiricism', 'experiment', 'experimental design', 'experimental method', 'experimental proof', 'experimentalism', 'experimentation', 'hit and miss'],
    'ra': ['amen-ra', 'anubis', 'apollo', 'bast', 'helios', 'horus', 'hyperion', 'isis', 'khem', 'min', 'neph', 'nephthys'],
    'rabbet': ['ankle', 'articulate', 'articulation', 'batten', 'batten down', 'bezel', 'bolt', 'boundary', 'buckle', 'butt', 'button', 'canal'],
    'rabbi': ['levite', 'abecedarian', 'authority', 'baal kore', 'boss', 'bwana', 'cantor', 'certified teacher', 'chef', 'chief', 'chief rabbi', 'church dignitary'],
    'rabbinate': ['sacred college', 'apostleship', 'call', 'care of souls', 'clergy', 'clerical order', 'clericals', 'holy orders', 'ministry', 'pastorage', 'pastoral care', 'pastorate'],
    'rabbinic': ['gemaric', 'mishnaic', 'talmudic', 'abbatial', 'abbatical', 'academic', 'archiepiscopal', 'bookish', 'canonical', 'capitular', 'capitulary', 'churchly'],
    'rabbit': ['belgian hare', 'chiroptera', 'hydra', 'lagomorpha', 'primates', 'rodentia', 'buck', 'bunny', 'cottontail', 'doe', 'hare', 'hotbed'],
    'rabble': ['and bobtail', 'army', 'bourgeoisie', 'canaille', 'cluster', 'cohue', 'common ruck', 'commonalty', 'commoners', 'crowd', 'crush', 'deluge'],
    'rabble rouser': ['agent provocateur', 'agitator', 'agitprop', 'catalyst', 'debater', 'declaimer', 'demagogue', 'exciter', 'firebrand', 'fomenter', 'haranguer', 'incendiary'],
    'rabble rousing': ['agitation', 'agitational', 'agitative', 'arousal', 'debating', 'declamation', 'demagogism', 'elocution', 'eloquence', 'exasperation', 'excitation', 'excitement'],
    'rabelaisian': ['fescennine', 'abusive', 'bawdy', 'blasphemous', 'blue', 'calumniatory', 'calumnious', 'caustic', 'comminatory', 'contumelious', 'cursing', 'cynical'],
    'rabid': ['dionysiac', 'abandoned', 'amok', 'bacchic', 'bellowing', 'berserk', 'bigoted', 'carried away', 'corybantic', 'crazed', 'crazy', 'delirious'],
    'rabies': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'texas fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax'],
    'raccoon': ['cape polecat', 'ape', 'bar', 'bear', 'cavy', 'chimp', 'chimpanzee', 'coon', 'ferret', 'foumart', 'glutton', 'groundhog'],
    'race': ['le mans', 'accelerate', 'adolescent stream', 'affiliation', 'affluence', 'afflux', 'affluxion', 'air race', 'animal kingdom', 'apparentation', 'aqueduct', 'arroyo'],
    'racecourse': ['archery ground', 'athletic field', 'badminton court', 'baseball field', 'basketball court', 'billiard parlor', 'bowling alley', 'bowling green', 'course', 'court', 'cricket ground', 'croquet ground'],
    'racer': ['jehu', 'amateur athlete', 'archer', 'athlete', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'blocking back', 'bowman', 'catcher'],
    'racing': ['affluent', 'automobile racing', 'confluent', 'coursing', 'decurrent', 'defluent', 'diffluent', 'dog racing', 'flowing', 'fluent', 'fluxional', 'fluxive'],
    'racism': ['anglophobia', 'jim crow', 'jim crow law', 'russophobia', 'abhorrence', 'abomination', 'anti-semitism', 'antipathy', 'apartheid', 'aversion', 'bias', 'bigotry'],
    'racist': ['anglophobe', 'russophobe', 'antiblack', 'biased', 'bigot', 'chauvinist', 'chauvinistic', 'colored', 'doctrinaire', 'dogmatic', 'dogmatist', 'fanatic'],
    'rack': ['chateaubriand', 'hydromatic', 'procrustean bed', 'adversity', 'afflict', 'affliction', 'agonize', 'agony', 'ail', 'amble', 'andante', 'anguish'],
    'rack rent': ['big price tag', 'extortionate price', 'famine price', 'fancy price', 'good price', 'high price', 'hot economy', 'inflation', 'inflationary gap', 'inflationary pressure', 'inflationary prices', 'inflationary spiral'],
    'racked': ['affected', 'afflicted', 'agonized', 'clawed', 'convulsed', 'crucified', 'devoured by', 'distressed', 'harrowed', 'hurt', 'hurting', 'imbued with'],
    'racket': ['babel', 'bedlam let loose', 'cosa nostra', 'lastex', 'mafia', 'ado', 'agate', 'agitation', 'art', 'artful dodge', 'artifice', 'babel'],
    'racketeer': ['judas', 'mafioso', 'bad person', 'bandit', 'betrayer', 'black marketeer', 'blackmailer', 'bloodsucker', 'bootlegger', 'brigand', 'convict', 'criminal'],
    'rackets': ['black hand', 'cosa nostra', 'mafia', 'black market', 'bootlegging', 'gambling', 'gangdom', 'gangland', 'gray market', 'illegal commerce', 'illegal operations', 'illegitimate business'],
    'racking': ['acute', 'afflictive', 'agonizing', 'atrocious', 'barbarous', 'biting', 'consuming', 'cramping', 'cruel', 'desolating', 'distressing', 'excruciating'],
    'raconteur': ['anecdotalist', 'anecdotist', 'fableist', 'fabler', 'fabulist', 'fictionist', 'mythmaker', 'mythopoet', 'narrator', 'novelettist', 'novelist', 'reciter'],
    'racy': ['adult', 'animated', 'bawdy', 'blue', 'brisk', 'broad', 'buoyant', 'burning', 'coarse', 'crude', 'curried', 'dirty'],
    'radar': ['aa radar', 'afc', 'afc mixer', 'crt', 'cw oscillator', 'mad radar', 'navaglobe', 'oboe', 'tr switch', 'tr unit', 'var', 'volscan'],
    'radar parts': ['afc', 'afc mixer', 'crt', 'cw oscillator', 'tr switch', 'tr unit', 'altimeter', 'amplifier', 'analyzer', 'cascade screen', 'cathode-ray tube', 'demodulator'],
    'raddle': ['arabesque', 'basketry', 'basketwork', 'braid', 'cancellation', 'cross-hatching', 'crossing-out', 'enlace', 'entwine', 'filigree', 'fret', 'fretwork'],
    'raddled': ['afflicted', 'bent', 'boiled', 'bombed', 'boozy', 'braided', 'canned', 'cockeyed', 'cockeyed drunk', 'crocked', 'crocko', 'elevated'],
    'radial': ['approaching', 'asymptotic', 'centripetal', 'centrolineal', 'concurrent', 'confluent', 'confocal', 'connivent', 'converging', 'focal', 'meeting', 'mutually approaching'],
    'radiance': ['aura', 'blare', 'blaze', 'blaze of glory', 'blazing light', 'blinding light', 'blitheness', 'blithesomeness', 'bright light', 'brightness', 'brilliance', 'brilliancy'],
    'radiant': ['ablaze', 'aerolite', 'aglow', 'alight', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'arbor', 'axis', 'axle'],
    'radiant energy': ['contamination', 'curiage', 'decontamination', 'emanation', 'fallout', 'half-life', 'highlight', 'illumination', 'irradiance', 'irradiancy', 'irradiation', 'light'],
    'radiate': ['be bright', 'beacon', 'beam', 'bedazzle', 'bestrew', 'blaze', 'blind', 'broadcast', 'burn', 'circulate', 'circumfuse', 'coruscate'],
    'radiating': ['approaching', 'asymptotic', 'centripetal', 'centrolineal', 'concurrent', 'confluent', 'confocal', 'connivent', 'converging', 'focal', 'meeting', 'mutually approaching'],
    'radiation': ['x ray', 'actinic ray', 'actinism', 'arc lighting', 'asteroids', 'atomic beam', 'atomic ray', 'attenuation', 'aurora particles', 'beam', 'beam of light', 'black and white'],
    'radiation physics': ['newtonian physics', 'x-ray photometry', 'x-ray spectrometry', 'acoustics', 'aerophysics', 'applied physics', 'astrophysics', 'atom-tagging', 'basic conductor physics', 'biophysics', 'chemical physics', 'cryogenics'],
    'radiation sickness': ['minamata disease', 'altitude sickness', 'anoxemia', 'anoxia', 'anoxic anoxia', 'anthrax', 'black lung', 'caisson disease', 'chilblain', 'decompression sickness', 'frostbite', 'immersion foot'],
    'radiator': ['am transmitter', 'bunsen burner', 'dutch oven', 'fm transmitter', 'rt transmitter', 'alpha radiator', 'amateur transmitter', 'beacon', 'bedpan', 'beta radiator', 'bloom heater', 'brazier'],
    'radical': ['bolshevik', 'bolshevist', 'fabian', 'gospel side', 'ic analysis', 'jacobin', 'kekule formula', 'wobbly', 'ab ovo', 'aboriginal', 'absolute', 'accidence'],
    'radical right': ['bircher', 'bourbon', 'tory', 'conservatist', 'conservative', 'diehard', 'extreme right-winger', 'hard hat', 'imperialist', 'monarchist', 'reactionarist', 'reactionary'],
    'radicalism': ['fabianism', 'jacobinism', 'new left', 'old left', 'abandon', 'anarchism', 'anarcho-syndicalism', 'boundlessness', 'conversion', 'criminal syndicalism', 'egregiousness', 'enormousness'],
    'radically': ['a outrance', 'absolutely', 'all out', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure', 'completely', 'dead', 'downright', 'essentially', 'extremely'],
    'radio': ['am receiver', 'am tuner', 'am-fm receiver', 'am-fm tuner', 'cb', 'rdf', 'teletype', 'wirephoto', 'advice', 'adviser', 'air', 'announce'],
    'radio control': ['automatic electronics', 'autonetics', 'bioinstrumentation', 'bionics', 'circuit analysis', 'communication theory', 'cybernetics', 'information theory', 'push-button control', 'remote control', 'remote handling', 'semiautomatic control'],
    'radio operator': ['arrl', 'amateur radio operator', 'bakehead', 'black gang', 'boilerman', 'bungs', 'cabin boy', 'chips', 'commissary steward', 'complement', 'control engineer', 'deckhand'],
    'radio receiver': ['af amplifier', 'afc', 'rf amplifier', 'amplifier', 'baffle', 'bypass', 'cabinet', 'capacitor', 'chassis', 'coil', 'condenser', 'console'],
    'radio station': ['am station', 'fm station', 'rdf station', 'advance base', 'clear-channel station', 'direction-finder station', 'inner station', 'launching base', 'lunar city', 'moon station', 'outer station', 'radar station'],
    'radio technician': ['arrl', 'amateur radio operator', 'control engineer', 'electrician', 'electrotechnician', 'groundman', 'ham', 'lineman', 'mixer', 'monitor', 'radio electrician', 'radio engineer'],
    'radio transmitter': ['am transmitter', 'fm transmitter', 'rt transmitter', 'amateur transmitter', 'beacon', 'coaxial cable', 'fan marker', 'frequency converter', 'frequency doubler', 'frequency meter', 'microphone', 'mixer'],
    'radio wave': ['amplitude', 'antinode', 'carrier', 'carrier wave', 'crest', 'de broglie wave', 'diffraction', 'electric wave', 'electromagnetic radiation', 'electromagnetic wave', 'frequency', 'frequency band'],
    'radioactivity': ['activity', 'artificial radioactivity', 'contamination', 'curiage', 'decontamination', 'fallout', 'half-life', 'natural radioactivity', 'nuclear radiation', 'radiant energy', 'radiation', 'radioactive radiation'],
    'radioelement': ['alpha radiator', 'americium', 'astatine', 'atomic cocktail', 'berkelium', 'beta radiator', 'cobalt', 'curium', 'einsteinium', 'fermium', 'fission products', 'fluorescent paint'],
    'radiogram': ['ecg', 'eeg', 'ekg', 'x ray', 'x-ray movie', 'cable', 'cablegram', 'chest x-ray', 'day letter', 'electrocardiogram', 'electrocorticogram', 'electroencephalogram'],
    'radiologist': ['anesthesiologist', 'atom-tagger', 'atomic scientist', 'cardiologist', 'chiropodist', 'dermatologist', 'eye doctor', 'geriatrician', 'gerontologist', 'gynecologist', 'immunologist', 'internist'],
    'radiology': ['x-ray photometry', 'x-ray spectrometry', 'atom-tagging', 'atomic science', 'atomics', 'atomistics', 'atomology', 'curiescopy', 'fluoroscopy', 'mass spectrography', 'mass spectrometry', 'molecular physics'],
    'radionics': ['newtonian physics', 'acoustics', 'aerophysics', 'applied physics', 'astrophysics', 'automation', 'avionics', 'basic conductor physics', 'biophysics', 'chemical physics', 'cryogenics', 'crystallography'],
    'radiorays': ['becquerel ray', 'grenz ray', 'roentgen ray', 'x radiation', 'x ray', 'actinic ray', 'actinism', 'alpha radiation', 'alpha ray', 'anode ray', 'atomic beam', 'atomic ray'],
    'radiotherapy': ['x-ray dosimetry', 'x-ray photometry', 'x-ray spectrometry', 'x-ray therapy', 'atom-tagging', 'cobalt therapy', 'curiescopy', 'curietherapy', 'fluoroscopy', 'irradiation', 'irradiation therapy', 'isotope therapy'],
    'radium': ['acid', 'actual cautery', 'americium', 'astatine', 'atomic cocktail', 'berkelium', 'brand', 'brand iron', 'branding iron', 'caustic', 'cauter', 'cauterant'],
    'radius': ['air line', 'ambit', 'amplitude', 'annular muscle', 'annulus', 'approach', 'area', 'areola', 'asymptote', 'aureole', 'axis', 'beeline'],
    'radix': ['beginning', 'bulb', 'bulbil', 'commencement', 'conception', 'corm', 'derivation', 'genesis', 'grass roots', 'head', 'inception', 'origin'],
    'raf': ['anac', 'arf', 'atc', 'ats', 'air command', 'air transport command', 'air transport service', 'airborne reconnaissance force', 'army-navy air corps', 'bomber command', 'casu', 'coastal command'],
    'raff': ['cattle', 'chaff', 'clamjamfry', 'debris', 'dregs', 'dregs of society', 'dust', 'junk', 'litter', 'lumber', 'masses', 'mob'],
    'raffish': ['boorish', 'carlish', 'churlish', 'cloddish', 'clownish', 'devil-may-care', 'fast', 'gay', 'hooliganish', 'loobyish', 'loutish', 'lubberly'],
    'raffle': ['bingo', 'call', 'cast lots', 'class lottery', 'cut lots', 'cut the cards', 'draft lottery', 'draw', 'draw lots', 'draw straws', 'drawing', 'gamble'],
    'raft': ['carling float', 'balsa', 'balsa raft', 'barge', 'batch', 'boat', 'bob', 'boom', 'buoy', 'bus', 'cart', 'coach'],
    'rafter': ['h beam', 'i beam', 'angle rafter', 'balk', 'batten', 'boom', 'box girder', 'breastsummer', 'corbel', 'crossbeam', 'crosstie', 'footing beam'],
    'rag': ['abuse', 'acid rock', 'act drop', 'afterglow', 'afterimage', 'andante tempo', 'apparel', 'array', 'asbestos', 'asbestos board', 'attire', 'avant-garde jazz'],
    'rag out': ['apparel', 'array', 'attire', 'bedeck', 'bedizen', 'bedrape', 'bundle up', 'clothe', 'deck', 'deck out', 'dight', 'dizen'],
    'raga': ['aeolian mode', 'dorian mode', 'greek modes', 'hindu mode', 'indian mode', 'locrian mode', 'lydian mode', 'phrygian mode', 'authentic mode', 'hypoaeolian mode', 'hypodorian mode', 'hypoionian mode'],
    'ragamuffin': ['arab', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'dogie', 'gamin', 'gamine', 'guttersnipe', 'hobo'],
    'rage': ['alecto', 'megaera', 'nemesis', 'tisiphone', 'abandon', 'acerbity', 'acrimony', 'agitation', 'amok', 'anger', 'asperity', 'assault'],
    'ragged': ['all in', 'bad', 'badgered', 'baited', 'battered', 'beat-up', 'bedeviled', 'bedraggled', 'beset', 'blowzy', 'brassy', 'brazen'],
    'raggedy': ['beat-up', 'bedraggled', 'blowzy', 'careless', 'chintzy', 'dilapidated', 'dowdy', 'down-at-heel', 'down-at-the-heels', 'drabbletailed', 'draggled', 'draggletailed'],
    'raging': ['dionysiac', 'abandoned', 'amok', 'anarchic', 'angry', 'bacchic', 'bellowing', 'berserk', 'blustering', 'blusterous', 'blustery', 'boisterous'],
    'ragman': ['arab', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'dogie', 'gamin', 'gamine', 'guttersnipe', 'hobo'],
    'ragpicker': ['arab', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'dogie', 'gamin', 'gamine', 'guttersnipe', 'hobo'],
    'ragtime': ['acid rock', 'andante tempo', 'avant-garde jazz', 'ballroom music', 'beat', 'bebop', 'boogie-woogie', 'bop', 'compound time', 'country rock', 'dance music', 'dances'],
    'raid': ['air attack', 'air raid', 'air strike', 'assault', 'attack', 'banditry', 'bear raid', 'blitz', 'board', 'boarding', 'brigandage', 'brigandism'],
    'raider': ['aggressor', 'assailant', 'assailer', 'assaulter', 'attacker', 'depredator', 'despoiler', 'forager', 'forayer', 'freebooter', 'invader', 'looter'],
    'rail': ['attack', 'baluster', 'balustrade', 'banister', 'bar', 'barrier', 'bawl out', 'berate', 'bottle up', 'boundary', 'box up', 'branch'],
    'rail at': ['abuse', 'bark at', 'barrack', 'berate', 'betongue', 'blacken', 'chaff', 'cut at', 'dig at', 'dump on', 'execrate', 'fleer'],
    'railing': ['balustrade', 'banister', 'bantering', 'barrier', 'booing', 'boundary', 'catcalling', 'chaffing', 'derisive', 'derisory', 'fence', 'fleering'],
    'raillery': ['badinage', 'banter', 'booing', 'catcalling', 'chaff', 'chaffing', 'derision', 'exchange', 'fleering', 'flippancy', 'fooling', 'fooling around'],
    'railroad': ['accelerate', 'branch', 'browbeat', 'bulldoze', 'bully', 'bullyrag', 'bundle', 'bustle', 'cable railway', 'coerce', 'cog railway', 'compel'],
    'railroad man': ['baggage man', 'bakehead', 'brakeman', 'brakie', 'butcher', 'conductor', 'dispatcher', 'fireman', 'footplate man', 'guard', 'lineman', 'porter'],
    'railroader': ['baggage man', 'bakehead', 'brakeman', 'brakie', 'butcher', 'conductor', 'dispatcher', 'fireman', 'footplate man', 'guard', 'lineman', 'porter'],
    'railway': ['branch', 'cable railway', 'cog railway', 'el', 'electric railway', 'elevated', 'elevated railway', 'embankment', 'feeder', 'feeder line', 'gravity-operated railway', 'horse railway'],
    'railway car': ['pullman', 'pullman car', 'baggage car', 'boxcar', 'caboose', 'car', 'carriage', 'chair car', 'coach', 'coal car', 'covered waggon', 'day coach'],
    'railway express': ['air express', 'airfreight', 'airlift', 'asportation', 'bearing', 'carriage', 'carry', 'carrying', 'cartage', 'conveyance', 'drayage', 'expressage'],
    'raiment': ['apparel', 'array', 'attire', 'bedeck', 'bedizenment', 'bedrape', 'bundle up', 'clad', 'clothe', 'clothes', 'clothing', 'costume'],
    'rain': ['jupiter pluvius', 'thor', 'zeus', 'abound', 'accord', 'administer', 'afford', 'agua', 'allot', 'allow', 'aqua', 'award'],
    'rain forest': ['afforestation', 'arboretum', 'boondocks', 'bush', 'bushveld', 'chase', 'climax forest', 'cloud forest', 'dendrology', 'forest', 'forest land', 'forest preserve'],
    'rainbow': ['amytal', 'amytal pill', 'dalmatian', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill'],
    'rainbowlike': ['burele', 'chatoyant', 'iridal', 'iridescent', 'iridial', 'iridian', 'irisated', 'irised', 'moire', 'mother-of-pearl', 'nacre', 'nacred'],
    'raindrop': ['scotch mist', 'bead', 'blood rain', 'dewdrop', 'drizzle', 'drop', 'droplet', 'evening mist', 'fall', 'flurry', 'gout of rain', 'mist'],
    'rainfall': ['scotch mist', 'blood rain', 'bogginess', 'damp', 'dampness', 'dewiness', 'drizzle', 'evening mist', 'exudation', 'fall', 'flurry', 'fogginess'],
    'rainmaker': ['dry ice', 'aeronaut', 'aeroplaner', 'aeroplanist', 'air pilot', 'airplanist', 'artificial nucleation', 'astronaut', 'aviator', 'barnstormer', 'birdman', 'captain'],
    'rainstorm': ['brash', 'burst of rain', 'cloudburst', 'cyclone', 'deluge', 'dirty weather', 'downfall', 'downflow', 'downpour', 'drencher', 'flood', 'foul weather'],
    'rainy': ['angry', 'blinding', 'boggy', 'cat-and-doggish', 'cloudy', 'cyclonic', 'damp', 'dampish', 'dank', 'dewy', 'dirty', 'drippy'],
    'rainy day': ['bad times', 'bust', 'cat-and-dog weather', 'depression', 'dirty weather', 'economic stagnation', 'evil day', 'hard times', 'heavy weather', 'monsoon', 'predominance of aquarius', 'raininess'],
    'raise': ['olympian heights', 'abandon', 'abet', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'acculturate', 'accumulate', 'accumulation', 'acme'],
    'raise hell': ['addle', 'addle the wits', 'ball up', 'be livid', 'be noisy', 'be pissed', 'becloud', 'bedazzle', 'befuddle', 'bewilder', 'bluster', 'boil'],
    'raised': ['accelerated', 'aggrandized', 'ampliate', 'amplified', 'assembled', 'augmented', 'beefed-up', 'bloated', 'bold', 'boosted', 'bossed', 'bossy'],
    'raiser': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter'],
    'raising': ['addition', 'adjunct', 'aggrandizement', 'ampliation', 'amplification', 'apotheosis', 'apprenticeship', 'architecture', 'ascent', 'assembly', 'assumption', 'augmentation'],
    'rake': ['casanova', 'don juan', 'lothario', 'aim at', 'angularity', 'ascend', 'backset', 'bank', 'barrage', 'be promiscuous', 'beat', 'blast'],
    'rake off': ['allotment', 'allowance', 'big end', 'bigger half', 'bit', 'bite', 'budget', 'capital gains', 'chunk', 'cleanup', 'clear profit', 'commission'],
    'rakish': ['abandoned', 'brave', 'bravura', 'braw', 'breezy', 'chic', 'chichi', 'dandy', 'dapper', 'daring', 'dashing', 'debauched'],
    'rally': ['highland games', 'olympiad', 'olympic games', 'olympics', 'abet', 'accumulate', 'adduce', 'advance', 'agglomerate', 'aggregate', 'aggroup', 'agitate'],
    'rally round': ['act with', 'align with', 'come together', 'crystallize', 'draw up', 'fall in', 'fall into line', 'fall into place', 'fall into rank', 'flock to', 'form', 'gather around'],
    'rallying cry': ['angelus', 'angelus bell', 'alarm', 'alarum', 'bark', 'battle cry', 'bawl', 'bellow', 'birdcall', 'bugle call', 'call', 'call to arms'],
    'ram': ['assault', 'bear', 'bear upon', 'bellwether', 'billy', 'billy goat', 'boar', 'boost', 'bubbly-jock', 'buck', 'bull', 'bulldoze'],
    'ram in': ['brim', 'charge', 'chock', 'congest', 'cram', 'cram in', 'crowd', 'crowd in', 'drive in', 'fill', 'fill to overflowing', 'fill up'],
    'ramble': ['wanderjahr', 'afoot and lighthearted', 'airing', 'amble', 'babble', 'bat around', 'be insane', 'blab', 'blabber', 'blather', 'blether', 'bum'],
    'rambler': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'bird of passage', 'drifter', 'floater'],
    'rambling': ['greek to one', 'wanderjahr', 'aberrancy', 'aberrant', 'aberration', 'aberrative', 'adrift', 'afloat', 'afoot and lighthearted', 'aimless', 'aimlessness', 'alternating'],
    'ramification': ['appendage', 'arborescence', 'arborization', 'arm', 'bifidity', 'biforking', 'bifurcation', 'bine', 'bipartition', 'bisection', 'bough', 'branch'],
    'ramify': ['accelerate', 'aggravate', 'ball up', 'beef up', 'bifurcate', 'bisect', 'blow up', 'branch', 'branch out', 'by two', 'cleave', 'complicate'],
    'ramous': ['v-shaped', 'y-shaped', 'arboreal', 'arborescent', 'arboriform', 'biforked', 'bifurcate', 'bifurcated', 'bowery', 'branched', 'branching', 'branchlike'],
    'ramp': ['acclivity', 'arise', 'ascent', 'assault', 'attack', 'back stairs', 'ballot-box stuffing', 'bank', 'barbarize', 'batter', 'be angry', 'be excitable'],
    'rampage': ['ado', 'agitation', 'amok', 'assault', 'attack', 'barbarize', 'batter', 'berserk', 'binge', 'bother', 'brawl', 'broil'],
    'rampant': ['abandoned', 'abounding', 'abundant', 'affluent', 'all-sufficing', 'ample', 'anabatic', 'aplenty', 'ascendant', 'ascending', 'ascensional', 'ascensive'],
    'rampart': ['abatis', 'abutment', 'advanced work', 'arc-boutant', 'arch dam', 'backstop', 'balistraria', 'bamboo curtain', 'bank', 'banquette', 'bar', 'barbed-wire entanglement'],
    'ramshackle': ['battered', 'beat-up', 'beaten up', 'broken-down', 'crumbling', 'decrepit', 'derelict', 'dilapidated', 'doddering', 'flimsy', 'groggy', 'in disrepair'],
    'ranch': ['arable land', 'barnyard', 'barton', 'breed', 'cattle ranch', 'chicken farm', 'collective farm', 'cotton plantation', 'croft', 'crop', 'culture', 'dairy farm'],
    'rancher': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'breaker', 'breeder', 'broncobuster', 'buckaroo', 'cattleman', 'coffee-planter', 'collective farm worker'],
    'rancid': ['awful', 'bad', 'bad-smelling', 'barfy', 'blown', 'brackish', 'cloying', 'corrupt', 'decayed', 'disagreeable', 'fecal', 'fetid'],
    'rancor': ['acerbity', 'acid', 'acidity', 'acidulousness', 'acrimony', 'animosity', 'animus', 'antagonism', 'antipathy', 'asperity', 'bad blood', 'bad feeling'],
    'rancorous': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'antagonistic', 'antipathetic', 'avenging'],
    'random': ['accidental', 'adventitious', 'adventitiously', 'aimless', 'aleatoric', 'aleatory', 'amorphous', 'any which way', 'anyhow', 'anywise', 'arbitrarily', 'arbitrary'],
    'random sample': ['accidentality', 'actuarial calculation', 'adjunct', 'adventitiousness', 'barometer', 'break', 'casualness', 'chance', 'component', 'contingent', 'cross section', 'destiny'],
    'randomness': ['aimlessness', 'capriciousness', 'causelessness', 'chance', 'chanciness', 'changeableness', 'derangement', 'designlessness', 'disarrangement', 'disarray', 'disarticulation', 'discomfiture'],
    'randy': ['animal', 'aphrodisiomaniacal', 'aroused', 'bawdy', 'carnal', 'clitoromaniacal', 'concupiscent', 'dirty', 'ejaculatory', 'erotic', 'eroticomaniacal', 'erotomaniacal'],
    'range': ['alps', 'andes', 'caucasus', 'himalayas', 'indian file', 'rockies', 'adjust', 'aesthetic distance', 'agora', 'aim', 'air transport', 'air travel'],
    'ranged': ['aligned', 'armed', 'arranged', 'arrayed', 'assorted', 'battled', 'categorized', 'classified', 'composed', 'constituted', 'deployed', 'disposed'],
    'ranger': ['audubon society', 'gurkhas', 'national wildlife service', 'ss', 'sierra club', 'special forces', 'waffen-ss', 'air warden', 'arboriculturist', 'attendant', 'caretaker', 'castellan'],
    'rani': ['kaiserin', 'begum', 'crown princess', 'czarina', 'empress', 'grand duchess', 'infanta', 'kumari', 'kunwari', 'maharani', 'malikzadi', 'princess'],
    'rank': ['english horn', 'ic analysis', 'indian file', 'kp', 'abject', 'abominable', 'absolute', 'abundant', 'adjust', 'align', 'alphabetize', 'analyze'],
    'rank and file': ['armed force', 'armed service', 'army', 'array', 'bourgeoisie', 'career soldiers', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty'],
    'ranked': ['aligned', 'arranged', 'arrayed', 'assorted', 'cataloged', 'categorized', 'classified', 'composed', 'constituted', 'disposed', 'filed', 'fixed'],
    'ranking': ['absolute', 'all-absorbing', 'analysis', 'analyzing', 'appraisal', 'appraisement', 'appraising', 'appreciation', 'arch', 'arrangement', 'ascendant', 'assessing'],
    'rankle': ['afflict', 'aggravate', 'agonize', 'ail', 'anger', 'annoy', 'arouse', 'be remembered', 'bite', 'bother', 'break up', 'bristle'],
    'rankled': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrimonious', 'bitter', 'burning', 'caustic', 'choleric'],
    'ransack': ['beat', 'burglarize', 'burgle', 'comb', 'depredate', 'despoil', 'examine', 'explore', 'fleece', 'forage', 'foray', 'freeboot'],
    'ransom': ['buy', 'deliver', 'deliverance', 'delivery', 'emancipate', 'extract', 'extricate', 'extrication', 'free', 'freeing', 'get back', 'liberate'],
    'rant': ['absurdity', 'act', 'amphigory', 'assault', 'attack', 'babble', 'babblement', 'balderdash', 'barbarize', 'batter', 'bawl out', 'be angry'],
    'ranter': ['herod', 'holy willie', 'joseph surface', 'mawworm', 'pecksniff', 'pharisee', 'tartuffe', 'affecter', 'blatherskite', 'bluff', 'bluffer', 'blusterer'],
    'ranting': ['dionysiac', 'abandoned', 'afebrile delirium', 'amok', 'babbling', 'bacchic', 'bellowing', 'berserk', 'blustering', 'blusterous', 'blustery', 'boisterous'],
    'rap': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'admonishment', 'admonition', 'adverse criticism', 'air', 'airing', 'analysis', 'analyze'],
    'rap session': ['airing', 'analysis', 'buzz session', 'canvassing', 'colloquium', 'colloquy', 'conference', 'consideration', 'debate', 'debating', 'deliberation', 'dialectic'],
    'rapacious': ['apician', 'a hog for', 'acquisitive', 'all-devouring', 'all-engulfing', 'avaricious', 'avid', 'bloodsucking', 'bolting', 'bottomless', 'coveting', 'covetous'],
    'rapacity': ['acquisitiveness', 'avarice', 'avariciousness', 'avidity', 'avidness', 'claim', 'covetousness', 'crapulence', 'crapulency', 'cupidity', 'demand', 'edacity'],
    'rape': ['abduction', 'abuse', 'assault', 'assault sexually', 'attack', 'banditry', 'barbarize', 'batter', 'battering', 'betray', 'betrayal', 'brigandage'],
    'rapid': ['abrupt', 'agile', 'alacritous', 'bluff', 'bold', 'breakneck', 'brisk', 'ceaseless', 'chattering', 'chute', 'constant', 'continual'],
    'rapidity': ['air speed', 'alacrity', 'bat', 'briskness', 'ceaselessness', 'celerity', 'chattering', 'constancy', 'constant flow', 'continualness', 'continuity', 'decisiveness'],
    'rapidly': ['always', 'amain', 'apace', 'at all times', 'at flank speed', 'at full speed', 'at once', 'briskly', 'ceaselessly', 'constantly', 'continually', 'daily'],
    'rapids': ['belch', 'burst', 'cascade', 'cataract', 'chute', 'collapse', 'comedown', 'crash', 'debacle', 'debouchment', 'declension', 'declination'],
    'rapist': ['mafioso', 'young turk', 'beast', 'beldam', 'berserk', 'berserker', 'betrayer', 'bomber', 'brute', 'bugger', 'coprophiliac', 'debaucher'],
    'rapping': ['accents', 'banging', 'blasting', 'bursting', 'chatter', 'colloquial discourse', 'colloquy', 'comment', 'communication', 'communion', 'conversation', 'converse'],
    'rapport': ['accord', 'accordance', 'addition', 'adjunct', 'affability', 'affairs', 'affiliation', 'affinity', 'agape', 'agreeability', 'agreeableness', 'agreement'],
    'rapprochement': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'amity', 'bonds of harmony', 'brotherly love', 'caritas', 'cement of friendship', 'charity', 'communion'],
    'rapscallion': ['bad boy', 'blackguard', 'booger', 'buffoon', 'bugger', 'cutup', 'devil', 'elf', 'enfant terrible', 'funmaker', 'hood', 'hoodlum'],
    'rapt': ['absent', 'absentminded', 'absorbed', 'abstracted', 'arrested', 'assiduous', 'beatific', 'bemused', 'bewitched', 'blissful', 'buried in thought', 'bursting with happiness'],
    'raptorial': ['all-devouring', 'all-engulfing', 'bloodsucking', 'clawed', 'dentate', 'digital', 'digitate', 'digitated', 'extortionate', 'fanged', 'fingered', 'grabby'],
    'rapture': ['abandon', 'affection', 'affectionateness', 'amativeness', 'amorousness', 'beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'cheer'],
    'rapturous': ['bursting with happiness', 'carried away', 'delighted', 'ecstatic', 'elate', 'elated', 'enchanted', 'enraptured', 'enravished', 'entranced', 'euphoric', 'exalted'],
    'rare': ['a cut above', 'above', 'admirable', 'adulterated', 'ahead', 'airy', 'almost unheard-of', 'another', 'ascendant', 'at a premium', 'attenuate', 'attenuated'],
    'rarefied': ['adulterated', 'air-built', 'airy', 'attenuate', 'attenuated', 'boyish', 'chimerical', 'clannish', 'cliquish', 'cloud-built', 'cut', 'dainty'],
    'rarefy': ['add to', 'adulterate', 'aggrandize', 'amplify', 'attenuate', 'augment', 'baptize', 'bloat', 'blow up', 'broaden', 'build', 'build up'],
    'rarely': ['abnormally', 'at infrequent intervals', 'exiguously', 'extremely', 'hardly', 'hardly ever', 'here and there', 'in places', 'in spots', 'incredibly', 'infrequently', 'little'],
    'raring to': ['agog', 'alacritous', 'all agog', 'animated', 'anxious', 'avid', 'breathless', 'bursting to', 'desirous', 'eager', 'forward', 'full of life'],
    'rarity': ['abnormality', 'airiness', 'airy texture', 'amazement', 'anomaly', 'astonishing thing', 'astonishment', 'attenuation', 'chinchiness', 'chintziness', 'conversation piece', 'curio'],
    'rascal': ['bad boy', 'bastard', 'blackguard', 'blighter', 'booger', 'bounder', 'buffoon', 'bugger', 'cad', 'cutup', 'dastard', 'devil'],
    'rash': ['abrupt', 'abscess', 'adventuresome', 'adventurous', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia'],
    'rasher': ['bit', 'butt', 'chip', 'chunk', 'clip', 'clipping', 'coat', 'coating', 'collop', 'covering', 'crumb', 'cut'],
    'rashness': ['abruptness', 'alacrity', 'expeditiousness', 'feverishness', 'furiousness', 'haste', 'hastiness', 'hurriedness', 'impatience', 'impetuosity', 'impetuousness', 'impulsiveness'],
    'rasp': ['ablate', 'abrade', 'abrase', 'afflict', 'agonize', 'ail', 'annoy', 'bark', 'belch', 'bite', 'blare', 'blat'],
    'rasping': ['ablation', 'ablative', 'abradant', 'abrasion', 'abrasive', 'air pollution', 'attrition', 'attritive', 'attritus', 'bones', 'bran', 'buffing'],
    'rasputin': ['svengali', 'vip', 'access', 'bad influence', 'big wheel', 'court', 'eminence grise', 'five-percenter', 'friend at court', 'good influence', 'gray eminence', 'heavyweight'],
    'rat': ['angora goat', 'arctic fox', 'belgian hare', 'benedict arnold', 'brutus', 'caffre cat', 'indian buffalo', 'judas', 'judas iscariot', 'kodiak bear', 'quisling', 'sob'],
    'rat race': ['charybdis', 'absurdity', 'aimlessness', 'bootlessness', 'busyness', 'dirty work', 'dizzy round', 'donkeywork', 'drudgery', 'eddy', 'employment', 'emptiness'],
    'ratable': ['assessable', 'assessment', 'cess', 'chargeable', 'conscience money', 'contribution', 'direct tax', 'dutiable', 'duty', 'graduated taxation', 'imposition', 'impost'],
    'ratchet': ['cog', 'comb', 'crag', 'fang', 'harrow', 'jag', 'peak', 'pecten', 'projection', 'rake', 'sawtooth', 'snag'],
    'rate': ['vat', 'abuse', 'account', 'ad valorem duty', 'admonish', 'alcohol tax', 'alphabetize', 'amount', 'amusement tax', 'analyze', 'antecede', 'anyhow'],
    'rated': ['ad valorem', 'appraised', 'assessed', 'assorted', 'cataloged', 'classified', 'evaluated', 'filed', 'good for', 'graded', 'grouped', 'hierarchic'],
    'rather': ['ok', 'roger', 'a bit', 'a little', 'a rebours', 'absolutely', 'acceptably', 'adequately', 'after all', 'again', 'against the grain', 'albeit'],
    'rathskeller': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'cabaret', 'cafe', 'cocktail lounge', 'dive'],
    'ratification': ['john hancock', 'ok', 'acceptance', 'accord', 'acquiescence', 'affirmance', 'affirmation', 'affirmative', 'affirmative voice', 'agreement', 'approbation', 'approval'],
    'ratified': ['accepted', 'acknowledged', 'admitted', 'adopted', 'affirmed', 'allowed', 'appointed', 'approved', 'authenticated', 'avowed', 'carried', 'certified'],
    'ratify': ['ok', 'accede to', 'accept', 'accord to', 'accredit', 'adopt', 'affiliate', 'affirm', 'agree to', 'amen', 'approve', 'approve of'],
    'rating': ['abuse', 'admonishment', 'admonition', 'analysis', 'analyzing', 'appraisal', 'appraisement', 'appraising', 'appreciation', 'apprizal', 'approximation', 'arrangement'],
    'ratio': ['vernunft', 'amount', 'analogousness', 'arithmetical proportion', 'balance', 'brain', 'brains', 'caliber', 'commensurability', 'comparability', 'comparableness', 'comparativeness'],
    'ratiocination': ['abstract thought', 'act of thought', 'brainwork', 'cerebration', 'cogitation', 'conceit', 'conception', 'conceptualization', 'conclusion', 'creative thought', 'deduction', 'deductive reasoning'],
    'ration': ['administer', 'allocate', 'allot', 'allotment', 'allowance', 'amount', 'apportion', 'apportionment', 'assign', 'assignment', 'batch', 'big end'],
    'rational': ['acceptable', 'admissible', 'algorismic', 'algorithmic', 'aliquot', 'all there', 'analytic', 'balanced', 'bright', 'calm', 'cardinal', 'cerebral'],
    'rationale': ['account', 'allegorization', 'clarification', 'cracking', 'decipherment', 'decoding', 'demonstration', 'demythologization', 'editing', 'elucidation', 'emendation', 'enlightenment'],
    'rationalism': ['buddhology', 'mariolatry', 'mariology', 'mercersburg theology', 'apologetics', 'canonics', 'crisis theology', 'deduction', 'deductive reasoning', 'demonstration', 'dialogical theology', 'discourse'],
    'rationalistic': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'allegorizing', 'animist', 'animistic', 'annotative', 'atomistic', 'clarifying', 'cosmotheistic'],
    'rationality': ['iq', 'vernunft', 'admissibility', 'apprehension', 'balance', 'brain', 'brains', 'caliber', 'capacity', 'common sense', 'comprehension', 'conception'],
    'rationalization': ['account', 'adjustment', 'alienation', 'apparent soundness', 'approach', 'arrangement', 'attack', 'autism', 'autistic thinking', 'avoidance mechanism', 'blame-shifting', 'blueprint'],
    'rationalize': ['account', 'account for', 'adjust', 'allegorize', 'analyze', 'apply reason', 'argue insincerely', 'arrange', 'calculate', 'cast', 'chart', 'clarify'],
    'rationally': ['analytically', 'artfully', 'astutely', 'circumspectly', 'cleverly', 'considerately', 'cunningly', 'discerningly', 'discreetly', 'in all conscience', 'in all reason', 'in reason'],
    'rationing': ['apportionment', 'arrest', 'arrestation', 'budgeting', 'check', 'constraint', 'control', 'cooling', 'cooling down', 'cooling off', 'curb', 'curtailment'],
    'rations': ['c ration', 'k ration', 'abundance', 'accumulation', 'allotment', 'allowance', 'amassment', 'backlog', 'board', 'budget', 'collection', 'commissariat'],
    'rattail': ['braid', 'brush', 'bun', 'cauda', 'caudal appendage', 'caudation', 'chignon', 'coil', 'cue', 'dock', 'fantail', 'knot'],
    'rattle': ['bedlam let loose', 'klaxon', 'abash', 'abate', 'addle', 'addle the wits', 'agitate', 'agreeable rattle', 'assault', 'attenuate', 'babble', 'babbler'],
    'rattlebrained': ['blank', 'brainless', 'dizzy', 'empty', 'empty-headed', 'empty-minded', 'empty-pated', 'empty-skulled', 'featherbrained', 'featherheaded', 'flighty', 'fluttery'],
    'ratty': ['angry', 'annoyed', 'beset', 'choleric', 'crabbed', 'cranky', 'cross', 'dirty', 'disagreeable', 'dowdy', 'down-at-heel', 'down-at-the-heels'],
    'raucous': ['absonant', 'atonal', 'boisterous', 'brassy', 'brazen', 'brusque', 'cacophonous', 'choked', 'coarse', 'cracked', 'croaking', 'croaky'],
    'raunchy': ['fescennine', 'rabelaisian', 'bawdy', 'blue', 'coarse', 'dirty', 'disheveled', 'filthy', 'foul', 'foul-mouthed', 'foul-spoken', 'foul-tongued'],
    'ravage': ['abuse', 'adulterate', 'alloy', 'banditry', 'beset', 'betray', 'betrayal', 'bloodbath', 'blue ruin', 'breakup', 'brigandage', 'brigandism'],
    'ravaged': ['ablative', 'ausgespielt', 'bankrupt', 'beset', 'biodegradable', 'blasted', 'blighted', 'blown', 'broken', 'corrosive', 'decomposable', 'decomposing'],
    'ravager': ['betrayer', 'debaucher', 'deceiver', 'defiler', 'depredator', 'despoiler', 'forager', 'forayer', 'freebooter', 'looter', 'marauder', 'pillager'],
    'ravages of time': ['ablation', 'atomization', 'breakup', 'corridors of time', 'corrosion', 'crumbling', 'decay', 'decomposition', 'degradation', 'dilapidation', 'disintegration', 'disjunction'],
    'rave': ['abuse', 'acclaim', 'accolade', 'admiration', 'applaud', 'assault', 'attack', 'babble', 'barbarize', 'bark at', 'bash', 'batter'],
    'ravel': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 'answer', 'ball up', 'bottom', 'can of worms', 'clarify', 'clear up', 'complex', 'complicate', 'confound'],
    'raven': ['angry clouds', 'atramentous', 'batten', 'be ravenous', 'black', 'black as coal', 'black as ebony', 'black as ink', 'black as midnight', 'black as night', 'black cat', 'black clouds'],
    'ravenous': ['apician', 'a hog for', 'acquisitive', 'all-devouring', 'all-engulfing', 'avaricious', 'avid', 'bloodsucking', 'bolting', 'bottomless', 'coveting', 'covetous'],
    'ravine': ['abysm', 'abyss', 'arroyo', 'bottom', 'bottom glade', 'bottoms', 'box canyon', 'breach', 'break', 'canyon', 'cavity', 'chap'],
    'raving': ['dionysiac', 'abandoned', 'afebrile delirium', 'amok', 'anarchic', 'angry', 'babble', 'babbling', 'bacchic', 'balderdash', 'beaming', 'bellowing'],
    'ravish': ['abuse', 'adulterate', 'alloy', 'assault sexually', 'becharm', 'betray', 'bewitch', 'canker', 'captivate', 'carry away', 'charm', 'cheapen'],
    'ravished': ['abandoned', 'amok', 'bellowing', 'berserk', 'bursting with happiness', 'carried away', 'delirious', 'demoniac', 'distracted', 'ecstatic', 'elate', 'elated'],
    'ravisher': ['betrayer', 'debaucher', 'deceiver', 'defiler', 'depredator', 'despoiler', 'forager', 'forayer', 'freebooter', 'looter', 'marauder', 'pillager'],
    'ravishment': ['abandon', 'abuse', 'banditry', 'beatification', 'beatitude', 'betrayal', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'brigandage', 'brigandism'],
    'raw': ['rabelaisian', 'siberian', 'a novice at', 'a stranger to', 'abusive', 'adolescent', 'algetic', 'algid', 'angry', 'arctic', 'at half cock', 'awkward'],
    'raw deal': ['atrocity', 'bad fortune', 'bad luck', 'disservice', 'evil dispensation', 'evil fortune', 'evil star', 'frowns of fortune', 'great wrong', 'grievance', 'gross injustice', 'hard lines'],
    'raw recruit': ['abecedarian', 'alphabetarian', 'apprentice', 'articled clerk', 'baby', 'beginner', 'boot', 'catechumen', 'conscript', 'deb', 'debutant', 'draft'],
    'rawboned': ['angular', 'bony', 'flat', 'flat-chested', 'fleshless', 'gangling', 'gangly', 'gaunt', 'gawky', 'lank', 'lanky', 'lean'],
    'rawhide': ['leatherette', 'leatheroid', 'baste', 'bastinado', 'beat', 'belabor', 'belt', 'birch', 'blacksnake', 'buffet', 'bullwhack', 'bullwhip'],
    'ray': ['reptilia', 'x ray', 'actinic ray', 'actinism', 'amplitude', 'antinode', 'atom', 'atomic beam', 'atomic ray', 'beam', 'beam of light', 'crest'],
    'ray of sunshine': ['leibnizian optimist', 'pollyanna', 'aspirant', 'aspirer', 'broad day', 'chiliast', 'dawn', 'day', 'day glow', 'daylight', 'dayshine', 'daytide'],
    'rayless': ['ableptical', 'amaurotic', 'beamless', 'benighted', 'bereft of light', 'black', 'black as night', 'blind', 'caliginous', 'color-blind', 'dark', 'dark as night'],
    'raze': ['ablate', 'abrade', 'abrase', 'align', 'bark', 'beat down', 'blot', 'blot out', 'blow down', 'blow over', 'bowl down', 'bowl over'],
    'razz': ['bronx cheer', 'banter', 'bird', 'boo', 'booing', 'catcall', 'chaff', 'deride', 'fool', 'grin at', 'haze', 'hiss'],
    'razzing': ['banter', 'bantering', 'booing', 'catcalling', 'chaffing', 'derision', 'derisive', 'derisory', 'fleering', 'flippancy', 'flippant', 'fooling'],
    're': ['about', 'anent', 'apropos of', 'as', 'as for', 'as regards', 'as respects', 'as to', 'concerning', 'in connection with', 'in point of', 'in re'],
    're create': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'better', 'break up', 'change', 'convert', 'copy', 'deform', 'denature'],
    're creation': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'alteration', 'amelioration', 'apostasy', 'betterment', 'break', 'change', 'change of heart', 'changeableness'],
    're form': ['amend', 'copy', 'do over', 'duplicate', 'make over', 'new-model', 're-create', 'reassemble', 'rebuild', 'reclaim', 'reconstitute', 'reconstruct'],
    'reach': ['accomplish', 'achieve', 'aesthetic distance', 'affect', 'ambit', 'amount', 'amount to', 'amplitude', 'answer', 'approach', 'approach anchorage', 'area'],
    'reach out': ['be lengthy', 'be prolonged', 'belong', 'carry', 'carry out', 'cover', 'crane', 'encompass', 'environ', 'extend', 'extend out', 'go'],
    'react': ['acknowledge', 'act', 'answer', 'answer back', 'be affected', 'be in tune', 'be inspired', 'be involved', 'be moved', 'behave', 'care about', 'catch the flame'],
    'reaction': ['bourbonism', 'toryism', 'acknowledgment', 'action and reaction', 'aeromotor', 'affect', 'affection', 'answer', 'answering', 'antagonism', 'antipathy', 'antiphon'],
    'reactionary': ['bircher', 'bourbon', 'colonel blimp', 'epistle side', 'methuselah', 'tory', 'antagonistic', 'antediluvian', 'antipathetic', 'antiphonal', 'antique', 'atavistic'],
    'reactionism': ['bourbonism', 'toryism', 'backwardness', 'conservatism', 'conservativeness', 'die-hardism', 'extreme right', 'extreme right wing', 'extreme rightism', 'know-nothingism', 'laissez-faireism', 'monarchism'],
    'reactivate': ['activate', 'give back', 'mobilize', 'place in', 'put back', 'recharge', 'reconstitute', 'reconvert', 'recruit', 'reenact', 'reestablish', 'refill'],
    'reactor': ['atomic pile', 'breeder reactor', 'bricks', 'chain reactor', 'chain-reacting pile', 'fast pile', 'furnace', 'heterogeneous reactor', 'homogeneous reactor', 'intermediate pile', 'lattice', 'neutron factory'],
    'read': ['absorb', 'announce', 'appreciate', 'apprehend', 'assign to', 'assimilate', 'be with one', 'bone', 'catch', 'catch on', 'comprehend', 'con'],
    'readable': ['absorbing', 'allegorical', 'apprehensible', 'articulate', 'associational', 'cognizable', 'comprehensible', 'connotational', 'connotative', 'decipherable', 'definable', 'denotational'],
    'reader': ['bible clerk', 'bible reader', 'boanerges', 'flexowriter typewriter', 'teleplotter', 'abecedarium', 'abecedary', 'achromatic lens', 'acolyte', 'acolytus', 'almoner', 'alphabet book'],
    'readily': ['agilely', 'agreeably', 'animatedly', 'anxiously', 'apace', 'ardently', 'at once', 'at short notice', 'avidly', 'breathlessly', 'charitably', 'cheerfully'],
    'readiness': ['italian hand', 'ok', 'a thing for', 'ability', 'acceptance', 'accord', 'acquiescence', 'acuity', 'acuteness', 'address', 'adeptness', 'adroitness'],
    'reading': ['crt spot', 'dm display', 'doppler signal', 'if signal', 'im display', 'rf echoes', 'address', 'after-dinner speech', 'allocution', 'application', 'barometer', 'beam'],
    'reading glass': ['achromatic lens', 'astigmatic lens', 'burning glass', 'camera', 'coated lens', 'concave lens', 'concavo-convex lens', 'condenser', 'convex lens', 'eyeglass', 'eyepiece', 'glass'],
    'reading matter': ['advance sheets', 'advertising matter', 'article', 'autograph', 'brainchild', 'composition', 'computer printout', 'copy', 'document', 'draft', 'edited version', 'engrossment'],
    'readout': ['flexowriter typewriter', 'teleplotter', 'alphabetical printer', 'barometer', 'canon', 'check', 'criterion', 'degree', 'digital graph plotter', 'gauge', 'graduated scale', 'hard copy'],
    'ready': ['daedalian', 'machiavellian', 'machiavellic', 'about', 'accessible', 'accordant', 'acquiescent', 'active', 'acute', 'adaptable', 'adept', 'adjusted'],
    'ready made': ['assembled', 'bespoke', 'bought', 'boughten', 'built', 'cast', 'constructed', 'crafted', 'created', 'custom', 'custom-built', 'custom-made'],
    'ready-made': ['adaptable', 'believable', 'convenient', 'conventional', 'credible', 'expedient', 'finished', 'hackneyed', 'handy', 'pedestrian', 'plausible', 'prefabricated'],
    'ready-to-wear': ['assembled', 'bespoke', 'built', 'cast', 'constructed', 'crafted', 'created', 'custom', 'custom-built', 'custom-made', 'cut-and-dried', 'cut-and-dry'],
    'reagent': ['acid', 'acidity', 'agent', 'alkali', 'alkalinity', 'alloisomer', 'anion', 'antacid', 'atom', 'base', 'biochemical', 'cation'],
    'real': ['gaussian integer', 'absolute', 'actual', 'admitting no question', 'algebraic number', 'algorismic', 'algorithmic', 'aliquot', 'almighty', 'appreciable', 'ascertained', 'attested'],
    'real estate': ['acres', 'alluvion', 'alluvium', 'arable land', 'block', 'chattels real', 'clay', 'clod', 'clos', 'close', 'croft', 'crust'],
    'real property': ['acres', 'alluvion', 'alluvium', 'arable land', 'chattels real', 'clay', 'clod', 'crust', 'demesne', 'dirt', 'domain', 'dry land'],
    'realign': ['accommodate', 'adapt', 'adjust', 'align', 'alter', 'ameliorate', 'better', 'break up', 'change', 'collimate', 'collineate', 'convert'],
    'realignment': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'alteration', 'amelioration', 'apostasy', 'betterment', 'break', 'change', 'change of heart', 'changeableness'],
    'realism': ['marxism', 'absolute realism', 'animalism', 'artlessness', 'atomism', 'authenticity', 'behaviorism', 'bona fideness', 'commonsense realism', 'dialectical materialism', 'down-to-earthness', 'earthiness'],
    'realist': ['cyrenaic', 'eleatic', 'epicurean', 'marxian', 'marxist', 'megarian', 'stoic', 'animist', 'animistic', 'atomistic', 'commonsense', 'commonsense philosopher'],
    'realistic': ['cyrenaic', 'eleatic', 'epicurean', 'marxian', 'marxist', 'megarian', 'stoic', 'animist', 'animistic', 'astute', 'atomistic', 'authentic'],
    'reality': ['accomplished fact', 'actuality', 'adventure', 'authenticity', 'circumstance', 'confirmability', 'demonstratability', 'doubtlessness', 'entelechy', 'episode', 'eternal verities', 'event'],
    'realizable': ['achievable', 'actable', 'attainable', 'banausic', 'compassable', 'doable', 'effective', 'effectual', 'efficient', 'feasible', 'negotiable', 'operable'],
    'realization': ['accident', 'accomplished fact', 'accomplishment', 'achievement', 'actualization', 'alphabet', 'apparition', 'appearance', 'appearing', 'apperception', 'appreciation', 'appreciativeness'],
    'realize': ['absorb', 'accomplish', 'achieve', 'act', 'actualize', 'adumbrate', 'appreciate', 'apprehend', 'assimilate', 'attain', 'author', 'be acquainted with'],
    'realized': ['accomplished', 'achieved', 'appreciated', 'apprehended', 'ascertained', 'attained', 'compassed', 'comprehended', 'conceived', 'consummated', 'discerned', 'discharged'],
    'really': ['ok', 'roger', 'absolutely', 'actually', 'all right', 'almighty', 'alright', 'alrighty', 'amen', 'as you say', 'assuredly', 'at bottom'],
    'realm': ['ally', 'ambit', 'animal kingdom', 'archduchy', 'archdukedom', 'area', 'arena', 'bailiwick', 'beat', 'body politic', 'border', 'borderland'],
    'realpolitik': ['machtpolitik', 'tammany hall', 'bossism', 'career politics', 'confrontation politics', 'consensus politics', 'economics in action', 'empirical politics', 'kid-glove politics', 'machine politics', 'partisan politics', 'partisanism'],
    'realtor': ['bill broker', 'broker', 'cambist', 'cotton broker', 'diamond broker', 'discount broker', 'estate agent', 'furniture broker', 'grain broker', 'hotel broker', 'insurance broker', 'land broker'],
    'realty': ['acres', 'chattels real', 'demesne', 'domain', 'grounds', 'honor', 'land', 'landed property', 'lands', 'lot', 'lots', 'manor'],
    'ream': ['auger', 'bawl out', 'beat', 'bilk', 'bite', 'bore', 'broach', 'bugger', 'cardboard', 'chew', 'chew ass', 'chew out'],
    'reap': ['abbreviate', 'abridge', 'abstract', 'acquire', 'bag', 'be seized of', 'bob', 'boil down', 'bring in', 'capsulize', 'capture', 'catch'],
    'reaper': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'coffee-planter', 'collective farm worker', 'crofter', 'cropper', 'cultivator', 'dirt farmer', 'dry farmer'],
    'reappear': ['alternate', 'be here again', 'circle', 'come again', 'come and go', 'come around', 'come round', 'come round again', 'come up again', 'cycle', 'echo', 'go back'],
    'reappearance': ['alternation', 'beat', 'cyclicalness', 'doubling', 'duplication', 'echo', 'imitation', 'intermittence', 'intermittency', 'meter', 'oscillation', 'pendulum motion'],
    'reappearing': ['phoenixlike', 'continuous', 'cyclical', 'ever-recurring', 'frequent', 'haunting', 'incessant', 'periodic', 're-creative', 're-formative', 'reborn', 'recrudescent'],
    'rear': ['aft', 'after', 'aftermost', 'apprentice', 'arena', 'arise', 'arse', 'ascend', 'ass', 'assemble', 'back', 'backdrop'],
    'rear end': ['afterpart', 'afterpiece', 'back', 'back door', 'back seat', 'back side', 'backside', 'behind', 'bottom', 'breech', 'butt', 'buttocks'],
    'rearing': ['anabatic', 'apotheosis', 'apprenticeship', 'ascendant', 'ascending', 'ascensional', 'ascensive', 'ascent', 'assumption', 'basic training', 'beatification', 'bolt upright'],
    'rearward': ['a rebours', 'a reculons', 'aft', 'after', 'aftermost', 'afterpart', 'afterpiece', 'against the grain', 'anticlockwise', 'arear', 'ass-backwards', 'astern'],
    'reason': ['vernunft', 'acceptable', 'accomplishment', 'account', 'admissibility', 'advise with', 'aim', 'air', 'allegorization', 'ambition', 'analyze', 'answer'],
    'reason to believe': ['basis for belief', 'body of evidence', 'chain of evidence', 'clue', 'data', 'datum', 'documentation', 'evidence', 'exhibit', 'fact', 'facts', 'grounds'],
    'reasonable': ['acceptable', 'admissible', 'all there', 'allowable', 'apparent', 'appropriate', 'arguable', 'balanced', 'believable', 'bright', 'budget', 'cheap'],
    'reasonably': ['analytically', 'artfully', 'astutely', 'at a bargain', 'at a sacrifice', 'at budget prices', 'at cost', 'at cost price', 'at piggy-bank prices', 'at prime cost', 'at reduced rates', 'at small cost'],
    'reasoning': ['vernunft', 'abstract thought', 'act of thought', 'analysis', 'analytic', 'arguments', 'brain', 'brains', 'brainwork', 'cerebral', 'cerebration', 'cogitation'],
    'reasonless': ['abnormal', 'absonant', 'arbitrary', 'batty', 'bedlamite', 'bereft of reason', 'brainless', 'brainsick', 'capricious', 'careless', 'contradictory', 'contrary to reason'],
    'reassurance': ['aid and comfort', 'ascertainment', 'assurance', 'certification', 'check', 'checking', 'collation', 'comfort', 'condolence', 'confirmation', 'consolation', 'determination'],
    'reassure': ['afford hope', 'ascertain', 'assure', 'augur well', 'bear up', 'bid fair', 'bolster', 'brace', 'brace up', 'buck up', 'buoy up', 'certify'],
    'reassuring': ['assuring', 'auspicious', 'bright with promise', 'cheering', 'comforting', 'condolatory', 'condolent', 'condoling', 'consolatory', 'consoling', 'encouraging', 'favorable'],
    'reasty': ['bad', 'bad-smelling', 'fecal', 'fetid', 'foul', 'frowsty', 'frowy', 'frowzy', 'fulsome', 'funky', 'fusty', 'gamy'],
    'rebarbative': ['abhorrent', 'abominable', 'bad', 'barfy', 'base', 'beastly', 'below contempt', 'beneath contempt', 'brackish', 'cloying', 'contemptible', 'crude'],
    'rebate': ['abate', 'abatement', 'agio', 'allow', 'allowance', 'bank discount', 'bate', 'breakage', 'bribe', 'cash discount', 'chain discount', 'charge off'],
    'rebel': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'cong', 'fenian', 'guevarist'],
    'rebellion': ['anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism', 'chaos', 'civil disorder', 'confusion', 'contumacy', 'criminal syndicalism', 'defiance', 'disobedience', 'disorder'],
    'rebellious': ['alienated', 'beefing', 'bellyaching', 'bitching', 'breakaway', 'complaining', 'complaintful', 'contumacious', 'crabbing', 'crabby', 'cranky', 'croaking'],
    'rebirth': ['adoption', 'amendment', 'change of allegiance', 'change of heart', 'change of mind', 'circumcision', 'conversion', 'copy', 'doubling', 'duplication', 'echo', 'imitation'],
    'reborn': ['assimilated', 'born again', 'changed', 'circumcised', 'converted', 'justified', 'naturalized', 'reappearing', 'recrudescent', 'redeemed', 'redivivus', 'reformed'],
    'rebound': ['adaptability', 'backfire', 'backlash', 'backlashing', 'be reflected', 'be sent back', 'boom', 'boomerang', 'booming', 'bounce', 'bounce back', 'bounciness'],
    'rebuff': ['abjuration', 'abjure', 'abjurement', 'backfire', 'backlash', 'backlashing', 'bafflement', 'balk', 'be proof against', 'bear up', 'bear up against', 'beat back'],
    'rebuild': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'better', 'break up', 'change', 'convert', 'copy', 'deform', 'denature'],
    'rebuilding': ['copy', 'duplication', 'imitation', 'palingenesis', 're-creation', 're-formation', 'reassembling', 'reassembly', 'rebirth', 'reconstitution', 'reconstruction', 'redesign'],
    'rebuilt': ['altered', 'better', 'changeable', 'changed', 'converted', 'degenerate', 'deviant', 'divergent', 'improved', 'metamorphosed', 'metastasized', 'modified'],
    'rebuke': ['admonish', 'admonishment', 'admonition', 'bawl out', 'berate', 'berating', 'blowing up', 'bring to book', 'call down', 'call to account', 'carpet', 'castigate'],
    'rebut': ['advocate', 'allege in support', 'answer', 'answer conclusively', 'argue down', 'argue for', 'assert', 'be contrary to', 'belie', 'blow sky-high', 'break', 'call into question'],
    'rebuttal': ['answer', 'argument', 'bucking', 'challenge', 'comeback', 'complete answer', 'confounding', 'confutation', 'contention', 'contradiction', 'contraposition', 'contraremonstrance'],
    'recalcitrance': ['antagonism', 'antipathy', 'averseness', 'aversion', 'backlash', 'backwardness', 'bad blood', 'challenge', 'clashing', 'collision', 'combative reaction', 'competition'],
    'recalcitrant': ['adamant', 'adversary', 'adversative', 'adverse', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'at odds', 'averse', 'beyond control'],
    'recall': ['abolish', 'abolishment', 'abolition', 'abrogate', 'abrogation', 'anamnesis', 'annul', 'annulment', 'arouse', 'awaken', 'bid come', 'bring back'],
    'recant': ['abandon', 'abjure', 'abolish', 'abrogate', 'annul', 'assert the contrary', 'back down', 'back out', 'backwater', 'belie', 'brush aside', 'cancel'],
    'recantation': ['abandonment', 'abjuration', 'abjurement', 'abnegation', 'abolishment', 'abolition', 'abrogation', 'absolute contradiction', 'annulment', 'cancel', 'canceling', 'cancellation'],
    'recap': ['abbreviate', 'abbreviation', 'abridge', 'abridgment', 'abstract', 'add up', 'apocope', 'bob', 'boil down', 'capsulize', 'cast up', 'cipher up'],
    'recapitulate': ['abbreviate', 'abridge', 'abstract', 'add up', 'battologize', 'bob', 'boil down', 'capsulize', 'cast up', 'cipher up', 'clip', 'compress'],
    'recapitulation': ['abbreviation', 'abridgment', 'abstract', 'account', 'accounts', 'apocope', 'body count', 'capitulation', 'census', 'compression', 'condensation', 'conspectus'],
    'recapture': ['bring back', 'bring to mind', 'call back', 'call to mind', 'call up', 'conjure up', 'evoke', 'get back', 'go back', 'go back over', 'hark back', 'look back'],
    'recede': ['abate', 'back', 'back up', 'backslide', 'bate', 'close', 'cock', 'decline', 'depart', 'die away', 'diminish', 'drain'],
    'receding': ['declining', 'diminishing', 'dwindling', 'dying', 'ebbing', 'fading', 'recedence', 'recession', 'retirement', 'retiring', 'retractation', 'retractility'],
    'receipt': ['acceptance', 'acknowledge receipt of', 'acknowledgment', 'acquire', 'acquisition', 'acquittance', 'admission', 'admittance', 'aid', 'alterative', 'analeptic', 'answer'],
    'receipts': ['accounts', 'accounts payable', 'accounts receivable', 'assets', 'budget', 'budgeting', 'capital gains', 'cleanup', 'clear profit', 'costing-out', 'dividends', 'earnings'],
    'receivable': ['admissible', 'admissive', 'admissory', 'back', 'due', 'hospitable', 'imbibitory', 'in arrear', 'in arrears', 'ingestive', 'intromissive', 'intromittent'],
    'receivables': ['avails', 'box office', 'commissions', 'credit', 'credits', 'disposable income', 'dividend', 'dividends', 'earned income', 'earnings', 'gains', 'gate'],
    'receive': ['abide by', 'accede', 'accept', 'accept for gospel', 'accept implicitly', 'acclaim', 'acknowledge receipt of', 'acquiesce', 'acquiesce in', 'acquire', 'admit', 'agree'],
    'received': ['christian', 'accepted', 'acclaimed', 'acknowledged', 'admired', 'admitted', 'advocated', 'affirmed', 'allowed', 'applauded', 'approved', 'authentic'],
    'receiver': ['christian', 'god-fearing man', 'telautography', 'teletype', 'teletype network', 'teletyping', 'accepter', 'accountant', 'acquirer', 'addressee', 'audience', 'auditor'],
    'recension': ['amendment', 'article', 'autograph', 'brainchild', 'composition', 'computer printout', 'copy', 'correction', 'document', 'draft', 'edited version', 'editing'],
    'recent': ['ancient', 'brand-new', 'current', 'early', 'erstwhile', 'fore', 'former', 'fresh', 'immemorial', 'just out', 'late', 'later'],
    'recently': ['aforetime', 'afresh', 'anew', 'before', 'before now', 'beforetime', 'earlier', 'erenow', 'erewhile', 'erst', 'formerly', 'heretofore'],
    'receptacle': ['amnion', 'androecium', 'anther', 'autoclave', 'bag', 'basket', 'billy', 'bladder', 'bleb', 'blister', 'boll', 'botany'],
    'reception': ['acceptance', 'acceptation', 'acception', 'access', 'accueil', 'acquiescence', 'acquisition', 'admissibility', 'admission', 'admittance', 'affair', 'assemblee'],
    'receptive': ['accessible', 'acquiescent', 'adaptable', 'admissible', 'admissive', 'admissory', 'agreeable', 'alacritous', 'alert', 'alive to', 'amenable', 'amiable'],
    'recess': ['jim crow', 'abeyance', 'adjourn', 'adytum', 'alcove', 'apartheid', 'apartness', 'ashram', 'asylum', 'bay', 'bolt-hole', 'bosom'],
    'recession': ['abandonment', 'alcove', 'backset', 'backsliding', 'backward motion', 'backward step', 'bad times', 'bay', 'boom', 'bottoming out', 'business cycle', 'business fluctuations'],
    'recessive': ['atavistic', 'reactionary', 'recedent', 'recessional', 'recessionary', 'recidivist', 'recidivous', 'regressive', 'retroactive', 'retrocedent', 'retrocessive', 'retrograde'],
    'recessive character': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory', 'allele'],
    'recharge': ['activate', 'bring back', 'bring to', 'call back', 'reactivate', 'reanimate', 'recall to life', 'recruit', 'refresh', 'regenerate', 'reheat the ashes', 'reinspire'],
    'recherche': ['braw', 'breakaway', 'chic', 'classy', 'clothes-conscious', 'cosmopolitan', 'dainty', 'dapper', 'dashing', 'delicate', 'dressed to advantage', 'dressed to kill'],
    'recidivate': ['backslide', 'cock', 'fall', 'fall again into', 'fall astern', 'fall back', 'fall behind', 'fall from grace', 'get behind', 'go backwards', 'go behind', 'have a relapse'],
    'recidivism': ['about-face', 'amorality', 'apostasy', 'atheism', 'backing', 'backset', 'backslide', 'backsliding', 'backward motion', 'backward step', 'betrayal', 'bolt'],
    'recidivist': ['adamic', 'sabbath-breaker', 'apostate', 'atavistic', 'atheist', 'atheistic', 'backslider', 'backsliding', 'bad egg', 'bad lot', 'black sheep', 'blasphemer'],
    'recipe': ['mo', 'aid', 'alterative', 'analeptic', 'approach', 'assistance', 'balm', 'balsam', 'corrective', 'cure', 'form', 'formula'],
    'recipient': ['accepter', 'acquirer', 'addressee', 'admissible', 'admissive', 'admissory', 'audience', 'auditor', 'beholder', 'beneficiary', 'consignee', 'getter'],
    'reciprocal': ['algorismic', 'algorithmic', 'aliquot', 'ally', 'alter ego', 'alternate', 'analogon', 'analogous', 'analogue', 'answering', 'associate', 'associated'],
    'reciprocate': ['accord', 'act in concert', 'act together', 'affiliate', 'agree', 'agree with', 'ally', 'alternate', 'amalgamate', 'answer', 'answer to', 'associate'],
    'reciprocation': ['lissajous figure', 'alternation', 'back-and-forth', 'balance', 'battledore and shuttlecock', 'boomerang', 'coequality', 'comeback', 'coming and going', 'communion', 'community', 'commutation'],
    'reciprocity': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'alternation', 'amity', 'balance', 'battledore and shuttlecock', 'bipartisanship', 'bonds of harmony', 'brotherly love'],
    'recital': ['philharmonic concert', 'account', 'address', 'after-dinner speech', 'allocution', 'assignment', 'band concert', 'chalk talk', 'chamber concert', 'concert', 'copy', 'critique'],
    'recitation': ['address', 'after-dinner speech', 'allocution', 'assignment', 'chalk talk', 'debate', 'declamation', 'diatribe', 'discourse', 'disquisition', 'eulogy', 'exercise'],
    'recite': ['add up', 'affirm', 'allege', 'allegorize', 'assert', 'asseverate', 'aver', 'battologize', 'cast up', 'chronicle', 'cipher up', 'commit to memory'],
    'reciter': ['roscius', 'actor', 'actress', 'anecdotist', 'antagonist', 'bad guy', 'barnstormer', 'character', 'character actor', 'character man', 'character woman', 'child actor'],
    'reckless': ['accident-prone', 'adventuresome', 'agile', 'airy', 'apathetic', 'ataractic', 'audacious', 'blase', 'brash', 'breakneck', 'carefree', 'careless'],
    'recklessly': ['a corps perdu', 'airily', 'any old way', 'any which way', 'anyhow', 'apathetically', 'bunglingly', 'carelessly', 'casually', 'clumsily', 'cursorily', 'desperately'],
    'recklessness': ['abandon', 'accidia', 'acedia', 'apathy', 'ataraxia', 'ataraxy', 'callowness', 'careless abandon', 'carelessness', 'casualness', 'childishness', 'cursoriness'],
    'reckon': ['account', 'account as', 'account for', 'add', 'add up', 'algebraize', 'appraise', 'appreciate', 'approximate', 'assess', 'assume', 'attend to'],
    'reckon on': ['bank', 'bank on', 'bargain for', 'bet on', 'build on', 'calculate', 'calculate on', 'count on', 'depend', 'depend on', 'figure on', 'forestall'],
    'reckon with': ['account with', 'admit', 'assimilate', 'bear in mind', 'clear the board', 'complete', 'comprehend', 'comprise', 'contain', 'count in', 'cover', 'embody'],
    'reckoning': ['a reckoning of', 'account', 'account current', 'account of', 'account rendered', 'account stated', 'accounts', 'adding', 'addition', 'aggregate', 'allowance', 'amount'],
    'reclaim': ['abet', 'aid', 'amend', 'assist', 'avail', 'bail out', 'bear a hand', 'befriend', 'benefit', 'comfort', 'do good', 'doctor'],
    'reclaimable': ['ameliorable', 'amendable', 'correctable', 'corrigible', 'curable', 'emendable', 'fixable', 'improvable', 'medicable', 'mendable', 'recoverable', 'rectifiable'],
    'reclamation': ['about-face', 'amendment', 'amends', 'atonement', 'backing', 'backsliding', 'change of allegiance', 'change of heart', 'change of mind', 'compensation', 'composition', 'compromise'],
    'recline': ['abut on', 'be based on', 'bear on', 'bed', 'bed down', 'bestraddle', 'bestride', 'cant', 'couch', 'crawl', 'curl up', 'go to bed'],
    'reclining': ['accubation', 'accumbency', 'accumbent', 'couchancy', 'couchant', 'couche', 'crawling', 'debasement', 'decumbency', 'decumbent', 'depression', 'draped'],
    'recluse': ['diogenes', 'hieronymian', 'hieronymite', 'timon of athens', 'anchoress', 'anchorite', 'anchoritic', 'ascetic', 'bedridden invalid', 'cenobite', 'character', 'cloistered'],
    'recognition': ['acceptance', 'acclaim', 'acknowledgment', 'action', 'admission', 'allowance', 'anagnorisis', 'angle', 'apperception', 'appreciation', 'appreciativeness', 'architectonics'],
    'recognizable': ['apparent', 'appreciable', 'apprehensible', 'ascertainable', 'beholdable', 'cognizable', 'comprehensible', 'conceivable', 'detectable', 'discernible', 'disclosed', 'discoverable'],
    'recognizance': ['agreement', 'arrangement', 'bail', 'bond', 'commitment', 'contract', 'contract by deed', 'contract of record', 'contract quasi', 'covenant of indemnity', 'debenture', 'debenture bond'],
    'recognize': ['accept', 'acknowledge', 'admit', 'agree', 'agree provisionally', 'allow', 'appreciate', 'apprehend', 'approve', 'assent grudgingly', 'avow', 'be acquainted with'],
    'recognized': ['accepted', 'acknowledged', 'admitted', 'affirmed', 'allowed', 'appreciated', 'apprehended', 'approved', 'ascertained', 'authenticated', 'avowed', 'being done'],
    'recoil': ['about the bush', 'antagonism', 'antipathy', 'avoid', 'avoidance', 'backfire', 'backlash', 'backlashing', 'backwash', 'balk', 'bashfulness', 'beat around'],
    'recollect': ['arouse', 'awaken', 'bring back', 'bring to mind', 'call back', 'call to mind', 'call up', 'cite', 'conjure up', 'evoke', 'go back', 'go back over'],
    'recollected': ['alive', 'assured', 'balanced', 'collected', 'composed', 'confident', 'eidetic', 'enduring', 'equanimous', 'equilibrious', 'fresh', 'green'],
    'recollection': ['mnemosyne', 'affect memory', 'anamnesis', 'anterograde memory', 'atavism', 'collective memory', 'commitment to memory', 'computer memory', 'disk memory', 'drum memory', 'emotional response', 'engram'],
    'recommend': ['acclaim', 'advance', 'advise', 'advocacy', 'advocate', 'advocating', 'advocation', 'applaud', 'approve', 'back', 'blandish', 'boost'],
    'recommendable': ['advantageous', 'advisable', 'appropriate', 'becoming', 'befitting', 'congruous', 'convenient', 'decent', 'desirable', 'expedient', 'favorable', 'feasible'],
    'recommendation': ['advice', 'advocacy', 'approbation', 'approval', 'backing', 'blessing', 'character', 'commendation', 'counsel', 'direction', 'encouragement', 'endorsement'],
    'recompense': ['accord', 'amend', 'amends', 'atone', 'atone for', 'atonement', 'award', 'balance', 'balancing', 'blood money', 'comeuppance', 'commutation'],
    'reconcilable': ['accordant', 'affirmative', 'agreeable', 'agreeing', 'answerable', 'at one', 'coexistent', 'coexisting', 'coherent', 'coincident', 'coinciding', 'commensurate'],
    'reconcile': ['accept', 'accommodate', 'accommodate with', 'accord', 'adapt', 'adapt to', 'adjust', 'adjust to', 'agree with', 'arrange matters', 'assimilate', 'assimilate to'],
    'reconciled': ['accepting', 'accommodating', 'acquiescent', 'adapting', 'adaptive', 'adjusting', 'amenable', 'at ease', 'comfortable', 'compliant', 'composed', 'content'],
    'reconciliation': ['acceptance', 'accommodation', 'accord', 'accordance', 'acquiescence', 'adaptation', 'adaption', 'adjustment', 'agreement', 'amity', 'appeasement', 'arbitration'],
    'recondite': ['abstract', 'abstruse', 'academic', 'arcane', 'beclouded', 'blind', 'buried', 'cabalistic', 'cabbalistic', 'close', 'clouded', 'concealed'],
    'recondition': ['cobble', 'commission', 'condition', 'darn', 'do up', 'doctor', 'face-lift', 'fix', 'fix up', 'furbish', 'mend', 'overhaul'],
    'reconnaissance': ['air cover', 'air raid', 'air support', 'bombing', 'cover', 'dry run', 'examination', 'exploration', 'inspection', 'investigation', 'milk run', 'mission'],
    'reconnoiter': ['be vigilant', 'be watchful', 'bug', 'case', 'course', 'cover', 'do', 'eye', 'eyeball', 'follow', 'gaze at', 'go over'],
    'reconsider': ['amend', 'correct', 'draw off', 'go back over', 'have second thoughts', 're-examine', 'reappraise', 'rebehold', 'recheck', 'reevaluate', 'reexamine', 'reinquire'],
    'reconsideration': ['afterthought', 'commitment to memory', 'developed thought', 'exercise of memory', 'flashback', 'hindsight', 'learning by heart', 'looking back', 'mature thought', 'memoir', 'memorization', 'memorizing'],
    'reconstitute': ['copy', 'do over', 'duplicate', 'give back', 'make over', 'place in', 'put back', 're-create', 're-form', 'reactivate', 'readjust', 'realign'],
    'reconstruct': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'better', 'break up', 'change', 'convert', 'copy', 'deform', 'denature'],
    'reconstruction': ['copy', 'duplication', 'imitation', 'palingenesis', 're-creation', 're-formation', 'reassembling', 'reassembly', 'rebirth', 'rebuilding', 'reconstitution', 'redesign'],
    'record': ['cd', 'clio', 'muse of history', 'accomplishment', 'accomplishments', 'account', 'account rendered', 'accounting', 'acme', 'acta', 'adventures', 'album'],
    'record book': ['account book', 'accounts payable ledger', 'accounts receivable ledger', 'atlas', 'balance sheet', 'bank ledger', 'bankbook', 'books', 'calendar', 'card ledger', 'casebook', 'cashbook'],
    'record changer': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'record keeping': ['accounting', 'analysis', 'booking', 'braking', 'cataloging', 'chronicling', 'computation', 'coordination', 'enlistment', 'enrollment', 'entering', 'entry'],
    'record player': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'recorder': ['ca', 'cpa', 'english horn', 'flexowriter typewriter', 'ja', 'pandean pipe', 'teleplotter', 'accountant', 'accountant general', 'actuary', 'alphabetical printer', 'amicus curiae'],
    'recording': ['account', 'annals', 'apograph', 'booking', 'carbon', 'carbon copy', 'cartridge', 'cassette', 'catalog', 'cataloging', 'chronicle', 'chronicling'],
    'recording instrument': ['gramophone', 'teletype', 'anemograph', 'autograph', 'cash register', 'chronograph', 'electrograph', 'facsimile telegraph', 'hygrograph', 'kymograph', 'oscillograph', 'pari-mutuel'],
    'recording secretary': ['amanuensis', 'calligrapher', 'chirographer', 'clerk', 'copier', 'copyist', 'ink spiller', 'inkslinger', 'letterer', 'pen', 'pencil driver', 'penman'],
    'recount': ['account', 'accounts', 'add up', 'allegorize', 'battologize', 'body count', 'capitulation', 'cast up', 'census', 'cipher up', 'communicate', 'count'],
    'recounting': ['account', 'accounts', 'body count', 'capitulation', 'census', 'copy', 'count', 'critique', 'dwelling upon', 'elaboration', 'going over', 'head count'],
    'recoup': ['atone', 'get back', 'kick back', 'make amends', 'make good', 'make reparation', 'make restitution', 'make up', 'make up for', 'make up to', 'pay back', 'pay in kind'],
    'recourse': ['ability', 'access', 'admittance', 'agency', 'alternative', 'availability', 'backup', 'capacity', 'capital', 'dernier ressort', 'device', 'devices'],
    'recover': ['balance', 'bounce back', 'bring back', 'come about', 'come around', 'come back', 'come round', 'come to', 'come up smiling', 'compensate', 'convalesce', 'deliver'],
    'recovery': ['great leap forward', 'advance', 'advancement', 'amelioration', 'amendment', 'ascent', 'bettering', 'betterment', 'boom', 'boost', 'bottoming out', 'business cycle'],
    'recreant': ['sabbath-breaker', 'apostate', 'arrant coward', 'atheist', 'atheistic', 'backslider', 'backsliding', 'bad egg', 'bad lot', 'base', 'black sheep', 'blackguardly'],
    'recreation': ['amusement', 'bracer', 'bracing', 'cordial', 'disport', 'dissipation', 'distraction', 'diversion', 'divertisement', 'divertissement', 'ease', 'enjoyment'],
    'recrudescence': ['amendment', 'atavism', 'backset', 'backward deviation', 'change of allegiance', 'change of heart', 'change of mind', 'falling back', 'improvement', 'lapse', 'new birth', 'palingenesis'],
    'recruit': ['abecedarian', 'accommodate', 'add to', 'afford', 'alphabetarian', 'apprentice', 'arriviste', 'articled clerk', 'augment', 'baby', 'beat the drums', 'beginner'],
    'recruitment': ['bugle call', 'call', 'call to arms', 'call-up', 'catchword', 'clarion', 'clarion call', 'compulsory military service', 'conscription', 'draft', 'draft call', 'drafting'],
    'rectal': ['abdominal', 'anal', 'appendical', 'cardiac', 'cecal', 'colic', 'colonic', 'coronary', 'duodenal', 'enteric', 'gastric', 'ileac'],
    'rectangle': ['little joe', 'biquadrate', 'four', 'four-part diaphony', 'foursome', 'quad', 'quadrangle', 'quadrature', 'quadrennium', 'quadrilateral', 'quadrille', 'quadrinomial'],
    'rectangular': ['cube-shaped', 'cubed', 'cubic', 'cubiform', 'cuboid', 'diced', 'elliptical', 'elongated', 'foursquare', 'normal', 'oblong', 'oblongated'],
    'rectifiable': ['ameliorable', 'amendable', 'correctable', 'corrigible', 'curable', 'emendable', 'fixable', 'improvable', 'medicable', 'mendable', 'reclaimable', 'recoverable'],
    'rectification': ['amendment', 'amends', 'atonement', 'balancing', 'commutation', 'compensation', 'correction', 'counteraction', 'counterbalancing', 'editing', 'emendation', 'expiation'],
    'rectify': ['accommodate', 'accommodate with', 'accord', 'adapt', 'adapt to', 'adjust', 'adjust to', 'agree with', 'ameliorate', 'amend', 'assimilate', 'assimilate to'],
    'rectilinear': ['arrowlike', 'dead straight', 'direct', 'even', 'flat', 'horizontal', 'in a line', 'level', 'lineal', 'linear', 'rectilineal', 'right'],
    'rectitude': ['angelicalness', 'assured probity', 'blamelessness', 'character', 'cleanness', 'conscientiousness', 'correctness', 'decency', 'erectness', 'estimableness', 'fairness', 'godliness'],
    'recto': ['epistle side', 'acknowledgments', 'back', 'back matter', 'bastard title', 'bibliography', 'catch line', 'catchword', 'colophon', 'conservative', 'contents', 'contents page'],
    'rector': ['dd', 'doctor of divinity', 'grand penitentiary', 'holy father', 'holy joe', 'abbe', 'abuna', 'academic dean', 'administration', 'administrator', 'agent', 'antipope'],
    'rectory': ['dymaxion house', 'white house', 'adobe house', 'advowson', 'benefice', 'building', 'care of souls', 'casa', 'charge', 'church house', 'clergy house', 'cliff dwelling'],
    'rectum': ['abdomen', 'anus', 'appendix', 'blind gut', 'bowels', 'brain', 'cecum', 'colon', 'duodenum', 'endocardium', 'entrails', 'foregut'],
    'recumbency': ['accubation', 'accumbency', 'couchancy', 'debasement', 'decumbency', 'depression', 'loll', 'lounging', 'lowness', 'lying', 'lying down', 'proneness'],
    'recumbent': ['accumbent', 'aslant', 'aslope', 'atilt', 'bevel', 'beveled', 'bias', 'biased', 'canting', 'careening', 'couchant', 'couche'],
    'recuperate': ['ameliorate', 'brace up', 'come about', 'come round', 'convalesce', 'gain', 'gain strength', 'get back', 'get better', 'get well', 'heal', 'improve'],
    'recuperation': ['comeback', 'convalescence', 'rally', 'ransom', 'recapture', 'reclaiming', 'reclamation', 'recoup', 'recoupment', 'recovery', 'redemption', 'regainment'],
    'recur': ['alternate', 'be here again', 'circle', 'come again', 'come and go', 'come around', 'come back', 'come round', 'come round again', 'come up again', 'continue', 'cycle'],
    'recurrence': ['indian file', 'alternation', 'array', 'articulation', 'atavism', 'backset', 'backward deviation', 'bank', 'beat', 'buzz', 'catena', 'catenation'],
    'recurrent': ['alternate', 'articulated', 'automatic', 'beaten', 'beating', 'catenated', 'ceaseless', 'circling', 'common', 'concatenated', 'connected', 'constant'],
    'recusant': ['alienated', 'antiestablishment', 'at odds with', 'at variance with', 'breakaway', 'contrary', 'counter-culture', 'deviant', 'differing', 'disagreeing', 'disobedient', 'dissentient'],
    'red': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'communist sympathizer', 'cong', 'fenian'],
    'red baiting': ['jim crow', 'jim crow law', 'mccarthyism', 'anti-semitism', 'apartheid', 'black power', 'black supremacy', 'chauvinism', 'class consciousness', 'class distinction', 'class hatred', 'class prejudice'],
    'red blooded': ['beefy', 'bouncing', 'bulldoggish', 'doughty', 'dynamic', 'energetic', 'forceful', 'forcible', 'forcy', 'full-blooded', 'full-strength', 'game'],
    'red cent': ['c-note', 'g-note', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'bagatelle', 'bauble', 'bean', 'bibelot', 'bit'],
    'red complexioned': ['blooming', 'blowzed', 'blowzy', 'burnt', 'florid', 'flush', 'flushed', 'full-blooded', 'glowing', 'hectic', 'red-faced', 'red-fleshed'],
    'red faced': ['abashed', 'ashamed', 'blooming', 'blowzed', 'blowzy', 'blushing', 'burnt', 'chagrined', 'chapfallen', 'crestfallen', 'crushed', 'embarrassed'],
    'red flag': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'beacon', 'beacon fire', 'bell', 'bell buoy', 'blinker', 'blue peter', 'buoy'],
    'red handed': ['blatantly', 'bloodthirsty', 'bloody', 'bloody-minded', 'cruel', 'cutthroat', 'flagrante delicto', 'gory', 'homicidal', 'in flagrante delicto', 'in the act', 'murderous'],
    'red herring': ['anguille', 'art', 'artful dodge', 'artifice', 'blind', 'caviar', 'chicanery', 'conspiracy', 'contrivance', 'coup', 'craft', 'cute trick'],
    'red hot': ['abandoned', 'ablaze', 'afire', 'ardent', 'baking', 'blistering', 'boiling', 'boiling over', 'breathless', 'broiling', 'burning', 'burning hot'],
    'red light': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'beacon', 'beacon fire', 'bell', 'bell buoy', 'blinker', 'blue peter', 'buoy'],
    'red light district': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'bagnio', 'barrio', 'bawdyhouse', 'black ghetto'],
    'red man': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'red tape': ['afterthought', 'beadledom', 'beat', 'beaten path', 'bind', 'block', 'blockage', 'bumbledom', 'bureaucracy', 'bureaucratic delay', 'bureaucratism', 'chinoiserie'],
    'redcoat': ['anzac', 'aussie', 'boche', 'fritz', 'gi', 'heinie', 'hun', 'jerry', 'johnny', 'kraut', 'tommy', 'tommy atkins'],
    'redden': ['blanch', 'blush', 'carmine', 'change color', 'color', 'color up', 'crimson', 'darken', 'flame', 'flush', 'frown', 'glare'],
    'redecorate': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'color', 'dandify', 'deck', 'deck out', 'decorate', 'dizen'],
    'redeem': ['abet', 'abide by', 'absolve', 'acknowledge', 'aid', 'amend', 'amortize', 'assist', 'atone', 'atone for', 'avail', 'bail out'],
    'redeemable': ['ameliorable', 'amendable', 'back', 'coming', 'coming to', 'correctable', 'corrigible', 'curable', 'deliverable', 'due', 'emendable', 'extricable'],
    'redeemed': ['absolved', 'acquitted', 'angelic', 'archangelic', 'assimilated', 'beatified', 'blotted', 'born again', 'canceled', 'canonized', 'celestial', 'changed'],
    'redeeming': ['apologetic', 'ascetic', 'atoning', 'cleansing', 'compensational', 'compensatory', 'expiatory', 'indemnificatory', 'lustral', 'lustrational', 'lustrative', 'penitential'],
    'redemption': ['absolution', 'adoption', 'amendment', 'amends', 'amnesty', 'atonement', 'change of allegiance', 'change of heart', 'change of mind', 'circumcision', 'compensation', 'composition'],
    'redemptive': ['christlike', 'christly', 'apologetic', 'ascetic', 'atoning', 'celestial', 'cleansing', 'compensational', 'compensatory', 'divine', 'empyrean', 'expiatory'],
    'redneck': ['backwoodsman', 'briar-hopper', 'brush ape', 'bushman', 'clam digger', 'cracker', 'desert rat', 'forester', 'frontiersman', 'hillbilly', 'hinterlander', 'mountain man'],
    'redness': ['amblyopia', 'blearedness', 'bleariness', 'bloom', 'blurredness', 'blush', 'dim eyes', 'dim-sightedness', 'dull-sightedness', 'fieriness', 'flush', 'glow'],
    'redo': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'color', 'come again', 'copy', 'dandify', 'deck', 'deck out'],
    'redolence': ['aroma', 'balm', 'balminess', 'bouquet', 'breath', 'definite odor', 'detectable odor', 'effluvium', 'emanation', 'essence', 'exhalation', 'flavor'],
    'redolent': ['ambrosial', 'aromatic', 'balmy', 'effluvious', 'essenced', 'evocative', 'flowery', 'fragrant', 'fruity', 'in retrospect', 'incense-breathing', 'malodorous'],
    'redouble': ['accelerate', 'aggravate', 'beef up', 'blow up', 'come again', 'complicate', 'concentrate', 'condense', 'consolidate', 'copy', 'deepen', 'ditto'],
    'redoubt': ['abatis', 'advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'bastion', 'battlement'],
    'redoubtable': ['appalling', 'astounding', 'awe-inspiring', 'awesome', 'awful', 'celebrated', 'dire', 'direful', 'distinguished', 'dread', 'dreaded', 'dreadful'],
    'redound to': ['advance', 'bend to', 'bias', 'conduce', 'conduce to', 'contribute', 'contribute to', 'decide', 'determine', 'dispose', 'forward', 'go'],
    'redress': ['amend', 'amends', 'annul', 'atone', 'atone for', 'atonement', 'balancing', 'blood money', 'cancel out', 'commutation', 'compensate', 'compensation'],
    'redskin': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'reduce': ['abase', 'abash', 'abate', 'abbreviate', 'abrade', 'abridge', 'abstract', 'acetify', 'acidify', 'acidulate', 'adjust', 'adjust to'],
    'reduced': ['abated', 'ablated', 'adulterated', 'attenuated', 'badly off', 'bated', 'belittled', 'best', 'bottom', 'bowed down', 'broken', 'brought down'],
    'reducing': ['abating', 'allaying', 'alleviating', 'assuaging', 'blunting', 'calorie-counting', 'chastening', 'cushioning', 'dampening', 'damping', 'deadening', 'diminishing'],
    'reduction': ['abasement', 'abatement', 'abbreviation', 'about-face', 'abridgment', 'abstract', 'acetification', 'acidification', 'acidulation', 'addition', 'agio', 'alchemy'],
    'reductive': ['ablative', 'arrested', 'backward', 'coarse', 'conceptually crude', 'contractive', 'crude', 'declining', 'decreasing', 'decrescendo', 'decrescent', 'deductive'],
    'redundancy': ['edp', 'abundance', 'amplitude', 'avalanche', 'battology', 'bedizenment', 'bit', 'channel', 'circumambages', 'circumbendibus', 'circumlocution', 'cloud of words'],
    'redundant': ['abundant', 'battological', 'circumlocutory', 'copious', 'de trop', 'diffuse', 'diffusive', 'dispensable', 'duplicative', 'echoic', 'echoing', 'effusive'],
    'reed': ['english horn', 'pandean pipe', 'adjutage', 'aerophone', 'aftergrass', 'anthrophore', 'arrow', 'arrowhead', 'aulos', 'axis', 'bamboo', 'barb'],
    'reed stop': ['english horn', 'bassoon', 'block flute', 'bombard', 'bourdon', 'cello', 'claribel', 'clarinet', 'clarion', 'concert flute', 'cornet', 'cornopean'],
    'reeducate': ['broaden the mind', 'catechize', 'civilize', 'demonstrate', 'direct', 'edify', 'educate', 'enlighten', 'give instruction', 'give lessons in', 'ground', 'guide'],
    'reef': ['ait', 'archipelago', 'arrest', 'atoll', 'backpedal', 'backwater', 'bank', 'bar', 'bill', 'brake', 'breakwater', 'cape'],
    'reefer': ['det', 'dmt', 'frigidaire', 'lsd', 'mary jane', 'pullman', 'pullman car', 'stp', 'thc', 'acid', 'antidepressant', 'ataractic'],
    'reek': ['bo', 'aerate', 'aerify', 'afterdamp', 'ash', 'ashes', 'atomize', 'bad breath', 'bad smell', 'be aromatic', 'be redolent of', 'blackdamp'],
    'reeking': ['bo', 'ablaze', 'aerial', 'aerodynamic', 'aerostatic', 'aery', 'afire', 'aflame', 'aflicker', 'aglow', 'airy', 'alight'],
    'reel': ['charybdis', 'chinese windlass', 'spanish windlass', 'avoid', 'be drunk', 'be intoxicated', 'blench', 'blink', 'blunder', 'bob', 'bobble', 'call off'],
    'reeling': ['addled', 'angular momentum', 'angular motion', 'angular velocity', 'axial motion', 'beery', 'bemused', 'besotted', 'blind drunk', 'bowling', 'careening', 'centrifugation'],
    'reenact': ['give back', 'place in', 'put back', 'reactivate', 'reconstitute', 'reconvert', 'recruit', 'reestablish', 'refill', 'reform', 'rehabilitate', 'reinstall'],
    'reentry': ['earth insertion', 'lem', 'lm', 'apogee', 'attitude-control rocket', 'backset', 'backsliding', 'backward motion', 'backward step', 'ballistic capsule', 'burn', 'capsule'],
    'reestablish': ['copy', 'do over', 'duplicate', 'give back', 'make over', 'place in', 'put back', 're-create', 're-form', 'reactivate', 'rebuild', 'recall'],
    'reeve': ['g-man', 'mp', 'alderman', 'archon', 'bailie', 'bailiff', 'beadle', 'beagle', 'bound bailiff', 'burghermaster', 'burgomaster', 'cabinet member'],
    'refection': ['aliment', 'alimentation', 'board', 'bracer', 'bracing', 'chow', 'cordial', 'enlivenment', 'entertainment', 'exhilaration', 'feed', 'invigoration'],
    'refer': ['account for', 'accredit', 'accredit with', 'accrete to', 'acknowledge', 'address to', 'advert', 'advert to', 'advise', 'advise with', 'affect', 'allude'],
    'refer to': ['account for', 'accredit with', 'accrete to', 'acknowledge', 'address to', 'advert to', 'advise with', 'affect', 'allude to', 'answer to', 'appeal to', 'appertain to'],
    'referable': ['accountable', 'affinitive', 'alleged', 'appertaining', 'ascribable', 'assignable', 'associative', 'attributable', 'attributed', 'charged', 'comparable', 'comparative'],
    'referee': ['jp', 'justice', 'act between', 'adjudge', 'adjudicate', 'arbiter', 'arbitrate', 'arbitrator', 'bargain', 'bencher', 'critic', 'go between'],
    'reference': ['acknowledgment', 'advocacy', 'advocating', 'advocation', 'affective meaning', 'allusion', 'angle', 'appeal to', 'applicability', 'application', 'appositeness', 'aspect'],
    'reference book': ['baedeker', 'yellow pages', 'atlas', 'bibliography', 'business directory', 'calendar', 'casebook', 'catalog', 'catalogue raisonne', 'checklist', 'city directory', 'classified catalog'],
    'reference mark': ['asterisk', 'bullet', 'centered dot', 'dagger', 'diacritical mark', 'end stop', 'fist', 'index', 'leaders', 'obelisk', 'paragraph', 'point'],
    'referendum': ['australian ballot', 'hare system', 'aye', 'ballot', 'by-election', 'canvass', 'canvassing', 'casting vote', 'caucus', 'closed primary', 'congressional election', 'constitutional referendum'],
    'referent': ['affective meaning', 'bearing', 'coloring', 'connotation', 'consequence', 'denotation', 'drift', 'effect', 'essence', 'extension', 'force', 'gist'],
    'referential': ['allegorical', 'allusive', 'allusory', 'associational', 'connotational', 'connotative', 'definable', 'denotational', 'denotative', 'expressive', 'extended', 'extensional'],
    'refill': ['accomplish', 'bring to completion', 'bring to fruition', 'complete', 'eke out', 'fill in', 'fill out', 'fulfill', 'give back', 'make good', 'make up', 'mature'],
    'refine': ['abate', 'abrade', 'abstract', 'acculturate', 'advance', 'ameliorate', 'amend', 'bate', 'beautify', 'better', 'bolt', 'boost'],
    'refined': ['attic', 'ciceronian', 'accurate', 'advanced', 'allergic', 'ameliorated', 'anaphylactic', 'appreciative', 'archetypical', 'aristocratic', 'assembled', 'attentive'],
    'refinement': ['atticism', 'ablation', 'abrasion', 'absoluteness', 'abstraction', 'acculturation', 'accuracy', 'acquired taste', 'appreciation', 'appreciation of differences', 'appreciation of excellence', 'appreciativeness'],
    'refinery': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery', 'brewery', 'brickyard', 'cannery'],
    'reflect': ['act like', 'adumbrate', 'affect', 'allude to', 'arch', 'assume', 'attract', 'be abstracted', 'bend', 'bend back', 'blurt', 'blurt out'],
    'reflect upon': ['accuse', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'blame', 'call to account', 'cast blame upon', 'cast reflection upon', 'censure', 'complain against', 'condemn'],
    'reflection': ['crt spot', 'dm display', 'doppler signal', 'if signal', 'im display', 'parthian shot', 'rf echoes', 's-curve', 'action and reaction', 'address', 'adumbration', 'adverse criticism'],
    'reflective': ['careful', 'circumspect', 'cogitative', 'cognitive', 'concentrating', 'concentrative', 'conceptive', 'conceptual', 'conceptualized', 'considerate', 'contemplating', 'contemplative'],
    'reflector': ['cassegrainian telescope', 'newtonian telescope', 'oao', 'oso', 'astronomical observatory', 'astronomical telescope', 'cheval glass', 'coelostat', 'concave mirror', 'convex mirror', 'coronagraph', 'coronograph'],
    'reflex': ['pavlovian conditioning', 'action and reaction', 'adumbration', 'answer', 'antiphonal', 'arch', 'automatic', 'automatic reaction', 'automatic response', 'autonomic reaction', 'back', 'backlash'],
    'reflex action': ['action and reaction', 'answer', 'automatic reaction', 'automatic writing', 'automatism', 'autonomic reaction', 'blind impulse', 'bounceback', 'compulsiveness', 'conditioning', 'echo', 'echolalia'],
    'reflexive': ['active', 'active voice', 'antiphonal', 'automatic', 'blind', 'casual', 'compulsive', 'conditioned', 'forced', 'gut', 'ill-advised', 'ill-considered'],
    'refluent': ['antiphonal', 'ascending', 'axial', 'back', 'back-flowing', 'backward', 'descending', 'down-trending', 'downward', 'drifting', 'flowing', 'fluent'],
    'reflux': ['brownian movement', 'charybdis', 'maelstrom', 'action and reaction', 'advance', 'angular motion', 'answer', 'ascending', 'ascent', 'automatic reaction', 'autonomic reaction', 'axial motion'],
    'reform': ['fabianism', 'about-face', 'accommodate', 'accommodation', 'acculturate', 'adapt', 'adaptation', 'adjust', 'adjustment', 'advance', 'alter', 'alteration'],
    'reform school': ['pow camp', 'bastille', 'black hole', 'borstal', 'borstal institution', 'borstal school', 'bridewell', 'brig', 'cell', 'concentration camp', 'condemned cell', 'death cell'],
    'reformation': ['fabianism', 'abject apology', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'adoption', 'alteration', 'amelioration', 'amendment', 'apology', 'apostasy'],
    'reformatory': ['pow camp', 'bastille', 'black hole', 'borstal', 'borstal institution', 'borstal school', 'bridewell', 'brig', 'can', 'cell', 'concentration camp', 'condemned cell'],
    'reformed': ['advanced', 'altered', 'ameliorated', 'assimilated', 'beautified', 'better', 'bettered', 'bowdlerized', 'changeable', 'changed', 'civilized', 'cleaned'],
    'reformer': ['fabian', 'tammany man', 'extremist', 'machine politician', 'meliorist', 'old campaigner', 'party boss', 'party chieftain', 'party leader', 'pol', 'political hack', 'political leader'],
    'refound': ['copy', 'do over', 'duplicate', 'make over', 're-create', 're-form', 'rebuild', 'reconstitute', 'reconstruct', 'redesign', 'redo', 'reestablish'],
    'refract': ['bend', 'bias', 'crook', 'curve', 'deflect', 'deviate', 'diffract', 'diffuse', 'disperse', 'distort', 'diverge', 'divert'],
    'refraction': ['atmospheric attenuation', 'blind spots', 'clutter', 'deflection', 'deflexure', 'diffraction', 'diffusion', 'dispersion', 'distortion', 'false echoes', 'flection', 'flexure'],
    'refractor': ['cassegrainian telescope', 'newtonian telescope', 'oao', 'oso', 'astronomical observatory', 'astronomical telescope', 'coelostat', 'coronagraph', 'coronograph', 'heliostat', 'observatory', 'orrery'],
    'refractory': ['adversary', 'adversative', 'adverse', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'at odds', 'averse', 'beyond control', 'breachy'],
    'refrain': ['ps', 'parthian shot', 'spenserian stanza', 'abandon', 'abort', 'abstain', 'abstain from', 'addendum', 'afterthought', 'air', 'anacrusis', 'antistrophe'],
    'refraining': ['encratism', 'friday', 'lenten fare', 'pythagoreanism', 'pythagorism', 'rechabitism', 'shakerism', 'spartan fare', 'stoicism', 'abstainment', 'abstemiousness', 'abstention'],
    'refresh': ['activate', 'aerate', 'air', 'air out', 'air-condition', 'air-cool', 'airify', 'amuse', 'animate', 'arouse', 'awaken', 'beef up'],
    'refresh the memory': ['bring to recollection', 'brush up', 'carry back', 'get up on', 'give a hint', 'give the cue', 'hold the promptbook', 'jog the memory', 'nag', 'nudge', 'polish up', 'prompt'],
    'refresher course': ['academic specialty', 'area', 'classical education', 'core curriculum', 'course', 'course of study', 'curriculum', 'discipline', 'elective', 'field', 'general education', 'general studies'],
    'refreshing': ['analeptic', 'beneficial', 'benign', 'bracing', 'brisk', 'cheering', 'constitutional', 'cooling', 'cordial', 'corroborant', 'crisp', 'crispy'],
    'refreshment': ['aerage', 'aeration', 'air conditioning', 'air cooling', 'airing', 'aliment', 'alimentation', 'bite', 'board', 'case hardening', 'chow', 'collation'],
    'refrigerant': ['dry ice', 'freon', 'algific', 'ammonia', 'blast-freezing', 'carbon dioxide', 'chilling', 'congealing', 'coolant', 'cooling', 'ether', 'ethyl chloride'],
    'refrigerate': ['air-condition', 'air-cool', 'anhydrate', 'benumb', 'bite', 'blast-freeze', 'brine', 'chill', 'cool', 'corn', 'cure', 'cut'],
    'refrigeration': ['anhydration', 'blast-freezing', 'bottling', 'brining', 'canning', 'corning', 'curing', 'dehydration', 'desiccation', 'dry-curing', 'drying', 'embalming'],
    'refuge': ['alibi', 'apology', 'asylum', 'blind', 'bolt-hole', 'cache', 'citadel', 'cloak', 'color', 'concealment', 'corner', 'cover'],
    'refugee': ['dp', 'uitlander', 'absconder', 'alien', 'barbarian', 'bolter', 'deracine', 'displaced person', 'eloper', 'emigrant', 'emigre', 'escapee'],
    'refund': ['abate', 'abatement', 'agio', 'allow', 'allowance', 'amends', 'atone', 'atonement', 'bank discount', 'bate', 'breakage', 'cash discount'],
    'refurbish': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'clean up', 'color', 'dandify', 'deck', 'deck out', 'decorate'],
    'refusal': ['eighteenth amendment', 'prohibition party', 'volstead act', 'abjuration', 'abjurement', 'antipathy', 'averseness', 'aversion', 'backwardness', 'ban', 'brush-off', 'bucking'],
    'refuse': ['abjure', 'afterglow', 'afterimage', 'balance', 'ban', 'bar', 'be unmoved', 'be unwilling', 'beat back', 'beg off', 'bilge', 'bilgewater'],
    'refutable': ['arguable', 'at issue', 'confutable', 'conjectural', 'contestable', 'controversial', 'controvertible', 'debatable', 'defeasible', 'deniable', 'disprovable', 'disputable'],
    'refutation': ['abjuration', 'abjurement', 'abrogation', 'absolute contradiction', 'annulment', 'answer', 'argument', 'argumentum', 'case', 'complete answer', 'confounding', 'confutation'],
    'refute': ['abjure', 'advocate', 'allege in support', 'answer', 'answer conclusively', 'argue down', 'argue for', 'assert', 'assert the contrary', 'belie', 'break', 'champion'],
    'refuting': ['apologetic', 'confounding', 'confutative', 'confuting', 'contradictory', 'contrary', 'excusatory', 'excusing', 'extenuating', 'extenuative', 'justificatory', 'justifying'],
    'regain': ['achieve', 'attain', 'compass', 'gain', 'get back', 'ransom', 'reach', 'recapture', 'reclaim', 'recoup', 'recover', 'recruit'],
    'regal': ['advantageous', 'aristocratic', 'august', 'auspicious', 'beneficial', 'benevolent', 'bon', 'bonny', 'braw', 'bueno', 'capital', 'cogent'],
    'regale': ['allay', 'amuse', 'animate', 'appease', 'assuage', 'banquet', 'beguile', 'bewitch', 'board', 'brace', 'brace up', 'bread'],
    'regalement': ['amusement', 'appetite', 'banquet', 'board', 'bracer', 'bracing', 'cannibalism', 'carnivorism', 'carnivority', 'carnivorousness', 'celebration', 'chewing'],
    'regalia': ['sunday best', 'apparatus', 'appurtenances', 'armory', 'badge', 'badge of office', 'badges', 'baton', 'blazonry', 'brassard', 'bravery', 'button'],
    'regard': ['amor', 'anschauung', 'christian love', 'eros', 'platonic love', 'tlc', 'abide by', 'accommodatingness', 'accord respect to', 'account', 'account as', 'act up to'],
    'regardful': ['acclamatory', 'accommodating', 'accommodative', 'active', 'admiring', 'advertent', 'agog', 'agreeable', 'alert', 'all ears', 'all eyes', 'appreciative'],
    'regarding': ['about', 'anent', 'apropos', 'apropos of', 'as for', 'as regards', 'as respects', 'as to', 'concerning', 'in connection with', 'in point of', 'in re'],
    'regardless': ['airy', 'aloof', 'anyhow', 'anyway', 'anywise', 'apathetic', 'at all', 'at all costs', 'at all events', 'at any cost', 'at any rate', 'ataractic'],
    'regatta': ['highland games', 'le mans', 'olympiad', 'olympic games', 'air race', 'automobile race', 'bicycle race', 'boat race', 'carousel', 'contest of speed', 'cross-country race', 'dash'],
    'regency': ['absolute monarchy', 'aedileship', 'agency', 'agentship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'assignment', 'autarchy', 'authority', 'authorization'],
    'regenerate': ['amend', 'born again', 'bring back', 'bring to', 'call back', 'circumcised', 'convert', 'converted', 'copy', 'do over', 'duplicate', 'give salvation'],
    'regeneration': ['fabianism', 'adoption', 'amendment', 'change of allegiance', 'change of heart', 'change of mind', 'circumcision', 'conversion', 'copy', 'duplication', 'extremism', 'gradualism'],
    'regicide': ['aborticide', 'fratricide', 'fungicide', 'genocide', 'germicide', 'herbicide', 'homicide', 'infanticide', 'insecticide', 'matricide', 'microbicide', 'parricide'],
    'regime': ['acid-ash diet', 'administration', 'allergy diet', 'bland diet', 'calorie chart', 'calorie counter', 'civil government', 'curative measures', 'cure', 'diabetic diet', 'diet', 'diet book'],
    'regiment': ['kp', 'age group', 'align', 'allocate', 'allot', 'apportion', 'army', 'army group', 'array', 'band', 'battalion', 'battery'],
    'regimentation': ['spartanism', 'allocation', 'allotment', 'apportionment', 'arrangement', 'array', 'arraying', 'astringency', 'austerity', 'authoritarianism', 'collation', 'collocation'],
    'region': ['kreis', 'abode', 'acres', 'alluvion', 'alluvium', 'ambit', 'arable land', 'archbishopric', 'archdiocese', 'area', 'arrondissement', 'bailiwick'],
    'regional': ['areal', 'cartographic', 'chorographic', 'dialect', 'dialectal', 'geodetic', 'geographic', 'geographical', 'idiomatic', 'local', 'locational', 'navigational'],
    'regional accent': ['acadian', 'anglo-indian', 'brooklynese', 'cajun', 'canadian french', 'cockney', 'french canadian', 'gullah', 'midland', 'midland dialect', 'new england dialect', 'pennsylvania dutch'],
    'register': ['english horn', 'french pitch', 'accord', 'account', 'account book', 'accountant', 'accounts payable ledger', 'accounts receivable ledger', 'act', 'act as foil', 'active list', 'adversaria'],
    'registered': ['booked', 'documented', 'down', 'enrolled', 'entered', 'filed', 'indexed', 'inscribed', 'legal', 'logged', 'minuted', 'of record'],
    'registrar': ['ca', 'cpa', 'accountant', 'accountant general', 'actuary', 'amanuensis', 'archivist', 'auditor', 'bank accountant', 'bank examiner', 'bookkeeper', 'calculator'],
    'registration': ['booking', 'cataloging', 'chronicling', 'enlistment', 'enrollment', 'entering', 'entry', 'filing', 'impanelment', 'indexing', 'inscribing', 'inscription'],
    'registry': ['account', 'account book', 'accounts payable ledger', 'accounts receivable ledger', 'active list', 'adversaria', 'aide-memoire', 'annals', 'annotation', 'archives', 'balance sheet', 'bank ledger'],
    'regnant': ['ascendant', 'at the head', 'average', 'besetting', 'boss', 'chief', 'commanding', 'common', 'controlling', 'current', 'dominant', 'epidemic'],
    'regress': ['about-face', 'advance', 'ascend', 'back', 'back up', 'backing', 'backset', 'backslide', 'backsliding', 'backward motion', 'backward step', 'budge'],
    'regression': ['brownian movement', 'freudian fixation', 'about-face', 'advance', 'angular motion', 'arrested development', 'ascending', 'ascent', 'atavism', 'axial motion', 'backflowing', 'backing'],
    'regressive': ['apostate', 'ascending', 'atavistic', 'axial', 'back', 'back-flowing', 'backsliding', 'backward', 'coming apart', 'cracking', 'crumbling', 'decadent'],
    'regret': ['abject apology', 'acknowledgment', 'affliction', 'anguish', 'apologies', 'apology', 'attrition', 'ayenbite of inwit', 'be sorry for', 'bemoan', 'bewail', 'bitterness'],
    'regretful': ['apologetic', 'ashamed', 'baffled', 'balked', 'betrayed', 'bilked', 'blasted', 'blighted', 'chapfallen', 'conscience-smitten', 'conscience-stricken', 'contrite'],
    'regrettable': ['abominable', 'affecting', 'afflictive', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beneath contempt', 'bitter', 'blameworthy', 'bleak'],
    'regular': ['conservative', 'democrat', 'labourite', 'ok', 'republican', 'tory', 'whig', 'absolute', 'acceptable', 'accepted', 'accordant', 'accustomed'],
    'regularity': ['arrangement', 'array', 'balance', 'bilateral symmetry', 'cadence', 'ceaselessness', 'chattering', 'clockwork regularity', 'concord', 'conformity', 'congruity', 'consistency'],
    'regularize': ['adjust', 'arrange', 'array', 'assimilate to', 'balance', 'chart', 'codify', 'cool off', 'coordinate', 'damp', 'deploy', 'dispose'],
    'regularly': ['always', 'as a rule', 'as per usual', 'as things go', 'as usual', 'at all times', 'at every turn', 'at regular intervals', 'at stated times', 'ceaselessly', 'chiefly', 'chronically'],
    'regulate': ['abate', 'accommodate', 'accord', 'adapt', 'adjust', 'adjust to', 'administer', 'administrate', 'alter', 'arrange', 'array', 'assimilate'],
    'regulation': ['procrustean law', 'accepted', 'accommodation', 'accustomed', 'act', 'adaptation', 'adjustment', 'administration', 'assimilation', 'attunement', 'authoritative', 'authority'],
    'regulatory': ['ascendant', 'at the head', 'boss', 'chief', 'commanding', 'controlling', 'directing', 'directive', 'directorial', 'directory', 'dominant', 'general'],
    'regurgitate': ['barf', 'be seasick', 'be sick', 'bring up', 'chuck up', 'come again', 'copy', 'course', 'disgorge', 'ditto', 'do a repeat', 'do again'],
    'regurgitation': ['charybdis', 'maelstrom', 'back stream', 'backflow', 'backwash', 'backwater', 'barf', 'countercurrent', 'counterflow', 'counterflux', 'disgorgement', 'doubling'],
    'rehabilitate': ['account for', 'change', 'clear', 'cry sour grapes', 'destigmatize', 'do justice to', 'exculpate', 'explain', 'fix up', 'give back', 'justify', 'place in'],
    'rehabilitation': ['about-face', 'adjustive reaction', 'adjustment', 'backing', 'backsliding', 'clearance', 'clearing', 'destigmatization', 'destigmatizing', 'disenchantment', 'exculpation', 'explanation'],
    'rehash': ['battologize', 'copy', 'critique', 'dwelling upon', 'elaboration', 'fill', 'give an encore', 'go over', 'go through', 'going over', 'iterate', 'iteration'],
    'rehearsal': ['gedankenexperiment', 'account', 'accounts', 'apprenticeship', 'audition', 'basic training', 'bench test', 'body count', 'breaking', 'breeding', 'capitulation', 'census'],
    'rehearse': ['add up', 'allegorize', 'announce', 'apprentice', 'battologize', 'break', 'break in', 'break the news', 'breed', 'bring up', 'bring word', 'cast up'],
    'reign': ['administration', 'ascendancy', 'authority', 'averageness', 'be in', 'be in force', 'be the rage', 'be the rule', 'be the thing', 'bear reign', 'call the shots', 'charisma'],
    'reigning': ['ascendant', 'at the head', 'average', 'besetting', 'boss', 'chief', 'commanding', 'common', 'controlling', 'current', 'dominant', 'epidemic'],
    'reimburse': ['atone', 'balance', 'compensate', 'give satisfaction', 'indemnify', 'kick back', 'make amends', 'make good', 'make reparation', 'make restitution', 'make up for', 'make up to'],
    'reimbursement': ['amends', 'atonement', 'compensation', 'indemnification', 'kickback', 'making good', 'paying back', 'recompense', 'recoupment', 'redress', 'refund', 'refundment'],
    'rein': ['administration', 'arrest', 'arrestation', 'backpedal', 'backwater', 'brake', 'bridle', 'check', 'clip the wings', 'collect', 'command', 'constrain'],
    'reincarnate': ['body', 'come again', 'copy', 'corporealize', 'corporify', 'ditto', 'do a repeat', 'do again', 'do over', 'double', 'duplicate', 'echo'],
    'reincarnation': ['avatar', 'catabolism', 'catalysis', 'consubstantiation', 'corporealization', 'displacement', 'doubling', 'duplication', 'echo', 'embodiment', 'heterotopia', 'imitation'],
    'reindeer': ['cape elk', 'siberian husky', 'virginia deer', 'antelope', 'ass', 'beast of burden', 'buck', 'camel', 'camelopard', 'caribou', 'deer', 'deerlet'],
    'reinforce': ['accelerate', 'add to', 'affirm', 'afford support', 'aggravate', 'attest', 'augment', 'authenticate', 'back', 'back up', 'bear', 'bear out'],
    'reinforced': ['accelerated', 'aggrandized', 'amplified', 'augmented', 'backed', 'beefed-up', 'bloated', 'boosted', 'broadened', 'calcified', 'callous', 'calloused'],
    'reinforcement': ['pavlovian conditioning', 'accelerando', 'acceleration', 'accession', 'accessory', 'accompaniment', 'accouterment', 'addenda', 'addendum', 'additament', 'addition', 'additive'],
    'reins': ['oregon boat', 'back band', 'backstrap', 'bearing rein', 'bellyband', 'bilbo', 'bit', 'blinders', 'blinds', 'bond', 'bonds', 'breeching'],
    'reinstate': ['account for', 'clear', 'cry sour grapes', 'destigmatize', 'do justice to', 'exculpate', 'explain', 'give back', 'justify', 'place in', 'purge', 'put back'],
    'reinstatement': ['about-face', 'backing', 'backsliding', 'clearance', 'clearing', 'destigmatization', 'destigmatizing', 'disenchantment', 'exculpation', 'explanation', 'flip-flop', 'improvement'],
    'reinstitute': ['copy', 'do over', 'duplicate', 'give back', 'make over', 'place in', 'put back', 're-create', 're-form', 'reactivate', 'rebuild', 'reconstitute'],
    'reissue': ['battologize', 'bring out', 'circulate', 'copy', 'critique', 'demonetize', 'devaluate', 'devalue', 'do over', 'duplicate', 'duplication', 'dwelling upon'],
    'reiterate': ['battologize', 'doubled', 'duplicated', 'dwell on', 'echoed', 'fill', 'give an encore', 'go over', 'go through', 'harp on', 'ingeminate', 'iterate'],
    'reiteration': ['abundance', 'amplitude', 'banality', 'bromide', 'chestnut', 'cliche', 'cloud of words', 'commonplace', 'commonplace expression', 'conduplication', 'copiousness', 'copy'],
    'reiterative': ['abundant', 'battological', 'copious', 'diffuse', 'diffusive', 'duplicative', 'echoic', 'echoing', 'effusive', 'extravagant', 'exuberant', 'fecund'],
    'reject': ['abandon', 'abjure', 'ban', 'bar', 'bar out', 'barf', 'be contrary to', 'be seasick', 'be sick', 'be skeptical', 'be unmoved', 'be unwilling'],
    'rejected': ['abandoned', 'belied', 'cast-off', 'castaway', 'confounded', 'confuted', 'contemned', 'declined', 'declined with thanks', 'deflated', 'denied', 'derelict'],
    'rejection': ['eighteenth amendment', 'prohibition party', 'volstead act', 'abnegation', 'agnosticism', 'agreement to disagree', 'alienation', 'apostasy', 'atheism', 'ban', 'bar', 'barring'],
    'rejoice': ['adore', 'animate', 'appreciate', 'bask in', 'be pleased with', 'boost', 'brighten', 'buoy up', 'caper', 'caracole', 'carol', 'celebrate'],
    'rejoicing': ['anniversaries', 'buxom', 'celebrating', 'celebration', 'ceremony', 'commemoration', 'delighting', 'dressing ship', 'elate', 'elated', 'exultant', 'exulting'],
    'rejoin': ['acknowledge', 'answer', 'answer back', 'come back', 'come back at', 'come in', 'confute', 'countercharge', 'counterclaim', 'echo', 'flash back', 'give acknowledgment'],
    'rejoinder': ['acknowledgment', 'answer', 'answering', 'antiphon', 'back answer', 'back talk', 'backchat', 'comeback', 'confutation', 'contraremonstrance', 'counteraccusation', 'counterblast'],
    'rejuvenate': ['bring back', 'bring to', 'call back', 'modernize', 'reanimate', 'recall to life', 'recharge', 'reclaim', 'recondition', 'reconstruct', 'recover', 'recruit'],
    'rejuvenation': ['new birth', 'palingenesis', 'palingenesy', 'reanimation', 'rebirth', 'recrudescence', 'refreshment', 'regeneracy', 'regenerateness', 'regeneration', 'regenesis', 'rejuvenescence'],
    'rekindle': ['bank', 'bring back', 'bring to', 'burn', 'call back', 'conflagrate', 'enkindle', 'fan the flame', 'feed', 'feed the fire', 'fire', 'ignite'],
    'relapse': ['about-face', 'apostasy', 'backing', 'backset', 'backslide', 'backsliding', 'backward motion', 'backward step', 'cock', 'decline', 'degenerate', 'degeneration'],
    'relate': ['add up', 'affect', 'affirm', 'allege', 'allegorize', 'ally', 'analogize', 'announce', 'answer', 'answer to', 'appertain', 'appertain to'],
    'related': ['affiliate', 'affiliated', 'affinal', 'agnate', 'akin', 'allied', 'associate', 'associated', 'avuncular', 'bound', 'bracketed', 'closely related'],
    'relation': ['about', 'absorption', 'affective meaning', 'affiliation', 'agnation', 'allegory', 'alliance', 'analogy', 'ancestry', 'anent', 'apropos', 'association'],
    'relations': ['accord', 'act of love', 'addition', 'adjunct', 'adultery', 'affairs', 'affiliation', 'affinity', 'agnate', 'alliance', 'ancestry', 'aphrodisia'],
    'relationship': ['accord', 'addition', 'adjunct', 'affairs', 'affiliation', 'affinity', 'agnation', 'alliance', 'ancestry', 'approximation', 'assemblage', 'association'],
    'relative': ['affiliated', 'affinitive', 'agnate', 'allied', 'analogical', 'analogous', 'ancestry', 'appertaining', 'applicable', 'approximate', 'apropos', 'associated'],
    'relatively': ['after a fashion', 'appositely', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst', 'comparably'],
    'relativity': ['einstein theory', 'balance', 'coequality', 'communion', 'community', 'contingency', 'continuum theory', 'corelation', 'correlation', 'correlativism', 'correlativity', 'correspondence'],
    'relator': ['anecdotist', 'fableist', 'fabler', 'fabulist', 'fictionist', 'mythmaker', 'mythopoet', 'narrator', 'novelettist', 'novelist', 'raconteur', 'reciter'],
    'relax': ['abate', 'admit', 'admit exceptions', 'allow', 'allow for', 'amuse', 'arrest', 'backpedal', 'backwater', 'bate', 'be at ease', 'be easy'],
    'relaxation': ['abatement', 'abridgment', 'allayment', 'alleviation', 'amusement', 'assuagement', 'attenuation', 'attrition', 'bagginess', 'blunting', 'calming', 'carelessness'],
    'relaxed': ['bohemian', 'affable', 'ambling', 'at ease', 'at home', 'at rest', 'bagging', 'baggy', 'blank', 'blankminded', 'blase', 'breezy'],
    'relaxing': ['abating', 'allaying', 'alleviating', 'assuaging', 'blunting', 'chastening', 'comfortable', 'comfy', 'commodious', 'contented', 'convenient', 'cozy'],
    'relay': ['le mans', 'adder', 'air race', 'alternator', 'analytical control unit', 'analyzer', 'anchor watch', 'anode', 'armature', 'assign', 'autoconverter', 'automobile race'],
    'relay station': ['am station', 'comsat', 'fm station', 'intelsat', 'rdf station', 'syncom', 'telstar', 'booster amplifiers', 'boosters', 'clear-channel station', 'communication satellite', 'direction-finder station'],
    'release': ['ok', 'abandonment', 'abjuration', 'absolution', 'absolve', 'accord', 'account', 'acknowledgment', 'acquaintance', 'acquit', 'acquittal', 'acquittance'],
    'released': ['abandoned', 'abjured', 'afoot and lighthearted', 'asleep', 'asleep in jesus', 'at large', 'at liberty', 'at rest', 'bereft of life', 'breathless', 'called home', 'carrion'],
    'relegate': ['accredit', 'assign', 'ban', 'banish', 'bar', 'bar out', 'blackball', 'blockade', 'cast out', 'charge', 'commend', 'commit'],
    'relent': ['accede', 'accept', 'acquiesce', 'assent', 'be agreeable', 'be conservative', 'be moderate', 'be pacifistic', 'bend', 'capitulate', 'come round', 'comply'],
    'relentless': ['adamant', 'adamantine', 'ardent', 'assiduous', 'bound', 'bound and determined', 'bowelless', 'cast-iron', 'ceaseless', 'certain', 'committed', 'constant'],
    'relentlessness': ['act of god', 'adamantness', 'application', 'ardor', 'assiduity', 'assiduousness', 'bulldog tenacity', 'certainty', 'commitment', 'concentration', 'constancy', 'cruelty'],
    'relevance': ['account', 'admissibility', 'advantage', 'affective meaning', 'affinity', 'applicability', 'application', 'appositeness', 'appropriateness', 'aptitude', 'aptness', 'bearing'],
    'relevant': ['a propos', 'ad rem', 'adapted', 'admissible', 'akin', 'allied', 'allowable', 'appertaining', 'applicable', 'applying', 'apposite', 'appropriate'],
    'reliability': ['acceptability', 'aplomb', 'authenticity', 'authoritativeness', 'balance', 'balanced personality', 'believability', 'believableness', 'calculability', 'conceivability', 'constancy', 'cool'],
    'reliable': ['absolute', 'accurate', 'adducible', 'admissible', 'apposite', 'attestative', 'attested', 'attestive', 'authentic', 'authenticated', 'balanced', 'based on'],
    'reliance': ['maecenas', 'abettor', 'acceptation', 'acception', 'acquiescence', 'admirer', 'advocate', 'aficionado', 'aid', 'angel', 'anticipation', 'apologist'],
    'relic': ['agnus dei', 'holy grail', 'host', 'methuselah', 'pieta', 'sanctus bell', 'sangraal', 'account', 'ancient manuscript', 'annals', 'antediluvian', 'antique'],
    'relics': ['afterglow', 'afterimage', 'ashes', 'balance', 'body', 'bones', 'butt', 'butt end', 'cadaver', 'candle ends', 'carcass', 'carrion'],
    'relief': ['adc', 'cysp sculpture', 'medicaid', 'medicare', 'abatement', 'agent', 'aid', 'aid and comfort', 'alimony', 'allayment', 'alleviation', 'allotment'],
    'relieve': ['abate', 'abet', 'abridge', 'absolve', 'act for', 'aid', 'allay', 'alleviate', 'alternate', 'anesthetize', 'appease', 'assist'],
    'religion': ['babi', 'babism', 'bahaism', 'brahmanism', 'brahmoism', 'buddhism', 'buddhology', 'chen yen buddhism', 'christianity', 'mariolatry', 'mariology', 'mercersburg theology'],
    'religionist': ['brahman', 'buddhist', 'christian', 'god-fearing man', 'holy willie', 'joseph surface', 'mawworm', 'pecksniff', 'pharisee', 'tartuffe', 'accepter', 'affecter'],
    'religious': ['christian', 'christianlike', 'christianly', 'god-fearing', 'mariological', 'abbacomes', 'abbot', 'accurate', 'adoring', 'anthropomorphic', 'anthropotheistic', 'ascetic'],
    'relinquish': ['abandon', 'abdicate', 'abjure', 'abnegate', 'abort', 'acknowledge defeat', 'be pensioned', 'be superannuated', 'beg a truce', 'belay', 'cancel', 'capitulate'],
    'relinquished': ['abandoned', 'abjured', 'antiquated', 'antique', 'archaic', 'ceded', 'deserted', 'discontinued', 'dispensed with', 'disposed of', 'disused', 'done with'],
    'relinquishment': ['abandonment', 'abdication', 'abeyance', 'abjuration', 'abjurement', 'breakoff', 'capitulation', 'cease', 'ceasing', 'cessation', 'cession', 'close'],
    'reliquary': ['arch', 'barrow', 'beehive tomb', 'bone house', 'boundary stone', 'box grave', 'brass', 'burial', 'burial chamber', 'burial mound', 'bust', 'cairn'],
    'relish': ['adore', 'affection', 'aftertaste', 'amusement', 'animal pleasure', 'anticipate', 'anticipation', 'appetite', 'appreciate', 'appreciation', 'ardency', 'ardor'],
    'relocate': ['anchor', 'billet at', 'bivouac', 'burrow', 'camp', 'carry away', 'carry off', 'cart away', 'colonize', 'come to anchor', 'delocalize', 'dislodge'],
    'reluct': ['antagonize', 'arise', 'battle', 'beat against', 'beat up against', 'breast the wave', 'buck', 'buffet', 'buffet the waves', 'challenge', 'close with', 'combat'],
    'reluctance': ['antipathy', 'averseness', 'aversion', 'backwardness', 'capacitive reactance', 'cautiousness', 'challenge', 'circumspection', 'combative reaction', 'complaint', 'counteraction', 'creeping'],
    'reluctant': ['afraid', 'ambling', 'antagonistic', 'apathetic', 'averse', 'backward', 'balking', 'balky', 'calculating', 'careful', 'cautious', 'chary'],
    'reluctantly': ['cautiously', 'circumspectly', 'crawlingly', 'creepingly', 'deliberately', 'dilatorily', 'easily', 'falteringly', 'gently', 'grudgingly', 'haltingly', 'idly'],
    'rely': ['await', 'bank', 'bank on', 'bet on', 'build on', 'calculate', 'commit', 'confide', 'count on', 'depend', 'depend on', 'entrust'],
    'rely on': ['abut on', 'aspire to', 'bank on', 'be based on', 'bear on', 'bestraddle', 'bestride', 'bet on', 'calculate on', 'confide', 'confide in', 'count on'],
    'remain': ['abide', 'balance', 'be found', 'be left', 'be located', 'be met with', 'be present', 'be situated', 'be still', 'be there', 'berth', 'bide'],
    'remainder': ['adjunct', 'afterlife', 'balance', 'bonus', 'component', 'contingent', 'copyhold', 'credit', 'cross section', 'deficit', 'detachment', 'detail'],
    'remaining': ['abiding', 'age-long', 'aged', 'ancient', 'antique', 'as a bonus', 'changeless', 'chronic', 'commorant', 'constant', 'continuing', 'continuous'],
    'remains': ['account', 'afterglow', 'afterimage', 'ancient manuscript', 'annals', 'antique', 'antiquity', 'archaism', 'artifact', 'ashes', 'balance', 'body'],
    'remake': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'better', 'break up', 'change', 'convert', 'copy', 'deform', 'denature'],
    'remaking': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'alteration', 'amelioration', 'apostasy', 'betterment', 'break', 'change', 'change of heart', 'changeableness'],
    'remand': ['assign', 'bring back', 'commend', 'commit', 'commit to prison', 'commitment', 'committal', 'confide', 'consign', 'consignment', 'delegate', 'enfeoff'],
    'remark': ['parthian shot', 'address', 'advertence', 'advertency', 'affirmation', 'alertness', 'allegation', 'allude to', 'analysis', 'animadvert', 'annotation', 'answer'],
    'remarkable': ['appalling', 'arresting', 'astonishing', 'astounding', 'beguiling', 'bewildering', 'celebrated', 'conspicuous', 'curious', 'different', 'distinguished', 'egregious'],
    'remarkably': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'awfully', 'beguilingly', 'bewilderingly', 'consequentially', 'conspicuously', 'copiously'],
    'remedial': ['adjuvant', 'aidful', 'alleviating', 'alleviative', 'alterative', 'analeptic', 'analgesic', 'anesthetic', 'anodyne', 'assuasive', 'balmy', 'balsamic'],
    'remedy': ['abatement', 'abet', 'aid', 'allayment', 'alleviate', 'alleviation', 'ameliorate', 'amend', 'amends', 'analgesia', 'anesthesia', 'anesthetizing'],
    'remember': ['bear in mind', 'bring back', 'bring to mind', 'bring to recollection', 'call back', 'call to mind', 'call up', 'carry back', 'cite', 'commemorate', 'conjure up', 'educe'],
    'rememberable': ['celebrated', 'conspicuous', 'distinguished', 'eminent', 'esteemed', 'estimable', 'exceptional', 'extraordinary', 'marked', 'memorable', 'noble', 'notable'],
    'remembered': ['alive', 'eidetic', 'enduring', 'fresh', 'green', 'kept in remembrance', 'lasting', 'recalled', 'recollected', 'reexperienced', 'relived', 'reminiscent'],
    'remembrance': ['mnemosyne', 'affect memory', 'aide-memoire', 'anamnesis', 'anniversaries', 'anterograde memory', 'arch', 'atavism', 'barrow', 'best love', 'best regards', 'best wishes'],
    'remind': ['admonish', 'advise', 'bring to recollection', 'carry back', 'cite', 'cue', 'give a hint', 'give the cue', 'hint', 'hold the promptbook', 'imply', 'intimate'],
    'reminder': ['admonition', 'adversaria', 'aide-memoire', 'annotation', 'cue', 'docket', 'entry', 'flapper', 'footnote', 'gesture', 'hint', 'indication'],
    'reminiscence': ['anamnesis', 'anecdotes', 'commitment to memory', 'exercise of memory', 'flashback', 'hindsight', 'learning by heart', 'looking back', 'memoir', 'memoirs', 'memories', 'memorization'],
    'reminiscent': ['evocative', 'in retrospect', 'memoried', 'mindful', 'mnemonic', 'recalling', 'recollected', 'redolent', 'reexperienced', 'relived', 'remembered', 'remindful'],
    'remiss': ['micawberish', 'backward', 'behindhand', 'bone-lazy', 'cadging', 'careless', 'culpably negligent', 'dallying', 'delaying', 'delinquent', 'derelict', 'dilatory'],
    'remissible': ['admissible', 'allowable', 'condonable', 'defensible', 'dispensable', 'excusable', 'exemptible', 'expiable', 'forgivable', 'inoffensive', 'justifiable', 'legitimate'],
    'remission': ['abatement', 'abeyance', 'absolution', 'acquittal', 'acquittance', 'allayment', 'alleviation', 'amnesty', 'assuagement', 'attrition', 'blunting', 'break'],
    'remit': ['abate', 'absolve', 'acquit', 'address', 'air-express', 'airfreight', 'airmail', 'alleviate', 'amnesty', 'assign', 'assuage', 'attenuate'],
    'remittance': ['acquitment', 'acquittal', 'acquittance', 'allowance', 'amortization', 'amortizement', 'binder', 'cash', 'cash payment', 'clearance', 'consideration', 'debt service'],
    'remitted': ['absolved', 'acquitted', 'blotted', 'canceled', 'condoned', 'discharged', 'disregarded', 'exculpated', 'excused', 'exonerated', 'expended', 'forgiven'],
    'remittent': ['calenture', 'childbed fever', 'continued fever', 'delirium', 'eruptive fever', 'febricity', 'febrility', 'fever', 'fever heat', 'feverishness', 'fire', 'flush'],
    'remnant': ['afterglow', 'afterimage', 'balance', 'bit', 'butt', 'butt end', 'candle ends', 'chaff', 'debris', 'detritus', 'end', 'fag end'],
    'remodel': ['amend', 'new-model', 're-create', 're-form', 'reassemble', 'rebuild', 'reclaim', 'reconstruct', 'redeem', 'refabricate', 'refashion', 'reform'],
    'remonstrance': ['admonition', 'advice', 'advising', 'advocacy', 'beef', 'bitch', 'boycott', 'briefing', 'caution', 'cautioning', 'caveat', 'challenge'],
    'remonstrate': ['admonish', 'beef', 'bitch', 'boggle', 'boycott', 'call in question', 'caution', 'challenge', 'charge', 'combat', 'complain', 'complain loudly'],
    'remonstrative': ['admonitory', 'advisory', 'cautionary', 'consultative', 'consultatory', 'didactic', 'directive', 'exhortative', 'exhortatory', 'expostulative', 'expostulatory', 'hortative'],
    'remorse': ['anxiety', 'apologies', 'attrition', 'ayenbite of inwit', 'bitterness', 'compunction', 'contriteness', 'contrition', 'embarrassment', 'grief', 'guilt', 'guilty conscience'],
    'remorseful': ['anxious', 'apologetic', 'ashamed', 'bad', 'bitter', 'compunctious', 'conscience-smitten', 'conscience-stricken', 'contrite', 'embarrassed', 'full of remorse', 'guilty'],
    'remorseless': ['bowelless', 'callous', 'cruel', 'dog-eat-dog', 'flinty', 'griefless', 'hard', 'harsh', 'heartless', 'impenitent', 'implacable', 'inclement'],
    'remote': ['olympian', 'above all that', 'abstracted', 'acquisitive', 'alien', 'aloof', 'ambitious for self', 'ancient', 'apart', 'arcane', 'asunder', 'at a distance'],
    'removable': ['assignable', 'communicable', 'conductive', 'consignable', 'contagious', 'conveyable', 'expressable', 'impartable', 'interchangeable', 'mailable', 'metathetic', 'movable'],
    'removal': ['doppler effect', 'abandonment', 'ablation', 'abrasion', 'abstraction', 'alienation', 'amotion', 'amputation', 'anastomotic operation', 'assassination', 'avulsion', 'baring'],
    'remove': ['abandon', 'abate', 'abrade', 'abscond', 'abstract', 'amount', 'annihilate', 'assassinate', 'avulse', 'bare', 'bate', 'beat a retreat'],
    'removed': ['olympian', 'alien', 'alienated', 'alone', 'aloof', 'apart', 'asunder', 'at a distance', 'away', 'backward', 'bashful', 'blank'],
    'remunerate': ['accord', 'amend', 'award', 'compensate', 'correct', 'emend', 'fee', 'give satisfaction', 'grant', 'guerdon', 'indemnify', 'make all square'],
    'remuneration': ['amends', 'atonement', 'base pay', 'blood money', 'compensation', 'consideration', 'damages', 'dismissal wage', 'earnings', 'emolument', 'escalator clause', 'escalator plan'],
    'remunerative': ['advantageous', 'banausic', 'breadwinning', 'compensating', 'compensative', 'compensatory', 'fat', 'gainful', 'good', 'lucrative', 'moneymaking', 'of value'],
    'renaissance': ['new birth', 'palingenesis', 'palingenesy', 'reanimation', 'rebirth', 'recrudescence', 'refreshment', 'regeneracy', 'regenerateness', 'regeneration', 'regenesis', 'rejuvenation'],
    'renascence': ['amendment', 'change of allegiance', 'change of heart', 'change of mind', 'copy', 'duplication', 'imitation', 'improvement', 'new birth', 'palingenesis', 'palingenesy', 're-creation'],
    'rencontre': ['olympic games', 'olympics', 'bout', 'collision course', 'competition', 'concours', 'conflict', 'confrontation', 'contest', 'derby', 'encounter', 'engagement'],
    'rend': ['abrade', 'afflict', 'amputate', 'atomize', 'ax', 'badger', 'bark', 'bisect', 'blackmail', 'blemish', 'bloody', 'break'],
    'render': ['english', 'abandon', 'abide by', 'abjure', 'accompany', 'accomplish', 'accord', 'achieve', 'adhere to', 'administer', 'administrate', 'afford'],
    'rendering': ['alphabet', 'art', 'blueprint', 'cameo', 'cantando', 'catalog', 'cataloging', 'character', 'character sketch', 'charactering', 'characterization', 'chart'],
    'rendezvous': ['appointment', 'assemble', 'assemblee', 'assembly', 'assignation', 'assignation house', 'at home', 'ball', 'brawl', 'bunch', 'bunch up', 'caucus'],
    'rendition': ['alphabet', 'art', 'blueprint', 'cameo', 'cantando', 'catalog', 'cataloging', 'character', 'character sketch', 'charactering', 'characterization', 'chart'],
    'renegade': ['sabbath-breaker', 'apostate', 'apostatize', 'atheist', 'atheistic', 'backslider', 'backsliding', 'blasphemer', 'blasphemous', 'bolter', 'collaborationist', 'collaborative'],
    'renege': ['abandon', 'abjure', 'abolish', 'abrogate', 'annul', 'apostatize', 'back down', 'back out', 'backpedal', 'backwater', 'beg off', 'cancel'],
    'renew': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'amend', 'animate', 'begin again', 'better', 'brace', 'brace up', 'break up'],
    'renewal': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'alteration', 'amelioration', 'amendment', 'another shot', 'another try', 'apostasy', 'atavism', 'backset'],
    'renewed': ['additional', 'altered', 'animated', 'another', 'assimilated', 'better', 'born again', 'changeable', 'changed', 'circumcised', 'converted', 'degenerate'],
    'renitency': ['antagonism', 'antipathy', 'averseness', 'aversion', 'backlash', 'backwardness', 'challenge', 'clashing', 'collision', 'combative reaction', 'complaint', 'conflict'],
    'renitent': ['antagonistic', 'antipathetic', 'apathetic', 'backward', 'balking', 'balky', 'breakaway', 'clashing', 'complaining', 'conflicting', 'contradicting', 'contradictory'],
    'renounce': ['abandon', 'abdicate', 'abjure', 'abort', 'abstain from', 'acknowledge defeat', 'assert the contrary', 'avoid', 'back down', 'back out', 'backwater', 'beg a truce'],
    'renounced': ['abandoned', 'abjured', 'antiquated', 'antique', 'archaic', 'ceded', 'contemned', 'declined', 'declined with thanks', 'denied', 'deserted', 'despised'],
    'renovate': ['brighten up', 'brush up', 'clean', 'cleanse', 'coin', 'copy', 'do over', 'do up', 'duplicate', 'face-lift', 'fix', 'fix up'],
    'renovation': ['copy', 'duplication', 'face-lift', 'furbishment', 'imitation', 'palingenesis', 're-creation', 're-formation', 'rebirth', 'rebuilding', 'reconditioning', 'reconstitution'],
    'renown': ['acclaim', 'celebrity', 'character', 'consequence', 'dignity', 'distinction', 'eclat', 'eminence', 'esteem', 'fame', 'famousness', 'figure'],
    'renowned': ['acclaimed', 'august', 'celebrated', 'distinguished', 'elevated', 'eminent', 'exalted', 'fabled', 'famed', 'famous', 'far-famed', 'far-heard'],
    'rent': ['abrasion', 'abysm', 'abyss', 'aggravated', 'arroyo', 'bareboat charter', 'blemish', 'box canyon', 'breach', 'break', 'breakage', 'broach'],
    'rental': ['bareboat charter', 'chambers', 'charter', 'flat', 'hire', 'hiring', 'lease', 'lend-lease', 'let', 'lodgings', 'quitrent', 'rack rent'],
    'renter': ['board-and-roomer', 'boarder', 'hirer', 'homesteader', 'incumbent', 'leaseholder', 'lessee', 'lodger', 'occupant', 'occupier', 'paying guest', 'resident'],
    'renunciation': ['abandonment', 'abdication', 'abeyance', 'abjuration', 'abjurement', 'abnegation', 'abrogation', 'absolute contradiction', 'annulment', 'apostasy', 'breakoff', 'capitulation'],
    'renunciative': ['abjuratory', 'abnegative', 'adversative', 'breakaway', 'contemptuous', 'contradicting', 'contradictory', 'contrary', 'declinatory', 'denying', 'despising', 'disaffirming'],
    'reoccurrence': ['alternation', 'beat', 'cyclicalness', 'doubling', 'duplication', 'echo', 'imitation', 'intermittence', 'intermittency', 'meter', 'oscillation', 'pendulum motion'],
    'reorganization': ['copy', 'duplication', 'imitation', 'overturn', 'palingenesis', 're-creation', 're-formation', 'realignment', 'rearrangement', 'rebirth', 'rebuilding', 'reconstitution'],
    'reorganize': ['copy', 'do over', 'duplicate', 'make over', 're-create', 're-form', 'readjust', 'realign', 'rearrange', 'rebuild', 'reconstitute', 'reconstruct'],
    'repair': ['adjust', 'adjustment', 'amends', 'apply', 'atone', 'atone for', 'bad condition', 'brighten up', 'brush up', 'case', 'cobble', 'commission'],
    'reparable': ['ameliorable', 'amendable', 'correctable', 'corrigible', 'curable', 'emendable', 'fixable', 'improvable', 'medicable', 'mendable', 'reclaimable', 'recoverable'],
    'reparation': ['adjustment', 'amends', 'atonement', 'balancing', 'blood money', 'commutation', 'compensation', 'composition', 'compromise', 'consideration', 'correction', 'counteraction'],
    'reparative': ['amendatory', 'analeptic', 'apologetic', 'ascetic', 'atoning', 'balancing', 'cleansing', 'compensating', 'compensational', 'compensative', 'compensatory', 'counteracting'],
    'repartee': ['acknowledgment', 'answer', 'answering', 'antiphon', 'aphorism', 'apothegm', 'back answer', 'back talk', 'backchat', 'badinage', 'banter', 'bon mot'],
    'repay': ['accord', 'atone', 'award', 'balance', 'be gainful', 'be profitable', 'be worthwhile', 'compensate', 'cover', 'do penance', 'expiate', 'fill up'],
    'repayment': ['amends', 'atonement', 'balancing', 'commutation', 'compensation', 'counteraction', 'counterbalancing', 'expiation', 'indemnification', 'indemnity', 'kickback', 'lex talionis'],
    'repeal': ['abolish', 'abolition', 'abrogate', 'abrogation', 'annihilate', 'annul', 'annulment', 'bring to naught', 'cancel', 'cancellation', 'countermand', 'counterorder'],
    'repeat': ['act like', 'affect', 'alternate', 'assume', 'be here again', 'bis', 'bob', 'borrow', 'burden', 'chant', 'chime', 'chorus'],
    'repeated': ['ceaseless', 'chattering', 'constant', 'continual', 'doubled', 'duplicated', 'echoed', 'incessant', 'machine gun', 'oscillating', 'perennial', 'perpetual'],
    'repeatedly': ['again and again', 'commonly', 'day after day', 'day by day', 'frequently', 'habitually', 'in many instances', 'many a time', 'many times', 'many times over', 'most often', 'much'],
    'repeater': ['automatic', 'backslider', 'ballot-box stuffer', 'balloter', 'blowgun', 'blowpipe', 'elector', 'firearm', 'flamethrower', 'floater', 'fraudulent voter', 'gat'],
    'repel': ['abjure', 'anticipate', 'appall', 'avert', 'bar', 'be proof against', 'bear up', 'bear up against', 'beat back', 'beat off', 'block', 'blunt'],
    'repellent': ['abhorrent', 'abominable', 'base', 'beastly', 'below contempt', 'beneath contempt', 'complaining', 'contemptible', 'crude', 'despicable', 'detestable', 'diamagnetic'],
    'repelling': ['antigravity', 'awful', 'centrifugal force', 'diamagnetic', 'diamagnetism', 'disaffinity', 'dreadful', 'forbidding', 'foul', 'frightful', 'ghastly', 'grisly'],
    'repentance': ['day of atonement', 'yom kippur', 'abject apology', 'apology', 'asceticism', 'attrition', 'change of heart', 'cold purgatorial fires', 'compunction', 'contriteness', 'contrition', 'deathbed repentance'],
    'repentant': ['abject', 'apologetic', 'ascetic', 'ashamed', 'atoning', 'cleansing', 'compensational', 'compensatory', 'compunctious', 'contrite', 'embarrassed', 'expiatory'],
    'repercussion': ['aftermath', 'antagonism', 'antipathy', 'backfire', 'backlash', 'backlashing', 'backwash', 'boomerang', 'bounce', 'bound', 'cantando', 'carom'],
    'repercussive': ['booming', 'bouncing', 'bounding', 'echoic', 'echoing', 'growling', 'lingering', 'persistent', 'reboant', 'rebounding', 'recalcitrant', 'recoiling'],
    'repertory': ['abundance', 'account', 'accounts', 'accumulation', 'active list', 'amassment', 'archives', 'armory', 'arsenal', 'attic', 'backlog', 'bank'],
    'repetition': ['ceaselessness', 'chattering', 'clockwork regularity', 'clone', 'conduplication', 'constancy', 'constant flow', 'continualness', 'continuance', 'continuation', 'continuity', 'copy'],
    'repetitious': ['battological', 'boring', 'duplicative', 'echoic', 'echoing', 'imitative', 'iterative', 'long-winded', 'parrotlike', 'pleonastic', 'prolix', 'recapitulative'],
    'repetitive': ['abundant', 'articulated', 'automatic', 'battological', 'beaten', 'boring', 'catenated', 'ceaseless', 'concatenated', 'connected', 'constant', 'continual'],
    'repine': ['be sorry for', 'bemoan', 'bewail', 'deplore', 'dirge', 'elegize', 'fuss', 'give sorrow words', 'grieve', 'keen', 'kick', 'knell'],
    'replace': ['act for', 'alter', 'attend', 'boot', 'bounce', 'break', 'bump', 'bust', 'can', 'cashier', 'change', 'change places with'],
    'replacement': ['agency', 'agent', 'alternate', 'alternative', 'analogy', 'backup', 'backup man', 'change', 'changeling', 'commutation', 'comparison', 'copy'],
    'replenish': ['accommodate', 'accomplish', 'afford', 'bring to completion', 'bring to fruition', 'clothe', 'complete', 'contribute', 'donate', 'eke out', 'endow', 'fill'],
    'replete': ['sro', 'abounding', 'abundant', 'affluent', 'all-sufficing', 'allayed', 'ample', 'aplenty', 'awash', 'bottomless', 'bounteous', 'bountiful'],
    'repletion': ['abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bellyful', 'bonanza', 'bountifulness', 'bountiousness', 'bumper crop', 'congestion'],
    'replevin': ['annex', 'attach', 'bail', 'bond', 'collectivize', 'commandeer', 'communalize', 'communize', 'confiscate', 'distrain', 'earnest', 'earnest money'],
    'replica': ['doppelganger', 'actual thing', 'burlesque', 'carbon copy', 'clone', 'copy', 'counterpart', 'dead ringer', 'ditto', 'double', 'dummy', 'dupe'],
    'replicate': ['photostat', 'xerox', 'clone', 'copy', 'ditto', 'double', 'dupe', 'duplicate', 'facsimile', 'geminate', 'hectograph', 'imitate'],
    'replication': ['altmann theory', 'dna', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'rna', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory', 'acknowledgment'],
    'reply': ['esp', 'acknowledge', 'acknowledgment', 'action and reaction', 'advocate', 'allege in support', 'answer', 'answer back', 'answering', 'antiphon', 'approach', 'argue for'],
    'report': ['agnus dei', 'benedicite', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'nunc dimittis', 'pr', 'te deum', 'trisagion'],
    'reportage': ['advice', 'broadcast journalism', 'information', 'intelligence', 'journalism', 'news', 'news agency', 'news medium', 'news service', 'newsiness', 'newsletter', 'newsmagazine'],
    'reported': ['accessible', 'affirmed', 'afloat', 'announced', 'bandied about', 'broadcast', 'brought to notice', 'bruited about', 'circulated', 'common knowledge', 'common property', 'current'],
    'reporter': ['a tale-bearing animal', 'adviser', 'anchorman', 'announcer', 'annunciator', 'authority', 'broadcaster', 'busybody', 'cameraman', 'channel', 'city editor', 'columnist'],
    'repose': ['abide', 'abide in', 'abnegation', 'abstinence', 'accubation', 'accumbency', 'ataraxia', 'ataraxy', 'be', 'be coextensive with', 'be comprised in', 'be constituted by'],
    'reposeful': ['at rest', 'calm', 'cloistered', 'comfortable', 'comfy', 'commodious', 'contented', 'convenient', 'cool', 'cozy', 'cushioned', 'cushiony'],
    'reposing': ['accumbent', 'asleep', 'asleep in jesus', 'at rest', 'bereft of life', 'breathless', 'called home', 'calm', 'carrion', 'cloistered', 'cool', 'couchant'],
    'reposit': ['bank', 'bundle away', 'cache', 'coffer', 'deposit', 'file', 'hutch', 'lay', 'lay away', 'lay down', 'lay in', 'lay in store'],
    'repository': ['fort knox', 'acquaintance', 'advocate', 'alter ego', 'archives', 'armory', 'arsenal', 'attic', 'backer', 'bank', 'basement', 'bay'],
    'repossess': ['get back', 'ransom', 'recapture', 'reclaim', 'recoup', 'recover', 'recruit', 'recuperate', 'redeem', 'regain', 'renovate', 'reoccupy'],
    'repossession': ['disendowment', 'disherison', 'disinheritance', 'disownment', 'dispossession', 'disseisin', 'eviction', 'expropriation', 'foreclosure', 'ransom', 'recapture', 'reclaiming'],
    'reprehend': ['accuse', 'admonish', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'berate', 'blame', 'bring to book', 'call to account', 'cast blame upon', 'cast reflection upon'],
    'reprehensible': ['abominable', 'accusable', 'amiss', 'arraignable', 'arrant', 'at fault', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beneath contempt'],
    'reprehension': ['admonishment', 'admonition', 'anathema', 'arraignment', 'blame', 'castigation', 'censure', 'chastisement', 'chiding', 'condemnation', 'correction', 'damnation'],
    'represent': ['act a part', 'act between', 'act for', 'act out', 'affect', 'answer for', 'appear for', 'arbitrate', 'assert', 'back up', 'bargain', 'betoken'],
    'representation': ['australian ballot', 'hare system', 'abstract', 'abstraction', 'account', 'acting', 'affectation', 'agency', 'altarpiece', 'appearance', 'apprehension', 'assertion'],
    'representative': ['mp', 'member of congress', 'member of parliament', 'acting', 'advocate', 'agent', 'alderman', 'alter ego', 'alternate', 'alternative', 'ambassador', 'amicus curiae'],
    'repress': ['arrest', 'asphyxiate', 'ban', 'bar', 'bate', 'beat down', 'black out', 'blunt', 'bottle up', 'break', 'browbeat', 'bulldoze'],
    'repressed': ['lethean', 'olympian', 'absentminded', 'aloof', 'amnestic', 'backward', 'bashful', 'blank', 'blocked', 'chilled', 'chilly', 'cold'],
    'repression': ['eighteenth amendment', 'prohibition party', 'volstead act', 'aloofness', 'arrest', 'arrestation', 'arrestment', 'backwardness', 'bamboo curtain', 'ban', 'barrier of secrecy', 'bashfulness'],
    'repressive': ['absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'authoritarian', 'authoritative', 'autocratic', 'bossy', 'brutal', 'choking'],
    'reprieve': ['absolution', 'afterthought', 'amnesty', 'benevolence', 'bind', 'block', 'blockage', 'bureaucratic delay', 'catharsis', 'cleanse', 'cleanse away', 'cleansing'],
    'reprimand': ['admonish', 'admonishment', 'admonition', 'aspersion', 'attack', 'attaint', 'badge of infamy', 'bar sinister', 'baton', 'bawl out', 'bend sinister', 'berate'],
    'reprint': ['ditto copy', 'photostat', 'xerox', 'xerox copy', 'battologize', 'bring out', 'contact print', 'copy', 'critique', 'do over', 'duplicate', 'dwelling upon'],
    'reprisal': ['amends', 'avengement', 'avenging', 'blood feud', 'comeuppance', 'compensation', 'counterblow', 'desert', 'deserts', 'feud', 'getting even', 'indemnification'],
    'reproach': ['accusal', 'accusation', 'accuse', 'accusing', 'admonish', 'admonishment', 'admonition', 'allegation', 'allege', 'allegement', 'anathematize', 'anathemize'],
    'reproachful': ['abusive', 'admonitory', 'blackening', 'blameful', 'censorious', 'condemnatory', 'contemptuous', 'critical', 'damnatory', 'denunciatory', 'deprecative', 'deprecatory'],
    'reprobate': ['abandoned', 'abominable', 'accursed', 'accuse', 'amoral', 'anathematize', 'anathemize', 'animadvert on', 'arraign', 'arrant', 'atrocious', 'backslider'],
    'reproduce': ['photostat', 'xerox', 'be fruitful', 'be productive', 'bear', 'beget', 'blossom', 'breed', 'brew', 'burgeon', 'clone', 'come again'],
    'reproduction': ['abstract', 'abstraction', 'altarpiece', 'block print', 'breeding', 'budding', 'burgeoning', 'burlesque', 'carbon', 'carbon copy', 'clone', 'collage'],
    'reproductive': ['phoenixlike', 'fecundative', 'fertilizing', 'germinal', 'life-giving', 'multiparous', 'procreant', 'procreative', 'propagative', 're-creative', 're-formative', 'reappearing'],
    'reproof': ['admonishment', 'admonition', 'castigation', 'chastisement', 'chiding', 'correction', 'lecture', 'lesson', 'objurgation', 'rap', 'rating', 'rebuke'],
    'reprove': ['admonish', 'bring to book', 'call down', 'call to account', 'chasten', 'chastise', 'chide', 'correct', 'have words with', 'lecture', 'lesson', 'objurgate'],
    'reptile': ['gila monster', 'reptilia', 'agama', 'alligator', 'amphibian', 'anguine', 'animal', 'anole', 'aquatic', 'atiptoe', 'batrachian', 'bearded lizard'],
    'reptilian': ['abject', 'abominable', 'alligator', 'amphibian', 'anguine', 'arrant', 'atrocious', 'base', 'batrachian', 'beggarly', 'cheesy', 'colubriform'],
    'republic': ['absolute monarchy', 'ally', 'archduchy', 'archdukedom', 'aristocracy', 'autarchy', 'autocracy', 'autonomy', 'body politic', 'buffer state', 'captive nation', 'chieftaincy'],
    'republican': ['conservative', 'democrat', 'labourite', 'tory', 'whig', 'heeler', 'loyalist', 'partisan', 'party faithful', 'party hack', 'party man', 'party member'],
    'republican party': ['american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party', 'greenback party'],
    'repudiate': ['abandon', 'abjure', 'abrogate', 'apostatize', 'assert the contrary', 'back down', 'back out', 'backwater', 'ban', 'bar', 'bar out', 'be unmoved'],
    'repudiation': ['abjuration', 'abjurement', 'abnegation', 'abrogation', 'absolute contradiction', 'agreement to disagree', 'alienation', 'annulment', 'apostasy', 'bad debt', 'ban', 'bar'],
    'repudiative': ['abjuratory', 'abnegative', 'adversative', 'breakaway', 'contradicting', 'contradictory', 'contrary', 'creedless', 'denying', 'disaffirming', 'disallowing', 'disavowing'],
    'repugnance': ['anglophobia', 'russophobia', 'abhorrence', 'abominability', 'abomination', 'allergy', 'antagonism', 'anti-semitism', 'antipathy', 'antithesis', 'argumentation', 'averseness'],
    'repugnant': ['abhorrent', 'abjuratory', 'abnegative', 'abominable', 'acrid', 'adversary', 'adversative', 'adverse', 'adversive', 'alien', 'antagonistic', 'anti'],
    'repulse': ['abjuration', 'abjure', 'abjurement', 'backfire', 'backlash', 'backlashing', 'bafflement', 'balk', 'be proof against', 'bear up', 'bear up against', 'beat back'],
    'repulsion': ['abhorrence', 'abomination', 'allergy', 'antagonism', 'antipathy', 'aversion', 'challenge', 'cold sweat', 'combative reaction', 'complaint', 'counteraction', 'creeping flesh'],
    'repulsive': ['abhorrent', 'abominable', 'arrant', 'atrocious', 'awful', 'bad', 'bad-smelling', 'barfy', 'base', 'beastly', 'below contempt', 'beneath contempt'],
    'reputable': ['christian', 'authoritative', 'blameless', 'celebrated', 'charismatic', 'charming', 'clean', 'consequential', 'conspicuous', 'creditable', 'decent', 'dependable'],
    'reputation': ['acclaim', 'authority', 'celebrity', 'character', 'credit', 'dignity', 'distinction', 'eclat', 'eminence', 'esteem', 'fame', 'famousness'],
    'repute': ['ascendancy', 'assume', 'authority', 'be afraid', 'believe', 'celebrity', 'character', 'charisma', 'charm', 'clout', 'conceive', 'conclude'],
    'reputed': ['alleged', 'assumed', 'believed', 'conjectural', 'considered', 'creditable', 'deemed', 'estimable', 'held', 'hypothetical', 'judged', 'presumed'],
    'request': ['appeal', 'application', 'apply for', 'ask', 'ask for', 'beg', 'beg leave', 'beseech', 'bespeak', 'call', 'call for', 'crave'],
    'requiem': ['dry mass', 'eucharistic rites', 'lady mass', 'low mass', 'mass', 'missa', 'missa bassa', 'missa cantata', 'missa legata', 'missa media', 'missa praesanctificatorum', 'missa privata'],
    'require': ['affect', 'appoint', 'ask', 'ask for', 'assess', 'assume', 'authorize', 'be hurting for', 'be indicated', 'bind', 'blackmail', 'bring'],
    'required': ['absolute', 'binding', 'called for', 'compulsatory', 'compulsory', 'conclusive', 'de rigueur', 'decisive', 'decretory', 'dictated', 'entailed', 'essential'],
    'requirement': ['bare necessities', 'blackmail', 'call', 'call for', 'claim', 'condition', 'contribution', 'demand', 'demand for', 'desideration', 'desideratum', 'draft'],
    'requisite': ['appropriate', 'bare necessities', 'boundary condition', 'call for', 'called for', 'catch', 'clause', 'condign', 'condition', 'demand', 'demand for', 'deserved'],
    'requisition': ['address', 'adopt', 'adoption', 'application', 'apply for', 'appropriate', 'appropriation', 'arrogate', 'arrogation', 'ask', 'ask for', 'asking'],
    'requital': ['amends', 'atonement', 'blood money', 'comeuppance', 'compensation', 'consideration', 'damages', 'desert', 'deserts', 'guerdon', 'honorarium', 'indemnification'],
    'requite': ['alternate', 'amend', 'atone', 'avenge', 'bandy', 'be quits with', 'change', 'commute', 'compensate', 'compensate for', 'content', 'cooperate'],
    'rescind': ['abbreviate', 'abolish', 'abridge', 'abrogate', 'annul', 'blot out', 'blue-pencil', 'bowdlerize', 'cancel', 'censor', 'countermand', 'counterorder'],
    'rescript': ['acknowledgment', 'amendment', 'answer', 'answering', 'antiphon', 'appointment', 'back answer', 'back talk', 'backchat', 'billet', 'brevet', 'bull'],
    'rescue': ['emancipation proclamation', 'abet', 'affranchise', 'affranchisement', 'aid', 'assist', 'assistance', 'avail', 'bail out', 'bear a hand', 'befriend', 'benefit'],
    'rescuer': ['audubon society', 'national wildlife service', 'sierra club', 'air-sea rescue', 'coast guard', 'conservationist', 'conservator', 'deliverer', 'forest ranger', 'freer', 'game warden', 'keeper'],
    'research': ['amassing evidence', 'analysis', 'assay', 'beat the bushes', 'bring to test', 'burrow', 'check out', 'close inquiry', 'confirm', 'cut and try', 'delve', 'delve into'],
    'research and development': ['r and d', 'control', 'control experiment', 'controlled experiment', 'cut and try', 'empiricism', 'experiment', 'experimental design', 'experimental method', 'experimental proof', 'experimentalism', 'experimentation'],
    'research paper': ['article', 'causerie', 'descant', 'discourse', 'discussion', 'disquisition', 'dissertation', 'essay', 'etude', 'examination', 'excursus', 'exposition'],
    'researcher': ['analyst', 'analyzer', 'assayer', 'delver', 'digger', 'essayer', 'experimenter', 'hunter', 'perquisitor', 'ransacker', 'research worker', 'researchist'],
    'resection': ['abscission', 'amputation', 'anastomotic operation', 'bloodless operation', 'butchering', 'capital operation', 'chopping', 'cleavage', 'compensating operation', 'corneal transplant', 'crescent operation', 'cutting'],
    'resemblance': ['accord', 'accordance', 'affinity', 'agreement', 'alikeness', 'alliance', 'analogy', 'aping', 'approach', 'approximation', 'assimilation', 'certified copy'],
    'resemble': ['admit of comparison', 'ape', 'appear like', 'approach', 'approximate', 'be', 'be commensurable', 'be comparable', 'be like', 'be redolent of', 'bear resemblance', 'bring to mind'],
    'resentful': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrimonious', 'aggravated', 'agitated', 'angry', 'annoyed'],
    'resentment': ['faustianism', 'acrimony', 'agitation', 'anger', 'animosity', 'animus', 'annoyance', 'antagonism', 'antipathy', 'anxiety', 'bitterness', 'cold comfort'],
    'reservation': ['indian reservation', 'allowance', 'appointment', 'archives', 'area', 'arrangement', 'bank', 'bespeaking', 'bird sanctuary', 'booking', 'briefing', 'cession'],
    'reserve': ['indian reservation', 'abstain', 'accessible', 'adjourn', 'allocate', 'allot', 'aloofness', 'alternate', 'alternative', 'aplomb', 'appoint', 'appropriate to'],
    'reserved': ['olympian', 'spartan', 'abbreviated', 'abridged', 'aloof', 'antisocial', 'aposiopestic', 'backward', 'bashful', 'blank', 'brief', 'brusque'],
    'reserves': ['swiss bank account', 'us army reserve', 'us naval reserve', 'agent', 'alternate', 'alternative', 'analogy', 'army reserves', 'assets', 'auxiliaries', 'backlog', 'backup'],
    'reservoir': ['archives', 'armory', 'arsenal', 'artificial lake', 'attic', 'backlog', 'bank', 'basement', 'bay', 'bayou lake', 'bin', 'bonded warehouse'],
    'reshape': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'amend', 'better', 'break up', 'change', 'convert', 'copy', 'deform'],
    'reside': ['abide', 'abide in', 'anchor', 'be coextensive with', 'be comprised in', 'be constituted by', 'be contained in', 'be present in', 'berth', 'bide', 'billet at', 'bivouac'],
    'residence': ['abiding', 'abiding place', 'abode', 'address', 'cantonment', 'castle', 'chateau', 'cohabitation', 'commorancy', 'crash pad', 'crib', 'domicile'],
    'residency': ['hippocratic oath', 'abiding', 'abode', 'cohabitation', 'commorancy', 'domicile', 'dwelling', 'general practice', 'habitancy', 'habitation', 'home', 'house'],
    'resident': ['doctor of medicine', 'gp', 'md', 'abiding', 'addressee', 'allopath', 'allopathist', 'ambassador', 'ambassadress', 'apostolic delegate', 'artist-in-residence', 'attache'],
    'residue': ['afterglow', 'afterimage', 'balance', 'butt', 'butt end', 'candle ends', 'chaff', 'debris', 'detritus', 'dregs', 'end', 'excess'],
    'resign': ['abandon', 'abdicate', 'abjure', 'accede', 'accept', 'acknowledge defeat', 'acquiesce', 'assent', 'be agreeable', 'be pensioned', 'be superannuated', 'cease'],
    'resignation': ['quakerism', 'abandonment', 'abdication', 'abeyance', 'abjuration', 'abjurement', 'acceptance', 'acclimation', 'acclimatization', 'acedia', 'acquiescence', 'adaptation'],
    'resigned': ['laodicean', 'olympian', 'abandoned', 'abject', 'abjured', 'accepting', 'accommodating', 'acquiescent', 'adapting', 'adaptive', 'adjusting', 'agreeable'],
    'resilience': ['adaptability', 'adjustability', 'airiness', 'alterability', 'backfire', 'backlash', 'backlashing', 'boomerang', 'bounce', 'bounciness', 'bound', 'breeziness'],
    'resilient': ['able to adapt', 'adaptable', 'adaptive', 'adjustable', 'airy', 'alterable', 'alterative', 'bouncing', 'bouncy', 'bounding', 'breezy', 'buoyant'],
    'resin': ['canada balsam', 'sonora lac', 'acacia', 'agar', 'amber', 'ambergris', 'ammoniac', 'amyrin', 'anime', 'balsam', 'bassorin', 'benjamin'],
    'resist': ['antagonize', 'arrest', 'assail', 'assault', 'attack', 'baffle', 'balk', 'battle', 'be antipathetic', 'be at cross-purposes', 'be inimical', 'be proof against'],
    'resistance': ['charley', 'vc', 'vietcong', 'acquired immunity', 'active immunity', 'alienation', 'antagonism', 'antibody', 'antigen', 'antipathy', 'arrest', 'arrestation'],
    'resistant': ['against', 'airtight', 'antagonistic', 'antipathetic', 'at odds', 'averse', 'ballproof', 'beyond control', 'bombproof', 'bony', 'breachy', 'breakaway'],
    'resister': ['bitter-ender', 'brawler', 'defendant', 'diehard', 'disputant', 'dissentient', 'dissident', 'intransigent', 'irreconcilable', 'last-ditcher', 'litigant', 'naysayer'],
    'resolute': ['abandoned', 'adamant', 'afire', 'ardent', 'assiduous', 'bent', 'bold', 'bound', 'bound and determined', 'bulldog', 'bulldoggish', 'burning'],
    'resolutely': ['assiduously', 'audaciously', 'bec et ongles', 'boldly', 'bravely', 'bulldoggishly', 'chivalrously', 'committedly', 'courageously', 'daringly', 'decidedly', 'decisively'],
    'resolution': ['abandon', 'ablation', 'about-face', 'accommodation', 'accomplishment', 'accuracy', 'act', 'action', 'acutance', 'adaptation', 'adjustment', 'aim'],
    'resolvable': ['answerable', 'ascertainable', 'capable of solution', 'convertible', 'decipherable', 'decodable', 'determinable', 'doable', 'explainable', 'explicable', 'modifiable', 'open to solution'],
    'resolve': ['abort', 'accommodate', 'adjust', 'adopt', 'agree', 'aim', 'aim at', 'alter into', 'ambition', 'analyze', 'anatomize', 'animus'],
    'resolvent': ['ablative', 'anticoagulant', 'biodegradable', 'corrosive', 'cutting', 'decomposable', 'decomposing', 'degradable', 'dilapidated', 'diluent', 'dilutant', 'disintegrable'],
    'resonance': ['amplitude', 'antinode', 'crest', 'de broglie wave', 'diffraction', 'electromagnetic radiation', 'electromagnetic wave', 'fluctuation', 'frequency', 'frequency band', 'frequency spectrum', 'guided wave'],
    'resonant': ['beating', 'booming', 'consonant', 'deep', 'earsplitting', 'electrifying', 'enhanced', 'fat', 'fluctuant', 'fluctuating', 'fluctuational', 'full'],
    'resonate': ['bob', 'bobble', 'careen', 'coggle', 'dangle', 'fluctuate', 'flutter', 'librate', 'lurch', 'nutate', 'oscillate', 'pendulate'],
    'resort': ['ability', 'action', 'ad hoc measure', 'affect', 'agency', 'alternative', 'amusement park', 'answer', 'artifice', 'attend', 'backup', 'ballroom'],
    'resort to': ['bring into play', 'convert to use', 'enlist into service', 'fall back upon', 'frequent', 'go to', 'hang out at', 'haunt', 'have recourse to', 'hie to', 'impress', 'look to'],
    'resound': ['awake the dead', 'be reflected', 'be sent back', 'blast', 'blast the ear', 'bless', 'boom', 'bounce back', 'celebrate', 'come again', 'come up again', 'crash'],
    'resounding': ['assertive', 'boom', 'booming', 'consonant', 'deafening', 'ear-piercing', 'ear-rending', 'ear-splitting', 'earthshaking', 'echo', 'echoic', 'echoing'],
    'resource': ['ability', 'action', 'ad hoc measure', 'address', 'adeptness', 'adroitness', 'airmanship', 'answer', 'aptitude', 'artfulness', 'artifice', 'artisanship'],
    'resourceful': ['daedalian', 'machiavellian', 'machiavellic', 'acute', 'adaptable', 'adept', 'adjustable', 'adroit', 'all-around', 'ambidextrous', 'amphibious', 'apt'],
    'resources': ['swiss bank account', 'ability', 'assessed valuation', 'assets', 'assets and liabilities', 'available means', 'balance', 'bank account', 'bottom dollar', 'budget', 'capacity', 'capital'],
    'respect': ['anschauung', 'ok', 'abide by', 'accept', 'acceptance', 'accord respect to', 'accordance', 'account', 'acquittal', 'acquittance', 'act up to', 'adhere to'],
    'respectable': ['christian', 'ok', 'acceptable', 'adequate', 'admissible', 'all right', 'appreciable', 'appropriate', 'becoming', 'befitting', 'better than nothing', 'betwixt and between'],
    'respected': ['admired', 'adored', 'appreciated', 'creditable', 'esteemed', 'estimable', 'held in esteem', 'held in respect', 'highly considered', 'highly esteemed', 'highly regarded', 'highly reputed'],
    'respectful': ['acclamatory', 'accommodating', 'admiring', 'affable', 'agreeable', 'appreciative', 'approbatory', 'attentive', 'cap in hand', 'ceremonious', 'civil', 'commendatory'],
    'respecting': ['about', 'anent', 'apropos of', 'as for', 'as regards', 'as respects', 'as to', 'concerning', 'in connection with', 'in point of', 'in re', 'in reference to'],
    'respective': ['absolute', 'certain', 'common', 'communal', 'commutual', 'concrete', 'conjoint', 'corresponding', 'defined', 'definite', 'detailed', 'determinate'],
    'respectively': ['apiece', 'commonly', 'communally', 'distributively', 'each', 'each to each', 'entre nous', 'even stephen', 'fifty-fifty', 'half-and-half', 'in equal shares', 'in proportion'],
    'respiration': ['aqua-lung', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'breath', 'breath of air', 'breathing', 'broken wind', 'cough', 'exhalation', 'expiration', 'exsufflation'],
    'respire': ['be alive', 'be animate', 'blow', 'breathe', 'breathe hard', 'breathe in', 'breathe out', 'cough', 'draw breath', 'exhale', 'exhaust', 'exist'],
    'respite': ['abeyance', 'afterthought', 'bind', 'block', 'blockage', 'blow', 'break', 'breath', 'breather', 'breathing', 'breathing place', 'breathing space'],
    'resplendence': ['babylonian splendor', 'aura', 'blare', 'blaze', 'blaze of glory', 'blazing light', 'blinding light', 'bright light', 'brightness', 'brilliance', 'brilliancy', 'brilliant light'],
    'resplendent': ['beaming', 'bedazzling', 'blazing', 'blinding', 'blooming', 'bright', 'bright and shining', 'brilliant', 'charismatic', 'dazzling', 'devastating', 'divine'],
    'respond': ['acknowledge', 'act', 'advocate', 'allege in support', 'alternate', 'answer', 'answer back', 'antiphon', 'apprehend', 'argue for', 'assert', 'bandy'],
    'respond to': ['accord', 'act toward', 'agree', 'agree with', 'answer', 'answer to', 'approach', 'assent', 'assort with', 'be consistent', 'be of one', 'be uniform with'],
    'respondent': ['accused', 'answerer', 'answering', 'antiphonal', 'confutative', 'correspondent', 'defendant', 'echoic', 'echoing', 'libelee', 'prisoner', 'reacting'],
    'response': ['agnus dei', 'benedicite', 'esp', 'gloria', 'gloria patri', 'gloria in excelsis', 'introit', 'magnificat', 'miserere', 'nunc dimittis', 'te deum', 'trisagion'],
    'responsibility': ['accountability', 'accountableness', 'accounting for', 'action', 'agency', 'agentship', 'amenability', 'answerability', 'answerableness', 'application', 'arrogation', 'ascription'],
    'responsible': ['accountable', 'administrative', 'amenable', 'answerable', 'answerable for', 'apt to', 'at fault', 'authoritative', 'capable of', 'chargeable', 'chief', 'creditable'],
    'responsive': ['accessible', 'acquiescent', 'adaptable', 'adaptive', 'agreeable', 'alacritous', 'alert', 'alive', 'allergic', 'amenable', 'anaphylactic', 'answering'],
    'rest': ['abeyance', 'abide', 'abide in', 'advocate', 'afterglow', 'afterimage', 'allay', 'alpenstock', 'annihilation', 'appease', 'arm', 'arrive'],
    'rest assured': ['aller sans dire', 'aspire to', 'bank on', 'be axiomatic', 'be certain', 'be confident', 'be convinced', 'be satisfied', 'bet on', 'confide', 'count on', 'desire'],
    'rest home': ['va hospital', 'almshouse', 'asylum', 'base hospital', 'clinic', 'community hospital', 'convalescent home', 'convalescent hospital', 'evacuation hospital', 'field hospital', 'foster home', 'general hospital'],
    'rest on': ['abut on', 'bank on', 'be based on', 'be contingent on', 'be dependent on', 'be predicated on', 'bear on', 'bear upon', 'bestraddle', 'bestride', 'bet on', 'calculate on'],
    'rest room': ['wc', 'backhouse', 'bagnio', 'balneae', 'balneum', 'basement', 'bath', 'bathhouse', 'bathroom', 'baths', 'caldarium', 'can'],
    'restate': ['battologize', 'fill', 'give an encore', 'go over', 'go through', 'iterate', 'pad', 'paraphrase', 'practice', 'reaffirm', 'reassert', 'recapitulate'],
    'restaurant': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop'],
    'restful': ['appeasing', 'at peace', 'at rest', 'bloodless', 'calm', 'calming', 'cloistered', 'comfortable', 'comforting', 'comfy', 'commodious', 'concordant'],
    'resting place': ['advocate', 'alpenstock', 'apodosis', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'barrow', 'bearer', 'beehive tomb'],
    'restitution': ['about-face', 'amends', 'atonement', 'backing', 'backsliding', 'balancing', 'blood money', 'commutation', 'compensation', 'composition', 'compromise', 'consideration'],
    'restitutive': ['analeptic', 'apologetic', 'ascetic', 'atoning', 'cleansing', 'compensational', 'compensatory', 'curative', 'expiatory', 'indemnificatory', 'lustral', 'lustrational'],
    'restive': ['antsy', 'antsy-pantsy', 'anxious', 'apathetic', 'backward', 'balking', 'balky', 'beefing', 'bellyaching', 'beyond control', 'bigoted', 'bitching'],
    'restless': ['adrift', 'afloat', 'agitated', 'alternating', 'amorphous', 'antsy', 'antsy-pantsy', 'anxious', 'apprehensive', 'beefing', 'bellyaching', 'bitching'],
    'restlessness': ['faustianism', 'activity', 'actuation', 'ado', 'agitation', 'ailment', 'alertness', 'all-night vigil', 'anxiety', 'bluster', 'bobbery', 'boil'],
    'restoration': ['great leap forward', 'about-face', 'advance', 'advancement', 'amelioration', 'amendment', 'ascent', 'backing', 'backsliding', 'bettering', 'betterment', 'boost'],
    'restorative': ['phoenixlike', 'activator', 'adjuvant', 'aid', 'alterative', 'analeptic', 'animator', 'arouser', 'assistance', 'astringent', 'balm', 'balsam'],
    'restore': ['abet', 'account for', 'aid', 'amend', 'arouse', 'assist', 'avail', 'bail out', 'bear a hand', 'befriend', 'benefit', 'better'],
    'restrain': ['abate', 'adjust to', 'allay', 'alleviate', 'alter', 'anchor', 'arrest', 'assuage', 'attemper', 'bank the fire', 'bar', 'bind'],
    'restrained': ['attic', 'ciceronian', 'olympian', 'aesthetic', 'aloof', 'arrested', 'artistic', 'aseptic', 'backward', 'barred', 'bashful', 'beleaguered'],
    'restraint': ['atticism', 'oregon boat', 'abnegation', 'absolutism', 'abstinence', 'aloofness', 'aplomb', 'appropriateness', 'arrest', 'arrestation', 'arrestment', 'assurance'],
    'restraint of trade': ['arrest', 'arrestation', 'balance of trade', 'big business', 'business', 'business dealings', 'check', 'commerce', 'commercial affairs', 'commercial relations', 'constraint', 'control'],
    'restrict': ['abate', 'adjust to', 'allocate', 'allot', 'alter', 'appoint', 'appropriate to', 'assign', 'assign to', 'assuage', 'bar', 'be into'],
    'restricted': ['angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'arcane', 'authoritative', 'bound', 'bounded', 'boxed in', 'cabalistic', 'cabined', 'censored'],
    'restriction': ['allowance', 'arrest', 'arrestation', 'arrestment', 'ban', 'bar', 'barring', 'blockade', 'blockage', 'blocking', 'boundary', 'bounds'],
    'restrictive': ['altering', 'assuasive', 'bounding', 'choking', 'confining', 'constrictive', 'contrary', 'counterproductive', 'cramping', 'crosswise', 'defining', 'definitive'],
    'restructure': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'better', 'break up', 'change', 'convert', 'copy', 'deform', 'denature'],
    'result': ['accomplishment', 'accrue from', 'aftereffect', 'aftermath', 'answer', 'arise', 'arise from', 'artifact', 'ascertainment', 'attend', 'be contingent on', 'be due to'],
    'resultant': ['accidental', 'accompanying', 'ado', 'afloat', 'afoot', 'by-product', 'circumstantial', 'consequence', 'consequent', 'consequential', 'corollary', 'current'],
    'resume': ['clio', 'muse of history', 'adventures', 'annals', 'autobiography', 'battologize', 'begin again', 'biographical sketch', 'biography', 'carry on', 'case history', 'chronicle'],
    'resumption': ['another shot', 'another try', 'doubling', 'duplication', 'echo', 'fresh start', 'imitation', 'new beginning', 'plagiarism', 'quotation', 'ransom', 'reappearance'],
    'resurgence': ['new birth', 'palingenesis', 'palingenesy', 'reanimation', 'rebirth', 'recrudescence', 'refreshment', 'regeneracy', 'regenerateness', 'regeneration', 'regenesis', 'rejuvenation'],
    'resurrect': ['bring back', 'bring to', 'call back', 'copy', 'do over', 'duplicate', 'make over', 'raise', 're-create', 're-form', 'reactivate', 'reanimate'],
    'resurrection': ['apotheosis', 'ascension', 'assumption', 'copy', 'duplication', 'gathering', 'imitation', 'new birth', 'palingenesis', 'palingenesy', 're-creation', 're-formation'],
    'resuscitate': ['abet', 'aid', 'animate', 'assist', 'avail', 'awake', 'awaken', 'bail out', 'be begotten', 'be born', 'be incarnated', 'bear a hand'],
    'retable': ['communion table', 'altar', 'altar carpet', 'altar desk', 'altar facing', 'altar of prothesis', 'altar rail', 'altar side', 'altar slab', 'altar stair', 'altar stone', 'altarpiece'],
    'retail': ['battologize', 'be in', 'bestrew', 'bill of sale', 'broadcast', 'business', 'carry', 'circumfuse', 'close out', 'commercial', 'convert into cash', 'cut under'],
    'retail store': ['boutique', 'chain store', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dime store', 'discount house', 'discount store', 'emporium'],
    'retailer': ['caterer', 'chandler', 'commissariat', 'commissary', 'dealer', 'distributor', 'donor', 'furnisher', 'importer', 'jobber', 'manciple', 'marketer'],
    'retailing': ['accouterment', 'agency', 'armament', 'barter', 'bartering', 'brokerage', 'buying and selling', 'catering', 'chandlery', 'consumer preference study', 'consumer research', 'consumer survey'],
    'retain': ['absorb', 'balance', 'ballast', 'bear in mind', 'bespeak', 'book', 'bottle up', 'brief', 'brood over', 'cherish', 'cite', 'commission'],
    'retained': ['alive', 'conserved', 'eidetic', 'enduring', 'fresh', 'green', 'held', 'held back', 'held in reserve', 'kept', 'kept in remembrance', 'lasting'],
    'retainer': ['account', 'adherent', 'allowance', 'appendage', 'assessment', 'bill', 'blackmail', 'blood money', 'dangler', 'dependent', 'emolument', 'fee'],
    'retaining wall': ['abutment', 'arc-boutant', 'bank', 'beam', 'breakwater', 'bulwark', 'buttress', 'buttress pier', 'buttressing', 'embankment', 'flying buttress', 'groin'],
    'retake': ['boom shot', 'close-up', 'deuce shot', 'follow-focus shot', 'full shot', 'get back', 'group shot', 'kinescope', 'long shot', 'matte shot', 'medium shot', 'motion picture'],
    'retaliate': ['alternate', 'atone', 'avenge', 'bandy', 'be quits with', 'change', 'come back at', 'commute', 'compensate', 'cooperate', 'counter', 'counterchange'],
    'retaliation': ['alternation', 'amends', 'atonement', 'avengement', 'avenging', 'balancing', 'battledore and shuttlecock', 'blood feud', 'blow for blow', 'commutation', 'compensation', 'cooperation'],
    'retaliatory': ['amendatory', 'avenging', 'balancing', 'changeable', 'commutable', 'commutative', 'compensating', 'compensatory', 'convertible', 'counteracting', 'counteractive', 'counterbalancing'],
    'retard': ['arrest', 'backpedal', 'backwater', 'balk', 'block', 'bottle up', 'brake', 'bridle', 'check', 'clip the wings', 'confine', 'constrain'],
    'retardant': ['complaining', 'disputatious', 'disputing', 'dissentient', 'dissenting', 'fractious', 'noncooperative', 'objecting', 'obstructive', 'on the barricades', 'proof against', 'protesting'],
    'retardation': ['afterthought', 'amentia', 'arrest', 'arrestation', 'arrested development', 'arrestment', 'backwardness', 'bind', 'blithering idiocy', 'block', 'blockage', 'blocking'],
    'retarded': ['arrested', 'babbling', 'back', 'backward', 'behind', 'behindhand', 'belated', 'blithering', 'blocked', 'bridled', 'burbling', 'checked'],
    'retch': ['barf', 'be nauseated', 'be seasick', 'be sick', 'bring up', 'choke on', 'chuck up', 'disgorge', 'egest', 'feed the fish', 'feel disgust', 'gag'],
    'retell': ['allegorize', 'battologize', 'fable', 'fabulize', 'fictionalize', 'fill', 'give an encore', 'go over', 'go through', 'iterate', 'mythicize', 'mythify'],
    'retention': ['abnegation', 'adhesiveness', 'bullheadedness', 'camera-eye', 'cohesiveness', 'consistency', 'contradiction', 'declension', 'declination', 'declinature', 'declining', 'denial'],
    'reticence': ['aloofness', 'backwardness', 'bashfulness', 'blankness', 'chilliness', 'coldness', 'constraint', 'coolness', 'detachment', 'discreetness', 'discretion', 'distance'],
    'reticent': ['olympian', 'aloof', 'backward', 'bashful', 'blank', 'chilled', 'chilly', 'close', 'close-lipped', 'close-tongued', 'closemouthed', 'cold'],
    'reticle': ['arabesque', 'basketry', 'basketwork', 'cancellation', 'cross-hatching', 'crossing-out', 'filigree', 'fret', 'fretwork', 'grate', 'grating', 'grid'],
    'reticular': ['barred', 'cancellated', 'crossbarred', 'filigreed', 'grated', 'gridded', 'laced', 'lacelike', 'lacy', 'latticelike', 'meshed', 'meshy'],
    'retina': ['baby blues', 'banjo eyes', 'bright eyes', 'clear eyes', 'cornea', 'eye', 'eyeball', 'eyelid', 'goggle eyes', 'iris', 'lens', 'lid'],
    'retinue': ['attendance', 'attendant', 'attendants', 'body of retainers', 'cohort', 'company', 'convoy', 'cortege', 'court', 'crew', 'employees', 'entourage'],
    'retire': ['abandon', 'abdicate', 'abscond', 'amortize', 'avoid the limelight', 'back down', 'back out', 'be pensioned', 'be superannuated', 'beat a retreat', 'bed', 'bed down'],
    'retired': ['abandoned', 'abjured', 'anonymous', 'antiquated', 'antique', 'apart', 'archaic', 'closet', 'deserted', 'detached', 'devious', 'discontinued'],
    'retirement': ['jim crow', 'abandonment', 'abdication', 'abstention', 'abstinence', 'acquitment', 'acquittal', 'acquittance', 'aloofness', 'amortization', 'amortizement', 'anonymity'],
    'retiring': ['olympian', 'aloof', 'aseptic', 'backward', 'bashful', 'blank', 'boat-shaped', 'boatlike', 'bowl-shaped', 'bowllike', 'cavelike', 'cavernous'],
    'retort': ['acknowledge', 'acknowledgment', 'aerosol', 'alembic', 'answer', 'answer back', 'answering', 'antiphon', 'anvil', 'aphorism', 'apothegm', 'atomizer'],
    'retouch': ['adjust', 'adulterate', 'brighten up', 'brush up', 'cook', 'correct', 'doctor', 'fake', 'finish', 'fix', 'freshen', 'furbish'],
    'retrace': ['bring back', 'bring to mind', 'call back', 'call to mind', 'call up', 'conjure up', 'evoke', 'go back', 'go back over', 'hark back', 'look back', 'mind'],
    'retract': ['abandon', 'abjure', 'abolish', 'abrogate', 'annul', 'assert the contrary', 'back', 'back down', 'back out', 'backwater', 'belie', 'cancel'],
    'retraction': ['abandonment', 'abjuration', 'abjurement', 'abolishment', 'abolition', 'abrogation', 'absolute contradiction', 'annulment', 'attrition', 'cancel', 'canceling', 'cancellation'],
    'retread': ['balloon tire', 'belted bias tire', 'belted radial tire', 'bias tire', 'cobble', 'commission', 'condition', 'darn', 'do up', 'doctor', 'face-lift', 'felly'],
    'retreat': ['jim crow', 'abandon', 'abandonment', 'abscond', 'adytum', 'alcove', 'almshouse', 'apartheid', 'apartness', 'arbor', 'ascend', 'ashram'],
    'retreating': ['boat-shaped', 'boatlike', 'bowl-shaped', 'bowllike', 'cavelike', 'cavernous', 'concave', 'concaved', 'craterlike', 'cup-shaped', 'cupped', 'cymbiform'],
    'retrench': ['abate', 'abbreviate', 'abrade', 'abridge', 'abstract', 'arrest', 'bate', 'bob', 'boil down', 'bridle', 'capsulize', 'check'],
    'retrenchment': ['abbreviation', 'abridgment', 'abstract', 'apocope', 'arrest', 'arrestation', 'attrition', 'check', 'cheeseparing', 'compression', 'condensation', 'conspectus'],
    'retribution': ['affliction', 'amends', 'atonement', 'avengement', 'avenging', 'blood money', 'castigation', 'chastening', 'chastisement', 'comeuppance', 'compensation', 'condign punishment'],
    'retributive': ['castigatory', 'chastening', 'chastising', 'compensating', 'compensative', 'compensatory', 'corrective', 'disciplinary', 'grueling', 'indemnificatory', 'inflictive', 'lucrative'],
    'retrievable': ['ameliorable', 'amendable', 'correctable', 'corrigible', 'curable', 'emendable', 'fixable', 'improvable', 'medicable', 'mendable', 'reclaimable', 'recoverable'],
    'retrieval': ['deliverance', 'delivery', 'extrication', 'freeing', 'liberation', 'lifesaving', 'ransom', 'recapture', 'reclaiming', 'reclamation', 'recoup', 'recoupment'],
    'retrieve': ['bring', 'bring back', 'call for', 'chase after', 'cover', 'deliver', 'extract', 'extricate', 'fetch', 'fetch and carry', 'free', 'get'],
    'retro rocket': ['earth insertion', 'lem', 'lm', 'apogee', 'attitude-control rocket', 'ballistic capsule', 'burn', 'capsule', 'deep-space ship', 'docking', 'docking maneuver', 'ferry rocket'],
    'retroaction': ['action and reaction', 'answer', 'automatic reaction', 'autonomic reaction', 'backset', 'backsliding', 'backward motion', 'backward step', 'bounceback', 'echo', 'lapse', 'predictable response'],
    'retroactive': ['a priori', 'antiphonal', 'back', 'backward', 'early', 'ex post facto', 'into the past', 'reacting', 'reactionary', 'reactive', 'recessive', 'reflex'],
    'retrocede': ['back', 'backslide', 'cock', 'decline', 'die away', 'diminish', 'drift away', 'dwindle', 'ebb', 'fade', 'fade away', 'fall astern'],
    'retroflex': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'arch', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation'],
    'retroflexion': ['backset', 'backsliding', 'backward motion', 'backward step', 'ectropion', 'eversion', 'introversion', 'intussusception', 'invagination', 'inversion', 'lapse', 'pronation'],
    'retrograde': ['aft', 'after', 'aftermost', 'atavistic', 'back', 'backslide', 'backward', 'cock', 'coming apart', 'cracking', 'crumbling', 'decadent'],
    'retrogress': ['advance', 'ascend', 'back', 'back up', 'backslide', 'budge', 'change', 'change place', 'circle', 'climb', 'cock', 'come after'],
    'retrogression': ['brownian movement', 'about-face', 'advance', 'angular motion', 'ascending', 'ascent', 'axial motion', 'backflowing', 'backing', 'backset', 'backsliding', 'backward motion'],
    'retrogressive': ['ascending', 'atavistic', 'axial', 'back', 'back-flowing', 'backward', 'coming apart', 'cracking', 'crumbling', 'decadent', 'declining', 'degenerate'],
    'retrospect': ['afterthought', 'bring back', 'bring to mind', 'call back', 'call to mind', 'call up', 'cite', 'commitment to memory', 'conjure up', 'evoke', 'exercise of memory', 'flashback'],
    'retrospection': ['commitment to memory', 'exercise of memory', 'flashback', 'hindsight', 'learning by heart', 'looking back', 'memoir', 'memorization', 'memorizing', 'memory', 'recall', 'recalling'],
    'retrospective': ['a priori', 'back', 'backward', 'demonstration', 'display', 'early', 'enactment', 'evocative', 'ex post facto', 'exhibit', 'exhibition', 'exposition'],
    'retrousse': ['blocky', 'chubby', 'chunky', 'dumpy', 'fat', 'podgy', 'pudgy', 'pug', 'pugged', 'snub-nosed', 'squat', 'squattish'],
    'return': ['crt spot', 'dm display', 'doppler signal', 'if signal', 'im display', 'rf echoes', 'about-face', 'acknowledge', 'acknowledgment', 'action and reaction', 'advent', 'advert'],
    'return to': ['backslide', 'begin again', 'come again', 'cry back to', 'fall', 'fall again into', 'fall back', 'fall from grace', 'go back to', 'have a relapse', 'have another shot', 'have another try'],
    'returnable': ['atavistic', 'changeable', 'commutable', 'commutative', 'convertible', 'equal', 'equalizing', 'equivalent', 'even', 'exchanged', 'give-and-take', 'interchangeable'],
    'returns': ['account', 'account rendered', 'accounting', 'acta', 'agenda', 'annual', 'avails', 'beadroll', 'box office', 'brief', 'bulletin', 'cadastre'],
    'reunion': ['affair', 'at home', 'gathering', 'get-together', 'levee', 'making up', 'matinee', 'rapprochement', 'reception', 'reconcilement', 'reconciliation', 'salon'],
    'reunite': ['accommodate', 'adjust', 'arrange matters', 'bring to terms', 'bring together', 'compose', 'compromise', 'fix up', 'harmonize', 'heal the breach', 'mediate', 'patch things up'],
    'revaluation': ['afterthought', 'circulation', 'demonetization', 'devaluation', 'developed thought', 'issuance', 'mature thought', 'monetization', 're-examination', 'reappraisal', 'recheck', 'reconsideration'],
    'revamp': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'amend', 'better', 'blue-pencil', 'break up', 'change', 'convert', 'correct'],
    'reveal': ['affect', 'air', 'argue', 'bare', 'be indicative of', 'be significant of', 'be symptomatic of', 'bespeak', 'betoken', 'betray', 'brandish', 'break it to'],
    'revealed': ['biblical', 'gospel', 'mosaic', 'new-testament', 'old-testament', 'apocalyptic', 'apostolic', 'apparent', 'bald', 'bare', 'beholdable', 'canonical'],
    'revealing': ['apocalypse', 'apocalyptic', 'baring', 'betraying', 'clear', 'clear as crystal', 'crystal', 'crystal-clear', 'crystalline', 'diaphane', 'diaphanous', 'disclosing'],
    'reveille': ['angelus', 'angelus bell', 'alarm', 'alarum', 'arousal', 'awakening', 'battle cry', 'birdcall', 'bugle call', 'call', 'last post', 'moose call'],
    'revel': ['adore', 'anniversaries', 'appreciate', 'bacchanal', 'ball', 'banquet', 'bask in', 'bat', 'be pleased with', 'bender', 'binge', 'bout'],
    'revelation': ['christophany', 'satanophany', 'admission', 'afflatus', 'angelophany', 'announcement', 'apocalypse', 'apparition', 'appearance', 'appearing', 'arising', 'astonishment'],
    'revelational': ['biblical', 'christophanic', 'gospel', 'mosaic', 'new-testament', 'old-testament', 'satanophanic', 'angelophanic', 'apocalyptic', 'apostolic', 'appearing', 'betraying'],
    'reveler': ['alcoholic', 'alcoholic addict', 'bacchanal', 'bacchanalian', 'bibber', 'big drunk', 'boozer', 'carouser', 'chronic alcoholic', 'chronic drunk', 'contestant', 'cutup'],
    'revelry': ['ball', 'banquet', 'carousal', 'celebration', 'cheer', 'conviviality', 'feast', 'festivity', 'fun', 'gaiety', 'good cheer', 'heartiness'],
    'revenge': ['amends', 'atonement', 'avenge', 'avengement', 'avenging', 'balancing', 'comeuppance', 'commutation', 'compensation', 'counteraction', 'counterbalancing', 'counterblow'],
    'revenue': ['avails', 'box office', 'commissions', 'credit', 'credits', 'disposable income', 'dividend', 'dividends', 'earned income', 'earnings', 'gain', 'gains'],
    'revenuer': ['bow street runner', 'fbi', 'fbi agent', 'federal', 'g-man', 'internal revenue service', 'secret service', 'sherlock holmes', 't-man', 'assessor', 'customhouse', 'customs'],
    'reverberate': ['acknowledge', 'answer', 'answer back', 'be reflected', 'be sent back', 'boom', 'bounce back', 'come again', 'come back', 'come back at', 'come up again', 'echo'],
    'reverberation': ['acknowledgment', 'action and reaction', 'answer', 'answering', 'antiphon', 'automatic reaction', 'autonomic reaction', 'back answer', 'back talk', 'backchat', 'boom', 'booming'],
    'revere': ['accord respect to', 'admire', 'adore', 'adulate', 'apotheosize', 'appreciate', 'beatify', 'cherish', 'dearly love', 'defer to', 'deify', 'do homage to'],
    'revered': ['admired', 'adored', 'appreciated', 'beloved', 'cherished', 'creditable', 'darling', 'dear', 'dearly beloved', 'esteemed', 'estimable', 'favorite'],
    'reverence': ['accord respect to', 'admiration', 'admire', 'adoration', 'adore', 'adulation', 'apotheosis', 'apotheosize', 'appreciate', 'appreciation', 'approbation', 'approval'],
    'reverend': ['august', 'awe-inspiring', 'awesome', 'awful', 'churchman', 'cleric', 'clerk', 'creditable', 'divine', 'dreadful', 'ecclesiastic', 'esteemed'],
    'reverent': ['christian', 'christianlike', 'christianly', 'admiring', 'adorant', 'adoring', 'apotheosizing', 'awed', 'awestricken', 'awestruck', 'believing', 'cultish'],
    'reverie': ['walter mitty', 'absence of mind', 'absentmindedness', 'absorption', 'abstractedness', 'abstraction', 'amnesia', 'bad dream', 'bemusement', 'brown study', 'castle-building', 'catalepsy'],
    'reversal': ['abolishment', 'abolition', 'about-face', 'about-turn', 'abrogation', 'accommodation', 'adaptation', 'adjustment', 'afterthoughts', 'alchemy', 'alteration', 'amelioration'],
    'reverse': ['hydromatic', 'abandon', 'abolish', 'about-face', 'about-turn', 'abrogate', 'adversative', 'adverse', 'adversity', 'adversive', 'afterpart', 'afterpiece'],
    'reversed': ['arsy-varsy', 'ass over elbows', 'back', 'back-to-front', 'backward', 'backwards', 'capsized', 'chiastic', 'counter', 'everted', 'hyperbatic', 'inside out'],
    'reversible': ['ameliorable', 'amendable', 'atavistic', 'correctable', 'corrigible', 'curable', 'emendable', 'fixable', 'improvable', 'medicable', 'mendable', 'reactionary'],
    'reversion': ['about-face', 'about-turn', 'atavism', 'back track', 'back trail', 'backing', 'backing off', 'backing out', 'backing up', 'backset', 'backsliding', 'backup'],
    'reversionary': ['atavistic', 'compensatory', 'indemnificatory', 'reactionary', 'recessive', 'recidivist', 'recidivous', 'redeeming', 'redemptional', 'redemptive', 'regressive', 'reparative'],
    'revert': ['back', 'back up', 'backslide', 'cock', 'come after', 'come again', 'come back', 'come last', 'come up again', 'cry back to', 'echo', 'fall'],
    'revertible': ['atavistic', 'compensatory', 'indemnificatory', 'reactionary', 'recessive', 'recidivist', 'recidivous', 'redeeming', 'redemptional', 'redemptive', 'regressive', 'reparative'],
    'review': ['grand guignol', 'passion play', 'tom show', 'abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'afterthought', 'air', 'airing', 'analysis'],
    'reviewer': ['advertising writer', 'analysis', 'annalist', 'annotator', 'art critic', 'audit', 'author', 'authoress', 'belletrist', 'bibliographer', 'book reviewer', 'captious critic'],
    'revile': ['abuse', 'asperse', 'bark at', 'barrack', 'bawl out', 'berate', 'besmirch', 'bespatter', 'betongue', 'blacken', 'blackguard', 'call names'],
    'revilement': ['abuse', 'assailing', 'assault', 'attack', 'berating', 'bitter words', 'blackening', 'calumny', 'character assassination', 'contumely', 'defamation', 'defamation of character'],
    'revise': ['alter', 'amend', 'amendment', 'blue', 'blue-pencil', 'blueprint', 'change', 'cold-type proof', 'color proof', 'computer proof', 'copy', 'copy out'],
    'revision': ['amendment', 'copy', 'correction', 'duplication', 'editing', 'edition', 'emendation', 'imitation', 'improvement', 'modification', 'overhaul', 'overhauling'],
    'revisional': ['fabian', 'phoenixlike', 'corrective', 'emendatory', 'gradualistic', 'melioristic', 'radical', 're-creative', 're-formative', 'reappearing', 'reformational', 'reformative'],
    'revisionism': ['bohemianism', 'bolshevism', 'castroism', 'communist information bureau', 'communist party', 'fabianism', 'maoism', 'marxian socialism', 'marxism', 'marxism-leninism', 'stalinism', 'titoism'],
    'revisionist': ['bolshevik', 'bolshevist', 'castroite', 'communist', 'communist sympathizer', 'fabian', 'leninist', 'maoist', 'marxist', 'marxist-leninist', 'red', 'stalinist'],
    'revival': ['great leap forward', 'mass', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'advance', 'advancement', 'alteration', 'amelioration', 'amendment', 'animation'],
    'revivalist': ['adorer', 'beadsman', 'celebrant', 'chapelgoer', 'churchgoer', 'colporteur', 'communicant', 'congregation', 'daily communicant', 'evangelist', 'idolater', 'missionary'],
    'revive': ['abet', 'accommodate', 'activate', 'adapt', 'adjust', 'aid', 'alter', 'ameliorate', 'animate', 'arouse', 'assist', 'avail'],
    'revived': ['altered', 'animated', 'better', 'changeable', 'changed', 'converted', 'degenerate', 'deviant', 'divergent', 'energized', 'exhilarated', 'improved'],
    'revocation': ['abjuration', 'abjurement', 'abolishment', 'abolition', 'abrogation', 'absolute contradiction', 'annulment', 'cancel', 'canceling', 'cancellation', 'cassation', 'contradiction'],
    'revoke': ['abjure', 'abolish', 'abrogate', 'annihilate', 'annul', 'assert the contrary', 'back down', 'back out', 'backwater', 'belie', 'bring to naught', 'cancel'],
    'revolt': ['antagonism', 'antipathy', 'appall', 'arise', 'backlash', 'bloodless revolution', 'bouleversement', 'boycott', 'boycottage', 'break', 'breakdown', 'breakup'],
    'revolted': ['anguished', 'anxious', 'bored', 'cheerless', 'depressed', 'disgusted', 'grim', 'joyless', 'nauseated', 'nauseous', 'pleasureless', 'prey to malaise'],
    'revolting': ['abhorrent', 'abominable', 'appalling', 'awful', 'base', 'beastly', 'below contempt', 'beneath contempt', 'contemptible', 'crude', 'despicable', 'detestable'],
    'revolution': ['fabianism', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'alteration', 'ambit', 'amelioration', 'anarchism', 'anarcho-syndicalism', 'anarchy', 'angular momentum'],
    'revolutionary': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'cong', 'fabian', 'fenian'],
    'revolutionist': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'cong', 'fenian', 'guevarist'],
    'revolutionize': ['alter', 'arise', 'change', 'coin', 'create', 'discover', 'innovate', 'insurge', 'insurrect', 'introduce', 'introduce new blood', 'invent'],
    'revolve': ['alternate', 'be here again', 'brood over', 'chaw', 'chew over', 'circle', 'circuit', 'circuiteer', 'circulate', 'circulation', 'circumambulate', 'circummigrate'],
    'revolver': ['automatic', 'blowgun', 'blowpipe', 'firearm', 'flamethrower', 'gat', 'gun', 'handgun', 'heater', 'musket', 'peashooter', 'piece'],
    'revue': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger', 'closet drama'],
    'revulsion': ['abhorrence', 'abomination', 'about-face', 'action and reaction', 'answer', 'antipathy', 'automatic reaction', 'autonomic reaction', 'aversion', 'backing', 'backsliding', 'bloodless revolution'],
    'revulsive': ['abhorrent', 'antiphonal', 'cataclysmic', 'catastrophic', 'insurrectionary', 'invidious', 'obnoxious', 'radical', 'reacting', 'reactionary', 'reactive', 'reflex'],
    'reward': ['academy award', 'nobel prize', 'oscar', 'amends', 'annihilation', 'atonement', 'award', 'bait', 'bane', 'biological death', 'blood money', 'booby prize'],
    'rewarding': ['advantageous', 'affable', 'agreeable', 'amiable', 'amicable', 'blissful', 'cheerful', 'compatible', 'compensating', 'compensative', 'compensatory', 'complaisant'],
    'reword': ['battologize', 'fill', 'give an encore', 'go over', 'go through', 'iterate', 'pad', 'paraphrase', 'practice', 'reaffirm', 'reassert', 'recapitulate'],
    'rewrite': ['amend', 'amendment', 'blue-pencil', 'copy', 'copy out', 'correct', 'correction', 'draft', 'draw up', 'edit', 'editing', 'emend'],
    'rewrite man': ['city editor', 'columnist', 'copy chief', 'copy editor', 'copyman', 'copyreader', 'correspondent', 'cub reporter', 'diaskeuast', 'editor', 'editorial writer', 'feature editor'],
    'reynard': ['african hunting dog', 'artful dodger', 'cape hunting dog', 'philadelphia lawyer', 'yankee horse trader', 'brush wolf', 'charmer', 'coyote', 'crafty rascal', 'dingo', 'dodger', 'fox'],
    'rf': ['af', 'cps', 'ehf', 'hf', 'hz', 'mf', 'shf', 'uhf', 'vhf', 'vlf', 'audio frequency', 'carrier frequency'],
    'rfd': ['pp', 'rd', 'airmail', 'book post', 'correspondence', 'direct mail', 'direct-mail selling', 'express', 'fourth-class mail', 'frank', 'halfpenny post', 'junk mail'],
    'rh factor': ['rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'agglutinin', 'allergen', 'anaphylactin', 'antiantibody', 'antibody', 'antigen', 'antiserum', 'antitoxic serum'],
    'rhadamanthus': ['aeacus', 'aides', 'aidoneus', 'astraea', 'cerberus', 'charon', 'cora', 'despoina', 'dike', 'dis', 'dis pater', 'erebus'],
    'rhapsodic': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'bardic', 'blissful', 'bucolic', 'bursting with happiness'],
    'rhapsodical': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'bardic', 'bucolic', 'bursting with happiness', 'carried away'],
    'rhapsodist': ['don quixote', 'meistersinger', 'parnassian', 'quixote', 'addict', 'arch-poet', 'ballad maker', 'ballad singer', 'balladeer', 'balladmonger', 'bard', 'beat poet'],
    'rhapsodize': ['acclaim', 'be enthusiastic', 'bubble over', 'carry on over', 'drool', 'effervesce', 'enthuse', 'extol', 'go on over', 'gush', 'gush over', 'idealize'],
    'rhapsody': ['classic', 'classical music', 'concert music', 'concertino', 'concerto', 'concerto grosso', 'drool', 'fustian', 'heaven', 'highfalutin', 'lexiphanicism', 'longhair music'],
    'rhetoric': ['barnumism', 'affectation', 'articulateness', 'bedizenment', 'big talk', 'bluster', 'bombast', 'choice of words', 'command of language', 'command of words', 'composition', 'convolution'],
    'rhetorical': ['gongoresque', 'johnsonian', 'affected', 'articulate', 'artificial', 'aureate', 'bedizened', 'big-sounding', 'bombastic', 'chichi', 'contrived', 'convoluted'],
    'rhetorician': ['cicero', 'demosthenes', 'gongorist', 'marinist', 'william jennings bryan', 'winston churchill', 'elocutionist', 'euphuist', 'fine writer', 'mannerist', 'master of style', 'orator'],
    'rheum': ['asiatic flu', 'hong kong flu', 'abscess', 'acute bronchitis', 'adenoiditis', 'ague', 'aluminosis', 'amygdalitis', 'anemia', 'ankylosis', 'anoxia', 'anthracosilicosis'],
    'rheumatic': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'cancerous', 'case', 'chlorotic', 'colicky', 'consumptive', 'dropsical', 'dyspeptic'],
    'rheumatic fever': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'rheumatism': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis'],
    'rheumy': ['bloody', 'chylifactive', 'chylifactory', 'chylific', 'excretory', 'humoral', 'ichorous', 'lachrymal', 'lachrymose', 'lacrimatory', 'lactational', 'lacteal'],
    'rhinestone': ['anklet', 'armlet', 'bangle', 'beads', 'bijou', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet', 'charm', 'chatelaine'],
    'rhomboid': ['bend', 'bias', 'cube-shaped', 'cubed', 'cubic', 'cubiform', 'cuboid', 'diagonal', 'diced', 'foursquare', 'oblique', 'oblique angle'],
    'rhubarb': ['bedlam let loose', 'irish potato', 'kraut', 'altercation', 'apologetics', 'apologia', 'apology', 'argument', 'argumentation', 'aubergine', 'barney', 'beans'],
    'rhyme': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'accord', 'alba', 'alliterate', 'alliteration', 'anacreontic'],
    'rhyming': ['alliteral', 'alliterating', 'alliterative', 'assonant', 'assonantal', 'belabored', 'chanting', 'chiming', 'cliche-ridden', 'dingdong', 'harping', 'humdrum'],
    'rhythm': ['alexandrine', 'accent', 'accentuation', 'alternation', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antispast', 'arrhythmia', 'arsis', 'bacchius'],
    'rhythm-and-blues': ['acid rock', 'avant-garde jazz', 'ballroom music', 'bebop', 'boogie-woogie', 'bop', 'country rock', 'dance music', 'dances', 'folk rock', 'hard rock', 'hot jazz'],
    'rhythmic': ['alternate', 'antispastic', 'beating', 'cadenced', 'cadent', 'circling', 'cyclic', 'dactylic', 'epochal', 'even', 'every other', 'iambic'],
    'rhythmical': ['alternate', 'antispastic', 'beating', 'cadenced', 'cadent', 'circling', 'cyclic', 'dactylic', 'epochal', 'even', 'every other', 'iambic'],
    'rialto': ['agora', 'auto show', 'bazaar', 'boat show', 'campo', 'commercial complex', 'emporium', 'exposition', 'fair', 'flea fair', 'flea market', 'forum'],
    'rib': ['chateaubriand', 'banter', 'better half', 'bilge', 'blade roast', 'blain', 'bleb', 'blister', 'blob', 'boss', 'bow', 'breast'],
    'ribald': ['babbitt', 'fescennine', 'philistine', 'rabelaisian', 'abusive', 'arriviste', 'bawdy', 'blasphemous', 'blue', 'boor', 'bounder', 'bourgeois'],
    'ribaldry': ['rabelaisianism', 'x-rated movie', 'bad language', 'bawdiness', 'bawdry', 'billingsgate', 'blue language', 'blue movie', 'coarseness', 'colorful language', 'crassness', 'crudeness'],
    'ribbed': ['canaliculate', 'canaliculated', 'chamfered', 'channeled', 'corduroy', 'corduroyed', 'corrugate', 'corrugated', 'costate', 'crimped', 'cut', 'dadoed'],
    'ribbon': ['mystik tape', 'scotch tape', 'x ray', 'actinic ray', 'actinism', 'adhesive tape', 'arch', 'atomic beam', 'atomic ray', 'band', 'bandage', 'bandeau'],
    'riboflavin': ['adermin', 'aneurin', 'antiberi-beri factor', 'ascorbic acid', 'axerophthol', 'biotin', 'carotene', 'cholecalciferol', 'choline', 'cobalamin', 'cryptoxanthin', 'cyanocobalamin'],
    'rich': ['abounding', 'abounding in riches', 'absurd', 'abundant', 'achingly sweet', 'adipose', 'affluent', 'agreeable', 'agreeable-sounding', 'all-sufficing', 'ambrosial', 'ample'],
    'rich man': ['daddy warbucks', 'billionaire', 'bloated plutocrat', 'capitalist', 'fat cat', 'individualist', 'man of means', 'man of substance', 'man of wealth', 'millionaire', 'moneybags', 'moneyed man'],
    'riches': ['abundance', 'affluence', 'assets', 'bottomless purse', 'bulging purse', 'easy circumstances', 'embarras de richesses', 'fortune', 'gold', 'handsome fortune', 'high income', 'high tax bracket'],
    'rick': ['abundance', 'accumulation', 'amassment', 'anthill', 'archives', 'armory', 'arsenal', 'attic', 'backlog', 'bank', 'bank up', 'basement'],
    'rickets': ['lombardy leprosy', 'anemia', 'ariboflavinosis', 'beriberi', 'cachexia', 'chlorosis', 'deficiency anemia', 'dermatitis', 'goiter', 'greensickness', 'keratomalacia', 'kwashiorkor'],
    'rickety': ['adrift', 'afloat', 'allergic', 'anemic', 'anile', 'apoplectic', 'arthritic', 'bagging', 'baggy', 'bandy', 'bandy-legged', 'bilious'],
    'ricochet': ['backfire', 'backlash', 'backlashing', 'boomerang', 'bounce', 'bounce back', 'bound', 'bound back', 'cannon', 'cannon off', 'carom', 'contrecoup'],
    'rictus': ['bob', 'bobble', 'bounce', 'bump', 'didder', 'dither', 'falter', 'grimace', 'jar', 'jerk', 'jig', 'jigget'],
    'rid': ['abandon', 'abjure', 'abolish', 'abstract', 'assassinate', 'cast', 'cast aside', 'cast away', 'cast off', 'cast out', 'cede', 'chuck'],
    'riddance': ['abandonment', 'abjuration', 'break', 'breakout', 'cession', 'clearance', 'deliverance', 'delivery', 'deportation', 'detachment', 'discard', 'discarding'],
    'riddle': ['chinese puzzle', 'anagram', 'answer', 'arabesque', 'assort', 'auger', 'babble', 'baffle', 'bafflement', 'basketry', 'basketwork', 'be greek to'],
    'ride': ['sunday drive', 'abut on', 'aggravate', 'airing', 'annoy', 'auto', 'badger', 'bait', 'bamboozle', 'banter', 'be at', 'be based on'],
    'ride out': ['be safe', 'be unflappable', 'come through', 'get home free', 'hold fast', 'hold out', 'hold up', 'keep safe', 'make heavy weather', 'not budge', 'outride', 'pull through'],
    'ride roughshod over': ['beat down', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'clamp down on', 'coerce', 'compel', 'cow', 'daunt', 'despotize'],
    'ride to hounds': ['beat', 'chase', 'course', 'dog', 'drive', 'falcon', 'flush', 'follow the hounds', 'fowl', 'go hunting', 'gun', 'hawk'],
    'rider': ['addendum', 'affix', 'allonge', 'appendix', 'bidet', 'bill', 'broncobuster', 'buckaroo', 'caballero', 'calendar', 'carriage horse', 'cart horse'],
    'ridge': ['acme', 'apex', 'apogee', 'arete', 'back', 'bean', 'bilge', 'blain', 'bleb', 'blister', 'blob', 'boss'],
    'ridicule': ['airs', 'arrogance', 'badinage', 'banter', 'barrack', 'be above', 'be contemptuous of', 'be disrespectful', 'be merry with', 'be overfamiliar with', 'brashness', 'brassiness'],
    'ridiculing': ['abusive', 'aweless', 'back-biting', 'bantering', 'belittling', 'bitchy', 'blackening', 'blameful', 'booing', 'calumniatory', 'calumnious', 'catcalling'],
    'ridiculous': ['a bit thick', 'a bit thin', 'absurd', 'amusing', 'antic', 'barred', 'beyond belief', 'bizarre', 'closed-out', 'cockamamie', 'comic', 'comical'],
    'riding': ['kreis', 'anchorage', 'archbishopric', 'archdiocese', 'arrondissement', 'automobiling', 'bailiwick', 'bicycling', 'biking', 'bishopric', 'borough', 'busing'],
    'rife': ['abounding', 'abundant', 'affluent', 'afloat', 'alive with', 'all-sufficing', 'ample', 'aplenty', 'average', 'bandied about', 'besetting', 'bottomless'],
    'riffle': ['ball up', 'billow', 'bollix up', 'bore', 'breakers', 'chop', 'choppiness', 'chopping sea', 'chute', 'cockle', 'comb', 'comber'],
    'riffraff': ['bilge', 'bilgewater', 'canaille', 'carrion', 'cattle', 'chaff', 'clamjamfry', 'debris', 'dishwater', 'ditchwater', 'dregs', 'dregs of society'],
    'rifle': ['amazon', 'zouave', 'air serviceman', 'automatic', 'bersagliere', 'blowgun', 'blowpipe', 'brave', 'burglarize', 'burgle', 'canal', 'canalize'],
    'rifleman': ['amazon', 'nimrod', 'zouave', 'air serviceman', 'archer', 'artilleryman', 'bersagliere', 'bowman', 'brave', 'cannon fodder', 'cannoneer', 'carabineer'],
    'rift': ['abysm', 'abyss', 'alienation', 'arroyo', 'birthmark', 'blackhead', 'bleb', 'blemish', 'blister', 'box canyon', 'breach', 'breach of friendship'],
    'rig': ['dalai lama', 'holy roman emperor', 'inca', 'kaiser', 'accouter', 'accouterments', 'adulterate', 'angle', 'antic', 'apparatus', 'appliances', 'appoint'],
    'rigamarole': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'blabber', 'blather', 'bombast', 'claptrap', 'double-talk', 'drivel'],
    'rigged': ['accoutered', 'armed', 'catered', 'cooked', 'cooked-up', 'cut out', 'cut-and-dried', 'cut-and-dry', 'decked', 'doctored', 'endowed', 'engineered'],
    'rigged out': ['appareled', 'arrayed', 'attired', 'bedecked', 'breeched', 'capped', 'chausse', 'clad', 'cloaked', 'clothed', 'coifed', 'costumed'],
    'rigging': ['accouterments', 'advocate', 'alpenstock', 'anchor chain', 'anchor rode', 'apparatus', 'apparel', 'appliances', 'appointments', 'appurtenances', 'arm', 'armament'],
    'right': ['bill of rights', 'bircher', 'bourbon', 'christian', 'declaration of right', 'epistle side', 'magna carta', 'magna charta', 'ok', 'petition of right', 'roger', 'tory'],
    'right and left': ['abroad', 'all about', 'all round', 'aside', 'askance', 'askant', 'asquint', 'broadly', 'broadside', 'broadside on', 'crabwise', 'edgeway'],
    'right away': ['pdq', 'all at once', 'all together', 'apace', 'at a blow', 'at a stroke', 'at once', 'at one blow', 'at one jump', 'at one stroke', 'at one swoop', 'at one time'],
    'right hand': ['epistle side', 'alter ego', 'clockwise', 'confidant', 'conservative', 'decanal side', 'dexter', 'dextral', 'dextrocardial', 'dextrocerebral', 'dextrocular', 'dextrogyrate'],
    'right hand man': ['alter ego', 'assistant', 'confidant', 'employee', 'fidus achates', 'girl friday', 'helper', 'hired hand', 'hired man', 'hireling', 'inferior', 'junior'],
    'right mind': ['balance', 'contact with reality', 'healthy mind', 'lucid interval', 'lucidity', 'mental balance', 'mental equilibrium', 'mental health', 'mental hygiene', 'mental poise', 'normalcy', 'normality'],
    'right minded': ['christian', 'angelic', 'appositeness', 'appropriateness', 'aptness', 'blameless', 'clean', 'creditable', 'decent', 'erect', 'estimable', 'ethical'],
    'right sort': ['acceptable person', 'capital fellow', 'diamond', 'gem', 'gentleman', 'good fellow', 'good lot', 'good man', 'good person', 'good sort', 'good woman', 'honest man'],
    'right wing': ['bircher', 'bourbon', 'epistle side', 'tory', 'backward', 'bitter-ender', 'clockwise', 'conservatist', 'conservative', 'decanal side', 'dexter', 'dextral'],
    'right winger': ['bircher', 'bourbon', 'epistle side', 'tory', 'conservationist', 'conservatist', 'conservative', 'decanal side', 'diehard', 'extreme right-winger', 'fogy', 'hard hat'],
    'right-about-face': ['about-face', 'about-turn', 'afterthoughts', 'back track', 'back trail', 'backing', 'backing off', 'backing out', 'backing up', 'backup', 'better thoughts', 'change of mind'],
    'right-of-way': ['autobahn', 'us highway', 'accomplishment', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'ascendancy', 'autoroute', 'autostrada'],
    'righteous': ['christendom', 'christian', 'christlike', 'christly', 'god-fearing', 'according to hoyle', 'angelic', 'appropriate', 'apt', 'blameless', 'clean', 'condign'],
    'righteousness': ['christianity', 'christlikeness', 'christliness', 'angelicalness', 'appropriateness', 'assured probity', 'beauty of holiness', 'blamelessness', 'character', 'cleanness', 'correctitude', 'correctness'],
    'rightful': ['according to hoyle', 'actionable', 'applicable', 'appropriate', 'apt', 'authentic', 'authorized', 'balanced', 'becoming', 'befitting', 'bona fide', 'candid'],
    'rightfully': ['appropriately', 'as is proper', 'as is right', 'by right', 'by rights', 'condignly', 'correctly', 'deservedly', 'disinterestedly', 'dispassionately', 'duly', 'equally'],
    'rightist': ['bircher', 'bourbon', 'tory', 'bitter-ender', 'conservationist', 'conservatist', 'conservative', 'diehard', 'extreme right-winger', 'fogy', 'fundamentalist', 'hard hat'],
    'rightly': ['accurately', 'advantageously', 'advisably', 'appropriately', 'as is proper', 'as is right', 'by right', 'by rights', 'condignly', 'congruously', 'conveniently', 'correctly'],
    'rightness': ['absoluteness', 'accuracy', 'attention to fact', 'care for truth', 'correctness', 'delicacy', 'exactitude', 'exactness', 'faithfulness', 'faultlessness', 'fidelity', 'fineness'],
    'rightward': ['anticlockwise', 'astarboard', 'clockwise', 'counterclockwise', 'dexter', 'dextrad', 'dextrally', 'earthward', 'heavenward', 'homeward', 'landward', 'leeward'],
    'rigid': ['abiding', 'accurate', 'adamant', 'adamantine', 'at a standstill', 'attentive', 'austere', 'buckram', 'careful', 'cast-iron', 'changeless', 'close'],
    'rigidity': ['abidingness', 'absoluteness', 'accuracy', 'adamantness', 'attention to fact', 'care for truth', 'changelessness', 'concentration', 'constancy', 'correctness', 'delicacy', 'dourness'],
    'rigidly': ['abidingly', 'absolutely', 'adamantly', 'always', 'changelessly', 'dead', 'definitely', 'directly', 'dourly', 'enduringly', 'even', 'exactly'],
    'rigmarole': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'blabber', 'blather', 'bombast', 'claptrap', 'double-talk', 'drivel'],
    'rigor': ['albigensianism', 'catharism', 'franciscanism', 'sabbatarianism', 'trappism', 'waldensianism', 'yoga', 'absolute zero', 'absoluteness', 'abstinence', 'abstruseness', 'accuracy'],
    'rigorous': ['herculean', 'siberian', 'abstruse', 'accurate', 'acid', 'acidulous', 'acrid', 'acrimonious', 'acute', 'adamant', 'adamantine', 'adverse'],
    'rigorously': ['absolutely', 'accurately', 'adamantly', 'all to pieces', 'badly', 'conscientiously', 'dead', 'definitely', 'directly', 'dourly', 'even', 'exactingly'],
    'rile': ['aggravate', 'agitate', 'annoy', 'arouse', 'badger', 'bait', 'be at', 'beat', 'beat up', 'bedevil', 'beset', 'bother'],
    'riled': ['aggravated', 'angered', 'angry', 'annoyed', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'chafed', 'cross', 'disturbed', 'exasperated'],
    'rim': ['adjoin', 'balloon tire', 'bank', 'befringe', 'belted bias tire', 'belted radial tire', 'bias tire', 'bind', 'board', 'border', 'bordure', 'bound'],
    'rime': ['jack frost', 'abysm', 'abyss', 'arroyo', 'black frost', 'box canyon', 'breach', 'break', 'canyon', 'cavity', 'chap', 'chasm'],
    'rimple': ['cocker', 'cockle', 'corrugate', 'corrugation', 'crankle', 'crease', 'crimp', 'crimple', 'crinkle', 'crumple', 'fold', 'furrow'],
    'rind': ['leatherette', 'leatheroid', 'bark', 'border', 'bran', 'capsule', 'case', 'chaff', 'circumference', 'coat', 'cork', 'corn shuck'],
    'ring': ['bund', 'chinese boxing', 'ddd', 'kekule formula', 'rochdale cooperative', 'affiliation', 'agora', 'alliance', 'amphitheater', 'anklet', 'annular muscle', 'annulet'],
    'ring in': ['accomplish', 'achieve', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be received', 'blow in', 'bob up', 'bring up'],
    'ringed': ['begirt', 'belted', 'cinctured', 'circled', 'circumscribed', 'circumscript', 'defined', 'definite', 'delimited', 'demarcated', 'determinate', 'determined'],
    'ringer': ['agent', 'alternate', 'alternative', 'analogy', 'backup', 'blagueur', 'bluff', 'bluffer', 'change', 'changeling', 'charlatan', 'comparison'],
    'ringing': ['booming', 'change ringing', 'chime', 'chiming', 'chink', 'clang', 'clanging', 'clangor', 'clank', 'clanking', 'clink', 'consonant'],
    'ringleader': ['mahdi', 'agent provocateur', 'agitator', 'agitprop', 'bell cow', 'bell mare', 'bellwether', 'born leader', 'boss', 'cacique', 'catalyst', 'charismatic leader'],
    'ringlet': ['annulet', 'circlet', 'cirrus', 'coil', 'corkscrew', 'crimp', 'curl', 'curlicue', 'evolute', 'eye', 'eyelet', 'frizz'],
    'ringmaster': ['mc', 'acrobat', 'aerialist', 'auteur', 'ballyhoo man', 'bareback rider', 'barker', 'callboy', 'circus artist', 'clown', 'costume designer', 'costumer'],
    'ringside': ['texas tower', 'beacon', 'belvedere', 'bleachers', 'bridge', 'conning tower', 'gallery', 'gazebo', 'grandstand', 'lighthouse', 'lookout', 'loophole'],
    'ringworm': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acne', 'acne vulgaris', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery'],
    'rink': ['archery ground', 'athletic field', 'badminton court', 'baseball field', 'basketball court', 'billiard parlor', 'bowling alley', 'bowling green', 'course', 'court', 'cricket ground', 'croquet ground'],
    'rinse': ['ablution', 'abstergent', 'baptize', 'bath', 'bathe', 'bathing', 'brew', 'cathartic', 'clean', 'cleaner', 'cleaning', 'cleaning agent'],
    'rinsing': ['ablution', 'affusion', 'aspergation', 'aspersion', 'baptism', 'bath', 'bathing', 'bedewing', 'bones', 'chaff', 'cleaning out', 'culm'],
    'riot': ['abundance', 'ado', 'affluence', 'affray', 'ample sufficiency', 'ampleness', 'amplitude', 'anarchism', 'anarchy', 'arise', 'assault', 'attack'],
    'rioter': ['agitator', 'battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'combatant', 'competitor'],
    'rioting': ['assault', 'attack', 'battering', 'butchery', 'disorderliness', 'forcible seizure', 'killing', 'laying waste', 'looting', 'massacre', 'obstreperousness', 'onslaught'],
    'riotous': ['abandoned', 'abounding', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'boisterous', 'bottomless', 'bounteous', 'bountiful', 'brawling'],
    'rip': ['casanova', 'don juan', 'lothario', 'abrade', 'abrasion', 'agonize', 'badger', 'ball the jack', 'bark', 'barrel', 'blackmail', 'blemish'],
    'rip off': ['burglary', 'caper', 'cheat', 'clinquant', 'commit robbery', 'counterfeit', 'deception', 'dummy', 'fake', 'fakement', 'filch', 'flam'],
    'rip out': ['avulse', 'cut out', 'deracinate', 'dig out', 'dig up', 'disentangle', 'draw', 'draw out', 'dredge', 'dredge up', 'eradicate', 'evolve'],
    'rip roaring': ['anarchic', 'angry', 'blaring', 'blatant', 'blatting', 'blustering', 'blusterous', 'blustery', 'boisterous', 'brassy', 'brawling', 'brazen'],
    'ripe': ['accomplished', 'adult', 'age', 'aged', 'all ready', 'all set', 'appropriate', 'apt', 'archetypical', 'armed', 'armed and ready', 'auspicious'],
    'ripen': ['advance', 'age', 'alter into', 'attain majority', 'be converted into', 'bear fruit', 'beautify', 'become', 'better', 'bloom', 'blossom', 'blow'],
    'ripened': ['adult', 'archetypical', 'blase', 'classic', 'consummate', 'cosmopolitan', 'cosmopolite', 'developed', 'exemplary', 'experienced', 'expert', 'finished'],
    'riposte': ['acknowledge', 'acknowledgment', 'advocate', 'allege in support', 'answer', 'answer back', 'answering', 'antiphon', 'aphorism', 'apothegm', 'argue for', 'argument'],
    'ripping': ['ok', 'abscission', 'ace-high', 'amputation', 'bad', 'bang-up', 'bonzer', 'boss', 'bully', 'but good', 'butchering', 'chopping'],
    'ripple': ['agitate', 'agitation', 'babble', 'beat', 'beat up', 'billow', 'bore', 'breakers', 'broken ground', 'broken water', 'bubble', 'burble'],
    'rippled': ['cockled', 'cockly', 'corrugate', 'corrugated', 'creased', 'crimped', 'crimpy', 'crinkled', 'crinkly', 'crumpled', 'furrowed', 'knitted'],
    'ripply': ['broken', 'bumpy', 'choppy', 'coarse', 'coarse-grained', 'corrugated', 'cross-grained', 'grainy', 'granulated', 'homespun', 'horripilant', 'inequal'],
    'riptide': ['direct tide', 'ebb', 'ebb and flow', 'ebb tide', 'flood', 'flood tide', 'flow', 'flux', 'flux and reflux', 'full tide', 'high tide', 'high water'],
    'rise': ['great leap forward', 'olympian heights', 'abruptness', 'access', 'accession', 'acclivity', 'accomplishment', 'accretion', 'accrual', 'accrue', 'accrue from', 'accruement'],
    'rise above': ['accept', 'beat', 'best', 'bestraddle', 'bestride', 'bulk', 'bulk large', 'clear', 'command', 'condone', 'countenance', 'defeat'],
    'risibility': ['homeric laughter', 'belly laugh', 'boff', 'boffola', 'burst of laughter', 'cachinnation', 'cackle', 'chortle', 'chuckle', 'convulsion', 'crow', 'fit of laughter'],
    'risible': ['absurd', 'amusing', 'bizarre', 'buxom', 'comic', 'comical', 'droll', 'eccentric', 'farcical', 'frivolous', 'funny', 'gleeful'],
    'rising': ['brownian movement', 'abruptness', 'abscess', 'acclinate', 'acclivitous', 'acclivity', 'advance', 'anabasis', 'anabatic', 'angular motion', 'aposteme', 'apparition'],
    'risk': ['accident', 'accidentality', 'actuarial calculation', 'admit of', 'adventitiousness', 'adventure', 'be liable', 'be subjected to', 'beard', 'bet', 'bid fair to', 'brave'],
    'riskiness': ['chanciness', 'criticalness', 'danger', 'delicacy', 'desultoriness', 'doubtfulness', 'dubiousness', 'hazard', 'hazardousness', 'infirmity', 'insecurity', 'insolidity'],
    'risky': ['accidental', 'adventitious', 'adventurous', 'aleatory', 'blue', 'broad', 'casual', 'causeless', 'chance', 'chancy', 'contingent', 'dangerous'],
    'risque': ['rabelaisian', 'abusive', 'bawdy', 'blasphemous', 'blue', 'broad', 'calumniatory', 'calumnious', 'comminatory', 'contumelious', 'cursing', 'damnatory'],
    'ritardando': ['a poco', 'adagietto', 'adagio', 'allargando', 'allegretto', 'allegro', 'andante', 'andantino', 'calando', 'crescendo', 'decrescendo', 'diminuendo'],
    'rite': ['amenities', 'anniversaries', 'baccalaureate service', 'celebrating', 'celebration', 'ceremonial', 'ceremonies', 'ceremony', 'civilities', 'commemoration', 'commencement', 'convocation'],
    'rite of passage': ['baccalaureate service', 'celebration', 'ceremonial', 'ceremony', 'commencement', 'convocation', 'empty formality', 'exercise', 'exercises', 'formal', 'formality', 'function'],
    'ritual': ['high-church', 'sefer torah', 'torah', 'torah scroll', 'virginal', 'amenities', 'automatic', 'baccalaureate service', 'baptismal', 'bon ton', 'breviary', 'buckram'],
    'ritualistic': ['high-church', 'baptismal', 'ceremonial', 'ceremonious', 'conventional', 'decorous', 'eucharistic', 'formal', 'formular', 'formulary', 'hieratic', 'liturgic'],
    'ritzy': ['babylonian', 'corinthian', 'awe-inspiring', 'awful', 'barbaric', 'braw', 'chic', 'classy', 'clothes-conscious', 'cosmopolitan', 'dapper', 'dashing'],
    'rival': ['admit of comparison', 'adversary', 'adversative', 'adverse', 'alien', 'amount to', 'antagonist', 'antagonistic', 'antagonize', 'anti', 'antipathetic', 'antithetic'],
    'rivaling': ['a cut above', 'above', 'ahead', 'ascendant', 'better', 'capping', 'chosen', 'competing', 'competitive', 'cutthroat', 'distinguished', 'eclipsing'],
    'rivalry': ['antagonism', 'antipathy', 'bad blood', 'clashing', 'collision', 'competition', 'competitiveness', 'conflict', 'contention', 'contrariety', 'contrariness', 'controversy'],
    'rive': ['amputate', 'ax', 'bisect', 'breach', 'break', 'broach', 'butcher', 'carve', 'check', 'chink', 'chop', 'cleave'],
    'river': ['niagara', 'adolescent stream', 'arroyo', 'beck', 'bourn', 'braided stream', 'branch', 'brook', 'brooklet', 'burn', 'cascade', 'cataract'],
    'riverhead': ['font', 'fount', 'fountain', 'fountainhead', 'head', 'headspring', 'headstream', 'headwater', 'headwaters', 'mainspring', 'mine', 'quarry'],
    'riverside': ['bank', 'beach', 'berm', 'coast', 'coastal', 'coastland', 'coastline', 'embankment', 'foreshore', 'ironbound coast', 'lido', 'littoral'],
    'rivet': ['affix', 'articulate', 'attach', 'batten', 'batten down', 'bolt', 'buckle', 'butt', 'button', 'clasp', 'cleat', 'clip'],
    'riviera': ['bank', 'beach', 'berm', 'coast', 'coastland', 'coastline', 'embankment', 'foreshore', 'ironbound coast', 'lido', 'littoral', 'plage'],
    'rivulet': ['adolescent stream', 'arroyo', 'beck', 'bourn', 'braided stream', 'branch', 'brook', 'brooklet', 'burn', 'channel', 'creek', 'crick'],
    'rn': ['lpn', 'naval construction battalion', 'royal navy', 'seabees', 'usn', 'united states navy', 'argosy', 'armada', 'charge nurse', 'coast guard', 'district nurse', 'division'],
    'rna': ['altmann theory', 'dna', 'dna double helix', 'de vries theory', 'galtonian theory', 'mendelianism', 'mendelism', 'verworn theory', 'weismann theory', 'weismannism', 'wiesner theory', 'allele'],
    'roach': ['det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'acid', 'afterglow', 'afterimage', 'antidepressant', 'ataractic', 'balance'],
    'road': ['autobahn', 'us highway', 'access', 'air lane', 'alley', 'alleyway', 'anchorage', 'anchorage ground', 'approach', 'approaches', 'arm', 'armlet'],
    'road hog': ['sunday driver', 'backseat driver', 'bus driver', 'busman', 'cabby', 'cabdriver', 'careerist', 'chauffeur', 'driver', 'egotist', 'fortune hunter', 'hack'],
    'road map': ['baedeker', 'lambert conformal projection', 'mercator projection', 'miller projection', 'yellow pages', 'aeronautical chart', 'astronomical chart', 'atlas', 'azimuthal projection', 'bibliography', 'business directory', 'cartographer'],
    'road test': ['gedankenexperiment', 'assay', 'audition', 'bench test', 'bring to test', 'confirm', 'cut and try', 'dry run', 'essay', 'experiment', 'flight test', 'give a try'],
    'roadbed': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'roadblock': ['arch dam', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barricade', 'barrier', 'bear-trap dam', 'beaver dam', 'blank wall', 'block'],
    'roadhouse': ['amusement park', 'ballroom', 'boardinghouse', 'cabaret', 'cafe chantant', 'cafe dansant', 'casino', 'dance floor', 'dance hall', 'dancing pavilion', 'dorm', 'dormitory'],
    'roadway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'roam': ['amble', 'bat', 'bat around', 'bum', 'circumambulate', 'count ties', 'cruise', 'dally', 'dawdle', 'divagate', 'drift', 'flit'],
    'roamer': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'bird of passage', 'drifter', 'floater'],
    'roaming': ['wanderjahr', 'afoot and lighthearted', 'bumming', 'circumforaneous', 'discursion', 'discursive', 'divagation', 'divagatory', 'drifting', 'errant', 'errantry', 'flitting'],
    'roan': ['titian', 'adust', 'auburn', 'bay', 'bay-colored', 'bayard', 'brazen', 'bronze', 'bronze-colored', 'bronzed', 'brownish-red', 'buckskin'],
    'roar': ['bedlam let loose', 'assault', 'attack', 'barbarize', 'bark', 'batter', 'battle cry', 'bawl', 'bay', 'be in stitches', 'be noisy', 'bedlam'],
    'roaring': ['abandoned', 'amok', 'bellowing', 'berserk', 'blaring', 'booming', 'cannonading', 'carried away', 'delirious', 'demoniac', 'distracted', 'earsplitting'],
    'roast': ['chateaubriand', 'aspic', 'assail', 'attack', 'bake', 'baked', 'banter', 'barbecue', 'baste', 'be in heat', 'blade roast', 'blanch'],
    'roaster': ['bantam', 'cornish hen', 'banterer', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'broiler', 'brooder', 'broody hen', 'caille', 'canard'],
    'roasting': ['ardent', 'ass-reaming', 'baking', 'banter', 'bantering', 'barbecuing', 'basting', 'bawling-out', 'blistering', 'boiling', 'booing', 'braising'],
    'rob': ['bereave', 'cheat', 'commit robbery', 'defraud', 'despoil', 'disinherit', 'dispossess', 'divest', 'filch', 'heist', 'hijack', 'hold up'],
    'robber': ['bandit', 'bank robber', 'body snatcher', 'booster', 'brigand', 'buccaneer', 'burglar', 'bushranger', 'cat burglar', 'cat man', 'chicken thief', 'con man'],
    'robbery': ['armed robbery', 'asportation', 'assault and robbery', 'banditry', 'bank robbery', 'bereavement', 'breaking and entering', 'burglary', 'burgling', 'caper', 'cattle lifting', 'cattle stealing'],
    'robe': ['afghan', 'apparel', 'appurtenances', 'array', 'attire', 'bathrobe', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedeck', 'bedrape'],
    'robin hood': ['autolycus', 'barabbas', 'bill sikes', 'claude duval', 'dick turpin', 'jack sheppard', 'jean valjean', 'jimmy valentine', 'john dillinger', 'jonathan wild', 'raffles', 'thief of baghdad'],
    'robotlike': ['accordant', 'alike', 'automatic', 'balanced', 'consistent', 'consonant', 'constant', 'continuous', 'correspondent', 'equable', 'equal', 'even'],
    'robust': ['able-bodied', 'active', 'acute', 'aggressive', 'animated', 'athletic', 'beefy', 'booming', 'bouncing', 'brawny', 'brisk', 'doughty'],
    'rock': ['gibraltar', 'irish confetti', 'acid rock', 'adamant', 'adamantine', 'affect', 'agitate', 'amaze', 'appease', 'astonish', 'astound', 'avant-garde jazz'],
    'rock bottom': ['base', 'basement', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock', 'belly', 'best', 'bottom', 'bottom side', 'bottommost'],
    'rock garden': ['japanese garden', 'alpine garden', 'arboretum', 'bed', 'bog garden', 'border', 'botanical garden', 'dry garden', 'flower bed', 'flower garden', 'garden', 'garden spot'],
    'rockbound': ['corrugated', 'cragged', 'craggy', 'crinkled', 'crumpled', 'dour', 'firm', 'fundamentalist', 'gravelly', 'hard', 'harsh', 'hidebound'],
    'rockbound coast': ['bank', 'beach', 'berm', 'coast', 'coastland', 'coastline', 'coral heads', 'embankment', 'foreshore', 'ironbound coast', 'ledges', 'lee shore'],
    'rocker': ['burin', 'clarifier', 'colander', 'cradle', 'cribble', 'die', 'engraving tool', 'etching ball', 'etching ground', 'etching needle', 'etching point', 'filter'],
    'rocket': ['aa target rocket', 'abm', 'asm', 'ats', 'asp', 'asroc', 'atlas', 'atlas-agena', 'atlas-centaur', 'bullpup', 'cajun', 'corporal'],
    'rocket power': ['action and reaction', 'aeromotor', 'atomic power', 'electric power', 'electropower', 'horsepower', 'hydraulic power', 'hydroelectric power', 'impulse', 'jet power', 'jet propulsion', 'manpower'],
    'rocket propulsion': ['action and reaction', 'aeromotor', 'charge', 'diesel propulsion', 'exhaust', 'fuel', 'gas propulsion', 'gasoline propulsion', 'jet power', 'jet propulsion', 'liquid oxygen', 'plasma-jet propulsion'],
    'rocketry': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics'],
    'rocking': ['appeasing', 'calming', 'careening', 'cradling', 'dangling', 'dreamy', 'drowsy', 'gentling', 'hushing', 'lulling', 'lurching', 'mollifying'],
    'rocking horse': ['agate', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble', 'blocks', 'checkerboard', 'chessboard', 'club', 'cockhorse', 'cricket bat'],
    'rocky': ['adamant', 'adamantine', 'ailing', 'apathetic', 'arduous', 'bad', 'below par', 'bony', 'bumpy', 'callous', 'cement', 'cemental'],
    'rococo': ['gothic', 'arabesque', 'archaic', 'baroque', 'baroqueness', 'bizarre', 'brain-born', 'busy', 'bygone', 'chichi', 'chinoiserie', 'dated'],
    'rod': ['maypole', 'atomic pile', 'automatic', 'bar', 'baton', 'billet', 'birch', 'blowgun', 'blowpipe', 'breeder reactor', 'bricks', 'caduceus'],
    'rodent': ['amphibian', 'aquatic', 'biped', 'canine', 'cannibal', 'carnivore', 'cosmopolite', 'feline', 'gnawer', 'herbivore', 'insectivore', 'invertebrate'],
    'rodeo': ['assemblage', 'assembly', 'burlesque show', 'call-up', 'canvass', 'carnival', 'census', 'circus', 'collection', 'colligation', 'collocation', 'combination'],
    'rodomontade': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'blabber', 'blather', 'bluff', 'bluster', 'bluster and bluff', 'blustering'],
    'roe': ['cape elk', 'partlet', 'virginia deer', 'albumen', 'anguille', 'antelope', 'biddy', 'bitch', 'bossy', 'brood mare', 'buck', 'camel'],
    'roebuck': ['cape elk', 'virginia deer', 'antelope', 'buck', 'camel', 'camelopard', 'caribou', 'deer', 'deerlet', 'doe', 'dromedary', 'eland'],
    'roentgenograph': ['ecg', 'eeg', 'ekg', 'x ray', 'x-ray movie', 'chest x-ray', 'electrocardiogram', 'electrocorticogram', 'electroencephalogram', 'electroencephalograph', 'electromyogram', 'encephalogram'],
    'roentgenotherapy': ['x-ray dosimetry', 'x-ray therapy', 'cobalt therapy', 'curietherapy', 'irradiation', 'irradiation therapy', 'isotope therapy', 'radiation therapy', 'radiotherapeutics', 'radiotherapy', 'radium therapy', 'radiumization'],
    'roger': ['ok', 'absolutely', 'all right', 'alright', 'alrighty', 'amen', 'as you say', 'assuredly', 'aye', 'by all means', 'certainly', 'da'],
    'rogue': ['sob', 'bad boy', 'balker', 'balky horse', 'bastard', 'blackguard', 'blighter', 'booger', 'bounder', 'buffoon', 'bugger', 'bum'],
    'roguery': ['baseness', 'chicanery', 'degradation', 'devilishness', 'devilment', 'devilry', 'deviltry', 'elfishness', 'foolishness', 'high spirits', 'impishness', 'knavery'],
    'roguish': ['arch', 'base', 'blackguardly', 'degraded', 'devilish', 'elfish', 'elvish', 'foolish', 'full of mischief', 'high-spirited', 'impish', 'infamous'],
    'roil': ['adiaphanousness', 'aggravate', 'agitate', 'agitation', 'annoy', 'arouse', 'badger', 'bait', 'be at', 'be turbulent', 'beat', 'beat up'],
    'roiled': ['adiaphanous', 'aggravated', 'angry', 'annoyed', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'chafed', 'cloudy', 'dark', 'disturbed'],
    'roily': ['adiaphanous', 'amiss', 'askew', 'awry', 'cloudy', 'cockeyed', 'convulsed', 'dark', 'deranged', 'disarranged', 'discomfited', 'discomposed'],
    'roister': ['bluff', 'bluster', 'bluster and bluff', 'bounce', 'brag', 'bully', 'carouse', 'celebrate', 'create a disturbance', 'create a riot', 'cut loose', 'debauch'],
    'roisterous': ['blustering', 'blusterous', 'blustery', 'boisterous', 'bullying', 'harum-scarum', 'hectoring', 'knock-down-and-drag-out', 'knockabout', 'noisy', 'raging', 'rambunctious'],
    'role': ['actor', 'antagonist', 'antihero', 'bit', 'bit part', 'capacity', 'cast', 'character', 'condition', 'cue', 'duty', 'end use'],
    'role player': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'actor', 'bamboozler', 'befuddler', 'beguiler', 'charmer', 'counterfeiter'],
    'roll': ['danish', 'danish pastry', 'english muffin', 'parker house roll', 'yorkshire pudding', 'account', 'advance', 'agenda', 'align', 'amble', 'angular momentum', 'angular motion'],
    'roll around': ['alternate', 'be here again', 'circle', 'come again', 'come and go', 'come around', 'come round', 'come round again', 'come up again', 'cycle', 'intermit', 'oscillate'],
    'roll back': ['abridge', 'compress', 'curtail', 'curtail expenses', 'cut', 'cut back', 'cut corners', 'cut down', 'damp', 'dampen', 'decrease', 'deduct'],
    'roll call': ['agenda', 'beadroll', 'cadastre', 'calendar', 'catalog', 'census', 'census report', 'checklist', 'checkroll', 'cloture', 'committee consideration', 'debate'],
    'roll in': ['accomplish', 'achieve', 'approach', 'arrive', 'arrive at', 'arrive in', 'attain', 'attain to', 'be received', 'bed', 'blow in', 'bob up'],
    'roll on': ['advance', 'commute', 'continue', 'course', 'cover ground', 'drift along', 'elapse', 'endure', 'expire', 'fare', 'fare forth', 'fetch'],
    'roll out': ['affect', 'arise', 'betoken', 'brandish', 'breathe', 'bring forth', 'bring forward', 'bring into view', 'bring out', 'bring to notice', 'dangle', 'demonstrate'],
    'roll up': ['amass', 'bale', 'bind up', 'bowl', 'bundle', 'bundle up', 'clamp', 'compress', 'crush', 'cumulate', 'do up', 'ensphere'],
    'rollback': ['abatement', 'agio', 'allowance', 'backset', 'backsliding', 'backward motion', 'backward step', 'bank discount', 'breakage', 'cash discount', 'chain discount', 'charge-off'],
    'roller': ['ace bandage', 'band-aid', 'abradant', 'abrasive', 'adhesive tape', 'application', 'band', 'bandage', 'bandaging', 'barrel', 'billow', 'binder'],
    'roller skate': ['coast', 'flit', 'flow', 'fly', 'glide', 'glissade', 'ice-skate', 'sail', 'sideslip', 'skate', 'skateboard', 'ski'],
    'rollick': ['antic', 'bask', 'bluff', 'bluster', 'bluster and bluff', 'bounce', 'brag', 'bully', 'caper', 'caracole', 'carol', 'carry on'],
    'rollicking': ['animated', 'antic', 'blustering', 'blusterous', 'blustery', 'boisterous', 'bullying', 'capersome', 'cheerful', 'coltish', 'exuberant', 'frisky'],
    'rolling': ['acrobatics', 'advance', 'advancement', 'advancing', 'aerobatics', 'alpen', 'alpestrine', 'alpigene', 'alpine', 'angular momentum', 'angular motion', 'angular velocity'],
    'rolling stock': ['amtrak', 'baggage train', 'cable railroad', 'choo-choo', 'cog railroad', 'cog railway', 'el', 'electric', 'electric train', 'elevated', 'express', 'express train'],
    'rolling stone': ['ahasuerus', 'ancient mariner', 'april showers', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'proteus', 'ulysses', 'bird of passage'],
    'roly poly': ['adipose', 'beefy', 'big-bellied', 'blimp', 'bloated', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky'],
    'roman': ['bildungsroman', 'gothic novel', 'ascender', 'back', 'bastard type', 'beard', 'belly', 'bevel', 'black letter', 'body', 'cap', 'capital'],
    'roman candle': ['aid to navigation', 'alarm', 'amber light', 'balefire', 'beacon', 'beacon fire', 'bell', 'bell buoy', 'blinker', 'blue peter', 'bomb', 'buoy'],
    'roman nosed': ['aquiline', 'aquiline-nosed', 'beak-nosed', 'beak-shaped', 'beaked', 'bill-like', 'bill-shaped', 'billed', 'clawlike', 'crookbilled', 'crooked', 'crooknosed'],
    'romance': ['marchen', 'western', 'western story', 'westerner', 'adulterous affair', 'adultery', 'adventure', 'adventure story', 'affair', 'allegorize', 'allegory', 'amor'],
    'romancer': ['don quixote', 'quixote', 'anecdotist', 'daydreamer', 'dreamer', 'dreamer of dreams', 'enthusiast', 'escapist', 'fableist', 'fabler', 'fabulist', 'fictionist'],
    'romantic': ['don quixote', 'quixote', 'utopian', 'abstract', 'absurd', 'adoring', 'affectionate', 'airy', 'allegoric', 'amorous', 'aroused', 'autistic'],
    'romanticism': ['affection', 'affectionateness', 'amativeness', 'amorousness', 'autism', 'autistic thinking', 'bathos', 'bleeding heart', 'cloyingness', 'demonstrativeness', 'dereism', 'dereistic thinking'],
    'romanticized': ['airy', 'allegoric', 'autistic', 'dereistic', 'fabulous', 'fictional', 'idealistic', 'impractical', 'in the clouds', 'legendary', 'mythic', 'mythological'],
    'romeo': ['casanova', 'don juan', 'lothario', 'amorist', 'amoroso', 'beau', 'boyfriend', 'caballero', 'cavalier', 'cavaliere servente', 'esquire', 'fellow'],
    'romp': ['amazon', 'androgyne', 'antic', 'babe', 'baby', 'beam', 'bob', 'bounce', 'broad', 'butch', 'cakewalk', 'caper'],
    'rondeau': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'rondelle': ['annular muscle', 'annulus', 'areola', 'aureole', 'chaplet', 'circle', 'circuit', 'circumference', 'circus', 'closed circle', 'corona', 'coronet'],
    'rood': ['agnus dei', 'calvary cross', 'christogram', 'greek cross', 'holy grail', 'host', 'jerusalem cross', 'latin cross', 'maltese cross', 'pieta', 'russian cross', 'sanctus bell'],
    'roof': ['dymaxion house', 'french roof', 'm roof', 'white house', 'abiding place', 'abode', 'address', 'adobe house', 'ancestral halls', 'apex', 'barrack roof', 'bonnet'],
    'roofed': ['armored', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'coped', 'covered', 'covert', 'cowled', 'curtained', 'eclipsed'],
    'roofing': ['adobe', 'ashlar', 'brick', 'bricks and mortar', 'ceiling', 'cement', 'clinker', 'concrete', 'covering materials', 'eaves', 'ferroconcrete', 'firebrick'],
    'rooftop': ['ceiling', 'clerestory', 'eaves', 'housetop', 'lantern', 'overhead', 'penthouse', 'plafond', 'ridgepole', 'roof', 'roof garden', 'roof-deck'],
    'rook': ['beat', 'beguile of', 'bilk', 'bishop', 'bleed', 'bunco', 'burn', 'castle', 'cheat', 'chessman', 'chisel', 'chouse'],
    'rookery': ['augean stables', 'birthplace', 'breeding place', 'brooder', 'cradle', 'dump', 'forcing bed', 'hatchery', 'hole', 'hotbed', 'hovel', 'incubator'],
    'rookie': ['abecedarian', 'alphabetarian', 'apprentice', 'arriviste', 'articled clerk', 'baby', 'beginner', 'boot', 'catechumen', 'colt', 'conscript', 'deb'],
    'room': ['a leg up', 'abide', 'accommodation', 'accommodations', 'air space', 'allowance', 'ample scope', 'apartment', 'area', 'bed', 'berth', 'billet'],
    'room temperature': ['aestival', 'blood-hot', 'blood-warm', 'calid', 'equatorial', 'genial', 'luke', 'lukewarm', 'mild', 'subtropical', 'summery', 'sunny'],
    'roomer': ['board-and-roomer', 'boarder', 'hirer', 'homesteader', 'incumbent', 'leaseholder', 'lessee', 'lodger', 'occupant', 'occupier', 'paying guest', 'renter'],
    'roomette': ['pullman', 'pullman car', 'baggage car', 'boxcar', 'caboose', 'car', 'carriage', 'chair car', 'coach', 'coal car', 'covered waggon', 'day coach'],
    'rooming house': ['boardinghouse', 'dorm', 'dormitory', 'doss house', 'fleabag', 'flophouse', 'guest house', 'hospice', 'hostel', 'hostelry', 'hotel', 'inn'],
    'roommate': ['ace', 'amigo', 'associate', 'bedfellow', 'bedmate', 'birthmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty', 'camarade'],
    'roomy': ['aerial', 'aeriform', 'aery', 'airish', 'airlike', 'airy', 'alfresco', 'ample', 'amplitudinous', 'atmospheric', 'big', 'breezy'],
    'roorback': ['bruit', 'buzz', 'canard', 'character assassination', 'common talk', 'cry', 'dirty politics', 'flying rumor', 'grapevine', 'hearsay', 'idea afloat', 'last-minute lie'],
    'roost': ['abide', 'accommodations', 'anchor', 'aviary', 'be seated', 'berth', 'billet', 'billet at', 'bird cage', 'birdhouse', 'bivouac', 'board'],
    'rooster': ['bantam', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'billy', 'billy goat', 'boar', 'broiler', 'brooder', 'broody hen', 'bubbly-jock'],
    'root': ['ic analysis', 'accidence', 'acclaim', 'affix', 'affixation', 'allomorph', 'ancestors', 'anchor', 'antecedents', 'applaud', 'base', 'basis'],
    'root out': ['abate', 'abolish', 'abscind', 'abstract', 'amputate', 'annihilate', 'avulse', 'ban', 'bar', 'blot out', 'bob', 'buck off'],
    'rooted': ['acknowledged', 'admitted', 'basic', 'chronic', 'confirmed', 'conventional', 'customary', 'deep-dyed', 'deep-engraven', 'deep-fixed', 'deep-grounded', 'deep-laid'],
    'rooter': ['adherent', 'admirer', 'amateur', 'applauder', 'appreciator', 'booster', 'buff', 'claqueur', 'collector', 'commender', 'devotee', 'dilettante'],
    'rootlike': ['botanic', 'bulbous', 'cereal', 'farinaceous', 'fruitlike', 'fruity', 'herbaceous', 'herbal', 'herbose', 'herbous', 'herby', 'leguminose'],
    'rope': ['havana', 'allure', 'ample scope', 'anchor', 'anchor chain', 'anchor rode', 'attach', 'attract', 'ax', 'backropes', 'bag', 'bait'],
    'rope off': ['bound', 'circle in', 'circumscribe', 'cordon', 'cordon off', 'define', 'delimit', 'delimitate', 'demarcate', 'determine', 'enclose', 'fix'],
    'ropy': ['adhesive', 'amylaceous', 'below par', 'capillary', 'cartilaginous', 'chewy', 'cirrose', 'cirrous', 'clabbered', 'clammy', 'clotted', 'coagulated'],
    'rorschach test': ['binet-simon test', 'brown personality inventory', 'goldstein-sheerer test', 'iq', 'iq test', 'kent mental test', 'minnesota preschool scale', 'oseretsky test', 'stanford revision', 'stanford-binet test', 'szondi test', 'tat'],
    'rosary': ['agnus dei', 'angelus', 'ave', 'ave maria', 'hail mary', 'holy grail', 'host', 'kyrie eleison', 'paternoster', 'pieta', 'sanctus bell', 'sangraal'],
    'rose': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'azure', 'badge', 'badge of office', 'badges'],
    'rose colored': ['leibnizian', 'bright', 'cheerful', 'chiliastic', 'coral', 'couleur de rose', 'encouraging', 'incarnadine', 'likely', 'millenarian', 'millennialistic', 'optimistic'],
    'rose oil': ['ambergris', 'ambrosia', 'aromatic', 'aromatic gum', 'aromatic water', 'attar', 'attar of roses', 'balm', 'balm of gilead', 'balsam', 'bay oil', 'bergamot oil'],
    'rose wine': ['demi-sec', 'domestic wine', 'extra sec', 'imported wine', 'light wine', 'must', 'new wine', 'nonvintage wine', 'pink wine', 'red wine', 'sec', 'smooth wine'],
    'rosette': ['danish pastry', 'french pastry', 'baklava', 'blintz', 'chocolate eclair', 'cream puff', 'dowdy', 'eclair', 'pandowdy', 'pastry', 'pasty', 'patisserie'],
    'roster': ['account', 'agenda', 'annals', 'batting order', 'beadroll', 'bill', 'bill of fare', 'blueprint', 'budget', 'cadastre', 'calendar', 'card'],
    'rostrum': ['ambo', 'antlia', 'balcony', 'beak', 'beezer', 'bill', 'bow', 'bowsprit', 'bugle', 'catafalque', 'conk', 'dais'],
    'rosy': ['leibnizian', 'auspicious', 'balmy', 'beaming', 'blithe', 'blithesome', 'blooming', 'blossoming', 'blowzed', 'blowzy', 'blushing', 'booming'],
    'rosy cheeked': ['blooming', 'blowzed', 'blowzy', 'burnt', 'florid', 'flush', 'flushed', 'fresh', 'fresh as april', 'full-blooded', 'glowing', 'green'],
    'rot': ['texas fever', 'anthrax', 'aphthous fever', 'baloney', 'bighead', 'bilge', 'black quarter', 'blackleg', 'blackwater', 'blah', 'blah-blah', 'blast'],
    'rota': ['account', 'agenda', 'annals', 'beadroll', 'cadastre', 'calendar', 'catalog', 'census', 'census report', 'checklist', 'checkroll', 'chronicle'],
    'rotary': ['o-shaped', 'alternate', 'ambagious', 'ascending', 'axial', 'back', 'back-flowing', 'backhanded', 'backward', 'beating', 'carrefour', 'circling'],
    'rotate': ['advance', 'alternate', 'ascend', 'back', 'back up', 'bandy', 'be here again', 'become airborne', 'budge', 'change', 'change place', 'circle'],
    'rotation': ['indian file', 'array', 'arsis', 'articulation', 'bank', 'beat', 'booster rocket', 'bout', 'buzz', 'catapult', 'catena', 'catenation'],
    'rotator': ['carousel', 'centrifuge', 'chuck', 'disk', 'drill', 'extractor', 'fan', 'governor', 'gyroscope', 'impeller', 'jack', 'merry-go-round'],
    'rote': ['automatically', 'commitment to memory', 'exercise of memory', 'flashback', 'grind', 'groove', 'hindsight', 'learning by heart', 'looking back', 'mechanically', 'memoir', 'memorization'],
    'rotogravure': ['albertype', 'book printing', 'chromotypography', 'chromotypy', 'chromoxylography', 'collotype', 'color printing', 'electronography', 'electrostatic printing', 'graphic arts', 'gravure', 'halftone engraving'],
    'rotor': ['airscrew', 'carousel', 'disk', 'driver', 'fan', 'impeller', 'merry-go-round', 'paddle wheel', 'piston', 'prop', 'propellant', 'propeller'],
    'rotten': ['abandoned', 'abominable', 'amiss', 'amoral', 'appalling', 'arrant', 'atrocious', 'awful', 'bad', 'bad-smelling', 'baneful', 'barfy'],
    'rotting': ['bad', 'cankered', 'carious', 'corrupt', 'decayed', 'decomposed', 'festering', 'foul', 'gangrened', 'gangrenous', 'gone bad', 'mortified'],
    'rotund': ['adipose', 'arched', 'beefy', 'bellied', 'bellylike', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'bowed', 'brawny', 'bulging'],
    'roue': ['casanova', 'don juan', 'lothario', 'debauchee', 'gallant', 'gay deceiver', 'gay dog', 'lady-killer', 'libertine', 'lover-boy', 'philanderer', 'profligate'],
    'rouge': ['any color', 'base', 'carmine', 'clown white', 'cold cream', 'color', 'compact', 'cosmetics', 'crimson', 'drugstore complexion', 'erythema', 'eye shadow'],
    'rough': ['babbitt', 'herculean', 'philistine', 'spartan', 'abrupt', 'abstruse', 'abuse', 'acerb', 'acerbic', 'acid', 'acidulous', 'acrid'],
    'rough diamond': ['acceptable person', 'capital fellow', 'crude', 'diamond', 'gem', 'gentleman', 'good fellow', 'good lot', 'good man', 'good person', 'good sort', 'good woman'],
    'rough draft': ['acid test', 'assay', 'black and white', 'blank determination', 'brouillon', 'cartoon', 'charcoal', 'charcoal drawing', 'chiaroscuro', 'crayon', 'criterion', 'crucial test'],
    'rough out': ['adumbrate', 'bat out', 'block in', 'block out', 'botch', 'brief', 'bungle', 'carve', 'cast', 'chalk out', 'characterize', 'chisel'],
    'rough sketch': ['acid test', 'assay', 'blank determination', 'brouillon', 'criterion', 'crucial test', 'crucible', 'determination', 'docimasy', 'essay', 'feeling out', 'first draft'],
    'roughcast': ['arrested', 'backward', 'bat out', 'block out', 'botch', 'broken', 'bumpy', 'bungle', 'carve', 'cast', 'cement', 'chisel'],
    'roughen': ['agitate', 'beat', 'beat up', 'boss', 'churn', 'churn up', 'coarsen', 'convulse', 'disarrange', 'discompose', 'disquiet', 'disturb'],
    'roughhew': ['bat out', 'block out', 'botch', 'bungle', 'carve', 'cast', 'chisel', 'create', 'cut', 'dash off', 'do anyhow', 'do by halves'],
    'roughhewn': ['arrested', 'backward', 'broken', 'bumpy', 'choppy', 'coarse', 'coarse-grained', 'corrugated', 'cross-grained', 'crude', 'embryonic', 'grainy'],
    'roughhouse': ['act up', 'ado', 'badness', 'behave ill', 'bother', 'brawl', 'broil', 'brouhaha', 'carry on', 'commotion', 'cut up', 'cut up rough'],
    'roughly': ['about', 'all but', 'all in all', 'all things considered', 'almost', 'altogether', 'approximately', 'approximatively', 'around', 'as a rule', 'as a whole', 'as an approximation'],
    'roughneck': ['babbitt', 'philistine', 'arriviste', 'boor', 'boorish', 'bounder', 'bourgeois', 'bruiser', 'bullyboy', 'cad', 'carlish', 'churl'],
    'roughness': ['cat', 'gothicism', 'abruptness', 'acerbity', 'acidity', 'acidulousness', 'acridity', 'acrimony', 'acuteness', 'aerospace', 'aerosphere', 'aggressiveness'],
    'rouleau': ['bale', 'barrel', 'bindle', 'bole', 'bolt', 'bouquet', 'budget', 'bundle', 'cask', 'coin', 'column', 'crown'],
    'roulette': ['bingo', 'card games', 'chuck and toss', 'chuck farthing', 'chuck-a-luck', 'crack-loo', 'crap game', 'crap shooting', 'craps', 'fan-tan', 'hazard', 'horse racing'],
    'round': ['attic', 'charybdis', 'chateaubriand', 'ciceronian', 'indian file', 'o-shaped', 'sro', 'about', 'absolute', 'ace', 'admitting no exception', 'again'],
    'round about': ['about', 'again', 'all over', 'all round', 'all through', 'anticlockwise', 'around', 'at about', 'back', 'backward', 'by', 'by way of'],
    'round and round': ['alternately', 'anticlockwise', 'around', 'back and forth', 'backward and forward', 'backwards and forwards', 'by turns', 'capriciously', 'changeably', 'clockwise', 'counterclockwise', 'desultorily'],
    'round out': ['accomplish', 'bag', 'balloon', 'belly', 'belly out', 'bilge', 'billow', 'bouge', 'bring to completion', 'bring to fruition', 'bug', 'bulge'],
    'round robin': ['pastoral epistle', 'aerogram', 'air letter', 'airgraph', 'billet-doux', 'bull', 'chain letter', 'dead letter', 'dimissorial', 'dimissory letter', 'drop letter', 'encyclical'],
    'round trip': ['ambit', 'beat', 'campaign', 'circle', 'circuit', 'course', 'cycle', 'excursion', 'expedition', 'full circle', 'grand tour', 'jaunt'],
    'round up': ['accumulate', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'assemble', 'batch', 'bring together', 'bulk', 'bunch', 'bunch together', 'bunch up'],
    'roundabout': ['byzantine', 'ferris wheel', 'o-shaped', 'ambages', 'ambagious', 'ambient', 'anfractuous', 'apparent', 'backhanded', 'balled up', 'bypass', 'carousel'],
    'rounded': ['junoesque', 'abrupt', 'accented', 'alveolar', 'annular', 'annulate', 'annulose', 'apical', 'apico-alveolar', 'apico-dental', 'arched', 'arciform'],
    'roundel': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'annular muscle', 'annulus', 'areola'],
    'roundelay': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'rounder': ['arab', 'casanova', 'don juan', 'lothario', 'bad lot', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'debauchee'],
    'roundhouse': ['long melford', 'backhand', 'backhander', 'backstroke', 'boathouse', 'bolo punch', 'carbarn', 'carport', 'carriage house', 'fix-it shop', 'garage', 'hangar'],
    'roundly': ['about', 'all but', 'all joking aside', 'almost', 'altogether', 'approximately', 'approximatively', 'as good as', 'bluffly', 'bluntly', 'broadly', 'brusquely'],
    'roundness': ['annularity', 'annulation', 'artlessness', 'belly', 'bluffness', 'bluntness', 'broadness', 'brusqueness', 'candidness', 'candor', 'circularity', 'convexity'],
    'roundsman': ['argus', 'charley', 'g-man', 'mp', 'airplane spotter', 'bailiff', 'beadle', 'beagle', 'bound bailiff', 'captain', 'catchpole', 'chief of police'],
    'roundup': ['assemblage', 'assembly', 'call-up', 'canvass', 'census', 'collection', 'colligation', 'collocation', 'combination', 'comparison', 'concourse', 'concurrence'],
    'rouse': ['aggravate', 'animate', 'annoy', 'arise', 'arouse', 'awake', 'awaken', 'bestir', 'blow the coals', 'blow up', 'bring forth', 'bring out'],
    'rousing': ['activating', 'alert', 'alluring', 'animate', 'animated', 'animating', 'animative', 'arousal', 'awakening', 'awful', 'bracing', 'bright'],
    'roustabout': ['bakehead', 'black gang', 'blue-collar worker', 'boilerman', 'breadwinner', 'bungs', 'cabin boy', 'casual', 'casual laborer', 'chips', 'commissary steward', 'common laborer'],
    'rout': ['a mass of', 'a world of', 'agitation', 'and bobtail', 'annihilate', 'army', 'attendance', 'attendant', 'bafflement', 'balk', 'batter', 'bawl'],
    'route': ['address', 'air lane', 'avenue', 'beat', 'carry', 'circuit', 'conduct', 'consign', 'convey', 'course', 'direct', 'direction'],
    'routine': ['indian file', 'mo', 'accustomed', 'act', 'afterpiece', 'algorithm', 'approach', 'arranged', 'arrangement', 'array', 'articulation', 'assigned'],
    'routinely': ['again and again', 'all in all', 'all things considered', 'altogether', 'as a rule', 'as a whole', 'as an approximation', 'at large', 'broadly', 'broadly speaking', 'by and large', 'chiefly'],
    'routinize': ['adjust', 'arrange', 'array', 'chart', 'codify', 'cool off', 'coordinate', 'deploy', 'dispose', 'fix', 'form', 'grade'],
    'rove': ['wanderjahr', 'afoot and lighthearted', 'bat around', 'bum', 'bumming', 'count ties', 'discursion', 'divagate', 'divagation', 'drift', 'drifting', 'err'],
    'rover': ['ahasuerus', 'ancient mariner', 'argonaut', 'blackbeard', 'captain hook', 'captain kidd', 'flying dutchman', 'goliard', 'henry morgan', 'jean lafitte', 'odysseus', 'oisin'],
    'roving': ['wanderjahr', 'aberrant', 'aberrative', 'adrift', 'afloat', 'afoot and lighthearted', 'aimless', 'aimlessness', 'alternating', 'amorphous', 'bumming', 'by the way'],
    'row': ['autobahn', 'bedlam let loose', 'indian file', 'us highway', 'ado', 'advance', 'affray', 'agitation', 'align', 'alley', 'alleyway', 'altercation'],
    'rowdy': ['babbitt', 'philistine', 'arriviste', 'bad', 'bad boy', 'battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'blaring', 'blatant'],
    'rowing': ['boating', 'canoeing', 'circumnavigation', 'coasting', 'cruising', 'gunkholing', 'motorboating', 'navigability', 'navigating', 'navigation', 'passage-making', 'periplus'],
    'royal': ['advantageous', 'anointed king', 'aristocratic', 'august', 'auspicious', 'baron', 'baroness', 'baronial', 'beneficial', 'benevolent', 'bon', 'bonny'],
    'royalism': ['bourbonism', 'nazism', 'toryism', 'backwardness', 'centralism', 'collectivism', 'communism', 'conservatism', 'conservativeness', 'constitutionalism', 'democratism', 'die-hardism'],
    'royalist': ['bircher', 'bourbon', 'tory', 'conservatist', 'conservative', 'diehard', 'extreme right-winger', 'hard hat', 'imperialist', 'monarchist', 'radical right', 'reactionarist'],
    'royalty': ['ffvs', 'ancestry', 'ancienne noblesse', 'anointed king', 'aristocracy', 'aristocraticalness', 'avails', 'baronage', 'baronetage', 'birth', 'blood', 'blue blood'],
    'rpm': ['air speed', 'celerity', 'dispatch', 'expedition', 'fastness', 'flight', 'flit', 'flurry', 'ground speed', 'haste', 'hurry', 'instantaneousness'],
    'rub': ['discordia', 'eris', 'ablate', 'abrade', 'abrase', 'afflict', 'aggravate', 'agonize', 'ail', 'air-dry', 'anhydrate', 'annoy'],
    'rub down': ['bed', 'bed down', 'break', 'bridle', 'brush', 'caress', 'curry', 'currycomb', 'drench', 'feed', 'fodder', 'frictionize'],
    'rub in': ['accent', 'accentuate', 'belabor', 'dwell on', 'emphasize', 'give emphasis to', 'harp on', 'highlight', 'italicize', 'overaccentuate', 'overemphasize', 'overstress'],
    'rub off': ['ablate', 'abrade', 'abrase', 'bark', 'chafe', 'erase', 'erode', 'file', 'fray', 'frazzle', 'fret', 'gall'],
    'rub out': ['abbreviate', 'ablate', 'abrade', 'abrase', 'abridge', 'annihilate', 'assassinate', 'bark', 'blast', 'blot', 'blot out', 'blue-pencil'],
    'rubber': ['buna', 'butyl rubber', 'iud', 'india rubber', 'lastex', 'paul pry', 'ace', 'bag', 'baleen', 'battledore', 'best bower', 'birth control device'],
    'rubber band': ['lastex', 'baleen', 'battledore', 'chewing gum', 'elastic', 'elastomer', 'gum', 'gum elastic', 'handball', 'jumping jack', 'racket', 'rubber'],
    'rubber stamp': ['john hancock', 'ok', 'accept', 'acceptance', 'accredit', 'affirm', 'affirmance', 'affirmation', 'amen', 'approbation', 'approval', 'approve'],
    'rubberneck': ['paul pry', 'peeping tom', 'adventurer', 'alpinist', 'astronaut', 'be curious', 'burn with curiosity', 'busybody', 'butt-in', 'buttinsky', 'campaign', 'camper'],
    'rubbery': ['able to adapt', 'adaptable', 'adjustable', 'alterable', 'alterative', 'anemic', 'asthenic', 'bloodless', 'changeable', 'checkered', 'chicken', 'cowardly'],
    'rubbing': ['apograph', 'brushing', 'carbon', 'carbon copy', 'caressing', 'companion', 'confrication', 'contacting', 'contingent', 'copy', 'dead ringer', 'double'],
    'rubbish': ['absurdity', 'afterglow', 'afterimage', 'amphigory', 'attack', 'babble', 'babblement', 'bad-mouth', 'balance', 'balderdash', 'baloney', 'bibble-babble'],
    'rubbishy': ['pickwickian', 'absurd', 'base', 'beggarly', 'beneath contempt', 'cheap', 'cheesy', 'common', 'contemptible', 'crummy', 'despicable', 'foolish'],
    'rubble': ['aa', 'abyssal rock', 'basalt', 'bedrock', 'block lava', 'brash', 'breccia', 'clamjamfry', 'conglomerate', 'crag', 'debris', 'druid stone'],
    'rube': ['babe', 'backwoodsman', 'boor', 'boorish', 'bucolic', 'bumpkin', 'butterfingers', 'child', 'child of nature', 'churlish', 'clod', 'cloddish'],
    'rubella': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'rubicund': ['titian', 'titian-red', 'blooming', 'blowzed', 'blowzy', 'bricky', 'burnt', 'cardinal', 'carmine', 'carnation', 'carnelian', 'cerise'],
    'ruble': ['deutschmark', 'mark', 'reichsmark', 'afghani', 'anna', 'baht', 'cent', 'centavo', 'centime', 'conto', 'dollar', 'dong'],
    'rubric': ['sefer torah', 'torah', 'torah scroll', 'virginal', 'abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'act', 'appellation', 'appellative'],
    'ruby': ['titian', 'titian-red', 'adamant', 'agate', 'alexandrite', 'amethyst', 'aquamarine', 'beryl', 'bloodstone', 'bricky', 'brilliant', 'carbuncle'],
    'ruche': ['crease', 'creasing', 'crimp', 'dog-ear', 'double', 'doubling', 'duplicature', 'flection', 'flexure', 'flounce', 'fold', 'frill'],
    'ruck': ['everyman', 'public', 'a mass of', 'a world of', 'aggregation', 'and bobtail', 'army', 'assemblage', 'average', 'average man', 'bank', 'bevy'],
    'ruckus': ['bedlam let loose', 'ado', 'agitation', 'altercation', 'barney', 'bedlam', 'bickering', 'blast', 'bluster', 'bobbery', 'bother', 'brawl'],
    'ruction': ['affray', 'broil', 'bustle', 'clamor', 'clatter', 'donnybrook', 'fight', 'fracas', 'fray', 'free-for-all', 'hassle', 'hubbub'],
    'ruddy': ['titian', 'titian-red', 'absolute', 'blamed', 'blankety-blank', 'blasted', 'bleeding', 'blessed', 'blinking', 'bloody', 'blooming', 'blowsy'],
    'rude': ['doric', 'gothic', 'philistine', 'angular', 'approximate', 'arrested', 'artless', 'awkward', 'backward', 'barbaric', 'barbarous', 'bare'],
    'rudeness': ['gothicism', 'bad manners', 'bad taste', 'barbarism', 'barbarousness', 'bombasticness', 'brashness', 'brassiness', 'brazenfacedness', 'brazenness', 'cacology', 'cacophony'],
    'rudiment': ['anlage', 'base', 'basement', 'basic', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock', 'blastula', 'bud', 'egg'],
    'rudimentary': ['lilliputian', 'tom thumb', 'abecedarian', 'aboriginal', 'antenatal', 'arrested', 'autochthonous', 'backward', 'basal', 'basic', 'basilar', 'beginning'],
    'rudiments': ['abecedarium', 'abecedary', 'alphabet', 'and arithmetic', 'basics', 'elementary education', 'elements', 'essentials', 'first principles', 'first steps', 'fundamentals', 'grammar'],
    'rue': ['affliction', 'anguish', 'be sorry for', 'bemoan', 'bewail', 'care', 'commiseration', 'compassion', 'compunction', 'contriteness', 'contrition', 'deplore'],
    'rueful': ['addicted', 'affecting', 'afflictive', 'aggrieved', 'anguished', 'ashamed', 'bitter', 'bleak', 'careworn', 'cheerless', 'comfortless', 'conscience-smitten'],
    'ruff': ['ace', 'barrage', 'beat', 'beating', 'best bower', 'bower', 'cards', 'clubs', 'crease', 'crimp', 'crisp', 'deck'],
    'ruffian': ['babbitt', 'philistine', 'arriviste', 'bad boy', 'battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'booger', 'boor', 'bounder'],
    'ruffianly': ['bad', 'boorish', 'carlish', 'churlish', 'cloddish', 'clownish', 'disorderly', 'disruptive', 'hooliganish', 'improper', 'loobyish', 'loutish'],
    'ruffle': ['abrade', 'addle', 'addle the wits', 'ado', 'affect', 'aggravate', 'agitate', 'agitation', 'annoy', 'arouse', 'badger', 'bait'],
    'rug': ['axminster', 'brussels carpet', 'caucasian rug', 'chinese rug', 'east indian rug', 'indian rug', 'oriental rug', 'persian rug', 'savonnerie', 'turkish rug', 'wilton', 'afghan'],
    'rugged': ['herculean', 'spartan', 'spartanic', 'abstruse', 'adamantine', 'arduous', 'asperous', 'astringent', 'austere', 'authoritarian', 'beefy', 'bitter'],
    'rugged individualist': ['capitalist', 'free lance', 'free spirit', 'free trader', 'freethinker', 'independent', 'individualist', 'isolationist', 'latitudinarian', 'liberal', 'libertarian', 'libertine'],
    'rugous': ['cockled', 'cockly', 'corrugate', 'corrugated', 'cragged', 'craggy', 'creased', 'crimped', 'crimpy', 'crinkled', 'crinkly', 'crumpled'],
    'ruin': ['waterloo', 'abuse', 'afterglow', 'afterimage', 'ancient manuscript', 'annihilate', 'antique', 'antiquity', 'archaism', 'artifact', 'assault', 'atrophy'],
    'ruination': ['bane', 'bankruptcy', 'bloodbath', 'blue ruin', 'breakage', 'breakdown', 'breakup', 'carnage', 'collapse', 'confusion', 'consumption', 'crack-up'],
    'ruined': ['all up with', 'ausgespielt', 'bankrupt', 'battered', 'beat', 'beat-up', 'beaten', 'beaten up', 'bested', 'beyond recall', 'beyond remedy', 'blasted'],
    'ruinous': ['ablative', 'annihilative', 'ausgespielt', 'baleful', 'baneful', 'bankrupt', 'battered', 'beat-up', 'beaten up', 'bedraggled', 'biodegradable', 'black'],
    'rule': ['aristotelian sorites', 'goclenian sorites', 'procrustean law', 'sop', 't square', 'a priori truth', 'acme', 'act', 'act on', 'administration', 'antetype', 'antitype'],
    'rule of thumb': ['r and d', 'control', 'control experiment', 'controlled experiment', 'cut and try', 'empiricism', 'experiment', 'experimental design', 'experimental method', 'experimental proof', 'experimentalism', 'experimentation'],
    'rule out': ['abscind', 'amputate', 'annihilate', 'anticipate', 'avert', 'ban', 'bar', 'bate', 'blot', 'blot out', 'bob', 'cancel'],
    'ruler': ['a per se', 't square', 'ace', 'anointed king', 'birch', 'boss', 'cane', 'captain', 'castellan', 'champion', 'chatelain', 'chatelaine'],
    'ruling': ['absolute', 'act', 'action', 'appointment', 'arch', 'armipotent', 'ascendant', 'at the head', 'authoritarian', 'authoritative', 'authorized', 'autocratic'],
    'ruling class': ['aedileship', 'archbishopric', 'archiepiscopacy', 'archiepiscopate', 'aristocracy', 'barons', 'bishopric', 'bureaucracy', 'chairmanship', 'chancellery', 'chancellorate', 'chancellorship'],
    'rum': ['john barleycorn', 'ok', 'absurd', 'ace-high', 'alcohol', 'alcoholic beverage', 'alcoholic drink', 'aqua vitae', 'ardent spirits', 'bad', 'bang-up', 'beverage'],
    'rumble': ['bedlam let loose', 'action', 'aerial combat', 'affray', 'armored combat', 'bark', 'battle', 'battle royal', 'bawl', 'be reflected', 'be sent back', 'bedlam'],
    'rumbling': ['boom', 'booming', 'cannonading', 'echo', 'echoic', 'echoing', 'fulminating', 'growl', 'growling', 'grumble', 'grumbling', 'lingering'],
    'rumen': ['abdomen', 'abomasum', 'bay window', 'beerbelly', 'belly', 'breadbasket', 'craw', 'crop', 'diaphragm', 'embonpoint', 'first stomach', 'gizzard'],
    'ruminant': ['amphibian', 'aquatic', 'asinine', 'biped', 'bovid', 'bovine', 'canine', 'cannibal', 'caprid', 'caprine', 'carnivore', 'chewing'],
    'ruminate': ['be abstracted', 'bite', 'brood', 'brood over', 'champ', 'chaw', 'chew', 'chew over', 'chew the cud', 'chew up', 'chomp', 'chump'],
    'rummage': ['beat', 'comb', 'conglomeration', 'disarrange', 'disarray', 'discompose', 'disorganize', 'disrupt', 'disturb', 'domiciliary visit', 'dragnet', 'examine'],
    'rummy': ['bizarre', 'boozehound', 'boozer', 'bottle sucker', 'bum', 'curious', 'drunk', 'eccentric', 'elbow bender', 'ginhound', 'guzzler', 'hooch hound'],
    'rumor': ['announce', 'blab', 'break the news', 'breathe', 'bring word', 'bruit', 'bruit about', 'buzz', 'canard', 'chat', 'circulate', 'common talk'],
    'rumormonger': ['a tale-bearing animal', 'busybody', 'gossip', 'gossip columnist', 'gossiper', 'gossipmonger', 'newsmonger', 'newspaperman', 'quidnunc', 'reporter', 'scandalmonger', 'tabby'],
    'rump': ['chateaubriand', 'afterglow', 'afterimage', 'backside', 'balance', 'beam', 'behind', 'blade roast', 'bottom', 'breast', 'brisket', 'butt'],
    'rumple': ['agitate', 'beat', 'beat up', 'bristle', 'churn', 'churn up', 'clutter', 'cocker', 'cockle', 'convulse', 'corrugate', 'corrugation'],
    'rumpled': ['cockled', 'cockly', 'corrugate', 'corrugated', 'creased', 'crimped', 'crimpy', 'crinkled', 'crinkly', 'crumpled', 'disheveled', 'furrowed'],
    'rumpus': ['bedlam let loose', 'ado', 'affray', 'agitation', 'barney', 'bedlam', 'blast', 'bluster', 'bobbery', 'bother', 'brawl', 'broil'],
    'run': ['brownian movement', 'everyman', 'indian file', 'le mans', 'lehrfreiheit', 'public', 'zeitgeist', 'abide', 'abrade', 'abrasion', 'abscond', 'absquatulate'],
    'run across': ['alight upon', 'blunder upon', 'bump into', 'chance upon', 'come across', 'come among', 'come on', 'come up against', 'come upon', 'confront', 'discover serendipitously', 'encounter'],
    'run after': ['act up to', 'agree to anything', 'approach', 'break the ice', 'bring', 'bring back', 'brown-nose', 'call for', 'chase', 'chase after', 'chivy', 'court'],
    'run against': ['aggravated assault', 'aggression', 'amphibious attack', 'antagonize', 'armed assault', 'assailing', 'assailment', 'assault', 'attack', 'banzai attack', 'be antipathetic', 'be at cross-purposes'],
    'run aground': ['be clobbered', 'be felled', 'be poleaxed', 'be staggered', 'be stricken', 'beach', 'cast away', 'come to grief', 'drown', 'founder', 'ground', 'have a mishap'],
    'run along': ['blow', 'cut and run', 'cut out', 'depart', 'exit', 'flee', 'fly', 'get off', 'go', 'hightail', 'leave', 'make tracks'],
    'run amok': ['babble', 'be insane', 'carouse', 'create a disturbance', 'create a riot', 'cut loose', 'dote', 'drivel', 'drool', 'go berserk', 'have a demon', 'make a commotion'],
    'run at': ['aggravated assault', 'aggression', 'amphibious attack', 'armed assault', 'assailing', 'assailment', 'assault', 'attack', 'banzai attack', 'blitz', 'blitzkrieg', 'breakthrough'],
    'run away': ['abscond', 'absquatulate', 'beat a retreat', 'bolt', 'clear out', 'cut and run', 'cut out', 'decamp', 'depart', 'desert', 'elope', 'flee'],
    'run down': ['abandoned', 'ausgespielt', 'battered', 'beat-up', 'beaten up', 'belittle', 'blow', 'break down', 'bring down', 'bring into discredit', 'bring low', 'broken-down'],
    'run for': ['approach anchorage', 'bear down on', 'bear down upon', 'bear for', 'bear up for', 'bear up to', 'break for', 'close with', 'dash for', 'fetch', 'go aboard', 'go alongside'],
    'run in': ['acclimated', 'acclimatized', 'accommodated', 'accustomed', 'adapted', 'adjusted', 'apprehend', 'arrest', 'barney', 'bust', 'call on', 'call upon'],
    'run into': ['add up to', 'afford', 'aggregate', 'aggregate to', 'alight upon', 'alter into', 'amount to', 'bang', 'bang into', 'be converted into', 'become', 'blunder upon'],
    'run off': ['abscond', 'absquatulate', 'beat a retreat', 'bolt', 'bring out', 'clear out', 'cut and run', 'cut out', 'decamp', 'depart', 'desert', 'elope'],
    'run on': ['abide', 'advance', 'babble', 'be continuous', 'bide', 'blab', 'blabber', 'blather', 'blether', 'carry on', 'catenate', 'cease not'],
    'run out': ['advance', 'ago', 'antiquated', 'antique', 'apostatize', 'be all over', 'be consumed', 'be done for', 'be no more', 'be used up', 'become extinct', 'become void'],
    'run over': ['abound', 'autopsy', 'battologize', 'bristle with', 'brood over', 'browse', 'call off', 'call over', 'call the roll', 'canvass', 'cascade', 'cataract'],
    'run ragged': ['debilitated', 'drooping', 'droopy', 'enervated', 'enfeebled', 'fagged', 'faint', 'fainting', 'fatigued', 'feeling faint', 'flagging', 'footsore'],
    'run riot': ['arise', 'bespread', 'carouse', 'cover', 'create a disturbance', 'create a riot', 'cut loose', 'debauch', 'dissipate', 'fill', 'flood', 'go berserk'],
    'run the gauntlet': ['affront', 'beard', 'bell the cat', 'bite the bullet', 'brave', 'brazen', 'brazen out', 'confront', 'face', 'face the music', 'face up', 'face up to'],
    'run through': ['auger', 'bayonet', 'bespread', 'bite', 'blow', 'bore', 'broach', 'browse', 'budget', 'consume', 'continue the same', 'core'],
    'run wild': ['carouse', 'create a disturbance', 'create a riot', 'cut loose', 'give way to', 'go all out', 'go berserk', 'go flat out', 'go unrestrained', 'let go', 'let loose', 'make a commotion'],
    'runabout': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'ulysses', 'bird of passage', 'drifter', 'floater'],
    'runaround': ['avoidance', 'avoiding reaction', 'buck-passing', 'circumvention', 'defense mechanism', 'dodge', 'duck', 'elusion', 'elusiveness', 'equivocation', 'escape', 'eschewal'],
    'runaway': ['dp', 'absconder', 'at large', 'bolter', 'breather', 'cakewalk', 'cinch', 'conquest', 'deserter', 'disappearing', 'disengaged', 'displaced person'],
    'rundle': ['adolescent stream', 'arroyo', 'beck', 'bourn', 'braided stream', 'branch', 'brook', 'brooklet', 'burn', 'carousel', 'channel', 'creek'],
    'rundown': ['airmanship', 'brief', 'briefing', 'core', 'essence', 'flight plan', 'flying lessons', 'gist', 'main point', 'meat', 'pilot training', 'pilotship'],
    'rune': ['alchemy', 'arrowhead', 'bewitchery', 'character', 'charm', 'conjuration', 'cuneiform', 'demotic character', 'determinative', 'divination', 'enchantment', 'fetishism'],
    'rung': ['amount', 'caliber', 'compass', 'cut', 'degree', 'doorstep', 'extent', 'footrest', 'footstep', 'grade', 'height', 'interval'],
    'runic': ['alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'bardic', 'bucolic', 'didactic', 'dithyrambic'],
    'runnel': ['adolescent stream', 'aqueduct', 'arroyo', 'beck', 'bed', 'bourn', 'braided stream', 'branch', 'brook', 'brooklet', 'bum', 'burn'],
    'runner': ['hermes', 'iris', 'jehu', 'mercury', 'paul revere', 'pheidippides', 'skimobile', 'sno-cat', 'agent', 'appendage', 'arm', 'bine'],
    'runner up': ['champ', 'champion', 'conquering hero', 'conqueror', 'conquistador', 'defeater', 'easy winner', 'hero', 'master', 'pancratiast', 'shoo-in', 'subduer'],
    'running': ['acting', 'action', 'active', 'activity', 'actual', 'actuation', 'affluent', 'agency', 'agile', 'alive', 'articulated', 'as is'],
    'running head': ['banner', 'banner head', 'billhead', 'book stamp', 'bookplate', 'brand', 'broad arrow', 'cachet', 'caption', 'check', 'colophon', 'counterfoil'],
    'running mate': ['also-ran', 'aspirant', 'baby kisser', 'buddy', 'candidate', 'chum', 'comate', 'companion', 'comrade', 'crony', 'dark horse', 'defeated candidate'],
    'running start': ['advantage', 'alpha', 'anticipation', 'beginning', 'beginnings', 'blast-off', 'bulge', 'coign of vantage', 'commencement', 'creation', 'cutting edge', 'dawn'],
    'runny': ['excretory', 'exudative', 'flowing', 'fluent', 'fluid', 'fluidal', 'fluidic', 'fluxible', 'fluxile', 'fluxional', 'fluxionary', 'juicy'],
    'runoff': ['bout', 'by-election', 'caucus', 'closed primary', 'congressional election', 'contest', 'contested election', 'decathlon', 'defluxion', 'direct primary', 'discharge', 'double-header'],
    'runs': ['bm', 'bloody flux', 'bowel movement', 'catharsis', 'crap', 'defecation', 'dejection', 'diarrhea', 'dysentery', 'evacuation', 'flux', 'lientery'],
    'runt': ['lilliputian', 'tom thumb', 'a nobody', 'a nothing', 'bantam', 'banty', 'brownie', 'button', 'chit', 'cipher', 'common man', 'diminutive'],
    'runty': ['lilliputian', 'tom thumb', 'couchant', 'crouched', 'debased', 'depressed', 'dumpy', 'dwarf', 'dwarfed', 'dwarfish', 'elfin', 'flat'],
    'runway': ['airstrip', 'alameda', 'apron', 'beaten path', 'beaten track', 'berm', 'bicycle path', 'boardwalk', 'bridle path', 'catwalk', 'clearway', 'esplanade'],
    'rupture': ['abrade', 'abrasion', 'abysm', 'abyss', 'alienation', 'arroyo', 'bark', 'blemish', 'bloody', 'box canyon', 'breach', 'breach of friendship'],
    'ruptured': ['aggravated', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped', 'cracked', 'crazed', 'cut', 'damaged', 'deteriorated'],
    'rural': ['arcadian', 'agrarian', 'agrestic', 'agricultural', 'agronomic', 'arable', 'arcadian', 'bucolic', 'campestral', 'countrified', 'country', 'exurban'],
    'ruse': ['art', 'artful dodge', 'artifice', 'bag of tricks', 'blind', 'bluff', 'bosey', 'catch', 'chicanery', 'chouse', 'conspiracy', 'contrivance'],
    'rush': ['brownian movement', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'accelerate', 'ado', 'advance', 'affluence', 'afflux', 'affluxion'],
    'rushed': ['a bit previous', 'advanced', 'at the double', 'crowded', 'double-quick', 'double-time', 'far ahead', 'forward', 'half-baked', 'half-cocked', 'hard-pressed', 'hard-pushed'],
    'rushing': ['abrupt', 'affluent', 'ascending', 'axial', 'back', 'back-flowing', 'backward', 'confluent', 'coursing', 'decurrent', 'defluent', 'descending'],
    'rust': ['titian', 'titian-red', 'adust', 'age', 'algae', 'antiquate', 'auburn', 'autophyte', 'bay', 'bay-colored', 'bayard', 'bean'],
    'rustic': ['arcadian', 'bauer', 'spartan', 'agrarian', 'agrestic', 'agricultural', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'apple knocker', 'artless'],
    'rusticate': ['ban', 'banish', 'blackball', 'cast out', 'cop out', 'countrify', 'cut', 'deport', 'disfellowship', 'exclude', 'excommunicate', 'exile'],
    'rustle': ['abstract', 'and', 'annex', 'appropriate', 'bag', 'boost', 'borrow', 'celerity', 'cop', 'crib', 'crinkle', 'defraud'],
    'rusty': ['titian', 'titian-red', 'a stranger to', 'adust', 'anile', 'auburn', 'bay', 'bay-colored', 'bayard', 'brazen', 'bricky', 'bronze'],
    'rut': ['alameda', 'be in heat', 'beat', 'beaten path', 'beaten track', 'berm', 'bezel', 'bicycle path', 'boardwalk', 'bridle path', 'bureaucracy', 'bureaucratism'],
    'ruth': ['attrition', 'benevolence', 'clemency', 'commiseration', 'compassion', 'compunction', 'condolence', 'contrition', 'favor', 'feeling', 'forbearance', 'forgiveness'],
    'ruthful': ['afflicted', 'bleeding', 'charitable', 'clement', 'commiserative', 'compassionate', 'condolent', 'doleful', 'dolorous', 'forbearant', 'gentle', 'human'],
    'ruthless': ['draconian', 'tartarean', 'animal', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bestial', 'bloodthirsty', 'bloody', 'bloody-minded'],
    'ruthlessness': ['animality', 'atrociousness', 'barbarity', 'barbarousness', 'beastliness', 'bestiality', 'bloodiness', 'bloodlust', 'bloodthirst', 'bloodthirstiness', 'bloody-mindedness', 'brutality'],
    'rutty': ['broken', 'bumpy', 'burning', 'canaliculate', 'canaliculated', 'chamfered', 'channeled', 'choppy', 'coarse', 'coarse-grained', 'concupiscent', 'corduroy'],
    'sabbatarian': ['albigensian', 'catharist', 'franciscan', 'high-churchist', 'trappist', 'waldensian', 'abstainer', 'abstinent', 'anchorite', 'anchoritic', 'ascetic', 'austere'],
    'sabbatical': ['comfortable', 'festal', 'furlough', 'holiday', 'leave', 'leave of absence', 'liberty', 'paid holiday', 'paid vacation', 'quiet', 'restful', 'sabbatical leave'],
    'saber rattling': ['aggression', 'aggressiveness', 'antagonism', 'bellicism', 'bellicose', 'bellicosity', 'belligerence', 'belligerency', 'bulldozing', 'chauvinism', 'combativeness', 'commination'],
    'sable': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'atramentous', 'azure', 'bandeau', 'bar'],
    'sabotage': ['baffle', 'balk', 'bankruptcy', 'blast', 'block', 'bouleversement', 'brave', 'break up', 'breakage', 'breakdown', 'bugger', 'challenge'],
    'sac': ['anac', 'arf', 'atc', 'ats', 'air command', 'air transport command', 'air transport service', 'airborne reconnaissance force', 'army-navy air corps', 'bomber command', 'casu', 'coastal command'],
    'saccharin': ['ambrosia', 'artificial sweetener', 'blackstrap', 'calcium cyclamate', 'cane syrup', 'clover honey', 'comb honey', 'corn syrup', 'cyclamates', 'edulcoration', 'honey', 'honeycomb'],
    'saccharine': ['candied', 'cloying', 'deferential', 'disarming', 'honeyed', 'insinuating', 'insinuative', 'luscious', 'mawkish', 'oversweet', 'rich', 'sickly-sweet'],
    'sacerdotal': ['abbatial', 'abbatical', 'apostolic', 'archiepiscopal', 'canonical', 'capitular', 'capitulary', 'ceremonial', 'ceremonious', 'churchly', 'clerical', 'conventional'],
    'sachem': ['dalai lama', 'establishment', 'holy roman emperor', 'inca', 'kaiser', 'vip', 'ardri', 'baron', 'bey', 'big gun', 'big man', 'big name'],
    'sachet': ['atomizer', 'censer', 'fumigator', 'incense burner', 'incensory', 'odorator', 'odorizer', 'parfumoir', 'perfumer', 'pomander', 'potpourri', 'pouncet-box'],
    'sack': ['acquire', 'assault', 'attack', 'ax', 'bag', 'balloon', 'banditry', 'barbarize', 'barrel', 'basket', 'batter', 'be seized of'],
    'sackcloth and ashes': ['day of atonement', 'yom kippur', 'asceticism', 'black', 'cold purgatorial fires', 'crape', 'cypress', 'cypress lawn', 'deep mourning', 'fasting', 'flagellation', 'hair shirt'],
    'sacking': ['assault', 'attack', 'banditry', 'battering', 'brigandage', 'brigandism', 'butchery', 'depredation', 'despoiling', 'despoilment', 'despoliation', 'direption'],
    'sacramental': ['agnus dei', 'high-church', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'ark', 'asperger', 'asperges', 'aspergillum', 'bambino'],
    'sacrarium': ['easter sepulcher', 'lady chapel', 'adytum', 'ambry', 'apse', 'baptistery', 'blindstory', 'chancel', 'chantry', 'chapel', 'chapel of ease', 'chapel royal'],
    'sacred': ['all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'alto', 'angelic', 'awe-inspiring', 'awesome', 'awful', 'baritone', 'bass'],
    'sacrifice': ['abandon', 'abandonment', 'abjuration', 'abjure', 'altruism', 'annihilate', 'appease', 'bane', 'be bereaved of', 'bereave of life', 'bereavement', 'blood'],
    'sacrificial': ['atoning', 'best', 'bottom', 'conciliatory', 'cut', 'expiatory', 'giveaway', 'given up', 'half-price', 'lowest', 'marked down', 'propitiatory'],
    'sacrilege': ['abomination', 'abuse', 'atrocity', 'befouling', 'befoulment', 'blasphemousness', 'blasphemy', 'contamination', 'crime', 'debasement', 'defilement', 'desecration'],
    'sacrilegious': ['aberrant', 'abnormal', 'abominable', 'apostate', 'atheistic', 'atrocious', 'backsliding', 'blasphemous', 'criminal', 'delinquent', 'deviant', 'disgraceful'],
    'sacristan': ['bible clerk', 'bible reader', 'acolyte', 'almoner', 'anagnost', 'beadle', 'bedral', 'capitular', 'capitulary', 'choir chaplain', 'churchwarden', 'clerk'],
    'sacristy': ['easter sepulcher', 'ambry', 'apse', 'baptistery', 'blindstory', 'chancel', 'choir', 'cloisters', 'confessional', 'confessionary', 'crypt', 'diaconicon'],
    'sacrosanct': ['awesome', 'awful', 'divine', 'esteemed', 'heavenly', 'holy', 'ineffable', 'inenarrable', 'inexpressible', 'inviolable', 'inviolate', 'numinous'],
    'sad': ['quaker-colored', 'abominable', 'acier', 'affecting', 'afflictive', 'anguished', 'anxious', 'arrant', 'ashen', 'ashy', 'atrocious', 'awful'],
    'sad case': ['bowery bum', 'beachcomber', 'beggar', 'beggarly fellow', 'blighter', 'budmash', 'bum', 'bummer', 'caitiff', 'derelict', 'devil', 'drifter'],
    'sad sack': ['bowery bum', 'milquetoast', 'baby', 'beachcomber', 'beggar', 'beggarly fellow', 'big baby', 'blighter', 'budmash', 'bum', 'bummer', 'caitiff'],
    'sadden': ['affect', 'aggrieve', 'beat down', 'cast down', 'damp', 'dampen', 'dampen the spirits', 'darken', 'dash', 'deject', 'depress', 'discourage'],
    'saddle': ['chateaubriand', 'back band', 'backstrap', 'bearing rein', 'bed', 'bed down', 'bellyband', 'bench', 'bit', 'blade roast', 'blinders', 'blinds'],
    'saddle horse': ['bidet', 'carriage horse', 'cart horse', 'cavalry horse', 'draft horse', 'dray horse', 'driving horse', 'fill horse', 'filler', 'gigster', 'hack', 'hackney'],
    'saddle stitching': ['smyth sewing', 'backing', 'bibliopegy', 'binder board', 'binding', 'book cloth', 'book cover', 'book jacket', 'bookbinding', 'bookcase', 'case', 'casemaking'],
    'saddle with': ['account for', 'accredit with', 'accrete to', 'accuse of', 'acknowledge', 'add', 'adjoin', 'affix', 'agglutinate', 'annex', 'append', 'apply to'],
    'saddled': ['beholden', 'beholden to', 'bound', 'bounden', 'bounden to', 'burdened', 'charged', 'committed', 'cumbered', 'duty-bound', 'encumbered', 'fraught'],
    'saddler': ['baker', 'bidet', 'bookdealer', 'bookseller', 'butcher', 'carriage horse', 'cart horse', 'cavalry horse', 'chandler', 'clothing merchant', 'confectioner', 'draft horse'],
    'saddlery': ['antique store', 'apothecary', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'chemist', 'cigar store', 'clothiers', 'clothing store', 'confectionery', 'dress shop'],
    'sadism': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'animality', 'atrociousness', 'autoeroticism', 'barbarity', 'barbarousness', 'beastliness', 'bestiality', 'bisexuality'],
    'sadist': ['annoyer', 'badgerer', 'bugger', 'bully', 'coprophiliac', 'erotomaniac', 'exhibitionist', 'fetishist', 'harasser', 'harrier', 'heckler', 'masochist'],
    'sadistic': ['draconian', 'tartarean', 'animal', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bestial', 'bloodthirsty', 'bloody', 'bloody-minded'],
    'sadly': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'bleakly', 'brashly', 'by ill hap', 'by ill luck', 'confoundedly'],
    'sadness': ['aching heart', 'agony', 'agony of mind', 'anguish', 'bale', 'beggarliness', 'bitterness', 'blackishness', 'bleakness', 'bleeding heart', 'blue devils', 'blues'],
    'sadomasochism': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'bisexuality', 'coprophilia', 'exhibitionism', 'fetishism', 'heterosexuality', 'homoeroticism', 'homosexualism'],
    'safari': ['campaign', 'circuit', 'course', 'excursion', 'expedition', 'grand tour', 'jaunt', 'journey', 'junket', 'outing', 'package tour', 'peregrination'],
    'safe': ['fort knox', 'ok', 'acceptable', 'all right', 'allowable', 'appropriate', 'armed', 'bank', 'bona fide', 'bursary', 'calculating', 'canny'],
    'safe conduct': ['bill of health', 'bodyguard', 'cavalier', 'chaperon', 'clearance', 'companion', 'conductor', 'convoy', 'duenna', 'escort', 'esquire', 'fellow traveler'],
    'safeguard': ['advocate', 'aegis', 'arm', 'arm guard', 'armament', 'armor', 'assurance', 'assure', 'backstop', 'bill of health', 'bless', 'bodyguard'],
    'safekeeping': ['care', 'charge', 'cold storage', 'conservancy', 'conservation', 'conservationism', 'cover', 'custodianship', 'custody', 'dead storage', 'defense', 'dry storage'],
    'safety': ['aegis', 'arm guard', 'assurance', 'backstop', 'buffer', 'bulwark', 'bumper', 'contraceptive', 'copyright', 'cover', 'crash helmet', 'cushion'],
    'safety belt': ['mae west', 'breeches buoy', 'buoy', 'cork jacket', 'ejection capsule', 'ejection seat', 'ejector seat', 'life belt', 'life buoy', 'life jacket', 'life net', 'life preserver'],
    'safety glass': ['aegis', 'arm guard', 'backstop', 'buffer', 'bulwark', 'bumper', 'coat', 'coating', 'collop', 'contraceptive', 'copyright', 'covering'],
    'safety zone': ['abri', 'air-raid shelter', 'bomb shelter', 'bombproof', 'bunker', 'cave', 'concealment', 'cover', 'covert', 'coverture', 'cyclone cellar', 'dugout'],
    'sag': ['abate', 'ablate', 'arch', 'bag', 'basin', 'bate', 'be eaten away', 'bear market', 'bear off', 'bearish market', 'beat down', 'bend'],
    'sagacious': ['acute', 'all-knowing', 'anticipant', 'anticipatory', 'apperceptive', 'appercipient', 'apprehending', 'apprehensive', 'argute', 'astute', 'aware', 'blase'],
    'sagacity': ['acuity', 'acumen', 'acuteness', 'anticipation', 'apperception', 'astuteness', 'background', 'blaseness', 'cogency', 'comprehension', 'contemplation', 'discernment'],
    'sage': ['nestor', 'solomon', 'ace', 'acute', 'authority', 'broad-minded', 'crackerjack', 'deep', 'discerning', 'doctor', 'doyen', 'doyenne'],
    'sagging': ['abatement', 'abridgment', 'alleviation', 'attenuation', 'bagging', 'baggy', 'ballooning', 'collapsing', 'contraction', 'dampening', 'damping', 'debilitated'],
    'sahara': ['arabia deserta', 'death valley', 'barren', 'barren land', 'barrens', 'brush', 'bush', 'desert', 'desolation', 'dust bowl', 'heath', 'howling wilderness'],
    'sahib': ['esquire', 'herr', 'master', 'mister', 'sir', 'boss', 'bwana', 'chef', 'chief', 'church dignitary', 'don', 'ecclesiarch'],
    'said': ['aforementioned', 'aforenamed', 'aforesaid', 'articulated', 'beforementioned', 'enunciated', 'foregoing', 'forementioned', 'forenamed', 'former', 'lingual', 'linguistic'],
    'sail': ['aeroplane', 'airlift', 'airplane', 'balloon', 'balloon sail', 'batten', 'be airborne', 'be effortless', 'be painless', 'boat', 'boltrope', 'breeze'],
    'sail for': ['approach anchorage', 'bear down on', 'bear down upon', 'bear for', 'bear up for', 'bear up to', 'break for', 'close with', 'dash for', 'fetch', 'go aboard', 'go alongside'],
    'sail into': ['ambush', 'assail', 'assault', 'attack', 'blitz', 'bushwhack', 'collide', 'come at', 'come down on', 'crack down on', 'descend on', 'descend upon'],
    'sailing': ['aeronautics', 'air service', 'airline', 'astronautics', 'aviation', 'ballooning', 'blind flying', 'boating', 'canoeing', 'circumnavigation', 'cloud-seeding', 'coasting'],
    'sailing vessel': ['bark', 'bawley', 'bilander', 'brig', 'brigantine', 'bully', 'buss', 'caravel', 'cat', 'catamaran', 'clipper', 'corsair'],
    'sailor': ['ab', 'ancient mariner', 'argonaut', 'dylan', 'flying dutchman', 'neptune', 'od', 'poseidon', 'varuna', 'able seaman', 'able-bodied seaman', 'adventurer'],
    'sailplane': ['aeroplane', 'airlift', 'airplane', 'balloon', 'be airborne', 'cruise', 'drift', 'ferry', 'flit', 'fly', 'glide', 'glider'],
    'saint': ['ambrose of milan', 'athanasius', 'barnabas', 'basil', 'christian', 'clement of alexandria', 'clement of rome', 'cyprian of carthage', 'cyril of jerusalem', 'god-fearing man', 'gregory of nyssa', 'hermas'],
    'sainted': ['aggrandized', 'angelic', 'apotheosized', 'archangelic', 'asleep', 'asleep in jesus', 'at rest', 'awesome', 'beatified', 'bereft of life', 'big', 'blessed'],
    'sainthood': ['christianity', 'christlikeness', 'christliness', 'angelicalness', 'beatification', 'beatitude', 'beauty of holiness', 'blessedness', 'blessing', 'canonization', 'consecration', 'dedication'],
    'saintliness': ['christianity', 'christlikeness', 'christliness', 'angelicalness', 'beauty of holiness', 'fear of god', 'godlikeness', 'godliness', 'godly-mindedness', 'goodness', 'heavenliness', 'heavenly-mindedness'],
    'saintly': ['christlike', 'christly', 'elysian', 'god-fearing', 'angelic', 'archangelic', 'beatific', 'beatified', 'blameless', 'blessed', 'blissful', 'canonized'],
    'sake': ['account', 'advantage', 'aim', 'ambition', 'animus', 'aspiration', 'basis', 'behalf', 'benefit', 'calling', 'cause', 'consideration'],
    'salaam': ['bend', 'bend the knee', 'bend the neck', 'bending the knee', 'best wishes', 'bob', 'bob a curtsy', 'bob down', 'bow', 'bow and scrape', 'bow down', 'bow the head'],
    'salacious': ['fescennine', 'rabelaisian', 'animal', 'aphrodisiomaniacal', 'bawdy', 'blue', 'carnal', 'clitoromaniacal', 'concupiscent', 'dirty', 'ejaculatory', 'erotic'],
    'salad': ['caesar salad', 'jell-o salad', 'waldorf salad', 'all sorts', 'ambrosia', 'aspic', 'assemblage', 'assortment', 'brew', 'broad spectrum', 'chef salad', 'cole slaw'],
    'salad days': ['bloom', 'budtime', 'early years', 'florescence', 'flowering time', 'jeunesse', 'juvenescence', 'juvenility', 'my burning youth', 'my green age', 'prime of life', 'seedtime of life'],
    'salamander': ['amphibian', 'andiron', 'batrachian', 'bullfrog', 'chain', 'coal tongs', 'crane', 'croaker', 'crook', 'damper', 'elemental', 'elemental spirit'],
    'salami': ['vienna sausage', 'bangers', 'black pudding', 'blood pudding', 'bologna', 'braunschweiger', 'frank', 'frankfurter', 'gooseliver', 'headcheese', 'hot dog', 'knockwurst'],
    'salary': ['base pay', 'compensation', 'dismissal wage', 'earnings', 'emolument', 'escalator clause', 'escalator plan', 'fee', 'financial remuneration', 'gross income', 'guaranteed annual wage', 'hire'],
    'sale': ['abalienation', 'alienation', 'amortization', 'amortizement', 'assignation', 'assignment', 'available', 'bargain and sale', 'barter', 'bazaar', 'bequeathal', 'buying'],
    'sales force': ['agent', 'clerk', 'floorwalker', 'sales agent', 'sales engineer', 'sales manager', 'sales personnel', 'salesclerk', 'salesgirl', 'saleslady', 'salesman', 'salespeople'],
    'sales talk': ['address', 'after-dinner speech', 'allocution', 'allurement', 'ballyhoo', 'blandishment', 'cajolement', 'cajolery', 'chalk talk', 'coaxing', 'conning', 'debate'],
    'salesman': ['agent', 'clerk', 'floorwalker', 'sales agent', 'sales engineer', 'sales force', 'sales manager', 'sales personnel', 'salesclerk', 'salesgirl', 'saleslady', 'salespeople'],
    'salesmanship': ['advocacy', 'advocating', 'allurement', 'blandishment', 'bruiting', 'buildup', 'cajolement', 'cajolery', 'coaxing', 'conning', 'consumer preference study', 'consumer research'],
    'salience': ['arrantness', 'bas-relief', 'bellying', 'blatancy', 'boldness', 'bulging', 'conspicuousness', 'dignity', 'distinction', 'embossment', 'eminence', 'esteem'],
    'salient': ['airspace', 'area', 'arrant', 'arresting', 'bas-relief', 'bellying', 'belt', 'blatant', 'bold', 'boldness', 'bulging', 'celebrated'],
    'salina': ['artificial lake', 'bayou lake', 'cistern', 'dam', 'dead water', 'dike', 'etang', 'farm pond', 'fishpond', 'freshwater lake', 'glacial lake', 'inland sea'],
    'saliva': ['absorption', 'assimilation', 'bile', 'chyle', 'colostrum', 'digestion', 'digestive system', 'discharge', 'dribble', 'drivel', 'drool', 'expectoration'],
    'salivary': ['excretory', 'lachrymal', 'lachrymose', 'lacrimatory', 'lactational', 'lacteal', 'lacteous', 'rheumy', 'salivant', 'salivous', 'secretional', 'secretive'],
    'sallow': ['achromatic', 'achromic', 'anemic', 'ashen', 'ashy', 'aureate', 'auric', 'beige', 'bled white', 'bloodless', 'buff', 'buff-yellow'],
    'sally': ['access', 'aggravated assault', 'aggression', 'amphibious attack', 'aphorism', 'apothegm', 'arise', 'armed assault', 'assailing', 'assailment', 'assault', 'attack'],
    'salmagundi': ['caesar salad', 'jell-o salad', 'waldorf salad', 'all sorts', 'ambrosia', 'aspic', 'assemblage', 'assortment', 'broad spectrum', 'chef salad', 'cole slaw', 'combination salad'],
    'salmon': ['loch ness monster', 'alevin', 'benthon', 'benthos', 'broad jumper', 'bucking bronco', 'buckjumper', 'cetacean', 'coral', 'dolphin', 'fingerling', 'fish'],
    'salon': ['british museum', 'guggenheim museum', 'hermitage', 'louvre', 'metropolitan museum', 'national gallery', 'prado', 'rijksmuseum', 'tate gallery', 'uffizi', 'vanity fair', 'affair'],
    'saloon': ['pullman car', 'alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'best room', 'bistro', 'blind tiger', 'bucket shop', 'cabaret'],
    'salt': ['ab', 'ancient mariner', 'argonaut', 'attic', 'atticism', 'dylan', 'flying dutchman', 'neptune', 'od', 'poseidon', 'tabasco', 'varuna'],
    'salt away': ['bank', 'bundle away', 'cache', 'coffer', 'deposit', 'file', 'hutch', 'lay aside', 'lay away', 'lay by', 'lay down', 'lay in'],
    'salt flat': ['arabia deserta', 'death valley', 'sahara', 'alkali flat', 'alluvial plain', 'barren', 'barren land', 'barrens', 'basin', 'bottomland', 'brush', 'bush'],
    'salt marsh': ['alkali flat', 'alluvial plain', 'basin', 'baygall', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'bushveld', 'campo', 'champaign'],
    'salt water': ['agua', 'aqua', 'big drink', 'blue water', 'drink', 'drinking water', 'eau', 'ground water', 'hard water', 'head', 'heavy water', 'high sea'],
    'saltatory': ['anabatic', 'ascendant', 'ascending', 'ascensional', 'ascensive', 'bouncing', 'bounding', 'climbing', 'convulsive', 'eclamptic', 'fidgety', 'fitful'],
    'salty': ['attic', 'biting', 'blue', 'brackish', 'brilliant', 'briny', 'broad', 'clever', 'droll', 'facetious', 'funny', 'humorous'],
    'salubrious': ['beneficial', 'benign', 'bracing', 'constitutional', 'good', 'good for', 'health-enhancing', 'health-preserving', 'healthful', 'healthy', 'hygeian', 'hygienic'],
    'salutary': ['aidful', 'beneficial', 'benign', 'bracing', 'conducive', 'constitutional', 'constructive', 'contributory', 'furthersome', 'good', 'good for', 'health-enhancing'],
    'salutation': ['accost', 'address', 'bend', 'bending the knee', 'bob', 'bow', 'bowing and scraping', 'citation', 'curtsy', 'dipping the colors', 'embrace', 'eulogy'],
    'salutatory': ['address', 'after-dinner speech', 'allocution', 'chalk talk', 'debate', 'declamation', 'diatribe', 'eulogy', 'exhortation', 'filibuster', 'forensic', 'forensic address'],
    'salute': ['accost', 'acknowledge', 'address', 'adulate', 'anniversaries', 'apostrophize', 'apotheosize', 'appeal to', 'approach', 'beat the drum', 'belaud', 'bend'],
    'salvage': ['abatement', 'admission', 'admission fee', 'agio', 'allowance', 'amends', 'anchorage', 'atonement', 'bank discount', 'blood money', 'breakage', 'brokerage'],
    'salvation': ['adoption', 'circumcision', 'conservancy', 'conservation', 'conservationism', 'conversion', 'deliverance', 'delivery', 'environmental conservation', 'extrication', 'forest conservation', 'forest management'],
    'salve': ['trinkgeld', 'abate', 'aid', 'allay', 'alleviate', 'alleviative', 'alleviator', 'anesthetize', 'anodyne', 'anoint', 'appease', 'assuage'],
    'salvo': ['allowance', 'anniversaries', 'antiaircraft barrage', 'appreciation', 'bang', 'bark', 'barrage', 'blast', 'bombardment', 'bowshot', 'box barrage', 'broadside'],
    'samaritan': ['aid', 'aider', 'assister', 'backer', 'befriender', 'benefactor', 'benefactress', 'benefiter', 'good samaritan', 'good person', 'help', 'helper'],
    'sambo': ['cape colored', 'eurasian', 'cattalo', 'citrange', 'cross', 'crossbreed', 'griffe', 'half blood', 'half-bred', 'half-breed', 'half-caste', 'high yellow'],
    'same': ['doppelganger', 'tweedledum and tweedledee', 'actual thing', 'aforementioned', 'aforenamed', 'aforesaid', 'alike', 'all one', 'all the same', 'anyhow', 'anyway', 'at any rate'],
    'same mind': ['acclamation', 'accord', 'accordance', 'agreement', 'agreement of all', 'chorus', 'common assent', 'common consent', 'concert', 'concord', 'concordance', 'concurrence'],
    'sameness': ['accordance', 'agreement', 'alikeness', 'alliance', 'analogy', 'aping', 'approach', 'approximation', 'assimilation', 'broken record', 'clockwork regularity', 'closeness'],
    'samiel': ['santa ana', 'chinook', 'chinook wind', 'devil', 'dust storm', 'foehn', 'harmattan', 'hot wind', 'khamsin', 'peesash', 'sandstorm', 'shaitan'],
    'samisen': ['dobro guitar', 'f-hole guitar', 'spanish guitar', 'archlute', 'balalaika', 'banjo', 'banjo-uke', 'banjo-ukulele', 'banjo-zither', 'banjorine', 'banjuke', 'bass guitar'],
    'sample': ['adjunct', 'assay', 'barometer', 'bite', 'bring to test', 'canvass', 'case', 'case history', 'characteristic', 'component', 'conduct a poll', 'confirm'],
    'samson': ['achilles', 'antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'david', 'goliath', 'hector', 'hercules', 'polyphemus'],
    'sanatorium': ['va hospital', 'asylum', 'base hospital', 'clinic', 'community hospital', 'convalescent home', 'convalescent hospital', 'evacuation hospital', 'field hospital', 'general hospital', 'home', 'hospital'],
    'sanctified': ['tartuffian', 'tartuffish', 'affected', 'aggrandized', 'apotheosized', 'awesome', 'beatified', 'big', 'blessed', 'canonized', 'canting', 'consecrated'],
    'sanctify': ['aggrandize', 'apotheose', 'apotheosize', 'beatify', 'bless', 'canonize', 'cleanse', 'confirm', 'consecrate', 'crown', 'dedicate', 'deify'],
    'sanctimonious': ['pecksniffian', 'quakerish', 'tartuffian', 'tartuffish', 'victorian', 'affected', 'canting', 'censorious', 'deceiving', 'demure', 'false', 'fanatical'],
    'sanctimony': ['pecksniffery', 'quakerishness', 'tartuffery', 'tartuffism', 'bibliolatry', 'cant', 'censoriousness', 'charismatic gift', 'charismatic movement', 'charismatic renewal', 'demureness', 'demurity'],
    'sanction': ['john hancock', 'ok', 'accede to', 'accept', 'acceptance', 'accord', 'accord to', 'accredit', 'acquiescence', 'adherence', 'admiration', 'admire'],
    'sanctioned': ['accepted', 'actionable', 'applicable', 'authoritative', 'authorized', 'canonical', 'cathedral', 'chartered', 'competent', 'constitutional', 'empowered', 'enfranchised'],
    'sanctity': ['christianity', 'christlikeness', 'christliness', 'angelicalness', 'beauty of holiness', 'dedication', 'devotion', 'divinity', 'fear of god', 'godlikeness', 'godliness', 'godly-mindedness'],
    'sanctuary': ['indian reservation', 'adytum', 'archives', 'asylum', 'bank', 'bird sanctuary', 'bolt-hole', 'cache', 'chapel', 'church', 'concealment', 'corner'],
    'sanctum': ['adytum', 'ashram', 'cabinet', 'cell', 'cloister', 'closet', 'den', 'hermitage', 'hideaway', 'hideout', 'hiding place', 'holy of holies'],
    'sanctus': ['agnus dei', 'alleluia', 'anamnesis', 'blessing', 'canon', 'collect', 'communion', 'consecration', 'credo', 'dismissal', 'epistle', 'fraction'],
    'sand': ['backbone', 'breccia', 'buff', 'burnish', 'debris', 'detritus', 'dress', 'emery', 'file', 'furbish', 'grain', 'granule'],
    'sand dune': ['anthill', 'barrow', 'brae', 'butte', 'down', 'drumlin', 'dune', 'fell', 'foothills', 'hill', 'hillock', 'hummock'],
    'sandbank': ['ait', 'archipelago', 'atoll', 'bank', 'bar', 'cay', 'continental island', 'coral head', 'coral heads', 'coral island', 'coral reef', 'flat'],
    'sandbar': ['ait', 'archipelago', 'atoll', 'bank', 'bar', 'cay', 'continental island', 'coral head', 'coral heads', 'coral island', 'coral reef', 'flat'],
    'sander': ['buff', 'buffer', 'calender', 'chamois', 'drag', 'glazer', 'goose', 'grader', 'harrow', 'iron', 'mangle', 'plane'],
    'sanding': ['ablation', 'abrasion', 'abrasive', 'attrition', 'buffing', 'burnishing', 'chafe', 'chafing', 'detrition', 'dressing', 'erasure', 'erosion'],
    'sandpaper': ['broken ground', 'broken water', 'buff', 'burnish', 'chop', 'corduroy', 'corduroy road', 'corrugation', 'dress', 'emery', 'file', 'furbish'],
    'sandstone': ['aa', 'abyssal rock', 'basalt', 'bedrock', 'block lava', 'brash', 'breccia', 'conglomerate', 'crag', 'druid stone', 'festooned pahoehoe', 'gneiss'],
    'sandwich': ['blt', 'dagwood sandwich', 'sloppy joe', 'swiss cheese sandwich', 'bacon-lettuce-tomato sandwich', 'canape', 'cheeseburger', 'corned beef sandwich', 'double-decker sandwich', 'drag in', 'edge in', 'egg salad sandwich'],
    'sandy': ['saharan', 'anhydrous', 'arenaceous', 'arenarious', 'arid', 'athirst', 'aureate', 'auric', 'beige', 'bone-dry', 'breccial', 'brecciated'],
    'sane': ['admissible', 'all there', 'balanced', 'bright', 'bunkum', 'clearheaded', 'clearminded', 'cogent', 'commonsense', 'compelling', 'compos mentis', 'conceptive'],
    'sanforized': ['attenuated', 'consumed', 'corky', 'dried-up', 'emacerated', 'emaciated', 'parched', 'preshrunk', 'sear', 'shriveled', 'shriveled up', 'shrunk'],
    'sang-froid': ['buddha-like composure', 'oriental calm', 'aloofness', 'aplomb', 'ataraxy', 'balance', 'balanced personality', 'calm disposition', 'calm of mind', 'calmness', 'composure', 'constancy'],
    'sanguinary': ['draconian', 'tartarean', 'aggressive', 'animal', 'antagonistic', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'battling', 'beastly', 'bellicose'],
    'sanguine': ['agape', 'agog', 'all agog', 'ambivert', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'aspiring', 'assured', 'awaiting', 'beaming'],
    'sanitary': ['antiseptic', 'aseptic', 'beneficial', 'benign', 'boiled', 'bracing', 'clean', 'constitutional', 'decontaminated', 'disinfected', 'good', 'good for'],
    'sanitation': ['antisepsis', 'decontamination', 'disinfection', 'disinfestation', 'epidemiology', 'flash pasteurization', 'fumigation', 'health physics', 'hygenics', 'hygiene', 'hygienics', 'mental hygiene'],
    'sanity': ['iq', 'apprehension', 'balance', 'caliber', 'capacity', 'common sense', 'comprehension', 'conception', 'cool head', 'coolheadedness', 'coolness', 'deductive power'],
    'sannyasi': ['albigensian', 'brahman', 'catharist', 'franciscan', 'ramwat', 'sabbatarian', 'trappist', 'waldensian', 'abstainer', 'anchorite', 'ascetic', 'bairagi'],
    'sans culotte': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'cong', 'fenian', 'guevarist'],
    'sans serif': ['ascender', 'back', 'bastard type', 'beard', 'belly', 'bevel', 'black letter', 'body', 'cap', 'capital', 'case', 'counter'],
    'sans souci': ['accepting', 'at ease', 'comfortable', 'composed', 'content', 'contented', 'easy', 'easygoing', 'eupeptic', 'euphoric', 'happy', 'of good comfort'],
    'santa claus': ['father christmas', 'kriss kringle', 'maecenas', 'saint nicholas', 'saint nick', 'santa', 'almoner', 'almsgiver', 'angel', 'assignor', 'awarder', 'backer'],
    'sap': ['abate', 'abri', 'approach trench', 'asshole', 'attenuate', 'axiom', 'babe', 'beverage', 'blood', 'blunt', 'boob', 'booby'],
    'sapid': ['agreeable', 'ambrosial', 'appetizing', 'dainty', 'delectable', 'delicate', 'delicious', 'delightful', 'exquisite', 'flavored', 'flavorful', 'flavorous'],
    'sapient': ['authority', 'broad-minded', 'deep', 'discriminating', 'doctor', 'elder', 'elder statesman', 'erudite', 'great soul', 'guru', 'illuminate', 'intellect'],
    'sapless': ['saharan', 'anemic', 'anhydrous', 'arid', 'asthenic', 'athirst', 'bland', 'bloodless', 'bone-dry', 'chicken', 'cowardly', 'dead'],
    'sapling': ['adolescent', 'baby', 'conifer', 'evergreen', 'fledgling', 'fruit tree', 'hardwood tree', 'hopeful', 'infant', 'junior', 'juvenal', 'juvenile'],
    'sapped': ['ausgespielt', 'burned-out', 'devitalized', 'disabled', 'drained', 'effete', 'enervated', 'enfeebled', 'eviscerated', 'exhausted', 'fatigued', 'incapacitated'],
    'sapphic': ['ac-dc', 'alcaic', 'anacreontic', 'castalian', 'homeric', 'hudibrastic', 'pierian', 'pindaric', 'theocritean', 'amphierotic', 'autoerotic', 'bardic'],
    'sapphire': ['adamant', 'agate', 'alexandrite', 'amethyst', 'aquamarine', 'azure', 'azure-blue', 'azure-colored', 'azurean', 'azured', 'azureous', 'beryl'],
    'sapphism': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'bisexuality', 'coprophilia', 'exhibitionism', 'fetishism', 'heterosexuality', 'homoeroticism', 'homosexualism'],
    'sappy': ['absurd', 'apish', 'asinine', 'balmy', 'bathetic', 'batty', 'beery', 'befooled', 'beguiled', 'besotted', 'brainless', 'budding'],
    'saprolite': ['aa', 'abyssal rock', 'basalt', 'bedrock', 'block lava', 'brash', 'breccia', 'conglomerate', 'crag', 'druid stone', 'festooned pahoehoe', 'gneiss'],
    'saprophyte': ['algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'diatom', 'fern', 'fruits and vegetables'],
    'saprophytic': ['accompanying', 'accordant', 'agreeing', 'associate', 'associated', 'at one with', 'coacting', 'coactive', 'coadunate', 'coincident', 'collaborative', 'collective'],
    'sarcasm': ['atticism', 'acerbity', 'acridity', 'acridness', 'acrimony', 'agile wit', 'asperity', 'bitterness', 'black humor', 'burlesque', 'caricature', 'causticity'],
    'sarcastic': ['rabelaisian', 'acerb', 'acerbic', 'acid', 'acidic', 'acidulous', 'acrid', 'acrimonious', 'biting', 'bitter', 'captious', 'carping'],
    'sarcoma': ['benign tumor', 'callosity', 'callus', 'cancer', 'carcinoma', 'corn', 'cyst', 'excrescence', 'fungosity', 'fungus', 'growth', 'intumescence'],
    'sardonic': ['rabelaisian', 'caustic', 'contemptuous', 'corrosive', 'cynical', 'derisive', 'derisory', 'disdainful', 'dry', 'ironic', 'ironical', 'jeering'],
    'sarge': ['nco', 'acting corporal', 'acting sergeant', 'centurion', 'chief warrant officer', 'color sergeant', 'corporal', 'first sergeant', 'havildar', 'lance corporal', 'lance sergeant', 'master sergeant'],
    'sartrian': ['augustinian', 'averroist', 'berkeleian', 'cartesian', 'hegelian', 'heideggerian', 'heraclitean', 'humean', 'husserlian', 'kantian', 'leibnizian', 'neo-hegelian'],
    'sash': ['cadre', 'case', 'casement', 'casing', 'chassis', 'cincture', 'doorframe', 'fabric', 'frame', 'framework', 'framing', 'girdle'],
    'sashay': ['amble', 'barge', 'be getting along', 'bowl along', 'bundle', 'buzz off', 'clump', 'come away', 'commute', 'course', 'cover ground', 'depart'],
    'sassy': ['audacious', 'bandbox', 'biggety', 'bluff', 'bold', 'brash', 'brazen', 'cheeky', 'chutzpadik', 'cocky', 'contemptuous', 'crusty'],
    'satan': ['aides', 'aidoneus', 'ananias', 'apollyon', 'baron munchausen', 'beelzebub', 'cerberus', 'charon', 'cora', 'despoina', 'dis', 'dis pater'],
    'satanic': ['draconian', 'mephistophelian', 'tartarean', 'abhorrent', 'abominable', 'amoral', 'animal', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'beastly'],
    'satanism': ['black mass', 'black magic', 'chthonian worship', 'demonism', 'demonography', 'demonolatry', 'demonology', 'demonomancy', 'demonomy', 'demonry', 'devil lore', 'devil worship'],
    'sate': ['allay', 'appease', 'assuage', 'cloy', 'cram', 'engorge', 'feast', 'feed', 'fill', 'fill up', 'glut', 'gorge'],
    'sated': ['allayed', 'apathetic', 'benumbed', 'blase', 'bored', 'cloyed', 'crammed', 'dead', 'debilitated', 'disgusted', 'dopey', 'dormant'],
    'satellite': ['atda', 'ats', 'alouette', 'anna', 'apollo', 'ariel', 'atlas-score', 'biosatellite', 'comsat', 'cosmos', 'courier', 'diapason'],
    'satiate': ['allay', 'appease', 'assuage', 'be infinitely repetitive', 'be tedious', 'bore', 'brim', 'charge', 'chock', 'choke', 'cloy', 'congest'],
    'satiated': ['sro', 'allayed', 'blase', 'bloated', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full', 'choked', 'chuck-full'],
    'satin': ['alabaster', 'attenuate', 'attenuated', 'billiard table', 'blubber', 'bowling alley', 'bowling green', 'breeze', 'butter', 'clay', 'cushion', 'daintiness'],
    'satiny': ['attenuate', 'attenuated', 'buffed', 'burnished', 'cottony', 'dainty', 'delicate', 'downy', 'filmy', 'fine', 'fine-drawn', 'fine-grained'],
    'satire': ['atticism', 'english sonnet', 'goliardic verse', 'horatian ode', 'hudibrastic verse', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'rabelaisian', 'sapphic ode', 'shakespearean sonnet', 'agile wit'],
    'satirical': ['hudibrastic', 'rabelaisian', 'abusive', 'burlesque', 'caricatural', 'caustic', 'chaffing', 'cynical', 'derisive', 'disparaging', 'doggerel', 'dry'],
    'satirist': ['meistersinger', 'parnassian', 'arch-poet', 'ballad maker', 'balladmonger', 'banana', 'bard', 'beat poet', 'bucoliast', 'burlesquer', 'caricaturist', 'clown'],
    'satisfaction': ['acceptance', 'accordance', 'acquitment', 'acquittal', 'acquittance', 'adequacy', 'adequate supply', 'adequateness', 'adherence', 'affair of honor', 'amends', 'amortization'],
    'satisfactional': ['apologetic', 'ascetic', 'atoning', 'cleansing', 'compensational', 'compensatory', 'expiatory', 'lustral', 'lustrational', 'lustrative', 'penitential', 'piacular'],
    'satisfactory': ['ok', 'absolute', 'acceptable', 'adequate', 'admissible', 'all right', 'ample', 'assuring', 'authoritative', 'barely sufficient', 'better than nothing', 'cogent'],
    'satisfied': ['accepting', 'allayed', 'assured', 'at ease', 'believing', 'certain', 'charmed', 'cloyed', 'comfortable', 'composed', 'confident', 'content'],
    'satisfy': ['abide by', 'achieve inner harmony', 'act up to', 'adhere to', 'allay', 'amortize', 'answer', 'appease', 'ascertain', 'assuage', 'assure', 'atone'],
    'satisfying': ['absolute', 'adequate', 'affable', 'agreeable', 'amiable', 'amicable', 'ample', 'assuring', 'authoritative', 'blissful', 'cheerful', 'cloying'],
    'satori': ['a priori knowledge', 'anticipation', 'ataraxia', 'ataraxy', 'buddhi', 'calmness', 'clairvoyance', 'composure', 'contemplation', 'direct apprehension', 'immediate cognition', 'imperturbability'],
    'saturate': ['allay', 'bathe', 'besprinkle', 'breathe', 'brew', 'brim', 'charge', 'chock', 'choke', 'cloy', 'color', 'congest'],
    'saturated': ['sro', 'allayed', 'awash', 'bathed', 'bloated', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full', 'choked'],
    'saturation': ['munsell chroma', 'technicolor', 'amplitude', 'bellyful', 'brewing', 'bright color', 'brightness', 'brilliance', 'chroma', 'chromatic color', 'chromaticity', 'color'],
    'saturation point': ['activity', 'amplitude', 'artificial radioactivity', 'bellyful', 'congestion', 'contamination', 'curiage', 'decontamination', 'engorgement', 'fallout', 'fill', 'flood tide'],
    'saturnine': ['black', 'bleak', 'crabbed', 'dark', 'dismal', 'dour', 'drear', 'drearisome', 'dreary', 'funebrial', 'funereal', 'gloomy'],
    'satyr': ['cailleac', 'faunus', 'pan', 'priapus', 'vidar', 'vitharr', 'aphrodisiomaniac', 'bugger', 'coprophiliac', 'corn spirit', 'dirty old man', 'eroticomaniac'],
    'sauce': ['colbert', 'french dressing', 'italian dressing', 'lorenzo dressing', 'ritz sauce', 'russian dressing', 'smitane', 'soubise', 'alcohol', 'all sorts', 'allemande', 'answer back'],
    'saucer': ['annular muscle', 'annulus', 'areola', 'aureole', 'chaplet', 'circle', 'circuit', 'circumference', 'circus', 'closed circle', 'corona', 'coronet'],
    'saucer shaped': ['bell-like', 'bell-shaped', 'boat-shaped', 'boatlike', 'bowl-shaped', 'bowllike', 'campaniform', 'campanular', 'campanulate', 'cavelike', 'cavernous', 'concave'],
    'saucy': ['arch', 'arrogant', 'audacious', 'bantam', 'biggety', 'bluff', 'bold', 'brash', 'brassy', 'brazen', 'bumptious', 'challenging'],
    'sault': ['niagara', 'cascade', 'cataract', 'chute', 'fall', 'falls', 'force', 'linn', 'nappe', 'rapid', 'rapids', 'riff'],
    'sauna': ['finnish bath', 'japanese bath', 'russian bath', 'swedish bath', 'turkish bath', 'bagnio', 'balneae', 'balneum', 'bath', 'bathe', 'bathhouse', 'bathroom'],
    'saunter': ['airing', 'amble', 'andante', 'barge', 'bat around', 'bowl along', 'bum', 'bundle', 'claudicate', 'claudication', 'clump', 'constitutional'],
    'sausage': ['vienna sausage', 'bangers', 'black pudding', 'blood pudding', 'bologna', 'braunschweiger', 'frank', 'frankfurter', 'gooseliver', 'headcheese', 'hot dog', 'knockwurst'],
    'saute': ['bake', 'barbecue', 'baste', 'blanch', 'boil', 'braise', 'brew', 'broil', 'brown', 'coddle', 'cook', 'curry'],
    'savage': ['draconian', 'goth', 'gothic', 'mafioso', 'neanderthal', 'tartarean', 'young turk', 'abrade', 'abuse', 'afflict', 'aggressive', 'aggrieve'],
    'savagery': ['gothicism', 'neanderthalism', 'acuteness', 'age of ignorance', 'animality', 'atrociousness', 'atrocity', 'barbarism', 'barbarity', 'barbarousness', 'beastliness', 'benightedness'],
    'savanna': ['alkali flat', 'alluvial plain', 'basin', 'bottomland', 'bushveld', 'campo', 'champaign', 'champaign country', 'coastal plain', 'delta', 'desert', 'down'],
    'savant': ['admirable crichton', 'academician', 'adept', 'aficionado', 'amateur', 'artisan', 'artist', 'attache', 'authority', 'bookman', 'buff', 'classicist'],
    'save': ['abet', 'abstain', 'accumulate', 'aid', 'amass', 'anticipate', 'aside from', 'assist', 'avail', 'avert', 'backlog', 'bail out'],
    'saved': ['angelic', 'archangelic', 'beatified', 'born again', 'canonized', 'celestial', 'cherubic', 'circumcised', 'conserved', 'converted', 'extra', 'fresh'],
    'saver': ['audubon society', 'national wildlife service', 'sierra club', 'conservationist', 'conservator', 'deliverer', 'economist', 'economizer', 'forest ranger', 'game warden', 'keeper', 'lifesaver'],
    'saving': ['scotch', 'aside from', 'bar', 'barring', 'beside', 'besides', 'but', 'cache', 'canny', 'careful', 'chary', 'cheeseparing'],
    'saving clause': ['alternative', 'bill', 'boundary condition', 'calendar', 'catch', 'choice', 'clause', 'companion bills amendment', 'condition', 'donnee', 'dragnet clause', 'enacting clause'],
    'savings': ['swiss bank account', 'assets', 'backlog', 'balance', 'bank account', 'bottom dollar', 'budget', 'cache', 'cash reserves', 'checking account', 'command of money', 'exchequer'],
    'savior': ['christ', 'christ jesus', 'emmanuel', 'god the son', 'god-man', 'immanuel', 'jesu', 'jesus', 'jesus christ', 'jesus of nazareth', 'king of glory', 'king of heaven'],
    'savitar': ['agni', 'amen-ra', 'apollo', 'asvins', 'avalokita', 'bhairava', 'bhairavi', 'brahma', 'chandi', 'daksha', 'devaki', 'devi'],
    'savoir faire': ['adroitness', 'comprehension', 'diplomacy', 'discretion', 'finesse', 'grace', 'knowledge', 'knowledgeability', 'poise', 'polish', 'savvy', 'skill'],
    'savoir-faire': ['ability', 'adaptability', 'address', 'adeptness', 'adroitness', 'affection', 'airmanship', 'aplomb', 'artfulness', 'artisanship', 'artistry', 'attribute'],
    'savor': ['adore', 'aftertaste', 'appreciate', 'ardency', 'ardor', 'aroma', 'attribute', 'badge', 'bask in', 'be fond of', 'be partial to', 'be pleased with'],
    'savorless': ['bland', 'dead', 'dilute', 'diluted', 'distasteful', 'fade', 'flat', 'flavorless', 'gruelly', 'ill-flavored', 'inane', 'indifferent'],
    'savory': ['agreeable', 'ambrosia', 'ambrosial', 'appetizer', 'appetizing', 'aromatic', 'balmy', 'bonne bouche', 'cate', 'choice morsel', 'comestible', 'creditable'],
    'savvy': ['ability', 'absorb', 'acuity', 'acuteness', 'address', 'adeptness', 'adroitness', 'airmanship', 'appreciate', 'apprehend', 'apprehension', 'aptitude'],
    'saw': ['vandyke edge', 'adage', 'amputate', 'ana', 'analects', 'aphorism', 'apothegm', 'ax', 'axiom', 'backsaw', 'band saw', 'belt saw'],
    'saw toothed': ['v-shaped', 'y-shaped', 'akimbo', 'angular', 'battlemented', 'bent', 'chopped', 'cornered', 'corrugated', 'cragged', 'craggy', 'crenate'],
    'sawbones': ['doctor of medicine', 'gp', 'md', 'md', 'allopath', 'allopathist', 'attending physician', 'coroner', 'country doctor', 'croaker', 'doc', 'doctor'],
    'sawbuck': ['c-note', 'g-note', 'buck', 'cartwheel', 'cent', 'century', 'clotheshorse', 'copper', 'dime', 'dollar', 'dollar bill', 'fifty cents'],
    'sawdust': ['afterglow', 'afterimage', 'air pollution', 'attritus', 'balance', 'bran', 'butt', 'butt end', 'candle ends', 'chaff', 'cosmic dust', 'crumb'],
    'sawmill': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery', 'brewery', 'brickyard', 'cannery'],
    'saxhorn': ['alpenhorn', 'alphorn', 'althorn', 'alto horn', 'ballad horn', 'baritone', 'bass horn', 'brass choir', 'brass wind', 'brass-wind instrument', 'brasses', 'bugle'],
    'saxophone': ['english horn', 'pandean pipe', 'aulos', 'basset horn', 'basset oboe', 'bassoon', 'bombard', 'clarinet', 'contrabassoon', 'contrafagotto', 'cromorne', 'double bassoon'],
    'say': ['australian ballot', 'hare system', 'parthian shot', 'about', 'absolute power', 'absolutism', 'acknowledge', 'acme', 'address', 'affirm', 'affirmance', 'affirmation'],
    'say so': ['absolute power', 'absolutism', 'affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'assertion', 'asseveration', 'authority', 'averment', 'avouchment'],
    'say the word': ['ok', 'accord', 'admit', 'allow', 'bid', 'call on', 'call the signals', 'call upon', 'charge', 'command', 'commission', 'consent'],
    'saying': ['parthian shot', 'adage', 'address', 'affirmance', 'affirmation', 'allegation', 'ana', 'analects', 'announcement', 'annunciation', 'answer', 'aphorism'],
    'scab': ['abscess', 'aposteme', 'bed sore', 'birthmark', 'blackhead', 'blackleg', 'blain', 'bleb', 'blemish', 'blister', 'boil', 'bubo'],
    'scabby': ['abject', 'abominable', 'arrant', 'asperous', 'atrocious', 'barfy', 'base', 'beggarly', 'blemished', 'checked', 'cheesy', 'cicatrized'],
    'scabies': ['texas fever', 'acne', 'acne vulgaris', 'anthrax', 'aphthous fever', 'bighead', 'black quarter', 'blackleg', 'blackwater', 'blind staggers', 'bloody flux', 'broken wind'],
    'scabrous': ['asperous', 'bristly', 'craggy', 'downy', 'flaky', 'flocculent', 'furfuraceous', 'harsh', 'jagged', 'knobby', 'knotty', 'lentiginous'],
    'scads': ['abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'batch', 'bonanza', 'bountifulness', 'bountiousness', 'bumper crop', 'considerable'],
    'scaffold': ['ax', 'block', 'cross', 'death chair', 'death chamber', 'drop', 'echafaudage', 'electric chair', 'gallows', 'gallows-tree', 'gas chamber', 'gibbet'],
    'scag': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'scalawag': ['balker', 'balky horse', 'blackguard', 'crock', 'crowbait', 'devil', 'dog', 'enfant terrible', 'garron', 'goat', 'hack', 'jade'],
    'scald': ['abrade', 'abrasion', 'bake', 'bark', 'be in heat', 'blaze', 'blemish', 'bloody', 'bloom', 'boil', 'brand', 'break'],
    'scalded': ['aggravated', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped', 'cracked', 'crazed', 'cut', 'damaged', 'deteriorated'],
    'scalding': ['ardent', 'baking', 'blistering', 'boiling', 'broiling', 'burning', 'burning hot', 'canicular', 'ebullient', 'feverish', 'fiery', 'flushed'],
    'scale': ['danish balance', 'indian file', 'lambert conformal projection', 'mercator projection', 'miller projection', 'roman balance', 'weightometer', 'accommodation ladder', 'adjust', 'aeronautical chart', 'alloy balance', 'amount'],
    'scale down': ['abridge', 'compress', 'contract', 'curtail', 'cut', 'cut back', 'cut down', 'damp', 'dampen', 'decrease', 'deduct', 'deflate'],
    'scaling': ['air attack', 'air raid', 'air strike', 'boarding', 'breakup', 'crack-up', 'diffusion', 'disintegration', 'dispersal', 'disruption', 'dissolution', 'escalade'],
    'scallop': ['dungeness crab', 'japanese crab', 'vandyke', 'vandyke edge', 'armadillo shell', 'bake', 'barbecue', 'baste', 'blanch', 'blaze', 'blue point', 'boil'],
    'scalloped': ['baked', 'battlemented', 'boiled', 'braised', 'broiled', 'browned', 'chopped', 'coddled', 'cooked', 'crenate', 'crenated', 'crenellated'],
    'scalp': ['bark', 'be caught short', 'be short', 'belong', 'bucket', 'bucketshop', 'decorticate', 'deposit margin', 'excoriate', 'flay', 'go long', 'hold on'],
    'scalper': ['adventurer', 'agent', 'big operator', 'clerk', 'floorwalker', 'gunslinger', 'lame duck', 'margin purchaser', 'operator', 'plunger', 'sales agent', 'sales engineer'],
    'scaly': ['asperous', 'branny', 'chalklike', 'chalky', 'comminute', 'comminuted', 'crushed', 'detrital', 'detrited', 'disintegrated', 'dusty', 'efflorescent'],
    'scam': ['ballot-box stuffing', 'beat', 'beguile of', 'bilk', 'bunco', 'burn', 'cardsharping', 'cheat', 'cheating', 'chisel', 'chouse', 'chouse out of'],
    'scamp': ['bad boy', 'begrudge', 'bird', 'blackguard', 'blink', 'booger', 'buffoon', 'bugger', 'carefully ignore', 'chap', 'cold-shoulder', 'cut a corner'],
    'scamper': ['bolt', 'bundle', 'burst', 'burst of speed', 'bustle', 'canter', 'career', 'chase', 'crowd', 'dart', 'dash', 'dash off'],
    'scamping': ['cheeseparing', 'culpably negligent', 'derelict', 'frugal', 'frugal to excess', 'inadvertent', 'inattentive', 'laissez-faire', 'lax', 'loose', 'neglectful', 'neglecting'],
    'scampish': ['arch', 'base', 'blackguardly', 'degraded', 'devilish', 'elfish', 'elvish', 'foolish', 'full of mischief', 'high-spirited', 'impish', 'infamous'],
    'scan': ['alliterate', 'analysis', 'assonate', 'audit', 'autopsy', 'block out', 'browse', 'canvass', 'cap verses', 'check', 'check out', 'check over'],
    'scandal': ['abomination', 'abuse', 'asperse', 'aspersion', 'atrocity', 'backbiting', 'backstabbing', 'bad', 'badge of infamy', 'belittlement', 'bitchiness', 'black mark'],
    'scandalize': ['affront', 'asperse', 'calumniate', 'defame', 'denigrate', 'disturb', 'gall', 'horrify', 'libel', 'offend', 'outrage', 'rankle'],
    'scandalous': ['aberrant', 'abnormal', 'abominable', 'abusive', 'arrant', 'atrocious', 'awful', 'back-biting', 'backbiting', 'bad', 'base', 'beastly'],
    'scanning': ['edp', 'stabreim', 'alliterative meter', 'analyzing', 'antispastic', 'automatic tracking', 'cadenced', 'classifying', 'collating', 'computer technology', 'computer typesetting', 'computing'],
    'scansion': ['stabreim', 'alliterative meter', 'blocking', 'detailing', 'enumeration', 'itemization', 'measure', 'meter', 'metrical pattern', 'metrics', 'numbers', 'parsing'],
    'scant': ['lenten', 'spartan', 'abstemious', 'angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'arrested', 'ascetic', 'austere', 'bankrupt in', 'bare of'],
    'scantiness': ['lenten fare', 'austerity', 'chinchiness', 'chintziness', 'daintiness', 'dearth', 'defalcation', 'deficiency', 'deficit', 'delicacy', 'diminutiveness', 'exiguity'],
    'scanty': ['lenten', 'spartan', 'abstemious', 'angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'arrested', 'ascetic', 'at a premium', 'austere', 'barely sufficient'],
    'scape': ['maypole', 'abscond', 'airscape', 'bar', 'break', 'breakout', 'bunk', 'cityscape', 'cloudscape', 'decamp', 'diorama', 'exterior'],
    'scapegoat': ['burnt offering', 'collection', 'drink offering', 'dupe', 'ex voto offering', 'fall guy', 'front', 'goat', 'gull', 'heave offering', 'hecatomb', 'holocaust'],
    'scapegrace': ['backslider', 'bad boy', 'bad egg', 'bad lot', 'black sheep', 'booger', 'buffoon', 'bugger', 'cutup', 'degenerate', 'devil', 'elf'],
    'scar': ['birthmark', 'blackhead', 'blaze', 'blaze a trail', 'bleb', 'blemish', 'blister', 'blotch', 'bluff', 'brand', 'bulla', 'burn'],
    'scarab': ['amulet', 'charm', 'fetish', 'fylfot', 'gammadion', 'good-luck charm', 'hoodoo', 'juju', 'love charm', 'lucky bean', 'lucky piece', 'madstone'],
    'scarce': ['almost unheard-of', 'at a premium', 'barely', 'cheeseparing', 'chinchy', 'chintzy', 'curtailed', 'deficient', 'exiguous', 'failing', 'few', 'hardly'],
    'scarcely': ['a bit', 'a little', 'at infrequent intervals', 'barely', 'by a hair', 'by an ace', 'by no means', 'ever so little', 'exiguously', 'extremely', 'faintly', 'fairly'],
    'scarcity': ['absence', 'chinchiness', 'chintziness', 'dearth', 'deficiency', 'exiguity', 'fewness', 'inadequacy', 'inadequateness', 'infrequence', 'infrequency', 'insufficiency'],
    'scare': ['abject fear', 'affright', 'alarm', 'awe', 'blue funk', 'bluff off', 'collect', 'come by', 'consternation', 'cow', 'cowardice', 'curdle the blood'],
    'scare up': ['accumulate', 'amass', 'assemble', 'bring together', 'collect', 'cull', 'dig up', 'gather', 'gather in', 'get in', 'get together', 'glean'],
    'scarecrow': ['dracula', 'frankenstein', 'wolf-man', 'baboon', 'bag', 'blemish', 'blot', 'bogey', 'bogeyman', 'bugaboo', 'bugbear', 'bust'],
    'scared': ['afeared', 'afraid', 'aghast', 'alarmed', 'anxious', 'appalled', 'fear-struck', 'feared', 'fearful', 'frightened', 'haunted with fear', 'horrified'],
    'scared stiff': ['aghast', 'appalled', 'ashen', 'astounded', 'awed', 'awestricken', 'awestruck', 'blanched', 'cowed', 'deadly pale', 'frozen', 'gray with fear'],
    'scaredy cat': ['milquetoast', 'baby', 'big baby', 'chicken', 'chicken liver', 'coward', 'fraid-cat', 'fraidy-cat', 'funk', 'funker', 'invertebrate', 'jellyfish'],
    'scarehead': ['banner', 'banner head', 'caption', 'drop head', 'dropline', 'epigraph', 'hanger', 'head', 'heading', 'headline', 'jump head', 'legend'],
    'scarer': ['dracula', 'frankenstein', 'wolf-man', 'bogey', 'bogeyman', 'bugaboo', 'bugbear', 'fee-faw-fum', 'frightener', 'ghost', 'ghoul', 'hobgoblin'],
    'scarf': ['roman collar', 'ankle', 'articulate', 'articulation', 'band', 'bandanna', 'batten', 'batten down', 'bertha', 'boa', 'bolt', 'boundary'],
    'scarify': ['vandyke', 'agonize', 'assail', 'attack', 'blaze', 'blaze a trail', 'blemish', 'blister', 'bloody', 'blotch', 'brand', 'castigate'],
    'scariness': ['alarmingness', 'appallingness', 'awfulness', 'creepiness', 'direness', 'disconcertingness', 'dismayingness', 'disquietingness', 'dreadfulness', 'eeriness', 'fearfulness', 'fearsomeness'],
    'scarlet': ['titian', 'titian-red', 'bricky', 'cardinal', 'carmine', 'carnation', 'carnelian', 'cerise', 'cherry', 'cherry-colored', 'cherry-red', 'crimson'],
    'scarlet fever': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'scarlet woman': ['b-girl', 'cyprian', 'paphian', 'call girl', 'daughter of joy', 'erring sister', 'fallen woman', 'fille de joie', 'harlot', 'hooker', 'hustler', 'meretrix'],
    'scarp': ['abatis', 'advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'bastion', 'battlement'],
    'scarred': ['blemished', 'checked', 'cicatrized', 'cracked', 'crazed', 'defaced', 'defective', 'deformed', 'disfigured', 'distorted', 'faulty', 'flawed'],
    'scary': ['aghast', 'alarming', 'anxious', 'awing', 'bashful', 'chilling', 'cowardly', 'crawly', 'creepy', 'daunting', 'deterrent', 'deterring'],
    'scat': ['baloney', 'bel canto', 'bilge', 'blah', 'blah-blah', 'bop', 'bosh', 'bravura', 'bull', 'bullshit', 'bunk', 'bunkum'],
    'scat singing': ['bel canto', 'bravura', 'choral singing', 'coloratura', 'croon', 'crooning', 'folk singing', 'hum', 'humming', 'intonation', 'lyricism', 'operatic singing'],
    'scathe': ['abuse', 'afflict', 'aggrieve', 'assail', 'attack', 'bankruptcy', 'befoul', 'bewitch', 'blight', 'blister', 'breakage', 'breakdown'],
    'scathing': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'astringent', 'biting', 'bitter'],
    'scatological': ['rabelaisian', 'abusive', 'blasphemous', 'calumniatory', 'calumnious', 'coarse', 'comminatory', 'contumelious', 'crappy', 'cursing', 'damnatory', 'denunciatory'],
    'scatology': ['argot', 'bad language', 'billingsgate', 'blue language', 'cant', 'colorful language', 'cursing', 'cussing', 'dirty language', 'dirty talk', 'dysphemism', 'evil speaking'],
    'scatter': ['atomize', 'bend', 'besprinkle', 'bestrew', 'bias', 'blow', 'break into pieces', 'break to pieces', 'break up', 'broadcast', 'cast', 'circulate'],
    'scatterbrain': ['birdbrain', 'featherbrain', 'featherhead', 'flibbertigibbet', 'fool', 'giddybrain', 'giddyhead', 'goose', 'harebrain', 'rattlebrain', 'rattlehead', 'rattlepate'],
    'scatterbrained': ['adrift', 'afloat', 'alternating', 'amorphous', 'blank', 'brainless', 'capricious', 'changeable', 'changeful', 'dazed', 'desultory', 'deviable'],
    'scattered': ['alienated', 'all up with', 'anarchic', 'arsy-varsy', 'ass-backwards', 'balled up', 'beat', 'beaten', 'bested', 'bollixed up', 'broadcast', 'chaotic'],
    'scattering': ['a few', 'aloofness', 'anarchy', 'attenuation', 'attenuative', 'bit', 'breakup', 'broadcast', 'broadcasting', 'chaos', 'circumfusion', 'confusion'],
    'scavenge': ['bleach', 'bowdlerize', 'clean', 'clean out', 'clean up', 'cleanse', 'clear out', 'delouse', 'depurate', 'deterge', 'dry-clean', 'dust'],
    'scavenger': ['amphibian', 'aquatic', 'biped', 'canine', 'cannibal', 'carnivore', 'chimney sweep', 'cleanser', 'cosmopolite', 'crossing sweeper', 'feline', 'flue cleaner'],
    'scenario': ['book', 'continuity', 'cue', 'design', 'framework', 'game plan', 'layout', 'libretto', 'lines', 'outline', 'playbook', 'plot'],
    'scenario writer': ['advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'choreographer', 'coauthor', 'collaborator', 'columnist', 'comedian'],
    'scend': ['be poised', 'billow', 'bore', 'break', 'breakers', 'chop', 'choppiness', 'chopping sea', 'comb', 'comber', 'crash', 'dash'],
    'scene': ['access', 'act', 'act drop', 'action', 'afterpiece', 'agora', 'airscape', 'altercation', 'amphitheater', 'appear', 'area', 'arena'],
    'scenery': ['act drop', 'agora', 'airscape', 'amphitheater', 'arena', 'asbestos', 'asbestos board', 'athletic field', 'auditorium', 'backdrop', 'background', 'batten'],
    'scenic': ['actor-proof', 'all-star', 'awe-inspiring', 'awesome', 'ballet', 'balletic', 'beautiful', 'breathtaking', 'cinematic', 'cinematographic', 'dramatic', 'dramatical'],
    'scent': ['ambergris', 'ambrosia', 'aroma', 'aromatic', 'aromatic gum', 'aromatic water', 'aromatize', 'attar', 'attar of roses', 'balm', 'balm of gilead', 'balminess'],
    'scented': ['ambrosial', 'aromatic', 'balmy', 'essenced', 'flowery', 'fragrant', 'fruity', 'incense-breathing', 'musky', 'odorate', 'odoriferous', 'odorous'],
    'scepter': ['baton', 'caduceus', 'cap of dignity', 'cap of maintenance', 'chain of office', 'coronet', 'crook', 'crosier', 'cross-staff', 'crown', 'diadem', 'ermine'],
    'schedule': ['active list', 'agenda', 'allocate', 'allot', 'appoint', 'approach', 'appropriate to', 'arrange', 'arrangement', 'assign', 'assign to', 'attack'],
    'scheduled': ['arranged', 'billed', 'blueprinted', 'booked', 'cadastral', 'calculated', 'cataloged', 'charted', 'contrived', 'designed', 'devised', 'entered'],
    'schema': ['alphabet', 'approach', 'arrangement', 'art', 'attack', 'blueprint', 'blueprinting', 'calculation', 'catalog', 'catalogue raisonne', 'charactering', 'characterization'],
    'scheme': ['byzantine intrigues', 'action', 'anagnorisis', 'angle', 'approach', 'architectonics', 'architecture', 'argument', 'arrangement', 'art', 'artful dodge', 'artifice'],
    'schemer': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'machiavellian', 'quisling', 'archtraitor', 'betrayer', 'calculator', 'cockatrice', 'coconspirator', 'conniver'],
    'scheming': ['byzantine', 'machiavellian', 'machiavellic', 'acute', 'arch', 'artful', 'artifice', 'astute', 'cabal', 'cagey', 'calculating', 'canny'],
    'scherzo': ['adagietto', 'adagio', 'allegretto', 'allegro', 'andante', 'andantino', 'crescendo', 'decrescendo', 'diminuendo', 'forte', 'fortissimo', 'larghetto'],
    'schism': ['affiliation', 'alienation', 'apostasy', 'betrayal', 'body', 'bolt', 'branch', 'breach', 'breach of friendship', 'break', 'breakaway', 'chasm'],
    'schismatic': ['young turk', 'apostate', 'backslider', 'bolter', 'breakaway', 'collaborationist', 'collaborator', 'convert', 'defector', 'demurrer', 'denominationalist', 'deserter'],
    'schismatical': ['abjuratory', 'alienated', 'antiestablishment', 'at odds with', 'at variance with', 'breakaway', 'counter-culture', 'denominational', 'differing', 'disagreeing', 'dissentient', 'dissenting'],
    'schist': ['aa', 'abyssal rock', 'basalt', 'bedrock', 'block lava', 'brash', 'breccia', 'conglomerate', 'crag', 'druid stone', 'festooned pahoehoe', 'gneiss'],
    'schizoid': ['alcoholic', 'alternating personality', 'ambivert', 'antisocial personality', 'brain-damaged', 'brain-injured', 'catatoniac', 'catatonic', 'certifiable', 'certifiable case', 'choleric', 'cycloid'],
    'schizophrenia': ['alternating personality', 'brain disease', 'catatonia', 'catatonic schizophrenia', 'crack-up', 'dementia praecox', 'depersonalization', 'disconnection', 'dissociation', 'dissociation of personality', 'double personality', 'dual personality'],
    'schizophrenic': ['brain-damaged', 'brain-injured', 'catatoniac', 'catatonic', 'certifiable', 'certifiable case', 'disturbed', 'manic-depressive', 'mental', 'mental case', 'mentally ill', 'mentally sick'],
    'schlemiel': ['asshole', 'boob', 'booby', 'chump', 'ding-a-ling', 'dingbat', 'dingdong', 'dupe', 'fall guy', 'galoot', 'goof', 'gull'],
    'schlep': ['airing', 'amble', 'chug on', 'constitutional', 'drab', 'forced march', 'frump', 'hike', 'jaunt', 'jog on', 'litterbug', 'lumber'],
    'schlock': ['abominable', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beneath contempt', 'blameworthy', 'brutal', 'contemptible', 'deplorable', 'despicable'],
    'schmaltzy': ['bathetic', 'beery', 'cloying', 'gooey', 'gushing', 'maudlin', 'mawkish', 'mushy', 'namby-pamby', 'nostalgic', 'nostomanic', 'oversentimental'],
    'schmuck': ['ass', 'born fool', 'buffoon', 'clown', 'doodle', 'egregious ass', 'figure of fun', 'fool', 'idiot', 'ignoramus', 'jackass', 'jerk'],
    'schnapps': ['john barleycorn', 'alcohol', 'alcoholic beverage', 'alcoholic drink', 'aqua vitae', 'ardent spirits', 'beverage', 'booze', 'brew', 'drink', 'grog', 'hard liquor'],
    'schnozzle': ['antlia', 'beak', 'beezer', 'bill', 'bugle', 'conk', 'muffle', 'muzzle', 'nares', 'neb', 'nib', 'nose'],
    'scholar': ['academic', 'academician', 'aficionado', 'amateur', 'auditor', 'authority', 'autodidact', 'bookman', 'bookworm', 'brain', 'buff', 'classicist'],
    'scholarly': ['abstruse', 'academic', 'bookish', 'brainy', 'civilized', 'cross-disciplinary', 'cultivated', 'cultured', 'deep', 'devoted to studies', 'diligent', 'disciplinary'],
    'scholarship': ['aid', 'alimony', 'allotment', 'allowance', 'annuity', 'assistance', 'award', 'bibliolatry', 'bibliomania', 'bluestockingism', 'book learning', 'book madness'],
    'scholastic': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'abstruse', 'academic', 'academician', 'animist', 'animistic', 'atomistic', 'bibliophagic'],
    'scholiast': ['allegorist', 'annotator', 'book reviewer', 'captious critic', 'carper', 'caviler', 'censor', 'censurer', 'cicerone', 'clarifier', 'cognoscente', 'commentator'],
    'scholium': ['adversaria', 'aide-memoire', 'annotation', 'apparatus criticus', 'comment', 'commentary', 'commentation', 'docket', 'entry', 'exegesis', 'footnote', 'gloss'],
    'school': ['american', 'art nouveau', 'ashcan school', 'barbizon', 'bauhaus', 'bolognese', 'british', 'cobra', 'dutch', 'flemish', 'fontainebleau', 'french'],
    'school of thought': ['aesthetics', 'axiology', 'casuistry', 'cosmology', 'epistemology', 'ethics', 'first philosophy', 'gnosiology', 'logic', 'mental philosophy', 'metaphysics', 'moral philosophy'],
    'schoolbook': ['abecedarium', 'abecedary', 'alphabet book', 'battledore', 'casebook', 'exercise book', 'gradus', 'grammar', 'hornbook', 'manual', 'manual of instruction', 'primer'],
    'schoolboy': ['boy', 'bub', 'bubba', 'buck', 'bud', 'buddy', 'classmate', 'colt', 'cub', 'fellow', 'fellow student', 'fledgling'],
    'schooling': ['book learning', 'booklore', 'catechization', 'coaching', 'didactics', 'direction', 'edification', 'education', 'enlightenment', 'guidance', 'illumination', 'indoctrination'],
    'schoolman': ['academician', 'bookman', 'canonist', 'classicist', 'clerk', 'colossus of knowledge', 'divine', 'divinity student', 'genius', 'giant of learning', 'humanist', 'learned clerk'],
    'schoolmaster': ['abecedarian', 'certified teacher', 'docent', 'doctor', 'dominie', 'don', 'educationist', 'educator', 'fellow', 'guide', 'guru', 'instructor'],
    'schoolmate': ['ace', 'amigo', 'associate', 'bedfellow', 'bedmate', 'birthmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty', 'camarade'],
    'schoolteacher': ['abecedarian', 'certified teacher', 'docent', 'doctor', 'dominie', 'don', 'educationist', 'educator', 'fellow', 'guide', 'guru', 'instructor'],
    'sci fi': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'apologue', 'bedtime story', 'detective story', 'fable', 'fabliau', 'fairy tale'],
    'sciatica': ['ms', 'amyotrophic lateral sclerosis', 'brain disease', 'cephalalgia', 'cerebral palsy', 'chorea', 'emotional disorder', 'epilepsy', 'falling sickness', 'glossopharyngeal neuralgia', 'headache', 'herpes zoster'],
    'science': ['academic discipline', 'academic specialty', 'applied science', 'area', 'arena', 'art', 'body of knowledge', 'branch', 'concern', 'craft', 'department of knowledge', 'discipline'],
    'science fiction': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'apologue', 'bedtime story', 'detective story', 'fable', 'fabliau', 'fairy tale'],
    'scientific': ['close', 'constant', 'delicate', 'detailed', 'direct', 'disciplinary', 'down-to-earth', 'earthy', 'even', 'exact', 'express', 'faithful'],
    'scientism': ['down-to-earthness', 'earthiness', 'freedom from illusion', 'hardheadedness', 'lack of feelings', 'matter-of-factness', 'positivism', 'practical-mindedness', 'practicality', 'practicalness', 'pragmaticism', 'pragmatism'],
    'scintilla': ['blink', 'blinking', 'cast', 'coruscation', 'dash', 'firefly', 'gleam', 'glimmer', 'glimmering', 'glisten', 'glister', 'glitter'],
    'scintillate': ['be brilliant', 'be merry with', 'blink', 'coruscate', 'crack a joke', 'crack wise', 'fleer at', 'fun', 'gibe at', 'glance', 'gleam', 'glimmer'],
    'scintillating': ['attic', 'ablaze', 'adroit', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'apt', 'ardent', 'biting', 'blazing'],
    'scintillation': ['aphorism', 'apothegm', 'black spot', 'blink', 'blinking', 'bloom', 'blooping', 'bon mot', 'boutade', 'bright idea', 'bright thought', 'brilliant idea'],
    'scion': ['appendage', 'arm', 'bine', 'bough', 'branch', 'branchedness', 'branchiness', 'burgeon', 'child', 'daughter', 'deadwood', 'descendant'],
    'scissile': ['alienable', 'breakable', 'brittle', 'brittle as glass', 'crackable', 'crisp', 'crispy', 'crumbly', 'crushable', 'delicate', 'dissoluble', 'dissolvable'],
    'scission': ['abscission', 'amputation', 'butchering', 'chopping', 'cleavage', 'cutting', 'dichotomy', 'enucleation', 'excision', 'fission', 'laceration', 'mutilation'],
    'scissor': ['amputate', 'ax', 'bisect', 'butcher', 'carve', 'chop', 'cleave', 'cut', 'cut away', 'cut in two', 'cut off', 'dichotomize'],
    'scissure': ['abysm', 'abyss', 'arroyo', 'box canyon', 'breach', 'break', 'canyon', 'cavity', 'chap', 'chasm', 'check', 'chimney'],
    'sclerosis': ['abscess', 'ague', 'anemia', 'angina', 'angina pectoris', 'ankylosis', 'anoxia', 'aortic insufficiency', 'aortic stenosis', 'apnea', 'apoplectic stroke', 'apoplexy'],
    'scoff': ['parthian shot', 'affront', 'aspersion', 'atrocity', 'back answer', 'barrack', 'belittle', 'bolt', 'boo', 'brickbat', 'caustic remark', 'chaff'],
    'scoff at': ['affront', 'be merry with', 'break the law', 'call names', 'care naught for', 'crack a joke', 'crack wise', 'defy', 'deride', 'despise', 'disdain', 'dishonor'],
    'scoffing': ['humism', 'pyrrhonism', 'abusive', 'agnosticism', 'banter', 'bantering', 'blackening', 'blameful', 'booing', 'catcalling', 'censorious', 'chaffing'],
    'scofflaw': ['judas', 'betrayer', 'convict', 'criminal', 'crook', 'deceiver', 'desperado', 'desperate criminal', 'double-dealer', 'felon', 'fugitive', 'gallows bird'],
    'scold': ['xanthippe', 'admonish', 'amazon', 'baste', 'battle-ax', 'bawl out', 'beldam', 'belittler', 'berate', 'bitch', 'blame', 'blister'],
    'scolding': ['admonishment', 'admonition', 'beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'castigation', 'chastisement', 'chiding', 'complaining'],
    'sconce': ['abatis', 'advanced work', 'amercement', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'bastion'],
    'scone': ['danish', 'danish pastry', 'english muffin', 'parker house roll', 'yorkshire pudding', 'bagel', 'bialy', 'bialystoker', 'bun', 'clover-leaf roll', 'coffee cake', 'crescent roll'],
    'scoop': ['account', 'acquaintance', 'alveolation', 'alveolus', 'announcement', 'antrum', 'armpit', 'article', 'bail', 'basin', 'beat', 'bit'],
    'scoot': ['barrel', 'beeline', 'bolt', 'bustle', 'career', 'dart', 'dash', 'flee', 'fleet', 'fling', 'fly', 'haste'],
    'scope': ['a leg up', 'actionability', 'affective meaning', 'ambit', 'amount', 'ample scope', 'amplitude', 'applicability', 'area', 'bearing', 'bigness', 'binoculars'],
    'scorch': ['abrade', 'abrasion', 'air-dry', 'anhydrate', 'assail', 'attack', 'attaint', 'bake', 'ball the jack', 'bark', 'barrel', 'be in heat'],
    'scorched': ['adust', 'aggravated', 'ashen', 'ashy', 'baked', 'blistered', 'broken', 'burned', 'burnt', 'burnt-up', 'burst', 'busted'],
    'scorcher': ['jehu', 'broiler', 'flier', 'goer', 'hell-driver', 'horse racer', 'hot day', 'hummer', 'hustler', 'jockey', 'racer', 'roaster'],
    'scorching': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'ardent', 'baking', 'biting'],
    'score': ['nachtmusik', 'sexagesima', 'vandyke', 'absolute music', 'accompaniment', 'accomplish', 'account', 'account current', 'account for', 'account rendered', 'account stated', 'accounts payable'],
    'scoreboard': ['bulletin board', 'card', 'catalog card', 'disc', 'file', 'filing card', 'film', 'index card', 'library catalog', 'magnetic tape', 'microcard', 'microdot'],
    'scored': ['battlemented', 'canaliculate', 'canaliculated', 'chamfered', 'channeled', 'chopped', 'corduroy', 'corduroyed', 'corrugate', 'corrugated', 'costate', 'crenate'],
    'scorer': ['accountant', 'amanuensis', 'archivist', 'arranger', 'ballad maker', 'balladeer', 'balladist', 'balladmonger', 'bookkeeper', 'clerk', 'composer', 'contrapuntist'],
    'scores': ['a mass of', 'a world of', 'army', 'bevy', 'bunch', 'cloud', 'clutter', 'covey', 'flight', 'flock', 'flocks', 'hail'],
    'scoria': ['aa', 'abyssal rock', 'alluvion', 'alluvium', 'ash', 'ashes', 'basalt', 'bedrock', 'block lava', 'brand', 'brash', 'breccia'],
    'scorn': ['abhor', 'airs', 'arrogance', 'be above', 'be contemptuous of', 'care nothing for', 'clannishness', 'cliquishness', 'contemn', 'contempt', 'contemptuousness', 'contumely'],
    'scornful': ['abjuratory', 'arrogant', 'clannish', 'cliquish', 'contemptuous', 'contumelious', 'declinatory', 'deprecative', 'derisive', 'derisory', 'despising', 'disdainful'],
    'scorpion': ['arachnid', 'arthropod', 'beetle', 'bug', 'caterpillar', 'centipede', 'chilopod', 'daddy longlegs', 'diplopod', 'fly', 'harvestman', 'hexapod'],
    'scot': ['account', 'admission', 'admission fee', 'allowance', 'anchorage', 'assessment', 'bill', 'blackmail', 'blood money', 'brokerage', 'carfare', 'cellarage'],
    'scot free': ['afoot and lighthearted', 'at large', 'at liberty', 'clear', 'detached', 'disengaged', 'easygoing', 'emancipated', 'escaped', 'fled', 'flown', 'footloose'],
    'scotch': ['vandyke', 'abrade', 'arrest', 'baffle', 'balk', 'bark', 'bearing rein', 'birthmark', 'bit', 'blast', 'blaze', 'blaze a trail'],
    'scotland yard': ['cheka', 'fbi', 'gestapo', 'interpol', 'mp', 'mvd', 'mounties', 'nkvd', 'ogpu', 'rcmp', 'sp', 'constabulary'],
    'scoundrel': ['bastard', 'blackguard', 'bounder', 'cad', 'criminal', 'cur', 'deceiver', 'devil', 'good-for-nothing', 'heel', 'knave', 'louse'],
    'scour': ['ablate', 'abrade', 'abrase', 'baptize', 'bark', 'bath', 'bathe', 'beat', 'beat the bushes', 'beeline', 'bite', 'blow'],
    'scourge': ['adversity', 'afflict', 'affliction', 'ambulatory plague', 'bane', 'baste', 'bastinado', 'beat', 'belabor', 'belt', 'birch', 'black death'],
    'scouring': ['ablation', 'ablution', 'abrasion', 'abrasive', 'afterglow', 'afterimage', 'attrition', 'balance', 'bones', 'buffing', 'burnishing', 'butt'],
    'scout': ['argus', 'cia man', 'charley', 'abhor', 'abjure', 'advance guard', 'airhead', 'airplane spotter', 'ancestor', 'announcer', 'antecedent', 'avant-garde'],
    'scouting': ['abjuration', 'abjurement', 'chucking', 'chucking out', 'contempt', 'contradiction', 'declination', 'declining', 'denial', 'despisal', 'despising', 'disapproval'],
    'scowl': ['angry look', 'black look', 'color', 'dirty look', 'flush', 'frown', 'glare', 'gloom', 'glower', 'gnarl', 'grimace', 'growl'],
    'scrabble': ['all fours', 'barbouillage', 'beat about', 'bore', 'burrow', 'clamber', 'crawl', 'crawling', 'creep', 'creeping', 'delve', 'dig'],
    'scrag': ['ko', 'and quarter', 'call off', 'cancel', 'complete', 'delete', 'dispose of', 'draw', 'drop the curtain', 'end off', 'expunge', 'extinguish'],
    'scraggly': ['beat-up', 'bedraggled', 'blowzy', 'careless', 'chintzy', 'corrugated', 'cragged', 'craggy', 'crinkled', 'crumpled', 'dilapidated', 'drabbletailed'],
    'scraggy': ['lilliputian', 'tom thumb', 'angular', 'asperous', 'bony', 'corrugated', 'cragged', 'craggy', 'crinkled', 'crumpled', 'dumpy', 'dwarf'],
    'scram': ['be off', 'beat it', 'begone', 'blow', 'clear out', 'decamp', 'dog it', 'duck and run', 'duck out', 'flake off', 'get', 'get going'],
    'scramble': ['aesopian language', 'babel', 'greek', 'action', 'admix', 'ado', 'aerial combat', 'affray', 'agitation', 'air cover', 'air raid', 'air support'],
    'scrambled': ['aimless', 'amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'beyond one', 'blended', 'combined', 'complex', 'complicated', 'composite', 'compound'],
    'scrap': ['abandon', 'abort', 'affray', 'afterglow', 'afterimage', 'argue', 'argument', 'atom', 'balance', 'barney', 'battle', 'battle royal'],
    'scrap iron': ['bones', 'chaff', 'culm', 'deadwood', 'dishwater', 'draff', 'dregs', 'dust', 'filings', 'garbage', 'gash', 'hogwash'],
    'scrapbook': ['domesday book', 'festschrift', 'account book', 'address book', 'adversaria', 'album', 'ana', 'analects', 'annual', 'anthology', 'appointment calendar', 'appointment schedule'],
    'scrape': ['ablate', 'ablation', 'abrade', 'abrase', 'abrasion', 'abrasive', 'accumulate', 'aggregate', 'amass', 'assemble', 'attrition', 'autolithograph'],
    'scrape along': ['clear', 'clear the hurdle', 'come along', 'come on', 'contrive', 'cope', 'cut the mustard', 'eke out', 'engineer', 'get along', 'get by', 'get on'],
    'scrape together': ['accumulate', 'agglomerate', 'aggregate', 'aggroup', 'amass', 'assemble', 'batch', 'bring together', 'bulk', 'bunch', 'bunch together', 'bunch up'],
    'scrapper': ['battler', 'belligerent', 'belted knight', 'bickerer', 'bitter-ender', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'combatant', 'competitor'],
    'scrapple': ['aspic', 'barbecue', 'boiled meat', 'bouilli', 'civet', 'flesh', 'forcemeat', 'game', 'hachis', 'hash', 'jerky', 'joint'],
    'scrappy': ['aggressive', 'antagonistic', 'argumental', 'argumentative', 'arrested', 'battling', 'bellicose', 'belligerent', 'bloodthirsty', 'bloody', 'bloody-minded', 'brawling'],
    'scratch': ['ablation', 'abort', 'abrade', 'abrasion', 'abrasive', 'adequate', 'anamorphosis', 'attrition', 'autolithograph', 'bad likeness', 'barbouillage', 'bark'],
    'scratch pad': ['domesday book', 'account book', 'address book', 'adversaria', 'album', 'annual', 'appointment calendar', 'appointment schedule', 'blankbook', 'blotter', 'calendar', 'cashbook'],
    'scratch the surface': ['be innocent of', 'coquet with', 'dabble', 'give up', 'have no idea', 'know a little', 'know not', 'know not what', 'know nothing of', 'not know', 'not rightly know', 'pass'],
    'scratched': ['canaliculate', 'canaliculated', 'chamfered', 'channeled', 'corduroy', 'corduroyed', 'corrugate', 'corrugated', 'costate', 'crimped', 'cut', 'dadoed'],
    'scratchy': ['chafing', 'dry', 'fretting', 'galling', 'grating', 'grinding', 'hoarse', 'irritant', 'irritating', 'irritative', 'itchy', 'jangling'],
    'scrawl': ['barbouillage', 'doodle', 'hen scratches', 'hen tracks', 'illegibility', 'indecipherability', 'inscribe', 'pattes de mouche', 'pothookery', 'pothooks', 'pothooks and hangers', 'scrabble'],
    'scrawny': ['lenten', 'spartan', 'abstemious', 'angular', 'anorectic', 'anorexic', 'ascetic', 'austere', 'bony', 'cadaverous', 'drawn', 'dwarfed'],
    'screak': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'bray', 'call', 'caterwaul'],
    'scream': ['bark', 'battle cry', 'bawl', 'bay', 'bell', 'bellow', 'belly laugh', 'blare', 'blat', 'blate', 'bleat', 'blubber'],
    'screamer': ['banner', 'banner head', 'bloomer', 'blooper', 'bobble', 'bonehead play', 'boner', 'boo-boo', 'boob stunt', 'boot', 'caption', 'drop head'],
    'screaming': ['absurd', 'amusing', 'bawling', 'bizarre', 'blatant', 'blinding', 'boanergean', 'brawling', 'brazen', 'brazenfaced', 'clamorous', 'clamoursome'],
    'scree': ['aa', 'abyssal rock', 'alluvion', 'alluvium', 'basalt', 'bedrock', 'block lava', 'brash', 'breccia', 'conglomerate', 'crag', 'debris'],
    'screech': ['bark', 'battle cry', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'blubber', 'boom'],
    'screen': ['tv', 'tv set', 'act drop', 'advocate', 'aegis', 'alibi', 'analyze', 'apology', 'apply to', 'arabesque', 'arm', 'arm guard'],
    'screened': ['armed', 'armored', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'coped', 'copyrighted', 'covered', 'covert', 'cowled'],
    'screenwriter': ['choreographer', 'comedian', 'dramatist', 'dramatizer', 'dramaturge', 'farcer', 'farceur', 'farceuse', 'farcist', 'gagman', 'joke writer', 'jokesmith'],
    'screw': ['procrustean bed', 'airscrew', 'anamorphism', 'anamorphosis', 'apply pressure', 'articulate', 'ask', 'ask for', 'asymmetry', 'badger', 'ball', 'batten'],
    'screw up': ['abreast', 'acquainted', 'affix', 'amiss', 'anarchy', 'anchor', 'annex', 'attach', 'au courant', 'back', 'ball up', 'belay'],
    'screwball': ['abnormal', 'alien', 'aliene', 'anomalous', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bedlamite', 'bonkers'],
    'screwy': ['abnormal', 'anomalous', 'apish', 'asinine', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'befooled', 'beguiled'],
    'scribble': ['anamorphosis', 'bad likeness', 'barbouillage', 'botch', 'burlesque', 'caricature', 'daub', 'distortion', 'doodle', 'hen scratches', 'hen tracks', 'illegibility'],
    'scribbler': ['amanuensis', 'calligrapher', 'chirographer', 'clerk', 'copier', 'copyist', 'hack', 'ink spiller', 'inkslinger', 'letterer', 'literary hack', 'pen'],
    'scribe': ['levite', 'accountant', 'advertising writer', 'amanuensis', 'annalist', 'archivist', 'art critic', 'author', 'authoress', 'baal kore', 'belletrist', 'bibliographer'],
    'scrim': ['act drop', 'asbestos', 'asbestos board', 'backdrop', 'batten', 'border', 'cloth', 'coulisse', 'counterweight', 'curtain', 'curtain board', 'cyclorama'],
    'scrimmage': ['action', 'aerial combat', 'affray', 'armored combat', 'battle', 'battle royal', 'brawl', 'broil', 'brouhaha', 'brush', 'bullfight', 'clash'],
    'scrimp': ['begrudge', 'economize', 'enforce economies', 'exiguous', 'famish', 'grudge', 'husband', 'keep within compass', 'live upon nothing', 'make ends meet', 'manage', 'pinch'],
    'scrimping': ['scotch', 'canny', 'careful', 'chary', 'cheeseparing', 'chinchy', 'chintzy', 'conserving', 'cooling', 'cooling down', 'cooling off', 'curtailment'],
    'scrimpy': ['cheeseparing', 'chinchy', 'close', 'deficient', 'exiguous', 'failing', 'inadequate', 'insufficient', 'mean', 'narrow', 'niggardly', 'poor'],
    'scrip': ['federal reserve note', 'and pence', 'article', 'assignat', 'autograph', 'baggage check', 'bank note', 'bill', 'blank', 'brainchild', 'cash', 'check'],
    'script': ['ipa', 'ita', 'initial teaching alphabet', 'alphabet', 'alphabetics', 'arrange', 'art', 'article', 'ascender', 'autograph', 'autography', 'back'],
    'scriptural': ['biblical', 'christian', 'gospel', 'mosaic', 'new-testament', 'old-testament', 'accepted', 'apocalyptic', 'apostolic', 'approved', 'authentic', 'authoritative'],
    'scripture': ['bhagavad-gita', 'bible', 'book of mormon', 'douay bible', 'holy scripture', 'holy writ', 'king james version', 'koran', 'revised standard version', 'revised version', 'septuagint', 'testament'],
    'scriptwriter': ['advertising writer', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'choreographer', 'coauthor', 'collaborator', 'columnist', 'comedian'],
    'scrivener': ['accountant', 'amanuensis', 'archivist', 'bookkeeper', 'calligrapher', 'chirographer', 'clerk', 'copier', 'copyist', 'documentalist', 'engraver', 'filing clerk'],
    'scroll': ['a string', 'aldine', 'aldine book', 'amati', 'cremona', 'd string', 'e string', 'elzevir', 'elzevir book', 'g string', 'strad', 'stradivari'],
    'scrotum': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'scrounge': ['abstract', 'and', 'annex', 'appropriate', 'bag', 'beg', 'boost', 'borrow', 'bum', 'cadge', 'cadger', 'come up with'],
    'scrounger': ['beggar', 'body snatcher', 'booster', 'bum', 'bummer', 'cadger', 'chicken thief', 'con man', 'crook', 'den of thieves', 'embezzler', 'filcher'],
    'scrounging': ['abstraction', 'annexation', 'appropriation', 'beggary', 'begging', 'bone-lazy', 'boosting', 'bumming', 'cadging', 'conversion', 'conveyance', 'dilatory'],
    'scrub': ['a nobody', 'a nothing', 'abandon', 'ablate', 'ablation', 'ablution', 'abort', 'abrade', 'abrase', 'abrasion', 'abrasive', 'afforestation'],
    'scrubby': ['lilliputian', 'tom thumb', 'abject', 'abominable', 'afforestational', 'arborary', 'arboreal', 'arboreous', 'arborescent', 'arboresque', 'arborical', 'arboriform'],
    'scrubland': ['afforestation', 'arboretum', 'boondocks', 'bush', 'bushveld', 'chase', 'climax forest', 'cloud forest', 'dendrology', 'forest', 'forest land', 'forest preserve'],
    'scruffy': ['abject', 'abominable', 'arrant', 'atrocious', 'base', 'beggarly', 'beneath contempt', 'cheap', 'cheesy', 'common', 'contemptible', 'crummy'],
    'scrumptious': ['ok', 'ace-high', 'adorable', 'agreeable', 'ambrosial', 'bad', 'bang-up', 'bonzer', 'boss', 'bully', 'but good', 'cool'],
    'scrunch': ['abrade', 'atomize', 'beat', 'belch', 'blare', 'blat', 'bray', 'brecciate', 'burr', 'buzz', 'cackle', 'caw'],
    'scruple': ['pyrrhonism', 'ace', 'apprehension', 'atom', 'awake a doubt', 'back down', 'balance', 'balk', 'balk at', 'bashfulness', 'be diffident', 'be doubtful'],
    'scrupulous': ['pyrrhonic', 'accurate', 'active', 'agnostic', 'analyze', 'attentive', 'bashful', 'boggling', 'canvass', 'careful', 'case', 'cautious'],
    'scrutinize': ['attend to business', 'autopsy', 'be alert', 'be obsessed with', 'canvass', 'check', 'check out', 'check over', 'check up on', 'concentrate on', 'contemplate', 'dissect'],
    'scrutiny': ['analysis', 'attention to detail', 'audit', 'check', 'close study', 'contemplation', 'eagle eye', 'enquiry', 'examination', 'exploration', 'eye', 'eyeball inspection'],
    'scuba': ['aqua-lung', 'air cylinder', 'aquascope', 'artificial respiration', 'aspiration', 'asthmatic wheeze', 'bathyscaphe', 'bathysphere', 'benthoscope', 'breath', 'breath of air', 'breathing'],
    'scud': ['cloudcuckooland', 'alto-cumulus', 'alto-stratus', 'anvil cloud', 'banner cloud', 'billowy cloud', 'blast', 'blow', 'bolt', 'brash', 'breakers', 'burst'],
    'scuff': ['ablate', 'ablation', 'abrade', 'abrase', 'abrasion', 'abrasive', 'amble', 'attrition', 'barge', 'bark', 'blemish', 'bloody'],
    'scuffle': ['action', 'aerial combat', 'affray', 'agonize', 'amble', 'armored combat', 'barge', 'battle', 'battle royal', 'bobbery', 'bowl along', 'box'],
    'scull': ['boat', 'canoe', 'carry sail', 'catch a crab', 'circumnavigate', 'coast', 'cross', 'cruise', 'cut a crab', 'feather', 'feather an oar', 'give way'],
    'sculler': ['bargee', 'bargeman', 'barger', 'boat-handler', 'boater', 'boatman', 'boatsman', 'ferrier', 'ferryman', 'galley slave', 'gondolier', 'lighterman'],
    'scullery maid': ['abigail', 'amah', 'au pair girl', 'ayah', 'betweenmaid', 'biddy', 'chambermaid', 'chaperon', 'companion', 'cook', 'dishwasher', 'dishwiper'],
    'scullion': ['dishwasher', 'dishwiper', 'domestic', 'domestic servant', 'drudge', 'dry cleaner', 'help', 'launderer', 'laundress', 'laundryman', 'laundrywoman', 'menial'],
    'sculpt': ['assemble', 'block out', 'carve', 'cast', 'chase', 'chisel', 'create', 'cut', 'efform', 'engrave', 'fashion', 'figure'],
    'sculptor': ['arp', 'cysp sculpture', 'french', 'maillol', 'michelangelo', 'milles', 'moore', 'oldenburg', 'phidias', 'picasso', 'pisano', 'praxiteles'],
    'sculpture': ['abstract art', 'art', 'art form', 'artist', 'arts and crafts', 'arts of design', 'assemble', 'autolithograph', 'be a printmaker', 'block out', 'bronze', 'bust'],
    'sculptured': ['anaglyphic', 'anaglyptic', 'anastatic', 'carved', 'ceroplastic', 'chased', 'creased', 'cut', 'embossed', 'enchased', 'engraved', 'engraven'],
    'scum': ['aerate', 'alluvion', 'alluvium', 'androcyte', 'antheridium', 'antherozoid', 'apply to', 'ash', 'beat', 'bilge', 'bilgewater', 'blanket'],
    'scummy': ['abject', 'abominable', 'arrant', 'atrocious', 'barfy', 'base', 'beggarly', 'beneath contempt', 'cheap', 'cheesy', 'common', 'contemptible'],
    'scurf': ['bilge', 'bilgewater', 'canaille', 'carrion', 'chip', 'corruption', 'dandruff', 'decay', 'dishwater', 'ditchwater', 'excrement', 'filth'],
    'scurfy': ['asperous', 'barfy', 'branny', 'chalklike', 'chalky', 'comminute', 'comminuted', 'crappy', 'crushed', 'detrital', 'detrited', 'disgusting'],
    'scurrilous': ['fescennine', 'rabelaisian', 'abusive', 'atrocious', 'back-biting', 'backhand', 'backhanded', 'bawdy', 'belittling', 'bitchy', 'blasphemous', 'blue'],
    'scurry': ['bolt', 'bundle', 'burst', 'burst of speed', 'bustle', 'canter', 'career', 'chase', 'crowd', 'dart', 'dash', 'dash off'],
    'scurvy': ['lombardy leprosy', 'abject', 'abominable', 'anemia', 'ariboflavinosis', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'base-minded', 'beastly'],
    'scutcheon': ['achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'azure', 'bandeau', 'bar', 'bar sinister'],
    'scuttle': ['french door', 'ko', 'amble', 'archway', 'back door', 'back out', 'bankrupt', 'barge', 'barway', 'be lost', 'boggle', 'bolt'],
    'scuttlebutt': ['bruit', 'buzz', 'canard', 'common talk', 'cry', 'flying rumor', 'gossip', 'grapevine', 'hearsay', 'idea afloat', 'latrine rumor', 'news stirring'],
    'scuz': ['carrion', 'corruption', 'dandruff', 'decay', 'excrement', 'filth', 'foul matter', 'furfur', 'gangrene', 'mess', 'muck', 'mucus'],
    'scuzzy': ['beggarly', 'beneath contempt', 'cheap', 'cheesy', 'common', 'contemptible', 'crummy', 'despicable', 'gaudy', 'gimcracky', 'mean', 'meretricious'],
    'sea': ['abundance', 'acres', 'bags', 'barrels', 'big drink', 'billow', 'blue', 'blue water', 'bore', 'breakers', 'brine', 'briny'],
    'sea cock': ['ball cock', 'ball valve', 'bung', 'bunghole', 'check valve', 'cock', 'cork', 'drain cock', 'draw cock', 'faucet', 'gate', 'lid'],
    'sea dog': ['ab', 'ancient mariner', 'argonaut', 'dylan', 'flying dutchman', 'neptune', 'od', 'poseidon', 'varuna', 'able seaman', 'able-bodied seaman', 'bluejacket'],
    'sea lane': ['air lane', 'approaches', 'beat', 'channel', 'circuit', 'course', 'fairway', 'flight path', 'itinerary', 'line', 'orbit', 'path'],
    'sea rover': ['ab', 'ancient mariner', 'argonaut', 'blackbeard', 'captain hook', 'captain kidd', 'dylan', 'flying dutchman', 'henry morgan', 'jean lafitte', 'neptune', 'od'],
    'sea serpent': ['loch ness monster', 'alevin', 'benthon', 'benthos', 'cetacean', 'dolphin', 'fingerling', 'fish', 'fry', 'game fish', 'grilse', 'kipper'],
    'seabee': ['naval construction battalion', 'naval reservist', 'rn', 'royal marine', 'royal navy', 'seabees', 'usn', 'united states navy', 'argosy', 'armada', 'bluejacket', 'boot'],
    'seacoast': ['bank', 'beach', 'berm', 'coast', 'coastland', 'coastline', 'embankment', 'foreshore', 'ironbound coast', 'lido', 'littoral', 'plage'],
    'seafarer': ['ab', 'ancient mariner', 'argonaut', 'dylan', 'flying dutchman', 'neptune', 'od', 'poseidon', 'varuna', 'able seaman', 'able-bodied seaman', 'bluejacket'],
    'seafaring': ['boating', 'canoeing', 'circumnavigation', 'coasting', 'cruising', 'gunkholing', 'marine', 'maritime', 'motorboating', 'nautical', 'naval', 'navigability'],
    'seal': ['john hancock', 'ok', 'accept', 'acceptance', 'accredit', 'affirm', 'affirmance', 'affirmation', 'agree on terms', 'amen', 'approbation', 'approval'],
    'seal off': ['bang', 'bar', 'barricade', 'batten', 'batten down', 'bolt', 'button', 'button up', 'choke', 'choke off', 'clap', 'close'],
    'seal up': ['bang', 'bar', 'barricade', 'batten', 'batten down', 'bolt', 'bosom', 'bottle up', 'box up', 'bury', 'button', 'button up'],
    'sealed': ['able', 'accepted', 'acknowledged', 'admitted', 'affirmed', 'agreed', 'airtight', 'allowed', 'approved', 'arranged', 'auricular', 'authenticated'],
    'seam': ['abysm', 'abyss', 'ankle', 'arroyo', 'articulation', 'band', 'bed', 'bedding', 'belt', 'blaze', 'blaze a trail', 'blemish'],
    'seaman': ['ab', 'ancient mariner', 'argonaut', 'davy', 'davy jones', 'dylan', 'flying dutchman', 'neptune', 'nereid', 'nereus', 'od', 'oceanid'],
    'seamanship': ['ability', 'address', 'adeptness', 'adroitness', 'airmanship', 'artfulness', 'artisanship', 'artistry', 'bravura', 'brilliance', 'capability', 'capacity'],
    'seamless': ['articulated', 'catenated', 'ceaseless', 'concatenated', 'connected', 'constant', 'continual', 'continued', 'continuing', 'continuous', 'cyclical', 'direct'],
    'seamy': ['abhorrent', 'contemptible', 'dark', 'degenerate', 'degraded', 'depraved', 'derogatory', 'discreditable', 'dishonorable', 'disreputable', 'distasteful', 'foul'],
    'seance': ['assemblee', 'assembly', 'assignation', 'at home', 'audience', 'ball', 'bargaining', 'bargaining session', 'brawl', 'caucus', 'colloquium', 'commission'],
    'seaplane': ['aeroboat', 'aeroplane', 'airlift', 'airplane', 'amphibian', 'balloon', 'be airborne', 'boat seaplane', 'clipper', 'cruise', 'drift', 'ferry'],
    'seaport': ['anchorage', 'anchorage ground', 'basin', 'berth', 'breakwater', 'bulkhead', 'dock', 'dockage', 'dockyard', 'dry dock', 'embankment', 'groin'],
    'sear': ['sanforize', 'sanforized', 'adust', 'air-dry', 'anhydrate', 'attaint', 'attenuate', 'attenuated', 'bake', 'baked', 'barbecue', 'baste'],
    'search': ['analysis', 'angle for', 'ask for', 'beat', 'beat about for', 'beat the bushes', 'burrow', 'cast about', 'chase', 'check', 'chivy', 'comb'],
    'search warrant': ['bench warrant', 'capias', 'caveat', 'death warrant', 'domiciliary visit', 'dragnet', 'exploration', 'fieri facias', 'forage', 'frisk', 'habere facias possessionem', 'house-search'],
    'searching': ['chase', 'cynegetic', 'delving', 'digging', 'dogging', 'domiciliary visit', 'dragnet', 'exploration', 'fishing', 'follow', 'follow-up', 'following'],
    'seared': ['adust', 'ashen', 'ashy', 'baked', 'blistered', 'boiled', 'braised', 'brazen', 'broiled', 'browned', 'burned', 'burnt'],
    'seascape': ['airscape', 'cityscape', 'cloudscape', 'diorama', 'exterior', 'farmscape', 'interior', 'landscape', 'lookout', 'outlook', 'panorama', 'pastoral'],
    'seashore': ['aquatic', 'balneal', 'bank', 'beach', 'berm', 'coast', 'coastland', 'coastline', 'deep-sea', 'embankment', 'estuarine', 'foreshore'],
    'seaside': ['bank', 'beach', 'berm', 'coast', 'coastal', 'coastland', 'coastline', 'embankment', 'foreshore', 'ironbound coast', 'lido', 'littoral'],
    'season': ['abate', 'acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'adjust to', 'age', 'alter', 'anhydrate', 'assuage'],
    'seasonable': ['a propos', 'ad rem', 'adapted', 'advantageous', 'advisable', 'applicable', 'apposite', 'appropriate', 'apropos', 'apt', 'auspicious', 'becoming'],
    'seasonal': ['aestival', 'alternate', 'arctic', 'autumn', 'autumnal', 'beating', 'boreal', 'brumal', 'canicular', 'circling', 'cyclic', 'epochal'],
    'seasoned': ['acclimated', 'acclimatized', 'accommodated', 'accustomed', 'adapted', 'adjusted', 'aged', 'blase', 'brisk', 'burning', 'case-hardened', 'conditioned'],
    'seasoning': ['ability', 'acclimation', 'acclimatization', 'accommodation', 'accustoming', 'adaption', 'adjustment', 'aging', 'anhydration', 'background', 'beautification', 'blaseness'],
    'seat': ['cp', 'eames chair', 'ghq', 'hq', 'hitchcock chair', 'tv chair', 'abiding place', 'abode', 'accommodate', 'address', 'angle', 'armchair'],
    'seat belt': ['aegis', 'arm guard', 'backstop', 'buffer', 'bulwark', 'bumper', 'contraceptive', 'copyright', 'crash helmet', 'cushion', 'dashboard', 'dodger'],
    'seated': ['assigned', 'deployed', 'embosomed', 'emplaced', 'ensconced', 'established', 'fixed', 'installed', 'located', 'placed', 'planted', 'positioned'],
    'seato': ['al', 'anzus council', 'aspac', 'arab league', 'bis', 'british commonwealth', 'cacm', 'cento', 'central treaty organization', 'colombo plan', 'common market', 'commonwealth of nations'],
    'seawall': ['abutment', 'anchorage', 'anchorage ground', 'arc-boutant', 'arch dam', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier', 'basin'],
    'seaward': ['anticlockwise', 'clockwise', 'counterclockwise', 'earthward', 'heavenward', 'homeward', 'in blue water', 'landward', 'leeward', 'leftward', 'oceanward', 'oceanwards'],
    'seaweed': ['algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'diatom', 'fern', 'fruits and vegetables'],
    'sebaceous': ['adipose', 'blubbery', 'buttery', 'butyraceous', 'chrismal', 'chrismatory', 'fat', 'fatty', 'greasy', 'lardaceous', 'lardy', 'mucoid'],
    'sec': ['aec', 'atomic energy commission', 'cab', 'cia', 'central intelligence agency', 'civil aeronautics board', 'district of columbia', 'domestic council', 'eda', 'eeoc', 'eib', 'epa'],
    'secant': ['air line', 'axis', 'beeline', 'chiasmal', 'chiasmic', 'chiastic', 'chord', 'crisscross', 'cross', 'crosscut', 'crossed', 'crossing'],
    'secede': ['abandon', 'agree to differ', 'agree to disagree', 'apostacize', 'apostatize', 'be at variance', 'be in dissent', 'beg to differ', 'betray', 'bolt', 'break away', 'change sides'],
    'secession': ['agreement to disagree', 'alienation', 'apostasy', 'backsliding', 'betrayal', 'bolt', 'break', 'breakaway', 'breaking', 'counter-culture', 'defection', 'dereliction'],
    'secessionist': ['abjuratory', 'apostate', 'backslider', 'bolter', 'breakaway', 'collaborationist', 'collaborator', 'convert', 'defector', 'deserter', 'fifth columnist', 'mugwump'],
    'seclude': ['bolt', 'cloister', 'closet', 'confine', 'cop out', 'cordon', 'cordon off', 'cull out', 'divide', 'enclose', 'forsake the world', 'ghettoize'],
    'secluded': ['abstruse', 'alone', 'anonymous', 'apart', 'at rest', 'beclouded', 'blind', 'buried', 'calm', 'cloistered', 'close', 'closet'],
    'seclusion': ['jim crow', 'alien', 'alienation', 'aloneness', 'aloofness', 'anonymity', 'apartheid', 'celibacy', 'closed meeting', 'color bar', 'confidentiality', 'confidentialness'],
    'seconal': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal pill', 'tuinal', 'tuinal pill'],
    'second': ['janus-like', 'maecenas', 'ok', 'abettor', 'abundant year', 'academic year', 'accept', 'accredit', 'acolyte', 'adjutant', 'admirer', 'advance'],
    'second best': ['mickey mouse', 'base', 'cheap', 'cheesy', 'coarse', 'common', 'disappointing', 'falling short', 'fourth-class', 'inferior', 'irregular', 'low class'],
    'second childhood': ['advanced age', 'advanced years', 'age of retirement', 'an incurable disease', 'anility', 'caducity', 'childishness', 'debility', 'decline', 'decline of life', 'declining years', 'decrepitude'],
    'second class': ['mickey mouse', 'base', 'cheap', 'cheesy', 'coarse', 'common', 'declasse', 'fourth-class', 'hack', 'inferior', 'irregular', 'low-class'],
    'second fiddle': ['back seat', 'cog', 'commonality', 'commonalty', 'creature', 'flunky', 'follower', 'hoi polloi', 'humbleness', 'humility', 'inferior', 'inferiority'],
    'second nature': ['automatism', 'bad habit', 'characteristic', 'creature of habit', 'custom', 'force of habit', 'habit', 'habit pattern', 'habitude', 'pattern', 'peculiarity', 'practice'],
    'second rate': ['mickey mouse', 'base', 'cheap', 'cheesy', 'coarse', 'common', 'declasse', 'fourth-class', 'hack', 'inferior', 'irregular', 'low-class'],
    'second sight': ['esp', 'a priori knowledge', 'anticipation', 'buddhi', 'clairsentience', 'clairvoyance', 'direct apprehension', 'extrasensory perception', 'foresight', 'immediate cognition', 'insight', 'inspiration'],
    'second string': ['agent', 'alternate', 'alternative', 'analogy', 'back seat', 'backup', 'cast', 'change', 'changeling', 'common', 'company', 'comparison'],
    'second thoughts': ['about-face', 'afterthought', 'afterthoughts', 'ambitendency', 'ambivalence', 'better thoughts', 'capriciousness', 'change of mind', 'changeableness', 'developed thought', 'double-mindedness', 'dubiety'],
    'second to none': ['beyond compare', 'beyond comparison', 'easily first', 'facile princeps', 'immortal', 'incomparable', 'inimitable', 'invincible', 'matchless', 'nulli secundus', 'peerless', 'sui generis'],
    'second wind': ['new birth', 'palingenesis', 'palingenesy', 'reanimation', 'rebirth', 'recrudescence', 'refreshment', 'regeneracy', 'regenerateness', 'regeneration', 'regenesis', 'rejuvenation'],
    'secondary': ['janus-like', 'maxwell triangle', 'munsell scale', 'accessory', 'accident', 'accidental', 'addendum', 'addition', 'additional', 'adjunct', 'adscititious', 'adventitious'],
    'secondary school': ['gymnasium', 'latin school', 'realgymnasium', 'realschule', 'academy', 'grammar school', 'high', 'high school', 'intermediate school', 'junior high', 'junior high school', 'middle school'],
    'seconder': ['maecenas', 'abettor', 'admirer', 'advocate', 'aficionado', 'angel', 'apologist', 'backer', 'buff', 'champion', 'defender', 'dependence'],
    'seconds': ['burley', 'cuban', 'fannie mae', 'federal agency bond', 'ginnie mae', 'havana', 'havana seed', 'latakia', 'maryland', 'russian', 'series e bond', 'series h bond'],
    'secrecy': ['jim crow', 'apartheid', 'apartness', 'burial', 'burying', 'censorship', 'clandestineness', 'clouding', 'concealedness', 'concealment', 'confidentiality', 'confidentially'],
    'secret': ['abstract', 'abstruse', 'arcane', 'arcanum', 'beclouded', 'behind the curtain', 'behind the scenes', 'blind', 'buried', 'by stealth', 'cabala', 'cabalistic'],
    'secret agent': ['cia man', 'asker', 'catechist', 'cloak-and-dagger operative', 'counterintelligence agent', 'counterspy', 'cross-interrogator', 'cross-questioner', 'detective', 'double agent', 'espionage agent', 'examiner'],
    'secret language': ['aesopian language', 'babel', 'greek', 'argot', 'babble', 'cant', 'cipher', 'code', 'coded message', 'cryptoanalysis', 'cryptoanalytics', 'cryptogram'],
    'secret place': ['adytum', 'ashram', 'asylum', 'being', 'bolt-hole', 'bones', 'bosom', 'breast', 'cache', 'cell', 'center', 'cloister'],
    'secret police': ['cheka', 'fbi', 'gestapo', 'interpol', 'mp', 'mvd', 'mounties', 'nkvd', 'ogpu', 'rcmp', 'sp', 'scotland yard'],
    'secret service': ['bugging', 'cloak-and-dagger work', 'counterespionage', 'counterintelligence', 'electronic surveillance', 'espial', 'espionage', 'following', 'intelligence', 'intelligence bureau', 'intelligence service', 'intelligence work'],
    'secrete': ['accumulate', 'amass', 'backlog', 'bosom', 'bottle up', 'bury', 'cache', 'camouflage', 'classify', 'cloak', 'collect', 'conceal'],
    'secretion': ['burial', 'burying', 'clouding', 'concealedness', 'concealment', 'covering', 'covering up', 'covertness', 'darkening', 'deception', 'discharge', 'discharging'],
    'secretive': ['close', 'closemouthed', 'dark', 'discreet', 'disinclined to communicate', 'evasive', 'excretory', 'lachrymal', 'lachrymose', 'lacrimatory', 'lactational', 'lacteal'],
    'secretly': ['behind closed doors', 'behind the curtain', 'behind the scenes', 'behind the veil', 'by stealth', 'confidentially', 'covertly', 'furtively', 'hugger-mugger', 'in a corner', 'in a whisper', 'in camera'],
    'secretory': ['egestive', 'eliminative', 'excretionary', 'excretive', 'excretory', 'exudative', 'lachrymal', 'lachrymose', 'lacrimatory', 'lactational', 'lacteal', 'lacteous'],
    'sect': ['babi', 'babism', 'bahaism', 'brahmanism', 'brahmoism', 'buddhism', 'chen yen buddhism', 'christianity', 'adherents', 'affiliation', 'anthroposophy', 'body'],
    'sectarian': ['bohemian', 'adherent', 'alienated', 'antiestablishment', 'apostate', 'at odds with', 'at variance with', 'beatification', 'beatitude', 'beatnik', 'bigot', 'bigoted'],
    'sectarianism': ['clannishness', 'clanship', 'cliqueyness', 'cliquishness', 'cliquism', 'denominationalism', 'eclecticism', 'esprit de corps', 'ethnocentricity', 'exclusiveness', 'faction', 'factionalism'],
    'sectary': ['bohemian', 'maecenas', 'young turk', 'abettor', 'adherent', 'admirer', 'advocate', 'aficionado', 'alienated', 'angel', 'antiestablishment', 'apologist'],
    'section': ['kp', 'abscission', 'adjunct', 'airspace', 'allocate', 'allot', 'amputation', 'anacrusis', 'anastomotic operation', 'apportion', 'area', 'army'],
    'sectional': ['areal', 'denominational', 'factional', 'fractional', 'fragmentary', 'geographical', 'incomplete', 'interested', 'locational', 'part', 'partial', 'partisan'],
    'sectionalism': ['autarky', 'bimetallism', 'clannishness', 'clanship', 'cliqueyness', 'cliquishness', 'cliquism', 'denominationalism', 'economic self-sufficiency', 'esprit de corps', 'ethnocentricity', 'exclusiveness'],
    'sector': ['adjunct', 'component', 'contingent', 'crescent', 'cross section', 'detachment', 'detail', 'district', 'division', 'dole', 'fraction', 'half circle'],
    'secular': ['philistine', 'annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'bodily', 'brother', 'carnal', 'carnal-minded', 'catamenial', 'catechumen'],
    'secularism': ['buddhology', 'mariolatry', 'mariology', 'marxism', 'mercersburg theology', 'animalism', 'apologetics', 'atheism', 'atomism', 'behaviorism', 'canonics', 'commonsense realism'],
    'secure': ['accept', 'acquire', 'admit', 'advocate', 'affix', 'anchor', 'anchored', 'annex', 'arm', 'armor', 'arouse', 'arrogant'],
    'security': ['easy street', 'aegis', 'affluence', 'aplomb', 'armament', 'armor', 'arrogance', 'aspiration', 'assumption', 'assurance', 'assured faith', 'assuredness'],
    'security blanket': ['aid', 'backing', 'carriage', 'carrying', 'maintenance', 'moral support', 'psychological support', 'reliance', 'subsidy', 'subvention', 'support', 'supportive relationship'],
    'sedate': ['anesthetize', 'aristocratic', 'august', 'calm', 'collected', 'composed', 'controlled', 'conventional', 'cool', 'courtly', 'decorous', 'demure'],
    'sedated': ['anesthetized', 'cataleptic', 'comatose', 'doped', 'dozy', 'dreamy', 'drowsy', 'drugged', 'drugged with sleep', 'half asleep', 'heavy', 'heavy with sleep'],
    'sedation': ['catalepsy', 'coma', 'encephalitis lethargica', 'high', 'lethargy', 'narcohypnosis', 'narcolepsy', 'narcoma', 'narcosis', 'narcotic stupor', 'narcotization', 'nod'],
    'sedative': ['mickey finn', 'allaying', 'anodyne', 'balm', 'barbiturate', 'calmant', 'calmative', 'calming', 'depressant', 'depressing', 'downer', 'hypnotic'],
    'sedentary': ['abeyant', 'apathetic', 'at a standstill', 'cataleptic', 'catatonic', 'dead', 'dopey', 'dormant', 'dull', 'fixed', 'flat', 'foul'],
    'sediment': ['alluvion', 'alluvium', 'ash', 'bottoms', 'cinder', 'clinker', 'debris', 'deposit', 'deposition', 'deposits', 'detritus', 'diluvium'],
    'sedition': ['action', 'agitation', 'alienation', 'collaboration', 'coup', 'disaffection', 'estrangement', 'extremism', 'factiousness', 'fifth-column activity', 'fomentation', 'fraternization'],
    'seditionist': ['agent provocateur', 'agitator', 'agitprop', 'catalyst', 'demagogue', 'exciter', 'firebrand', 'fomenter', 'incendiary', 'inciter', 'inflamer', 'instigator'],
    'seditious': ['alienated', 'breakaway', 'contumacious', 'disaffected', 'disloyal', 'dissident', 'extreme', 'extremistic', 'factious', 'faithless', 'inflammatory', 'insurgent'],
    'seduce': ['abuse', 'allure', 'attract', 'bait', 'bait the hook', 'becharm', 'beguile', 'betray', 'bewitch', 'blandish', 'cajole', 'captivate'],
    'seducer': ['artful dodger', 'casanova', 'circe', 'don juan', 'lorelei', 'lothario', 'machiavel', 'machiavelli', 'machiavellian', 'parthenope', 'romeo', 'siren'],
    'seduction': ['abuse', 'agacerie', 'allure', 'allurement', 'appeal', 'attraction', 'attractiveness', 'beguilement', 'beguiling', 'betrayal', 'bewitchery', 'bewitchment'],
    'seductive': ['acceptable', 'adorable', 'agreeable', 'alluring', 'appealing', 'appetizing', 'attracting', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling'],
    'seductress': ['aspasia', 'circe', 'delilah', 'don juan', 'jezebel', 'lorelei', 'messalina', 'parthenope', 'phryne', 'siren', 'thais', 'adventuress'],
    'sedulous': ['active', 'ardent', 'assiduous', 'busy', 'constant', 'continuing', 'diligent', 'dogged', 'elaborate', 'enduring', 'energetic', 'faithful'],
    'see': ['nb', 'animadvert', 'ante', 'ante up', 'appear', 'appraise', 'appreciate', 'apprehend', 'archbishopric', 'archdiocese', 'ascertain', 'assister'],
    'see after': ['attend to', 'baby-sit', 'care for', 'chaperon', 'cherish', 'conserve', 'foster', 'keep watch over', 'look after', 'look out for', 'look to', 'matronize'],
    'see fit': ['choose', 'choose rather', 'choose to', 'command', 'decide', 'decree', 'desire', 'determine', 'favor', 'have a bias', 'have preference', 'have rather'],
    'see it through': ['carry through', 'exhaust every move', 'follow out', 'follow through', 'follow up', 'get along', 'get on', 'go all lengths', 'go all out', 'go for broke', 'go on', 'go on with'],
    'see the light': ['appear', 'arise', 'awake', 'awaken', 'be begotten', 'be born', 'be incarnated', 'become manifest', 'become public', 'become visible', 'break', 'buzz about'],
    'see through': ['be hep to', 'be on to', 'be wise to', 'catch on to', 'come alive', 'descry', 'discern', 'make out', 'penetrate', 'perceive', 'pierce', 'plumb'],
    'see to': ['advert to', 'angle for', 'ask for', 'attend to', 'baby-sit', 'be aware of', 'be engrossed in', 'be responsible for', 'beat about for', 'care for', 'carry on', 'carry out'],
    'seeable': ['apparent', 'beholdable', 'clear', 'clear as crystal', 'crystal-clear', 'detectable', 'discernible', 'disclosed', 'distinct', 'evident', 'explicit', 'exposed'],
    'seed': ['anlage', 'acorn', 'affiliation', 'androcyte', 'antheridium', 'antherozoid', 'apparentation', 'basis', 'bed', 'berry', 'bird seed', 'birth'],
    'seeding': ['dry ice', 'artificial nucleation', 'broadcast', 'broadcasting', 'cloud seeder', 'cloud-seeding', 'dissemination', 'insemination', 'planting', 'rain doctor', 'rainmaker', 'rainmaking'],
    'seedling': ['amphibian', 'angiosperm', 'annual', 'aquatic plant', 'biennial', 'conifer', 'cosmopolite', 'cutting', 'deciduous plant', 'dicot', 'dicotyledon', 'ephemeral'],
    'seedy': ['mickey mouse', 'ailing', 'bad', 'base', 'beat-up', 'bedraggled', 'below par', 'blowzy', 'broken-down', 'careless', 'cheap', 'cheesy'],
    'seek': ['address', 'aim', 'angle for', 'ask for', 'aspire', 'be after', 'be curious', 'be determined', 'beat about for', 'beg', 'bid for', 'burn with curiosity'],
    'seeker': ['applicant', 'aspirant', 'bidder', 'candidate', 'chaser', 'claimant', 'delver', 'digger', 'follower', 'hopeful', 'hunter', 'perquisitor'],
    'seem': ['ape', 'appear', 'appear like', 'approach', 'approximate', 'be like', 'be redolent of', 'bear resemblance', 'bring to mind', 'call to mind', 'call up', 'come close'],
    'seeming': ['barmecidal', 'barmecide', 'prospero', 'acting', 'affectation', 'airiness', 'airy', 'alleged', 'angle', 'apparent', 'apparitional', 'appearance'],
    'seemingly': ['allegedly', 'apparently', 'artificially', 'as it seems', 'as it were', 'assumably', 'assumedly', 'assumptively', 'at first sight', 'conceivably', 'erroneously', 'evidently'],
    'seemly': ['accepted', 'according to hoyle', 'acknowledged', 'admitted', 'advantageous', 'advisable', 'apposite', 'appropriate', 'approved', 'apropos', 'apt', 'becoming'],
    'seep': ['bleed', 'condense', 'discharge', 'distill', 'dribble', 'drip', 'dripple', 'drop', 'effuse', 'emit', 'excrete', 'exfiltrate'],
    'seep in': ['absorb', 'adsorb', 'assimilate', 'blot', 'blot up', 'chemisorb', 'chemosorb', 'digest', 'drink', 'drink in', 'drink up', 'engross'],
    'seepage': ['absorbency', 'absorbent', 'absorption', 'access', 'admission', 'adsorbent', 'adsorption', 'assimilation', 'blotter', 'blotting', 'blotting paper', 'chemisorption'],
    'seer': ['cassandra', 'don quixote', 'druid', 'quixote', 'tv-viewer', 'astrologer', 'augur', 'authority', 'beholder', 'bird-watcher', 'bystander', 'calamity howler'],
    'seesaw': ['ferris wheel', 'lissajous figure', 'alternate', 'alternately', 'alternation', 'back and fill', 'back and forth', 'back-and-forth', 'backward and forward', 'backwards and forwards', 'battledore and shuttlecock', 'cant'],
    'seethe': ['abound', 'assemble', 'bake', 'bathe', 'be angry', 'be excitable', 'be in heat', 'be livid', 'be pissed', 'be turbulent', 'bellow', 'blaze'],
    'seething': ['agitation', 'ardent', 'baking', 'blistering', 'bluster', 'bobbery', 'boil', 'boiling', 'boiling over', 'brewing', 'broiling', 'brouhaha'],
    'segment': ['adjunct', 'affiliation', 'air line', 'allotment', 'allowance', 'analyze', 'anatomize', 'apportion', 'assay', 'axis', 'beeline', 'big end'],
    'segmentation': ['abstraction', 'alienation', 'analysis', 'analyzation', 'anatomizing', 'anatomy', 'assay', 'assaying', 'breakdown', 'breaking down', 'breaking up', 'breakup'],
    'segregate': ['abrupt', 'alien', 'alienate', 'analyze', 'anatomize', 'apart', 'atomize', 'bolt', 'cast off', 'cast out', 'change', 'choose'],
    'segregated': ['alienated', 'apart', 'cordoned', 'cordoned off', 'detached', 'disarticulated', 'disconnected', 'disengaged', 'disjoined', 'disjoint', 'disjointed', 'disjunct'],
    'segregation': ['jim crow', 'jim crow law', 'alien', 'alteration', 'analysis', 'anatomization', 'anti-semitism', 'apartheid', 'apartness', 'atomization', 'black power', 'black supremacy'],
    'seigneur': ['brahman', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'blue blood', 'boss', 'bwana', 'chef', 'chief', 'church dignitary'],
    'seize': ['abduct', 'absorb', 'accroach', 'adopt', 'afflict', 'annex', 'appreciate', 'apprehend', 'appropriate', 'arrest', 'arrogate', 'assimilate'],
    'seize the day': ['blow', 'capitalize on', 'carpe diem', 'cash in', 'dissipate', 'gamble away', 'go through', 'hang the expense', 'improve the occasion', 'lavish', 'make no provision', 'not be behindhand'],
    'seizure': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'abduction', 'abscess', 'access', 'accession', 'acquired epilepsy', 'activated epilepsy', 'acute pain', 'adoption', 'affect epilepsy'],
    'seldom': ['abnormally', 'at infrequent intervals', 'few', 'hardly', 'hardly ever', 'incredibly', 'infrequently', 'irregularly', 'little', 'not often', 'occasional', 'occasionally'],
    'select': ['accepted', 'adopted', 'advert to', 'allude to', 'analyze', 'appoint', 'appointed', 'approved', 'assign', 'be taken as', 'best', 'better'],
    'selection': ['abstract', 'acumen', 'allocation', 'alternative', 'alternativity', 'appointment', 'assignment', 'assortment', 'attribution', 'batch', 'categorization', 'characterization'],
    'selective': ['accurate', 'adoptive', 'appointive', 'appreciative', 'censorious', 'choicy', 'choosing', 'choosy', 'clannish', 'cliquish', 'conscientious', 'constituent'],
    'selective service': ['active service', 'call', 'call-up', 'compulsory military service', 'conscription', 'draft', 'draft call', 'drafting', 'duty', 'enlistment', 'enrollment', 'impressment'],
    'selectman': ['alderman', 'archon', 'bailie', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor', 'city councilman', 'city father', 'city manager', 'commissar'],
    'self': ['i myself', 'alter', 'alter ego', 'alterum', 'anima', 'anima humana', 'atman', 'ba', 'better self', 'breath', 'breath of life', 'buddhi'],
    'self-abasement': ['abasement', 'altruism', 'comedown', 'commitment', 'consecration', 'debasement', 'dedication', 'deflation', 'descent', 'devotion', 'disgrace', 'disinterest'],
    'self-absorption': ['acquisitiveness', 'anesthesia', 'autism', 'careerism', 'catatonia', 'chill', 'chilliness', 'cold blood', 'cold heart', 'coldheartedness', 'coldness', 'coolness'],
    'self-acting': ['arbitrary', 'automated', 'automatic', 'automatous', 'autonomous', 'cybernated', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous'],
    'self-adjusting': ['automated', 'automatic', 'automatous', 'cybernated', 'self-acting', 'self-active', 'self-closing', 'self-controlled', 'self-cooking', 'self-directed', 'self-directing', 'self-dumping'],
    'self-admiration': ['acquisitiveness', 'amour propre', 'amour-propre', 'autism', 'autoeroticism', 'careerism', 'complacency', 'conceitedness', 'consequentiality', 'ego trip', 'egotism', 'graspingness'],
    'self-appointed': ['assuming', 'busy', 'busybody', 'forward', 'impertinent', 'inquisitive', 'insolent', 'meddlesome', 'meddling', 'nosy', 'officious', 'overweening'],
    'self-assertive': ['assertive', 'audacious', 'bold', 'cocksure', 'controlled', 'firm-minded', 'forward', 'impertinent', 'importunate', 'independent', 'intrusive', 'meddlesome'],
    'self-assured': ['arrogant', 'assured', 'balanced', 'cocksure', 'collected', 'composed', 'confident', 'convinced', 'decided', 'determined', 'equanimous', 'equilibrious'],
    'self-centered': ['acquisitive', 'ambitious for self', 'autistic', 'careerist', 'egocentric', 'egocentristic', 'egoistic', 'egotistical', 'grasping', 'greedy', 'individualistic', 'narcissan'],
    'self-command': ['aplomb', 'assurance', 'balance', 'composure', 'confidence', 'constraint', 'control', 'discipline', 'equability', 'equanimity', 'equilibrium', 'independence'],
    'self-complacent': ['bovine', 'complacent', 'consequential', 'narcissan', 'narcissine', 'narcissistic', 'narcistic', 'overproud', 'overweening', 'priggish', 'self-admiring', 'self-approving'],
    'self-confidence': ['aplomb', 'arrogance', 'assurance', 'assuredness', 'balance', 'belief', 'boastfulness', 'certitude', 'cockiness', 'cocksureness', 'conceit', 'confidence'],
    'self-confident': ['arrogant', 'assertive', 'assured', 'balanced', 'cocksure', 'collected', 'composed', 'confident', 'convinced', 'decided', 'definite', 'determined'],
    'self-congratulatory': ['complacent', 'consequential', 'narcissan', 'narcissine', 'narcissistic', 'narcistic', 'overproud', 'overweening', 'self-admiring', 'self-approving', 'self-assuming', 'self-complacent'],
    'self-conscious': ['affected', 'anxious', 'apprehensive', 'artificial', 'awkward', 'bashful', 'confused', 'conscious', 'coy', 'demure', 'diffident', 'embarrassed'],
    'self-contained': ['acquisitive', 'aloof', 'ambitious for self', 'autarchic', 'autarkic', 'autistic', 'autonomous', 'bashful', 'calm', 'careerist', 'close', 'collected'],
    'self-content': ['amour-propre', 'autoeroticism', 'bovine', 'bovinity', 'complacence', 'complacency', 'complacent', 'consequential', 'consequentiality', 'ego trip', 'narcism', 'narcissan'],
    'self-contradiction': ['aberrancy', 'aberration', 'absurdity', 'ambiguity', 'ambivalence', 'antinomy', 'asymmetry', 'defectiveness', 'delusion', 'deviancy', 'disproportion', 'disproportionateness'],
    'self-contradictory': ['aberrant', 'abnormal', 'abroad', 'absonant', 'absurd', 'adrift', 'all abroad', 'all off', 'all wrong', 'ambiguous', 'ambivalent', 'amiss'],
    'self-control': ['abnegation', 'abstinence', 'acceptance', 'aplomb', 'arrest', 'arrestation', 'assurance', 'balance', 'calm', 'calmness', 'check', 'composure'],
    'self-controlled': ['spartan', 'accepting', 'armed with patience', 'assured', 'automated', 'automatic', 'automatous', 'balanced', 'collected', 'composed', 'confident', 'controlled'],
    'self-deception': ['airy nothing', 'autism', 'bamboozlement', 'befooling', 'bluffing', 'bubble', 'calculated deception', 'chimera', 'circumvention', 'conning', 'daydream', 'deceiving'],
    'self-defense': ['avoidance reaction', 'defence', 'defense', 'defense in depth', 'defense mechanism', 'defenses', 'deterrent capacity', 'ego defenses', 'escape mechanism', 'guard', 'negative taxis', 'protection'],
    'self-denial': ['albigensianism', 'catharism', 'franciscanism', 'sabbatarianism', 'trappism', 'waldensianism', 'yoga', 'abnegation', 'abstaining', 'abstemiousness', 'abstention', 'abstinence'],
    'self-denying': ['albigensian', 'catharist', 'franciscan', 'sabbatarian', 'trappist', 'waldensian', 'abstinent', 'altruistic', 'anchoritic', 'ascetic', 'austere', 'committed'],
    'self-destructive': ['baneful', 'bloodthirsty', 'bloody', 'bloody-minded', 'calamitous', 'cataclysmal', 'cataclysmic', 'catastrophic', 'consuming', 'consumptive', 'cruel', 'cutthroat'],
    'self-determination': ['communist threat', 'declaration of independence', 'western imperialism', 'absolute monarchy', 'aristocracy', 'atrocity story', 'autarchy', 'autarky', 'autocracy', 'automatic control', 'automation', 'automatism'],
    'self-determined': ['arbitrary', 'autarchic', 'autarkic', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'free-spirited', 'freewheeling', 'gratuitous'],
    'self-discipline': ['abnegation', 'aplomb', 'composure', 'constraint', 'control', 'denial', 'discipline', 'forbearance', 'frugality', 'golden mean', 'independence', 'moderateness'],
    'self-doubt': ['pyrrhonism', 'apprehension', 'diffidence', 'distrust', 'distrustfulness', 'doubt', 'doubtfulness', 'dubiety', 'dubiousness', 'half-belief', 'lack of self-confidence', 'lack of self-reliance'],
    'self-effacing': ['altruistic', 'backward', 'bashful', 'committed', 'consecrated', 'dedicated', 'deprecative', 'deprecatory', 'devoted', 'diffident', 'disinterested', 'humble'],
    'self-esteem': ['acquisitiveness', 'amour propre', 'amour-propre', 'arrogance', 'autism', 'autoeroticism', 'boastfulness', 'careerism', 'clear', 'complacency', 'conceit', 'consequentiality'],
    'self-esteeming': ['acquisitive', 'ambitious for self', 'autistic', 'careerist', 'complacent', 'consequential', 'egotistical', 'erect', 'grasping', 'greedy', 'house-proud', 'independent'],
    'self-evident': ['absolute', 'actual', 'admitting no question', 'apparent', 'axiomatic', 'clear', 'clear as crystal', 'clear-cut', 'confirmable', 'crystal-clear', 'definite', 'demonstrable'],
    'self-explanatory': ['apparent', 'clear', 'clear as crystal', 'comprehensible', 'crystal-clear', 'discernible', 'distinct', 'evident', 'explicit', 'express', 'indisputable', 'indubitable'],
    'self-governing': ['absolute', 'aristocratic', 'autarchic', 'autarkic', 'authoritarian', 'autocratic', 'automated', 'automatic', 'automatous', 'autonomous', 'bureaucratic', 'civic'],
    'self-government': ['declaration of independence', 'absolute monarchy', 'aplomb', 'aristocracy', 'autarchy', 'autarky', 'autocracy', 'automatic control', 'automation', 'automatism', 'automatization', 'autonomy'],
    'self-gratification': ['amusement', 'animal pleasure', 'bodily pleasure', 'carnal delight', 'comfort', 'content', 'contentment', 'coziness', 'creature comforts', 'ease', 'endpleasure', 'enjoyment'],
    'self-identity': ['agreement', 'coequality', 'coincidence', 'congruence', 'correspondence', 'differentiation', 'differentness', 'distinctiveness', 'egohood', 'equality', 'equivalence', 'homogeneity'],
    'self-immolation': ['altruism', 'blazing', 'blistering', 'branding', 'burning', 'burnt offering', 'calcination', 'car of jagannath', 'carbonization', 'cauterization', 'cautery', 'cineration'],
    'self-importance': ['accent', 'amour-propre', 'arrogance', 'assurance', 'assuredness', 'autoeroticism', 'belief', 'certitude', 'cocksureness', 'complacency', 'concern', 'concernment'],
    'self-important': ['arrogant', 'assured', 'big', 'big-league', 'big-name', 'big-time', 'bigwig', 'bigwigged', 'bloated', 'bombastic', 'cocksure', 'complacent'],
    'self-indulgence': ['acquisitiveness', 'amusement', 'animal pleasure', 'autism', 'bodily pleasure', 'careerism', 'carnal delight', 'comfort', 'content', 'contentment', 'coziness', 'crapulence'],
    'self-indulgent': ['acquisitive', 'ambitious for self', 'autistic', 'bibulous', 'careerist', 'crapulent', 'crapulous', 'debauching', 'dissipating', 'dissolute', 'egotistical', 'epicurean'],
    'self-interest': ['acquisitiveness', 'autism', 'careerism', 'ego', 'ego trip', 'egocentricity', 'egocentrism', 'egoism', 'egoisticalness', 'egotism', 'egotisticalness', 'graspingness'],
    'self-knowledge': ['acquaintance', 'corpus', 'data', 'datum', 'experience', 'expertise', 'facts', 'factual base', 'familiarity', 'information', 'intelligence', 'intimacy'],
    'self-pity': ['benevolence', 'clemency', 'commiseration', 'compassion', 'condolence', 'favor', 'feeling', 'forbearance', 'forgiveness', 'grace', 'humanity', 'kindness'],
    'self-possessed': ['aloof', 'assured', 'balanced', 'calm', 'collected', 'composed', 'confident', 'controlled', 'cool', 'detached', 'dignified', 'easy'],
    'self-possession': ['aplomb', 'assurance', 'ataraxy', 'balance', 'calmness', 'composure', 'confidence', 'constraint', 'control', 'coolness', 'discipline', 'equability'],
    'self-preservation': ['avoidance reaction', 'defence', 'defense', 'defense in depth', 'defense mechanism', 'defenses', 'deterrent capacity', 'ego defenses', 'escape mechanism', 'guard', 'negative taxis', 'protection'],
    'self-protection': ['avoidance reaction', 'defence', 'defense', 'defense in depth', 'defense mechanism', 'defenses', 'deterrent capacity', 'ego defenses', 'escape mechanism', 'guard', 'negative taxis', 'protection'],
    'self-regulating': ['automated', 'automatic', 'automatous', 'cybernated', 'self-acting', 'self-active', 'self-adjusting', 'self-closing', 'self-controlled', 'self-cooking', 'self-directed', 'self-directing'],
    'self-reliance': ['declaration of independence', 'arrogance', 'assurance', 'assuredness', 'autarchy', 'autarky', 'autonomy', 'belief', 'boastfulness', 'certitude', 'cocksureness', 'conceit'],
    'self-reliant': ['arrogant', 'assured', 'autarchic', 'autarkic', 'autonomous', 'cocksure', 'confident', 'convinced', 'decided', 'determined', 'erect', 'free-spirited'],
    'self-respect': ['amour propre', 'amour-propre', 'arrogance', 'autoeroticism', 'boastfulness', 'complacency', 'conceit', 'consequentiality', 'dignity', 'ego trip', 'face', 'haughtiness'],
    'self-respecting': ['complacent', 'consequential', 'erect', 'house-proud', 'independent', 'narcissan', 'narcissine', 'narcissistic', 'narcistic', 'overproud', 'overweening', 'prideful'],
    'self-restrained': ['assured', 'balanced', 'collected', 'composed', 'confident', 'controlled', 'equanimous', 'equilibrious', 'firm-minded', 'forward', 'importunate', 'independent'],
    'self-restraint': ['abnegation', 'abstinence', 'aplomb', 'assurance', 'balance', 'calm', 'calmness', 'composure', 'confidence', 'conservatism', 'constraint', 'continence'],
    'self-revealing': ['accessible', 'approachable', 'candid', 'communicative', 'conversable', 'demonstrative', 'effusive', 'expansive', 'extroverted', 'frank', 'free', 'free-speaking'],
    'self-righteous': ['tartuffian', 'tartuffish', 'affected', 'canting', 'complacent', 'false', 'goody', 'goody-goody', 'holier-than-thou', 'hypocritical', 'insincere', 'mealy-mouthed'],
    'self-righteousness': ['tartuffery', 'tartuffism', 'affectation', 'cant', 'false piety', 'falseness', 'goody-goodiness', 'hypocrisy', 'insincerity', 'mealymouthedness', 'mummery', 'oiliness'],
    'self-sacrificing': ['altruistic', 'committed', 'consecrated', 'dedicated', 'devoted', 'disinterested', 'humble', 'modest', 'sacrificing', 'self-abasing', 'self-abnegating', 'self-abnegatory'],
    'self-satisfaction': ['amour-propre', 'autoeroticism', 'bovinity', 'complacence', 'complacency', 'consequentiality', 'ego trip', 'narcism', 'narcissism', 'overproudness', 'overweening pride', 'self-admiration'],
    'self-satisfied': ['bovine', 'complacent', 'consequential', 'narcissan', 'narcissine', 'narcissistic', 'narcistic', 'overproud', 'overweening', 'self-admiring', 'self-approving', 'self-assuming'],
    'self-seeking': ['acquisitive', 'acquisitiveness', 'ambitious for self', 'autism', 'autistic', 'careerism', 'careerist', 'ego trip', 'egoistic', 'egomaniacal', 'egotism', 'egotistic'],
    'self-serving': ['acquisitive', 'acquisitiveness', 'ambitious for self', 'autism', 'autistic', 'careerism', 'careerist', 'ego trip', 'egoistic', 'egomaniacal', 'egotism', 'egotistic'],
    'self-styled': ['affected', 'apocryphal', 'artificial', 'assumed', 'bastard', 'bogus', 'brummagem', 'byname', 'cognominal', 'colorable', 'colored', 'counterfeit'],
    'self-sufficient': ['acquisitive', 'ambitious for self', 'autarchic', 'autarkic', 'autistic', 'autonomous', 'bashful', 'careerist', 'close', 'closed', 'complacent', 'consequential'],
    'self-willed': ['balking', 'balky', 'bigoted', 'bulldogged', 'bulletheaded', 'bullheaded', 'case-hardened', 'contrary', 'contumacious', 'determined', 'difficult', 'disobedient'],
    'self-winding': ['automated', 'automatic', 'automatous', 'cybernated', 'self-acting', 'self-active', 'self-adjusting', 'self-closing', 'self-controlled', 'self-cooking', 'self-directed', 'self-directing'],
    'selfish': ['acquisitive', 'ambitious for self', 'autistic', 'avaricious', 'careerist', 'covetous', 'egocentric', 'egocentristic', 'egoistic', 'egoistical', 'egomaniacal', 'egotistic'],
    'selfishness': ['autotheism', 'ego', 'egocentricity', 'egocentrism', 'egoism', 'egoisticalness', 'egotism', 'egotisticalness', 'individualism', 'self', 'self-absorption', 'self-centeredness'],
    'selfless': ['olympian', 'altruistic', 'candid', 'charitable', 'committed', 'consecrated', 'considerate', 'dedicated', 'detached', 'devoted', 'disinterested', 'dispassionate'],
    'selflessness': ['olympian detachment', 'altruism', 'commitment', 'consecration', 'dedication', 'detachment', 'devotion', 'disinterest', 'disinterestedness', 'dispassion', 'dispassionateness', 'humility'],
    'selfness': ['agreement', 'coequality', 'coincidence', 'congruence', 'correspondence', 'differentiation', 'differentness', 'distinctiveness', 'egohood', 'equality', 'equivalence', 'homogeneity'],
    'selfsame': ['doppelganger', 'actual thing', 'alike', 'all one', 'all the same', 'carbon copy', 'consubstantial', 'copy', 'dead ringer', 'ditto', 'double', 'duplicate'],
    'sell': ['abalienate', 'advertise', 'alien', 'alienate', 'amortize', 'argue into', 'assign', 'assure', 'ballyhoo', 'bark', 'barter', 'be convincing'],
    'sell out': ['apostatize', 'bear witness against', 'beguile', 'betray', 'blab', 'blow the whistle', 'bolt', 'break away', 'bunk', 'clear the trade', 'close out', 'convert'],
    'sell short': ['belittle', 'clear the trade', 'close out', 'convert', 'convert into cash', 'cut under', 'deprecate', 'depreciate', 'disparage', 'dump', 'effect a sale', 'job'],
    'seller': ['agent', 'chandler', 'clerk', 'colporteur', 'dealer', 'drummer', 'fishmonger', 'floorwalker', 'hawker', 'ironmonger', 'merchant', 'peddler'],
    'selling': ['accouterment', 'allurement', 'armament', 'blandishment', 'cajolement', 'cajolery', 'catering', 'chandlery', 'coaxing', 'conning', 'consumer preference study', 'consumer research'],
    'sellout': ['judas kiss', 'betrayal', 'consumer preference study', 'consumer research', 'consumer survey', 'direct-mail selling', 'double cross', 'hard sell', 'hawking', 'high-pressure salesmanship', 'huckstering', 'jobbing'],
    'selvage': ['bank', 'beading', 'binding', 'board', 'border', 'bordering', 'bordure', 'brim', 'brink', 'brow', 'coast', 'edge'],
    'semantic': ['connotative', 'demonstrative', 'denominative', 'denotative', 'descriptive', 'designative', 'diagnostic', 'emblematic', 'evidential', 'exhibitive', 'expressive', 'figural'],
    'semantics': ['bowwow theory', 'comparative linguistics', 'derivation', 'descriptive linguistics', 'dialectology', 'dingdong theory', 'etymology', 'glossematics', 'glossography', 'glossology', 'glottochronology', 'glottology'],
    'semaphore': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'beacon', 'beacon fire', 'bell', 'bell buoy', 'blinker', 'blue peter', 'buoy'],
    'semblance': ['prospero', 'accordance', 'acting', 'affectation', 'affinity', 'agreement', 'air', 'airiness', 'alibi', 'alikeness', 'alliance', 'analogy'],
    'semen': ['androcyte', 'antheridium', 'antherozoid', 'autacoid', 'bile', 'chalone', 'digestive secretion', 'endocrine', 'gall', 'gastric juice', 'hormone', 'intestinal juice'],
    'semester': ['abundant year', 'academic year', 'annum', 'bissextile year', 'calendar month', 'calendar year', 'century', 'common year', 'day', 'decade', 'decennary', 'decennium'],
    'semiannual': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'decennial', 'diurnal', 'fortnightly'],
    'semiautomatic': ['automated', 'automatic', 'automatic device', 'automaton', 'automatous', 'cybernated', 'cyborg', 'mechanical man', 'robot', 'self-acting', 'self-active', 'self-adjusting'],
    'semicircle': ['crescent', 'crescent moon', 'fifty percent', 'fifty-fifty', 'half', 'half circle', 'half-and-half', 'half-moon', 'hemicycle', 'hemisphere', 'horseshoe', 'lunula'],
    'semicircular': ['cynthian', 's-shaped', 'bicorn', 'corniform', 'crescent', 'crescent-shaped', 'crescentic', 'crescentiform', 'crescentlike', 'falcate', 'falciform', 'horn-shaped'],
    'semiconscious': ['asleep', 'cataleptic', 'catatonic', 'cold', 'comatose', 'dead', 'doped', 'drugged', 'half-conscious', 'narcotized', 'nirvanic', 'oblivious'],
    'semigloss': ['creamy', 'delicate', 'eggshell', 'flat', 'gloss', 'iridescent', 'light', 'mellow', 'mother-of-pearl', 'nacreous', 'opalescent', 'pale'],
    'semimonthly': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'decennial', 'diurnal', 'fortnightly'],
    'seminal': ['aboriginal', 'abundant', 'basal', 'basic', 'benchmark', 'blooming', 'bountiful', 'bursting', 'bursting out', 'central', 'cervical', 'clitoral'],
    'seminar': ['academic specialty', 'airing', 'analysis', 'area', 'buzz session', 'canvassing', 'classical education', 'colloquium', 'colloquy', 'conference', 'consideration', 'core curriculum'],
    'seminary': ['bible institute', 'gymnasium', 'hebrew school', 'latin school', 'realgymnasium', 'realschule', 'sabbath school', 'schule', 'sunday school', 'talmud torah', 'academy', 'church school'],
    'semiskilled': ['amateurish', 'unaccomplished', 'unbusinesslike', 'uncoached', 'unendowed', 'unfinished', 'ungifted', 'uninitiated', 'unpolished', 'unprepared', 'unprimed', 'unprofessional'],
    'semiweekly': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'decennial', 'diurnal', 'fortnightly'],
    'semiyearly': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'decennial', 'diurnal', 'fortnightly'],
    'senate': ['austria', 'barbados', 'belgium', 'brazil', 'canada', 'chile', 'colombia', 'dominican republic', 'ecuador', 'ethiopia', 'fiji', 'france'],
    'senator': ['mp', 'member of congress', 'member of parliament', 'alderman', 'assemblyman', 'chosen freeholder', 'city father', 'congressman', 'congresswoman', 'councilman', 'floor leader', 'lawgiver'],
    'send': ['address', 'address to', 'advance', 'air-express', 'airfreight', 'airmail', 'allocate', 'ask for', 'assign', 'be poised', 'beam', 'becharm'],
    'send away': ['air-express', 'airfreight', 'airmail', 'ban', 'banish', 'beat back', 'blackball', 'bow out', 'brush off', 'bundle', 'bundle off', 'cast out'],
    'send for': ['bid come', 'call', 'call away', 'call back', 'call for', 'call forth', 'call in', 'call out', 'call together', 'call up', 'cite', 'conjure'],
    'send forth': ['air-express', 'airfreight', 'airmail', 'blow out', 'bring out', 'bundle', 'bundle off', 'cast forth', 'consign', 'debouch', 'decant', 'discharge'],
    'send off': ['godspeed', 'adieu', 'air-express', 'airfreight', 'airmail', 'aloha', 'alpha', 'beat back', 'begin', 'beginning', 'blast away', 'blast off'],
    'send out': ['accredit', 'aerate', 'aerify', 'assign', 'atomize', 'authorize', 'blow out', 'carbonate', 'cast forth', 'charge', 'charter', 'chlorinate'],
    'senile': ['aged', 'aging', 'ancient', 'anile', 'childish', 'childlike', 'crabbed', 'debilitated', 'declining', 'decrepit', 'doddered', 'doddering'],
    'senility': ['aboriginality', 'abulia', 'advanced age', 'advanced years', 'age', 'age of retirement', 'an incurable disease', 'ancien regime', 'ancientness', 'anility', 'antiquity', 'arteriosclerotic psychosis'],
    'senior': ['a per se', 'absolute', 'ace', 'ancient', 'antecedent', 'anterior', 'anticipatory', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic'],
    'senior citizen': ['father time', 'methuselah', 'nestor', 'old paar', 'ancient', 'centenarian', 'dotard', 'elder', 'gaffer', 'geezer', 'golden-ager', 'gramps'],
    'seniority': ['aboriginality', 'accomplishment', 'age', 'ancien regime', 'ancientness', 'antiquity', 'ascendancy', 'atavism', 'authority', 'cobwebs of antiquity', 'consequence', 'deanship'],
    'senora': ['frau', 'fraulein', 'miss', 'mistress', 'mlle', 'mme', 'mmes', 'dame', 'dona', 'donna', 'lady', 'madam'],
    'senorita': ['frau', 'fraulein', 'miss', 'mistress', 'mlle', 'mme', 'mmes', 'dame', 'dona', 'donna', 'lady', 'madam'],
    'sensation': ['affect', 'affection', 'amazement', 'astonishing thing', 'astonishment', 'awareness', 'bang', 'bean', 'best seller', 'big hit', 'bomb', 'bombshell'],
    'sensational': ['barnumesque', 'gongoresque', 'johnsonian', 'acid', 'affected', 'amazing', 'arresting', 'astonishing', 'astounding', 'bedizened', 'beguiling', 'bewildering'],
    'sensationalism': ['barnumism', 'thespian art', 'affectation', 'aggrandizement', 'amateur theatricals', 'amplification', 'ballyhoo', 'bedizenment', 'big talk', 'blatancy', 'blood and thunder', 'blowing up'],
    'sense': ['iq', 'absorb', 'acceptation', 'admissibility', 'affect', 'affection', 'affective meaning', 'air', 'anticipate', 'appreciate', 'appreciation', 'appreciation of differences'],
    'senseless': ['abiotic', 'abnormal', 'absonant', 'absurd', 'aimless', 'amorphous', 'anesthetized', 'apish', 'asinine', 'asleep', 'azoic', 'batty'],
    'senses': ['balance', 'chromesthesia', 'color hearing', 'consciousness', 'contact with reality', 'faculties', 'five senses', 'healthy mind', 'hearing', 'intellectual gifts', 'intellectuals', 'lucid interval'],
    'sensibility': ['acuity', 'acumen', 'acuteness', 'adaptability', 'affectibility', 'affection', 'affectivity', 'agreeability', 'amenability', 'apperception', 'appreciation', 'appreciation of differences'],
    'sensible': ['acknowledging', 'acquainted with', 'admissible', 'alive to', 'all there', 'all-knowing', 'apperceptive', 'appercipient', 'appreciable', 'appreciative', 'appreciative of', 'apprehending'],
    'sensitive': ['accurate', 'acute', 'adaptable', 'affected', 'agitable', 'algetic', 'allergic', 'anaphylactic', 'angry', 'appreciative', 'attuned', 'aware'],
    'sensitivity': ['acuteness', 'affectivity', 'agitability', 'allergy', 'anaphylaxis', 'appreciation', 'appreciation of differences', 'appreciativeness', 'artistic judgment', 'awareness', 'censoriousness', 'choosiness'],
    'sensitivity to': ['a thing for', 'affinity', 'aptitude', 'aptness', 'bent', 'bias', 'cast', 'conatus', 'conduciveness', 'delight', 'diathesis', 'disposition'],
    'sensitivity training': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'assertiveness training', 'behavior modification', 'behavior therapy', 'bioenergetics', 'biofeedback', 'confrontation therapy'],
    'sensual': ['cyprian', 'cyrenaic', 'abandoned', 'amorous', 'animal', 'aphrodisiomaniacal', 'appetitive', 'banausic', 'bawdy', 'bent on pleasure', 'bodily', 'carnal'],
    'sensualist': ['casanova', 'cyrenaic', 'don juan', 'heliogabalus', 'lothario', 'romeo', 'sardanapalus', 'bon vivant', 'carpet knight', 'debauchee', 'epicure', 'epicurean'],
    'sensuality': ['animality', 'bawdiness', 'carnality', 'clitoromania', 'coldness', 'concupiscence', 'dirtiness', 'eroticism', 'eroticomania', 'erotomania', 'flesh', 'fleshliness'],
    'sensuous': ['dionysian', 'appealing', 'attractive', 'bacchic', 'bewitching', 'captivating', 'charming', 'delightful', 'dionysiac', 'enchanting', 'engaging', 'enravishing'],
    'sentence': ['parthian shot', 'acquittal', 'act on', 'action', 'adage', 'address', 'adjectival phrase', 'adjudge', 'adjudicate', 'affirmation', 'allegation', 'ana'],
    'sententious': ['gongoresque', 'johnsonian', 'spartan', 'abbreviated', 'abridged', 'admonitory', 'advisory', 'affected', 'allegorical', 'aphoristic', 'aposiopestic', 'associational'],
    'sentience': ['affectibility', 'alertness', 'all-night vigil', 'consciousness', 'impressibility', 'impressionability', 'insomnia', 'insomniac', 'insomnolence', 'insomnolency', 'lidless vigil', 'limen'],
    'sentient': ['alive', 'alive to', 'au courant', 'awake', 'aware', 'cognizant', 'conscious', 'conversant', 'emotionable', 'feeling', 'impressible', 'impressionable'],
    'sentiment': ['amor', 'christian love', 'eros', 'platonic love', 'admiration', 'adoration', 'affect', 'affection', 'affections', 'affective faculty', 'affectivity', 'agape'],
    'sentimental': ['adoring', 'affectionate', 'apish', 'asinine', 'bathetic', 'batty', 'beery', 'befooled', 'beguiled', 'besotted', 'brainless', 'buffoonish'],
    'sentimentality': ['affection', 'affectionateness', 'amativeness', 'amorousness', 'bathos', 'bleeding heart', 'cloyingness', 'corn', 'corniness', 'demonstrativeness', 'ecstasy', 'emotionalism'],
    'sentry': ['argus', 'cassandra', 'charley', 'jeremiah', 'admonisher', 'airplane spotter', 'cautioner', 'fire patrolman', 'fire warden', 'fireguard', 'flagman', 'forward observer'],
    'sentry box': ['nissen hut', 'quonset hut', 'booth', 'crib', 'gatehouse', 'hut', 'hutch', 'kiosk', 'lean-to', 'outbuilding', 'outhouse', 'pavilion'],
    'separate': ['aberrate', 'abrupt', 'aggravate', 'agree to differ', 'agree to disagree', 'alien', 'alienate', 'alienated', 'alone', 'aloof', 'analyze', 'anatomize'],
    'separated': ['alien', 'alienated', 'alone', 'aloof', 'apart', 'assorted', 'asunder', 'at a distance', 'at odds', 'at variance', 'away', 'companionless'],
    'separately': ['adrift', 'alone', 'apart', 'apart from', 'aside from', 'asunder', 'away from', 'by itself', 'concretely', 'definitely', 'distinctly', 'especially'],
    'separateness': ['alienation', 'aloneness', 'aloofness', 'anarchy', 'apartheid', 'celibacy', 'chaos', 'confusion', 'contrariety', 'contrast', 'departure', 'detachment'],
    'separation': ['jim crow', 'aberration', 'aesthetic distance', 'alien', 'alienation', 'alteration', 'analysis', 'analyzation', 'anatomization', 'anatomizing', 'anatomy', 'annulment'],
    'separatism': ['abstraction', 'alienation', 'apartheid', 'detachment', 'disarticulation', 'disassociation', 'disconnectedness', 'disconnection', 'discontinuity', 'disengagement', 'disjointing', 'disjunction'],
    'separatist': ['abjuratory', 'apostate', 'backslider', 'bolter', 'breakaway', 'collaborationist', 'collaborator', 'convert', 'defector', 'demurrer', 'deserter', 'dissenter'],
    'separative': ['ablative', 'biodegradable', 'characteristic', 'characterizing', 'contrastive', 'corrosive', 'decomposable', 'decomposing', 'degradable', 'diacritical', 'diagnostic', 'differencing'],
    'sepia': ['beige', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'chocolate', 'cinnamon', 'cocoa', 'cocoa-brown', 'coffee', 'coffee-brown', 'drab'],
    'sept': ['affiliation', 'animal kingdom', 'apparentation', 'birth', 'blood', 'bloodline', 'bracket', 'branch', 'breed', 'brood', 'caste', 'category'],
    'septet': ['heptateuch', 'spenserian stanza', 'antistrophe', 'bipartisanship', 'book', 'burden', 'canto', 'chorus', 'coaction', 'coadjuvancy', 'coadministration', 'coagency'],
    'septic': ['bad', 'bad for', 'cankered', 'contaminated', 'diseased', 'foul', 'gangrened', 'gangrenous', 'harmful', 'infected', 'injurious', 'insalubrious'],
    'septuagenarian': ['father time', 'methuselah', 'nestor', 'old paar', 'sexagesima', 'boxcar', 'boxcars', 'centenarian', 'dotard', 'dozen', 'duodecimo', 'eighty'],
    'septum': ['barrier', 'brattice', 'buffer', 'buffer state', 'bulkhead', 'bumper', 'cloison', 'collision mat', 'cushion', 'diaphragm', 'dissepiment', 'dividing line'],
    'sepulcher': ['barrow', 'beehive tomb', 'bone house', 'box grave', 'burial', 'burial chamber', 'burial mound', 'catacombs', 'cenotaph', 'charnel house', 'cist', 'cist grave'],
    'sepulchral': ['baritone', 'bass', 'cavernous', 'cinerary', 'contralto', 'deep', 'deep-echoing', 'deep-pitched', 'deep-toned', 'deepmouthed', 'dirgelike', 'dismal'],
    'sequel': ['aftereffect', 'aftermath', 'alternation', 'by-product', 'chain', 'chasing', 'close', 'closing', 'conclusion', 'consecution', 'consequence', 'consequent'],
    'sequence': ['indian file', 'aftereffect', 'afterlife', 'aftermath', 'alternation', 'arrangement', 'array', 'articulation', 'bank', 'buzz', 'by-product', 'catena'],
    'sequential': ['appendant', 'catenary', 'connected', 'consecutive', 'consequent', 'consequential', 'consistent', 'continuous', 'cyclic', 'deducible', 'derivable', 'derivational'],
    'sequester': ['abrupt', 'accroach', 'alienate', 'annex', 'arrogate', 'attach', 'cast off', 'cast out', 'cloister', 'close off', 'collectivize', 'commandeer'],
    'sequestered': ['abstruse', 'alienated', 'anchoritic', 'anonymous', 'at rest', 'beclouded', 'blind', 'buried', 'calm', 'cloistered', 'close', 'closet'],
    'sequitur': ['ps', 'parthian shot', 'addendum', 'afterthought', 'appendix', 'back matter', 'chorus', 'coda', 'codicil', 'colophon', 'conclusion', 'consequence'],
    'seraphic': ['christlike', 'christly', 'elysian', 'god-fearing', 'admirable', 'adorable', 'angelic', 'archangelic', 'beatified', 'blissful', 'canonized', 'caressable'],
    'seraphim': ['angel', 'angel of light', 'angel of love', 'angelology', 'angels', 'archangel', 'archangels', 'beatified soul', 'canonized mortal', 'celestial', 'cherub', 'cherubim'],
    'sere': ['adust', 'arid', 'atrophied', 'baked', 'bare', 'bone-dry', 'brittle', 'burnt', 'corky', 'deep-worn', 'dehydrated', 'desiccated'],
    'serenade': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'address', 'addresses', 'alba', 'amorous pursuit', 'anthem', 'art song', 'aubade'],
    'serendipity': ['accidentality', 'actuarial calculation', 'adventitiousness', 'break', 'bringing to light', 'casual discovery', 'casualness', 'catching', 'chance', 'chance discovery', 'destiny', 'detection'],
    'serene': ['at peace', 'bloodless', 'bucolic', 'calm', 'clear', 'cloudless', 'collected', 'composed', 'concordant', 'cool', 'coolheaded', 'diaphanous'],
    'serenity': ['buddha-like composure', 'oriental calm', 'abnegation', 'abstinence', 'aplomb', 'ataraxia', 'ataraxy', 'calm', 'calm disposition', 'calm of mind', 'calmness', 'composure'],
    'serf': ['apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'bootlick', 'bootlicker', 'brown-nose'],
    'serfdom': ['abjectness', 'absolutism', 'attendance', 'baseness', 'bond service', 'bondage', 'captivity', 'control', 'debt slavery', 'deprivation of freedom', 'disenfranchisement', 'disfranchisement'],
    'sergeant': ['g-man', 'mp', 'nco', 'acting corporal', 'acting sergeant', 'bailiff', 'beadle', 'beagle', 'bound bailiff', 'captain', 'catchpole', 'centurion'],
    'serial': ['grand guignol', 'passion play', 'tom show', 'alternate', 'annual', 'antimasque', 'article', 'audience success', 'ballet', 'beating', 'best seller', 'bimonthly'],
    'series': ['indian file', 'alternation', 'array', 'arsis', 'articulation', 'back number', 'bank', 'battery', 'beat', 'biotype', 'block', 'bout'],
    'serious': ['abandoned', 'acute', 'afire', 'alarming', 'ardent', 'arduous', 'austere', 'awe-inspiring', 'bad', 'bound', 'bound and determined', 'burning'],
    'seriously': ['actively', 'actually', 'all joking aside', 'ardently', 'assuredly', 'badly', 'bec et ongles', 'candidly', 'certainly', 'clearly', 'committedly', 'critically'],
    'seriousness': ['abandon', 'ardency', 'ardor', 'commitment', 'committedness', 'decidedness', 'decision', 'decisiveness', 'decorousness', 'dedication', 'definiteness', 'demureness'],
    'sermon': ['address', 'admonishment', 'admonition', 'assignment', 'castigation', 'chalk talk', 'chastisement', 'chiding', 'correction', 'discourse', 'disquisition', 'dressing-down'],
    'sermonize': ['deliver a lecture', 'descant', 'dilate', 'discourse', 'discuss', 'dissert', 'dissertate', 'evangelize', 'expatiate', 'explain', 'exposit', 'expound'],
    'sermonizer': ['boanerges', 'chalk talker', 'churchman', 'circuit rider', 'cleric', 'clerk', 'discourser', 'divine', 'ecclesiastic', 'expositor', 'expounder', 'homilist'],
    'serous': ['bloody', 'chylifactive', 'chylifactory', 'chylific', 'excretory', 'humoral', 'ichorous', 'lachrymal', 'lachrymose', 'lacrimatory', 'lactational', 'lacteal'],
    'serpent': ['apollyon', 'beelzebub', 'benedict arnold', 'brutus', 'judas', 'judas iscariot', 'lucifer', 'old nick', 'old scratch', 'quisling', 'satan', 'alpenhorn'],
    'serpentine': ['byzantine', 'machiavellian', 'machiavellic', 'mephistophelian', 'aberrant', 'aberrative', 'acute', 'affluent', 'ambagious', 'amphibian', 'anfractuous', 'anguiform'],
    'serrate': ['v-shaped', 'vandyke', 'y-shaped', 'akimbo', 'angular', 'battlemented', 'bent', 'blaze', 'chop', 'chopped', 'cornered', 'corrugated'],
    'serried': ['articulated', 'assembled', 'bristling', 'catenated', 'ceaseless', 'close', 'close-knit', 'close-textured', 'close-woven', 'compact', 'compacted', 'compressed'],
    'serum': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'agglutinin', 'allergen', 'anaphylactin', 'antiantibody', 'antibody', 'antigen', 'antiserum'],
    'servant': ['charlie mccarthy', 'ganymede', 'acolyte', 'adherent', 'adjutant', 'agent', 'aid', 'aide', 'aide-de-camp', 'aider', 'amah', 'ancilla'],
    'serve': ['accommodate', 'accord', 'act', 'act as', 'act for', 'administer', 'administer to', 'advance', 'advantage', 'afford', 'allot', 'allow'],
    'serve time': ['alternate', 'be imprisoned', 'cover', 'do a hitch', 'do a stint', 'do a tour', 'do time', 'enlist', 'fill in for', 'have a go', 'have tenure', 'hold office'],
    'service': ['american plan', 'european plan', 'mass', 'a la carte', 'accommodation', 'account', 'acquiescence', 'act of grace', 'act of kindness', 'action', 'active service', 'activities'],
    'serviceable': ['advantageous', 'agential', 'agentival', 'agentive', 'aidful', 'aiding', 'appropriate', 'assisting', 'banausic', 'beneficial', 'commodious', 'conducive'],
    'serviceman': ['amazon', 'air serviceman', 'armed forces', 'brave', 'cannon fodder', 'cobbler', 'doctor', 'fighter', 'fighting man', 'fixer', 'food for powder', 'forces'],
    'servile': ['abject', 'abused', 'accepting', 'acquiescent', 'agreeable', 'apple-polishing', 'ass-kissing', 'assenting', 'attendant', 'attending', 'base', 'bootlicking'],
    'servility': ['abjection', 'abjectness', 'absolutism', 'acquiescence', 'agreeability', 'agreeableness', 'allegiance', 'apple-polishing', 'ass-kissing', 'back seat', 'baseness', 'bend'],
    'serving': ['accessory', 'acting', 'adjuvant', 'ancillary', 'antepast', 'assistant', 'assisting', 'attendant', 'attending', 'auxiliary', 'behavioral', 'course'],
    'servitude': ['absolutism', 'attendance', 'bond service', 'bondage', 'captivity', 'control', 'debt slavery', 'deprivation of freedom', 'disenfranchisement', 'disfranchisement', 'domination', 'employ'],
    'servomechanism': ['flettner control', 'action', 'autosyn', 'clockworks', 'cybernion', 'direct-current servo', 'drive train', 'gear', 'hemostat', 'hydraulic servo', 'innards', 'machinery'],
    'sesquicentennial': ['anniversary', 'annual holiday', 'bicentenary', 'bicentennial', 'biennial', 'birthday', 'bissextile day', 'cental', 'centare', 'centenarian', 'centenary', 'centennial'],
    'sesquipedalian': ['latinate', 'a mile long', 'awkward', 'bombastic', 'cramped', 'cumbrous', 'elephantine', 'extensive', 'far-flung', 'far-reaching', 'fargoing', 'forced'],
    'session': ['council of nicaea', 'council of trent', 'lateran council', 'vatican council', 'abundant year', 'academic year', 'annum', 'assemblee', 'assembly', 'assignation', 'at home', 'audience'],
    'set': ['a to z', 'a to izzard', 'brownian movement', 'platonic form', 'platonic idea', 'zeitgeist', 'abet', 'accepted', 'accommodate', 'accord', 'accretion', 'acrid'],
    'set about': ['accept', 'assume', 'attack', 'attempt', 'begin', 'blast away', 'blast off', 'buckle to', 'commence', 'dive in', 'dive into', 'embark in'],
    'set against': ['aggravate', 'alienate', 'antagonize', 'come between', 'disaffect', 'disunite', 'divide', 'embitter', 'envenom', 'estrange', 'exacerbate', 'fan the flame'],
    'set apart': ['abrupt', 'abscind', 'alienate', 'allocate', 'allot', 'amputate', 'analyze', 'anatomize', 'annihilate', 'appoint', 'appropriate to', 'assign'],
    'set aside': ['abandon', 'abolish', 'abrogate', 'abrupt', 'abscind', 'adjourn', 'admit', 'admit exceptions', 'alienate', 'allocate', 'allot', 'allow'],
    'set back': ['arrest', 'backpedal', 'backwater', 'bog down', 'bottle up', 'brake', 'bridle', 'check', 'clip the wings', 'constrain', 'contain', 'control'],
    'set before': ['advance', 'affront', 'brave', 'breast', 'bring before', 'bring forward', 'bring up', 'broach', 'challenge', 'choose rather', 'commend to attention', 'confront'],
    'set down': ['abase', 'abash', 'account for', 'accredit with', 'accrete to', 'acknowledge', 'admonish', 'affirm', 'allege', 'announce', 'annunciate', 'apply to'],
    'set forth': ['advance', 'affect', 'approve', 'argue', 'articulate', 'assert', 'attest', 'be off', 'bespeak', 'betoken', 'brandish', 'breathe'],
    'set in': ['bed', 'begin', 'blast', 'blast away', 'blast off', 'blow', 'blow a hurricane', 'blow great guns', 'blow over', 'blow up', 'bluster', 'breeze'],
    'set in motion': ['actuate', 'animate', 'bundle', 'bundle off', 'compel', 'drive', 'drive on', 'energize', 'float', 'force', 'forward', 'foster'],
    'set off': ['actuate', 'adjoin', 'adorn', 'allocate', 'allot', 'analogize', 'analyze', 'anatomize', 'appoint', 'appropriate to', 'array', 'assign'],
    'set on': ['abet', 'aching for', 'aggravate', 'agitate', 'alienate', 'ambush', 'arouse', 'assail', 'assault', 'attack', 'bed on', 'bent on'],
    'set out': ['adorn', 'align', 'allocate', 'allot', 'apportion', 'arrange', 'array', 'be off', 'bear', 'bear for', 'bear up for', 'bear up to'],
    'set right': ['accommodate', 'accord', 'adapt', 'adjust', 'adjust to', 'amend', 'assimilate', 'atone', 'attune', 'awaken', 'break the spell', 'broaden the mind'],
    'set sail': ['begin', 'blast away', 'blast off', 'clap on', 'commence', 'crack on', 'dive in', 'fall to', 'get to', 'give her beans', 'go ahead', 'head into'],
    'set straight': ['admonish', 'amend', 'awaken', 'break the spell', 'bring to book', 'burst the bubble', 'call to account', 'chastise', 'chide', 'compensate', 'conduct to', 'correct'],
    'set to': ['accept', 'affix', 'altercate', 'anchor', 'annex', 'apologetics', 'apologia', 'apology', 'argument', 'argumentation', 'assume', 'attach'],
    'set up': ['abet', 'aggrandize', 'aggravate', 'aid', 'amend', 'angel', 'animate', 'annoy', 'apotheose', 'apotheosize', 'arouse', 'arrange'],
    'set upon': ['ambush', 'assail', 'assault', 'attack', 'blitz', 'bushwhack', 'come at', 'come down on', 'crack down on', 'descend on', 'descend upon', 'fall on'],
    'seta': ['barb', 'barbel', 'bristle', 'capillament', 'cilium', 'coat', 'fleece', 'fur', 'hair', 'horsehair', 'mane', 'pelt'],
    'setback': ['arrest', 'arrestation', 'arrestment', 'atavism', 'backset', 'backsliding', 'backward deviation', 'backward motion', 'backward step', 'bafflement', 'balk', 'betrayed hope'],
    'setoff': ['abatement', 'agio', 'allowance', 'antipode', 'antipodes', 'antipole', 'antithesis', 'antonym', 'balance', 'ballast', 'bank discount', 'breakage'],
    'setting': ['intertype', 'linotype', 'monotype', 'adaptation', 'agora', 'amphitheater', 'arena', 'arrangement', 'arteriosclerosis', 'atherosclerosis', 'athletic field', 'auditorium'],
    'settle': ['ko', 'abalienate', 'abide', 'accommodate', 'accommodate with', 'accord', 'adapt', 'adapt to', 'adjust', 'adjust to', 'affirm', 'afford proof of'],
    'settle down': ['alight', 'anchor', 'attain majority', 'be conservative', 'be moderate', 'be pacifistic', 'billet at', 'bivouac', 'bloom', 'burrow', 'camp', 'cave'],
    'settle upon': ['account for', 'accredit with', 'accrete to', 'acknowledge', 'apply to', 'ascribe to', 'assign to', 'attach to', 'attribute to', 'blame', 'blame for', 'blame on'],
    'settle with': ['accommodate', 'account with', 'adjust', 'arrange', 'be quits', 'bring to account', 'bring to book', 'call to account', 'castigate', 'chasten', 'chastise', 'clear the board'],
    'settled': ['sol', 'acquitted', 'agreed', 'all bets off', 'all off', 'all over', 'all up', 'all up with', 'anchored', 'arranged', 'ascertained', 'assigned'],
    'settlement': ['abalienation', 'abatement of differences', 'absolute indication', 'absolute interest', 'accommodation', 'acquitment', 'acquittal', 'acquittance', 'adjustment', 'affirmation', 'agreement', 'alienation'],
    'settler': ['ko', 'maecenas', 'santa claus', 'almoner', 'almsgiver', 'angel', 'arrival', 'arriviste', 'assignor', 'awarder', 'backer', 'bestower'],
    'setup': ['anatomy', 'approach', 'architectonics', 'architecture', 'arrangement', 'array', 'assemblage', 'assembly', 'attack', 'blueprint', 'blueprinting', 'breeze'],
    'seventh': ['consecutive intervals', 'degree', 'diapason', 'diatessaron', 'diatonic interval', 'diatonic semitone', 'enharmonic diesis', 'enharmonic interval', 'fifth', 'fourth', 'half step', 'halftone'],
    'seventh heaven': ['acme', 'apex', 'apogee', 'beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'brow', 'cap', 'celestial throne'],
    'sever': ['abandon', 'amputate', 'analyze', 'anatomize', 'atomize', 'ax', 'bisect', 'bob', 'break off', 'break up', 'butcher', 'carve'],
    'several': ['a certain number', 'a few', 'a number', 'absolute', 'assorted', 'at odds', 'at variance', 'certain', 'concrete', 'considerable', 'contrary', 'contrasted'],
    'severally': ['adrift', 'alone', 'apart', 'apart from', 'apiece', 'aside from', 'asunder', 'away from', 'by itself', 'distributively', 'diversely', 'each'],
    'severance': ['abscission', 'alteration', 'amputation', 'analysis', 'anatomization', 'atomization', 'butchering', 'change', 'chopping', 'clearance', 'cleavage', 'cutting'],
    'severe': ['draconian', 'herculean', 'siberian', 'spartan', 'spartanic', 'abrupt', 'absolute', 'absolutist', 'absolutistic', 'abstruse', 'acerbic', 'acid'],
    'severed': ['cleft', 'cloven', 'cracked', 'cut', 'in pieces', 'in shreds', 'lacerate', 'lacerated', 'mangled', 'mutilated', 'quartered', 'ragged'],
    'severely': ['acutely', 'ascetically', 'austerely', 'awfully', 'badly', 'barely', 'brutally', 'coldly', 'coolly', 'critically', 'crudely', 'cruelly'],
    'severity': ['spartan simplicity', 'spartanism', 'abruptness', 'absolute zero', 'absoluteness', 'abusiveness', 'accuracy', 'acerbity', 'acidity', 'acidulousness', 'acridity', 'acrimony'],
    'sew': ['articulate', 'batten', 'batten down', 'bleed', 'bolt', 'buckle', 'butt', 'button', 'clasp', 'cleat', 'clip', 'dovetail'],
    'sew up': ['absorb', 'bugger', 'cobble', 'commission', 'condition', 'consume', 'cook up', 'darn', 'do up', 'doctor', 'engross', 'fag'],
    'sewage': ['bm', 'bilge', 'bilgewater', 'bowel movement', 'buffalo chips', 'ca-ca', 'carrion', 'coprolite', 'coprolith', 'cow chips', 'cow flops', 'cow pats'],
    'sewer': ['singer', 'abri', 'antre', 'bog', 'bunker', 'burrow', 'cave', 'cavern', 'cesspool', 'cloaca', 'cloaca maxima', 'cove'],
    'sewing': ['smyth sewing', 'applique', 'backing', 'baste', 'bibliopegy', 'bind', 'binder board', 'binding', 'book cloth', 'book cover', 'book jacket', 'bookbinding'],
    'sex': ['amor', 'christian love', 'eros', 'platonic love', 'act of love', 'admiration', 'adoration', 'adultery', 'affection', 'agape', 'amorous', 'aphrodisia'],
    'sex act': ['act of love', 'adultery', 'aphrodisia', 'ass', 'balling', 'carnal knowledge', 'climax', 'cohabitation', 'coition', 'coitus', 'coitus interruptus', 'commerce'],
    'sex appeal': ['agacerie', 'allure', 'allurement', 'appeal', 'attraction', 'attractiveness', 'beguilement', 'beguiling', 'bewitchery', 'bewitchment', 'blandishment', 'cajolery'],
    'sex drive': ['carnality', 'coldness', 'flesh', 'fleshliness', 'frigidity', 'impotence', 'libido', 'love', 'lovemaking', 'marriage', 'potency', 'sensuality'],
    'sex organs': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'sex starved': ['concupiscent', 'ejaculatory', 'goatish', 'horny', 'hot', 'hot-blooded', 'itching', 'lascivious', 'libidinous', 'lickerish', 'lustful', 'orgasmic'],
    'sexagenarian': ['father time', 'methuselah', 'nestor', 'old paar', 'sexagesima', 'boxcar', 'boxcars', 'centenarian', 'dotard', 'dozen', 'duodecimo', 'eighty'],
    'sexed': ['amorous', 'carnal', 'erogenic', 'erogenous', 'erotic', 'erotogenic', 'fleshly', 'gamic', 'heterosexual', 'libidinal', 'nuptial', 'oversexed'],
    'sexism': ['jim crow', 'jim crow law', 'anti-semitism', 'apartheid', 'black power', 'black supremacy', 'chauvinism', 'class consciousness', 'class distinction', 'class hatred', 'class prejudice', 'class war'],
    'sexist': ['timonistic', 'antiblack', 'antisocial', 'biased', 'bigot', 'chauvinist', 'chauvinistic', 'colored', 'cynic', 'cynical', 'doctrinaire', 'dogmatic'],
    'sexploitation': ['rabelaisianism', 'x-rated movie', 'bawdiness', 'bawdry', 'blue movie', 'dirt', 'dirtiness', 'dirty movie', 'erotic art', 'erotic literature', 'erotographomania', 'fescenninity'],
    'sextant': ['astrolabe', 'astronavigation', 'azimuth circle', 'azimuth compass', 'bevel', 'bevel protractor', 'bevel square', 'celestial navigation', 'chronometer', 'clinometer', 'coastwise navigation', 'consolan'],
    'sextet': ['german band', 'hexateuch', 'jewish star', 'magen david', 'philharmonic', 'spenserian stanza', 'antistrophe', 'band', 'big band', 'bipartisanship', 'book', 'brass'],
    'sexton': ['bible clerk', 'bible reader', 'acolyte', 'almoner', 'anagnost', 'beadle', 'bedral', 'capitular', 'capitulary', 'choir chaplain', 'churchwarden', 'clerk'],
    'sexual': ['amative', 'amatory', 'amorous', 'animal', 'aphrodisiomaniacal', 'ardent', 'bawdy', 'bodily', 'caressive', 'carnal', 'clitoromaniacal', 'concupiscent'],
    'sexual assault': ['abuse', 'betrayal', 'criminal assault', 'debauchment', 'defilement', 'defloration', 'deflowering', 'deflowerment', 'despoilment', 'devirgination', 'priapism', 'rape'],
    'sexual climax': ['access', 'act of love', 'adultery', 'aphrodisia', 'apoplexy', 'ass', 'attack', 'balling', 'carnal knowledge', 'climax', 'cohabitation', 'coition'],
    'sexual desire': ['an universal wolf', 'andromania', 'anger', 'animus', 'aphrodisia', 'appetence', 'appetency', 'appetite', 'appetition', 'ardency', 'ardor', 'biological urge'],
    'sexual intercourse': ['act of love', 'adultery', 'amorous dalliance', 'aphrodisia', 'ass', 'balling', 'billing and cooing', 'bundling', 'caressing', 'carnal knowledge', 'climax', 'cohabitation'],
    'sexual preference': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'bisexuality', 'coprophilia', 'exhibitionism', 'fetishism', 'heterosexuality', 'homoeroticism', 'homosexualism'],
    'sexuality': ['animality', 'bawdiness', 'carnality', 'clitoromania', 'coldness', 'concupiscence', 'dirtiness', 'eroticism', 'eroticomania', 'erotomania', 'flesh', 'fleshliness'],
    'sexy': ['alluring', 'amorous', 'animal', 'aphrodisiomaniacal', 'appealing', 'arousing', 'bawdy', 'bedroom', 'blue', 'broad', 'captivating', 'carnal'],
    'shabby': ['mickey mouse', 'ng', 'abandoned', 'abject', 'abominable', 'arrant', 'atrocious', 'awful', 'bare', 'base', 'battered', 'beastly'],
    'shack': ['nissen hut', 'quonset hut', 'booth', 'box', 'bum', 'cabin', 'caboose', 'camp', 'cot', 'cottage', 'crib', 'derelict'],
    'shackle': ['oregon boat', 'anchor', 'arrest', 'bar', 'barrier', 'bearing rein', 'bilbo', 'bind', 'bit', 'bond', 'bonds', 'bottle up'],
    'shade': ['masan', 'achromatism', 'adumbration', 'air', 'amount', 'anima', 'anima humana', 'apparition', 'appearance', 'apply paint', 'astral', 'astral spirit'],
    'shades': ['polaroid glasses', 'bifocals', 'blinkers', 'cheaters', 'colored glasses', 'contact lens', 'dark glasses', 'divided spectacles', 'eyeglass', 'eyeglasses', 'eyeshade', 'eyeshield'],
    'shading': ['arrangement', 'atmosphere', 'balance', 'black spot', 'blackening', 'blocking the light', 'bloom', 'blooping', 'brushwork', 'clouding', 'color', 'composition'],
    'shadow': ['masan', 'adherent', 'adumbrate', 'adumbration', 'afterglow', 'afterimage', 'air', 'airy nothing', 'alter ego', 'amount', 'anima', 'anima humana'],
    'shadowing': ['ambuscade', 'ambush', 'ambushment', 'blackening', 'blind', 'blocking the light', 'booby trap', 'bugging', 'chase', 'chasing', 'cloak-and-dagger work', 'clouding'],
    'shadowy': ['air-built', 'airy', 'aleatoric', 'aleatory', 'amorphous', 'asomatous', 'astral', 'blear', 'bleared', 'bleary', 'blind', 'blobby'],
    'shady': ['amoral', 'bent', 'blue', 'bosky', 'broad', 'clouded', 'conscienceless', 'corrupt', 'corrupted', 'criminal', 'crooked', 'curtained'],
    'shaft': ['abysm', 'abyss', 'adit', 'air duct', 'air hole', 'air passage', 'air shaft', 'air tube', 'airway', 'antenna tower', 'arch', 'arrow'],
    'shag': ['burley', 'cuban', 'havana', 'havana seed', 'latakia', 'maryland', 'russian', 'turkish', 'virginia', 'bright', 'bring', 'bring back'],
    'shaggy': ['bristly', 'broken', 'bumpy', 'bushy', 'choppy', 'cirrose', 'coarse', 'coarse-grained', 'corrugated', 'cross-grained', 'disheveled', 'fleecy'],
    'shah': ['dalai lama', 'holy roman emperor', 'inca', 'kaiser', 'ardri', 'bey', 'cacique', 'caesar', 'cham', 'czar', 'kaid', 'khan'],
    'shake': ['bebung', 'abandon', 'abate', 'accost', 'address', 'affright', 'age', 'agitate', 'agitating', 'agitation', 'alarm', 'alcoholic drink'],
    'shake down': ['assay', 'badger', 'blackmail', 'bring to test', 'comb', 'confirm', 'cut and try', 'essay', 'exact', 'experiment', 'extort', 'fan'],
    'shake off': ['beg', 'cast off', 'circumvent', 'clear', 'dispel', 'ditch', 'do away with', 'double', 'eliminate', 'elude', 'escape', 'evade'],
    'shake up': ['abate', 'accelerate', 'accuse', 'action', 'ad hoc measure', 'agitate', 'anathematize', 'anathemize', 'animadvert on', 'answer', 'arouse', 'arraign'],
    'shakedown': ['gedankenexperiment', 'audition', 'badger game', 'bench test', 'blackmail', 'bloodsucking', 'dry run', 'extortion', 'flight test', 'hearing', 'pilot plan', 'practical test'],
    'shaken': ['agitated', 'balled-up', 'bothered', 'bowled down', 'chaotic', 'confused', 'crushed', 'dashed', 'demoralized', 'discomposed', 'disconcerted', 'disordered'],
    'shakes': ['ague', 'all-overs', 'blue johnnies', 'blue devils', 'bumpiness', 'chattering', 'chorea', 'cold shivers', 'cold sweat', 'didder', 'disquiet', 'disquietude'],
    'shaking': ['agitated', 'ague', 'all shook up', 'all-overish', 'aquiver', 'aspen', 'blurred', 'brandish', 'brandishing', 'breathy', 'bumpiness', 'chattering'],
    'shaky': ['adrift', 'afloat', 'agitated', 'aguey', 'aguish', 'algid', 'all shook up', 'all-overish', 'anile', 'aquiver', 'aspen', 'bagging'],
    'shallow': ['airy', 'amateur', 'amateurish', 'ankle-deep', 'asinine', 'bank', 'bar', 'birdbrained', 'birdwitted', 'catchpenny', 'coral reef', 'cursory'],
    'shallowness': ['a little learning', 'absentmindedness', 'amateurism', 'appearance', 'big deal', 'carelessness', 'dilettantism', 'dilettantship', 'disregard', 'disregardfulness', 'distraction', 'emptiness'],
    'sham': ['tartuffery', 'tartuffism', 'act', 'act a part', 'acting', 'adulterated', 'affect', 'affectation', 'affected', 'affectedness', 'airs', 'airs and graces'],
    'shamble': ['amble', 'andante', 'barge', 'bowl along', 'bundle', 'claudication', 'clump', 'crawl', 'creep', 'dead march', 'dogtrot', 'drag'],
    'shambles': ['augean stables', 'belsen', 'dmz', 'abattoir', 'aceldama', 'battle line', 'battle site', 'battlefield', 'battleground', 'bloodbath', 'blue ruin', 'botch'],
    'shame': ['abasement', 'abash', 'abashment', 'abomination', 'apologies', 'atrocity', 'attrition', 'ayenbite of inwit', 'bad', 'besmirch', 'bitterness', 'blacken'],
    'shamed': ['abashed', 'ashamed', 'at a discount', 'blushing', 'chagrined', 'chapfallen', 'crestfallen', 'crushed', 'discredited', 'disgraced', 'embarrassed', 'hangdog'],
    'shamefaced': ['abashed', 'ashamed', 'bashful', 'blushing', 'chagrined', 'chapfallen', 'chastened', 'confused', 'conscience-smitten', 'conscience-stricken', 'conscious', 'coy'],
    'shameful': ['aberrant', 'abnormal', 'abominable', 'arrant', 'ashamed', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beneath contempt', 'beneath one'],
    'shameless': ['abandoned', 'aberrant', 'abnormal', 'abominable', 'amoral', 'arrant', 'atrocious', 'audacious', 'aweless', 'barefaced', 'blatant', 'bold'],
    'shampoo': ['ablution', 'abstergent', 'baptize', 'bath', 'bathe', 'cathartic', 'cleaner', 'cleaning agent', 'cleaning out', 'cleaning solvent', 'cleanser', 'cleansing cream'],
    'shamrock': ['armory', 'badge', 'badge of office', 'badges', 'baton', 'blazonry', 'brassard', 'button', 'cap and gown', 'chain', 'chain of office', 'class ring'],
    'shanghai': ['abduce', 'abduct', 'blackjack', 'bludgeon', 'bulldoze', 'bully', 'carry away', 'carry off', 'coerce', 'crimp', 'dragoon', 'hijack'],
    'shangri la': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley'],
    'shank': ['chateaubriand', 'ankle', 'ascender', 'back', 'bastard type', 'bayonet legs', 'beard', 'belly', 'bevel', 'black letter', 'blade roast', 'body'],
    'shanty': ['nissen hut', 'quonset hut', 'booth', 'box', 'cabin', 'caboose', 'camp', 'cot', 'cottage', 'crib', 'gatehouse', 'hut'],
    'shapable': ['adaptable', 'bendable', 'bending', 'compliant', 'ductile', 'elastic', 'extensible', 'extensile', 'fabricable', 'facile', 'fictile', 'flexible'],
    'shape': ['masan', 'platonic form', 'platonic idea', 'accommodate', 'accommodate with', 'accord', 'adapt', 'adapt to', 'adjust', 'adjust to', 'adjustment', 'aesthetic form'],
    'shape up': ['advance', 'ameliorate', 'amend', 'be so', 'be such', 'come along', 'come on', 'come out', 'come through', 'come together', 'contrive', 'crystallize'],
    'shaped': ['arranged', 'assembled', 'blueprinted', 'built', 'calculated', 'cast', 'charted', 'constructed', 'contrived', 'crafted', 'created', 'custom'],
    'shapeless': ['aberrant', 'abnormal', 'adrift', 'afloat', 'aimless', 'aleatoric', 'aleatory', 'alternating', 'amorphic', 'amorphous', 'anarchic', 'anomalistic'],
    'shapely': ['junoesque', 'agreeable', 'amply endowed', 'balanced', 'becoming', 'bonny', 'braw', 'built', 'built for comfort', 'buxom', 'callipygian', 'callipygous'],
    'shard': ['abrade', 'atomize', 'beat', 'bit', 'bones', 'bray', 'break', 'brecciate', 'butt', 'chaff', 'chip', 'chunk'],
    'share': ['adjunct', 'allocate', 'allocation', 'allot', 'allotment', 'allowance', 'apportion', 'apportionment', 'appropriate', 'appropriation', 'assign', 'be affected'],
    'sharecropper': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'coffee-planter', 'collective farm worker', 'crofter', 'cropper', 'cultivator', 'dirt farmer', 'dry farmer'],
    'sharecropping': ['agrarianism', 'agricultural geology', 'agriculture', 'agrology', 'agronomics', 'agronomy', 'collective farm', 'collectivism', 'collectivity', 'collegiality', 'common ownership', 'communal effort'],
    'sharing': ['accessory', 'accord', 'accordance', 'affiliation', 'affinity', 'agape', 'agreement', 'amity', 'announcement', 'apportionment', 'association', 'bonds of harmony'],
    'shark': ['admirable crichton', 'loch ness monster', 'reptilia', 'adept', 'alevin', 'animal', 'anthropophagite', 'artisan', 'artist', 'attache', 'authority', 'barbarian'],
    'sharp': ['admirable crichton', 'attic', 'machiavellian', 'machiavellic', 'siberian', 'v-shaped', 'y-shaped', 'abrupt', 'abruptly', 'absonant', 'absorbing', 'accidental'],
    'sharp eye': ['x-ray eye', 'custodianship', 'custody', 'eagle eye', 'gimlet eye', 'guard', 'guardedness', 'guardianship', 'invigilation', 'keen eye', 'lookout', 'monitoring'],
    'sharp eyed': ['argus-eyed', 'alert', 'all ears', 'all eyes', 'attentive', 'aux aguets', 'aware', 'cat-eyed', 'clear-eyed', 'clear-sighted', 'custodial', 'eagle-eyed'],
    'sharpen': ['accelerate', 'aculeate', 'acuminate', 'agent provocateur', 'aggravate', 'amplify', 'animate', 'annoy', 'augment', 'barb', 'beef up', 'blow up'],
    'sharpener': ['ax', 'blade', 'cold steel', 'cutlery', 'cutter', 'dagger', 'edge tools', 'emery', 'file', 'grindstone', 'hone', 'knife'],
    'sharper': ['adventurer', 'betting ring', 'bettor', 'boneshaker', 'bunco artist', 'bunco steerer', 'cardshark', 'cardsharp', 'cardsharper', 'carpetbagger', 'cheat', 'compulsive gambler'],
    'sharply': ['abruptly', 'acerbically', 'acutely', 'angrily', 'closely', 'cuttingly', 'definitely', 'definitively', 'distinctly', 'firmly', 'harshly', 'intensely'],
    'sharpness': ['italian hand', 'abruptness', 'absolute zero', 'acerbity', 'acidity', 'acidness', 'acidulousness', 'acridity', 'acridness', 'acrimony', 'acuity', 'acuteness'],
    'sharpshooter': ['nimrod', 'zouave', 'archer', 'artilleryman', 'bersagliere', 'bowman', 'cannoneer', 'carabineer', 'chasseur', 'crack shot', 'dead shot', 'deadeye'],
    'shatter': ['agitate', 'annihilate', 'atomize', 'blast', 'break', 'break into pieces', 'break to pieces', 'break up', 'burst', 'clack', 'clatter', 'cleave'],
    'shattered': ['aggravated', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped', 'cracked', 'crazed', 'cut', 'damaged', 'deteriorated'],
    'shatterproof': ['airtight', 'ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'chip-proof', 'corrosionproof', 'dampproof', 'fire-resisting', 'fireproof', 'flameproof', 'foolproof'],
    'shave': ['abate', 'abbreviate', 'abrade', 'abridge', 'abscind', 'abstract', 'amputate', 'annihilate', 'ban', 'bar', 'bate', 'beat'],
    'shaved': ['abbreviated', 'abridged', 'abstracted', 'bobbed', 'capsule', 'capsulized', 'clipped', 'compressed', 'condensed', 'cropped', 'curtailed', 'cut short'],
    'shaving': ['acomia', 'afterglow', 'afterimage', 'alopecia', 'balance', 'baldhead', 'baldness', 'baldpate', 'baldy', 'beardlessness', 'bit', 'bones'],
    'she': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'ego', 'ethical self', 'female', 'female being', 'he', 'her', 'herself'],
    'sheaf': ['bale', 'bindle', 'bolt', 'bouquet', 'budget', 'bundle', 'deck', 'fagot', 'fardel', 'fasces', 'fascine', 'nosegay'],
    'shear': ['abbreviate', 'abridge', 'abscind', 'abstract', 'amputate', 'annihilate', 'ban', 'bar', 'barb', 'barber', 'bare', 'bleed'],
    'sheared': ['abbreviated', 'abridged', 'abstracted', 'bobbed', 'capsule', 'capsulized', 'clipped', 'compressed', 'condensed', 'cropped', 'curtailed', 'cut short'],
    'sheath': ['leatherette', 'leatheroid', 'case', 'casing', 'coat', 'cuticle', 'dermis', 'encasement', 'fell', 'fleece', 'flesh', 'fur'],
    'sheathe': ['apparel', 'array', 'attire', 'bedeck', 'bedrape', 'board', 'box', 'brick', 'bundle up', 'case', 'clad', 'clapboard'],
    'sheathed': ['armored', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'coped', 'covered', 'covert', 'cowled', 'curtained', 'eclipsed'],
    'sheathing': ['beam', 'billet', 'blanketing', 'blocking', 'blotting out', 'board', 'boarding', 'case', 'casing', 'cementwork', 'clapboard', 'cloaking'],
    'shed': ['nissen hut', 'quonset hut', 'abandon', 'addition', 'booth', 'cashier', 'cast', 'cast off', 'cote', 'crib', 'defoliate', 'desquamate'],
    'sheen': ['afterglow', 'air glow', 'brightness', 'burnish', 'candescence', 'dazzle', 'finish', 'flush', 'glaze', 'gleam', 'glimmer', 'glint'],
    'sheep': ['babbitt', 'columbia', 'karakul', 'kerry hill', 'lincoln', 'merino', 'middle american', 'panama', 'philistine', 'romeldale', 'romney', 'suffolk'],
    'sheepish': ['abject', 'amenable', 'apologetic', 'asinine', 'blushful', 'blushing', 'bovid', 'bovine', 'caprid', 'caprine', 'compliant', 'contrite'],
    'sheepishly': ['abjectly', 'apologetically', 'bashfully', 'blushingly', 'contritely', 'coyly', 'demurely', 'diffidently', 'guiltily', 'humbly', 'penitentially', 'penitently'],
    'sheepskin': ['affidavit', 'attestation', 'authority', 'authorization', 'bill of health', 'certificate', 'certificate of proficiency', 'certification', 'credential', 'deposition', 'diploma', 'navicert'],
    'sheer': ['aberrancy', 'aberration', 'about ship', 'abrupt', 'absolute', 'absolutely', 'airy', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'angle'],
    'sheer off': ['about the bush', 'avert', 'avoid', 'bear off', 'beat around', 'beg the question', 'blench', 'blink', 'cringe', 'dodge', 'draw aside', 'draw back'],
    'sheet': ['afghan', 'alabaster', 'area', 'article', 'back matter', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedsheet', 'bedspread', 'blanket'],
    'sheeting': ['afghan', 'beam', 'bed linen', 'bedclothes', 'bedcover', 'bedding', 'bedsheet', 'bedspread', 'billet', 'blanket', 'board', 'boarding'],
    'sheik': ['casanova', 'don juan', 'lothario', 'romeo', 'amoroso', 'beau', 'boyfriend', 'caballero', 'cavalier', 'cavaliere servente', 'esquire', 'fellow'],
    'sheikh': ['dalai lama', 'holy roman emperor', 'inca', 'kaiser', 'muslim rulers', 'prinz', 'abdal', 'ardri', 'atheling', 'bey', 'cacique', 'caesar'],
    'shelf': ['archives', 'armory', 'arsenal', 'attic', 'band', 'bank', 'bar', 'basement', 'bay', 'beam-end', 'bed', 'bedding'],
    'shell': ['eustachian tube', 'acting area', 'aim at', 'alveolation', 'alveolus', 'ante up', 'antrum', 'anvil', 'apron', 'apron stage', 'armadillo shell', 'armature'],
    'shell game': ['bingo', 'boiler room', 'bucket shop', 'bunco game', 'card games', 'chuck and toss', 'chuck farthing', 'chuck-a-luck', 'con game', 'confidence game', 'crack-loo', 'crap game'],
    'shell out': ['accord', 'administer', 'afford', 'allot', 'allow', 'award', 'bestow', 'bestow on', 'budget', 'communicate', 'confer', 'cost'],
    'shell shock': ['accident neurosis', 'anaphylactic shock', 'anxiety hysteria', 'anxiety neurosis', 'association neurosis', 'battle fatigue', 'blast neurosis', 'combat fatigue', 'compensation neurosis', 'compulsion neurosis', 'conversion hysteria', 'conversion neurosis'],
    'shellac': ['apply paint', 'beat', 'bedaub', 'bedizen', 'begild', 'besmear', 'blank', 'brush on paint', 'bulldoze', 'calcimine', 'clobber', 'coat'],
    'shellacking': ['beating', 'calcimining', 'clobbering', 'coating', 'covering', 'crushing defeat', 'debacle', 'decisive defeat', 'defeasance', 'drubbing', 'enameling', 'fresco'],
    'shellfire': ['antiaircraft fire', 'cross fire', 'curtain fire', 'direct fire', 'dry fire', 'file fire', 'fire', 'fire of demolition', 'firepower', 'fireworks', 'firing', 'flack'],
    'shellfish': ['dungeness crab', 'japanese crab', 'blue point', 'clam', 'coquillage', 'crab', 'crawdad', 'crawfish', 'crayfish', 'langouste', 'limpet', 'littleneck clam'],
    'shelter': ['abri', 'accommodation', 'accommodations', 'air-raid shelter', 'arm', 'armor', 'asylum', 'bed', 'berth', 'billet', 'blanket', 'bless'],
    'sheltered': ['armed', 'at rest', 'calm', 'cloaked', 'cloistered', 'cool', 'copyrighted', 'covered', 'defended', 'dwindling', 'ebbing', 'even-tenored'],
    'sheltering': ['covering', 'custodial', 'defensive', 'fostering', 'guardian', 'guarding', 'immunizing', 'parental', 'preventive', 'prophylactic', 'protecting', 'protective'],
    'shelve': ['adjourn', 'ascend', 'bank', 'cant', 'careen', 'climb', 'continue', 'decline', 'defer', 'delay', 'descend', 'dip'],
    'shelved': ['abandoned', 'deserted', 'disregarded', 'half-done', 'ignored', 'laid aside', 'left undone', 'missed', 'neglected', 'omitted', 'overlooked', 'passed by'],
    'shenanigan': ['antic', 'caper', 'device', 'fast one', 'frolic', 'game', 'gimmick', 'goings-on', 'lark', 'legerdemain', 'maneuver', 'mischievousness'],
    'shepherd': ['dd', 'doctor of divinity', 'gyropilot', 'holy joe', 'abbe', 'air warden', 'attend', 'attend to', 'attendant', 'automatic pilot', 'baby-sit', 'boatheader'],
    'sheriff': ['g-man', 'mp', 'bailiff', 'beadle', 'beagle', 'bound bailiff', 'captain', 'catchpole', 'chief of police', 'commissioner', 'constable', 'deputy'],
    'sherlock holmes': ['bow street runner', 'fbi', 'fbi agent', 'federal', 'g-man', 'secret service', 'sherlock', 't-man', 'detective', 'dick', 'eye', 'fed'],
    'shibboleth': ['banality', 'bromide', 'byword', 'catch phrase', 'catchword', 'cliche', 'countersign', 'cry', 'fad word', 'jargon', 'open sesame', 'password'],
    'shield': ['achievement', 'advocate', 'aegis', 'alerion', 'animal charge', 'annulet', 'apply to', 'argent', 'arm', 'arm guard', 'armament', 'armature'],
    'shielded': ['armed', 'armored', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'coped', 'copyrighted', 'covered', 'covert', 'cowled'],
    'shielding': ['blanketing', 'cloaking', 'coating', 'covering', 'custodial', 'defending', 'defensive', 'enveloping', 'fostering', 'guardian', 'guarding', 'immunizing'],
    'shift': ['doppler effect', 'aberrancy', 'aberration', 'about ship', 'about the bush', 'about-face', 'accommodation', 'action', 'ad hoc measure', 'adaptation', 'adjustment', 'advance'],
    'shifting': ['aberrancy', 'aberrant', 'aberration', 'aberrative', 'adrift', 'afloat', 'alternating', 'alternation', 'amorphous', 'bend', 'bias', 'bickering'],
    'shiftless': ['aimless', 'bone-lazy', 'cadging', 'dilatory', 'do-nothing', 'doless', 'dronish', 'drony', 'easy', 'ergophobic', 'faineant', 'feckless'],
    'shiftlessness': ['dilatoriness', 'do-nothingness', 'ergophobia', 'faineancy', 'faineantise', 'fecklessness', 'hastiness', 'heedlessness', 'hoboism', 'improvidence', 'indolence', 'inertia'],
    'shifty': ['machiavellian', 'machiavellic', 'acute', 'adrift', 'afloat', 'alternating', 'ambidextrous', 'amoral', 'amorphous', 'arch', 'artful', 'astute'],
    'shill': ['agent provocateur', 'bid', 'bid in', 'bid up', 'blind', 'bonnet', 'booster', 'by-bidder', 'capper', 'come-on man', 'decoy', 'make a bid'],
    'shillelagh': ['malacca cane', 'alpenstock', 'bat', 'baton', 'billy', 'billy club', 'bludgeon', 'cane', 'club', 'crook', 'crosier', 'cross'],
    'shilling': ['deutschmark', 'mark', 'reichsmark', 'afghani', 'anna', 'baht', 'bawbee', 'cent', 'centavo', 'centime', 'conto', 'crown'],
    'shilly shally': ['alternate', 'back and fill', 'back down', 'balance', 'change', 'dally', 'dawdle', 'debate', 'delay', 'deliberate', 'demur', 'dillydally'],
    'shilly shallying': ['caution', 'cautious', 'cautiousness', 'dalliance', 'dallying', 'dawdling', 'delaying', 'demurring', 'diffidence', 'diffident', 'dilatoriness', 'dilatory'],
    'shimmer': ['blink', 'blinking', 'coruscate', 'coruscation', 'firefly', 'flicker', 'gleam', 'glimmer', 'glimmering', 'glint', 'glisk', 'glisten'],
    'shimmering': ['blink', 'blinking', 'blinky', 'coruscant', 'coruscating', 'coruscation', 'firefly', 'glimmer', 'glimmering', 'glimmerous', 'glimmery', 'glisten'],
    'shin': ['ankle', 'bayonet legs', 'bowlegs', 'calf', 'clamber', 'clamber up', 'climb', 'climb over', 'climb up', 'cnemis', 'dash', 'drumstick'],
    'shindig': ['kaffeeklatsch', 'affair', 'assemblee', 'assembly', 'assignation', 'at home', 'bal', 'bal costume', 'bal masque', 'ball', 'barn dance', 'bash'],
    'shindy': ['bedlam let loose', 'kaffeeklatsch', 'ado', 'bal', 'bal costume', 'bal masque', 'ball', 'barn dance', 'barney', 'bash', 'bedlam', 'blast'],
    'shine': ['amor', 'christian love', 'eros', 'platonic love', 'admiration', 'adoration', 'affection', 'afterglow', 'agape', 'air glow', 'antic', 'ardency'],
    'shine up to': ['act up to', 'agree to anything', 'approach', 'break the ice', 'brown-nose', 'court', 'cultivate', 'curry favor', 'dance attendance on', 'fall all over', 'fall over', 'fawn upon'],
    'shingle': ['arch over', 'bank', 'barber', 'beach', 'beam', 'berm', 'bestraddle', 'bestride', 'billet', 'board', 'boarding', 'bob'],
    'shingled': ['arenaceous', 'arenarious', 'breccial', 'brecciated', 'bridging', 'craggy', 'crystal', 'crystalline', 'grainy', 'granular', 'granulate', 'granulated'],
    'shingles': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'ms', 'acne', 'acne vulgaris', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis'],
    'shining': ['aglow', 'beaming', 'beamy', 'blooming', 'blushing', 'bright', 'bright and sunny', 'brilliant', 'burning', 'burnished', 'candescent', 'charismatic'],
    'shiny': ['aglow', 'beaming', 'beamy', 'bleached', 'blushing', 'bright', 'bright and sunny', 'buffed', 'burning', 'burnished', 'candescent', 'clean'],
    'ship': ['graf zeppelin', 'address', 'aeroplane', 'aerostat', 'air-express', 'aircraft', 'airfreight', 'airmail', 'airplane', 'airship', 'argosy', 'ark'],
    'shipmate': ['ace', 'amigo', 'associate', 'bedfellow', 'bedmate', 'birthmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty', 'camarade'],
    'shipment': ['air express', 'airfreight', 'airlift', 'asportation', 'baggage', 'bearing', 'cargo', 'carriage', 'carry', 'carrying', 'cartage', 'consignment'],
    'shipper': ['aquarius', 'ganymede', 'hebe', 'bearer', 'bheesty', 'busboy', 'caddie', 'cargo handler', 'carrier', 'carrier pigeon', 'carter', 'common carrier'],
    'shipping': ['air express', 'airfreight', 'airlift', 'argosy', 'asportation', 'bearing', 'bottoms', 'carriage', 'carry', 'carrying', 'cartage', 'conveyance'],
    'shipshape': ['all ataunto', 'anal', 'ataunt', 'bungup and bilge-free', 'chipper', 'dinky', 'neat', 'orderly', 'sleek', 'slick', 'smart', 'snug'],
    'shipwreck': ['accident', 'beach', 'blow', 'break up', 'breakdown', 'breaking up', 'breakup', 'bring to ruin', 'calamity', 'capsize', 'cast away', 'casualty'],
    'shipyard': ['anchorage', 'anchorage ground', 'armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'basin', 'berth', 'bindery', 'boatyard', 'boilery'],
    'shire': ['kreis', 'archbishopric', 'archdiocese', 'arrondissement', 'bailiwick', 'bishopric', 'borough', 'canton', 'city', 'commune', 'congressional district', 'constablewick'],
    'shirk': ['abandon', 'avoid', 'bilk', 'burke', 'bypass', 'creep', 'cut', 'dodge', 'dog it', 'double', 'duck', 'duck duty'],
    'shirker': ['bungler', 'clock watcher', 'disregarder', 'dodger', 'eye-servant', 'goldbrick', 'goldbricker', 'goof-off', 'idler', 'ignorer', 'malingerer', 'neglecter'],
    'shirr': ['bake', 'barbecue', 'baste', 'blanch', 'boil', 'braise', 'brew', 'broil', 'brown', 'cocker', 'cockle', 'coddle'],
    'shirt': ['basque', 'blouse', 'bodice', 'body shirt', 'body suit', 'coat shirt', 'corsage', 'dickey', 'doublet', 'dress shirt', 'evening shirt', 'gipon'],
    'shit': ['amytal', 'amytal pill', 'bm', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'sob', 'seconal'],
    'shitty': ['barfy', 'bum', 'cheesy', 'crappy', 'creepy', 'crummy', 'dirty', 'disgusting', 'dungy', 'excremental', 'excrementary', 'fecal'],
    'shiva': ['agni', 'asvins', 'atman', 'avalokita', 'bhairava', 'bhairavi', 'brahma', 'chandi', 'daksha', 'devaki', 'devi', 'dharma'],
    'shiver': ['ache', 'aching', 'agitation', 'all-overs', 'atomize', 'bang', 'be cold', 'bit', 'bob', 'bobble', 'boot', 'bounce'],
    'shivering': ['ache', 'aching', 'agitated', 'ague', 'aguey', 'aguish', 'algid', 'all shook up', 'all-overish', 'aspen', 'blue with cold', 'bumpiness'],
    'shivery': ['agitated', 'aguey', 'aguish', 'algid', 'all shook up', 'all-overish', 'aquiver', 'arctic', 'aspen', 'bashful', 'blue with cold', 'breakable'],
    'shoal': ['a mass of', 'a world of', 'ankle-deep', 'army', 'bank', 'bar', 'barrier', 'bevy', 'bunch', 'cloud', 'clutter', 'colony'],
    'shock': ['ac arc', 'poulsen arc', 'abscess', 'accident', 'ache', 'aching', 'agitate', 'ague', 'amplify', 'anaphylactic shock', 'anemia', 'ankylosis'],
    'shock absorber': ['alleviative', 'alleviator', 'anodyne', 'assuager', 'balm', 'calmative', 'cushion', 'dolorifuge', 'lenitive', 'mitigator', 'moderator', 'modulator'],
    'shock tactics': ['aerial tactics', 'aggravated assault', 'aggression', 'airborne tactics', 'amphibious attack', 'applied tactics', 'armed assault', 'armored tactics', 'assailing', 'assailment', 'assault', 'attack'],
    'shock therapy': ['metrazol shock therapy', 'metrazol therapy', 'x-ray therapy', 'actinotherapy', 'aerosol therapy', 'aerotherapeutics', 'aerotherapy', 'arsenotherapy', 'autoserum therapy', 'bacterial therapy', 'bacteriotherapy', 'bibliotherapy'],
    'shocked': ['agape', 'appalled', 'bowled down', 'confounded', 'dismayed', 'dumbfounded', 'electrified', 'horrified', 'jarred', 'jolted', 'offended', 'outraged'],
    'shocker': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'apologue', 'astonishment', 'bedtime story', 'blockbuster', 'blow', 'bomb'],
    'shocking': ['abhorrent', 'abominable', 'abrupt', 'absolute', 'amazing', 'appalling', 'arrant', 'astonishing', 'astounding', 'atrocious', 'awe-inspiring', 'awesome'],
    'shod': ['appareled', 'arrayed', 'attired', 'bedecked', 'breeched', 'capped', 'chausse', 'clad', 'cloaked', 'clothed', 'coifed', 'costumed'],
    'shoddy': ['ng', 'abject', 'abominable', 'affected', 'apocryphal', 'arrant', 'artificial', 'assumed', 'atrocious', 'awful', 'base', 'bastard'],
    'shoe': ['bonnet', 'boot', 'boots', 'breech', 'cap', 'chaussure', 'cloak', 'clodhoppers', 'coat', 'coif', 'footgear', 'footwear'],
    'shofar': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'ark', 'asperger', 'bambino', 'beadroll', 'beads', 'candle'],
    'shogun': ['dalai lama', 'holy roman emperor', 'inca', 'kaiser', 'ardri', 'bey', 'cacique', 'caesar', 'cham', 'czar', 'kaid', 'khan'],
    'shoo in': ['champ', 'champion', 'cinch', 'conquering hero', 'conqueror', 'conquistador', 'defeater', 'easy winner', 'hero', 'master', 'natural', 'pancratiast'],
    'shook': ['balled-up', 'bothered', 'bowled down', 'chaotic', 'confused', 'discomposed', 'disconcerted', 'disordered', 'disorganized', 'disturbed', 'electrified', 'embarrassed'],
    'shoot': ['photostat', 'x-ray', 'xerox', 'ache', 'acute pain', 'agonize', 'ail', 'aim at', 'altitude peak', 'anguish', 'annihilate', 'assassinate'],
    'shoot ahead': ['bestride', 'bypass', 'cross', 'dart ahead', 'dash ahead', 'distance', 'drive', 'drive on', 'ford', 'forge ahead', 'get ahead of', 'go across'],
    'shoot down': ['ko', 'blow to pieces', 'blow up', 'brain', 'bring down', 'burn to death', 'call off', 'cancel', 'charge', 'cock', 'complete', 'cook'],
    'shoot out': ['antiaircraft fire', 'cross fire', 'curtain fire', 'direct fire', 'dry fire', 'file fire', 'fire', 'fire of demolition', 'firepower', 'fireworks', 'firing', 'flack'],
    'shoot up': ['accrue', 'accumulate', 'advance', 'appreciate', 'balloon', 'bloat', 'blossom', 'bob up', 'boom', 'break water', 'breed', 'brew'],
    'shooting': ['acute', 'acute pain', 'afflictive', 'agonizing', 'antiaircraft fire', 'archery', 'atrocious', 'bane', 'beheading', 'bite', 'biting', 'blood'],
    'shooting star': ['aerolite', 'angry clouds', 'black cat', 'black clouds', 'bolide', 'broken mirror', 'chondrite', 'cosmic dust', 'fireball', 'gathering clouds', 'halcyon bird', 'meteor'],
    'shop': ['agency', 'atelier', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'betray', 'booking office', 'boutique', 'box office', 'branch', 'branch office'],
    'shopkeeper': ['bourgeoisie', 'chandler', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty', 'commoners', 'commons', 'dealer', 'distributor'],
    'shoplift': ['abstract', 'and', 'annex', 'appropriate', 'bag', 'boost', 'borrow', 'cop', 'crib', 'defraud', 'embezzle', 'extort'],
    'shoplifter': ['body snatcher', 'booster', 'chicken thief', 'con man', 'crook', 'den of thieves', 'embezzler', 'filcher', 'ganef', 'ghoul', 'grafter', 'grave robber'],
    'shopping': ['buy', 'buying', 'buying power', 'buying up', 'catalog buying', 'coemption', 'consumer power', 'consumer sovereignty', 'consumerism', 'cornering', 'emption', 'hire purchase'],
    'shopping center': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'art center', 'auto show', 'barrio', 'bazaar'],
    'shoptalk': ['varietyese', 'wall streetese', 'washingtonese', 'business english', 'businessese', 'cinemese', 'collegese', 'commercialism', 'computerese', 'economese', 'federalese', 'journalese'],
    'shopworn': ['bare', 'cliche', 'cliched', 'deep-worn', 'dog-eared', 'hackneyed', 'overused', 'overworked', 'sere', 'shelfworn', 'stale', 'threadbare'],
    'shoran': ['gyrosin compass', 'rdf', 'var', 'astronavigation', 'celestial navigation', 'chronometer', 'coastwise navigation', 'compass', 'consolan', 'dead reckoning', 'direction finder', 'electronic navigation'],
    'shore': ['afford support', 'aquatic', 'back', 'back up', 'balneal', 'bank', 'beach', 'beam', 'bear', 'bear out', 'bear up', 'berm'],
    'shore up': ['afford support', 'back', 'back up', 'bear', 'bear out', 'bear up', 'beef up', 'bolster', 'bolster up', 'brace', 'brace up', 'buoy up'],
    'shorn': ['abated', 'ablated', 'attenuated', 'bated', 'belittled', 'bereaved', 'bereaved of', 'bereft', 'consumed', 'contracted', 'curtailed', 'cut off'],
    'short': ['bermuda shorts', 'cinemascope', 'cinerama', 'spartan', 'technicolor', 'western', 'aback', 'abbreviate', 'abbreviated', 'abridged', 'abrupt', 'abruptly'],
    'short circuit': ['amplify', 'break', 'broken circuit', 'charge', 'circuit', 'circuital field', 'closed circuit', 'complete circuit', 'dead circuit', 'electrify', 'energize', 'galvanic circuit'],
    'short lived': ['brittle', 'capricious', 'changeable', 'corruptible', 'deciduous', 'dying', 'ephemeral', 'evanescent', 'fading', 'fickle', 'fleeting', 'flitting'],
    'short of': ['at a disadvantage', 'at the nadir', 'bankrupt in', 'bare of', 'below', 'below the mark', 'bereft of', 'deficient', 'denuded of', 'deprived of', 'destitute of', 'devoid of'],
    'short shrift': ['cruelty', 'flat refusal', 'flintiness', 'hardness', 'harshness', 'heartlessness', 'inclemency', 'inexorableness', 'mercilessness', 'pitilessness', 'point-blank refusal', 'rebuff'],
    'short story': ['bildungsroman', 'gothic novel', 'comic novel', 'detective novel', 'dime novel', 'dreadful', 'epistolary novel', 'erotic novel', 'historical novel', 'nouvelle', 'novel', 'novel of character'],
    'short-sighted': ['brash', 'careless', 'dim-sighted', 'heedless', 'impolitic', 'improvident', 'imprudent', 'impulsive', 'incautious', 'injudicious', 'limited', 'myopic'],
    'short-tempered': ['abrupt', 'acerbic', 'acid', 'acidulous', 'acrimonious', 'bearish', 'bluff', 'brusque', 'caustic', 'crabbed', 'crabby', 'crusty'],
    'shortage': ['absence', 'adulteration', 'arrear', 'arrearage', 'arrears', 'beggary', 'break', 'curtailment', 'dearth', 'decline', 'defalcation', 'default'],
    'shortchange': ['beat', 'beguile of', 'bilk', 'bunco', 'burn', 'cheat', 'chisel', 'chouse', 'chouse out of', 'cog', 'cog the dice', 'con'],
    'shortcoming': ['absence', 'adulteration', 'asymmetry', 'beggary', 'blemish', 'bug', 'catch', 'contrariety', 'crack', 'defect', 'defectibility', 'defection'],
    'shortcut': ['air lane', 'air line', 'axis', 'beat', 'beeline', 'bypass', 'chord', 'circuit', 'course', 'cut', 'cutoff', 'diagonal'],
    'shorten': ['abate', 'abbreviate', 'abrade', 'abridge', 'abstract', 'bate', 'be telegraphic', 'bob', 'bobtail', 'boil down', 'brief', 'capsule'],
    'shortened': ['spartan', 'abbreviated', 'abridged', 'abstracted', 'aposiopestic', 'bobbed', 'brief', 'brusque', 'capsule', 'capsulized', 'clipped', 'close'],
    'shorter': ['abated', 'ablated', 'attenuated', 'bated', 'belittled', 'consumed', 'contracted', 'curtailed', 'decreased', 'deflated', 'diminished', 'dissipated'],
    'shortfall': ['absence', 'arrear', 'arrearage', 'arrears', 'beggary', 'decline', 'defalcation', 'default', 'defectiveness', 'deficiency', 'deficit', 'delinquency'],
    'shorthand': ['speedwriting', 'arrowhead', 'autograph', 'autographic', 'brachygraphy', 'calligraphic', 'character', 'chirographic', 'contraction', 'cuneiform', 'cursive', 'demotic character'],
    'shorthanded': ['bare-handed', 'beggarly', 'empty-handed', 'famished', 'half-starved', 'ill off', 'ill-equipped', 'ill-furnished', 'ill-provided', 'impoverished', 'on short commons', 'pauperized'],
    'shortly': ['abruptly', 'after a while', 'anon', 'aphoristically', 'bearishly', 'before long', 'betimes', 'bluffly', 'bluntly', 'boorishly', 'brashly', 'briefly'],
    'shortsighted': ['asquint', 'astigmatic', 'authoritarian', 'bigot', 'bigoted', 'blind', 'blindfold', 'blindfolded', 'blink-eyed', 'blinking', 'blinky', 'borne'],
    'shortstop': ['amateur athlete', 'archer', 'athlete', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'blocking back', 'bowman', 'catcher', 'center'],
    'shortwave': ['audio-frequency', 'carrier', 'carrier wave', 'electric wave', 'electromagnetic wave', 'ground wave', 'hertzian wave', 'heterodyne', 'high-frequency', 'high-frequency wave', 'long wave', 'low-frequency wave'],
    'shot': ['nimrod', 'sol', 'telephoto', 'wirephoto', 'admission', 'admission fee', 'aerial photograph', 'all bets off', 'all off', 'all over', 'all up', 'altitude peak'],
    'shot put': ['bowl', 'cast', 'change of pace', 'change-up', 'chuck', 'chunk', 'curve', 'downcurve', 'fastball', 'fling', 'flip', 'forward pass'],
    'shot through': ['apertured', 'bicolor', 'bicolored', 'colorful', 'colory', 'crawling', 'crazy', 'creeping', 'crible', 'daedal', 'dichromatic', 'divers-colored'],
    'shotgun': ['automatic', 'blowgun', 'blowpipe', 'coerce', 'compel', 'concuss', 'constrain', 'firearm', 'flamethrower', 'gat', 'gun', 'handgun'],
    'should': ['be expedient', 'be forced', 'be in for', 'be necessary', 'be obliged', 'cannot do otherwise', 'cannot help but', 'had best', 'had better', 'have got to', 'have need to', 'have to'],
    'shoulder': ['chateaubriand', 'abutment', 'accept', 'advocate', 'afford support', 'alpenstock', 'ankle', 'arc-boutant', 'arm', 'arm in arm', 'articulation', 'as one'],
    'shout': ['homeric laughter', 'alleluia', 'aller sans dire', 'applaud', 'applause', 'bark', 'battle cry', 'bawl', 'be in stitches', 'be manifest', 'be no secret', 'bellow'],
    'shouting': ['bawling', 'blatant', 'boanergean', 'brawling', 'clamorous', 'clamoursome', 'crying', 'loudmouthed', 'noisy', 'obstreperous', 'openmouthed', 'screaming'],
    'shove': ['actuate', 'advance', 'assault', 'bear', 'bear upon', 'bearing', 'black-market', 'black-marketeer', 'boost', 'bootleg', 'bowl', 'buck'],
    'shove off': ['be off', 'bear off', 'beat it', 'begone', 'blow', 'buy it', 'cash in', 'check in', 'check out', 'clear out', 'croak', 'depart'],
    'shovel': ['backhoe', 'bail', 'bar spade', 'bore', 'bucket', 'burrow', 'coal shovel', 'cup', 'decant', 'delve', 'dig', 'dig out'],
    'shoving': ['bunt', 'butt', 'drive', 'driving', 'driving force', 'impulsion', 'motive', 'motive power', 'propellant', 'propelling', 'propelment', 'propulsion'],
    'show': ['grand guignol', 'passion play', 'prospero', 'tom show', 'accompany', 'accord', 'account for', 'acting', 'advertise', 'affect', 'affectation', 'affectedness'],
    'show business': ['amusement park', 'ballroom', 'cabaret', 'cafe chantant', 'cafe dansant', 'casino', 'dance floor', 'dance hall', 'dancing pavilion', 'entertainment industry', 'fun-fair', 'juke joint'],
    'show girl': ['artist', 'artiste', 'belly dancer', 'burlesque queen', 'chorine', 'chorus boy', 'chorus girl', 'conjurer', 'coryphee', 'dancer', 'dancing girl', 'ecdysiast'],
    'show off': ['boast', 'brag', 'brandish', 'display', 'disport', 'exhibit', 'exhibitionist', 'expose', 'flash', 'flaunt', 'flaunter', 'grandstand'],
    'show up': ['accomplish', 'achieve', 'appear', 'approach', 'arise', 'arrive', 'arrive at', 'arrive in', 'assister', 'attain', 'attain to', 'attend'],
    'showboat': ['elizabethan theater', 'globe theatre', 'greek theater', 'amphitheater', 'arena theater', 'auditorium', 'cabaret', 'circle theater', 'club', 'concert hall', 'exhibitionist', 'flaunter'],
    'showcase': ['counter', 'diaphane', 'display case', 'glass', 'glassware', 'light', 'notions counter', 'pane', 'pushcart', 'shopboard', 'shopwindow', 'stemware'],
    'showdown': ['antagonism', 'antipathy', 'antithesis', 'clashing', 'climax', 'collision', 'conflict', 'confrontation', 'contradiction', 'contradistinction', 'contraindication', 'contraposition'],
    'shower': ['finnish bath', 'japanese bath', 'kaffeeklatsch', 'russian bath', 'scotch mist', 'swedish bath', 'turkish bath', 'abound', 'abundance', 'accord', 'administer', 'aerosol'],
    'showing': ['christophanic', 'satanophanic', 'angelophanic', 'apocalyptic', 'apparent', 'apparition', 'appearance', 'appearing', 'arising', 'avatar', 'bared', 'beholdable'],
    'showing off': ['blazon', 'bravura', 'brilliancy', 'daring', 'dash', 'demonstration', 'display', 'dramatics', 'eclat', 'etalage', 'exhibition', 'exhibitionism'],
    'showman': ['mc', 'auteur', 'ballyhoo man', 'barker', 'callboy', 'costume designer', 'costumer', 'costumier', 'director', 'emcee', 'equestrian director', 'exhibitor'],
    'shown': ['ascertained', 'attested', 'authenticated', 'borne out', 'certified', 'circumstantiated', 'confirmed', 'corroborated', 'demonstrable', 'demonstrated', 'determined', 'displayable'],
    'shown up': ['belied', 'confounded', 'confuted', 'deflated', 'denied', 'discarded', 'discredited', 'dismissed', 'disproved', 'disputed', 'exploded', 'exposed'],
    'showy': ['byzantine', 'gongoresque', 'johnsonian', 'affected', 'arabesque', 'baroque', 'bedizened', 'big-sounding', 'brave', 'bravura', 'braw', 'chichi'],
    'shrapnel': ['ball', 'bar shot', 'bird shot', 'buckshot', 'bullet', 'cannon shot', 'cannonball', 'case shot', 'crossbar shot', 'duck shot', 'dumdum bullet', 'expanding bullet'],
    'shred': ['mystik tape', 'scotch tape', 'abrade', 'adhesive tape', 'atom', 'atomize', 'band', 'bandage', 'batten', 'beat', 'belt', 'bit'],
    'shredded': ['branny', 'chalklike', 'chalky', 'cleft', 'cloven', 'comminute', 'comminuted', 'cracked', 'crushed', 'cut', 'detrital', 'detrited'],
    'shrew': ['chiroptera', 'lagomorpha', 'primates', 'rodentia', 'xanthippe', 'amazon', 'banshee', 'battle-ax', 'beldam', 'bitch', 'cat', 'common scold'],
    'shrewd': ['byzantine', 'daedalian', 'machiavellian', 'machiavellic', 'acute', 'all-knowing', 'apperceptive', 'appercipient', 'apprehending', 'apprehensive', 'arch', 'artful'],
    'shrewdness': ['italian hand', 'acumen', 'acuteness', 'animal cunning', 'art', 'artfulness', 'artifice', 'astuteness', 'cageyness', 'callidity', 'canniness', 'cleverness'],
    'shrewish': ['aggressive', 'bellicose', 'belligerent', 'beyond control', 'bickering', 'breachy', 'catty', 'combative', 'contumacious', 'defiant', 'disputatious', 'divisive'],
    'shriek': ['homeric laughter', 'bark', 'battle cry', 'bawl', 'bay', 'be in stitches', 'beep', 'bell', 'bellow', 'belly laugh', 'blare', 'blast'],
    'shrieking': ['acute', 'argute', 'blinding', 'creaky', 'crude', 'ear-piercing', 'flaring', 'flashy', 'flaunting', 'garish', 'gaudy', 'glaring'],
    'shrift': ['absolution', 'acknowledgment', 'admission', 'amnesty', 'avowal', 'concession', 'confession', 'exculpation', 'excuse', 'exemption', 'exoneration', 'grace'],
    'shrill': ['absonant', 'acute', 'argute', 'atonal', 'cacophonous', 'caterwaul', 'cracked', 'creak', 'creaky', 'diaphonic', 'disconsonant', 'discordant'],
    'shrimp': ['chilopoda', 'chordata', 'dungeness crab', 'echiuroidea', 'ectoprocta', 'entoprocta', 'japanese crab', 'lilliputian', 'monoplacophora', 'nemertinea', 'phoronidea', 'tom thumb'],
    'shrine': ['arch', 'barrow', 'beehive tomb', 'bone house', 'boundary stone', 'box grave', 'brass', 'burial', 'burial chamber', 'burial mound', 'bust', 'cairn'],
    'shrink': ['sanforize', 'abate', 'ablate', 'about the bush', 'ache', 'agonize', 'ail', 'analyst', 'anguish', 'attenuate', 'avoid', 'avoid the limelight'],
    'shrinkage': ['sanforizing', 'ablation', 'atrophy', 'attenuation', 'attrition', 'consumption', 'corrosion', 'curtailment', 'cut', 'cutting', 'decrease', 'decrement'],
    'shrinking': ['olympian', 'sanforizing', 'aloof', 'aseptic', 'atrophy', 'attenuation', 'backward', 'bashful', 'bashfulness', 'blank', 'boggle', 'boggling'],
    'shrive': ['absolve', 'acquit', 'administer absolution', 'administer extreme unction', 'amnesty', 'clear', 'confess', 'decontaminate', 'destigmatize', 'discharge', 'dismiss', 'dispense from'],
    'shrivel': ['sanforize', 'age', 'air-dry', 'anhydrate', 'attenuate', 'bake', 'blot', 'brush', 'burn', 'cheat the undertaker', 'consume', 'contract'],
    'shriveled': ['lilliputian', 'sanforized', 'tom thumb', 'adust', 'anile', 'atrophied', 'attenuated', 'baked', 'brittle', 'burnt', 'cadaverous', 'consumed'],
    'shroud': ['advocate', 'alpenstock', 'apparel', 'arm', 'armor', 'array', 'athletic supporter', 'attire', 'back', 'backbone', 'backing', 'bandeau'],
    'shrouded': ['armored', 'buried', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'concealed', 'coped', 'covered', 'covert', 'cowled'],
    'shrove tuesday': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas'],
    'shrub': ['persian berry', 'alder', 'azalea', 'bayberry', 'blackberry', 'blackthorn', 'box', 'bramble', 'brier', 'brier bush', 'broom', 'bush'],
    'shrubbery': ['japanese garden', 'alpine garden', 'arboretum', 'bed', 'bog garden', 'border', 'botanical garden', 'bracken', 'brake', 'bramble', 'brier', 'brier bush'],
    'shrug': ['accept', 'bearing', 'beck', 'beckon', 'body language', 'carriage', 'charade', 'chironomy', 'condone', 'countenance', 'dactylology', 'deaf-and-dumb alphabet'],
    'shrug off': ['abandon', 'belittle', 'brush aside', 'brush off', 'care nothing for', 'deprecate', 'depreciate', 'dismiss', 'disparage', 'drop the subject', 'forget', 'forget about it'],
    'shrunken': ['lilliputian', 'sanforized', 'tom thumb', 'abated', 'ablated', 'atrophied', 'attenuated', 'bated', 'belittled', 'brittle', 'by the board', 'consumed'],
    'shtick': ['act', 'afterpiece', 'bit', 'chaser', 'curtain', 'curtain call', 'curtain raiser', 'divertimento', 'divertissement', 'epilogue', 'exode', 'exodus'],
    'shuck': ['bark', 'bran', 'capsule', 'case', 'chaff', 'corn shuck', 'cornhusk', 'decorticate', 'hull', 'husk', 'jacket', 'palea'],
    'shudder': ['bang', 'be cold', 'bob', 'bobble', 'boot', 'bounce', 'bump', 'charge', 'chatter', 'chill', 'convulse', 'convulsion'],
    'shuddering': ['abhorrence', 'abomination', 'ague', 'allergy', 'antagonism', 'antipathy', 'aspen', 'aversion', 'bumpiness', 'chattering', 'chorea', 'cold shivers'],
    'shuffle': ['admix', 'alloy', 'alternate', 'amalgamate', 'amble', 'andante', 'around the bush', 'back and fill', 'ball up', 'barge', 'beat about', 'befuddlement'],
    'shuffled': ['amiss', 'askew', 'awry', 'balled-up', 'bothered', 'chaotic', 'cockeyed', 'confused', 'convulsed', 'deranged', 'disarranged', 'discomfited'],
    'shuffling': ['micawberish', 'adrift', 'afloat', 'alternating', 'alternation', 'ambling', 'amorphous', 'backward', 'bickering', 'boggling', 'capricious', 'captious'],
    'shun': ['abstain', 'abstain from', 'avoid', 'be stuck-up', 'bilk', 'cold-shoulder', 'decline', 'despise', 'disdain', 'do without', 'dodge', 'double'],
    'shunning': ['avoidance', 'avoiding reaction', 'circumvention', 'defense mechanism', 'dodge', 'duck', 'elusion', 'elusiveness', 'equivocation', 'escape', 'eschewal', 'evasion'],
    'shunt': ['advance', 'avert', 'bear off', 'bowl', 'bunt', 'butt', 'carry away', 'carry off', 'cart away', 'change', 'deflect', 'delocalize'],
    'shunted': ['abandoned', 'deserted', 'disregarded', 'half-done', 'ignored', 'laid aside', 'left undone', 'missed', 'neglected', 'omitted', 'overlooked', 'passed by'],
    'shush': ['assibilate', 'assibilation', 'black out', 'buzz', 'censor', 'choke', 'choke off', 'dumbfound', 'effervesce', 'effervescence', 'effervescing', 'fizz'],
    'shut': ['ban', 'bang', 'bar', 'barricade', 'batten', 'batten down', 'blank', 'blind', 'blind-alley', 'block out', 'bolt', 'bolted'],
    'shut down': ['asphyxiate', 'be ruined', 'become insolvent', 'bottle up', 'break', 'bust', 'call a strike', 'call it quits', 'cease', 'censor', 'choke', 'choke off'],
    'shut eye': ['beauty sleep', 'beddy-bye', 'bedtime', 'blanket drill', 'bye-bye', 'doss', 'doze', 'dreamland', 'drowse', 'fitful sleep', 'hibernation', 'land of nod'],
    'shut in': ['diogenes', 'hieronymian', 'hieronymite', 'timon of athens', 'anchoress', 'anchorite', 'anchoritic', 'apoplectic', 'arthritic', 'ascetic', 'barred', 'bedridden invalid'],
    'shut off': ['abrupt', 'alienate', 'alienated', 'apart', 'bar', 'barricade', 'block', 'block out', 'block up', 'blockade', 'bolt', 'cast off'],
    'shut out': ['ban', 'banned', 'bar', 'bar out', 'barred', 'barricade', 'blank', 'blanked', 'block', 'block out', 'block up', 'blockade'],
    'shut up': ['anchoritic', 'answer', 'answer conclusively', 'argue down', 'bang', 'bar', 'barricade', 'batten', 'batten down', 'be mute', 'be silent', 'beleaguer'],
    'shutdown': ['abandonment', 'blockade', 'breakoff', 'cease', 'ceasing', 'cessation', 'close', 'closing', 'closure', 'desinence', 'desistance', 'discontinuance'],
    'shuttle': ['amtrak', 'air transport', 'air travel', 'airfreight', 'alternate', 'back and fill', 'baggage train', 'battledore and shuttlecock', 'cable railroad', 'choo-choo', 'cog railroad', 'cog railway'],
    'shy': ['pyrrhonic', 'about the bush', 'afraid', 'agnostic', 'apprehensive', 'around the bush', 'arrested', 'averse', 'avert', 'avoid', 'back down', 'backhanded'],
    'shyness': ['afraidness', 'bashfulness', 'boggle', 'boggling', 'compunction', 'confusion', 'coyness', 'demur', 'demureness', 'demurity', 'demurral', 'diffidence'],
    'shyster': ['artful dodger', 'philadelphia lawyer', 'yankee horse trader', 'ambulance chaser', 'blackguard', 'bunco artist', 'bunco steerer', 'cardsharp', 'cardsharper', 'carpetbagger', 'charmer', 'con artist'],
    'sib': ['affiliated', 'agnate', 'akin', 'allied', 'ancestry', 'avuncular', 'blood', 'blood relation', 'blood relative', 'clansman', 'closely related', 'cognate'],
    'siberia': ['alaska', 'antarctic zone', 'antarctica', 'arctic circle', 'arctic zone', 'china', 'darkest africa', 'frigid zones', 'god knows where', 'greenland', 'iceland', 'lower slobbovia'],
    'sibilate': ['assibilate', 'bark', 'bawl', 'bellow', 'blare', 'blat', 'blubber', 'boom', 'bray', 'breathe', 'buzz', 'cackle'],
    'sibilation': ['aphonia', 'artificial voice', 'broken speech', 'broken tones', 'broken voice', 'childish treble', 'choked voice', 'cracked voice', 'croak', 'crow', 'dysarthria', 'dyslalia'],
    'sibling': ['affiliated', 'agnate', 'akin', 'allied', 'ancestry', 'avuncular', 'blood', 'blood relation', 'blood relative', 'clansman', 'closely related', 'cognate'],
    'sic': ['abet', 'accurately', 'agitate', 'aid', 'catalyze', 'correctly', 'countenance', 'egg on', 'exhort', 'faultlessly', 'favor', 'flawlessly'],
    'sic on': ['aggravate', 'agitate', 'alienate', 'arouse', 'blow the coals', 'come between', 'disaffect', 'disunite', 'divide', 'estrange', 'excite', 'fan'],
    'sick': ['abnormal', 'affected', 'afflicted', 'ailing', 'airsick', 'amiss', 'annoyed', 'appalled', 'bad', 'below par', 'bent', 'bereft of reason'],
    'sick bay': ['va hospital', 'asylum', 'base hospital', 'clinic', 'community hospital', 'convalescent home', 'convalescent hospital', 'evacuation hospital', 'field hospital', 'general hospital', 'home', 'hospital'],
    'sick leave': ['awol', 'french leave', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'cut', 'day off', 'default', 'departure'],
    'sick mind': ['aberration', 'abnormality', 'alienation', 'brain damage', 'brainsickness', 'clouded mind', 'craziness', 'daftness', 'dementedness', 'dementia', 'derangement', 'disorientation'],
    'sick of': ['allayed', 'blase', 'cloyed', 'crammed', 'disgusted', 'dispirited', 'engorged', 'fed-up', 'full', 'full of', 'glutted', 'good and tired'],
    'sick person': ['apoplectic', 'arthritic', 'case', 'consumptive', 'dyspeptic', 'epileptic', 'incurable', 'inpatient', 'invalid', 'outpatient', 'patient', 'rheumatic'],
    'sicken': ['od', 'affect', 'afflict', 'appall', 'be brought down', 'be felled', 'be struck down', 'be traumatized', 'break out', 'catch', 'catch cold', 'collapse'],
    'sickening': ['abhorrent', 'abominable', 'bad', 'barfy', 'base', 'beastly', 'below contempt', 'beneath contempt', 'brackish', 'cloying', 'contemptible', 'crude'],
    'sickle cell anemia': ['christmas disease', 'hartnup disease', 'letterer-siwe syndrome', 'werdnig-hoffmann disease', 'achromatic vision', 'acute leukemia', 'albinism', 'anemia', 'angiohemophilia', 'aplastic anemia', 'chronic leukemia', 'color blindness'],
    'sickly': ['achromatic', 'achromic', 'ailing', 'anemic', 'ashen', 'ashy', 'bled white', 'bloodless', 'cachectic', 'cadaverous', 'chloranemic', 'cloying'],
    'sickness': ['aberration', 'abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'alienation', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect'],
    'sickroom': ['va hospital', 'asylum', 'base hospital', 'clinic', 'community hospital', 'convalescent home', 'convalescent hospital', 'evacuation hospital', 'field hospital', 'general hospital', 'home', 'hospital'],
    'siddur': ['sefer torah', 'torah', 'torah scroll', 'virginal', 'breviary', 'canon', 'church book', 'euchologion', 'euchology', 'farse', 'formulary', 'lectionary'],
    'side': ['anschauung', 'olympian detachment', 'olympian loftiness', 'actor', 'adjoin', 'affectation', 'affiliation', 'aggressive self-confidence', 'air line', 'airs', 'ancillary', 'angle'],
    'side door': ['french door', 'archway', 'back door', 'back road', 'back stairs', 'back street', 'back way', 'barway', 'bolt-hole', 'bulkhead', 'by-lane', 'bypass'],
    'side effect': ['accession', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct', 'adjuvant'],
    'side issue': ['accession', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct', 'adjuvant'],
    'side road': ['back door', 'back road', 'back stairs', 'back street', 'back way', 'by-lane', 'bypass', 'bypath', 'byroad', 'bystreet', 'byway', 'departure'],
    'side with': ['accord', 'act with', 'advocate', 'agree', 'agree in opinion', 'agree with', 'align with', 'back', 'back up', 'backstop', 'champion', 'chime in with'],
    'sided': ['bifacial', 'bilateral', 'dihedral', 'flanked', 'handed', 'lateral', 'many-sided', 'multilateral', 'one-sided', 'polyhedral', 'quadrilateral', 'tetrahedral'],
    'sidekick': ['ace', 'amigo', 'associate', 'bedfellow', 'bedmate', 'birthmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty', 'camarade'],
    'sidelight': ['account', 'acquaintance', 'announcement', 'blue book', 'briefing', 'bulletin', 'communication', 'communique', 'data', 'datum', 'directory', 'dispatch'],
    'sideline': ['avocation', 'bank', 'board', 'border', 'bordure', 'brim', 'brink', 'brow', 'by-line', 'catalog goods', 'coast', 'commodities'],
    'sidelong': ['aside', 'askance', 'askant', 'aslant', 'aslope', 'asquint', 'at an angle', 'atilt', 'away', 'backhand', 'backhanded', 'bevel'],
    'sidereal': ['cynthian', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical', 'celestial', 'circumplanetary', 'cislunar'],
    'sidestep': ['about the bush', 'around the bush', 'avert', 'avoid', 'back and fill', 'bear off', 'beat about', 'beat around', 'beg the question', 'bicker', 'blench', 'blink'],
    'sidestroke': ['australian crawl', 'aquaplaning', 'aquatics', 'backstroke', 'balneation', 'bathe', 'bathing', 'breaststroke', 'butterfly', 'crawl', 'diving', 'dog paddle'],
    'sideswipe': ['appulse', 'bang', 'bang into', 'brunt', 'brush', 'brush by', 'bulldozing', 'bulling', 'bump', 'bump into', 'cannon', 'carambole'],
    'sidetrack': ['avert', 'bear off', 'branch', 'bypath', 'byway', 'cable railway', 'cog railway', 'deflect', 'departure', 'deviation', 'digression', 'discursion'],
    'sidetracked': ['abandoned', 'deserted', 'disregarded', 'half-done', 'ignored', 'laid aside', 'left undone', 'missed', 'neglected', 'omitted', 'overlooked', 'passed by'],
    'sidewalk': ['alameda', 'beaten path', 'beaten track', 'berm', 'bicycle path', 'boardwalk', 'bridle path', 'catwalk', 'esplanade', 'fastwalk', 'foot pavement', 'footpath'],
    'sidewalk superintendent': ['tv-viewer', 'beholder', 'bird-watcher', 'bystander', 'drugstore cowboy', 'eyewitness', 'gaper', 'gazer', 'gazer-on', 'girl-watcher', 'goggler', 'kibitzer'],
    'sideward': ['ascending', 'axial', 'back', 'back-flowing', 'backward', 'crabwise', 'descending', 'down-trending', 'downward', 'drifting', 'flanking', 'flowing'],
    'sideways': ['across', 'across the grain', 'aside', 'askance', 'askant', 'aslant', 'aslope', 'asquint', 'at an angle', 'athwart', 'athwartships', 'breadthwise'],
    'siding': ['adobe', 'ashlar', 'bank', 'beam', 'billet', 'board', 'boarding', 'border', 'branch', 'brick', 'bricks and mortar', 'broadside'],
    'sidle': ['accost', 'advance', 'amble', 'approach', 'appropinquate', 'approximate', 'ascend', 'avert', 'bank', 'barge', 'bear down on', 'bear down upon'],
    'siege': ['attack', 'beleaguer', 'beleaguerment', 'besetment', 'besiege', 'besiegement', 'blockade', 'blockading', 'bottle up', 'bout', 'circumscription', 'confinement'],
    'sieve': ['analyze', 'analyzer', 'arabesque', 'assort', 'basketry', 'basketwork', 'bolt', 'bolter', 'breaker', 'cancellation', 'categorize', 'centrifuge'],
    'sift': ['air', 'analyze', 'appraise', 'assess', 'assort', 'bolt', 'canvass', 'catalog', 'categorize', 'choose', 'choose out', 'clarify'],
    'sifter': ['bolter', 'clarifier', 'colander', 'cradle', 'cribble', 'filter', 'grate', 'grating', 'lixiviator', 'percolator', 'purifier', 'refiner'],
    'sifting': ['amassing evidence', 'appraisal', 'assessment', 'assortment', 'bolting', 'categorization', 'clarification', 'classification', 'close inquiry', 'colature', 'culling', 'department of investigation'],
    'sigh': ['aqua-lung', 'ache', 'artificial respiration', 'aspirate', 'aspiration', 'asthmatic wheeze', 'bark', 'bated breath', 'bawl', 'bellow', 'bemoan', 'bewail'],
    'sight': ['anschauung', 'aim', 'aim at', 'airscape', 'amazement', 'angle', 'angle of vision', 'assumption', 'astonishing thing', 'astonishment', 'atrocity', 'attitude'],
    'sight see': ['campaign', 'cruise', 'fare', 'globe-trot', 'go abroad', 'go on safari', 'go overseas', 'go slumming', 'hit the trail', 'jaunt', 'journey', 'lionize'],
    'sightless': ['ableptical', 'amaurotic', 'behind the curtain', 'behind the scenes', 'benighted', 'bereft of light', 'blind', 'camouflaged', 'color-blind', 'concealed', 'dark', 'dim-sighted'],
    'sightly': ['junoesque', 'agreeable', 'amply endowed', 'becoming', 'bonny', 'braw', 'built', 'built for comfort', 'buxom', 'callipygian', 'callipygous', 'comely'],
    'sightseer': ['paul pry', 'peeping tom', 'adventurer', 'alpinist', 'astronaut', 'busybody', 'camper', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser'],
    'sigmoid': ['cynthian', 's-shaped', 'ambagious', 'anfractuous', 'bicorn', 'circuitous', 'circumlocutory', 'convolutional', 'corniform', 'crescent', 'crescent-shaped', 'crescentic'],
    'sign': ['ok', 'roman candle', 'abandon', 'abnormality', 'accent', 'accent mark', 'accept', 'accredit', 'acute disease', 'adumbration', 'advertisement', 'affection'],
    'sign language': ['bearing', 'beck', 'beckon', 'body language', 'carriage', 'charade', 'chironomy', 'dactylology', 'deaf-and-dumb alphabet', 'dumb show', 'finger alphabet', 'gesticulation'],
    'sign off': ['teletype', 'beam', 'broadcast', 'cable', 'flash', 'newscast', 'radiate', 'radio', 'radiobroadcast', 'send', 'send a wire', 'shortwave'],
    'sign on': ['teletype', 'affiliate', 'affiliate with', 'associate', 'beam', 'bespeak', 'book', 'brief', 'broadcast', 'cable', 'call up', 'combine'],
    'sign over': ['abalienate', 'alien', 'alienate', 'amortize', 'assign', 'barter', 'bequeath', 'cede', 'confer', 'consign', 'convey', 'deed'],
    'sign up': ['affiliate', 'affiliate with', 'alternate', 'associate', 'bespeak', 'book', 'brief', 'call up', 'combine', 'come into', 'commandeer', 'conscript'],
    'signal': ['algol', 'cobol', 'crt spot', 'dm display', 'doppler signal', 'edp', 'fortran', 'if signal', 'im display', 'rf echoes', 'roman candle', 'teletype'],
    'signal light': ['very flare', 'balefire', 'beacon fire', 'beacons', 'flare', 'flare-up', 'fusee', 'lighthouse', 'lightship', 'magnesium flare', 'occulting light', 'pharos'],
    'signalize': ['adorn', 'approve', 'argue', 'attest', 'beat the drum', 'bespeak', 'bestow honor upon', 'betoken', 'blow the trumpet', 'breathe', 'celebrate', 'commemorate'],
    'signalizing': ['connotative', 'demonstrative', 'denominative', 'denotative', 'designative', 'diagnostic', 'emblematic', 'evidential', 'exhibitive', 'expressive', 'figural', 'figurative'],
    'signature': ['id card', 'john hancock', 'ok', 'smyth sewing', 'accent', 'accent mark', 'acceptance', 'accommodation', 'acknowledgment', 'acknowledgments', 'adjustment', 'affirmance'],
    'signboard': ['arrow', 'blaze', 'compass needle', 'direction', 'direction post', 'finger post', 'fist', 'guide', 'guideboard', 'guidepost', 'hand', 'hour hand'],
    'signed': ['accepted', 'acknowledged', 'admitted', 'affirmed', 'agreed', 'allowed', 'approved', 'arranged', 'authenticated', 'avowed', 'certified', 'compacted'],
    'signet': ['john hancock', 'ok', 'acceptance', 'affirmance', 'affirmation', 'approbation', 'approval', 'authentication', 'authorization', 'autograph', 'billhead', 'book stamp'],
    'significance': ['accent', 'acceptation', 'affective meaning', 'authority', 'balefulness', 'banefulness', 'bearing', 'bodefulness', 'coloring', 'concern', 'concernment', 'connotation'],
    'significant': ['absolute', 'adducible', 'admissible', 'allegorical', 'associational', 'attestative', 'attestive', 'augural', 'authentic', 'based on', 'big', 'big-league'],
    'signification': ['acceptation', 'affective meaning', 'allocation', 'assignment', 'attribution', 'bearing', 'characterization', 'coloring', 'connotation', 'consequence', 'construction', 'denomination'],
    'signify': ['add up to', 'amount to something', 'announce', 'approve', 'argue', 'assign', 'attest', 'augur', 'be construed as', 'be featured', 'be indicative of', 'be prominent'],
    'signora': ['frau', 'fraulein', 'miss', 'mistress', 'mlle', 'mme', 'mmes', 'dame', 'dona', 'donna', 'lady', 'madam'],
    'signpost': ['samson post', 'arrow', 'baluster', 'balustrade', 'banister', 'blaze', 'compass needle', 'direction', 'direction post', 'doorjamb', 'doorpost', 'finger post'],
    'silage': ['barley', 'bird seed', 'bran', 'cat food', 'chicken feed', 'chop', 'corn', 'dog food', 'eatage', 'ensilage', 'feed', 'fodder'],
    'silence': ['answer', 'answer conclusively', 'argue down', 'asphyxiate', 'ataraxia', 'ataraxy', 'blow to pieces', 'blow up', 'blunt', 'bottle up', 'brain', 'brevity'],
    'silencer': ['acoustic tile', 'antiknock', 'baffler', 'cushion', 'damp', 'dampener', 'damper', 'gag', 'hushcloth', 'muffle', 'muffler', 'mute'],
    'silent': ['aphonic', 'brief', 'brusque', 'calm', 'checked', 'close', 'close-lipped', 'close-tongued', 'closemouthed', 'concise', 'curbed', 'curt'],
    'silent film': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'black-and-white film', 'cartoon', 'chiller', 'cinema', 'color film', 'creepie', 'documentary'],
    'silent majority': ['middle america', 'bourgeoisie', 'breakaway group', 'burgherdom', 'camp', 'caucus', 'division', 'ethnic group', 'faction', 'fourth-rater', 'interest', 'interest group'],
    'silhouette': ['adumbration', 'black and white', 'broad lines', 'brouillon', 'cartoon', 'charcoal', 'charcoal drawing', 'chiaroscuro', 'configuration', 'contour', 'crayon', 'dark shade'],
    'silicosis': ['asiatic flu', 'hong kong flu', 'acute bronchitis', 'adenoiditis', 'aluminosis', 'amygdalitis', 'anthracosilicosis', 'anthracosis', 'asbestosis', 'asthma', 'atypical pneumonia', 'bituminosis'],
    'silk': ['ag', 'da', 'kc', 'qc', 'ssc', 'us attorney', 'alabaster', 'attorney general', 'billiard table', 'blubber', 'bowling alley', 'bowling green'],
    'silk stocking': ['brahman', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'blue blood', 'cafe-society', 'count', 'daimio', 'duke', 'earl'],
    'silken': ['buffed', 'burnished', 'cottony', 'deferential', 'disarming', 'finished', 'furbished', 'glace', 'glassy', 'glazed', 'gleaming', 'glossy'],
    'silky': ['attenuate', 'attenuated', 'buffed', 'burnished', 'capillary', 'cirrose', 'cirrous', 'cottony', 'dainty', 'deferential', 'delicate', 'disarming'],
    'sill': ['base', 'basement', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock', 'doorsill', 'doorstone', 'floor', 'flooring', 'fond'],
    'silly': ['pickwickian', 'absurd', 'airy', 'apish', 'asinine', 'balmy', 'batty', 'bedazzled', 'befooled', 'beguiled', 'benumbed', 'besotted'],
    'silo': ['mark', 'bazooka', 'calliope', 'crib', 'elevator', 'garner', 'grain bin', 'grain elevator', 'granary', 'hayloft', 'haymow', 'hayrick'],
    'silt': ['alluvion', 'alluvium', 'ash', 'cinder', 'clinker', 'debris', 'deposit', 'deposition', 'deposits', 'detritus', 'diluvium', 'draff'],
    'silver': ['ag', 'al', 'am', 'ar', 'as', 'at', 'au', 'be', 'bi', 'ca', 'cb', 'cd'],
    'silver plate': ['anodized aluminum', 'chromium plate', 'copperplate', 'cutlery', 'dining utensils', 'electrocoating', 'electroplating', 'flat silver', 'flatware', 'forks', 'gold plate', 'hollow ware'],
    'silver plated': ['aureate', 'brass', 'brassy', 'brazen', 'bronze', 'bronzy', 'chromium-plated', 'copper', 'copperplated', 'coppery', 'cupreous', 'cuprous'],
    'silver tongued': ['ciceronian', 'demosthenian', 'demosthenic', 'tullian', 'achingly sweet', 'agreeable', 'agreeable-sounding', 'appealing', 'ariose', 'arioso', 'articulate', 'canorous'],
    'silverware': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'cutlery', 'dining utensils', 'dinnerware', 'durable goods', 'durables', 'earthenware', 'enamelware'],
    'silvery': ['quaker-colored', 'achingly sweet', 'acier', 'agreeable', 'agreeable-sounding', 'appealing', 'argent', 'argentine', 'ariose', 'arioso', 'ashen', 'ashy'],
    'silviculture': ['christmas tree farming', 'afforestation', 'arboretum', 'arboriculture', 'boondocks', 'bush', 'bushveld', 'chase', 'climax forest', 'cloud forest', 'dendrology', 'forest'],
    'similar': ['agnate', 'akin', 'alike', 'analogical', 'analogous', 'aped', 'approximate', 'approximating', 'approximative', 'be like', 'close', 'collatable'],
    'similarity': ['accord', 'addition', 'adjunct', 'affairs', 'affiliation', 'affinity', 'alikeness', 'alliance', 'analogousness', 'analogy', 'approximation', 'assemblage'],
    'similarize': ['accommodate', 'accord', 'adapt', 'adjust', 'adjust to', 'approximate', 'assimilate', 'attune', 'bring near', 'connaturalize', 'coordinate', 'cut to'],
    'similarly': ['above', 'additionally', 'again', 'all included', 'also', 'altogether', 'among other things', 'and all', 'and also', 'and so', 'as well', 'au reste'],
    'simile': ['accordance', 'affinity', 'agreement', 'alikeness', 'allegory', 'alliance', 'alliteration', 'allusion', 'anacoluthon', 'anadiplosis', 'analogy', 'anaphora'],
    'similitude': ['accordance', 'affinity', 'agreement', 'alikeness', 'allegory', 'alliance', 'ally', 'alter ego', 'analogon', 'analogue', 'analogy', 'aping'],
    'simmer': ['bake', 'barbecue', 'baste', 'be in heat', 'be livid', 'be pissed', 'blanch', 'blaze', 'bloom', 'blubber', 'bluster', 'boil'],
    'simmer down': ['calm down', 'collect', 'collect oneself', 'compose oneself', 'control', 'cool', 'cool it', 'cool off', 'get organized', 'quiet down', 'rein', 'relax'],
    'simon legree': ['absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'autocrat', 'caesar', 'commissar', 'czar', 'despot', 'dictator', 'disciplinarian'],
    'simon pure': ['pecksniffian', 'austere', 'authentic', 'bare', 'basic', 'bona fide', 'candid', 'canting', 'card-carrying', 'chaste', 'dinkum', 'elementary'],
    'simpatico': ['agreeable', 'amiable', 'amicable', 'brotherly', 'congenial', 'favorable', 'fraternal', 'friendlike', 'friendly', 'harmonious', 'kind', 'neighborlike'],
    'simper': ['affected', 'beam', 'bridle', 'bright smile', 'broad grin', 'crack a smile', 'ear-to-ear grin', 'gleaming smile', 'glowing smile', 'grin', 'grinning', 'idiotic grin'],
    'simpering': ['elegant', 'euphemistic', 'euphuistic', 'exquisite', 'formalistic', 'goody good-good', 'goody-goody', 'mincing', 'namby-pamby', 'overnice', 'overprecise', 'overrefined'],
    'simple': ['attic', 'bohemian', 'ciceronian', 'mickey mouse', 'spartan', 'a certain', 'absolute', 'aesthetic', 'affable', 'amateur', 'an', 'any'],
    'simpleminded': ['arrested', 'artless', 'babbling', 'backward', 'blithering', 'bluff', 'blunt', 'born yesterday', 'burbling', 'candid', 'childlike', 'confiding'],
    'simpleton': ['ament', 'born fool', 'bungler', 'clot', 'congenital idiot', 'cretin', 'defective', 'dullard', 'dullhead', 'dumbbell', 'dummkopf', 'dummy'],
    'simplicity': ['attic simplicity', 'atticism', 'bohemianism', 'abatement', 'abridgment', 'affability', 'agnosticism', 'agrarianism', 'alleviation', 'amentia', 'appropriateness', 'arrested development'],
    'simplification': ['allegorization', 'clarification', 'cracking', 'decipherment', 'decoding', 'demonstration', 'demythologization', 'disentanglement', 'disinvolvement', 'distillation', 'easing', 'editing'],
    'simplify': ['abridge', 'account for', 'aid', 'allegorize', 'boil down', 'chasten', 'clarify', 'clean up', 'clear the way', 'clear up', 'compress', 'crack'],
    'simplistic': ['arrested', 'backward', 'coarse', 'conceptually crude', 'crude', 'embryonic', 'in embryo', 'in ovo', 'in the rough', 'intellectually childish', 'oversimple', 'reductionistic'],
    'simply': ['absolutely', 'aesthetically', 'after a fashion', 'alone', 'altogether', 'appreciably', 'apprehensibly', 'articulately', 'artistically', 'artlessly', 'ascetically', 'at any rate'],
    'simulacrum': ['prospero', 'acting', 'affectation', 'airiness', 'ally', 'alter ego', 'analogon', 'analogue', 'angle', 'appearance', 'aspect', 'associate'],
    'simulate': ['act', 'act a part', 'act like', 'adopt', 'affect', 'ape', 'appear like', 'approach', 'appropriate', 'approximate', 'assume', 'be like'],
    'simulated': ['affected', 'alike', 'aped', 'apocryphal', 'artificial', 'assumed', 'bastard', 'bogus', 'brummagem', 'colorable', 'colored', 'consimilar'],
    'simulation': ['accordance', 'acting', 'adoption', 'affectation', 'agreement', 'alikeness', 'alliance', 'analogy', 'aping', 'appearance', 'approach', 'appropriation'],
    'simultaneity': ['accompaniment', 'accordance', 'agreement', 'alliance', 'association', 'cahoots', 'co-occurrence', 'co-working', 'coaction', 'coincidence', 'collaboration', 'collectivity'],
    'simultaneous': ['accessory', 'accompanying', 'agreeing', 'associated', 'attendant', 'attending', 'coetaneous', 'coeternal', 'coeval', 'coexistent', 'coexisting', 'coincident'],
    'simultaneously': ['all at once', 'all together', 'as one', 'as one man', 'at a blow', 'at a clip', 'at a stroke', 'at once', 'at one blow', 'at one jump', 'at one stroke', 'at one swoop'],
    'sin': ['aberrancy', 'aberration', 'abomination', 'atrocity', 'bad', 'breach', 'commit sin', 'crime', 'crime against humanity', 'criminal tendency', 'criminality', 'criminosis'],
    'since': ['aeons ago', 'after', 'after all', 'after that', 'afterwards', 'ages ago', 'ago', 'as', 'as long as', 'as things go', 'back', 'back when'],
    'sincere': ['abandoned', 'aboveboard', 'actual', 'afire', 'ardent', 'artless', 'authentic', 'bluff', 'blunt', 'bona fide', 'born yesterday', 'bound'],
    'sincerity': ['abandon', 'absolute realism', 'ardency', 'ardor', 'artlessness', 'authenticity', 'bluffness', 'bluntness', 'bona fideness', 'broadness', 'brusqueness', 'candidness'],
    'sine qua non': ['bench mark', 'boundary condition', 'cardinal point', 'catch', 'chief thing', 'clause', 'climax', 'condition', 'core', 'cornerstone', 'crisis', 'critical point'],
    'sine wave': ['lissajous figure', 'alternation', 'back-and-forth', 'coming and going', 'ebb and flow', 'flux and reflux', 'reciprocation', 'rhythmic play', 'seesaw', 'seesawing', 'teeter', 'teeter-totter'],
    'sinew': ['amperage', 'arm', 'armipotence', 'authority', 'backbone', 'beef', 'beefiness', 'bite', 'bitingness', 'black power', 'brawn', 'brawniness'],
    'sinewy': ['able-bodied', 'acid', 'athletic', 'biting', 'brawny', 'broad-shouldered', 'burly', 'cartilaginous', 'chewy', 'cohesive', 'coriaceous', 'corrosive'],
    'sinful': ['aberrant', 'abnormal', 'abominable', 'amiss', 'arrant', 'atrocious', 'bad', 'base', 'black', 'blamable', 'blameful', 'blameworthy'],
    'sing': ['anthem', 'babble', 'ballad', 'bark', 'bawl', 'be in heaven', 'be indiscreet', 'be pleased', 'be unguarded', 'beam', 'bellow', 'betray'],
    'singe': ['attaint', 'bedaub', 'besmear', 'besmirch', 'besmoke', 'bestain', 'blacken', 'blaze', 'blister', 'blur', 'brand', 'burn'],
    'singer': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'artist', 'artiste', 'balladeer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo'],
    'singing': ['alto', 'baritone', 'bass', 'beaming', 'beatific', 'beatified', 'bel canto', 'blessed', 'blissful', 'bravura', 'capering', 'cheerful'],
    'single': ['a certain', 'an', 'any', 'any one', 'appropriate', 'article', 'atomic', 'austere', 'bachelorlike', 'bare', 'basic', 'candid'],
    'single file': ['indian file', 'array', 'articulation', 'bank', 'buzz', 'catena', 'catenation', 'chain', 'chain reaction', 'chaining', 'concatenation', 'connection'],
    'single handed': ['alienated', 'alone', 'aloof', 'apart', 'companionless', 'detached', 'friendless', 'homeless', 'insular', 'isolated', 'kithless', 'lone'],
    'single minded': ['absorbed', 'absorbed in', 'adamant', 'artless', 'assiduous', 'bigoted', 'bluff', 'blunt', 'born yesterday', 'bound', 'bound and determined', 'buried in'],
    'singleness': ['aloneness', 'bachelordom', 'bachelorhood', 'bachelorism', 'bachelorship', 'celibacy', 'combination', 'continence', 'elementarity', 'fundamentality', 'fusion', 'homogeneity'],
    'singleton': ['ace', 'article', 'best bower', 'bower', 'cards', 'clubs', 'deck', 'deuce', 'diamonds', 'dummy', 'entity', 'face cards'],
    'singsong': ['alliterating', 'alliteration', 'alliterative', 'assonance', 'assonant', 'belabored', 'blah', 'broken-record', 'chanting', 'chime', 'chiming', 'cliche-ridden'],
    'singular': ['a certain', 'abnormal', 'absolute', 'absurd', 'alone', 'an', 'anomalous', 'any', 'any one', 'appropriate', 'atomic', 'atypical'],
    'singularity': ['aberration', 'abnormality', 'absurdity', 'anomaly', 'anticness', 'aroma', 'attribute', 'badge', 'bizarreness', 'bizarrerie', 'black hole', 'brand'],
    'singularly': ['abundantly', 'acutely', 'alone', 'amazingly', 'amply', 'apart', 'astonishingly', 'awesomely', 'by itself', 'characteristically', 'conspicuously', 'copiously'],
    'sinister': ['adverse', 'amoral', 'antagonistic', 'apocalyptic', 'backhand', 'backhanded', 'bad', 'baleful', 'baneful', 'base', 'black', 'bodeful'],
    'sinistral': ['backhand', 'backhanded', 'circuitous', 'counterclockwise', 'deflectional', 'deviant', 'deviative', 'devious', 'digressive', 'divagational', 'divergent', 'excursive'],
    'sink': ['babylon', 'gomorrah', 'ko', 'sodom', 'abate', 'ablate', 'advance', 'age', 'alveolation', 'alveolus', 'antrum', 'aquamanile'],
    'sink back': ['backslide', 'fall', 'fall again into', 'fall back', 'fall from grace', 'have a relapse', 'lapse', 'lapse back', 'recidivate', 'recur to', 'regress', 'relapse'],
    'sink in': ['affect', 'arrest the thoughts', 'be glimpsed', 'be remembered', 'bemire', 'bog', 'bog down', 'catch the thoughts', 'come home to', 'come through', 'dawn on', 'get across'],
    'sinker': ['brussels biscuit', 'melba toast', 'apple fritter', 'beignet', 'beignet aux pommes', 'biscuit', 'bismarck', 'bob', 'bowl', 'cast', 'change of pace', 'change-up'],
    'sinking': ['brownian movement', 'advance', 'aging', 'angular motion', 'anxious', 'apprehensive', 'ascending', 'ascent', 'axial', 'axial motion', 'back', 'back-flowing'],
    'sinner': ['bad person', 'criminal', 'crook', 'culprit', 'deceiver', 'delinquent', 'evil man', 'evil person', 'evildoer', 'felon', 'gangster', 'lawbreaker'],
    'sinuous': ['ambagious', 'anfractuous', 'bent', 'billowing', 'billowy', 'circuitous', 'circumlocutory', 'convoluted', 'convolutional', 'curvaceous', 'curvate', 'curvated'],
    'sinus': ['alveolation', 'alveolus', 'antrum', 'arc', 'armpit', 'basin', 'bow', 'bowl', 'catacaustic', 'catenary', 'caustic', 'cavity'],
    'sinusitis': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'brain fever', 'bronchitis'],
    'sip': ['beverage', 'bib', 'bite', 'booze', 'bumper', 'cast', 'dash', 'draft', 'drain the cup', 'dram', 'drench', 'drink'],
    'siphon': ['adjutage', 'aspirator', 'bleed', 'broach', 'canalize', 'carry', 'catheter', 'channel', 'channelize', 'conduct', 'convey', 'corkscrew'],
    'siphoning': ['aspiration', 'bleeding', 'bloodletting', 'broaching', 'cupping', 'drafting', 'drainage', 'draining', 'drawing', 'emptying', 'milking', 'phlebotomy'],
    'sire': ['esquire', 'master', 'mister', 'sir', 'abba', 'agent', 'ancestors', 'apprentice', 'architect', 'artificer', 'artist', 'author'],
    'siren': ['circe', 'davy', 'davy jones', 'don juan', 'dylan', 'euryale', 'gorgon', 'jezebel', 'klaxon', 'lorelei', 'mayday', 'medea'],
    'sirloin': ['chateaubriand', 'blade roast', 'breast', 'brisket', 'chuck', 'chuck roast', 'clod', 'cold cuts', 'filet mignon', 'flank', 'knuckle', 'loin'],
    'sirocco': ['santa ana', 'chinook', 'chinook wind', 'devil', 'dust storm', 'foehn', 'harmattan', 'hot wind', 'khamsin', 'peesash', 'samiel', 'sandstorm'],
    'sissified': ['afraid', 'breakable', 'brittle', 'cheap-jack', 'chicken', 'chickenhearted', 'cobwebby', 'coward', 'cowardly', 'cowed', 'crumbly', 'dainty'],
    'sissy': ['lord fauntleroy', 'milquetoast', 'percy', 'afraid', 'aunt', 'auntie', 'baby', 'big baby', 'blood brother', 'brethren', 'brother', 'bub'],
    'sister': ['greek', 'lpn', 'rn', 'abbess', 'affiliate', 'ally', 'alter ego', 'analogon', 'analogue', 'associate', 'aunt', 'auntie'],
    'sisterhood': ['affiliation', 'agnation', 'alliance', 'ancestry', 'blood', 'blood relationship', 'boon companionship', 'brotherhood', 'brotherliness', 'brothership', 'chumship', 'club'],
    'sisterly': ['agreeable', 'amiable', 'amicable', 'brotherly', 'congenial', 'favorable', 'fraternal', 'friendlike', 'friendly', 'harmonious', 'kind', 'neighborlike'],
    'sit': ['be gravid', 'be knocked up', 'be pregnant', 'be seated', 'be with child', 'breed', 'brood', 'bum around', 'call together', 'carry', 'carry young', 'clock'],
    'sit back': ['be a sideliner', 'be still', 'coast', 'delay', 'do nothing', 'drift', 'hang fire', 'hibernate', 'idle', 'lie dormant', 'not budge', 'not stir'],
    'sit down': ['anchor', 'be seated', 'billet at', 'bivouac', 'boycott', 'burrow', 'camp', 'colonize', 'come to anchor', 'domesticate', 'drop anchor', 'ensconce'],
    'sit down strike': ['arrest', 'bell', 'boycott', 'boycottage', 'check', 'checkmate', 'cutoff', 'dead stop', 'deadlock', 'end', 'endgame', 'ending'],
    'sit down with': ['advise with', 'bargain', 'call in', 'collogue', 'compare notes', 'confer', 'confer with', 'consult', 'consult with', 'counsel', 'deliberate', 'discuss'],
    'sit in': ['assemblee', 'assembly', 'assignation', 'at home', 'ball', 'be enfranchised', 'be implicated in', 'bear a hand', 'beef', 'bitch', 'boggle', 'boycott'],
    'sit in on': ['attend', 'attend to', 'auscultate', 'be all ears', 'be enfranchised', 'be implicated in', 'bear a hand', 'bend an ear', 'bug', 'chip in', 'cock the ears', 'contribute'],
    'sit on': ['abut on', 'adopt', 'appropriate', 'arrogate', 'asphyxiate', 'assume', 'bawl out', 'be based on', 'bear on', 'bestraddle', 'bestride', 'black out'],
    'sit tight': ['abide', 'await', 'be incognito', 'bide', 'bide the issue', 'burrow', 'dally', 'dawdle', 'delay', 'dillydally', 'disappear', 'drop from sight'],
    'sit up': ['abide', 'arise', 'await', 'bide', 'bide the issue', 'bristle', 'cock up', 'dally', 'dawdle', 'delay', 'dillydally', 'disentangle'],
    'sita': ['agni', 'asvins', 'avalokita', 'bhairava', 'bhairavi', 'brahma', 'chandi', 'daksha', 'devaki', 'devi', 'dharma', 'dharti mai'],
    'sitar': ['dobro guitar', 'f-hole guitar', 'spanish guitar', 'archlute', 'balalaika', 'banjo', 'banjo-uke', 'banjo-ukulele', 'banjo-zither', 'banjorine', 'banjuke', 'bass guitar'],
    'site': ['abode', 'agora', 'amphitheater', 'area', 'arena', 'athletic field', 'auditorium', 'background', 'bear garden', 'bearings', 'bench mark', 'bowl'],
    'sitting': ['assemblee', 'assembly', 'assignation', 'at home', 'audience', 'ball', 'bargaining', 'bargaining session', 'bigness', 'brawl', 'brooding', 'caucus'],
    'sitting duck': ['babe', 'boob', 'breeze', 'butt', 'chump', 'cinch', 'credulous person', 'cull', 'dupe', 'easy mark', 'easy pickings', 'easy target'],
    'situate': ['allocate', 'assign', 'collocate', 'deploy', 'dispose', 'emplace', 'fix', 'get a fix', 'home in on', 'install', 'localize', 'locate'],
    'situated': ['assigned', 'deployed', 'embosomed', 'emplaced', 'ensconced', 'established', 'fixed', 'installed', 'located', 'placed', 'planted', 'positioned'],
    'situation': ['anschauung', 'abode', 'alentours', 'allocation', 'ambience', 'ambit', 'angle', 'angle of vision', 'appointment', 'area', 'assignment', 'bargain'],
    'situation comedy': ['grand guignol', 'passion play', 'thalia', 'tom show', 'antimasque', 'arlequinade', 'audience success', 'ballet', 'black comedy', 'bomb', 'broad comedy', 'broadcast drama'],
    'six shooter': ['aa gun', 'bar', 'bb gun', 'big bertha', 'bren', 'bren gun', 'garand', 'garand rifle', 'gatling gun', 'lewis gun', 'long tom', 'thompson submachine gun'],
    'sixth': ['consecutive intervals', 'decimalization', 'decimation', 'degree', 'diapason', 'diatessaron', 'diatonic interval', 'diatonic semitone', 'enharmonic diesis', 'enharmonic interval', 'fifth', 'fourth'],
    'sixth sense': ['esp', 'a priori knowledge', 'anticipation', 'buddhi', 'chromesthesia', 'clairsentience', 'clairvoyance', 'color hearing', 'direct apprehension', 'extrasensory perception', 'five senses', 'foresight'],
    'sizable': ['gargantuan', 'amplitudinous', 'astronomical', 'awesome', 'big', 'boundless', 'bulky', 'bumper', 'colossal', 'considerable', 'cosmic', 'enormous'],
    'size': ['adjust', 'albumen', 'amplitude', 'appraise', 'appreciate', 'area', 'assay', 'assess', 'assort', 'autopsy', 'batter', 'bigness'],
    'size up': ['appraise', 'appreciate', 'assay', 'assess', 'autopsy', 'calculate', 'calibrate', 'caliper', 'canvass', 'check', 'check a parameter', 'check out'],
    'sizzle': ['assibilate', 'assibilation', 'ball the jack', 'barrel', 'be livid', 'be pissed', 'bluster', 'boil', 'boom', 'bowl along', 'breeze', 'breeze along'],
    'sizzler': ['jehu', 'battery', 'bells', 'bones', 'broiler', 'castanets', 'celesta', 'chime', 'chimes', 'clappers', 'crash cymbal', 'cymbals'],
    'sizzling': ['assibilation', 'baking', 'boiling', 'broiling', 'burning', 'buzz', 'clack', 'click', 'crack', 'cracking', 'crackle', 'crackling'],
    'skate': ['reptilia', 'bloke', 'boy', 'buck', 'chap', 'coast', 'fellow', 'flit', 'flow', 'fly', 'gent', 'gentleman'],
    'skateboard': ['coast', 'flit', 'flow', 'fly', 'glide', 'glissade', 'ice skates', 'ice-skate', 'roller skates', 'roller-skate', 'sail', 'sideslip'],
    'skedaddle': ['abscond', 'absquatulate', 'back out', 'beat a retreat', 'begone', 'boggle', 'bolt', 'career', 'chicken', 'chicken out', 'clear out', 'cut and run'],
    'skein': ['animal fiber', 'artificial fiber', 'bevy', 'capillament', 'charm', 'cilium', 'cirrus', 'cloud', 'cobweb', 'covey', 'denier', 'fiber'],
    'skeletal': ['attenuated', 'bony', 'cadaverous', 'corpselike', 'emacerated', 'emaciate', 'emaciated', 'flat', 'flat-chested', 'fleshless', 'gangling', 'gangly'],
    'skeleton': ['abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'adumbrate', 'anatomy', 'appendicular skeleton', 'ashes', 'axial skeleton', 'backing', 'barebones'],
    'skeptical': ['humean', 'pyrrhonic', 'agnostic', 'ambiguous', 'capricious', 'cautious', 'chancy', 'changeable', 'cynical', 'dicey', 'disbelieving', 'disinclined to believe'],
    'skepticism': ['humism', 'pyrrhonism', 'agnosticism', 'apprehension', 'caution', 'cautiousness', 'concern', 'diffidence', 'disinclination to believe', 'distrust', 'distrustfulness', 'doubt'],
    'sketch': ['grand guignol', 'passion play', 'tom show', 'abbreviation', 'abbreviature', 'abrege', 'abridge', 'abridgment', 'abstract', 'act', 'act as foil', 'adumbrate'],
    'sketchbook': ['air brush', 'art paper', 'best seller', 'book', 'bound book', 'brush', 'camera lucida', 'camera obscura', 'canvas', 'chalk', 'charcoal', 'classic'],
    'sketchy': ['adulterated', 'arrested', 'blemished', 'callow', 'crude', 'cursory', 'damaged', 'defective', 'deficient', 'depthless', 'embryonic', 'erroneous'],
    'skew': ['aberrancy', 'aberration', 'agee', 'agee-jawed', 'angle', 'angle off', 'askance', 'askant', 'askew', 'askewgee', 'asquint', 'asymmetric'],
    'skewed': ['agee', 'agee-jawed', 'askance', 'askant', 'askew', 'askewgee', 'asquint', 'asymmetric', 'awry', 'catawampous', 'catawamptious', 'cockeyed'],
    'skewer': ['articulate', 'auger', 'batten', 'batten down', 'bite', 'bolt', 'bore', 'broach', 'buckle', 'butt', 'button', 'clasp'],
    'ski': ['coast', 'flit', 'flow', 'fly', 'glide', 'glissade', 'ice skates', 'ice-skate', 'roller skates', 'roller-skate', 'sail', 'sideslip'],
    'skid': ['avalanche', 'bank', 'coast', 'crab', 'dip', 'drop', 'edge', 'fall', 'feather', 'fishtail', 'flit', 'flow'],
    'skid row': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'barrio', 'black ghetto', 'blighted area', 'bowery'],
    'skilful': ['able', 'accomplished', 'adept', 'adroit', 'apt', 'capable', 'clever', 'dexterous', 'experienced', 'expert', 'gifted', 'masterful'],
    'skill': ['mnemosyne', 'ability', 'accomplishment', 'adeptness', 'adroitness', 'affect memory', 'anterograde memory', 'aptitude', 'art', 'artistry', 'ascendancy', 'atavism'],
    'skill less': ['artless', 'half-assed', 'inadept', 'inapt', 'inattentive', 'inefficient', 'inept', 'inexpert', 'mediocre', 'pedestrian', 'poor', 'thoughtless'],
    'skilled': ['accomplished', 'adept', 'adept in', 'at concert pitch', 'at home in', 'career', 'coached', 'conversant', 'crack', 'crackerjack', 'expert', 'expert at'],
    'skillful': ['daedalian', 'adept', 'adroit', 'advantageous', 'apt', 'artistic', 'auspicious', 'authoritative', 'beneficial', 'benevolent', 'bon', 'bonny'],
    'skim': ['avalanche', 'ball the jack', 'barrel', 'blink', 'boom', 'bowl along', 'breeze', 'breeze along', 'browse', 'brush', 'brush by', 'carefully ignore'],
    'skimp': ['begrudge', 'blink', 'carefully ignore', 'cold-shoulder', 'cut a corner', 'cut corners', 'dodge', 'economize', 'enforce economies', 'exiguous', 'famish', 'fudge'],
    'skimping': ['scotch', 'canny', 'careful', 'chary', 'cheeseparing', 'chinchy', 'chintzy', 'conserving', 'cooling', 'cooling down', 'cooling off', 'culpably negligent'],
    'skimpy': ['lenten', 'spartan', 'abstemious', 'ascetic', 'austere', 'cheeseparing', 'chinchy', 'chintzy', 'deficient', 'dwarfed', 'dwarfish', 'exiguous'],
    'skin': ['c-note', 'g-note', 'iud', 'ablate', 'abrade', 'abrase', 'acne', 'acne vulgaris', 'bag', 'bark', 'barrel', 'bear the palm'],
    'skin deep': ['ankle-deep', 'cortical', 'cursory', 'cutaneous', 'depthless', 'dermal', 'dermic', 'ecderonic', 'ectodermal', 'ectodermic', 'endermatic', 'endermic'],
    'skin flick': ['cinemascope', 'cinerama', 'rabelaisianism', 'technicolor', 'western', 'x-rated movie', 'animated cartoon', 'bawdiness', 'bawdry', 'black-and-white film', 'blue movie', 'cartoon'],
    'skin popping': ['antitoxin', 'bag', 'bang', 'booster', 'booster dose', 'booster shot', 'deck', 'dose', 'draft', 'dropping', 'drug packet', 'fix'],
    'skinful': ['bellyful', 'bumper', 'capacity', 'charge', 'complement', 'cram', 'crush', 'engorgement', 'fill', 'full house', 'full measure', 'fullness'],
    'skinned': ['all up with', 'beat', 'beaten', 'bested', 'confounded', 'defeated', 'discomfited', 'done for', 'done in', 'down', 'fallen', 'fixed'],
    'skinny': ['angular', 'bony', 'cortical', 'cutaneous', 'dermal', 'dermic', 'ecderonic', 'ectodermal', 'ectodermic', 'emaciated', 'endermatic', 'endermic'],
    'skip': ['highland fling', 'abandon', 'abscond', 'absquatulate', 'amble', 'and jump', 'antic', 'avoid', 'avoidance', 'bail out', 'barge', 'beam'],
    'skip over': ['blink', 'carefully ignore', 'cold-shoulder', 'cut a corner', 'cut corners', 'dip into', 'dodge', 'examine cursorily', 'fudge', 'give the once-over', 'glance at', 'page through'],
    'skipper': ['od', 'admiral', 'be responsible for', 'boatswain', 'boss', 'call the signals', 'captain', 'carry on', 'chief', 'chief engineer', 'chief mate', 'chief petty officer'],
    'skirmish': ['action', 'aerial combat', 'affray', 'ambush', 'armored combat', 'assault', 'attack', 'battle', 'battle royal', 'box', 'brawl', 'broil'],
    'skirt': ['jane', 'mother hubbard', 'adjoin', 'babe', 'baby', 'ballet skirt', 'bank', 'befringe', 'beg', 'biddy', 'bind', 'bird'],
    'skit': ['grand guignol', 'passion play', 'tom show', 'act', 'afterpiece', 'antimasque', 'audience success', 'ballet', 'bit', 'bomb', 'broadcast drama', 'burlesque show'],
    'skittish': ['agitable', 'allergic', 'anaphylactic', 'animated', 'antic', 'bashful', 'capersome', 'changeable', 'coltish', 'combustible', 'confused', 'conscious'],
    'skulduggery': ['artifice', 'chicane', 'chicanery', 'collusion', 'connivance', 'connivery', 'conspiracy', 'covin', 'dodgery', 'foul play', 'machination', 'pettifoggery'],
    'skulk': ['army', 'bunch', 'clock watcher', 'colony', 'couch', 'cower', 'creep', 'cringe', 'crouch', 'dodge', 'dog it', 'drift'],
    'skulking': ['back-door', 'backstairs', 'clandestine', 'covert', 'cowering', 'cringing', 'doggo', 'feline', 'furtive', 'hidden out', 'hidlings', 'hole-and-corner'],
    'skull': ['azrael', 'black death', 'death', 'grim reaper', 'pale death', 'reaper', 'angel of death', 'brain box', 'brainpan', 'cranium', 'crossbones', 'epicranium'],
    'skull and crossbones': ['azrael', 'black death', 'death', 'grim reaper', 'pale death', 'reaper', 'angel of death', 'armory', 'badge', 'badge of office', 'badges', 'baton'],
    'skull session': ['assignment', 'chalk talk', 'discourse', 'disquisition', 'exercise', 'exposition', 'harangue', 'homework', 'homily', 'instruction', 'lecture', 'lecture-demonstration'],
    'skunk': ['cape polecat', 'animal', 'ape', 'bar', 'bear', 'beast', 'beat', 'blank', 'bulldoze', 'cavy', 'chimp', 'chimpanzee'],
    'sky': ['caelus', 'olympian heights', 'acme', 'aerial heights', 'air', 'apex', 'apogee', 'azure', 'blue sky', 'brow', 'caelum', 'canopy'],
    'sky blue': ['azure', 'azure-blue', 'azure-colored', 'azurean', 'azured', 'azureous', 'beryl-blue', 'berylline', 'blue', 'bluish', 'cerulean', 'ceruleous'],
    'sky dive': ['bail out', 'belly buster', 'belly flop', 'belly whopper', 'brolly', 'cannonball', 'chaplain', 'churchman', 'chute', 'cleric', 'clerical', 'clerk'],
    'skylark': ['carouse', 'celebrate', 'cut loose', 'debauch', 'hell around', 'jollify', 'jolly', 'lark', 'let go', 'let loose', 'let off steam', 'make merry'],
    'skylight': ['afterglow', 'air glow', 'bay', 'bay window', 'bow window', 'candescence', 'casement', 'casement window', 'ceiling', 'eaves', 'fan window', 'fanlight'],
    'skyrocket': ['advance', 'ameliorate', 'amend', 'bob up', 'break water', 'climb', 'come along', 'come on', 'develop', 'float up', 'fly up', 'fountain'],
    'skyrocketing': ['anabatic', 'ascendant', 'ascending', 'ascensional', 'ascensive', 'climbing', 'cutthroat', 'exacting', 'excessive', 'exorbitant', 'extortionate', 'extravagant'],
    'skyscraper': ['antenna tower', 'architecture', 'barbican', 'belfry', 'bell tower', 'building', 'campanile', 'casa', 'cliff dwelling', 'colossus', 'column', 'construct'],
    'skyward': ['above', 'abovestairs', 'airward', 'aloft', 'aloof', 'heavenward', 'high', 'high up', 'in the air', 'in the clouds', 'on high', 'on stilts'],
    'slab': ['bar', 'beam', 'billet', 'board', 'boarding', 'chunk', 'clapboard', 'coat', 'coating', 'collop', 'cord', 'cordwood'],
    'slabber': ['dribble', 'drivel', 'drool', 'expectorate', 'expectoration', 'foam', 'froth', 'hawk', 'mouth-watering', 'ptyalism', 'saliva', 'salivate'],
    'slabby': ['adhesive', 'amylaceous', 'barfy', 'clabbered', 'clammy', 'clotted', 'coagulated', 'crappy', 'curdled', 'dirty', 'disgusting', 'doughy'],
    'slack': ['laodicean', 'micawberish', 'olympian', 'paphian', 'abandon', 'abate', 'abatement', 'abeyant', 'aloof', 'ambling', 'anemic', 'apathetic'],
    'slacken': ['abate', 'allay', 'alleviate', 'anesthetize', 'appease', 'arrest', 'assuage', 'attemper', 'attenuate', 'backpedal', 'backwater', 'bank the fire'],
    'slackening': ['abatement', 'allayment', 'alleviation', 'arrest', 'assuagement', 'attenuation', 'attrition', 'blunting', 'calming', 'check', 'damping', 'deadening'],
    'slacker': ['bungler', 'clock watcher', 'disregarder', 'dodger', 'eye-servant', 'goldbrick', 'goldbricker', 'goof-off', 'idler', 'ignorer', 'loafer', 'malingerer'],
    'slag': ['alluvion', 'alluvium', 'ash', 'ashes', 'bones', 'brand', 'calx', 'carbon', 'chaff', 'charcoal', 'cinder', 'clinker'],
    'slake': ['abate', 'allay', 'alleviate', 'anesthetize', 'appease', 'assuage', 'bate', 'benumb', 'cloy', 'cram', 'cushion', 'deaden'],
    'slam': ['parthian shot', 'adverse criticism', 'altogether', 'animadversion', 'aspersion', 'attack', 'back answer', 'bad notices', 'bad press', 'bang', 'bang into', 'bar'],
    'slam bang': ['a corps perdu', 'carelessly', 'desperately', 'furiously', 'happen what may', 'hastily', 'head over heels', 'headfirst', 'headforemost', 'headlong', 'heedlessly', 'heels over head'],
    'slander': ['asperse', 'assail', 'attack', 'backbite', 'backbiting', 'backstabbing', 'barefaced lie', 'belie', 'belittlement', 'bitchiness', 'blackwash', 'calumniate'],
    'slanderer': ['thersites', 'backbiter', 'belittler', 'calumniator', 'caustic critic', 'cynic', 'debunker', 'decrier', 'defamer', 'deflater', 'depreciator', 'derogator'],
    'slanderous': ['abusive', 'back-biting', 'backbiting', 'belittling', 'bitchy', 'calumniatory', 'calumnious', 'catty', 'censorious', 'contemptuous', 'contumelious', 'decrying'],
    'slang': ['aesopian language', 'babel', 'greek', 'argot', 'babble', 'barbarism', 'bluff', 'bluster', 'bluster and bluff', 'bounce', 'brag', 'bully'],
    'slant': ['anschauung', 'aberrancy', 'aberration', 'across', 'action', 'aim', 'anagnorisis', 'angle', 'angle of vision', 'angularity', 'animus', 'approach'],
    'slanted': ['aslant', 'aslope', 'atilt', 'bevel', 'beveled', 'bias', 'biased', 'canting', 'careening', 'cooked', 'doctored', 'garbled'],
    'slanting': ['abstractionism', 'aslant', 'aslope', 'atilt', 'bevel', 'beveled', 'bias', 'biased', 'canting', 'careening', 'coloring', 'corruption'],
    'slap': ['parthian shot', 'abruptly', 'altogether', 'attack', 'back answer', 'bang', 'bash', 'bat', 'beat', 'biff', 'blip', 'blow'],
    'slap on': ['add', 'adjoin', 'affix', 'agglutinate', 'annex', 'append', 'attach', 'bedaub', 'besmear', 'burden', 'butter', 'coat'],
    'slapdash': ['a corps perdu', 'accident-prone', 'aimless', 'airily', 'amain', 'any old way', 'any which way', 'anyhow', 'apace', 'at once', 'breakneck', 'bunglingly'],
    'slaphappy': ['balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'bedazzled', 'bonkers', 'buggy', 'bughouse', 'bugs', 'crackers'],
    'slapstick': ['atticism', 'thalia', 'acting', 'agile wit', 'arlequinade', 'black comedy', 'black humor', 'bladder', 'broad', 'broad comedy', 'buffoonery', 'burlesque'],
    'slash': ['vandyke', 'abbreviate', 'abrade', 'abrasion', 'abridge', 'amputate', 'assail', 'attack', 'ax', 'band', 'bar', 'bark'],
    'slashed': ['aggravated', 'best', 'bottom', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped', 'cracked', 'crazed', 'cut'],
    'slashing': ['abscission', 'acid', 'amputation', 'biting', 'burr', 'butchering', 'chiseling', 'chopping', 'cleavage', 'corrosive', 'cross-hatching', 'cutting'],
    'slat': ['mystik tape', 'scotch tape', 'adhesive tape', 'band', 'bandage', 'bang', 'batten', 'beam', 'belt', 'billet', 'board', 'boarding'],
    'slate': ['australian ballot', 'indiana ballot', 'massachusetts ballot', 'absentee ballot', 'agenda', 'ballot', 'batting order', 'bill', 'bill of fare', 'blanket ballot', 'blister', 'blueprint'],
    'slather': ['bedaub', 'besmear', 'blow', 'butter', 'coat', 'dab', 'daub', 'dissipate', 'enamel', 'gamble away', 'gild', 'gloss'],
    'slattern': ['baggage', 'bimbo', 'blowsy', 'crone', 'dowdy', 'drab', 'draggletailed', 'fallen woman', 'frowsy', 'frump', 'gammer', 'hag'],
    'slatternly': ['beat-up', 'bedraggled', 'blowsy', 'blowzy', 'careless', 'chintzy', 'dilapidated', 'dirty', 'disheveled', 'disordered', 'dowdy', 'drabbletailed'],
    'slaughter': ['annihilate', 'annihilation', 'assault', 'attack', 'bane', 'barbarize', 'batter', 'battering', 'blood', 'bloodbath', 'bloodletting', 'bloodshed'],
    'slave': ['charlie mccarthy', 'agent', 'ancilla', 'apple-polisher', 'appliance', 'ass-licker', 'backscratcher', 'backslapper', 'beast of burden', 'bondmaid', 'bondman', 'bondslave'],
    'slave driver': ['big brother', 'simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'auditor', 'autarch', 'autocrat', 'boatswain', 'boss', 'caesar'],
    'slaver': ['adulate', 'apple-polish', 'babble', 'be insane', 'beslobber', 'beslubber', 'blandish', 'bootlick', 'cajole', 'compliment', 'conceit', 'cower'],
    'slavery': ['abjectness', 'absolutism', 'attendance', 'baseness', 'bond service', 'bondage', 'captivity', 'control', 'debt slavery', 'deprivation of freedom', 'dirty work', 'disenfranchisement'],
    'slavish': ['abused', 'apish', 'base', 'browbeaten', 'difficult', 'downtrod', 'downtrodden', 'emulative', 'formidable', 'ground down', 'heavy', 'henpecked'],
    'slaw': ['caesar salad', 'jell-o salad', 'waldorf salad', 'ambrosia', 'aspic', 'chef salad', 'cole slaw', 'combination salad', 'crab louis', 'fruit salad', 'green salad', 'herring salad'],
    'slay': ['amuse', 'annihilate', 'assassinate', 'becharm', 'beguile', 'bereave of life', 'bewitch', 'bump off', 'butcher', 'captivate', 'carry away', 'carry off'],
    'slayer': ['cain', 'apache', 'assassin', 'assassinator', 'bloodletter', 'bloodshedder', 'bravo', 'burker', 'butcher', 'button man', 'cannibal', 'cutthroat'],
    'slaying': ['bane', 'blood', 'bloodletting', 'bloodshed', 'braining', 'dealing death', 'destruction', 'destruction of life', 'dispatch', 'euthanasia', 'execution', 'extermination'],
    'sleazy': ['base', 'breakable', 'brittle', 'broken-down', 'cheap', 'cheap-jack', 'cheesy', 'chintzy', 'cobwebby', 'common', 'contemptible', 'crappy'],
    'sled': ['skimobile', 'sno-cat', 'barge', 'blade', 'boat', 'bobsleigh', 'bus', 'cart', 'coach', 'coast', 'coaster', 'cutter'],
    'sledgehammer': ['bang', 'baste', 'batter', 'beat', 'buffet', 'bulldozer', 'coercive', 'drub', 'flail', 'flap', 'forcible', 'hammer'],
    'sleek': ['adipose', 'anal', 'balmy', 'blooming', 'blossoming', 'blubbery', 'booming', 'braw', 'buff', 'buffed', 'burnish', 'burnished'],
    'sleep': ['ko', 'annihilation', 'ataraxia', 'ataraxy', 'bane', 'be caught napping', 'be neglectful', 'be negligent', 'beauty sleep', 'beddy-bye', 'bedtime', 'biological death'],
    'sleep on': ['adjourn', 'continue', 'defer', 'delay', 'drag out', 'entertain', 'extend', 'hang fire', 'hang up', 'hold off', 'hold over', 'hold up'],
    'sleep with': ['ball', 'be intimate', 'cohabit', 'come together', 'commit adultery', 'copulate', 'couple', 'cover', 'diddle', 'fornicate', 'frig', 'have sex'],
    'sleeper': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'pullman', 'pullman car', 'seconal'],
    'sleepiness': ['acedia', 'apathy', 'boredom', 'brain fag', 'debilitation', 'debility', 'drowsiness', 'dullness', 'enervation', 'enfeeblement', 'ennui', 'eyestrain'],
    'sleeping': ['abeyant', 'apathetic', 'asleep', 'asleep in jesus', 'at rest', 'bereft of life', 'between the lines', 'breathless', 'called home', 'carrion', 'cataleptic', 'catatonic'],
    'sleeping pill': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'sleeping sickness': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'sleepless': ['argus-eyed', 'agile', 'alert', 'alive', 'all ears', 'all eyes', 'ardent', 'assiduous', 'attentive', 'aux aguets', 'awake', 'bright'],
    'sleeplessness': ['acuity', 'acuteness', 'agility', 'alertness', 'all-night vigil', 'attention', 'attentiveness', 'brightness', 'consciousness', 'insomnia', 'insomniac', 'insomnolence'],
    'sleepwalking': ['amnesia', 'beauty sleep', 'beddy-bye', 'bedtime', 'blanket drill', 'bye-bye', 'catalepsy', 'cataplexy', 'catatonic stupor', 'daydreaming', 'daze', 'doze'],
    'sleepy': ['anesthetized', 'apathetic', 'asleep', 'beat', 'benumbed', 'blase', 'bored', 'boring', 'cataleptic', 'comatose', 'dazed', 'dead'],
    'sleepyhead': ['dawdle', 'dawdler', 'drone', 'foot-dragger', 'goldbrick', 'goof-off', 'laggard', 'lie-abed', 'lingerer', 'loiterer', 'plodder', 'procrastinator'],
    'sleet': ['dry ice', 'berg', 'calf', 'cryosphere', 'firn', 'floe', 'frazil', 'frost', 'frozen water', 'glaciation', 'glacier', 'glacieret'],
    'sleety': ['siberian', 'algid', 'arctic', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'boreal', 'brisk', 'brumal', 'cold'],
    'sleigh': ['skimobile', 'sno-cat', 'blade', 'coast', 'flit', 'flow', 'fly', 'glide', 'glissade', 'ice-skate', 'roller-skate', 'runner'],
    'sleigh bell': ['bell', 'chimes', 'church bell', 'clapper', 'cowbell', 'dinner bell', 'dinner gong', 'doorbell', 'fire bell', 'gong', 'gong bell', 'hand bell'],
    'sleight': ['adroitness', 'art', 'artful dodge', 'artifice', 'bag of tricks', 'blind', 'bluff', 'bosey', 'catch', 'chicane', 'chicanery', 'chouse'],
    'sleight of hand': ['prospero', 'airiness', 'appearance', 'artful dodge', 'artifice', 'bag of tricks', 'blind', 'bluff', 'bosey', 'catch', 'chicanery', 'chouse'],
    'slender': ['junoesque', 'lenten', 'spartan', 'abstemious', 'agreeable', 'airy', 'amply endowed', 'angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'ascetic'],
    'sleuth': ['bow street runner', 'fbi', 'fbi agent', 'federal', 'g-man', 'secret service', 'sherlock', 'sherlock holmes', 't-man', 'detective', 'dick', 'eye'],
    'slew': ['batch', 'bunch', 'clump', 'cluster', 'considerable', 'copse', 'crop', 'deal', 'gobs', 'good deal', 'great deal', 'group'],
    'slice': ['allotment', 'allowance', 'amputate', 'apportion', 'ax', 'big end', 'bigger half', 'bisect', 'bit', 'bite', 'breach', 'break'],
    'slick': ['byzantine', 'ciceronian', 'daedalian', 'demosthenian', 'demosthenic', 'machiavellian', 'machiavellic', 'tullian', 'acute', 'adept', 'adipose', 'adroit'],
    'slicker': ['abradant', 'abrasive', 'bunco artist', 'bunco steerer', 'burnish', 'cardsharp', 'cardsharper', 'carpetbagger', 'cheat', 'cheater', 'city slicker', 'con artist'],
    'slide': ['photostat', 'telephoto', 'wirephoto', 'xerox', 'xerox copy', 'advance', 'aerial photograph', 'aerophone', 'alabaster', 'avalanche', 'be effortless', 'be painless'],
    'slide back': ['backslide', 'fall', 'fall again into', 'fall back', 'fall from grace', 'have a relapse', 'lapse', 'lapse back', 'recidivate', 'recur to', 'regress', 'relapse'],
    'slide trombone': ['alpenhorn', 'alphorn', 'althorn', 'alto horn', 'ballad horn', 'baritone', 'bass horn', 'brass choir', 'brass wind', 'brass-wind instrument', 'brasses', 'bugle'],
    'sliding': ['coasting', 'coming apart', 'cracking', 'crumbling', 'decadent', 'declining', 'degenerate', 'deteriorating', 'disintegrating', 'draining', 'drooping', 'dwindling'],
    'sliding scale': ['base pay', 'compensation', 'dismissal wage', 'earnings', 'escalator clause', 'escalator plan', 'financial remuneration', 'gross income', 'guaranteed annual wage', 'hire', 'income', 'living wage'],
    'slight': ['lenten', 'spartan', 'abstemious', 'adulterated', 'affront', 'airy', 'ankle-deep', 'ascetic', 'asinine', 'attenuate', 'attenuated', 'austere'],
    'slighted': ['abandoned', 'deserted', 'disregarded', 'half-done', 'ignored', 'laid aside', 'left undone', 'missed', 'neglected', 'omitted', 'overlooked', 'passed by'],
    'slightly': ['a bit', 'a little', 'barely', 'by a hair', 'by an ace', 'ever so little', 'exiguously', 'extremely', 'faintly', 'fairly', 'feebly', 'frugally'],
    'slim': ['lenten', 'spartan', 'abstemious', 'adroit', 'airy', 'ascetic', 'attenuate', 'attenuated', 'austere', 'barebones', 'bean pole', 'beanstalk'],
    'slim pickings': ['lenten fare', 'austerity', 'exiguity', 'exiguousness', 'jejuneness', 'jejunity', 'leanness', 'meagerness', 'meanness', 'miserliness', 'narrowness', 'niggardliness'],
    'slime': ['carrion', 'clay', 'corruption', 'dandruff', 'decay', 'excrement', 'filth', 'foul matter', 'furfur', 'gangrene', 'glop', 'gumbo'],
    'slimy': ['abject', 'adhesive', 'adulatory', 'amylaceous', 'barfy', 'bland', 'blandishing', 'blarneying', 'buttery', 'cajoling', 'clabbered', 'clammy'],
    'sling': ['ace bandage', 'band-aid', 'adhesive tape', 'application', 'arbalest', 'ballista', 'band', 'bandage', 'bandaging', 'belt', 'binder', 'bowl'],
    'slink': ['amble', 'barge', 'bowl along', 'bundle', 'clump', 'contort', 'corkscrew', 'couch', 'cower', 'crawl', 'creep', 'cringe'],
    'slinky': ['airy', 'attenuate', 'attenuated', 'back-door', 'backstairs', 'boyish', 'clandestine', 'covert', 'cowering', 'cringing', 'delicate', 'diaphanous'],
    'slip': ['mystik tape', 'scotch tape', 'accord', 'adhesive tape', 'administer', 'adolescent', 'advance', 'afford', 'afghan', 'allot', 'allow', 'amplitude'],
    'slip away': ['bow out', 'creep out of', 'depart', 'disappear', 'duck out', 'escape', 'exit', 'find a loophole', 'go on furlough', 'go on leave', 'leave the scene', 'mooch off'],
    'slip back': ['backslide', 'cock', 'degenerate', 'deteriorate', 'disimprove', 'fall', 'fall again into', 'fall astern', 'fall back', 'fall behind', 'fall from grace', 'get behind'],
    'slip in': ['admit', 'barge in', 'be admitted', 'break in', 'break in upon', 'breeze in', 'burst in', 'bust in', 'butt in', 'charge in', 'come barging in', 'come between'],
    'slip out of': ['bow out', 'cast off', 'creep out of', 'depart', 'disappear', 'dodge', 'doff', 'dog it', 'douse', 'drop', 'duck', 'duck duty'],
    'slip up': ['blunder', 'bungle', 'deviate', 'err', 'fall into error', 'foozle', 'go amiss', 'go astray', 'go awry', 'go wrong', 'goof', 'lapse'],
    'slippage': ['avalanche', 'coast', 'comedown', 'debasement', 'decadence', 'decadency', 'declension', 'declination', 'decline', 'deformation', 'degeneracy', 'degenerateness'],
    'slippery': ['machiavellian', 'machiavellic', 'acute', 'adipose', 'ambidextrous', 'amoral', 'arch', 'artful', 'astute', 'blubbery', 'buttery', 'butyraceous'],
    'slipping': ['bad', 'coming apart', 'cracking', 'crumbling', 'decadent', 'declining', 'degenerate', 'despaired of', 'deteriorating', 'disintegrating', 'done for', 'draining'],
    'slipshod': ['barbarous', 'beat-up', 'bedraggled', 'blowzy', 'botched', 'bungling', 'careless', 'chintzy', 'clumsy', 'deficient', 'dilapidated', 'disheveled'],
    'slipup': ['balk', 'bevue', 'blooper', 'blunder', 'boner', 'bungle', 'error', 'false move', 'false step', 'fluff', 'inadvertence', 'inadvertency'],
    'slit': ['abrade', 'abysm', 'abyss', 'aggravated', 'amputate', 'aperture', 'arroyo', 'ax', 'bark', 'bezel', 'bisect', 'blemish'],
    'slither': ['amble', 'avalanche', 'barge', 'bowl along', 'bundle', 'clump', 'coast', 'coasting', 'crawl', 'creep', 'drag', 'droop'],
    'slithering': ['amphibian', 'anguine', 'batrachian', 'coasting', 'colubriform', 'crawling', 'creeping', 'crocodilian', 'flow', 'flowing', 'froggy', 'glide'],
    'slithery': ['adhesive', 'amylaceous', 'buttery', 'clabbered', 'clammy', 'clotted', 'coagulated', 'curdled', 'doughy', 'gaumy', 'gelatinous', 'glairy'],
    'sliver': ['bit', 'black sheep', 'blemish', 'butt', 'carve', 'chip', 'chunk', 'clip', 'clipping', 'collop', 'crumb', 'cut'],
    'slob': ['dry ice', 'berg', 'boor', 'butterfingers', 'calf', 'churl', 'clay', 'clumsy', 'cryosphere', 'drab', 'dub', 'duffer'],
    'slobber': ['asperge', 'babble', 'be insane', 'be stupid', 'bedew', 'bespatter', 'besprinkle', 'blather', 'blither', 'burble', 'dabble', 'damp'],
    'slobber over': ['adulate', 'be theatrical', 'beslobber', 'beslubber', 'blandish', 'cajole', 'compliment', 'conceit', 'emote', 'emotionalize', 'fawn upon', 'flatter'],
    'sloe': ['atramentous', 'black', 'black as coal', 'black as ebony', 'black as ink', 'black as midnight', 'black as night', 'coal-black', 'coaly', 'dark', 'dark as night', 'dark as pitch'],
    'slog': ['amble', 'bang', 'barge', 'bash', 'bat', 'belt', 'biff', 'bonk', 'bowl along', 'bundle', 'catch', 'clap'],
    'slogan': ['bugle call', 'byword', 'call to arms', 'call-up', 'catch phrase', 'catchword', 'clarion', 'clarion call', 'cliche', 'conscription', 'cry', 'device'],
    'slop': ['asperge', 'bathos', 'bedew', 'bespatter', 'besprinkle', 'bilge', 'bilgewater', 'bleeding heart', 'bolt', 'bones', 'carrion', 'cascade'],
    'slope': ['acclivity', 'angle', 'angularity', 'ascend', 'ascent', 'bank', 'bend', 'bevel', 'bezel', 'camber', 'cant', 'careen'],
    'sloping': ['aslant', 'aslope', 'atilt', 'bevel', 'beveled', 'bias', 'biased', 'canting', 'careening', 'inclinational', 'inclinatory', 'inclined'],
    'sloppy': ['all thumbs', 'amateurish', 'aquatic', 'aqueous', 'awkward', 'bagging', 'baggy', 'barfy', 'bathetic', 'beat-up', 'bedraggled', 'beery'],
    'slops': ['barley', 'bilge', 'bilgewater', 'bird seed', 'bones', 'bran', 'carrion', 'cat food', 'chaff', 'chicken feed', 'chop', 'corn'],
    'slosh': ['asperge', 'avalanche', 'babble', 'bang', 'bash', 'bat', 'bedew', 'belt', 'bespatter', 'besprinkle', 'biff', 'blizzard'],
    'sloshy': ['barfy', 'crappy', 'dirty', 'disgusting', 'fecal', 'feculent', 'fetid', 'filthy', 'flyblown', 'foul', 'gloppy', 'gunky'],
    'slot': ['ic analysis', 'abysm', 'abyss', 'aperture', 'appositive', 'arroyo', 'assign', 'assignment', 'attribute', 'attributive', 'box canyon', 'breach'],
    'sloth': ['chiroptera', 'lagomorpha', 'primates', 'rodentia', 'accidia', 'acedia', 'aloofness', 'anger', 'apathy', 'army', 'ataraxia', 'ataraxy'],
    'slothful': ['ambling', 'apathetic', 'bone-lazy', 'cadging', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'deliberate', 'dilatory'],
    'slouch': ['amble', 'andante', 'arm', 'barge', 'bay', 'bayou', 'bend', 'blockhead', 'blunderer', 'blunderhead', 'bog', 'boor'],
    'slough': ['abandon', 'baygall', 'bilge', 'bilgewater', 'bind', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'caries', 'carrion'],
    'slovenly': ['barbarous', 'beat-up', 'bedraggled', 'blowsy', 'blowzy', 'botched', 'bungling', 'careless', 'chintzy', 'clumsy', 'deficient', 'dilapidated'],
    'slow': ['boeotian', 'micawberish', 'after time', 'almost unheard-of', 'ambling', 'apathetic', 'arid', 'arrest', 'arrested', 'averse', 'back', 'backpedal'],
    'slow down': ['abate', 'allay', 'alleviate', 'arrest', 'assuage', 'attemper', 'backpedal', 'backwater', 'bank the fire', 'block', 'blunt', 'bog down'],
    'slow motion': ['andante', 'claudication', 'crawl', 'creep', 'dead march', 'dogtrot', 'footpace', 'funeral march', 'hobble', 'jog', 'jog trot', 'leisurely gait'],
    'slow time': ['alaska time', 'atlantic time', 'central time', 'eastern time', 'gmt', 'greenwich mean time', 'greenwich time', 'mountain time', 'yukon time', 'apparent time', 'civil time', 'daylight-saving time'],
    'slow up': ['afterthought', 'arrest', 'backpedal', 'backwater', 'bind', 'block', 'blockage', 'brake', 'bureaucratic delay', 'check', 'clip the wings', 'curb'],
    'slow witted': ['blunt', 'blunt-witted', 'dim', 'dim-witted', 'dopey', 'dull', 'dull of mind', 'dull-headed', 'dull-pated', 'dull-witted', 'fat-witted', 'gross-headed'],
    'slowdown': ['action', 'afterthought', 'arrest', 'bind', 'block', 'blockage', 'boom', 'bottoming out', 'boycott', 'boycottage', 'bureaucratic delay', 'business cycle'],
    'slowing down': ['arrest', 'arrestation', 'check', 'constraint', 'control', 'cooling', 'cooling down', 'cooling off', 'curb', 'curtailment', 'deceleration', 'delay'],
    'slowly': ['aridly', 'barrenly', 'bit by bit', 'bloodlessly', 'by degrees', 'by inches', 'by inchmeal', 'by slow degrees', 'cautiously', 'circumspectly', 'colorlessly', 'crawlingly'],
    'slowness': ['fabian policy', 'micawberism', 'acedia', 'afterthought', 'amble', 'antipathy', 'apathy', 'aridity', 'asininity', 'averseness', 'aversion', 'backwardness'],
    'slowpoke': ['dawdle', 'dawdler', 'drone', 'foot-dragger', 'goldbrick', 'goof-off', 'laggard', 'lie-abed', 'lingerer', 'loiterer', 'plodder', 'procrastinator'],
    'sludge': ['dry ice', 'berg', 'calf', 'clay', 'cryosphere', 'dregs', 'firn', 'floe', 'frazil', 'frozen water', 'glaciation', 'glacier'],
    'sludgy': ['barfy', 'crappy', 'dirty', 'disgusting', 'fecal', 'feculent', 'fetid', 'filthy', 'flyblown', 'foul', 'gloppy', 'gunky'],
    'slug': ['chilopoda', 'chordata', 'echiuroidea', 'ectoprocta', 'entoprocta', 'intertype', 'linotype', 'monoplacophora', 'monotype', 'nemertinea', 'phoronidea', 'baggage check'],
    'sluggard': ['bum', 'clock watcher', 'dallier', 'dawdle', 'dawdler', 'diddler', 'dillydallier', 'do-nothing', 'dolittle', 'doodler', 'drone', 'faineant'],
    'sluggish': ['laodicean', 'micawberish', 'olympian', 'abeyant', 'affluent', 'aloof', 'ambling', 'apathetic', 'backward', 'benumbed', 'blah', 'blase'],
    'sluggishness': ['hebetude', 'idleness', 'indolence', 'laggardness', 'languidness', 'languor', 'lassitude', 'laze', 'laziness', 'lethargy', 'lifelessness', 'phlegm'],
    'sluice': ['aboideau', 'air lock', 'aqueduct', 'arroyo', 'avenue', 'baptize', 'bath', 'bathe', 'bed', 'blow out', 'blowhole', 'canal'],
    'slum': ['augean stables', 'bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'barrio', 'black ghetto', 'blighted area'],
    'slumber': ['ataraxia', 'ataraxy', 'beauty sleep', 'beddy-bye', 'bedtime', 'blanket drill', 'bye-bye', 'calmness', 'coma', 'composure', 'contemplation', 'dorm'],
    'slumbering': ['abeyant', 'apathetic', 'asleep', 'cataleptic', 'catatonic', 'comatose', 'dead', 'dead asleep', 'deep asleep', 'dopey', 'dormant', 'dull'],
    'slumberland': ['beauty sleep', 'beddy-bye', 'bedtime', 'blanket drill', 'bye-bye', 'doze', 'dreamland', 'drowse', 'fitful sleep', 'hibernation', 'land of nod', 'light sleep'],
    'slumberous': ['comatose', 'dopey', 'dozy', 'drowsy', 'heavy', 'hebetudinous', 'hypnotic', 'narcotic', 'nodding', 'opiate', 'sluggish', 'snoozy'],
    'slummy': ['battered', 'beat-up', 'beaten up', 'broken-down', 'decrepit', 'derelict', 'dilapidated', 'in ruins', 'ramshackle', 'ruined', 'ruinous', 'run-down'],
    'slump': ['arrear', 'arrearage', 'arrears', 'bad times', 'be found wanting', 'bear market', 'bearish market', 'beat down', 'boom', 'bottoming out', 'break', 'business cycle'],
    'slur': ['accent', 'accent mark', 'affront', 'asperse', 'aspersion', 'attaint', 'bad-mouth', 'badge of infamy', 'bar', 'bar sinister', 'baton', 'bedaub'],
    'slur over': ['allow for', 'becloud', 'befog', 'blanket', 'blind', 'blink', 'blink at', 'camouflage', 'carefully ignore', 'cloak', 'cloud', 'cold-shoulder'],
    'slurp': ['aspirate', 'beverage', 'breathe in', 'bumper', 'draft', 'dram', 'draw in', 'drench', 'drink', 'drinking', 'eating', 'engorgement'],
    'slurp up': ['absorb', 'adsorb', 'assimilate', 'blot', 'blot up', 'chemisorb', 'chemosorb', 'digest', 'drink', 'drink in', 'drink up', 'engross'],
    'slush': ['avalanche', 'bathos', 'big mouth', 'bleeding heart', 'blizzard', 'candor', 'clay', 'cloyingness', 'communicativeness', 'conversableness', 'crystal', 'driven snow'],
    'slushy': ['siberian', 'algid', 'arctic', 'barfy', 'bathetic', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'boreal', 'brisk'],
    'slut': ['jezebel', 'partlet', 'bad woman', 'baggage', 'bandog', 'biddy', 'bitch', 'bossy', 'bowwow', 'broad', 'brood mare', 'bungler'],
    'sluttish': ['beat-up', 'bedraggled', 'blowzy', 'botched', 'bungling', 'careless', 'chintzy', 'clumsy', 'deficient', 'dilapidated', 'drabbletailed', 'draggled'],
    'sly': ['byzantine', 'machiavellian', 'machiavellic', 'acute', 'adroit', 'arch', 'artful', 'astute', 'back-door', 'backstairs', 'cagey', 'calculating'],
    'smack': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'smack of': ['ape', 'appear like', 'approach', 'approximate', 'be like', 'be redolent of', 'bear resemblance', 'bring to mind', 'call to mind', 'call up', 'come close', 'come near'],
    'smacking': ['active', 'activist', 'activistic', 'acute', 'aggressive', 'alive', 'animated', 'bouncing', 'bouncy', 'breezy', 'brisk', 'bubbly'],
    'small': ['lenten', 'lilliputian', 'spartan', 'abject', 'abominable', 'abstemious', 'airy', 'arrant', 'ascetic', 'atrocious', 'attenuate', 'attenuated'],
    'small chance': ['bare possibility', 'dark horse', 'doubtfulness', 'dubiousness', 'equivalent odds', 'even break', 'even chance', 'faint likelihood', 'fighting chance', 'gambling chance', 'good chance', 'hardly a chance'],
    'small change': ['bric-a-brac', 'chaff', 'change', 'chicken feed', 'chickenshit', 'details', 'froth', 'gimcrackery', 'knickknackery', 'minutiae', 'peanuts', 'petty cash'],
    'small fry': ['a nobody', 'a nothing', 'babyhood', 'bantam', 'banty', 'boyhood', 'button', 'childkind', 'children', 'chit', 'cipher', 'common man'],
    'small hours': ['alpenglow', 'aurora', 'belatedness', 'crepuscule', 'dawnlight', 'eleventh hour', 'first light', 'foredawn', 'glow', 'half-light', 'high time', 'last minute'],
    'small minded': ['authoritarian', 'bigot', 'bigoted', 'borne', 'closed', 'constricted', 'cramped', 'creedbound', 'deaf', 'deaf to reason', 'fanatical', 'hidebound'],
    'small potatoes': ['middle america', 'a nobody', 'a nothing', 'bourgeoisie', 'burgherdom', 'cipher', 'common man', 'dummy', 'figurehead', 'fourth-rater', 'insignificancy', 'jackstraw'],
    'small print': ['boundary condition', 'catch', 'clause', 'condition', 'donnee', 'escalator clause', 'escape clause', 'escape hatch', 'fine print', 'given', 'grounds', 'joker'],
    'small talk': ['babble', 'babbling', 'backchat', 'badinage', 'banter', 'bavardage', 'beauty-parlor chitchat', 'bibble-babble', 'chatter', 'chitchat', 'chitter-chatter', 'cocktail-party chitchat'],
    'small time': ['dinky', 'insignificant', 'jerkwater', 'lesser', 'measly', 'niggling', 'one-horse', 'pettifogging', 'petty', 'picayune', 'picayunish', 'piddling'],
    'smaller': ['abated', 'ablated', 'attenuated', 'bated', 'belittled', 'consumed', 'contracted', 'curtailed', 'decreased', 'deflated', 'diminished', 'dissipated'],
    'smallness': ['lenten fare', 'abjectness', 'abominableness', 'atrociousness', 'austerity', 'authoritarianism', 'baseness', 'beggarliness', 'bigotry', 'blind side', 'blind spot', 'blinders'],
    'smallpox': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'smarmy': ['adulatory', 'bland', 'blandishing', 'blarneying', 'buttery', 'cajoling', 'complimentary', 'courtierly', 'courtly', 'fair-spoken', 'fawning', 'fine-spoken'],
    'smart': ['attic', 'ache', 'active', 'acute', 'adept', 'adroit', 'affect', 'affliction', 'agile', 'agonize', 'ail', 'alacritous'],
    'smart aleck': ['narcissus', 'blowhard', 'boaster', 'boldface', 'braggadocio', 'braggart', 'brazenface', 'chutzpanik', 'egocentric', 'egoist', 'egotist', 'exhibitionist'],
    'smart alecky': ['aggressively self-confident', 'bantering', 'biggety', 'bluff', 'bold-faced', 'booing', 'brash', 'bumptious', 'catcalling', 'chaffing', 'cheeky', 'chesty'],
    'smart ass': ['gothamite', 'bantering', 'biggety', 'bluff', 'boldface', 'booing', 'brash', 'brazenface', 'catcalling', 'chaffing', 'cheeky', 'chutzpadik'],
    'smart set': ['vanity fair', 'aristocracy', 'beau monde', 'beautiful people', 'best people', 'blue bloods', 'bon ton', 'cafe society', 'carriage trade', 'cream of society', 'drawing room', 'elite'],
    'smarten up': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'color', 'dandify', 'deck', 'deck out', 'decorate', 'dizen'],
    'smarts': ['vernunft', 'acuity', 'acuteness', 'adroitness', 'aptitude', 'aptness', 'brain', 'braininess', 'brains', 'brightness', 'brilliance', 'clear thinking'],
    'smarty': ['boldface', 'brazenface', 'chutzpanik', 'hussy', 'know-it-all', 'malapert', 'minx', 'pup', 'puppy', 'saucebox', 'smart', 'smart aleck'],
    'smash': ['waterloo', 'abrade', 'accident', 'annihilate', 'appulse', 'asphyxiate', 'atomize', 'bang', 'bang into', 'bash', 'bastinado', 'bat'],
    'smashed': ['afflicted', 'aggravated', 'bent', 'boiled', 'bombed', 'boozy', 'broken', 'burned', 'burst', 'busted', 'canned', 'checked'],
    'smashing': ['ok', 'smyth sewing', 'abrasion', 'ace-high', 'appulse', 'atomization', 'attrition', 'backing', 'bad', 'bang-up', 'beating', 'bibliopegy'],
    'smashup': ['accident', 'appulse', 'blow', 'breakdown', 'breaking up', 'breakup', 'brunt', 'bulldozing', 'bulling', 'bump', 'calamity', 'cannon'],
    'smatter': ['babble', 'burst', 'cackle', 'chat', 'chatter', 'clack', 'few', 'fragment', 'gab', 'gas', 'handful', 'jaw'],
    'smattering': ['a little learning', 'amateurism', 'cast', 'coquetry', 'dabbling', 'dalliance', 'dallying', 'dash', 'dilettantism', 'dilettantship', 'few', 'fiddling'],
    'smear': ['anoint', 'apply paint', 'asperse', 'aspersion', 'attack', 'attaint', 'badge of infamy', 'bar sinister', 'baton', 'beat', 'bedaub', 'bedizen'],
    'smell': ['apprehend', 'aroma', 'be aromatic', 'be aware of', 'be conscious of', 'be redolent of', 'be sensible of', 'be warm', 'bouquet', 'breath', 'breathe', 'breathe in'],
    'smelly': ['aromatic', 'bad', 'bad-smelling', 'effluvious', 'fecal', 'fetid', 'foul', 'fragrant', 'frowsty', 'frowy', 'frowzy', 'fulsome'],
    'smelt': ['carve', 'chisel', 'colliquate', 'convert', 'cultivate', 'defrost', 'extract', 'flux', 'fuse', 'grow', 'harvest', 'machine'],
    'smelting': ['architecture', 'assembly', 'blazing', 'blistering', 'branding', 'building', 'burning', 'calcination', 'carbonization', 'casting', 'cauterization', 'cautery'],
    'smidgen': ['ace', 'atom', 'bit', 'dab', 'dole', 'dot', 'dram', 'dribble', 'driblet', 'dwarf', 'farthing', 'fleck'],
    'smile': ['accost', 'address', 'be in heaven', 'be pleased', 'beam', 'bob', 'bow', 'bright smile', 'broad grin', 'caper', 'caracole', 'chirp'],
    'smiling': ['beam', 'beaming', 'beatific', 'beatified', 'blessed', 'blissful', 'blithe', 'blithesome', 'bright', 'bright and sunny', 'bright smile', 'broad grin'],
    'smirch': ['aspersion', 'attaint', 'badge of infamy', 'bar sinister', 'baton', 'bedarken', 'bedaub', 'begrime', 'bend sinister', 'besmear', 'besmirch', 'besmoke'],
    'smirched': ['bedraggled', 'befouled', 'besmirched', 'blackened', 'blotchy', 'darkened', 'defiled', 'dingy', 'dirtied', 'dirty', 'discolored', 'drabbled'],
    'smirk': ['beam', 'bridle', 'bright smile', 'broad grin', 'crack a smile', 'ear-to-ear grin', 'fleer', 'gleaming smile', 'glowing smile', 'grimace', 'grin', 'grinning'],
    'smirking': ['bantering', 'beaming', 'beatific', 'beatified', 'blessed', 'blissful', 'booing', 'capering', 'catcalling', 'chaffing', 'cheerful', 'chirping'],
    'smite': ['affect', 'agonize', 'bang', 'bash', 'baste', 'bastinado', 'bat', 'beat', 'belabor', 'belt', 'biff', 'birch'],
    'smith': ['hephaestus', 'vulcan', 'wayland', 'ancestors', 'anglesmith', 'apprentice', 'architect', 'artificer', 'artist', 'author', 'begetter', 'beginner'],
    'smithereen': ['bit', 'butt', 'chip', 'chunk', 'clip', 'clipping', 'collop', 'crumb', 'cut', 'cutting', 'dollop', 'end'],
    'smitten': ['affected', 'afflicted', 'attached to', 'becharmed', 'beguiled', 'beset', 'bewitched', 'bothered', 'burdened', 'captivated', 'charmed', 'crazy about'],
    'smoke': ['aerate', 'aerify', 'afterdamp', 'air', 'air-dry', 'airy nothing', 'anhydrate', 'ash', 'ashes', 'atomize', 'attaint', 'bake'],
    'smoke screen': ['alibi', 'apology', 'blind', 'camouflage', 'cloak', 'color', 'cover', 'cover story', 'cover-up', 'device', 'disguise', 'domino'],
    'smoker': ['kaffeeklatsch', 'pullman', 'pullman car', 'baggage car', 'ball', 'blowout', 'boxcar', 'caboose', 'car', 'carriage', 'chair car', 'chewer'],
    'smoking': ['ablaze', 'aeration', 'aerial', 'aerification', 'aerodynamic', 'aerostatic', 'aery', 'afire', 'aflame', 'aflicker', 'aglow', 'airy'],
    'smoky': ['quaker-colored', 'acier', 'aerial', 'aerodynamic', 'aerostatic', 'aery', 'airy', 'ashen', 'ashy', 'besmirched', 'blackened', 'blotchy'],
    'smolder': ['bake', 'be angry', 'be excitable', 'be in heat', 'be latent', 'be livid', 'be pissed', 'bellow', 'blaze', 'bloom', 'blow a gasket', 'blow up'],
    'smoldering': ['abeyant', 'ablaze', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'apathetic', 'ardent', 'blazing', 'boiling', 'burning'],
    'smooch': ['begrime', 'besoil', 'bill and coo', 'blow a kiss', 'buss', 'copulate', 'dally', 'dirty', 'foul', 'grime', 'kiss', 'lip'],
    'smooth': ['ciceronian', 'demosthenian', 'demosthenic', 'machiavellian', 'machiavellic', 'mickey mouse', 'tullian', 'accordant', 'acomous', 'acute', 'adipose', 'adulatory'],
    'smooth sailing': ['clarity', 'clear coast', 'clear road', 'ease', 'easiness', 'easy going', 'effortlessness', 'facileness', 'facility', 'freedom', 'highroad', 'intelligibility'],
    'smooth the way': ['aid', 'anoint', 'be promising', 'beeswax', 'bid fair to', 'clear the way', 'daub', 'dress', 'ease', 'embrocate', 'enable', 'expedite'],
    'smooth tongued': ['ciceronian', 'demosthenian', 'demosthenic', 'tullian', 'adulatory', 'articulate', 'bland', 'blandishing', 'blarneying', 'buttery', 'cajoling', 'complimentary'],
    'smoother': ['abradant', 'abrasive', 'buff', 'buffer', 'burnish', 'calender', 'chamois', 'drag', 'glazer', 'goose', 'grader', 'harrow'],
    'smoothly': ['ardently', 'artfully', 'astutely', 'cagily', 'calmly', 'cannily', 'cleverly', 'cunningly', 'easily', 'effectively', 'effortlessly', 'eloquently'],
    'smorgasbord': ['antepast', 'antipasto', 'aperitif', 'appetizer', 'automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canape'],
    'smother': ['od', 'abate', 'allay', 'alleviate', 'asphyxiate', 'assuage', 'attemper', 'bake', 'bank the fire', 'be in heat', 'be killed', 'beat'],
    'smothered': ['arcane', 'bated', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'crushed', 'cryptic', 'damped', 'dampened'],
    'smudge': ['afterdamp', 'ash', 'ashes', 'aspersion', 'attaint', 'badge of infamy', 'bar sinister', 'baton', 'bedarken', 'bedaub', 'begrime', 'bend sinister'],
    'smudgy': ['besmirched', 'blotchy', 'dingy', 'dirty', 'dusty', 'fuliginous', 'grimy', 'grubby', 'grungy', 'messy', 'miry', 'muddy'],
    'smug': ['quakerish', 'victorian', 'bland', 'bovine', 'braw', 'buttery', 'censorious', 'chic', 'classy', 'clothes-conscious', 'complacent', 'conceited'],
    'smugness': ['quakerishness', 'amour-propre', 'autoeroticism', 'blandness', 'bovinity', 'butter', 'censoriousness', 'complacence', 'complacency', 'consequentiality', 'demureness', 'demurity'],
    'smut': ['rabelaisianism', 'x-rated movie', 'air pollution', 'algae', 'alluvion', 'alluvium', 'ash', 'ashes', 'attritus', 'autophyte', 'bawdiness', 'bawdry'],
    'smutty': ['fescennine', 'rabelaisian', 'bawdy', 'besmirched', 'blasted', 'blighted', 'blotchy', 'blown', 'blue', 'coarse', 'despoiled', 'dingy'],
    'snack': ['bait', 'bit', 'bite', 'butt', 'chip', 'chunk', 'clip', 'clipping', 'collation', 'collop', 'crumb', 'cut'],
    'snack bar': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop'],
    'snafu': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 'anarchic', 'anarchy', 'arsy-varsy', 'ass-backwards', 'ball up', 'balled up', 'bollix', 'bollix up', 'bollixed up'],
    'snag': ['baby tooth', 'bag', 'bar', 'bicuspid', 'blemish', 'block', 'blockade', 'bottleneck', 'brake', 'bucktooth', 'bug', 'canine'],
    'snaggled': ['bicuspid', 'corrugated', 'cragged', 'craggy', 'crinkled', 'crumpled', 'dental', 'dentiform', 'dentoid', 'fanged', 'gravelly', 'harsh'],
    'snail': ['chilopoda', 'chordata', 'dungeness crab', 'echiuroidea', 'ectoprocta', 'entoprocta', 'japanese crab', 'monoplacophora', 'nemertinea', 'phoronidea', 'blue point', 'clam'],
    'snake': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'quisling', 'adder', 'anaconda', 'animal', 'archtraitor', 'asp', 'beast', 'bend'],
    'snake pit': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 'can of worms', 'complex', 'jungle', 'knot', 'labyrinth', 'maze', 'meander', 'mesh', 'mess'],
    'snaky': ['machiavellian', 'machiavellic', 'aberrant', 'aberrative', 'acute', 'ambagious', 'amphibian', 'anfractuous', 'anguiform', 'anguine', 'arch', 'artful'],
    'snap': ['photostat', 'telephoto', 'wirephoto', 'x-ray', 'xerox', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'abrupt', 'ad-lib'],
    'snap back': ['answer', 'backfire', 'backlash', 'boomerang', 'bounce', 'bounce back', 'bound', 'bound back', 'cannon', 'cannon off', 'carom', 'come back at'],
    'snap up': ['abduct', 'animate', 'arouse', 'carry off', 'dynamize', 'electrify', 'energize', 'enliven', 'exhilarate', 'fire', 'galvanize', 'hearten'],
    'snapper': ['klaxon', 'blunder', 'boiler factory', 'boiler room', 'bull-roarer', 'bumble', 'catcall', 'cherry bomb', 'clack', 'clacker', 'clapper', 'cracker'],
    'snapping': ['awfully', 'clack', 'click', 'crack', 'cracking', 'crackle', 'crackling', 'crepitant', 'crepitation', 'damned', 'decrepitation', 'dreadfully'],
    'snappish': ['abrupt', 'acerbic', 'acid', 'bearish', 'bitchy', 'brusque', 'cankered', 'cantankerous', 'choleric', 'churlish', 'crabbed', 'crabby'],
    'snappy': ['siberian', 'active', 'activist', 'activistic', 'acute', 'aggressive', 'agile', 'algid', 'alive', 'animated', 'arctic', 'below zero'],
    'snapshot': ['telephoto', 'wirephoto', 'aerial photograph', 'black-and-white photograph', 'candid photograph', 'cheesecake', 'chronophotograph', 'color photograph', 'color print', 'diapositive', 'heliochrome', 'heliograph'],
    'snare': ['abstract', 'allure', 'allurement', 'and', 'annex', 'appropriate', 'bag', 'bait', 'bait the hook', 'baited trap', 'birdlime', 'bola'],
    'snarl': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 'allure', 'altercation', 'argument', 'ataxia', 'bait the hook', 'ball up', 'bark', 'bawl', 'belch'],
    'snarl up': ['ball up', 'bollix', 'bollix up', 'bugger', 'bugger up', 'complicate', 'confound', 'confuse', 'cook', 'embrangle', 'entangle', 'foul up'],
    'snarled': ['byzantine', 'balled up', 'complex', 'complicated', 'confounded', 'confused', 'convoluted', 'crabbed', 'daedal', 'devious', 'disheveled', 'elaborate'],
    'snatch': ['abduce', 'abduct', 'abduction', 'abstract', 'and', 'annex', 'apprehension', 'appropriate', 'arrest', 'arrestation', 'badger', 'bag'],
    'snazzy': ['brave', 'bravura', 'braw', 'chic', 'chichi', 'classy', 'clothes-conscious', 'cosmopolitan', 'dapper', 'daring', 'dashing', 'dressed to advantage'],
    'sneak': ['arrant coward', 'blackguard', 'caitiff', 'clandestine', 'couch', 'covert', 'cower', 'craven', 'crawl', 'creep', 'cringe', 'crouch'],
    'sneak in': ['affiliate', 'affiliate with', 'associate', 'barge in', 'break in', 'break in upon', 'burst in', 'butt in', 'charge in', 'combine', 'come between', 'come into'],
    'sneak preview': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'black-and-white film', 'cartoon', 'chiller', 'cinema', 'color film', 'creepie', 'documentary'],
    'sneaking': ['all fours', 'back-door', 'backstairs', 'clandestine', 'covert', 'cowering', 'crawl', 'crawling', 'creep', 'creeping', 'cringing', 'deep-rooted'],
    'sneaky': ['machiavellian', 'machiavellic', 'acute', 'arch', 'artful', 'astute', 'back-door', 'backstairs', 'cagey', 'calculating', 'canny', 'chiseling'],
    'sneer': ['barrack', 'be above', 'be contemptuous of', 'care nothing for', 'chaff', 'contemn', 'contempt', 'cut', 'cut at', 'cut direct', 'deride', 'derision'],
    'sneering': ['arrogant', 'bantering', 'booing', 'catcalling', 'chaffing', 'clannish', 'cliquish', 'contemptuous', 'contumelious', 'derisive', 'derisory', 'disdainful'],
    'sneeze': ['aqua-lung', 'artificial respiration', 'aspiration', 'assibilate', 'assibilation', 'asthmatic wheeze', 'blow', 'breath', 'breath of air', 'breathe', 'breathe hard', 'breathe in'],
    'sneeze at': ['abandon', 'be above', 'be contemptuous of', 'brush aside', 'brush off', 'care nothing for', 'contemn', 'deride', 'despise', 'disdain', 'dismiss', 'disparage'],
    'snicker': ['homeric laughter', 'be in stitches', 'belly laugh', 'boff', 'boffola', 'break up', 'burst into laughter', 'burst of laughter', 'burst out', 'burst out laughing', 'burst with laughter', 'bust a gut'],
    'snicker at': ['deride', 'grin at', 'hold in derision', 'laugh at', 'laugh to scorn', 'make fun of', 'make game of', 'make merry with', 'pan', 'pillory', 'point at', 'poke fun at'],
    'sniff': ['aqua-lung', 'artificial respiration', 'aspirate', 'aspiration', 'assibilate', 'assibilation', 'asthmatic wheeze', 'be warm', 'blow', 'breath', 'breath of air', 'breathe'],
    'sniff out': ['be warm', 'burn', 'follow', 'follow a clue', 'follow up', 'get wind of', 'hunt down', 'nose', 'nose out', 'run down', 'run to earth', 'scent'],
    'sniffle': ['aqua-lung', 'artificial respiration', 'aspirate', 'aspiration', 'assibilate', 'assibilation', 'asthmatic wheeze', 'blow', 'breath', 'breath of air', 'breathe', 'breathe hard'],
    'sniffles': ['asiatic flu', 'hong kong flu', 'acute bronchitis', 'adenoiditis', 'aluminosis', 'amygdalitis', 'anthracosilicosis', 'anthracosis', 'asbestosis', 'asthma', 'atypical pneumonia', 'bituminosis'],
    'sniffy': ['arrogant', 'asthmatic', 'breathing', 'clannish', 'cliquish', 'condescending', 'contemptuous', 'contumelious', 'disdainful', 'errhine', 'exclusive', 'expiratory'],
    'snifter': ['draft', 'dram', 'drench', 'drink', 'drop', 'gargle', 'guzzle', 'jigger', 'jolt', 'libation', 'nip', 'peg'],
    'snigger': ['homeric laughter', 'be in stitches', 'belly laugh', 'boff', 'boffola', 'break up', 'burst into laughter', 'burst of laughter', 'burst out', 'burst out laughing', 'burst with laughter', 'bust a gut'],
    'sniggle': ['allure', 'bag', 'bait', 'bait the hook', 'birdlime', 'bola', 'catch', 'catch out', 'chortle', 'chuckle', 'cobweb', 'decoy'],
    'snip': ['amputate', 'ax', 'bakehead', 'bantam', 'banty', 'bisect', 'bit', 'black gang', 'boilerman', 'breeze', 'bungs', 'butcher'],
    'snipe': ['aim at', 'attack', 'barrage', 'blast', 'blitz', 'bombard', 'cannon', 'cannonade', 'carp at', 'charge', 'cock', 'commence firing'],
    'sniper': ['nimrod', 'zouave', 'archer', 'artilleryman', 'bersagliere', 'bowman', 'cannoneer', 'carabineer', 'chasseur', 'crack shot', 'dead shot', 'deadeye'],
    'snippet': ['bantam', 'banty', 'bit', 'butt', 'button', 'chip', 'chit', 'chunk', 'clip', 'clipping', 'collop', 'crumb'],
    'snippy': ['abrupt', 'aggressive', 'bearish', 'beastly', 'bluff', 'blunt', 'brash', 'brief', 'brusque', 'cavalier', 'churlish', 'condescending'],
    'snitch': ['abstract', 'and', 'annex', 'appropriate', 'bag', 'beak', 'bear witness against', 'beezer', 'betray', 'betrayer', 'blab', 'blabber'],
    'snivel': ['bawl', 'be hypocritical', 'blandish', 'blubber', 'boohoo', 'break down', 'burst into tears', 'cant', 'cry', 'dissolve in tears', 'drop a tear', 'give lip service'],
    'sniveler': ['holy willie', 'joseph surface', 'mawworm', 'pecksniff', 'pharisee', 'tartuffe', 'affecter', 'canter', 'canting hypocrite', 'dissembler', 'dissimulator', 'formalist'],
    'sniveling': ['tartuffian', 'tartuffish', 'abject', 'affected', 'backscratching', 'bawling', 'beggarly', 'blubbering', 'bootlicking', 'canting', 'cowering', 'crawling'],
    'snob': ['brahmin', 'bootlicker', 'cold-shoulder', 'cut', 'egghead', 'elitist', 'hanger-on', 'high-hat', 'highbrow', 'lickspittle', 'mandarin', 'name-dropper'],
    'snobbery': ['affectation', 'clannishness', 'cliquishness', 'conceit', 'condescension', 'contemptuousness', 'disdain', 'disdainfulness', 'egotism', 'exclusiveness', 'haughtiness', 'hauteur'],
    'snobbish': ['affected', 'aloof', 'arrogant', 'clannish', 'cliquish', 'complacent', 'conceited', 'condescending', 'contemptuous', 'contumelious', 'disdainful', 'egotistical'],
    'snoop': ['paul pry', 'paul-pry', 'peeping tom', 'audient', 'auditor', 'backseat driver', 'busybody', 'butt-in', 'buttinsky', 'eavesdropper', 'fool with', 'gossip'],
    'snoot': ['antlia', 'beak', 'beezer', 'bill', 'bugle', 'conk', 'high-hat', 'muffle', 'muzzle', 'nares', 'neb', 'nib'],
    'snootful': ['bellyful', 'bumper', 'capacity', 'charge', 'complement', 'cram', 'crush', 'engorgement', 'fill', 'full house', 'full measure', 'fullness'],
    'snooty': ['arrogant', 'clannish', 'cliquish', 'condescending', 'contemptuous', 'contumelious', 'disdainful', 'exclusive', 'haughty', 'high-hat', 'patronizing', 'potty'],
    'snore': ['aqua-lung', 'artificial respiration', 'aspiration', 'assibilate', 'assibilation', 'asthmatic wheeze', 'belch', 'blare', 'blat', 'blow', 'bray', 'breath'],
    'snoring': ['aqua-lung', 'artificial respiration', 'aspiration', 'asthmatic', 'asthmatic wheeze', 'breath', 'breath of air', 'breathing', 'broken wind', 'cough', 'effervescent', 'errhine'],
    'snorkel': ['aqua-lung', 'foamite', 'acid', 'adjutage', 'air cylinder', 'aquascope', 'automatic sprinkler', 'bathyscaphe', 'bathysphere', 'benthoscope', 'carbon tet', 'carbon tetrachloride'],
    'snort': ['homeric laughter', 'assibilate', 'assibilation', 'bark', 'bawl', 'be above', 'be contemptuous of', 'be in stitches', 'bellow', 'belly laugh', 'beverage', 'blare'],
    'snot': ['bugger', 'carrion', 'chyle', 'colostrum', 'corruption', 'creep', 'crumb', 'cur', 'dandruff', 'decay', 'discharge', 'dog'],
    'snotty': ['arrogant', 'clannish', 'cliquish', 'condescending', 'contemptuous', 'contumelious', 'disdainful', 'exclusive', 'haughty', 'high-hat', 'muciferous', 'mucific'],
    'snout': ['antlia', 'beak', 'beezer', 'bib nozzle', 'bill', 'bugle', 'conk', 'muffle', 'muzzle', 'nares', 'neb', 'nib'],
    'snow': ['benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'methedrine', 'accord', 'administer', 'afford', 'alabaster', 'allot'],
    'snow job': ['allurement', 'bamboozlement', 'befooling', 'blandishment', 'bluffing', 'cajolement', 'cajolery', 'calculated deception', 'circumvention', 'coaxing', 'conning', 'deceiving'],
    'snow under': ['blank', 'bulldoze', 'clobber', 'cream', 'defeat utterly', 'frost', 'hail', 'ice', 'ice over', 'ice up', 'overbear', 'overwhelm'],
    'snowball': ['accrue', 'accumulate', 'accumulation', 'acervation', 'advance', 'agglomerate', 'agglomeration', 'aggregate', 'aggregation', 'amassment', 'appreciate', 'augment'],
    'snowbank': ['avalanche', 'blizzard', 'crystal', 'driven snow', 'flake', 'flurry', 'granular snow', 'igloo', 'mantle of snow', 'mogul', 'slosh', 'slush'],
    'snowbird': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser'],
    'snowcapped': ['nival', 'niveous', 'snow-bearded', 'snow-blanketed', 'snow-capped', 'snow-clad', 'snow-crested', 'snow-drifted', 'snow-driven', 'snow-encircled', 'snow-feathered', 'snow-hung'],
    'snowdrift': ['anthill', 'avalanche', 'bank', 'blizzard', 'cock', 'crystal', 'drift', 'driven snow', 'dune', 'embankment', 'flake', 'flurry'],
    'snowfall': ['avalanche', 'blizzard', 'crystal', 'driven snow', 'flake', 'flurry', 'granular snow', 'igloo', 'mantle of snow', 'mogul', 'slosh', 'slush'],
    'snowflake': ['avalanche', 'blizzard', 'crystal', 'driven snow', 'flake', 'flurry', 'granular snow', 'igloo', 'mantle of snow', 'mogul', 'slosh', 'slush'],
    'snowman': ['avalanche', 'blizzard', 'bust', 'carving', 'crystal', 'doll', 'dolly', 'driven snow', 'dummy', 'fantoccini', 'figure', 'figurehead'],
    'snowstorm': ['avalanche', 'black spot', 'blizzard', 'bloom', 'blooping', 'crystal', 'cyclone', 'definition', 'dirty weather', 'driven snow', 'flake', 'flare'],
    'snowy': ['argent', 'argentine', 'blotless', 'canescent', 'chalky', 'chaste', 'clean', 'cleanly', 'cretaceous', 'fleecy-white', 'frosted', 'frosty'],
    'snub': ['abbreviate', 'abbreviated', 'abridge', 'abridged', 'abstract', 'abstracted', 'arrest', 'ban', 'banish', 'beat back', 'blackball', 'bob'],
    'snub nosed': ['bandy', 'bandy-legged', 'blemished', 'bloated', 'blocky', 'bowlegged', 'chubby', 'chunky', 'club-footed', 'defaced', 'deformed', 'disfigured'],
    'snuff': ['aqua-lung', 'artificial respiration', 'aspirate', 'aspiration', 'assibilate', 'assibilation', 'asthmatic wheeze', 'blow', 'blow out', 'breath', 'breath of air', 'breathe'],
    'snuff out': ['blow out', 'cash in', 'check out', 'choke', 'conk', 'croak', 'damp', 'die', 'douse', 'drop', 'extinguish', 'kick in'],
    'snuffle': ['aqua-lung', 'tartuffery', 'tartuffism', 'affectation', 'artificial respiration', 'aspirate', 'aspiration', 'assibilate', 'assibilation', 'asthmatic wheeze', 'be hypocritical', 'blandish'],
    'snuffy': ['asthmatic', 'breathing', 'chewing', 'dingy', 'dirty', 'dusty', 'errhine', 'expiratory', 'grimy', 'grubby', 'grungy', 'heaving'],
    'snug': ['airtight', 'airworthy', 'anal', 'autistic', 'bashful', 'bold', 'brief', 'brusque', 'burrow', 'casual', 'cheerful', 'chipper'],
    'snuggery': ['alcove', 'bay', 'blockhouse', 'box', 'bungalow', 'cabin', 'carrel', 'chalet', 'corner', 'cot', 'cote', 'cottage'],
    'so': ['a deal', 'a great deal', 'a lot', 'abundantly', 'accordingly', 'accurately', 'ad eundem', 'after this fashion', 'almighty', 'along these lines', 'as', 'as all creation'],
    'so called': ['affected', 'alleged', 'apocryphal', 'artificial', 'assumed', 'avowed', 'bastard', 'bogus', 'brummagem', 'byname', 'claimed', 'cognominal'],
    'so far': ['after a fashion', 'already', 'appreciably', 'as yet', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside', 'at worst'],
    'so so': ['average', 'betwixt and between', 'dull', 'fair', 'fair to middling', 'fairish', 'fairishly', 'fairly', 'indifferent', 'indifferently', 'insipid', 'lackluster'],
    'soak': ['absorb', 'alcoholic', 'assimilate', 'bang', 'bash', 'bat', 'bathe', 'belt', 'bender', 'bib', 'bibber', 'biff'],
    'soak in': ['absorb', 'adsorb', 'assimilate', 'be glimpsed', 'blot', 'blot up', 'chemisorb', 'chemosorb', 'come through', 'dawn on', 'digest', 'drink'],
    'soak up': ['absorb', 'adsorb', 'air-dry', 'anhydrate', 'assimilate', 'bake', 'blot', 'blot up', 'brush', 'burn', 'chemisorb', 'chemosorb'],
    'soaked': ['sro', 'afflicted', 'awash', 'bathed', 'bent', 'bloated', 'boiled', 'bombed', 'boozy', 'brimful', 'brimming', 'bulging'],
    'soaker': ['alcoholic', 'alcoholic addict', 'bacchanal', 'bacchanalian', 'bibber', 'big drunk', 'boozehound', 'boozer', 'brash', 'burst of rain', 'carouser', 'chronic alcoholic'],
    'soaking': ['absorbent', 'adsorbent', 'assimilative', 'awash', 'bathed', 'bibulous', 'blotting', 'brewing', 'chemisorptive', 'chemosorptive', 'concentration', 'dampening'],
    'soap': ['grand guignol', 'passion play', 'tom show', 'abstergent', 'adulation', 'amole', 'antimasque', 'audience success', 'ballet', 'baptize', 'bar soap', 'bath'],
    'soap opera': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bathos', 'bleeding heart', 'bomb', 'broadcast', 'broadcast drama', 'burlesque show'],
    'soapbox': ['balcony', 'catafalque', 'dais', 'declaim', 'emplacement', 'estrade', 'floor', 'gallery', 'harangue', 'heliport', 'hustings', 'landing'],
    'soapy': ['adipose', 'adulatory', 'barmy', 'bland', 'blandishing', 'blarneying', 'blubbery', 'buttery', 'butyraceous', 'cajoling', 'chrismal', 'chrismatory'],
    'soar': ['advance', 'aeroplane', 'airlift', 'airplane', 'arise', 'ascend', 'aspire', 'back', 'back up', 'balloon', 'be airborne', 'become airborne'],
    'soaring': ['brownian movement', 'olympian', 'advance', 'aerial', 'aeronautics', 'air service', 'airline', 'airy', 'altitudinous', 'anabasis', 'angular motion', 'ascending'],
    'sob': ['bastard', 'bugger', 'creep', 'fart', 'heel', 'hood', 'hooligan', 'jerk', 'louse', 'meanie', 'mother', 'pill'],
    'sob sister': ['city editor', 'columnist', 'copy chief', 'copy editor', 'copyman', 'copyreader', 'correspondent', 'cub reporter', 'diaskeuast', 'editor', 'editorial writer', 'feature editor'],
    'sob story': ['bathos', 'bleeding heart', 'cloyingness', 'goo', 'hearts-and-flowers', 'maudlinness', 'mawkishness', 'mush', 'mushiness', 'namby-pamby', 'namby-pambyism', 'namby-pambyness'],
    'sobbing': ['bawling', 'blubbering', 'cry', 'crying', 'dissolved in tears', 'fit of crying', 'flood of tears', 'good cry', 'greet', 'in tears', 'lachryma', 'lachrymal'],
    'sober': ['quaker-colored', 'spartan', 'abstaining', 'abstentious', 'abstinent', 'acier', 'aristocratic', 'ascetic', 'ashen', 'ashy', 'august', 'austere'],
    'soberly': ['calmly', 'composedly', 'conservatively', 'coolly', 'decorously', 'demurely', 'dispassionately', 'earnestly', 'equably', 'evenly', 'formally', 'grandly'],
    'sobriety': ['abnegation', 'abstemiousness', 'abstention', 'abstinence', 'augustness', 'balance', 'blackishness', 'calm', 'calmness', 'common sense', 'conservatism', 'constraint'],
    'sociability': ['bohemianism', 'accessibility', 'affability', 'amiability', 'amiableness', 'amicability', 'amicableness', 'amity', 'approachability', 'big mouth', 'candor', 'casualness'],
    'sociable': ['bohemian', 'accessible', 'affable', 'agreeable', 'all jaw', 'amiable', 'amicable', 'approachable', 'associational', 'brotherly', 'candid', 'casual'],
    'social': ['affable', 'affair', 'amiable', 'amusing', 'associated', 'associational', 'at home', 'civic', 'civil', 'clubbable', 'clubbish', 'clubby'],
    'social class': ['ashram', 'association', 'body', 'caste', 'clan', 'class', 'colony', 'commonwealth', 'commune', 'community', 'economic class', 'endogamous group'],
    'social climbing': ['ambition', 'ambitious', 'ambitiousness', 'aspiring', 'careerism', 'careerist', 'careeristic', 'climbing', 'high-flying', 'high-reaching', 'lofty ambition', 'magnanimity'],
    'social convention': ['bon ton', 'conformity', 'consuetude', 'convention', 'custom', 'established way', 'etiquette', 'fashion', 'folkway', 'manner', 'manners', 'mores'],
    'social grace': ['affability', 'amenities', 'amiability', 'civilities', 'civility', 'clubbability', 'clubbishness', 'clubbism', 'comity', 'communicativeness', 'companionability', 'compatibility'],
    'social intercourse': ['esp', 'answer', 'collegiality', 'commerce', 'communication', 'communion', 'community', 'congress', 'connection', 'contact', 'conversation', 'converse'],
    'social outcast': ['dp', 'ishmael', 'castaway', 'declasse', 'derelict', 'displaced person', 'evictee', 'exile', 'expatriate', 'expellee', 'leper', 'outcast'],
    'social science': ['academic discipline', 'academic specialty', 'action', 'actions', 'activity', 'acts', 'address', 'affectation', 'air', 'applied science', 'area', 'arena'],
    'social security': ['adc', 'medicaid', 'medicare', 'accident insurance', 'actuary', 'annuity', 'assurance', 'aviation insurance', 'bail bond', 'bond', 'business life insurance', 'casualty insurance'],
    'socialism': ['fabian socialism', 'fabianism', 'marxian socialism', 'marxism', 'nazism', 'saint-simonism', 'centralism', 'collective farm', 'collective ownership', 'collectivism', 'collectivity', 'collegiality'],
    'socialist party': ['american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party', 'greenback party'],
    'socialistic': ['fabian', 'fourieristic', 'saint-simonian', 'associated', 'collective', 'collectivistic', 'common', 'communal', 'communistic', 'commutual', 'conjoint', 'cooperative'],
    'socialite': ['beau brummel', 'arbiter of fashion', 'clotheshorse', 'clubman', 'clubwoman', 'dandy', 'deb', 'debutante', 'fashion plate', 'fashionable', 'fop', 'man-about-town'],
    'socialize': ['acculturate', 'advance', 'ameliorate', 'amend', 'annex', 'associate', 'attach', 'better', 'boost', 'bring forward', 'civilize', 'collectivize'],
    'socialized medicine': ['adc', 'medicaid', 'medicare', 'aerospace medicine', 'biomedicine', 'clinical medicine', 'comparative medicine', 'constitutional medicine', 'cradle-to-grave security', 'dosimetric medicine', 'experimental medicine', 'guaranteed annual income'],
    'society': ['bund', 'everyman', 'john doe', 'public', 'rochdale cooperative', 'vanity fair', 'academy', 'acculturation', 'affiliation', 'alliance', 'ashram', 'assemblage'],
    'sock': ['ballet skirt', 'bang', 'bash', 'bat', 'beating', 'belt', 'biff', 'bladder', 'blow', 'bonk', 'bonnet', 'boot'],
    'sockdolager': ['ko', 'clincher', 'conclusive argument', 'crusher', 'death stroke', 'deathblow', 'end-all', 'ender', 'final stroke', 'finisher', 'finishing stroke', 'floorer'],
    'socket': ['alveolation', 'alveolus', 'antrum', 'armpit', 'basin', 'bowl', 'cavity', 'concave', 'concavity', 'crater', 'crypt', 'cup'],
    'socratic': ['augustinian', 'averroist', 'berkeleian', 'cartesian', 'hegelian', 'heideggerian', 'heraclitean', 'humean', 'husserlian', 'kantian', 'leibnizian', 'neo-hegelian'],
    'sod': ['acres', 'alluvion', 'alluvium', 'arable land', 'bugger', 'clay', 'clod', 'crust', 'cur', 'dirt', 'divot', 'dog'],
    'soda': ['foamite', 'acid', 'alcoholic drink', 'automatic sprinkler', 'beverage', 'carbon tet', 'carbon tetrachloride', 'carbon-dioxide foam', 'deck gun', 'deluge set', 'drink', 'drinkable'],
    'sodden': ['addled', 'awash', 'bathe', 'bathed', 'beery', 'bemused', 'besotted', 'blind drunk', 'brew', 'crapulent', 'crapulous', 'deluged'],
    'sodomist': ['bugger', 'coprophiliac', 'erotomaniac', 'exhibitionist', 'fetishist', 'masochist', 'narcissist', 'necrophiliac', 'nymphomaniac', 'paraphiliac', 'pederast', 'pedophiliac'],
    'sofa': ['bed', 'bedstead', 'bunk', 'chesterfield', 'couch', 'davenport', 'day bed', 'divan', 'doss', 'gurney', 'kip', 'litter'],
    'soft': ['mickey mouse', 'accented', 'accepting', 'adoring', 'affectionate', 'afraid', 'alveolar', 'anemic', 'apical', 'apico-alveolar', 'apico-dental', 'articulated'],
    'soft cover': ['best seller', 'book', 'bound book', 'classic', 'coloring book', 'definitive work', 'folio', 'great work', 'hardback', 'juvenile', 'juvenile book', 'limp-cover book'],
    'soft pedal': ['allow for', 'baffle', 'choke', 'choke off', 'color', 'cushion', 'damp', 'dampen', 'deaden', 'deafen', 'diminish', 'dull'],
    'soft sell': ['consumer preference study', 'consumer research', 'consumer survey', 'direct-mail selling', 'hard sell', 'hawking', 'high-pressure salesmanship', 'huckstering', 'jobbing', 'low-pressure salesmanship', 'mail-order selling', 'market research'],
    'soft soap': ['pecksniffery', 'tartuffery', 'tartuffism', 'adulation', 'advocate', 'allurement', 'be hypocritical', 'blandish', 'blandishment', 'blandness', 'blarney', 'bunkum'],
    'soft spoken': ['articulate', 'bland', 'buttery', 'disarming', 'eloquent', 'fair-spoken', 'fine-spoken', 'free-speaking', 'free-spoken', 'fulsome', 'glib', 'honey-mouthed'],
    'soft spot': ['a thing for', 'affinity', 'aptitude', 'aptness', 'assailability', 'bent', 'bias', 'cast', 'chink', 'conatus', 'conduciveness', 'delight'],
    'soften': ['abate', 'absorb the shock', 'adjust to', 'affect', 'agree', 'allay', 'alleviate', 'allow for', 'alter', 'anesthetize', 'appease', 'assent'],
    'soften up': ['abate', 'affect', 'attenuate', 'beleaguer', 'bend', 'beset', 'besiege', 'bias', 'blarney', 'blockade', 'blunt', 'butter'],
    'softened': ['abject', 'apologetic', 'bated', 'chastened', 'complaisant', 'conditioned', 'constrained', 'contrite', 'controlled', 'creamy', 'damped', 'dampened'],
    'softening': ['abatement', 'abating', 'allaying', 'allayment', 'alleviating', 'alleviation', 'alleviative', 'allowance', 'altering', 'analgesia', 'analgesic', 'anesthesia'],
    'softhearted': ['christian', 'christlike', 'christly', 'affectionate', 'benign', 'benignant', 'bleeding', 'brotherly', 'charitable', 'clement', 'commiserative', 'compassionate'],
    'softly': ['a la sourdine', 'compliantly', 'delicately', 'dimly', 'easily', 'faintly', 'feebly', 'gently', 'hushedly', 'low', 'pianissimo', 'piano'],
    'softness': ['acceptance', 'adynamia', 'airiness', 'anemia', 'ascent', 'atony', 'blah feeling', 'bloodlessness', 'bubbliness', 'buoyancy', 'cachexia', 'cachexy'],
    'softwood': ['arborary', 'arboreal', 'arboreous', 'arborescent', 'arboresque', 'arborical', 'arboriform', 'beam', 'billet', 'board', 'boarding', 'bushlike'],
    'softy': ['milquetoast', 'baby', 'big baby', 'chicken', 'crybaby', 'doormat', 'dull tool', 'gutless wonder', 'invertebrate', 'jellyfish', 'lightweight', 'meek soul'],
    'soggy': ['awash', 'bathed', 'deluged', 'dipped', 'drenched', 'dribbling', 'dripping', 'dripping wet', 'drowned', 'engulfed', 'flooded', 'immersed'],
    'soigne': ['a la mode', 'braw', 'chic', 'classy', 'clothes-conscious', 'cosmopolitan', 'dapper', 'dashing', 'dressed to advantage', 'dressed to kill', 'dressed up', 'elegant'],
    'soil': ['abuse', 'acres', 'adobe', 'airspace', 'alluvion', 'alluvium', 'arable land', 'area', 'attaint', 'bedaub', 'befoul', 'begrime'],
    'soil science': ['cosmical geology', 'dynamic geology', 'geodesy', 'geodetics', 'geodynamics', 'geognosy', 'geographics', 'geography', 'geological chemistry', 'geological engineering', 'geology', 'geomorphogeny'],
    'soiled': ['bedraggled', 'befouled', 'besmirched', 'blackened', 'darkened', 'defiled', 'dirtied', 'discolored', 'drabbled', 'draggled', 'fouled', 'foxed'],
    'soiree': ['affair', 'assemblee', 'assembly', 'assignation', 'at home', 'ball', 'brawl', 'caucus', 'colloquium', 'commission', 'committee', 'conclave'],
    'sojourn': ['abide', 'holiday', 'lay over', 'layover', 'linger', 'rest', 'sojournment', 'stay', 'stay over', 'stayover', 'stop', 'stop over'],
    'sojourner': ['addressee', 'artist-in-residence', 'denizen', 'dweller', 'habitant', 'house detective', 'incumbent', 'inhabitant', 'inhabiter', 'inmate', 'inpatient', 'intern'],
    'sol fa': ['anthem', 'ballad', 'bel canto', 'bobization', 'bravura', 'carol', 'chant', 'chirp', 'chirrup', 'choir', 'choral singing', 'chorus'],
    'solace': ['aid and comfort', 'allay', 'alleviate', 'ameliorate', 'amuse', 'amusement', 'assuage', 'assurance', 'assure', 'balm', 'bear up', 'beguile'],
    'solar': ['cynthian', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical', 'celestial', 'circumplanetary', 'cislunar'],
    'solar plexus': ['afferent neuron', 'autonomic nervous system', 'axon', 'brain', 'central nervous system', 'cerebral cortex', 'craniosacral nervous system', 'dendrite', 'effector organ', 'efferent neuron', 'ganglion', 'gray matter'],
    'solar rays': ['x ray', 'actinic ray', 'actinism', 'atomic beam', 'atomic ray', 'beam', 'beam of light', 'gamma ray', 'gleam', 'infrared ray', 'invisible radiation', 'leam'],
    'solar system': ['earth', 'jupiter', 'mars', 'mercury', 'neptune', 'pluto', 'saturn', 'uranus', 'venus', 'asteroid', 'inferior planet', 'major planet'],
    'solarium': ['best room', 'drawing room', 'foreroom', 'front room', 'gallery', 'lanai', 'living room', 'parlor', 'patio', 'piazza', 'porch', 'salon'],
    'sold on': ['assured', 'believing', 'certain', 'charmed', 'comfortable', 'confident', 'content', 'contented', 'convinced', 'cozy', 'delighted', 'devout'],
    'solder': ['accouple', 'accumulate', 'agglutinate', 'amass', 'articulate', 'assemble', 'associate', 'band', 'bind', 'blaze', 'blister', 'bond'],
    'soldier': ['amazon', 'gi', 'tommy atkins', 'aggressive', 'air serviceman', 'ant', 'army ant', 'bear arms', 'black ant', 'bold', 'brave', 'cannon fodder'],
    'soldiery': ['armed force', 'armed service', 'army', 'array', 'career soldiers', 'fighting machine', 'forces', 'ground forces', 'ground troops', 'host', 'legions', 'military establishment'],
    'sole': ['a certain', 'absolute', 'alone', 'an', 'any', 'any one', 'arch', 'atomic', 'azygous', 'bachelorlike', 'base', 'baseboard'],
    'solecism': ['irish bull', 'anachronism', 'anacoluthon', 'antiphrasis', 'argument', 'argument by analogy', 'argumentum ad baculum', 'argumentum ad captandum', 'argumentum ad hominem', 'bad case', 'barbarism', 'begging the question'],
    'solely': ['alone', 'barely', 'but', 'entirely', 'exclusively', 'integrally', 'irreducibly', 'just', 'merely', 'only', 'plainly', 'purely'],
    'solemn': ['christian', 'christianlike', 'christianly', 'admiring', 'adorant', 'adoring', 'apotheosizing', 'arid', 'aristocratic', 'august', 'awe-inspiring', 'awed'],
    'solemnity': ['aridity', 'augustness', 'baccalaureate service', 'barrenness', 'bleakness', 'bloodlessness', 'buckram', 'celebration', 'ceremonial', 'ceremoniousness', 'ceremony', 'characterlessness'],
    'solemnize': ['administer communion', 'attend communion', 'attend mass', 'beat the drum', 'blow the trumpet', 'celebrate', 'celebrate mass', 'commemorate', 'communicate', 'conventionalize', 'dignify', 'dress ship'],
    'solemnly': ['bleakly', 'ceremoniously', 'decorously', 'demurely', 'dismally', 'drearily', 'earnestly', 'formally', 'funereally', 'gloomily', 'grandly', 'gravely'],
    'solicit': ['accost', 'address', 'angle for', 'appeal to', 'apply', 'approach', 'ask', 'ask for', 'beg', 'beseech', 'bespeak', 'bid for'],
    'solicitation': ['addresses', 'all-out campaign', 'allurement', 'blandishment', 'cajolement', 'cajolery', 'campaign', 'campaign button', 'campaign commitments', 'campaign contribution', 'campaign fund', 'canvass'],
    'solicitor': ['advocate', 'agent', 'amicus curiae', 'applicant', 'aspirant', 'attorney', 'attorney-at-law', 'ballyhoo man', 'ballyhooer', 'barker', 'barrister', 'barrister-at-law'],
    'solicitous': ['accommodating', 'accommodative', 'affable', 'agitated', 'agreeable', 'all-overish', 'anxious', 'anxioused up', 'apprehensive', 'ardent', 'athirst', 'attentive'],
    'solicitude': ['tlc', 'accommodatingness', 'affability', 'agitation', 'agreeableness', 'alarm', 'all-overs', 'amenity', 'angst', 'anticipation', 'anxiety', 'anxiety hysteria'],
    'solid': ['ok', 'a certain', 'abiding', 'able to pay', 'ace-high', 'adamantine', 'agreeing', 'an', 'any', 'any one', 'appreciable', 'at one'],
    'solidarity': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'amity', 'bipartisanship', 'bonds of harmony', 'brotherly love', 'camaraderie', 'caritas', 'cement of friendship'],
    'solidification': ['anschluss', 'abbreviation', 'accretion', 'addition', 'adherence', 'adhesion', 'affiliation', 'agglomeration', 'agglutination', 'aggregation', 'agreement', 'alliance'],
    'solidified': ['backed', 'calcified', 'callous', 'calloused', 'case-hardened', 'clamped', 'compressed', 'concentrated', 'condensed', 'consolidated', 'constricted', 'contracted'],
    'solidify': ['abbreviate', 'add', 'adhere', 'agglomerate', 'amalgamate', 'assimilate', 'blend', 'body forth', 'bunch', 'cake', 'candy', 'circumscribe'],
    'solidity': ['abidingness', 'aplomb', 'authenticity', 'authoritativeness', 'authority', 'balance', 'balanced personality', 'body', 'calculability', 'callosity', 'callousness', 'changelessness'],
    'solitary': ['diogenes', 'hieronymian', 'hieronymite', 'timon of athens', 'a certain', 'abandoned', 'alien', 'alienated', 'all alone', 'alone', 'aloof', 'an'],
    'solitude': ['alienation', 'aloneness', 'aloofness', 'celibacy', 'confinement', 'detachment', 'emptiness', 'isolation', 'keeping apart', 'loneliness', 'loneness', 'lonesomeness'],
    'solo': ['air', 'airlift', 'alienated', 'alone', 'aloof', 'apart', 'aria', 'aria buffa', 'aria cantabile', 'aria da capo', 'aria da chiesa', 'aria di bravura'],
    'solon': ['mp', 'member of congress', 'member of parliament', 'alderman', 'assemblyman', 'chosen freeholder', 'city father', 'congressman', 'congresswoman', 'councilman', 'elder statesman', 'floor leader'],
    'solution': ['action', 'ad hoc measure', 'adaptation', 'allegorization', 'answer', 'arrangement', 'artifice', 'blend', 'chemical solution', 'clarification', 'colliquation', 'compound'],
    'solve': ['account for', 'allegorize', 'answer', 'bottom', 'break', 'cipher', 'clarify', 'clear up', 'colliquate', 'crack', 'cut', 'debug'],
    'solvent': ['ablative', 'able to pay', 'above water', 'abstergent', 'acetone', 'alcohol', 'all clear', 'all straight', 'anticoagulant', 'aqua regia', 'benzine', 'biodegradable'],
    'solving': ['accomplishment', 'answer', 'ascertainment', 'clearing up', 'cracking', 'decipherment', 'decoding', 'denouement', 'determination', 'disentanglement', 'end', 'end result'],
    'soma': ['anatomy', 'body', 'bones', 'carcass', 'clay', 'clod', 'corpus', 'figure', 'flesh', 'form', 'frame', 'hulk'],
    'somber': ['acheronian', 'acherontic', 'cimmerian', 'quaker-colored', 'stygian', 'acier', 'apocalyptic', 'ashen', 'ashy', 'bad', 'baleful', 'baneful'],
    'sombre': ['black', 'bleak', 'cheerless', 'dark', 'darkling', 'darksome', 'depressed', 'depressing', 'dim', 'dingy', 'dismal', 'doleful'],
    'some': ['daedalian', 'about', 'adept', 'adroit', 'all but', 'almost', 'an', 'any', 'anything', 'approximately', 'apt', 'artistic'],
    'somebody': ['adamite', 'establishment', 'vip', 'baron', 'being', 'big cheese', 'big gun', 'big man', 'big name', 'big noise', 'big wheel', 'big-timer'],
    'somehow': ['accidentally', 'after a fashion', 'anyhow', 'anyway', 'anywise', 'as it chanced', 'by a fluke', 'by accident', 'by chance', 'by good fortune', 'by hazard', 'by some means'],
    'someone': ['adamite', 'being', 'body', 'cat', 'chap', 'character', 'creature', 'customer', 'duck', 'earthling', 'fellow', 'groundling'],
    'somersault': ['be lost', 'capsizal', 'capsize', 'culbute', 'founder', 'go down', 'keel', 'keel over', 'overset', 'overthrow', 'overturn', 'pitchpole'],
    'something': ['establishment', 'vip', 'affair', 'an existence', 'any', 'anything', 'article', 'artifact', 'aught', 'baron', 'being', 'big gun'],
    'something else': ['ok', 'a mile off', 'ace-high', 'amazement', 'another', 'astonishing thing', 'astonishment', 'autre chose', 'away off', 'bad', 'bang-up', 'bonzer'],
    'sometime': ['ancient', 'any time', 'before long', 'by and by', 'bygone', 'early', 'erstwhile', 'eventually', 'finally', 'fore', 'former', 'immemorial'],
    'somewhat': ['a bit', 'a little', 'adequately', 'after a fashion', 'any', 'anything', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least'],
    'somnambulism': ['amnesia', 'beauty sleep', 'beddy-bye', 'bedtime', 'blanket drill', 'bye-bye', 'catalepsy', 'cataplexy', 'catatonic stupor', 'daydreaming', 'daze', 'doze'],
    'somnolence': ['acedia', 'apathy', 'boredom', 'doziness', 'drowsiness', 'dullness', 'enervation', 'ennui', 'fatigue', 'heaviness', 'hebetude', 'inanimation'],
    'somnolent': ['anesthetized', 'apathetic', 'benumbed', 'blase', 'bored', 'cataleptic', 'comatose', 'dead', 'debilitated', 'doped', 'dopey', 'dormant'],
    'son': ['aunt', 'auntie', 'blood brother', 'brethren', 'brother', 'bub', 'bubba', 'bud', 'buddy', 'child', 'country cousin', 'cousin'],
    'son of god': ['christ', 'christ jesus', 'emmanuel', 'god the son', 'god-man', 'immanuel', 'jesu', 'jesus', 'jesus christ', 'jesus of nazareth', 'king of glory', 'king of heaven'],
    'sonant': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulate', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation'],
    'sonar': ['astronavigation', 'bathometry', 'bathymetry', 'celestial navigation', 'chronometer', 'coastwise navigation', 'consolan', 'dead reckoning', 'depth sounding', 'echo sounding', 'echolocation', 'fathomage'],
    'sonata': ['nachtmusik', 'absolute music', 'adaptation', 'air varie', 'aleatory', 'aleatory music', 'arrangement', 'chamber music', 'chamber orchestra', 'composition', 'descant', 'electronic music'],
    'song': ['brautlied', 'christmas carol', 'english sonnet', 'horatian ode', 'italian sonnet', 'kunstlied', 'liebeslied', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'volkslied'],
    'song and dance': ['broadway musical', 'singspiel', 'act', 'afterpiece', 'ballad opera', 'ballet', 'ballet divertissement', 'bamboozlement', 'befooling', 'bit', 'bluffing', 'calculated deception'],
    'song writer': ['arranger', 'ballad maker', 'balladeer', 'balladist', 'balladmonger', 'composer', 'contrapuntist', 'ethnomusicologist', 'harmonist', 'harmonizer', 'hymnist', 'hymnographer'],
    'songbird': ['heldentenor', 'meistersinger', 'philomel', 'alto', 'aria singer', 'avifauna', 'baby bird', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo'],
    'songbook': ['arrangement', 'best seller', 'book', 'bound book', 'classic', 'coloring book', 'copy', 'definitive work', 'draft', 'edition', 'folio', 'great work'],
    'songster': ['heldentenor', 'meistersinger', 'philomel', 'alto', 'aria singer', 'arrangement', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante'],
    'sonnet': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'alba', 'anacreontic', 'balada', 'ballad', 'ballade'],
    'sonny': ['boy', 'bub', 'bubba', 'buck', 'bud', 'buddy', 'child', 'colt', 'cub', 'daughter', 'descendant', 'fellow'],
    'sonority': ['allophone', 'alveolar', 'apico-alveolar', 'apico-dental', 'articulation', 'aspiration', 'assimilation', 'bassness', 'bilabial', 'cacuminal', 'cerebral', 'check'],
    'sonorous': ['gongoresque', 'johnsonian', 'achingly sweet', 'affected', 'agreeable', 'agreeable-sounding', 'appealing', 'ariose', 'arioso', 'aureate', 'bedizened', 'big-sounding'],
    'soon': ['after a time', 'after a while', 'afterward', 'afterwards', 'anon', 'at bottom', 'at once', 'before long', 'betimes', 'by and by', 'by destiny', 'directly'],
    'sooner': ['before', 'beforehand', 'by choice', 'by election', 'by vote', 'colonial', 'colonist', 'colonizer', 'earlier', 'first', 'homesteader', 'immigrant'],
    'soot': ['air pollution', 'alluvion', 'alluvium', 'ash', 'ashes', 'attritus', 'bedarken', 'begrime', 'bemire', 'bemud', 'besmirch', 'besmoke'],
    'soothe': ['abate', 'allay', 'alleviate', 'anesthetize', 'appease', 'assuage', 'balm', 'becalm', 'benumb', 'calm', 'calm down', 'cease'],
    'soothing': ['united nations troops', 'abatement', 'allayment', 'alleviating', 'alleviation', 'alleviative', 'analgesia', 'analgesic', 'anesthesia', 'anesthetic', 'anesthetizing', 'anodyne'],
    'soothsay': ['adumbrate', 'augur', 'call', 'cast a horoscope', 'cast a nativity', 'divine', 'dope', 'dope out', 'dowse for water', 'forebode', 'forecast', 'foresee'],
    'soothsayer': ['cassandra', 'druid', 'astrologer', 'augur', 'calamity howler', 'crystal gazer', 'divinator', 'diviner', 'divineress', 'forecaster', 'foreknower', 'foreseer'],
    'sooty': ['besmirched', 'blotchy', 'dingy', 'dirty', 'dusty', 'fuliginous', 'grimy', 'grubby', 'grungy', 'messy', 'miry', 'muddy'],
    'sop': ['milquetoast', 'ass', 'baby', 'baksheesh', 'bathe', 'big baby', 'boodle', 'born fool', 'brew', 'bribe', 'bribe money', 'buffoon'],
    'sophism': ['apparent soundness', 'argument', 'argument by analogy', 'argumentum ad baculum', 'argumentum ad captandum', 'argumentum ad hominem', 'bad case', 'begging the question', 'casuistry', 'circular argument', 'circularity', 'claptrap'],
    'sophist': ['jesuit', 'casuist', 'choplogic', 'cosmologist', 'dialectician', 'logicaster', 'logician', 'logistician', 'metaphysician', 'paralogist', 'philosophaster', 'philosophe'],
    'sophistic': ['baseless', 'bogus', 'captious', 'casuistical', 'deceptive', 'fallacious', 'false', 'groundless', 'hypocritical', 'invalid', 'irrational', 'mad'],
    'sophistical': ['machiavellian', 'machiavellic', 'acute', 'apparently sound', 'arch', 'artful', 'astute', 'cagey', 'canny', 'casuistic', 'clever', 'colorable'],
    'sophisticate': ['blase', 'city slicker', 'cosmopolitan', 'cosmopolite', 'debase', 'disenchanted', 'disillusioned', 'doctor', 'knowing', 'load', 'man of experience', 'man-about-town'],
    'sophisticated': ['adult', 'advanced', 'blase', 'bored', 'braw', 'brittle', 'byzantine', 'chic', 'chichi', 'civilized', 'classy', 'clothes-conscious'],
    'sophistication': ['accomplishments', 'acquired taste', 'acquisition of knowledge', 'acquisitions', 'apparent soundness', 'appreciation of excellence', 'attainments', 'awareness', 'background', 'blaseness', 'casuistry', 'choiceness'],
    'sophistry': ['italian hand', 'acuteness', 'aesthetics', 'ambiguity', 'argument', 'argument by analogy', 'argumentum ad baculum', 'argumentum ad captandum', 'argumentum ad hominem', 'art', 'artfulness', 'artifice'],
    'sophomoric': ['amateur', 'amateurish', 'autodidactic', 'bookish', 'college-bred', 'collegiate', 'dabbling', 'dilettante', 'dilettantish', 'graduate', 'half-assed', 'half-baked'],
    'sopor': ['acedia', 'aloofness', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'catalepsy', 'coma', 'comatoseness', 'detachment'],
    'soporific': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'laodicean', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'olympian', 'seconal'],
    'sopping': ['awash', 'bathed', 'brewing', 'dampening', 'deluged', 'dipped', 'drench', 'drenched', 'drenching', 'dribbling', 'dripping', 'dripping wet'],
    'soprano': ['heldentenor', 'meistersinger', 'accompaniment', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso continuo'],
    'sorb': ['absorb', 'adsorb', 'assimilate', 'blot', 'blot up', 'chemisorb', 'chemosorb', 'digest', 'drink', 'drink in', 'drink up', 'engross'],
    'sorcerer': ['comus', 'faust', 'prospero', 'satan worshiper', 'satanist', 'airiness', 'appearance', 'charmer', 'chthonian', 'conjurer', 'delusiveness', 'demon worshiper'],
    'sorcerous': ['cantrip', 'hoodoo', 'incantational', 'incantatory', 'magian', 'magic', 'magical', 'mystic', 'necromantic', 'numinous', 'shaman', 'shamanic'],
    'sorcery': ['black mass', 'prospero', 'satanism', 'airiness', 'appearance', 'astrology', 'augury', 'bewitchment', 'black art', 'black magic', 'chthonian worship', 'clairvoyance'],
    'sordid': ['a hog for', 'abased', 'abominable', 'acquisitive', 'all-devouring', 'arrant', 'atrocious', 'avaricious', 'avid', 'awful', 'base', 'beastly'],
    'sore': ['abrasion', 'abscess', 'acerb', 'acerbate', 'acerbic', 'ache', 'aching', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid'],
    'sore spot': ['ache', 'aching', 'affront', 'algesia', 'blow', 'casus belli', 'cramp', 'cut', 'distress', 'dolor', 'exposed nerve', 'festering'],
    'sorehead': ['tartar', 'bear', 'bellyacher', 'complainant', 'complainer', 'crab', 'crank', 'croaker', 'crosspatch', 'dragon', 'faultfinder', 'feist'],
    'sorely': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly', 'damnably', 'deadly'],
    'soreness': ['a transient madness', 'acerbity', 'acid', 'acidity', 'acidulousness', 'acrimony', 'algesia', 'allergy', 'anaphylaxis', 'anger', 'angriness', 'animosity'],
    'sorghum': ['ambrosia', 'artificial sweetener', 'blackstrap', 'calcium cyclamate', 'cane syrup', 'clover honey', 'comb honey', 'corn syrup', 'cyclamates', 'edulcoration', 'honey', 'honeycomb'],
    'sorority': ['affiliation', 'alignment', 'alliance', 'amalgamation', 'association', 'boon companionship', 'brotherhood', 'brotherliness', 'cahoots', 'chumship', 'club', 'coadunation'],
    'sorption': ['absorbency', 'absorbent', 'absorption', 'adsorbent', 'adsorption', 'assimilation', 'blotter', 'blotting', 'blotting paper', 'chemisorption', 'chemosorption', 'digestion'],
    'sorrel': ['bay', 'bayard', 'beige', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'buckskin', 'calico pony', 'chestnut', 'chocolate', 'cinnamon'],
    'sorrow': ['ache', 'adversity', 'afflict', 'affliction', 'aggrieve', 'agonize', 'agony', 'anguish', 'apologies', 'attrition', 'ayenbite of inwit', 'bad luck'],
    'sorrowful': ['jeremianic', 'affecting', 'afflicted', 'afflictive', 'aggrieved', 'anguished', 'bitter', 'bleak', 'blue', 'careworn', 'cheerless', 'comfortless'],
    'sorry': ['abject', 'apologetic', 'ashamed', 'bad', 'base', 'base-minded', 'beggarly', 'beneath contempt', 'beneath one', 'cheap', 'cheerless', 'cheesy'],
    'sorry lot': ['backslider', 'bad egg', 'bad lot', 'black sheep', 'degenerate', 'fallen angel', 'lecher', 'lost sheep', 'lost soul', 'miscreant', 'pervert', 'pimp'],
    'sort': ['adjust', 'ailing', 'alphabetize', 'analyze', 'appraise', 'arrange', 'array', 'assess', 'assort', 'batch', 'battery', 'blood'],
    'sort of': ['a bit', 'a little', 'as it were', 'extremely', 'fairly', 'in a manner', 'in a measure', 'in a way', 'in some measure', 'kind of', 'moderately', 'more or less'],
    'sort out': ['analyze', 'answer', 'appraise', 'ascertain', 'assess', 'assort', 'assure', 'bolt', 'bottom', 'catalog', 'categorize', 'certify'],
    'sorted': ['aligned', 'arranged', 'arrayed', 'assorted', 'cataloged', 'categorized', 'classified', 'composed', 'constituted', 'disposed', 'filed', 'fixed'],
    'sortie': ['aggravated assault', 'aggression', 'air cover', 'air raid', 'air support', 'amphibious attack', 'armed assault', 'assailing', 'assailment', 'assault', 'attack', 'banzai attack'],
    'sorting': ['edp', 'analysis', 'analyzing', 'appraisal', 'arrangement', 'assessment', 'assortment', 'cataloging', 'categorization', 'classification', 'classifying', 'codification'],
    'sos': ['klaxon', 'mayday', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert', 'all clear', 'beacon', 'blinking light'],
    'sot': ['alcoholic', 'alcoholic addict', 'bacchanal', 'bacchanalian', 'bibber', 'big drunk', 'boozehound', 'boozer', 'bullheaded', 'carouser', 'chronic alcoholic', 'chronic drunk'],
    'sottish': ['boeotian', 'addicted to drink', 'asinine', 'beef-brained', 'beef-witted', 'bibacious', 'bibulous', 'blockish', 'bovine', 'chumpish', 'cloddish', 'cowish'],
    'sotto voce': ['a cappella', 'abbandono', 'accrescendo', 'affettuoso', 'agilmente', 'agitato', 'amabile', 'amoroso', 'appassionatamente', 'appassionato', 'aside', 'behind the curtain'],
    'sou': ['deutschmark', 'mark', 'reichsmark', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'afghani', 'anna', 'bagatelle', 'baht'],
    'soubrette': ['roscius', 'abigail', 'actor', 'actress', 'amah', 'antagonist', 'antihero', 'au pair girl', 'ayah', 'bad guy', 'barnstormer', 'betweenmaid'],
    'souffle': ['airy', 'beaten', 'blebby', 'blistered', 'blistering', 'blistery', 'boiled eggs', 'breakers', 'bubbling', 'bubbly', 'burbling', 'burbly'],
    'soul': ['adamite', 'geist', 'muse', 'afflatus', 'an existence', 'anima', 'anima humana', 'animating force', 'animus', 'ardency', 'ardor', 'article'],
    'soul mate': ['antony and cleopatra', 'pelleas and melisande', 'romeo and juliet', 'tristan and isolde', 'ally', 'alter ego', 'analogon', 'analogue', 'associate', 'bill-and-cooers', 'brother', 'close copy'],
    'soul stirring': ['agitating', 'breathtaking', 'charged', 'cliff-hanging', 'disquieting', 'distracting', 'disturbing', 'electric', 'exciting', 'exhilarating', 'galvanic', 'heady'],
    'soulful': ['affectional', 'affective', 'ardent', 'deep', 'demonstrative', 'emotiometabolic', 'emotiomotor', 'emotional', 'emotiovascular', 'emotive', 'expressive', 'feeling'],
    'soulless': ['abiotic', 'affectless', 'anesthetized', 'arctic', 'autistic', 'azoic', 'blunt', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity'],
    'sound': ['christian', 'able to pay', 'accepted', 'adamantine', 'admissible', 'advantageous', 'advertise', 'all there', 'announce', 'annunciate', 'appear', 'appear like'],
    'sound barrier': ['mach', 'mach number', 'mach one', 'mach two', 'air speed', 'escape velocity', 'ground speed', 'knots', 'shock wave', 'sonic barrier', 'sonic boom', 'sonic speed'],
    'sound like': ['ape', 'appear', 'appear like', 'approach', 'approximate', 'be like', 'be redolent of', 'bear resemblance', 'bring to mind', 'call to mind', 'call up', 'come close'],
    'sound track': ['backing', 'bibliofilm', 'bipack', 'black-and-white film', 'cartridge', 'color film', 'color negative film', 'dope', 'dry plate', 'emulsion', 'film', 'frame'],
    'sound truck': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'sound wave': ['amplitude', 'antinode', 'auditory effect', 'auditory phenomenon', 'crest', 'de broglie wave', 'diffraction', 'electromagnetic radiation', 'electromagnetic wave', 'frequency', 'frequency band', 'frequency spectrum'],
    'sounded': ['articulated', 'droning', 'enunciated', 'lingual', 'linguistic', 'monotone', 'monotonic', 'nuncupative', 'oral', 'parol', 'pronounced', 'said'],
    'sounder': ['telautography', 'teletype', 'teletype network', 'teletyping', 'barometer', 'closed-circuit telegraphy', 'code', 'duplex telegraphy', 'electricity', 'facsimile telegraph', 'feeler', 'interrupter'],
    'sounding': ['bathometry', 'bathymetry', 'booming', 'chiming', 'depth sounding', 'dinging', 'droning', 'echo sounding', 'echoic', 'echoing', 'echolocation', 'fathomage'],
    'sounding out': ['acid test', 'assay', 'blank determination', 'brouillon', 'criterion', 'crucial test', 'crucible', 'determination', 'docimasy', 'essay', 'feeling out', 'first draft'],
    'soundless': ['abysmal', 'abyssal', 'bottomless', 'cavernous', 'deep as hell', 'echoless', 'fathomless', 'gaping', 'hush', 'hush as death', 'hushed', 'inaudible'],
    'soundness': ['admissibility', 'advantageousness', 'agreeableness', 'aplomb', 'auspiciousness', 'authenticity', 'authoritativeness', 'authority', 'balance', 'balanced personality', 'beneficialness', 'benevolence'],
    'soundproof': ['airtight', 'ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'corrosionproof', 'dampproof', 'fire-resisting', 'fireproof', 'flameproof', 'foolproof', 'hermetic'],
    'soundproofing': ['acoustic tile', 'antiknock', 'baffler', 'cushion', 'damp', 'dampener', 'damper', 'gag', 'hushcloth', 'muffle', 'muffler', 'mute'],
    'soup': ['cat', 'aerospace', 'aerosphere', 'air hole', 'air pocket', 'airspace', 'albumen', 'batter', 'bisque', 'bonnyclabber', 'borscht', 'bouillabaisse'],
    'soup up': ['accelerate', 'aggravate', 'beef up', 'blow up', 'complicate', 'concentrate', 'condense', 'consolidate', 'deepen', 'double', 'enhance', 'exacerbate'],
    'soupcon': ['cast', 'dash', 'gleam', 'hint', 'idea', 'infusion', 'inkling', 'intimation', 'lick', 'look', 'sauce', 'scintilla'],
    'sour': ['abrupt', 'absonant', 'acerb', 'acerbate', 'acerbic', 'acerbity', 'acescency', 'acescent', 'acetify', 'acid', 'acidic', 'acidify'],
    'sour grapes': ['acid', 'acidulant', 'belittling', 'bread-and-butter pickle', 'chokecherry', 'comedown', 'contempt', 'crab apple', 'decrial', 'depreciation', 'derogation', 'detraction'],
    'sour note': ['atonalism', 'atonality', 'cacophony', 'clinker', 'discord', 'discordance', 'discordancy', 'disharmony', 'dissonance', 'dissonancy', 'dissonant chord', 'flatness'],
    'source': ['adviser', 'ambition', 'announcer', 'annunciator', 'antecedent', 'aspiration', 'author', 'authority', 'authorship', 'basis', 'begetter', 'beginning'],
    'source book': ['atlas', 'calendar', 'casebook', 'catalog', 'catalogue raisonne', 'city directory', 'classified catalog', 'concordance', 'cyclopedia', 'diatesseron', 'dictionary catalog', 'directory'],
    'sourdough': ['acid', 'acidulant', 'bread-and-butter pickle', 'butty', 'chokecherry', 'collier', 'crab apple', 'desert rat', 'dill pickle', 'driller', 'gold digger', 'gold miner'],
    'soured': ['acerb', 'acerbate', 'acerbic', 'acescent', 'aggravated', 'amplified', 'annoyed', 'augmented', 'baffled', 'balked', 'betrayed', 'bilious'],
    'souring': ['acescence', 'acetification', 'acidification', 'acidulation', 'aggravation', 'amplification', 'annoyance', 'augmentation', 'contentiousness', 'deepening', 'deliberate aggravation', 'deterioration'],
    'sourness': ['faustianism', 'acerbity', 'acidity', 'acidulousness', 'acridity', 'acridness', 'acrimony', 'anger', 'animosity', 'animus', 'asperity', 'astringence'],
    'sourpuss': ['bellyacher', 'brooder', 'complainer', 'crab', 'crank', 'crosspatch', 'depressive', 'gloomy gus', 'griper', 'grouch', 'grouser', 'kicker'],
    'sousaphone': ['alpenhorn', 'alphorn', 'althorn', 'alto horn', 'ballad horn', 'baritone', 'bass horn', 'brass choir', 'brass wind', 'brass-wind instrument', 'brasses', 'bugle'],
    'souse': ['baptism', 'baptize', 'bathe', 'bender', 'booze', 'booze up', 'boozehound', 'boozify', 'bottle sucker', 'brannigan', 'brew', 'brewing'],
    'soused': ['afflicted', 'awash', 'bathed', 'bent', 'boiled', 'bombed', 'boozy', 'canned', 'cockeyed', 'cockeyed drunk', 'crocked', 'crocko'],
    'south': ['dixie', 'dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'middle west', 'new england', 'north', 'north central region', 'northeast', 'northwest'],
    'south pole': ['alaska', 'antarctic zone', 'antarctica', 'arctic circle', 'arctic zone', 'china', 'darkest africa', 'frigid zones', 'god knows where', 'greenland', 'iceland', 'lower slobbovia'],
    'southeast': ['dixie', 'dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'middle west', 'new england', 'north', 'north central region', 'northeast', 'northwest'],
    'southerly': ['antarctic', 'arctic', 'austral', 'boreal', 'east', 'eastbound', 'easterly', 'eastermost', 'eastern', 'easternmost', 'hyperborean', 'meridional'],
    'southern': ['antarctic', 'arctic', 'austral', 'boreal', 'east', 'eastbound', 'easterly', 'eastermost', 'eastern', 'easternmost', 'hyperborean', 'meridional'],
    'southward': ['cardinal points', 'compass card', 'compass rose', 'degrees', 'east', 'eastward', 'half points', 'lubber line', 'north', 'northeast', 'northward', 'northwest'],
    'southwest': ['dixie', 'dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'middle west', 'new england', 'north', 'north central region', 'northeast', 'northwest'],
    'souvenir': ['mnemosyne', 'affect memory', 'anterograde memory', 'atavism', 'collective memory', 'commemoration', 'computer memory', 'disk memory', 'drum memory', 'emotional response', 'engram', 'favor'],
    'sovereign': ['absolute', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'anointed king', 'arch', 'ascendant', 'at the head', 'autarchic', 'autarkic'],
    'sovereignty': ['acme', 'administration', 'ascendance', 'ascendancy', 'ascendant', 'authority', 'authorization', 'balance of power', 'be-all and end-all', 'blue ribbon', 'caliphate', 'captainship'],
    'soviet': ['british cabinet', 'sanhedrin', 'us cabinet', 'advisory body', 'assembly', 'association', 'bench', 'bicameral legislature', 'board', 'board of aldermen', 'body of advisers', 'borough council'],
    'sow': ['partlet', 'barrow', 'bed', 'bestrew', 'biddy', 'bitch', 'boar', 'bossy', 'broadcast', 'brood mare', 'bullion', 'button'],
    'spa': ['bagnio', 'balneae', 'balneum', 'bath', 'bathhouse', 'bathroom', 'baths', 'caldarium', 'casino', 'club', 'clubhouse', 'gambling house'],
    'space': ['cat', 'accommodation', 'aerospace', 'aerosphere', 'aesthetic distance', 'air hole', 'air pocket', 'airspace', 'alien', 'align', 'allocate', 'allot'],
    'space capsule': ['earth insertion', 'lem', 'lm', 'apogee', 'attitude-control rocket', 'ballistic capsule', 'burn', 'capsule', 'deep-space ship', 'docking', 'docking maneuver', 'ferry rocket'],
    'space probe': ['atda', 'ats', 'alouette', 'anna', 'apollo', 'ariel', 'atlas-score', 'biosatellite', 'comsat', 'cosmos', 'courier', 'diapason'],
    'space time': ['einstein theory', 'chronology', 'continuity', 'continuum theory', 'cosmic constant', 'cubic', 'dimensional', 'duration', 'duree', 'flat', 'four-dimensional geometry', 'four-dimensional space'],
    'space walk': ['aerospace medicine', 'aerospace research', 'aerospace science', 'aerospace technology', 'astronautics', 'bioastronautics', 'break free', 'escape earth', 'escape velocity', 'go into orbit', 'grand tour', 'interplanetary travel'],
    'spacecraft': ['atda', 'ats', 'alouette', 'anna', 'apollo', 'ariel', 'atlas-score', 'biosatellite', 'comsat', 'cosmos', 'courier', 'diapason'],
    'spaced out': ['addicted', 'addicted to', 'asleep', 'cataleptic', 'catatonic', 'cold', 'comatose', 'dead', 'dependent', 'dependent on', 'doped', 'drugged'],
    'spaceship': ['earth insertion', 'lem', 'lm', 'apogee', 'attitude-control rocket', 'ballistic capsule', 'burn', 'capsule', 'deep-space ship', 'docking', 'docking maneuver', 'ferry rocket'],
    'spacious': ['gargantuan', 'ample', 'amplitudinous', 'astronomical', 'awesome', 'big', 'boundless', 'broad', 'bulky', 'capacious', 'colossal', 'commodious'],
    'spade': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'spadework': ['arrangement', 'basic training', 'briefing', 'clearing the decks', 'dirty work', 'donkeywork', 'drudgery', 'employment', 'equipment', 'fag', 'familiarization', 'fatigue'],
    'span': ['bifrost', 'a breath', 'accouple', 'accumulate', 'ace', 'aesthetic distance', 'agglutinate', 'amass', 'amplitude', 'appraise', 'appreciate', 'apse'],
    'spangle': ['adorn', 'band', 'bar', 'bead', 'bejewel', 'beribbon', 'bespangle', 'bespeckle', 'bespot', 'blink', 'blinking', 'blotch'],
    'spangled': ['ablaze', 'adorned', 'aglow', 'alight', 'bathed with light', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled'],
    'spanish guitar': ['dobro guitar', 'f-hole guitar', 'archlute', 'balalaika', 'banjo', 'banjo-uke', 'banjo-ukulele', 'banjo-zither', 'banjorine', 'banjuke', 'bass guitar', 'centerhole guitar'],
    'spank': ['admonish', 'bang', 'baste', 'bastinado', 'batter', 'beat', 'belabor', 'belt', 'birch', 'blip', 'box', 'bring to book'],
    'spanking': ['active', 'activist', 'activistic', 'acute', 'admonishment', 'admonition', 'aggressive', 'agile', 'alive', 'animated', 'awfully', 'banging'],
    'spar': ['chinese boxing', 'altercate', 'argue', 'argufy', 'bandy words', 'bar', 'bare pole', 'battle', 'beam', 'bicker', 'boom', 'bout'],
    'spare': ['lenten', 'scotch', 'spartan', 'abandon', 'abjure', 'absolve', 'abstain', 'abstain from', 'abstemious', 'accessory', 'additional', 'afford'],
    'spare time': ['casual', 'convenience', 'ease', 'extra', 'free time', 'freedom', 'goof-off time', 'idle hours', 'incidental', 'leisure', 'occasional', 'odd'],
    'spare tire': ['abdomen', 'abomasum', 'bay window', 'beerbelly', 'belly', 'breadbasket', 'craw', 'crop', 'diaphragm', 'embonpoint', 'first stomach', 'gizzard'],
    'spared': ['absolved', 'acquitted', 'blotted', 'canceled', 'chartered', 'condoned', 'conserved', 'disregarded', 'excepted', 'exculpated', 'excused', 'exempt'],
    'spareribs': ['bacon', 'butt', 'chitterlings', 'cochon de lait', 'cracklings', 'fat back', 'flitch', 'gammon', 'ham', 'ham steak', 'haslet', 'headcheese'],
    'sparge': ['aerosol', 'asperge', 'aspergil', 'aspergillum', 'atomizer', 'bedew', 'bespatter', 'besprinkle', 'clyster', 'concentrate sprayer', 'dabble', 'damp'],
    'sparing': ['lenten', 'scotch', 'spartan', 'absolution', 'abstemious', 'amnesty', 'ascetic', 'austere', 'benevolent', 'canny', 'careful', 'chary'],
    'sparingly': ['cannily', 'carefully', 'charily', 'economically', 'frugally', 'husbandly', 'in moderation', 'meagerly', 'moderately', 'poorly', 'providently', 'prudently'],
    'spark': ['ac arc', 'beau brummel', 'poulsen arc', 'abettor', 'activate', 'actuate', 'actuator', 'address', 'animate', 'animator', 'aperiodic discharge', 'arc'],
    'spark of life': ['anima', 'animating force', 'atman', 'bathmism', 'beating heart', 'biological clock', 'biorhythm', 'blood', 'breath', 'breath of life', 'divine breath', 'divine spark'],
    'spark plug': ['abettor', 'activator', 'actuator', 'animator', 'arouser', 'cajoler', 'coax', 'coaxer', 'encourager', 'energizer', 'firer', 'gadfly'],
    'sparkle': ['animation', 'be brilliant', 'be merry with', 'beam', 'blaze', 'blink', 'blinking', 'blubber', 'boil', 'boil over', 'boiling', 'brightness'],
    'sparkling': ['attic', 'beaming', 'beaten', 'beatific', 'beatified', 'biting', 'blebby', 'blessed', 'blinking', 'blinky', 'blissful', 'blistered'],
    'sparks': ['bakehead', 'black gang', 'boilerman', 'brass pounder', 'bungs', 'cabin boy', 'chips', 'commissary steward', 'complement', 'deckhand', 'deckie', 'dit-da artist'],
    'sparrer': ['chinese boxer', 'bantamweight', 'black belt', 'boxer', 'brown belt', 'bruiser', 'featherweight', 'fighter', 'fisticuffer', 'flyweight', 'heavyweight', 'karate expert'],
    'sparse': ['almost unheard-of', 'at a premium', 'broadcast', 'cheeseparing', 'chinchy', 'chintzy', 'diffuse', 'discrete', 'dispersed', 'dispread', 'disseminated', 'dissipated'],
    'sparsely': ['at infrequent intervals', 'at large', 'diffusely', 'dispersedly', 'everywhere', 'exiguously', 'hardly', 'hardly ever', 'here and there', 'in all quarters', 'in places', 'in spots'],
    'sparsity': ['chinchiness', 'chintziness', 'dearth', 'exiguity', 'fewness', 'infrequence', 'infrequency', 'meagerness', 'miserliness', 'niggardliness', 'occasionalness', 'paucity'],
    'spartan': ['apostolic', 'encratic', 'laconian', 'lenten', 'pythagorean', 'rechabite', 'shaker', 'spartanic', 'stoic', 'abbreviated', 'abridged', 'abstemious'],
    'spasm': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'abscess', 'access', 'ache', 'aching', 'acquired epilepsy', 'activated epilepsy', 'acute pain', 'ado', 'affect epilepsy'],
    'spasmodic': ['acute', 'adrift', 'afflictive', 'afloat', 'agonizing', 'aimless', 'alternating', 'amorphous', 'arrhythmic', 'atrocious', 'biting', 'broken'],
    'spasmodically': ['at haphazard', 'at intervals', 'at irregular intervals', 'at random', 'brokenly', 'by catches', 'by chance', 'by fits', 'by jerks', 'by snatches', 'capriciously', 'carelessly'],
    'spastic': ['apoplectic', 'arthritic', 'broken', 'capricious', 'careening', 'case', 'cataclysmic', 'catchy', 'choppy', 'consumptive', 'convulsive', 'desultory'],
    'spat': ['altercate', 'altercation', 'argument', 'beef', 'bicker', 'bickering', 'blood feud', 'box', 'brawl', 'broil', 'brood', 'buffet'],
    'spate': ['niagara', 'abundance', 'acres', 'affluence', 'afflux', 'affluxion', 'ample sufficiency', 'ampleness', 'amplitude', 'army', 'asperse', 'avalanche'],
    'spatter': ['asperge', 'barrage', 'beat', 'beating', 'bedabble', 'bedaub', 'bedew', 'bespatter', 'bespeckle', 'bespot', 'besprinkle', 'bloodstain'],
    'spattered': ['bespeckled', 'blotched', 'blotchy', 'dotted', 'dusted', 'freckle-faced', 'freckled', 'freckly', 'macular', 'maculate', 'maculated', 'peppered'],
    'spattering': ['affusion', 'aspergation', 'aspersion', 'attenuation', 'baptism', 'bath', 'bathing', 'beating', 'bedewing', 'broadcast', 'broadcasting', 'circumfusion'],
    'spatula': ['air brush', 'art paper', 'brush', 'camera lucida', 'camera obscura', 'canvas', 'chalk', 'charcoal', 'chisel', 'crayon', 'drawing paper', 'drawing pencil'],
    'spawn': ['albumen', 'bear', 'beget', 'breed', 'bring about', 'bring forth', 'bring into being', 'brood', 'call into being', 'cause', 'caviar', 'clutch'],
    'speak': ['accost', 'acquaint', 'act for', 'address', 'admonish', 'advert to', 'advertise', 'advertise of', 'advise', 'affect', 'affirm', 'allege'],
    'speak for': ['act for', 'advocate', 'allege in support', 'answer', 'answer for', 'appear for', 'argue for', 'assert', 'back up', 'champion', 'commission', 'contend for'],
    'speak for itself': ['aller sans dire', 'approve', 'argue', 'attest', 'be clear', 'be manifest', 'be no secret', 'be plain', 'bespeak', 'betoken', 'breathe', 'come across'],
    'speak out': ['affirm', 'affront', 'allege', 'announce', 'annunciate', 'appear', 'argue', 'assert', 'assever', 'asseverate', 'aver', 'avouch'],
    'speak to': ['accost', 'address', 'apostrophize', 'appeal to', 'approach', 'bespeak', 'buttonhole', 'call down', 'call to', 'come down on', 'dress down', 'give it to'],
    'speak up': ['affirm', 'affront', 'allege', 'announce', 'annunciate', 'appear', 'argue', 'assert', 'assever', 'asseverate', 'aver', 'avouch'],
    'speak up for': ['advocate', 'allege in support', 'answer', 'argue for', 'assert', 'champion', 'contend for', 'counter', 'defend', 'espouse', 'maintain', 'make a plea'],
    'speakeasy': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'cabaret', 'cafe', 'cocktail lounge', 'dive'],
    'speaker': ['acoustical network', 'capacitor speaker', 'chair', 'chairman', 'chatterbox', 'coaxial speaker', 'cone', 'convener', 'conversationalist', 'crossover network', 'debater', 'declaimer'],
    'speaking': ['esp', 'accents', 'answer', 'articulate', 'breathing', 'chatter', 'comment', 'commerce', 'communication', 'communion', 'congress', 'connection'],
    'speaking of': ['a propos', 'about', 'anent', 'apropos', 'apropos of', 'as for', 'as regards', 'as respects', 'as to', 'by the by', 'by the way', 'concerning'],
    'spear': ['anthrophore', 'assegai', 'auger', 'axis', 'bag', 'bayonet', 'bill', 'bine', 'bite', 'blade', 'bole', 'bore'],
    'spear side': ['affiliation', 'agnate', 'ancestry', 'apparentation', 'birth', 'blood', 'blood relation', 'blood relative', 'bloodline', 'branch', 'breed', 'clansman'],
    'spearhead': ['advance guard', 'airhead', 'avant-garde', 'battle line', 'be the bellwether', 'beachhead', 'beacon', 'blaze the trail', 'break the ice', 'bridgehead', 'cutting edge', 'farthest outpost'],
    'special': ['amtrak', 'absolute', 'another', 'article', 'article of commerce', 'article of merchandise', 'baggage train', 'best', 'bizarre', 'bosom', 'cable railroad', 'categorical'],
    'special case': ['allowance', 'cession', 'circumscription', 'concession', 'definiteness', 'exception', 'exemption', 'extenuating circumstances', 'grain of salt', 'grant', 'hedge', 'hedging'],
    'special delivery': ['pp', 'rd', 'rfd', 'airmail', 'book post', 'correspondence', 'direct mail', 'direct-mail selling', 'express', 'fourth-class mail', 'frank', 'halfpenny post'],
    'special interests': ['black power', 'italian vote', 'jewish vote', 'polish power', 'rasputin', 'svengali', 'vip', 'white power', 'access', 'bad influence', 'big wheel', 'black vote'],
    'special school': ['alternate', 'alternative school', 'blab school', 'boarding school', 'central school', 'consolidated school', 'continuation school', 'correspondence school', 'country day school', 'dame school', 'day school', 'evening school'],
    'special treatment': ['advance', 'advancement', 'allowance', 'cession', 'circumscription', 'concession', 'exception', 'exemption', 'expediting', 'expedition', 'extenuating circumstances', 'facilitation'],
    'specialist': ['wall streeter', 'adept', 'aficionado', 'amateur', 'anesthesiologist', 'artist', 'artiste', 'authoritative', 'authority', 'bond crowd', 'broker', 'buff'],
    'speciality': ['ability', 'accomplishment', 'adeptness', 'aptitude', 'area', 'art', 'baby', 'bag', 'bump', 'caliber', 'capability', 'capacity'],
    'specialization': ['alteration', 'analysis', 'anatomization', 'area', 'art', 'atomization', 'bag', 'business', 'calling', 'career', 'career building', 'careerism'],
    'specialize': ['analyze', 'anatomize', 'assign', 'atomize', 'be into', 'be strong in', 'bound', 'change', 'chop logic', 'condition', 'confine', 'contain'],
    'specialize in': ['be into', 'be strong in', 'carry on', 'conduct', 'confine', 'do', 'employ', 'engage in', 'exercise', 'feature', 'follow', 'go in for'],
    'specialty': ['academic discipline', 'academic specialty', 'adjunct', 'applied science', 'appurtenance', 'area', 'arena', 'aroma', 'arrangement', 'art', 'aspect', 'attribute'],
    'specialty shop': ['antique store', 'apothecary', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'chemist', 'cigar store', 'clothiers', 'clothing store', 'confectionery', 'dress shop'],
    'specie': ['and pence', 'cash', 'circulating medium', 'coin', 'coinage', 'coined liberty', 'cold cash', 'crown', 'currency', 'dollars', 'double eagle', 'doubloon'],
    'species': ['animal kingdom', 'antonomasia', 'binomial nomenclature', 'biosystematics', 'biosystematy', 'biotype', 'blood', 'branch', 'brand', 'breed', 'brood', 'cast'],
    'specific': ['absolute', 'aid', 'alterative', 'analeptic', 'assistance', 'balm', 'balsam', 'categorical', 'certain', 'characteristic', 'circumscribed', 'circumscript'],
    'specific gravity': ['g suit', 'apogeotropism', 'closeness', 'compactness', 'congestedness', 'congestion', 'consistence', 'consistency', 'crowdedness', 'denseness', 'density', 'firmness'],
    'specifically': ['at length', 'categorically', 'completely', 'concretely', 'definitely', 'distinctively', 'distinctly', 'especially', 'exactly', 'explicitly', 'expressly', 'fully'],
    'specification': ['allocation', 'allowance', 'analysis', 'anatomization', 'assignment', 'atomization', 'attribution', 'boundary condition', 'bounding', 'cameo', 'catalog', 'cataloging'],
    'specify': ['address to', 'adduce', 'advert to', 'allude to', 'anatomize', 'assign', 'atomize', 'baptize', 'be taken as', 'bound', 'bring to attention', 'bring to notice'],
    'specimen': ['case', 'case history', 'case in point', 'cross section', 'embodiment', 'example', 'exemplar', 'exponent', 'illustration', 'instance', 'little bite', 'little smack'],
    'specious': ['barmecidal', 'barmecide', 'airy', 'alleged', 'apparent', 'apparently sound', 'apparitional', 'autistic', 'avowed', 'beguiling', 'casuistic', 'chimeric'],
    'specious reasoning': ['apparent soundness', 'casuistry', 'circularity', 'deduction', 'deductive reasoning', 'demonstration', 'discourse', 'discourse of reason', 'discursive reason', 'disingenuousness', 'distortion', 'equivocalness'],
    'speciousness': ['acting', 'affectation', 'apparent character', 'apparent soundness', 'appearance', 'appearances', 'attitudinizing', 'bluff', 'bluffing', 'casuistry', 'cheating', 'circularity'],
    'speck': ['ace', 'amount', 'atom', 'band', 'bar', 'bespangle', 'bespeckle', 'bespot', 'besprinkle', 'birthmark', 'bit', 'black sheep'],
    'speckled': ['bespangled', 'bespattered', 'bespeckled', 'blotched', 'blotchy', 'brindled', 'dappled', 'discolored', 'dotted', 'dotty', 'dusted', 'flea-bitten'],
    'specs': ['polaroid glasses', 'bifocals', 'blinkers', 'cheaters', 'colored glasses', 'contact lens', 'dark glasses', 'divided spectacles', 'eyeglass', 'eyeglasses', 'glasses', 'goggles'],
    'spectacle': ['grand guignol', 'passion play', 'tom show', 'amazement', 'antimasque', 'astonishing thing', 'astonishment', 'audience success', 'ballet', 'blazon', 'bomb', 'bravura'],
    'spectacles': ['polaroid glasses', 'bifocals', 'blinkers', 'cheaters', 'colored glasses', 'contact lens', 'dark glasses', 'divided spectacles', 'eyeglass', 'eyeglasses', 'glasses', 'goggles'],
    'spectacular': ['actor-proof', 'all-star', 'amazing', 'astonishing', 'astounding', 'ballet', 'balletic', 'blatant', 'brazen', 'brazenfaced', 'breathtaking', 'cinematic'],
    'spectator': ['accepter', 'acquirer', 'addressee', 'aficionado', 'attender', 'attestant', 'attestator', 'attester', 'audience', 'auditor', 'auditory', 'beholder'],
    'specter': ['dracula', 'frankenstein', 'wolf-man', 'apparition', 'appearance', 'atua', 'bogey', 'bogeyman', 'bugaboo', 'bugbear', 'daemon', 'demon'],
    'spectral': ['barmecidal', 'barmecide', 'airy', 'apparent', 'apparitional', 'astral', 'autistic', 'bicolor', 'bicolored', 'cadaverous', 'chimeric', 'chromatic'],
    'spectrograph': ['cassegrainian telescope', 'newtonian telescope', 'oao', 'oso', 'astronomical observatory', 'astronomical telescope', 'coelostat', 'coronagraph', 'coronograph', 'heliostat', 'observatory', 'orrery'],
    'spectrometry': ['chromatics', 'chromatography', 'chromatology', 'chromatoscopy', 'colorimetry', 'electron optics', 'infrared spectroscopy', 'microscopics', 'microscopy', 'optical physics', 'optics', 'optometry'],
    'spectroscope': ['cassegrainian telescope', 'newtonian telescope', 'oao', 'oso', 'astronomical observatory', 'astronomical telescope', 'chromatoscope', 'coelostat', 'coronagraph', 'coronograph', 'heliostat', 'kaleidoscope'],
    'spectroscopy': ['astrogeology', 'astrognosy', 'astrography', 'astrolithology', 'astronomy', 'astrophotography', 'astrophysics', 'celestial mechanics', 'chromatics', 'chromatography', 'chromatology', 'chromatoscopy'],
    'spectrum': ['af', 'cps', 'dalmatian', 'ehf', 'hf', 'hz', 'indian file', 'mf', 'maxwell triangle', 'munsell scale', 'rf', 'shf'],
    'speculate': ['be abstracted', 'be caught short', 'be short', 'belong', 'brood', 'bucket', 'bucketshop', 'buy in', 'buy into', 'call', 'cast a horoscope', 'cast a nativity'],
    'speculation': ['abstraction', 'actuarial prediction', 'advisement', 'agiotage', 'analysis', 'apocalypse', 'arbitrage', 'betting', 'blind guess', 'bold conjecture', 'brainwork', 'brooding'],
    'speculative': ['abstract', 'academic', 'adventurous', 'aleatory', 'analytical', 'arguable', 'armchair', 'at issue', 'chancy', 'closet', 'cogitative', 'cognitive'],
    'speculator': ['adventurer', 'armchair authority', 'betting ring', 'bettor', 'big operator', 'boneshaker', 'cardshark', 'cardsharp', 'cardsharper', 'casuist', 'compulsive gambler', 'cosmologist'],
    'speech': ['esp', 'address', 'after-dinner speech', 'alliteration', 'allocution', 'allusion', 'anacoluthon', 'anadiplosis', 'analogy', 'anaphora', 'anastrophe', 'answer'],
    'speech organ': ['alveolar ridge', 'alveolus', 'apex', 'arytenoid cartilages', 'back', 'blade', 'dorsum', 'hard palate', 'larynx', 'lips', 'nasal cavity', 'oral cavity'],
    'speechless': ['anaudic', 'aphasic', 'aphonic', 'breathless', 'brief', 'brusque', 'close', 'close-tongued', 'closemouthed', 'concise', 'curt', 'dazed'],
    'speechmaker': ['debater', 'declaimer', 'demagogue', 'haranguer', 'jawsmith', 'panelist', 'public speaker', 'rabble-rouser', 'ranter', 'speaker', 'speecher', 'speechifier'],
    'speed': ['benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'methedrine', 'abruptness', 'accelerate', 'advance', 'advantage', 'aid'],
    'speed freak': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'chain smoker', 'cocaine sniffer', 'cokie', 'cubehead', 'dipsomaniac', 'dope fiend', 'doper', 'drug abuser'],
    'speed of sound': ['mach', 'mach number', 'mach one', 'mach two', 'air speed', 'escape velocity', 'ground speed', 'knots', 'shock wave', 'sonic barrier', 'sonic boom', 'sonic speed'],
    'speed up': ['accelerate', 'bundle', 'bustle', 'crack on', 'crowd', 'dispatch', 'drive on', 'expedite', 'forward', 'gain ground', 'haste', 'hasten'],
    'speeder': ['jehu', 'sunday driver', 'backseat driver', 'bus driver', 'busman', 'cabby', 'cabdriver', 'chauffeur', 'driver', 'flier', 'goer', 'hack'],
    'speedily': ['pdq', 'against the clock', 'amain', 'apace', 'at flank speed', 'at once', 'by forced marches', 'cursorily', 'decisively', 'directly', 'double-quick', 'expeditiously'],
    'speediness': ['agility', 'air speed', 'alacrity', 'briskness', 'celerity', 'decisiveness', 'dispatch', 'expedition', 'expeditiousness', 'fastness', 'flight', 'flit'],
    'speedup': ['accelerando', 'acceleration', 'aggravation', 'beefing-up', 'blowing up', 'blowup', 'concentration', 'condensation', 'consolidation', 'deepening', 'drive', 'enhancement'],
    'speedway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'speedy': ['abrupt', 'agile', 'alacritous', 'alert', 'apt', 'breakneck', 'brief', 'brisk', 'cometary', 'cursory', 'dashing', 'decisive'],
    'spell': ['jonah', 'access', 'act for', 'add up to', 'alchemy', 'allure', 'alternate', 'amount to', 'appeal', 'argue', 'arsis', 'attraction'],
    'spell out': ['account for', 'adduce', 'allegorize', 'amplify', 'anatomize', 'atomize', 'circumstantiate', 'cite', 'clarify', 'clear up', 'complete', 'construe'],
    'spellbind': ['absorb', 'absorb the attention', 'arrest', 'becharm', 'beguile', 'bewitch', 'captivate', 'carry away', 'cast a spell', 'catch', 'catch up', 'charm'],
    'spellbinder': ['cicero', 'circe', 'demosthenes', 'euryale', 'gorgon', 'medea', 'medusa', 'stheno', 'william jennings bryan', 'winston churchill', 'bewitcher', 'charmer'],
    'spellbinding': ['ciceronian', 'circean', 'demosthenian', 'demosthenic', 'tullian', 'absorbing', 'alchemy', 'alluring', 'appealing', 'appetizing', 'arresting', 'articulate'],
    'spellbound': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'arrested', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'becharmed'],
    'speller': ['abecedarium', 'abecedary', 'alphabet book', 'battledore', 'casebook', 'exercise book', 'gradus', 'grammar', 'hornbook', 'manual', 'manual of instruction', 'primer'],
    'spend': ['ablate', 'absorb', 'allot', 'assign', 'assimilate', 'attend to business', 'be exposed to', 'be subjected to', 'bestow', 'bleed white', 'blow', 'budget'],
    'spendthrift': ['big-time spender', 'dissipative', 'easy come', 'easy go', 'extravagant', 'improvident', 'incontinent', 'intemperate', 'lavish', 'overgenerous', 'overlavish', 'overliberal'],
    'spent': ['ablated', 'acquitted', 'all in', 'ausgespielt', 'beat', 'beat up', 'beaten', 'bleary', 'bone-weary', 'burned-out', 'burnt up', 'bushed'],
    'sperm': ['act of love', 'adultery', 'androcyte', 'antheridium', 'antherozoid', 'aphrodisia', 'ass', 'autacoid', 'balling', 'bile', 'carnal knowledge', 'chalone'],
    'spermatic': ['cervical', 'clitoral', 'excretory', 'fecundative', 'fertilizing', 'gametic', 'gamic', 'genital', 'germinal', 'lachrymal', 'lachrymose', 'lacrimatory'],
    'spermatozoa': ['androcyte', 'antheridium', 'antherozoid', 'male gamete', 'milt', 'pollen', 'protein', 'scum', 'seed', 'semen', 'seminal fluid', 'sperm'],
    'spermatozoon': ['anlage', 'androcyte', 'antheridium', 'antherozoid', 'bud', 'egg', 'embryo', 'germ', 'germen', 'loins', 'male gamete', 'milt'],
    'spew': ['barf', 'be seasick', 'be sick', 'belch', 'blow open', 'blow out', 'break out', 'bring up', 'burst', 'burst forth', 'burst out', 'cascade'],
    'sphere': ['aldebaran', 'canicula', 'dog star', 'hesper', 'hesperus', 'lucifer', 'north star', 'phosphor', 'phosphorus', 'polaris', 'sirius', 'venus'],
    'sphere of influence': ['eisenhower doctrine', 'monroe doctrine', 'nixon doctrine', 'truman doctrine', 'ambit', 'appeasement', 'bailiwick', 'balance of power', 'brinkmanship', 'coexistence', 'colonialism', 'compromise'],
    'spherical': ['bulblike', 'bulbous', 'cubic', 'dimensional', 'ellipsoid', 'flat', 'fourth-dimensional', 'global', 'globate', 'globe-shaped', 'globed', 'globelike'],
    'sphincter': ['annular muscle', 'annulus', 'areola', 'aureole', 'chaplet', 'circle', 'circuit', 'circumference', 'circus', 'closed circle', 'corona', 'coronet'],
    'spic': ['aussie', 'boche', 'canuck', 'chink', 'guinea', 'hunk', 'hunkie', 'jerry', 'kraut', 'krauthead', 'mick', 'mickey'],
    'spiccato': ['a cappella', 'abbandono', 'accidental', 'accrescendo', 'adagietto', 'adagio', 'affettuoso', 'agilmente', 'agitato', 'allegretto', 'allegro', 'amabile'],
    'spice': ['tabasco', 'worcestershire sauce', 'allspice', 'anchovies', 'angelica', 'applesauce', 'aroma', 'balm', 'balminess', 'basil', 'bell pepper', 'bite'],
    'spiceless': ['dead', 'dilute', 'diluted', 'fade', 'flat', 'flavorless', 'gruelly', 'inane', 'indifferent', 'insipid', 'jejune', 'mild'],
    'spicule': ['bramble', 'brier', 'bristle', 'burr', 'cactus', 'catchweed', 'cleavers', 'goose grass', 'needle', 'nettle', 'pine needle', 'prickle'],
    'spicy': ['ambrosial', 'aromatic', 'balmy', 'bawdy', 'biting', 'blue', 'brisk', 'broad', 'burning', 'curried', 'essenced', 'exciting'],
    'spider': ['chilopoda', 'chordata', 'echiuroidea', 'ectoprocta', 'entoprocta', 'monoplacophora', 'nemertinea', 'phoronidea', 'arachnid', 'arthropod', 'beetle', 'bug'],
    'spidery': ['bony', 'dilapidated', 'doddering', 'flat', 'flat-chested', 'fleshless', 'gangling', 'gangly', 'gaunt', 'gawky', 'groggy', 'lank'],
    'spiel': ['advertise', 'ballyhoo', 'bark', 'bat the breeze', 'beat the gums', 'bill', 'boost', 'build up', 'bulletin', 'chin', 'circularize', 'cry up'],
    'spieler': ['mc', 'auteur', 'ballyhoo man', 'ballyhooer', 'barker', 'bunco artist', 'bunco steerer', 'callboy', 'canvasser', 'cardsharp', 'cardsharper', 'carpetbagger'],
    'spiffy': ['ok', 'ace-high', 'bad', 'bandbox', 'bang-up', 'bonzer', 'boss', 'braw', 'bully', 'but good', 'chic', 'classy'],
    'spigot': ['ball cock', 'ball valve', 'bung', 'bunghole', 'check valve', 'cock', 'cork', 'drain cock', 'draw cock', 'faucet', 'gate', 'hydrant'],
    'spike': ['adulterate', 'ament', 'annul', 'auger', 'auricle', 'baffle', 'balk', 'bastardize', 'bayonet', 'bite', 'blast', 'block'],
    'spiked': ['acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'barbed', 'cornuted', 'cusped', 'cuspidate'],
    'spile': ['bar', 'bind', 'block', 'block up', 'blockade', 'bung', 'caulk', 'check valve', 'chink', 'choke', 'choke off', 'choke up'],
    'spill': ['mystik tape', 'scotch tape', 'accident', 'acknowledge', 'adhesive tape', 'admit', 'admit everything', 'allow', 'alluvion', 'alluvium', 'avow', 'babble'],
    'spill over': ['alluvion', 'alluvium', 'cascade', 'cataclysm', 'cataract', 'deluge', 'engulf', 'engulfment', 'fill', 'flood', 'inundate', 'inundation'],
    'spill the beans': ['babble', 'be indiscreet', 'be unguarded', 'betray', 'betray a confidence', 'blab', 'blabber', 'blurt', 'blurt out', 'give away', 'inform', 'inform on'],
    'spillway': ['aqueduct', 'arroyo', 'bed', 'canal', 'creek bed', 'culvert', 'donga', 'dry bed', 'flume', 'gulch', 'gully', 'gullyhole'],
    'spin': ['charybdis', 'sunday drive', 'advance', 'airing', 'angle', 'angular momentum', 'angular motion', 'angular velocity', 'ascend', 'axial motion', 'back', 'back up'],
    'spin out': ['chatter', 'continue', 'dawdle', 'drag out', 'draw', 'draw out', 'dwell on', 'elongate', 'extend', 'fill out', 'lengthen', 'lengthen out'],
    'spinal cord': ['afferent neuron', 'autonomic nervous system', 'axon', 'brain', 'central nervous system', 'cerebral cortex', 'craniosacral nervous system', 'dendrite', 'effector organ', 'efferent neuron', 'ganglion', 'gray matter'],
    'spindle': ['arbor', 'axis', 'axle', 'axle bar', 'axle shaft', 'axle spindle', 'axle-tree', 'distaff', 'fulcrum', 'gimbal', 'gudgeon', 'hinge'],
    'spindle side': ['affiliation', 'agnate', 'ancestry', 'apparentation', 'birth', 'blood', 'blood relation', 'blood relative', 'bloodline', 'branch', 'breed', 'clansman'],
    'spindly': ['bony', 'dilapidated', 'doddering', 'flat', 'flat-chested', 'fleshless', 'gangling', 'gangly', 'gaunt', 'gawky', 'groggy', 'lank'],
    'spindrift': ['breakers', 'collar', 'foam', 'froth', 'head', 'lather', 'meringue', 'mousse', 'offscum', 'plash', 'puff', 'scud'],
    'spine': ['advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'barb', 'barbel', 'barbule', 'bearer'],
    'spined': ['acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'barbed', 'cornuted', 'cusped', 'cuspidate'],
    'spineless': ['abulic', 'adrift', 'afloat', 'afraid', 'alternating', 'amorphous', 'anemic', 'asthenic', 'bloodless', 'capricious', 'changeable', 'changeful'],
    'spinet': ['klavier', 'steinway', 'baby grand', 'cembalo', 'clarichord', 'clavicembalo', 'clavichord', 'clavicittern', 'clavicymbal', 'clavicytherium', 'clavier', 'concert grand'],
    'spinner': ['bait', 'birdlime', 'bola', 'cobweb', 'dragnet', 'fishhook', 'fly', 'gill net', 'ground bait', 'hook', 'jenny', 'jig'],
    'spinning': ['angular momentum', 'angular motion', 'angular velocity', 'axial motion', 'bowling', 'centrifugation', 'circulation', 'circumgyration', 'circumrotation', 'full circle', 'gyrating', 'gyration'],
    'spinster': ['bachelor girl', 'feme sole', 'jenny', 'lone woman', 'maid', 'maiden', 'maiden lady', 'mule', 'old maid', 'silkworm', 'single girl', 'spider'],
    'spinsterhood': ['bachelordom', 'bachelorhood', 'bachelorism', 'bachelorship', 'celibacy', 'continence', 'maidenhead', 'maidenhood', 'misogamy', 'misogyny', 'monachism', 'monasticism'],
    'spiny': ['herculean', 'abstruse', 'acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'arduous', 'barbed'],
    'spiracle': ['air duct', 'air hole', 'air passage', 'air shaft', 'air tube', 'airway', 'armhole', 'avenue', 'blowhole', 'breathing hole', 'bullet-hole', 'bunghole'],
    'spiral': ['milky way', 'o-shaped', 'via lactea', 'acrobatics', 'aerobatics', 'ambagious', 'anfractuous', 'arise', 'ascend', 'aspire', 'backhanded', 'bank'],
    'spiraling': ['anabatic', 'ascendant', 'ascending', 'ascensional', 'ascensive', 'circling', 'circuition', 'circuitousness', 'circuitry', 'circularity', 'circulation', 'circumambience'],
    'spire': ['acme', 'antenna tower', 'anthrophore', 'apex', 'apogee', 'arise', 'ascend', 'aspire', 'axis', 'barbican', 'become airborne', 'belfry'],
    'spirit': ['geist', 'masan', 'muse', 'abandon', 'abduce', 'abduct', 'activity', 'adventuresomeness', 'adventurousness', 'affective meaning', 'afflatus', 'aggression'],
    'spirit world': ['bodilessness', 'ghostliness', 'immateriality', 'immaterialness', 'impalpability', 'imponderability', 'incorporeality', 'incorporeity', 'inextension', 'intangibility', 'nonexteriority', 'occult phenomena'],
    'spirited': ['abandoned', 'active', 'activist', 'activistic', 'acute', 'afire', 'aggressive', 'agog', 'alacritous', 'alert', 'alive', 'all agog'],
    'spiritless': ['laodicean', 'olympian', 'affectless', 'aloof', 'anesthetized', 'apathetic', 'arctic', 'arid', 'asleep', 'autistic', 'barren', 'benumbed'],
    'spirits': ['angostura bitters', 'canadian', 'canadian whiskey', 'cognac', 'grand champagne', 'irish', 'irish whiskey', 'john barleycorn', 'kirsch', 'scotch', 'scotch whiskey', 'absinthe'],
    'spiritual': ['christlike', 'christly', 'god-fearing', 'negro spiritual', 'affective', 'airy', 'angelic', 'anthem', 'arcane', 'asomatous', 'astral', 'automatist'],
    'spiritualism': ['berkeleianism', 'hegelianism', 'kantianism', 'neoplatonism', 'platonic form', 'platonic idea', 'platonism', 'absolute idealism', 'animatism', 'animism', 'form', 'hylozoism'],
    'spiritualist': ['berkeleian', 'hegelian', 'kantian', 'neoplatonist', 'platonist', 'animist', 'automatist', 'ecstatic', 'idealist', 'immaterialist', 'medium', 'necromancer'],
    'spiritualistic': ['berkeleian', 'hegelian', 'kantian', 'neoplatonic', 'neoplatonistic', 'platonic', 'platonistic', 'animist', 'animistic', 'automatist', 'clairaudient', 'clairsentient'],
    'spirituality': ['christianity', 'christlikeness', 'christliness', 'angelicalness', 'beauty of holiness', 'bliss', 'bodilessness', 'fear of god', 'ghostliness', 'godlikeness', 'godliness', 'godly-mindedness'],
    'spiritualize': ['attenuate', 'bolt', 'clarify', 'clear', 'decrassify', 'dematerialize', 'depurate', 'disembody', 'disincarnate', 'distill', 'edulcorate', 'elute'],
    'spirituous': ['air-built', 'airy', 'alcoholic', 'ardent', 'chimerical', 'cloud-built', 'dreamlike', 'ethereal', 'fanciful', 'fatuitous', 'fatuous', 'gaseous'],
    'spirochete': ['adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'bacillus', 'bacteria', 'bacterium', 'bug', 'coccus', 'echovirus'],
    'spit': ['andiron', 'assibilate', 'assibilation', 'auger', 'bayonet', 'bill', 'bite', 'bore', 'breakwater', 'broach', 'buzz', 'cape'],
    'spitball': ['bowl', 'cast', 'change of pace', 'change-up', 'chuck', 'chunk', 'curve', 'downcurve', 'fastball', 'fling', 'flip', 'forward pass'],
    'spite': ['anglophobia', 'russophobia', 'schadenfreude', 'abhorrence', 'abomination', 'animosity', 'annoy', 'antagonism', 'anti-semitism', 'antipathy', 'aversion', 'belligerence'],
    'spiteful': ['acrid', 'acrimonious', 'antagonistic', 'antipathetic', 'bearish', 'belligerent', 'bitchy', 'bitter', 'cankered', 'cantankerous', 'cattish', 'catty'],
    'spitfire': ['mafioso', 'young turk', 'battle-ax', 'beast', 'beldam', 'berserk', 'berserker', 'bitch', 'bomber', 'brute', 'cat', 'common scold'],
    'spitting distance': ['ace', 'bit', 'bowshot', 'brief span', 'close quarters', 'close range', 'crack', 'earreach', 'earshot', 'gunshot', 'hair', 'hair space'],
    'spitting image': ['doppelganger', 'actual thing', 'carbon copy', 'companion', 'copy', 'dead ringer', 'ditto', 'double', 'duplicate', 'effigy', 'equivalent', 'exact counterpart'],
    'splash': ['ado', 'asperge', 'babble', 'bedabble', 'bedew', 'bespatter', 'bespeckle', 'bespot', 'besprinkle', 'birthmark', 'blaze', 'blazon'],
    'splashing': ['affusion', 'aspergation', 'aspersion', 'babbling', 'baptism', 'bath', 'bathing', 'bedewing', 'bubbling', 'burbling', 'dampening', 'damping'],
    'splashy': ['aquatic', 'aqueous', 'brave', 'bravura', 'braw', 'chichi', 'daring', 'dashing', 'dirty', 'dressy', 'exhibitionistic', 'flamboyant'],
    'splat': ['bang', 'beam', 'billet', 'board', 'boarding', 'bump', 'burst', 'bust', 'clap', 'clapboard', 'clash', 'cord'],
    'splatter': ['scotch mist', 'asperge', 'beat', 'beat a ruffle', 'beat a tattoo', 'bedabble', 'bedew', 'bespatter', 'bespeckle', 'bespot', 'besprinkle', 'blood rain'],
    'splattered': ['bespeckled', 'blotched', 'blotchy', 'dotted', 'dusted', 'freckle-faced', 'freckled', 'freckly', 'macular', 'maculate', 'maculated', 'peppered'],
    'splay': ['aberrate', 'addition', 'adjunct', 'aggrandizement', 'ampliation', 'amplification', 'attenuation', 'augmentation', 'awkward', 'bestrew', 'branch', 'branch out'],
    'splayfoot': ['arch', 'bandy', 'bandy-legged', 'blemished', 'bloated', 'bowlegged', 'bowlegs', 'camelback', 'cleft palate', 'club-footed', 'clubfoot', 'crookback'],
    'spleen': ['abdomen', 'acerbity', 'acid', 'acidity', 'acidulousness', 'acrimony', 'anger', 'angst', 'anguish', 'animosity', 'anus', 'anxiety'],
    'spleeny': ['bearish', 'bitchy', 'cankered', 'cantankerous', 'churlish', 'crabbed', 'cranky', 'cross', 'cross-grained', 'crusty', 'cussed', 'disagreeable'],
    'splendid': ['babylonian', 'corinthian', 'admirable', 'advantageous', 'auspicious', 'awe-inspiring', 'awesome', 'awful', 'barbaric', 'baroque', 'beaming', 'bedazzling'],
    'splendidly': ['abundantly', 'acutely', 'amazingly', 'amply', 'aright', 'astonishingly', 'awesomely', 'brightly', 'brilliantly', 'capitally', 'conspicuously', 'copiously'],
    'splendiferous': ['babylonian', 'corinthian', 'awe-inspiring', 'awful', 'barbaric', 'dazzling', 'deluxe', 'divine', 'elaborate', 'elegant', 'exquisite', 'extravagant'],
    'splendor': ['babylonian splendor', 'aura', 'beauty', 'blare', 'blaze', 'blaze of glory', 'blazing light', 'blinding light', 'bright light', 'brightness', 'brilliance', 'brilliancy'],
    'splendorous': ['beaming', 'bedazzling', 'blinding', 'blooming', 'bright', 'bright and shining', 'brilliant', 'charismatic', 'dazzling', 'devastating', 'divine', 'effulgent'],
    'splenetic': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrimonious', 'adrenal', 'bearish', 'bitchy', 'bitter'],
    'splice': ['accouple', 'accumulate', 'adhesive', 'affixation', 'agglomeration', 'agglutinate', 'agglutination', 'aggregation', 'amass', 'annexation', 'arrange a match', 'articulate'],
    'spliced': ['affiliate', 'affiliated', 'allied', 'assembled', 'associate', 'associated', 'banded together', 'bound', 'bracketed', 'collateral', 'collected', 'conjoined'],
    'splint': ['ace bandage', 'band-aid', 'adhesive tape', 'application', 'band', 'bandage', 'bandaging', 'bathe', 'binder', 'brace', 'care for', 'cast'],
    'splinter': ['atomize', 'bit', 'black sheep', 'blemish', 'breach', 'break', 'break into pieces', 'break to pieces', 'break up', 'breakage', 'breakaway group', 'burst'],
    'splinter group': ['breakaway group', 'camp', 'caucus', 'division', 'ethnic group', 'faction', 'interest', 'interest group', 'minority group', 'offshoot', 'party', 'political party'],
    'split': ['ablate', 'abrupt', 'absquatulate', 'abysm', 'abyss', 'aggravated', 'agree to disagree', 'alienate', 'alienation', 'allot', 'amputate', 'aperture'],
    'split hairs': ['analyze', 'anatomize', 'around the bush', 'atomize', 'beat about', 'beg the question', 'bicker', 'boggle', 'cavil', 'change', 'chop logic', 'choplogic'],
    'split level': ['dymaxion house', 'white house', 'adobe house', 'building', 'casa', 'cliff dwelling', 'consulate', 'country house', 'country seat', 'dacha', 'deanery', 'dwelling house'],
    'split personality': ['alcoholic', 'alternating personality', 'antisocial personality', 'catatonia', 'catatonic schizophrenia', 'dementia praecox', 'depersonalization', 'disconnection', 'disordered personality', 'dissociation', 'dissociation of personality', 'disturbed personality'],
    'split second': ['breath', 'breathing', 'coup', 'crack', 'flash', 'half a jiffy', 'half a mo', 'half a second', 'half a shake', 'instant', 'jiff', 'jiffy'],
    'split the difference': ['accommodate', 'adjust', 'apportion', 'average', 'average out', 'avoid extremes', 'be partners in', 'compose', 'compound', 'compromise', 'cooperate', 'cop out'],
    'split up': ['apportion', 'break up', 'breakup', 'carve', 'carve up', 'cut', 'cut up', 'deactivate', 'deactivation', 'debrief', 'demob', 'demobilization'],
    'splitting': ['abscission', 'acute', 'amputation', 'apportionment', 'budgeting', 'butchering', 'catalysis', 'catalyst', 'chopping', 'cleavage', 'cutting', 'cutting the pie'],
    'splotch': ['band', 'bar', 'bedabble', 'bespangle', 'bespatter', 'bespeckle', 'bespot', 'birthmark', 'blaze', 'blaze a trail', 'blemish', 'bloodstain'],
    'splotchy': ['bespangled', 'bespeckled', 'blotched', 'blotchy', 'dotted', 'dotty', 'flea-bitten', 'flecked', 'fleckered', 'frecked', 'freckle-faced', 'freckled'],
    'splurge': ['access', 'binge', 'blazon', 'bravura', 'brilliancy', 'budget', 'burst', 'cost', 'cost out', 'cut a dash', 'cut a figure', 'cut a swath'],
    'splutter': ['assibilate', 'assibilation', 'barrage', 'beat', 'beat a ruffle', 'beat a tattoo', 'beating', 'bicker', 'blubber', 'bluff', 'bluster', 'bluster and bluff'],
    'spoil': ['accommodate', 'acquisition', 'baby', 'baffle', 'balk', 'be after', 'be all thumbs', 'be desirous of', 'be spoiling for', 'blackmail', 'blast', 'blemish'],
    'spoil for': ['ache for', 'be dying for', 'be hurting for', 'clamor for', 'cry for', 'gape for', 'hone for', 'hope for', 'itch for', 'languish for', 'long for', 'lust for'],
    'spoilage': ['biodegradability', 'biodegradation', 'breakup', 'caries', 'carrion', 'corrosion', 'corruption', 'decay', 'decomposition', 'degradability', 'degradation', 'dilapidation'],
    'spoiled': ['ausgespielt', 'bad', 'bankrupt', 'barfy', 'beautiless', 'blasted', 'blemished', 'blighted', 'blotted', 'botched', 'brackish', 'broken'],
    'spoils of office': ['blackmail', 'boodle', 'booty', 'campaign contribution', 'campaign fund', 'graft', 'haul', 'hot goods', 'loot', 'nepotism', 'perks', 'perquisite'],
    'spoke': ['approach', 'arrest', 'asymptote', 'bearing rein', 'bit', 'bottleneck', 'brake', 'chain', 'check', 'checkrein', 'chock', 'clog'],
    'spoken': ['articulate', 'articulated', 'colloquial', 'common', 'conversational', 'enunciated', 'everyday', 'familiar', 'informal', 'lingual', 'linguistic', 'nonstandard'],
    'spokesman': ['adviser', 'agent', 'announcer', 'annunciator', 'authority', 'champion', 'channel', 'communicant', 'communicator', 'connection', 'debater', 'declaimer'],
    'spoliate': ['depredate', 'desecrate', 'desolate', 'despoil', 'devastate', 'devour', 'fleece', 'forage', 'foray', 'freeboot', 'gut', 'loot'],
    'spoliation': ['banditry', 'bereavement', 'bloodbath', 'blue ruin', 'breakup', 'brigandage', 'brigandism', 'carnage', 'consumption', 'cost', 'damage', 'damnation'],
    'sponge': ['ace bandage', 'band-aid', 'finnish bath', 'india rubber', 'japanese bath', 'loch ness monster', 'russian bath', 'swedish bath', 'turkish bath', 'ablution', 'absorb', 'absorbency'],
    'sponger': ['barnacle', 'beat', 'beggar', 'bloodsucker', 'bummer', 'cadger', 'coupon clippers', 'deadbeat', 'drone', 'freeloader', 'hanger-on', 'idle rich'],
    'sponging': ['abject', 'ablution', 'absorbency', 'absorbent', 'absorption', 'adsorbent', 'adsorption', 'apple-polishing', 'ass-kissing', 'assimilation', 'backscratching', 'beggarly'],
    'spongy': ['absorbent', 'adsorbent', 'assimilative', 'baccate', 'bibulous', 'blotting', 'chemisorptive', 'chemosorptive', 'cribriform', 'digestive', 'doughy', 'edematous'],
    'sponsor': ['maecenas', 'abettor', 'accept the responsibility', 'admirer', 'advocate', 'aficionado', 'angel', 'answer for', 'apologist', 'assure', 'attest', 'back'],
    'sponsorship': ['abetment', 'advocacy', 'aegis', 'auspices', 'backing', 'capitalization', 'care', 'championship', 'charity', 'countenance', 'deficit financing', 'encouragement'],
    'spontaneity': ['abandon', 'autonomousness', 'autonomy', 'ease', 'extemporaneousness', 'free will', 'gratuitousness', 'indeliberation', 'independence', 'involuntariness', 'naturalness', 'offhandedness'],
    'spontaneous': ['ad lib', 'arbitrary', 'automated', 'automatic', 'automatous', 'autonomous', 'bat', 'baton', 'billy', 'billy club', 'bludgeon', 'casual'],
    'spoof': ['bamboozle', 'befool', 'cheat', 'chicane', 'deceit', 'deception', 'fake', 'fake out', 'fakement', 'flam', 'flimflam', 'fool'],
    'spoofing': ['bamboozlement', 'befooling', 'bluffing', 'calculated deception', 'circumvention', 'conning', 'deceiving', 'deception', 'deceptiveness', 'defrauding', 'delusion', 'delusiveness'],
    'spook': ['masan', 'affright', 'agent', 'agitate', 'alarm', 'apparition', 'appearance', 'astral', 'astral spirit', 'awe', 'banshee', 'bogey'],
    'spooky': ['creepy', 'eerie', 'eldritch', 'fidgety', 'ghost-haunted', 'ghost-ridden', 'goosey', 'haunted', 'high-strung', 'jittery', 'jumpy', 'macabre'],
    'spoon': ['administer', 'bail', 'bill and coo', 'blockhead', 'bucket', 'cluck', 'copulate', 'cup', 'cutlery', 'dally', 'deal', 'deal out'],
    'spoon feed': ['care for', 'cherish', 'coddle', 'cosset', 'cradle', 'cultivate', 'dry-nurse', 'feed', 'fondle', 'foster', 'lavish care on', 'mother'],
    'spoonerism': ['irish bull', 'abuse of terms', 'acronym', 'acrostic', 'amphibologism', 'amphiboly', 'anacoluthon', 'anagram', 'avyayibhava', 'back formation', 'bull', 'calembour'],
    'spoonlike': ['boat-shaped', 'boatlike', 'bowl-shaped', 'bowllike', 'cavelike', 'cavernous', 'concave', 'concaved', 'craterlike', 'cup-shaped', 'cupped', 'cymbiform'],
    'spoor': ['aroma', 'breath', 'broad hint', 'catchword', 'clue', 'condensation trail', 'contrail', 'course', 'cue', 'cue word', 'definite odor', 'detectable odor'],
    'sporadic': ['aimless', 'amorphous', 'broadcast', 'broken', 'capricious', 'careening', 'casual', 'catching', 'catchy', 'chance', 'changeable', 'changing'],
    'sporadically': ['at haphazard', 'at intervals', 'at irregular intervals', 'at large', 'at random', 'brokenly', 'by catches', 'by chance', 'by fits', 'by jerks', 'by snatches', 'capriciously'],
    'spore': ['adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'bacillus', 'bacteria', 'bacterium', 'basidium', 'bug', 'coccus'],
    'sport': ['beau brummel', 'monopoly', 'ping-pong', 'rugby', 'scrabble', 'acrobatics', 'action', 'adventurer', 'advertise', 'affect', 'agate', 'agonistics'],
    'sporting': ['acrobatic', 'agonistic', 'athletic', 'betting', 'cardsharping', 'casting lots', 'chase', 'chevy', 'chivy', 'coursing', 'cynegetics', 'fair-minded'],
    'sporting chance': ['best bet', 'blind bargain', 'chance at odds', 'favorable prospect', 'gambling chance', 'good chance', 'good opportunity', 'good possibility', 'likelihood', 'main chance', 'matter of chance', 'odds-on'],
    'sportive': ['animated', 'antic', 'arch', 'blithe', 'buoyant', 'capering', 'capersome', 'cavorting', 'coltish', 'devilish', 'elfish', 'elvish'],
    'sportscast': ['beam', 'broadcast', 'canned show', 'commercial', 'commercial program', 'electrical transcription', 'network show', 'newscast', 'radiate', 'radio', 'radio fare', 'radiobroadcast'],
    'sportsman': ['nimrod', 'adventurer', 'amateur athlete', 'archer', 'athlete', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'beater', 'betting ring'],
    'sportsmanship': ['candor', 'cricket', 'fair play', 'fair shake', 'fair-mindedness', 'fairness', 'good sportsmanship', 'honesty', 'honor', 'honorableness', 'integrity', 'justice'],
    'sportswear': ['apparel', 'array', 'attire', 'bedizenment', 'clothes', 'clothing', 'costume', 'drapery', 'dress', 'dressing', 'dry goods', 'duds'],
    'sporty': ['brave', 'bravura', 'braw', 'casual', 'chic', 'chichi', 'classy', 'daring', 'dashing', 'devil-may-care', 'dressy', 'en deshabille'],
    'spot': ['crt spot', 'dm display', 'doppler signal', 'if signal', 'im display', 'rf echoes', 'abode', 'ace', 'acne', 'aimless', 'allocate', 'appointment'],
    'spotless': ['christian', 'absolute', 'beyond all praise', 'blameless', 'bleached', 'blotless', 'bright', 'chaste', 'clean', 'cleanly', 'creditable', 'dainty'],
    'spotlight': ['pr', 'accent', 'accentuate', 'affect', 'arc', 'arc light', 'ballyhoo', 'beacon', 'belabor', 'betoken', 'blurb', 'brandish'],
    'spotted': ['assigned', 'bedraggled', 'befouled', 'besmirched', 'bespangled', 'bespeckled', 'blotched', 'blotchy', 'defiled', 'deployed', 'dirtied', 'dotted'],
    'spotted fever': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'spotter': ['argus', 'cia man', 'charley', 'airplane spotter', 'beagle', 'cloak-and-dagger operative', 'counterintelligence agent', 'counterspy', 'dick', 'double agent', 'espionage agent', 'eye'],
    'spotty': ['bad', 'bespangled', 'bespeckled', 'blotched', 'blotchy', 'brindled', 'broken', 'broken off', 'capricious', 'careening', 'catchy', 'cheeseparing'],
    'spout': ['anabasis', 'ascension', 'ascent', 'avenue', 'babble', 'beak', 'belch', 'blab', 'blabber', 'blather', 'blether', 'blow open'],
    'sprain': ['abrade', 'bark', 'blemish', 'bloody', 'break', 'burn', 'chafe', 'check', 'chip', 'claw', 'crack', 'craze'],
    'sprawl': ['accubation', 'accumbency', 'be lengthy', 'be prolonged', 'bed', 'bed down', 'belong', 'branch', 'branch out', 'capsize', 'careen', 'come a cropper'],
    'sprawling': ['accumbent', 'couchant', 'couche', 'crawling', 'decumbent', 'deltoid', 'draped', 'fan-shape', 'fan-shaped', 'fanlike', 'fanned', 'fanning'],
    'spray': ['aerate', 'aerify', 'aerosol', 'antiaircraft barrage', 'appendage', 'arm', 'asperge', 'aspergil', 'aspergillum', 'atomize', 'atomizer', 'barrage'],
    'spread': ['aberrate', 'aberration', 'accelerated', 'access', 'accessible', 'accession', 'accretion', 'accrual', 'accrue', 'accruement', 'accumbent', 'accumulate'],
    'spread eagle': ['hershey bar', 'achievement', 'alerion', 'animal charge', 'annulet', 'argent', 'armorial bearings', 'armory', 'arms', 'aviation badge', 'azure', 'badge'],
    'spread over': ['apply to', 'bespread', 'blanket', 'block', 'canopy', 'cloak', 'clothe', 'cloud', 'cope', 'cover', 'cover up', 'cowl'],
    'spree': ['bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'bender', 'binge', 'bout', 'bust', 'carousal', 'carouse', 'celebrate', 'celebration'],
    'sprig': ['adolescent', 'appendage', 'arm', 'baby', 'bine', 'bough', 'branch', 'branchedness', 'branchiness', 'burgeon', 'deadwood', 'flagellum'],
    'sprightly': ['attic', 'active', 'activist', 'activistic', 'agile', 'alert', 'alive', 'animate', 'animated', 'antic', 'biting', 'bouncing'],
    'spring': ['eastertide', 'highland fling', 'lastex', 'maytime', 'accrue from', 'adaptability', 'adolescence', 'aestival', 'air mattress', 'airiness', 'ambition', 'anabasis'],
    'spring fever': ['dilatoriness', 'do-nothingness', 'ergophobia', 'faineancy', 'faineantise', 'hoboism', 'indolence', 'inertia', 'inexertion', 'laggardness', 'laziness', 'lotus-eating'],
    'spring up': ['appear', 'approach', 'arise', 'be born', 'become', 'blossom', 'bob up', 'break forth', 'break out', 'break water', 'brew', 'burgeon'],
    'spring upon': ['ambush', 'astonish', 'bushwhack', 'catch at', 'catch off-guard', 'catch unawares', 'come from behind', 'come upon unexpectedly', 'do the unexpected', 'drop in on', 'fasten upon', 'jump'],
    'springboard': ['lastex', 'baleen', 'battledore', 'chewing gum', 'elastic', 'elastomer', 'gum', 'gum elastic', 'handball', 'jumping jack', 'racket', 'rubber'],
    'springbok': ['cape elk', 'virginia deer', 'antelope', 'buck', 'camel', 'camelopard', 'caribou', 'deer', 'deerlet', 'doe', 'dromedary', 'eland'],
    'springe': ['bait', 'birdlime', 'bola', 'booby trap', 'cobweb', 'deadfall', 'dragnet', 'fishhook', 'fly', 'gill net', 'ground bait', 'hook'],
    'springlike': ['aestival', 'arctic', 'autumn', 'autumnal', 'beryl-green', 'berylline', 'blue-green', 'bluish-green', 'boreal', 'brumal', 'canicular', 'chartreuse'],
    'springy': ['adaptable', 'adaptive', 'bendable', 'bending', 'bouncy', 'buoyant', 'compliant', 'ductile', 'elastic', 'extensible', 'extensile', 'fabricable'],
    'sprinkle': ['scotch mist', 'asperge', 'asperse', 'band', 'baptize', 'bar', 'bedew', 'bespangle', 'bespatter', 'bespeckle', 'bespot', 'besprinkle'],
    'sprinkled': ['bespangled', 'blotched', 'blotchy', 'cheeseparing', 'chinchy', 'chintzy', 'dotted', 'dotty', 'dusted', 'exiguous', 'flea-bitten', 'flecked'],
    'sprinkler': ['agnus dei', 'foamite', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'acid', 'aerosol', 'ark', 'asperger', 'asperges'],
    'sprinkling': ['a few', 'affusion', 'aspergation', 'aspersion', 'attenuation', 'baptism', 'baptismal gown', 'baptismal regeneration', 'baptistery', 'baptizement', 'bath', 'bathing'],
    'sprint': ['le mans', 'air race', 'automobile race', 'bicycle race', 'boat race', 'bound', 'burst', 'burst of speed', 'canter', 'contest of speed', 'cross-country race', 'dash'],
    'sprite': ['ariel', 'befind', 'corrigan', 'dingbelle', 'fifinella', 'finnbeara', 'hob', 'hobgoblin', 'mab', 'masan', 'oberon', 'puck'],
    'spritz': ['flush', 'font', 'fount', 'fountain', 'geyser', 'gush', 'jet', 'play', 'rush', 'spew', 'spit', 'spout'],
    'sprocket': ['cog', 'comb', 'crag', 'fang', 'harrow', 'jag', 'peak', 'pecten', 'projection', 'rake', 'ratchet', 'sawtooth'],
    'sprout': ['accrue from', 'adventurer', 'arise', 'arise from', 'be contingent on', 'be due to', 'begin', 'bine', 'bloom', 'blossom', 'bough', 'bourgeois gentilhomme'],
    'spruce': ['anal', 'bandbox', 'bowdlerized', 'braw', 'chic', 'classy', 'clean up', 'cleaned', 'cleaned up', 'cleansed', 'clothes-conscious', 'cosmopolitan'],
    'spruce up': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'blazon', 'brighten up', 'brush up', 'clean up', 'clear the decks', 'clear up', 'color'],
    'sprung': ['aggravated', 'anamorphous', 'askew', 'asymmetric', 'bent', 'bowed', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped'],
    'spry': ['active', 'activist', 'activistic', 'agile', 'alacritous', 'alive', 'animated', 'bouncing', 'bouncy', 'breezy', 'brisk', 'bubbly'],
    'spud': ['irish potato', 'kraut', 'aubergine', 'beans', 'cabbage', 'eggplant', 'greens', 'legumes', 'love apple', 'mad apple', 'pieplant', 'potato'],
    'spume': ['aerate', 'air', 'beat', 'breakers', 'bubble', 'chaff', 'chip', 'cobweb', 'collar', 'cork', 'cream', 'down'],
    'spunk': ['german tinder', 'adventuresomeness', 'adventurousness', 'aggression', 'aggressiveness', 'amadou', 'ambitiousness', 'backbone', 'bang', 'bottle', 'bottom', 'chutzpah'],
    'spunkless': ['laodicean', 'olympian', 'aloof', 'apathetic', 'benumbed', 'blah', 'blase', 'chicken', 'comatose', 'coward', 'craven', 'desensitized'],
    'spunky': ['beany', 'bold', 'bulldoggish', 'combustible', 'courageous', 'dauntless', 'doughty', 'explosive', 'fearless', 'fiery', 'game', 'gamy'],
    'spur': ['accelerate', 'activation', 'actuation', 'aculeate', 'acuminate', 'animate', 'appendage', 'arm', 'arouse', 'awaken', 'barb', 'barbel'],
    'spurious': ['affected', 'apocryphal', 'artificial', 'assumed', 'baseborn', 'bastard', 'bogus', 'brummagem', 'colorable', 'colored', 'contrived', 'counterfeit'],
    'spurn': ['abjure', 'ban', 'banish', 'beat back', 'blackball', 'brush aside', 'brush off', 'cast out', 'chase', 'chase away', 'chase off', 'chuck'],
    'spurned': ['contemned', 'declined', 'declined with thanks', 'denied', 'despised', 'disapproved', 'discarded', 'discounted', 'disdained', 'dismissed', 'disowned', 'excepted'],
    'spurt': ['a breath', 'acceleration', 'access', 'ado', 'advance', 'agitation', 'anabasis', 'ascension', 'ascent', 'belch', 'bit', 'blow out'],
    'spurtle': ['condensation', 'condense', 'distill', 'distillation', 'douse', 'dribble', 'drip', 'dripping', 'dripple', 'drop', 'filter', 'flush'],
    'sputter': ['assibilate', 'assibilation', 'barrage', 'beat', 'beat a ruffle', 'beat a tattoo', 'beating', 'bicker', 'blubber', 'bluff', 'bluster', 'bluster and bluff'],
    'sputtering': ['beating', 'clicking', 'dancing', 'desultory', 'drumming', 'flickering', 'flickery', 'flicky', 'fluttering', 'fluttery', 'guttering', 'palpitant'],
    'spy': ['cia man', 'agent', 'be vigilant', 'be watchful', 'beagle', 'behold', 'betrayer', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'bug'],
    'spying': ['bugging', 'cloak-and-dagger work', 'counterespionage', 'counterintelligence', 'detection', 'electronic surveillance', 'espial', 'espionage', 'following', 'intelligence', 'intelligence work', 'looking'],
    'squab': ['cornish hen', 'avifauna', 'baby bird', 'bear', 'bird', 'bird of jove', 'bird of juno', 'bird of minerva', 'bird of night', 'bird of passage', 'bird of prey', 'birdie'],
    'squabble': ['altercate', 'altercation', 'argufy', 'argument', 'beef', 'bicker', 'bicker over', 'bickering', 'blood feud', 'brawl', 'broil', 'caterwaul'],
    'squad': ['kp', 'age group', 'army', 'army group', 'band', 'battalion', 'battery', 'battle group', 'bevy', 'body', 'brigade', 'bunch'],
    'squadron': ['kp', 'naval construction battalion', 'rn', 'royal navy', 'seabees', 'usn', 'united states navy', 'air arm', 'air corps', 'air force', 'air service', 'argosy'],
    'squalid': ['abject', 'abominable', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beat-up', 'bedraggled', 'beggarly', 'beneath contempt', 'black'],
    'squall': ['altercation', 'bark', 'battle cry', 'bawl', 'bay', 'beef', 'bell', 'bellow', 'bickering', 'black squall', 'blare', 'blast'],
    'squally': ['aeolian', 'airish', 'airy', 'blasty', 'blowy', 'blustering', 'blusterous', 'blustery', 'boreal', 'breezy', 'brisk', 'castellatus'],
    'squalor': ['abjectness', 'abominableness', 'atrociousness', 'awfulness', 'baseness', 'beastliness', 'beggarliness', 'bestiality', 'blowziness', 'brutality', 'carelessness', 'chintziness'],
    'squander': ['ablate', 'absorb', 'assimilate', 'bleed white', 'blow', 'budget', 'burn up', 'consume', 'cost', 'cost out', 'decrease', 'deplete'],
    'squandered': ['ablated', 'by the board', 'consumed', 'depleted', 'dissipated', 'down the drain', 'eroded', 'expended', 'forfeit', 'forfeited', 'gone', 'gone to waste'],
    'square': ['babbitt', 'little joe', 'methuselah', 'middle american', 'philistine', 't square', 'aboveboard', 'absolutely', 'accommodate', 'accord', 'accordant', 'account with'],
    'square dance': ['little joe', 'bal', 'bal costume', 'bal masque', 'ball', 'barn dance', 'biquadrate', 'country dance', 'dance', 'fancy-dress ball', 'four', 'four-part diaphony'],
    'square dealing': ['aboveboard', 'authentic', 'bona fide', 'fair and square', 'fair-minded', 'foursquare', 'genuine', 'good-faith', 'on the level', 'on the square', 'on the up-and-up', 'open'],
    'squarely': ['absolutely', 'accurately', 'bang', 'dead', 'definitely', 'directly', 'equally', 'even', 'exactly', 'expressly', 'faithfully', 'fifty-fifty'],
    'squaring': ['little joe', 'accommodation', 'adaptation', 'adjustment', 'amends', 'assimilation', 'atonement', 'attunement', 'biquadrate', 'coaptation', 'compensation', 'composition'],
    'squash': ['abrade', 'annihilate', 'answer', 'answer conclusively', 'argue down', 'asphyxiate', 'assibilate', 'assibilation', 'atomize', 'bear', 'beat', 'black out'],
    'squashed': ['crushed', 'even', 'flat', 'flattened', 'flush', 'homaloidal', 'horizontal', 'level', 'plain', 'plane', 'quashed', 'quelled'],
    'squashy': ['baccate', 'dirty', 'doughy', 'flabby', 'fleshy', 'macerated', 'masticated', 'miry', 'mucky', 'muddy', 'mushy', 'oozy'],
    'squat': ['lilliputian', 'tom thumb', 'abide', 'adipose', 'anchor', 'be enfeoffed of', 'be possessed of', 'be seated', 'be seized of', 'beefy', 'bend', 'berth'],
    'squatter': ['arriviste', 'colonial', 'colonist', 'colonizer', 'emigrant', 'gate-crasher', 'greenhorn', 'hirer', 'homesteader', 'immigrant', 'incumbent', 'intruder'],
    'squatting': ['abiding', 'abode', 'adverse possession', 'alodium', 'burgage', 'claim', 'cohabitation', 'colony', 'commorancy', 'de facto', 'de jure', 'dependency'],
    'squaw': ['eve', 'frau', 'better half', 'common-law wife', 'concubine', 'dame', 'daughter of eve', 'distaff', 'domina', 'donna', 'dowager', 'feme'],
    'squawk': ['air a grievance', 'bark', 'bawl', 'beef', 'beefing', 'bellow', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'blare', 'blat'],
    'squawk box': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'squawky': ['brassy', 'brazen', 'choked', 'coarse', 'cracked', 'croaking', 'croaky', 'dry', 'grating', 'gruff', 'guttural', 'harsh'],
    'squeak': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'bray', 'break', 'call'],
    'squeak by': ['brush', 'brush by', 'caress', 'come in contact', 'contact', 'glance', 'graze', 'hit', 'impinge', 'kiss', 'nudge', 'osculate'],
    'squeaky': ['acute', 'argute', 'creaky', 'ear-piercing', 'howling', 'keen', 'keening', 'penetrating', 'piercing', 'piping', 'reedy', 'screaky'],
    'squeal': ['babble', 'bark', 'battle cry', 'bawl', 'bay', 'be indiscreet', 'be unguarded', 'bear witness against', 'beep', 'bell', 'bellow', 'betray'],
    'squealer': ['betrayer', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'canary', 'delator', 'fink', 'informer', 'narc', 'nark', 'peacher'],
    'squeamish': ['airsick', 'barfy', 'bashful', 'boggling', 'carsick', 'critical', 'dainty', 'delicate', 'demanding', 'demurring', 'difficult', 'diffident'],
    'squeeze': ['arrest', 'arrestation', 'arrestment', 'badger', 'bar', 'barricade', 'bear', 'bear against', 'bear down on', 'bear down upon', 'bear hard upon', 'bear hug'],
    'squeeze in': ['admit', 'barge in', 'be admitted', 'break in', 'break in upon', 'breeze in', 'burst in', 'bust in', 'butt in', 'charge in', 'come barging in', 'come between'],
    'squeezed': ['badly off', 'clamped', 'compressed', 'concentrated', 'condensed', 'consolidated', 'constricted', 'contracted', 'cramped', 'distressed', 'down to bedrock', 'embarrassed'],
    'squeezing': ['abuse of terms', 'catachresis', 'clamping', 'clamping down', 'compression', 'concentration', 'contorting', 'crush', 'decoction', 'distillation', 'distortion', 'eisegesis'],
    'squelch': ['answer', 'answer conclusively', 'argue down', 'asphyxiate', 'assibilate', 'assibilation', 'barb', 'black out', 'bottle up', 'buzz', 'censor', 'choke'],
    'squelchy': ['baccate', 'dirty', 'doughy', 'flabby', 'fleshy', 'macerated', 'masticated', 'miry', 'mucky', 'muddy', 'mushy', 'oozy'],
    'squib': ['atticism', 'agile wit', 'black humor', 'blasting cap', 'burlesque', 'cap', 'caricature', 'comedy', 'detonating powder', 'detonator', 'dry wit', 'electric detonator'],
    'squint': ['aberration', 'cast', 'circuitousness', 'cock the eye', 'convergent strabismus', 'cross-eye', 'cross-eyedness', 'crosswiseness', 'declination', 'deflection', 'deflexure', 'deviance'],
    'squinting': ['agee', 'agee-jawed', 'askance', 'askant', 'askew', 'askewgee', 'asquint', 'astigmatic', 'awry', 'blink-eyed', 'blinking', 'blinky'],
    'squire': ['brahman', 'casanova', 'don juan', 'ganymede', 'hebe', 'lothario', 'romeo', 'accompany', 'address', 'airline hostess', 'airline stewardess', 'amoroso'],
    'squirm': ['agonize', 'burn to', 'chafe', 'fidget', 'flip out', 'flounder', 'flutter', 'freak out on', 'fret', 'fuss', 'get excited', 'get high on'],
    'squirm out of': ['alibi', 'alibi out of', 'apologize for', 'cover with excuses', 'creep out of', 'excuse', 'find a loophole', 'lie out of', 'make apology for', 'offer excuse for', 'plead ignorance', 'shuffle out of'],
    'squirmy': ['antsy', 'antsy-pantsy', 'anxious', 'breathless', 'chafing', 'eager', 'edgy', 'excited', 'fretful', 'fretting', 'hasty', 'hopped-up'],
    'squirrel away': ['accumulate', 'amass', 'arrange for', 'backlog', 'collect', 'cumulate', 'forearm', 'garner', 'garner up', 'gather into barns', 'heap up', 'hide'],
    'squirrel cage': ['beat', 'beaten path', 'broken record', 'bureaucracy', 'bureaucratism', 'chinoiserie', 'daily grind', 'grind', 'groove', 'humdrum', 'invariability', 'irk'],
    'squirt': ['a nobody', 'a nothing', 'blow out', 'blowout', 'cast forth', 'cipher', 'common man', 'debouch', 'decant', 'discharge', 'disembogue', 'disgorge'],
    'squish': ['assibilate', 'assibilation', 'atomize', 'bear', 'break into pieces', 'break to pieces', 'break up', 'buzz', 'crash', 'crowd', 'crunch', 'crush'],
    'squishy': ['baccate', 'dirty', 'doughy', 'flabby', 'fleshy', 'macerated', 'masticated', 'miry', 'mucky', 'muddy', 'mushy', 'oozy'],
    'sro': ['brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full', 'chuck-full', 'congested', 'cram-full', 'crammed', 'farci', 'filled'],
    'stab': ['judas kiss', 'abrade', 'abrasion', 'ache', 'acute pain', 'afflict', 'aggrieve', 'agonize', 'ail', 'anguish', 'approach', 'assay'],
    'stabbing': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'acute', 'afflictive', 'agonizing'],
    'stabile': ['art object', 'brainchild', 'bric-a-brac', 'bronze', 'cast', 'classic', 'composition', 'constant', 'creation', 'design', 'equable', 'even'],
    'stability': ['abidingness', 'abnegation', 'abstinence', 'accordance', 'age', 'antiquity', 'application', 'assiduity', 'assiduousness', 'authenticity', 'authoritativeness', 'body'],
    'stabilize': ['appease', 'assimilate to', 'balance', 'ballast', 'calm', 'calm down', 'compose', 'cool', 'counterbalance', 'counterpoise', 'cradle', 'damp'],
    'stabilizer': ['alleviative', 'alleviator', 'anodyne', 'assuager', 'balance', 'balance rudder', 'balance wheel', 'ballast', 'balm', 'calmative', 'counterbalance', 'counterweight'],
    'stable': ['augean stables', 'abiding', 'accordant', 'accountable', 'adamantine', 'age group', 'age-long', 'aged', 'alike', 'ancient', 'antique', 'articulated'],
    'stableman': ['breaker', 'breeder', 'broncobuster', 'buckaroo', 'cattleman', 'cow keeper', 'cowman', 'dairy farmer', 'dairyman', 'equerry', 'farrier', 'grazier'],
    'staccato': ['a cappella', 'abbandono', 'accidental', 'accrescendo', 'adagietto', 'adagio', 'affettuoso', 'agilmente', 'agitato', 'allegretto', 'allegro', 'amabile'],
    'stack': ['abundance', 'accumulate', 'accumulation', 'add up', 'adulterate', 'agglomerate', 'agglomeration', 'aggregate', 'aggregation', 'agree', 'amass', 'amassment'],
    'stack the cards': ['beat', 'beguile of', 'bilk', 'bunco', 'burn', 'cheat', 'chisel', 'chouse', 'chouse out of', 'cog', 'cog the dice', 'con'],
    'stack up': ['admit of comparison', 'amount to', 'ape', 'appear like', 'approach', 'approximate', 'arrival', 'balance', 'bank', 'bank up', 'be commensurable', 'be comparable'],
    'stacked': ['junoesque', 'accumulated', 'agglomerate', 'aggregate', 'agreeable', 'amassed', 'amply endowed', 'assembled', 'becoming', 'bonny', 'braw', 'built'],
    'stadium': ['agora', 'amphitheater', 'arena', 'assembly hall', 'athletic field', 'auditorium', 'background', 'bear garden', 'bowl', 'boxing ring', 'bull ring', 'campus'],
    'staff': ['british cabinet', 'malacca cane', 'sanhedrin', 'us cabinet', 'accouter', 'advisory body', 'advocate', 'alpenstock', 'appoint', 'arm', 'armory', 'assembly'],
    'staff of life': ['french bread', 'irish soda bread', 'italian bread', 'black bread', 'bread', 'bread stick', 'bread stuff', 'brown bread', 'cracked-wheat bread', 'crust', 'dark bread', 'garlic bread'],
    'stag': ['cape elk', 'kaffeeklatsch', 'virginia deer', 'adventurer', 'antelope', 'ball', 'big operator', 'billy', 'billy goat', 'blowout', 'boar', 'broad jumper'],
    'stag film': ['rabelaisianism', 'x-rated movie', 'bawdiness', 'bawdry', 'blue movie', 'dirt', 'dirtiness', 'dirty movie', 'erotic art', 'erotic literature', 'erotographomania', 'fescenninity'],
    'stage': ['broadway', 'acting', 'acting area', 'agora', 'amphitheater', 'apron', 'apron stage', 'arena', 'athletic field', 'auditorium', 'autobus', 'back'],
    'stage fright': ['afraidness', 'agitation', 'apprehensiveness', 'attack of nerves', 'bashfulness', 'buck fever', 'case of nerves', 'confusion', 'coyness', 'demureness', 'demurity', 'diffidence'],
    'stage manager': ['mc', 'auteur', 'ballyhoo man', 'barker', 'callboy', 'costume designer', 'costumer', 'costumier', 'director', 'emcee', 'equestrian director', 'exhibitor'],
    'stage presence': ['acting', 'buffoonery', 'business', 'characterization', 'gag', 'ham', 'hammy acting', 'hoke', 'hokum', 'impersonation', 'mimesis', 'mimicking'],
    'stage show': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger', 'closet drama'],
    'stage whisper': ['aspiration', 'bated breath', 'breath', 'breathy voice', 'exhalation', 'little voice', 'low voice', 'mumble', 'mumbling', 'murmur', 'murmuration', 'murmuring'],
    'stagestruck': ['actor-proof', 'all-star', 'ballet', 'balletic', 'cinematic', 'cinematographic', 'dramatic', 'dramatical', 'dramaturgic', 'film', 'filmic', 'ham'],
    'stagger': ['affright', 'agitate', 'alarm', 'alternate', 'amaze', 'amble', 'amplitude', 'arrhythmia', 'astonish', 'astound', 'awe', 'awestrike'],
    'staggered': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled', 'bendy'],
    'staggering': ['amazing', 'ambling', 'ambulation', 'astonishing', 'astounding', 'backpacking', 'breathtaking', 'broken', 'capricious', 'careening', 'catchy', 'cautious'],
    'stagnant': ['abeyant', 'apathetic', 'benumbed', 'blase', 'bored', 'cataleptic', 'catatonic', 'contaminated', 'contemplative', 'dead', 'debilitated', 'dirty'],
    'stagnate': ['be a sideliner', 'be still', 'coast', 'constipate', 'decay', 'decline', 'decompose', 'degenerate', 'delay', 'deteriorate', 'do nothing', 'drift'],
    'stagy': ['actor-proof', 'affected', 'all-star', 'artificial', 'ballet', 'balletic', 'cinematic', 'cinematographic', 'dramatic', 'dramatical', 'dramaturgic', 'film'],
    'staid': ['arid', 'barren', 'calm', 'collected', 'composed', 'cool', 'decorous', 'demure', 'dignified', 'dry', 'dull', 'earnest'],
    'stain': ['apply paint', 'aspersion', 'attaint', 'badge of infamy', 'bar sinister', 'bastardize', 'baton', 'bedaub', 'bedizen', 'begild', 'bend sinister', 'besmear'],
    'stained': ['bedraggled', 'befouled', 'besmirched', 'blackened', 'colored', 'darkened', 'deep', 'deep-colored', 'defiled', 'dirtied', 'discolored', 'drabbled'],
    'staining': ['calcimining', 'coating', 'color printing', 'coloration', 'coloring', 'covering', 'dyeing', 'emblazonry', 'enameling', 'fresco', 'gilding', 'glazing'],
    'stainless': ['christian', 'absolute', 'beyond all praise', 'blameless', 'bleached', 'blotless', 'bright', 'chaste', 'clean', 'cleanly', 'creditable', 'dainty'],
    'stair': ['amount', 'caliber', 'compass', 'cut', 'degree', 'doorstep', 'extent', 'footrest', 'footstep', 'grade', 'height', 'interval'],
    'stairway': ['back stairs', 'companion', 'companionway', 'escalier', 'fire escape', 'flight of steps', 'incline', 'landing', 'landing stage', 'perron', 'ramp', 'spiral staircase'],
    'stake': ['derby', 'kentucky derby', 'kreis', 'preakness stakes', 'absolute interest', 'allotment', 'allowance', 'angel', 'ante', 'ante up', 'archbishopric', 'archdiocese'],
    'stake out': ['bound', 'bug', 'case', 'circle in', 'circumscribe', 'define', 'delimit', 'delimitate', 'demarcate', 'determine', 'enclose', 'fix'],
    'stakeout': ['bugging', 'cloak-and-dagger work', 'counterespionage', 'counterintelligence', 'electronic surveillance', 'espial', 'espionage', 'following', 'intelligence', 'intelligence work', 'military intelligence', 'observation'],
    'staker': ['angel', 'backer', 'entry', 'favorite', 'financer', 'funder', 'grubstaker', 'meal ticket', 'mudder', 'patron', 'plate horse', 'plater'],
    'stale': ['allurement', 'antiquated', 'back-number', 'bait', 'banal', 'bewhiskered', 'blown', 'boring', 'bromidic', 'cliche', 'cliched', 'come-on'],
    'stalemate': ['tweedledum and tweedledee', 'arrest', 'bell', 'blind alley', 'block', 'box', 'brake', 'bring to', 'bring up short', 'check', 'checkmate', 'corner'],
    'stalk': ['maypole', 'amble', 'anthrophore', 'axis', 'baluster', 'balustrade', 'banister', 'bar', 'barge', 'base', 'beat', 'bole'],
    'stalking': ['chase', 'chevy', 'chivy', 'clandestine behavior', 'clandestinity', 'coursing', 'covertness', 'cynegetics', 'dogging', 'domiciliary visit', 'dragnet', 'exploration'],
    'stalking horse': ['alibi', 'also-ran', 'ambuscade', 'ambush', 'ambushment', 'apology', 'aspirant', 'baby kisser', 'bidet', 'blind', 'booby trap', 'candidate'],
    'stall': ['fabian policy', 'micawberism', 'nissen hut', 'quonset hut', 'acrobatics', 'aerobatics', 'alcove', 'amen corner', 'anxious bench', 'anxious seat', 'area', 'arrest'],
    'stallion': ['houyhnhnm', 'billy', 'billy goat', 'boar', 'brood mare', 'bubbly-jock', 'buck', 'bull', 'bullock', 'chanticleer', 'charger', 'cock'],
    'stalwart': ['achilles', 'antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'conservative', 'cyclops', 'david', 'democrat', 'goliath', 'hector'],
    'stamen': ['androecium', 'anther', 'calyx', 'carpel', 'corolla', 'corolla tube', 'corona', 'epicalyx', 'gynoecium', 'megasporophyll', 'microsporophyll', 'perianth'],
    'stamina': ['application', 'assiduity', 'assiduousness', 'backbone', 'balls', 'bottom', 'bulldog tenacity', 'chutzpah', 'cohesiveness', 'concentration', 'constancy', 'courage'],
    'stammer': ['balbuties', 'be guilty', 'blush', 'change color', 'color', 'color up', 'crimson', 'dysphemia', 'falter', 'faltering', 'flush', 'gibber'],
    'stammering': ['balbutient', 'balbuties', 'bashful', 'bashfulness', 'battology', 'confused', 'confusion', 'conscious', 'coy', 'coyness', 'demure', 'demureness'],
    'stamp': ['john hancock', 'ok', 'platonic form', 'platonic idea', 'abolish', 'acceptance', 'aesthetic form', 'affirmance', 'affirmation', 'amble', 'animus', 'annihilate'],
    'stamp out': ['abscind', 'amputate', 'annihilate', 'ban', 'bar', 'blow out', 'bob', 'choke', 'clip', 'crop', 'cull', 'cut'],
    'stamped': ['accepted', 'acknowledged', 'admitted', 'affirmed', 'allowed', 'approved', 'authenticated', 'avowed', 'carved', 'certified', 'conceded', 'confessed'],
    'stampede': ['abject fear', 'accelerate', 'affright', 'alarm', 'awe', 'blue funk', 'boggle', 'bolt', 'bundle', 'bustle', 'charge', 'chase'],
    'stamping': ['smyth sewing', 'backing', 'bibliopegy', 'binder board', 'binding', 'book cloth', 'book cover', 'book jacket', 'bookbinding', 'bookcase', 'case', 'casemaking'],
    'stamping ground': ['ambit', 'bailiwick', 'baths', 'casino', 'club', 'clubhouse', 'constituency', 'footing', 'gambling house', 'gathering place', 'hangout', 'haunt'],
    'stance': ['affect', 'affectivity', 'affirmance', 'affirmation', 'air', 'allegation', 'announcement', 'annunciation', 'assertion', 'asseveration', 'assumption', 'attitude'],
    'stanch': ['arrest', 'asphyxiate', 'bar', 'bind', 'block', 'block up', 'blockade', 'bottle up', 'bung', 'caulk', 'cease', 'censor'],
    'stanchion': ['samson post', 'baluster', 'balustrade', 'banister', 'base', 'caryatid', 'colonnade', 'column', 'dado', 'die', 'doorjamb', 'doorpost'],
    'stand': ['anschauung', 'abide', 'abide by', 'abide with', 'accept', 'adhere to', 'advocate', 'affirm', 'affirmance', 'affirmation', 'afford', 'allegation'],
    'stand aloof': ['abrupt', 'abstain', 'abstain from', 'alienate', 'avoid', 'be stuck-up', 'be unmoved', 'be unwilling', 'beg off', 'cast off', 'cast out', 'cut adrift'],
    'stand apart': ['abrupt', 'alienate', 'be distinct', 'be distinguished', 'become an individual', 'cast off', 'cast out', 'clash with', 'conflict with', 'contrast with', 'cut adrift', 'cut off'],
    'stand aside': ['abdicate', 'abrupt', 'alienate', 'be pensioned', 'be superannuated', 'cast off', 'cast out', 'cut adrift', 'cut off', 'cut out', 'delete', 'demit'],
    'stand behind': ['assure', 'attest', 'back', 'back up', 'be sponsor for', 'bond', 'certify', 'champion', 'confirm', 'countersecure', 'endorse', 'ensure'],
    'stand by': ['abut', 'abut on', 'adjoin', 'advocate', 'around', 'aye', 'back', 'back up', 'be contiguous', 'be in contact', 'be prepared', 'be ready'],
    'stand down': ['pax dei', 'pax romana', 'peace of god', 'abandon', 'abdicate', 'abeyance', 'armistice', 'back out', 'be pensioned', 'be superannuated', 'beg off', 'break'],
    'stand fast': ['abide', 'be still', 'be unflappable', 'coast', 'die hard', 'dig in', 'freeze', 'get home free', 'hang in', 'hang in there', 'hang tough', 'hold fast'],
    'stand for': ['abide', 'abide with', 'advert to', 'affirm', 'allege', 'allude to', 'announce', 'annunciate', 'approach anchorage', 'argue', 'assert', 'assever'],
    'stand in': ['advocate', 'agent', 'alter ego', 'alternate', 'alternative', 'amicus curiae', 'analogy', 'assistant', 'attorney', 'backup', 'backup man', 'bit player'],
    'stand in for': ['act for', 'answer for', 'appear for', 'back up', 'change places with', 'commission', 'crowd out', 'cut out', 'deputize', 'displace', 'double for', 'fill in for'],
    'stand off': ['bear off', 'decline', 'die away', 'diminish', 'drift away', 'dwindle', 'ebb', 'fade', 'fade away', 'go', 'go away', 'haul off'],
    'stand on': ['abut on', 'affirm', 'allege', 'announce', 'annunciate', 'argue', 'assert', 'assever', 'asseverate', 'aver', 'avouch', 'avow'],
    'stand out': ['aller sans dire', 'amount to something', 'appear', 'balk', 'be evident', 'be featured', 'be manifest', 'be no secret', 'be noticeable', 'be prominent', 'be revealed', 'be seen'],
    'stand over': ['adjourn', 'administer', 'administrate', 'be master', 'boss', 'captain', 'chair', 'command', 'continue', 'defer', 'delay', 'direct'],
    'stand pat': ['ante', 'ante up', 'back', 'balk', 'be conservative', 'be unflappable', 'bet', 'bet on', 'call', 'cover', 'die hard', 'do nothing'],
    'stand still': ['abide', 'be conservative', 'be still', 'coast', 'do nothing', 'freeze', 'keep quiet', 'leave alone', 'let alone', 'let be', 'lie still', 'mark time'],
    'stand together': ['accord', 'act in concert', 'act together', 'affiliate', 'agree', 'ally', 'amalgamate', 'answer to', 'assent', 'associate', 'assort with', 'band'],
    'stand up': ['answer', 'arise', 'ascend', 'avail', 'be consistent', 'be equal to', 'be erect', 'be proof against', 'be the case', 'be true', 'be truthful', 'bear'],
    'stand up for': ['advocate', 'allege in support', 'answer', 'argue for', 'assert', 'assure', 'attest', 'back', 'be sponsor for', 'bond', 'certify', 'champion'],
    'stand up to': ['affront', 'beard', 'bell the cat', 'bite the bullet', 'brave', 'brazen', 'brazen out', 'challenge', 'complain', 'complain loudly', 'confront', 'contend with'],
    'standard': ['christian', 'dannebrog', 'jolly roger', 'old glory', 'procrustean law', 'samson post', 'star-spangled banner', 'stars and stripes', 'ten commandments', 'union flag', 'union jack', 'zeitgeist'],
    'standard bearer': ['mahdi', 'bell cow', 'bell mare', 'bellwether', 'born leader', 'boss', 'cacique', 'charismatic leader', 'choirmaster', 'choragus', 'conductor', 'coryphaeus'],
    'standard deviation': ['allowance', 'approximation', 'deviation', 'frequency curve', 'frequency distribution', 'game theory', 'imprecision', 'inaccuracy', 'inaccurateness', 'incorrectness', 'inexactitude', 'inexactness'],
    'standardize': ['adjust', 'arrange', 'array', 'assimilate to', 'balance', 'chart', 'codify', 'cool off', 'coordinate', 'damp', 'deploy', 'dispose'],
    'standby': ['maecenas', 'abettor', 'admirer', 'advocate', 'aficionado', 'angel', 'apologist', 'backer', 'bit player', 'buff', 'champion', 'defender'],
    'standing': ['abeyant', 'abidingness', 'age', 'angle', 'antiquity', 'apathetic', 'base', 'bearings', 'cachet', 'candidacy', 'candidature', 'capacity'],
    'standing order': ['procrustean law', 'sop', 'act', 'bill', 'bylaw', 'canon', 'code', 'common practice', 'criterion', 'decree', 'dictate', 'dictation'],
    'standing room only': ['sro', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full', 'chuck-full', 'congested', 'cram-full', 'crammed', 'farci'],
    'standoff': ['tweedledum and tweedledee', 'aloof', 'arrest', 'bell', 'check', 'checkmate', 'cutoff', 'dead heat', 'dead stop', 'deadlock', 'distant', 'draw'],
    'standoffish': ['olympian', 'above all that', 'aloof', 'backward', 'bashful', 'blank', 'chilled', 'chilly', 'cold', 'constrained', 'cool', 'detached'],
    'standpat': ['bircher', 'bourbon', 'tory', 'adamant', 'adamantine', 'at a standstill', 'backward', 'bitter-ender', 'conservatist', 'conservative', 'contemplative', 'die-hard'],
    'standpipe': ['adjutage', 'antenna tower', 'barbican', 'belfry', 'bell tower', 'campanile', 'catheter', 'colossus', 'column', 'cupola', 'derrick', 'dome'],
    'standpoint': ['anschauung', 'angle', 'angle of vision', 'base', 'basis', 'coign of vantage', 'direction', 'distance', 'eye', 'footing', 'frame of reference', 'framework'],
    'standstill': ['arrest', 'bell', 'blind alley', 'box', 'cessation', 'check', 'checkmate', 'corner', 'cul-de-sac', 'cutoff', 'dead end', 'dead set'],
    'stanford binet test': ['binet-simon test', 'brown personality inventory', 'goldstein-sheerer test', 'iq', 'iq test', 'kent mental test', 'minnesota preschool scale', 'oseretsky test', 'rorschach test', 'stanford revision', 'szondi test', 'tat'],
    'stanza': ['spenserian stanza', 'anacrusis', 'antistrophe', 'bass passage', 'book', 'bourdon', 'bridge', 'burden', 'cadence', 'canto', 'chorus', 'coda'],
    'stapes': ['eustachian tube', 'anvil', 'auditory apparatus', 'auditory canal', 'auditory meatus', 'auditory nerve', 'auditory ossicles', 'auditory tube', 'auricle', 'basilar membrane', 'bony labyrinth', 'cauliflower ear'],
    'staphylococcus': ['adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'bacillus', 'bacteria', 'bacterium', 'bug', 'coccus', 'echovirus'],
    'staple': ['anchored', 'article', 'article of commerce', 'article of merchandise', 'articulate', 'auto show', 'basic', 'basics', 'batten', 'batten down', 'bazaar', 'boat show'],
    'star': ['a per se', 'aldebaran', 'canicula', 'dog star', 'hershey bar', 'hesper', 'hesperus', 'lucifer', 'north star', 'phosphor', 'phosphorus', 'polaris'],
    'star crossed': ['badly off', 'depressed', 'dire', 'donsie', 'doomful', 'evil-starred', 'fatal', 'fortuneless', 'funest', 'hapless', 'ill off', 'ill-starred'],
    'star spangled': ['cynthian', 'ablaze', 'aglow', 'alight', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical'],
    'starboard': ['epistle side', 'astarboard', 'clockwise', 'conservative', 'decanal side', 'dexter', 'dextrad', 'dextral', 'dextrally', 'dextrocardial', 'dextrocerebral', 'dextrocular'],
    'starch': ['aggressiveness', 'albumen', 'bang', 'batter', 'bonnyclabber', 'butter', 'carbohydrate', 'clabber', 'cornstarch', 'cream', 'curd', 'dash'],
    'starched': ['buckram', 'firm', 'in buckram', 'pokerlike', 'prim', 'ramrodlike', 'renitent', 'rigid', 'rodlike', 'starch', 'starchy', 'stiff'],
    'starchy': ['adhesive', 'amylaceous', 'clabbered', 'clammy', 'clotted', 'coagulated', 'curdled', 'doughy', 'firm', 'gaumy', 'gelatinous', 'glairy'],
    'stare': ['be amazed', 'be astonished', 'be curious', 'bedroom eyes', 'bore', 'burn with curiosity', 'come-hither look', 'crane', 'crane the neck', 'dig around for', 'dig up', 'evil eye'],
    'stare down': ['affront', 'beard', 'bid defiance', 'brave', 'brazen out', 'call out', 'challenge', 'confront', 'crane', 'crane the neck', 'dare', 'defy'],
    'starets': ['methuselah', 'abecedarian', 'angel', 'antediluvian', 'antique', 'authority', 'back number', 'boss', 'bwana', 'certified teacher', 'chef', 'chief'],
    'stargazer': ['chaldean', 'astroalchemist', 'astrogeologist', 'astrographer', 'astrologer', 'astrologian', 'astromancer', 'astronomer', 'astrophysicist', 'genethliac', 'horoscoper', 'horoscopist'],
    'stargazing': ['walter mitty', 'absence of mind', 'absent', 'absentminded', 'absentmindedness', 'absorbed', 'absorption', 'abstracted', 'abstractedness', 'abstraction', 'aspect', 'astrodiagnosis'],
    'staring': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'arrant', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled'],
    'stark': ['spartan', 'absolute', 'absolutely', 'altogether', 'arrant', 'ascetic', 'austere', 'bald', 'bare', 'barren', 'basic', 'blasted'],
    'stark naked': ['bald', 'bare', 'bare-ass', 'gymnosophical', 'in native buff', 'in puris naturalibus', 'in the altogether', 'in the buff', 'in the raw', 'naked', 'naturistic', 'nude'],
    'stark raving mad': ['dionysiac', 'amok', 'bacchic', 'berserk', 'corybantic', 'desperate', 'frantic', 'frenetic', 'frenzied', 'furious', 'like one possessed', 'mad'],
    'starless': ['beamless', 'black', 'black as night', 'caliginous', 'dark', 'dark as night', 'dark as pitch', 'darkling', 'darksome', 'ebon', 'ebony', 'eclipsed'],
    'starlike': ['aglow', 'beaming', 'beamy', 'blushing', 'bright and sunny', 'burning', 'candescent', 'flushing', 'gleaming', 'gleamy', 'glinting', 'glowing'],
    'starlit': ['ablaze', 'aglow', 'alight', 'bathed with light', 'bespangled', 'brightened', 'candlelit', 'enlightened', 'firelit', 'gaslit', 'illuminated', 'in a blaze'],
    'starry': ['cynthian', 'aglow', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical', 'beaming', 'beamy'],
    'starry eyed': ['airy', 'ape about', 'autistic', 'beaming', 'beatific', 'beatified', 'blessed', 'blissful', 'bugs on', 'capering', 'cheerful', 'chirping'],
    'stars': ['friday', 'friday the thirteenth', 'appointed lot', 'astral influences', 'astrology', 'book of fate', 'constellation', 'cup', 'destination', 'destiny', 'dies funestis', 'doom'],
    'stars and stripes': ['dannebrog', 'jolly roger', 'old glory', 'star-spangled banner', 'union flag', 'union jack', 'and blue', 'banderole', 'banner', 'banneret', 'black flag', 'blue ensign'],
    'start': ['activate', 'advance', 'advantage', 'aid', 'allowance', 'alpha', 'arise', 'assistance', 'attack', 'avoid', 'backing', 'base'],
    'start up': ['bob up', 'bounce', 'bound', 'break forth', 'break in', 'break water', 'bring up', 'bristle up', 'broach', 'buck', 'buckjump', 'bundle'],
    'starting point': ['alpha', 'base', 'basis', 'beginning', 'blast-off', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bourn', 'break boundary'],
    'startle': ['affright', 'alarm', 'alert', 'amaze', 'arouse', 'astonish', 'astound', 'awe', 'awestrike', 'be startled', 'bedaze', 'bedazzle'],
    'startled': ['affrighted', 'alarmed', 'alerted', 'aroused', 'bowled down', 'consternated', 'daunted', 'dismayed', 'disquieted', 'electrified', 'frightened', 'in a fright'],
    'startling': ['abrupt', 'alarming', 'amazing', 'astonishing', 'astounding', 'awesome', 'awing', 'breathtaking', 'chilling', 'confounding', 'daunting', 'deterrent'],
    'starvation': ['lenten', 'spartan', 'absence', 'abstemious', 'abstinence from food', 'ascetic', 'asphyxiation', 'austere', 'beggary', 'choke', 'choking', 'defectiveness'],
    'starve': ['od', 'annihilate', 'asphyxiate', 'be in want', 'be killed', 'be pinched', 'be poor', 'be ravenous', 'begrudge', 'bereave of life', 'carry away', 'carry off'],
    'starved': ['aching for', 'attenuated', 'bare-handed', 'beggarly', 'cadaverous', 'corpselike', 'craving', 'deprived of', 'desirous of', 'dog-hungry', 'dying for', 'emacerated'],
    'stash': ['asylum', 'bank', 'bolt-hole', 'bosom', 'bottle up', 'bundle away', 'bury', 'cache', 'coffer', 'conceal', 'concealment', 'corner'],
    'stasis': ['a wise passiveness', 'abeyance', 'abidingness', 'apathy', 'catalepsy', 'catatonia', 'changelessness', 'constancy', 'contemplation', 'contemplative life', 'deadliness', 'deathliness'],
    'stat': ['ditto copy', 'photostat', 'xerox', 'xerox copy', 'clone', 'contact print', 'copy', 'ditto', 'double', 'dupe', 'duplicate', 'enlargement'],
    'state': ['babylonian splendor', 'everyman', 'john doe', 'kreis', 'public', 'affirm', 'air', 'allege', 'ally', 'announce', 'annunciate', 'archbishopric'],
    'state of affairs': ['affairs', 'circumstances', 'concerns', 'condition of things', 'conditions', 'dealings', 'doings', 'goings-on', 'how it goes', 'how it is', 'how things are', 'how things stand'],
    'state of war': ['all-out war', 'appeal to arms', 'armed combat', 'armed conflict', 'attack', 'battle', 'belligerence', 'belligerency', 'bloodshed', 'combat', 'fighting', 'hostilities'],
    'stated': ['accessible', 'affirmed', 'alleged', 'anchored', 'announced', 'ascertained', 'asserted', 'asseverated', 'assured', 'attested', 'averred', 'avouched'],
    'stateless person': ['dp', 'absconder', 'bolter', 'deported population', 'deportee', 'deracine', 'displaced person', 'eloper', 'emigrant', 'emigre', 'escapee', 'evacue'],
    'stately': ['babylonian', 'corinthian', 'aristocratic', 'august', 'awe-inspiring', 'awesome', 'awful', 'barbaric', 'ceremonial', 'ceremonious', 'conventional', 'courtly'],
    'statement': ['parthian shot', 'a priori principle', 'account', 'account rendered', 'accounting', 'accounts', 'acquaintance', 'acta', 'address', 'admission', 'affidavit', 'affirmance'],
    'statesman': ['admirable crichton', 'adept', 'artisan', 'artist', 'attache', 'authority', 'connaisseur', 'connoisseur', 'consultant', 'cordon bleu', 'crack shot', 'craftsman'],
    'statesmanlike': ['daedalian', 'adept', 'adroit', 'apt', 'artistic', 'authoritative', 'bravura', 'brilliant', 'civic', 'clean', 'clever', 'coordinated'],
    'static': ['babel', 'abeyant', 'abiding', 'apathetic', 'at a standstill', 'at anchor', 'atmospherics', 'battery-powered', 'bedlam', 'biostatic', 'birdies', 'blaring'],
    'statics': ['newtonian physics', 'acoustics', 'aerophysics', 'aerostatics', 'applied physics', 'astrophysics', 'basic conductor physics', 'biophysics', 'biostatics', 'chemical physics', 'cryogenics', 'crystallography'],
    'station': ['angle', 'appoint', 'appointment', 'arable land', 'assign', 'barnyard', 'barton', 'base', 'bearings', 'berth', 'billet', 'blood'],
    'stationary': ['abiding', 'adamant', 'adamantine', 'at a standstill', 'at anchor', 'changeless', 'constant', 'contemplative', 'continuing', 'dead-still', 'do-nothing', 'dormant'],
    'stationery': ['bond paper', 'carbon paper', 'cardboard', 'flimsy', 'foolscap', 'leaf', 'letter paper', 'note paper', 'pad', 'page', 'paper', 'papyrus'],
    'stationmaster': ['baggage man', 'bakehead', 'brakeman', 'brakie', 'butcher', 'conductor', 'dispatcher', 'fireman', 'footplate man', 'guard', 'lineman', 'porter'],
    'statuary': ['cysp sculpture', 'anaglyptics', 'anaglyptography', 'architectural sculpture', 'bone-carving', 'bust', 'carver', 'carving', 'casting', 'ceroplastics', 'chaser', 'chasing'],
    'statue': ['art object', 'atlas', 'brainchild', 'bric-a-brac', 'bronze', 'bust', 'carving', 'caryatid', 'cast', 'casting', 'classic', 'colossus'],
    'statuelike': ['at a standstill', 'at anchor', 'dead-still', 'fixed', 'idle', 'immobile', 'immotive', 'marmoreal', 'monumental', 'motionless', 'moveless', 'out of commission'],
    'statuesque': ['junoesque', 'agreeable', 'amply endowed', 'aristocratic', 'august', 'becoming', 'bonny', 'braw', 'built', 'built for comfort', 'buxom', 'callipygian'],
    'stature': ['altitude', 'authority', 'caliber', 'ceiling', 'consequence', 'dignity', 'elevation', 'eminence', 'exaltation', 'face', 'greatness', 'hauteur'],
    'status': ['angle', 'base', 'bearings', 'blood', 'bracket', 'branch', 'cachet', 'caliber', 'capacity', 'case', 'caste', 'category'],
    'statute': ['eighteenth amendment', 'prohibition party', 'volstead act', 'act', 'assize', 'ban', 'bill', 'bylaw', 'canon', 'contraband', 'decree', 'decretum'],
    'statutory': ['actionable', 'applicable', 'authoritative', 'authorized', 'binding', 'canonical', 'competent', 'constitutional', 'dictated', 'didactic', 'formulary', 'hard and fast'],
    'staunch': ['sabbatarian', 'airtight', 'ardent', 'bigoted', 'calculable', 'close', 'committed', 'compact', 'consistent', 'constant', 'creedbound', 'dedicated'],
    'staunchly': ['bec et ongles', 'bona fide', 'committedly', 'consistently', 'constantly', 'deafeningly', 'decidedly', 'decisively', 'determinedly', 'devotedly', 'earnestly', 'faithfully'],
    'stave': ['malacca cane', 'spenserian stanza', 'advocate', 'alpenstock', 'antistrophe', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'bar'],
    'stave off': ['adjourn', 'anticipate', 'avert', 'bar', 'beat off', 'block', 'check', 'continue', 'counter', 'debar', 'defer', 'deflect'],
    'stay': ['abandon', 'abeyance', 'abide', 'abort', 'adhere', 'adjourn', 'advocate', 'afford support', 'afterthought', 'agglomerate', 'alpenstock', 'amnesty'],
    'stay in line': ['attend to orders', 'comply', 'conform', 'defer to', 'fall in with', 'fall into line', 'fit in', 'follow the book', 'follow the crowd', 'follow the fashion', 'follow the rule', 'get in line'],
    'stay put': ['abide', 'adhere', 'agglomerate', 'be still', 'be unflappable', 'bunch', 'clasp', 'cleave', 'clinch', 'cling', 'cling to', 'clot'],
    'stay up': ['abide', 'await', 'bide', 'bide the issue', 'dally', 'dawdle', 'delay', 'dillydally', 'hang about', 'hang around', 'hold everything', 'hold on'],
    'staying power': ['application', 'assiduity', 'assiduousness', 'bulldog tenacity', 'concentration', 'constancy', 'continualness', 'continuance', 'continuation', 'continuity', 'decisiveness', 'diligence'],
    'stead': ['abet', 'abode', 'aid', 'area', 'assist', 'bearings', 'bench mark', 'district', 'do for', 'emplacement', 'help out', 'hole'],
    'steadfast': ['abiding', 'accordant', 'adamant', 'age-long', 'aged', 'alike', 'ancient', 'antique', 'ardent', 'assiduous', 'automatic', 'balanced'],
    'steadily': ['ad infinitum', 'always', 'at all times', 'at every turn', 'at regular intervals', 'at stated times', 'bec et ongles', 'bona fide', 'calmly', 'ceaselessly', 'committedly', 'composedly'],
    'steady': ['abiding', 'accordant', 'adamantine', 'ageless', 'alike', 'alternate', 'appease', 'ardent', 'arranged', 'articulated', 'assiduous', 'automatic'],
    'steady state': ['aplomb', 'balance', 'balanced personality', 'ceaselessness', 'complex variable', 'consecutiveness', 'constancy', 'constant flow', 'continualness', 'continuity', 'continuousness', 'cool'],
    'steak': ['london broil', 'salisbury steak', 't-bone steak', 'beefsteak', 'bifteck', 'chopped steak', 'club steak', 'cubed steak', 'fillet steak', 'flank steak', 'ground beef', 'ground chuck'],
    'steal': ['abstract', 'acquire', 'adopt', 'advantageous purchase', 'and', 'annex', 'appropriate', 'assume', 'bag', 'bargain', 'boost', 'borrow'],
    'steal the show': ['act', 'act as foil', 'appear', 'barnstorm', 'come out', 'emote', 'emotionalize', 'get top billing', 'mime', 'pantomime', 'patter', 'perform'],
    'stealing': ['abstraction', 'all fours', 'annexation', 'appropriation', 'blackmail', 'boodle', 'boosting', 'booty', 'burglary', 'conversion', 'conveyance', 'crawl'],
    'stealth': ['italian hand', 'acuteness', 'art', 'artfulness', 'artifice', 'astuteness', 'cageyness', 'callidity', 'canniness', 'clandestine behavior', 'clandestineness', 'clandestinity'],
    'stealthy': ['machiavellian', 'machiavellic', 'acute', 'arch', 'artful', 'astute', 'back-door', 'backstairs', 'cagey', 'canny', 'catlike', 'catty'],
    'steam': ['old faithful', 'aerate', 'aerify', 'afterdamp', 'agua', 'amperage', 'aqua', 'armipotence', 'atomize', 'authority', 'bake', 'barbecue'],
    'steam pipe': ['adjutage', 'burner', 'caliduct', 'catheter', 'cooker', 'cookery', 'drainpipe', 'efflux tube', 'element', 'fire hose', 'flue pipe', 'funnel'],
    'steam room': ['bagnio', 'balneae', 'balneum', 'bath', 'bathhouse', 'bathroom', 'baths', 'caldarium', 'lavatory', 'mikvah', 'public baths', 'rest room'],
    'steam up': ['annoy', 'arouse', 'awake', 'awaken', 'blow the coals', 'blow up', 'call forth', 'call up', 'charge', 'cock', 'enkindle', 'enrage'],
    'steamboat': ['boat', 'canoe', 'carry sail', 'circumnavigate', 'coast', 'cross', 'cruise', 'go by ship', 'go on shipboard', 'go to sea', 'make a passage', 'motorboat'],
    'steamed up': ['agog', 'ape about', 'aquiver', 'aroused', 'atingle', 'atwitter', 'bugs on', 'bursting', 'carried away', 'cracked on', 'crazy about', 'ebullient'],
    'steamer': ['dungeness crab', 'japanese crab', 'blue point', 'clam', 'coquillage', 'crab', 'crawdad', 'crawfish', 'crayfish', 'langouste', 'limpet', 'littleneck clam'],
    'steaming': ['ablaze', 'aeration', 'aerial', 'aerification', 'aerodynamic', 'aerostatic', 'aery', 'afire', 'airy', 'ardent', 'atomization', 'boating'],
    'steamroller': ['align', 'beat', 'beat down', 'big battalions', 'blackjack', 'blank', 'blast', 'blow down', 'bludgeon', 'break down', 'bring down', 'brute force'],
    'steamy': ['ablaze', 'aerial', 'aerodynamic', 'aerostatic', 'aery', 'afire', 'airy', 'ardent', 'arousing', 'beclouded', 'befogged', 'blurred'],
    'steed': ['houyhnhnm', 'brood mare', 'charger', 'colt', 'courser', 'critter', 'dobbin', 'entire', 'entire horse', 'equine', 'filly', 'foal'],
    'steel': ['excalibur', 'gibraltar', 'adamant', 'anneal', 'assessable stock', 'aureate', 'authorized capital stock', 'ax', 'bear up', 'beef up', 'bite the bullet', 'blade'],
    'steel band': ['german band', 'philharmonic', 'band', 'big band', 'brass', 'brass band', 'brass choir', 'brass quintet', 'brass section', 'brasses', 'callithumpian band', 'chamber orchestra'],
    'steeled': ['philistine', 'backed', 'calcified', 'callous', 'calloused', 'case-hardened', 'crusted', 'crusty', 'crystallized', 'flinty', 'fossilized', 'granulated'],
    'steelworks': ['blacksmith shop', 'bleachworks', 'bloomery', 'bottling works', 'brassworks', 'copperworks', 'dye works', 'forge', 'foundry', 'furnace', 'gasworks', 'glassworks'],
    'steely': ['philistine', 'quaker-colored', 'acier', 'adamant', 'adamantine', 'ashen', 'ashy', 'aureate', 'beefy', 'bony', 'bouncing', 'brass'],
    'steep': ['herculean', 'olympian', 'olympian heights', 'a bit much', 'abandoned', 'abrupt', 'abstruse', 'acme', 'aerial', 'aerial heights', 'airy', 'altitudinous'],
    'steeple': ['antenna tower', 'barbican', 'belfry', 'bell tower', 'campanile', 'cog', 'colossus', 'column', 'comb', 'crag', 'cupola', 'derrick'],
    'steeplechase': ['derby', 'highland fling', 'kentucky derby', 'preakness stakes', 'and jump', 'bounce', 'bouncing', 'bound', 'bounding', 'broad jump', 'buck', 'buckjump'],
    'steeplechaser': ['broncobuster', 'buckaroo', 'caballero', 'cavalier', 'cavalryman', 'chevalier', 'circus rider', 'cowboy', 'cowgirl', 'cowpuncher', 'entry', 'equestrian'],
    'steer': ['brahman', 'indian buffalo', 'advice', 'aim', 'alerting', 'aurochs', 'avoid', 'be responsible for', 'bear', 'bear for', 'bear up for', 'bear up to'],
    'steer clear of': ['avert', 'avoid', 'be stuck-up', 'bear off', 'dodge', 'draw aside', 'ease off', 'edge off', 'fight shy of', 'fly off', 'gee', 'give place to'],
    'steering': ['accounting', 'action', 'agency', 'aim', 'analysis', 'authority', 'azimuth', 'bearing', 'bent', 'braking', 'command', 'computation'],
    'steering committee': ['board', 'board of directors', 'board of regents', 'board of trustees', 'cabinet', 'cadre', 'council', 'directorate', 'directory', 'executive arm', 'executive committee', 'executive hierarchy'],
    'steersman': ['gyropilot', 'agent', 'automatic pilot', 'boatheader', 'boatsteerer', 'cicerone', 'conductor', 'conner', 'courier', 'cowherd', 'cox', 'coxswain'],
    'steinway': ['klavier', 'baby grand', 'cembalo', 'clarichord', 'clavicembalo', 'clavichord', 'clavicittern', 'clavicymbal', 'clavicytherium', 'clavier', 'concert grand', 'cottage piano'],
    'stela': ['arch', 'barrow', 'boundary stone', 'brass', 'bust', 'cairn', 'cenotaph', 'column', 'cromlech', 'cross', 'cup', 'cyclolith'],
    'stellar': ['cynthian', 'actor-proof', 'all-star', 'anagalactic', 'arch', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical'],
    'stem': ['ic analysis', 'maypole', 'accidence', 'accrue from', 'adjutage', 'advance', 'affiliation', 'affix', 'affixation', 'affront', 'allomorph', 'animal kingdom'],
    'stench': ['aroma', 'bar', 'bind', 'block', 'block up', 'blockade', 'breath', 'bung', 'caulk', 'chink', 'choke', 'choke off'],
    'stencil': ['abstract', 'abstraction', 'albertype', 'altarpiece', 'block print', 'book printing', 'cameography', 'cartoon', 'chalk', 'charcoal', 'chromotypography', 'chromotypy'],
    'stenographer': ['accountant', 'amanuensis', 'archivist', 'bookkeeper', 'brachygrapher', 'clerk', 'documentalist', 'engraver', 'filing clerk', 'librarian', 'marker', 'notary'],
    'stentorian': ['blaring', 'boanergean', 'booming', 'brazen-mouthed', 'clamorous', 'deafening', 'ear-piercing', 'ear-rending', 'ear-splitting', 'earsplitting', 'earthshaking', 'forte'],
    'step': ['abdicate', 'accelerate', 'accomplished fact', 'accomplishment', 'according to', 'ace', 'achievement', 'act', 'acta', 'action', 'activity', 'ad hoc measure'],
    'step aside': ['abdicate', 'about the bush', 'abrupt', 'alienate', 'avert', 'be pensioned', 'be superannuated', 'bear off', 'beat around', 'beg the question', 'cast off', 'cast out'],
    'step by step': ['bit by bit', 'by degrees', 'by inches', 'by inchmeal', 'by slow degrees', 'by stages', 'consecutively', 'degreewise', 'drop by drop', 'gradatim', 'grade by grade', 'gradually'],
    'step down': ['abridge', 'amplify', 'charge', 'compress', 'curtail', 'cut', 'cut back', 'cut down', 'damp', 'dampen', 'decrease', 'deduct'],
    'step forward': ['advance', 'come along', 'come forward', 'come on', 'cover ground', 'gain ground', 'gather head', 'gather way', 'get ahead', 'get along', 'go', 'go ahead'],
    'step in': ['act between', 'admit', 'arbitrate', 'bargain', 'barge in', 'be admitted', 'break in', 'breeze in', 'burst in', 'bust in', 'call', 'come barging in'],
    'step lively': ['bound', 'canter', 'drive', 'drive on', 'forge ahead', 'fox-trot', 'gallop', 'get', 'git', 'go ahead', 'go all out', 'hightail'],
    'step on it': ['accelerate', 'bolt', 'career', 'crack on', 'dart', 'dash', 'fling', 'gain ground', 'get cracking', 'haste', 'hasten', 'hie'],
    'step out': ['carouse', 'cast off', 'celebrate', 'cut loose', 'debauch', 'doff', 'douse', 'drop', 'hell around', 'jollify', 'jolly', 'lark'],
    'step up': ['accelerando', 'accelerate', 'acceleration', 'accost', 'advance', 'aggravate', 'aggravation', 'amplify', 'approach', 'appropinquate', 'approximate', 'bear down on'],
    'stepchild': ['child', 'daughter', 'descendant', 'foster child', 'grandchild', 'granddaughter', 'grandson', 'heiress', 'offspring', 'scion', 'son', 'son and heir'],
    'stepmother': ['dam', 'foster mother', 'genetrix', 'ma', 'mam', 'mama', 'mammy', 'mater', 'materfamilias', 'maternal ancestor', 'matriarch', 'mom'],
    'steppe': ['lebensraum', 'agricultural region', 'air space', 'alkali flat', 'alluvial plain', 'arable land', 'back country', 'basin', 'billiard table', 'black belt', 'bottomland', 'bowling green'],
    'stepper': ['jehu', 'ambler', 'cob', 'flier', 'gaited horse', 'galloper', 'goer', 'hell-driver', 'high-stepper', 'horse racer', 'hummer', 'hustler'],
    'stepping stone': ['bifrost', 'a leg up', 'back stairs', 'bascule bridge', 'bateau bridge', 'bridge', 'cantilever bridge', 'catwalk', 'chance', 'clear stage', 'companion', 'companionway'],
    'steps': ['back stairs', 'companion', 'companionway', 'escalier', 'fire escape', 'flight of steps', 'forearming', 'forehandedness', 'foresight', 'foresightedness', 'forethought', 'forethoughtfulness'],
    'stereo': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'stereoscopic': ['cubic', 'dimensional', 'flat', 'fourth-dimensional', 'microscopic', 'proportional', 'space', 'space-time', 'spatial', 'spatiotemporal', 'spherical', 'superficial'],
    'stereotype': ['assimilate to', 'automatism', 'autotype', 'bad habit', 'balance', 'bed', 'characteristic', 'confirm', 'creature of habit', 'custom', 'damp', 'deep-dye'],
    'stereotyped': ['alike', 'automatic', 'average', 'back-number', 'banal', 'beaten', 'besetting', 'bewhiskered', 'bromidic', 'cliche', 'cliched', 'common'],
    'sterile': ['abortive', 'acarpous', 'antiseptic', 'arid', 'aseptic', 'bare', 'barren', 'blah', 'blank', 'bloodless', 'boiled', 'bootless'],
    'sterility': ['aridity', 'asepsis', 'barrenness', 'birth control', 'bloodlessness', 'characterlessness', 'cleanliness', 'cleanly habits', 'cleanness', 'colorlessness', 'contraception', 'daintiness'],
    'sterilize': ['alter', 'antisepticize', 'autoclave', 'boil', 'castrate', 'change', 'chlorinate', 'clean', 'cleanse', 'decontaminate', 'delouse', 'demasculinize'],
    'sterling': ['christian', 'admirable', 'and pence', 'authentic', 'blameless', 'bona fide', 'candid', 'capital', 'card-carrying', 'cash', 'circulating medium', 'clean'],
    'stern': ['spartan', 'spartanic', 'adamant', 'adamantine', 'afterpart', 'afterpiece', 'arse', 'ascetic', 'ass', 'astringent', 'austere', 'authoritarian'],
    'sternway': ['brownian movement', 'advance', 'angular motion', 'ascending', 'ascent', 'axial motion', 'backflowing', 'backing', 'backset', 'backsliding', 'backward motion', 'backward step'],
    'stertor': ['aqua-lung', 'artificial respiration', 'aspiration', 'assibilation', 'asthmatic wheeze', 'breath', 'breath of air', 'breathing', 'broken wind', 'buzz', 'cough', 'effervescence'],
    'stertorous': ['asthmatic', 'brassy', 'brazen', 'breathing', 'choked', 'coarse', 'cracked', 'croaking', 'croaky', 'dry', 'errhine', 'expiratory'],
    'stevedore': ['aquarius', 'ganymede', 'hebe', 'bearer', 'bheesty', 'busboy', 'caddie', 'cargo handler', 'carrier', 'carrier pigeon', 'carter', 'common carrier'],
    'stew': ['b-girl', 'cyprian', 'irish stew', 'paphian', 'ado', 'agitation', 'agonize', 'all sorts', 'all-overs', 'angst', 'anxiety', 'anxiety hysteria'],
    'steward': ['federal', 'ganymede', 'hebe', 'mc', 'accountant', 'aerial photographer', 'agent', 'air warden', 'aircrew', 'aircrewman', 'airline hostess', 'airline stewardess'],
    'stewardess': ['ganymede', 'hebe', 'aerial photographer', 'aircrew', 'aircrewman', 'airline hostess', 'airline stewardess', 'attendant', 'avigator', 'bakehead', 'batman', 'bellboy'],
    'stewardship': ['administration', 'auspices', 'captainship', 'care', 'chairmanship', 'charge', 'convenership', 'cure', 'custodianship', 'custody', 'dictatorship', 'directorate'],
    'stewed': ['afflicted', 'baked', 'bent', 'boiled', 'bombed', 'boozy', 'braised', 'broiled', 'browned', 'canned', 'cockeyed', 'cockeyed drunk'],
    'stick': ['abide', 'abide with', 'abrade', 'acid', 'acuminate', 'addle', 'adhere', 'adhere to', 'advocate', 'affix', 'agglomerate', 'all'],
    'stick around': ['abide', 'await', 'bide', 'bide the issue', 'dally', 'dawdle', 'delay', 'dillydally', 'hang about', 'hang around', 'hold everything', 'hold on'],
    'stick at': ['back down', 'balance', 'blench', 'boggle', 'debate', 'deliberate', 'demur', 'falter', 'fear', 'fight shy of', 'flinch', 'hang back'],
    'stick it out': ['be unflappable', 'bear up', 'come up fighting', 'die hard', 'get along', 'get home free', 'get on', 'go on', 'go on with', 'hang in', 'hang in there', 'hang on'],
    'stick out': ['abide', 'aller sans dire', 'be conspicuous', 'be exposed', 'be manifest', 'be no secret', 'bear', 'bear up', 'beetle', 'bristle up', 'brook', 'cock up'],
    'stick shift': ['hydromatic', 'automatic transmission', 'cogwheel', 'differential', 'differential gear', 'freewheel', 'gear', 'gear train', 'gearbox', 'gearing', 'gearshift', 'gearwheel'],
    'stick together': ['accouple', 'accumulate', 'adhere', 'agglomerate', 'agglutinate', 'amass', 'articulate', 'assemble', 'associate', 'band', 'be consistent', 'be the case'],
    'stick up': ['arise', 'boost', 'bristle', 'bristle up', 'buoy up', 'cast up', 'cock up', 'commit robbery', 'elevate', 'erect', 'escalate', 'extrude'],
    'stick up for': ['advocate', 'allege in support', 'answer', 'argue for', 'assert', 'back', 'back up', 'champion', 'contend for', 'counter', 'defend', 'espouse'],
    'sticker': ['chinese puzzle', 'adherent', 'adhesive', 'baffling problem', 'barnacle', 'billhead', 'book stamp', 'bookplate', 'brain twister', 'bramble', 'brand', 'brier'],
    'stickle': ['abrupt', 'arduous', 'back down', 'balance', 'balk', 'blench', 'boggle', 'contend', 'contend for', 'debate', 'deliberate', 'demur'],
    'stickler': ['simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'ass', 'autarch', 'autocrat', 'bigot', 'bitter-ender', 'bullethead', 'caesar'],
    'stickling': ['bashful', 'bashfulness', 'boggle', 'boggling', 'cautious', 'compunction', 'demur', 'demurral', 'demurring', 'diffidence', 'diffident', 'falter'],
    'stickpin': ['anklet', 'armlet', 'bangle', 'beads', 'bijou', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet', 'charm', 'chatelaine'],
    'sticks': ['china', 'darkest africa', 'god knows where', 'greenland', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'siberia', 'south pole', 'thule', 'tierra del fuego'],
    'stickup': ['armed robbery', 'asportation', 'assault and robbery', 'banditry', 'bank robbery', 'cattle lifting', 'cattle stealing', 'extortion', 'heist', 'highway robbery', 'hijacking', 'holdup'],
    'sticky': ['adherent', 'adhesive', 'amylaceous', 'awkward', 'bathed in sweat', 'bathetic', 'beaded with sweat', 'beery', 'boggy', 'bulldogged', 'bulldoggish', 'bulldoggy'],
    'sticky wicket': ['bind', 'clutch', 'complication', 'crunch', 'embarrassing position', 'embarrassment', 'fine how-do-you-do', 'hell to pay', 'hobble', 'hot water', 'how-do-you-do', 'imbroglio'],
    'stiff': ['arab', 'bowery bum', 'latinate', 'a bit much', 'abandoned', 'abusive', 'adamant', 'adamantine', 'afflictive', 'alcoholic', 'all thumbs', 'aloof'],
    'stiff necked': ['quakerish', 'victorian', 'balking', 'balky', 'bigoted', 'bulldogged', 'bulletheaded', 'bullheaded', 'case-hardened', 'censorious', 'demure', 'dogged'],
    'stiffen': ['amplify', 'back', 'be tough', 'beef up', 'brace', 'brace up', 'buttress', 'case harden', 'charge', 'clot', 'coagulate', 'confirm'],
    'stiffened': ['accelerated', 'aggrandized', 'amplified', 'augmented', 'backed', 'beefed-up', 'bloated', 'boosted', 'broadened', 'calcified', 'callous', 'calloused'],
    'stiffness': ['adamantness', 'aridity', 'barrenness', 'bloodlessness', 'buckram', 'ceremonial', 'ceremoniousness', 'ceremony', 'characterlessness', 'cohesiveness', 'colorlessness', 'costliness'],
    'stifle': ['abate', 'allay', 'alleviate', 'asphyxiate', 'assuage', 'attemper', 'bake', 'bank the fire', 'bar', 'barricade', 'be in heat', 'black out'],
    'stifled': ['arcane', 'bated', 'blurred', 'breathy', 'cabalistic', 'censored', 'choked', 'choking', 'classified', 'close', 'closed', 'concealed'],
    'stifling': ['airless', 'breathless', 'breezeless', 'choking', 'close', 'constrictive', 'contrary', 'counterproductive', 'crosswise', 'extinguishment', 'hindering', 'hindersome'],
    'stigma': ['abscess', 'androecium', 'anther', 'aposteme', 'aspersion', 'attaint', 'badge of infamy', 'bar sinister', 'baton', 'bed sore', 'bend sinister', 'besmirchment'],
    'stigmatize': ['advert to', 'allude to', 'attaint', 'band', 'bar', 'be taken as', 'bedaub', 'besmear', 'besmirch', 'besmoke', 'bespangle', 'bespatter'],
    'stile': ['french door', 'samson post', 'archway', 'back door', 'back stairs', 'baluster', 'balustrade', 'banister', 'barway', 'bulkhead', 'carriage entrance', 'cellar door'],
    'still': ['telephoto', 'wirephoto', 'additionally', 'aerial photograph', 'aerosol', 'after all', 'again', 'albeit', 'all the same', 'allay', 'alleviate', 'along'],
    'still hunt': ['angle for', 'ask for', 'beat', 'beat about for', 'chase', 'chevy', 'chivy', 'course', 'coursing', 'cynegetics', 'delve for', 'dig for'],
    'still life': ['abstract', 'abstraction', 'altarpiece', 'art object', 'block print', 'brainchild', 'bric-a-brac', 'classic', 'collage', 'color print', 'composition', 'copy'],
    'stillborn': ['abortive', 'asleep', 'asleep in jesus', 'at rest', 'bearing', 'bereft of life', 'bootless', 'born', 'breathless', 'called home', 'calved', 'carrion'],
    'stillness': ['ataraxia', 'ataraxy', 'awful silence', 'calmness', 'composure', 'contemplation', 'dead', 'dead of night', 'deathlike silence', 'golden silence', 'hush', 'hush of night'],
    'stilted': ['gongoresque', 'johnsonian', 'latinate', 'affected', 'artificial', 'aureate', 'awkward', 'bedizened', 'big-sounding', 'bloated', 'bombastic', 'buckram'],
    'stimulant': ['adrenalin', 'benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'methedrine', 'activator', 'aloes', 'ammonium carbonate', 'amphetamine'],
    'stimulate': ['activate', 'actuate', 'affect the interest', 'animate', 'animating', 'arouse', 'attract', 'awaken', 'brace', 'brace up', 'bracing', 'bring forth'],
    'stimulated': ['actuated', 'agog', 'animated', 'aquiver', 'aroused', 'atingle', 'atwitter', 'bursting', 'carried away', 'ebullient', 'effervescent', 'energized'],
    'stimulating': ['activating', 'agitating', 'alluring', 'analeptic', 'animating', 'animative', 'aphrodisiac', 'aphroditous', 'ardent', 'arousing', 'bracing', 'breathtaking'],
    'stimulation': ['a high', 'actuation', 'aggravation', 'agitation', 'alpha decay', 'animation', 'arousal', 'arousing', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction'],
    'stimulus': ['activator', 'aggravation', 'agitation', 'animation', 'animator', 'antecedents', 'arousal', 'arouser', 'arousing', 'bait', 'base', 'basis'],
    'sting': ['acerbity', 'acidity', 'acridity', 'acrimony', 'aculeus', 'acuminate', 'acumination', 'affect', 'afflict', 'affront', 'aggrieve', 'agonize'],
    'stinging': ['acanaceous', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'aculeolate', 'acute'],
    'stingy': ['lenten', 'scotch', 'spartan', 'abstemious', 'ascetic', 'austere', 'avaricious', 'cheap', 'cheeseparing', 'chinchy', 'chintzy', 'close'],
    'stink': ['bo', 'bad breath', 'bad smell', 'be aromatic', 'be redolent of', 'body odor', 'breathe', 'emit a smell', 'exhale', 'fetidity', 'fetidness', 'fetor'],
    'stinker': ['havana', 'sob', 'bastard', 'beast', 'belvedere', 'blackguard', 'blighter', 'bounder', 'box of cigars', 'bugger', 'bum', 'cad'],
    'stinking': ['abhorrent', 'abominable', 'awful', 'bad', 'bad-smelling', 'barfy', 'base', 'beastly', 'below contempt', 'beneath contempt', 'besotted', 'bombed'],
    'stinko': ['afflicted', 'bent', 'boiled', 'bombed', 'boozy', 'canned', 'cockeyed', 'cockeyed drunk', 'crocked', 'crocko', 'disguised', 'drunk'],
    'stint': ['allotment', 'amount', 'anchor watch', 'apportionment', 'assignment', 'begrudge', 'bit', 'bound', 'bout', 'box', 'box in', 'box up'],
    'stinted': ['lenten', 'spartan', 'abstemious', 'ascetic', 'austere', 'boxed in', 'circumscribed', 'confined', 'cramped', 'dwarfed', 'dwarfish', 'exiguous'],
    'stinting': ['cheeseparing', 'economy', 'economy of assumption', 'economy of means', 'elegance', 'frugal', 'frugal to excess', 'frugality', 'law of parsimony', 'measured', 'moderate', 'overfrugal'],
    'stintless': ['bighearted', 'bounteous', 'bountiful', 'free', 'freehanded', 'freehearted', 'generous', 'giving', 'gracious', 'greathearted', 'handsome', 'hospitable'],
    'stipend': ['account', 'aid', 'alimony', 'allotment', 'allowance', 'annuity', 'assessment', 'assistance', 'award', 'bill', 'blackmail', 'blood money'],
    'stipendiary': ['allottee', 'almsman', 'almswoman', 'annuitant', 'assign', 'assignee', 'beneficiary', 'devisee', 'donee', 'dotal', 'dower', 'dowered'],
    'stipple': ['apply paint', 'autolithograph', 'band', 'bar', 'be a printmaker', 'bedaub', 'bedizen', 'begild', 'besmear', 'bespangle', 'bespeckle', 'bespot'],
    'stippled': ['bespangled', 'blotched', 'blotchy', 'dotted', 'dotty', 'flea-bitten', 'flecked', 'fleckered', 'frecked', 'freckled', 'freckly', 'macular'],
    'stipulate': ['agree', 'agree to', 'assign', 'attach a condition', 'bargain', 'bargain for', 'call for', 'compact', 'condition', 'contend for', 'contract', 'covenant'],
    'stipulated': ['agreed', 'arranged', 'certain', 'compacted', 'conditional', 'contracted', 'covenanted', 'designated', 'engaged', 'fixed', 'given', 'promised'],
    'stipulation': ['accord', 'agreement', 'allocation', 'arrangement', 'assignment', 'attribution', 'bargain', 'binding agreement', 'bond', 'boundary condition', 'cartel', 'catch'],
    'stir': ['action', 'activate', 'activeness', 'activism', 'activity', 'actuate', 'actuation', 'ado', 'advance', 'affect', 'agitate', 'agitation'],
    'stir up': ['abet', 'admix', 'aggravate', 'agitate', 'alloy', 'amalgamate', 'annoy', 'arouse', 'awake', 'awaken', 'beat', 'beat up'],
    'stirps': ['affiliation', 'animal kingdom', 'apparentation', 'birth', 'blood', 'bloodline', 'branch', 'breed', 'brood', 'clan', 'class', 'common ancestry'],
    'stirred up': ['agitated', 'agog', 'aquiver', 'aroused', 'atingle', 'atwitter', 'bursting', 'carried away', 'discomposed', 'disquieted', 'disturbed', 'ebullient'],
    'stirring': ['active', 'afoot', 'agitating', 'alluring', 'ardent', 'astir', 'awe-inspiring', 'breathtaking', 'burning', 'bustling', 'challenging', 'charged'],
    'stirrup': ['eustachian tube', 'anvil', 'auditory apparatus', 'auditory canal', 'auditory meatus', 'auditory nerve', 'auditory ossicles', 'auditory tube', 'auricle', 'basilar membrane', 'bellyband', 'bony labyrinth'],
    'stirrup cup': ['godspeed', 'mickey', 'mickey finn', 'adieu', 'aloha', 'aperitif', 'chaser', 'cocktail', 'conge', 'doch-an-dorrach', 'drink', 'eye-opener'],
    'stitch': ['french knot', 'ache', 'acute pain', 'ankle', 'articulate', 'articulation', 'batten', 'batten down', 'bit', 'bite', 'bolt', 'boring pain'],
    'stochastic': ['aimless', 'aleatoric', 'aleatory', 'amorphous', 'blobby', 'blurred', 'blurry', 'broad', 'casual', 'causeless', 'chance', 'chancy'],
    'stock': ['animalia', 'broadway', 'ability', 'abundance', 'acceptation', 'accepted', 'acception', 'accommodate', 'accumulate', 'accumulation', 'accustomed', 'acquiescence'],
    'stock company': ['aktiengesellschaft', 'accident insurance', 'acting company', 'actuary', 'aktiebolag', 'annuity', 'assurance', 'aviation insurance', 'bail bond', 'body corporate', 'bond', 'business'],
    'stock exchange': ['american stock exchange', 'amex', 'wall street', 'board', 'bourse', 'commodity exchange', 'corn pit', 'curb', 'curb exchange', 'curb market', 'exchange', 'exchange floor'],
    'stock market': ['american stock exchange', 'amex', 'wall street', 'board', 'bourse', 'commodity exchange', 'corn pit', 'curb', 'curb exchange', 'curb market', 'exchange', 'exchange floor'],
    'stock room': ['archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box', 'bunker'],
    'stock still': ['at a standstill', 'at anchor', 'dead-still', 'fixed', 'idle', 'immobile', 'immotive', 'motionless', 'moveless', 'out of commission', 'riding at anchor', 'static'],
    'stockade': ['pow camp', 'abatis', 'advanced work', 'balistraria', 'bank', 'banquette', 'barbed-wire entanglement', 'barbican', 'barricade', 'barrier', 'bartizan', 'bastille'],
    'stockbreeding': ['animal husbandry', 'animal rearing', 'bee culture', 'beekeeping', 'breeding', 'cattle-ranching', 'chicken-farming', 'dairy-farming', 'dressage', 'gnotobiotics', 'grazing', 'herding'],
    'stockbroker': ['realtor', 'wall streeter', 'bill broker', 'bond crowd', 'broker', 'cambist', 'cotton broker', 'curb broker', 'dealer', 'diamond broker', 'discount broker', 'estate agent'],
    'stockcar': ['pullman', 'pullman car', 'baggage car', 'boxcar', 'caboose', 'car', 'carriage', 'chair car', 'coach', 'coal car', 'covered waggon', 'day coach'],
    'stockjobbing': ['agiotage', 'arbitrage', 'brokerage', 'buying in', 'equity capital', 'flier', 'flutter', 'jobbing', 'legal bucketing', 'liquidation', 'plunge', 'profit taking'],
    'stockpile': ['abundance', 'accumulate', 'accumulation', 'acervation', 'agglomerate', 'agglomeration', 'aggregate', 'aggregation', 'amass', 'amassment', 'backlog', 'bank'],
    'stocks': ['oregon boat', 'assessable stock', 'authorized capital stock', 'bilbo', 'blue chip', 'blue chip stock', 'bond', 'bonds', 'borrowed stock', 'branks', 'bridle', 'camisole'],
    'stocks and bonds': ['assurance', 'bond', 'callable securities', 'cats and dogs', 'certificate of deposit', 'corporation securities', 'foreign securities', 'futures contract', 'government securities', 'guarantee', 'guaranty', 'indemnity'],
    'stocky': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blocky', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky'],
    'stodgy': ['spartan', 'adhesive', 'aloof', 'amylaceous', 'apathetic', 'arid', 'banausic', 'barren', 'blah', 'bland', 'blank', 'bloodless'],
    'stoic': ['laodicean', 'olympian', 'spartan', 'accepting', 'aloof', 'apathetic', 'armed with patience', 'at rest', 'benumbed', 'blah', 'blase', 'bovine'],
    'stoical': ['apathetic', 'calm', 'cool', 'disciplined', 'dispassionate', 'emotionless', 'frigid', 'impassive', 'imperturbable', 'indifferent', 'long-suffering', 'phlegmatic'],
    'stoicism': ['aristotelian philosophy', 'aristotelianism', 'christian ethics', 'encratism', 'epicureanism', 'friday', 'lenten fare', 'peripatetic school', 'peripateticism', 'platonic philosophy', 'platonism', 'pythagoreanism'],
    'stoke': ['bank', 'burn', 'chafe', 'coal', 'conflagrate', 'cook', 'detonate', 'electric-heat', 'enkindle', 'explode', 'fan the flame', 'feed'],
    'stoker': ['baggage man', 'bakehead', 'black gang', 'boilerman', 'brakeman', 'brakie', 'bungs', 'butcher', 'cabin boy', 'chips', 'commissary steward', 'complement'],
    'stolen goods': ['blackmail', 'boodle', 'bootleg liquor', 'booty', 'cigarettes', 'contraband', 'dope', 'drugs', 'graft', 'haul', 'hot goods', 'jewels'],
    'stolid': ['aloof', 'apathetic', 'arid', 'at rest', 'barren', 'blunt', 'bored', 'bovine', 'calm', 'careless', 'cloistered', 'cool'],
    'stomach': ['abatis', 'abdomen', 'abide', 'abomasum', 'accept', 'aftertaste', 'anus', 'appendix', 'appetite', 'bay window', 'bear', 'bear with'],
    'stomachache': ['ache', 'aching', 'angina', 'backache', 'bellyache', 'cephalalgia', 'colic', 'collywobbles', 'distress', 'earache', 'fret', 'gnawing'],
    'stomp': ['amble', 'barge', 'bowl along', 'bundle', 'clop', 'clump', 'drag', 'drub', 'flounce', 'foot', 'footslog', 'halt'],
    'stone': ['irish confetti', 'lydian stone', 'tarmac', 'tarvia', 'aa', 'abyssal rock', 'acorn', 'adamant', 'adamantine', 'adobe', 'agate', 'alexandrite'],
    'stone age man': ['bronze age man', 'hominidae', 'iron age man', 'aboriginal', 'aborigine', 'ancient', 'antediluvian', 'anthropoid', 'ape-man', 'autochthon', 'bushman', 'cave dweller'],
    'stone cold': ['siberian', 'algid', 'arctic', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'boreal', 'brisk', 'brumal', 'cold'],
    'stone faced': ['decorous', 'demure', 'earnest', 'formal', 'frowning', 'grave', 'grim', 'grim-faced', 'grim-visaged', 'long-faced', 'sedate', 'serious'],
    'stone wall': ['arch dam', 'backstop', 'balustrade', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier', 'bear-trap dam', 'beaver dam', 'boom', 'boundary'],
    'stonecutter': ['accountant', 'amanuensis', 'archivist', 'bookkeeper', 'carver', 'chaser', 'clay modeler', 'clerk', 'documentalist', 'earth artist', 'engraver', 'figurer'],
    'stonecutting': ['cysp sculpture', 'anaglyptics', 'anaglyptography', 'architectural sculpture', 'bone-carving', 'casting', 'ceroplastics', 'chasing', 'clay sculpture', 'decorative sculpture', 'earth art', 'embossing'],
    'stoned': ['asleep', 'blind', 'blind drunk', 'blotto', 'boozy', 'canned', 'cataleptic', 'catatonic', 'cold', 'comatose', 'dead', 'disguised'],
    'stonewall': ['baffle', 'balk', 'blast', 'brave', 'challenge', 'checkmate', 'circumvent', 'confound', 'confront', 'contravene', 'counter', 'counteract'],
    'stoneware': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'dinnerware', 'durable goods', 'durables', 'earthenware', 'enamelware', 'fixtures', 'flatware'],
    'stoning': ['bane', 'beheading', 'blood', 'bloodletting', 'bloodshed', 'braining', 'burning', 'capital punishment', 'crucifixion', 'dealing death', 'decapitation', 'decollation'],
    'stony': ['philistine', 'adamant', 'adamantine', 'bankrupt', 'beat', 'beggared', 'bony', 'broke', 'busted', 'callous', 'calloused', 'case-hardened'],
    'stooge': ['charlie mccarthy', 'roscius', 'act', 'act as foil', 'actor', 'actress', 'adherent', 'agent', 'also-ran', 'ancilla', 'antagonist', 'appear'],
    'stool': ['bm', 'babble', 'be indiscreet', 'be unguarded', 'bear witness against', 'bedpan', 'betray', 'betray a confidence', 'betrayer', 'blab', 'blabber', 'bloody flux'],
    'stool pigeon': ['agent provocateur', 'betrayer', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'canary', 'capper', 'come-on man', 'decoy', 'delator', 'fink'],
    'stoop': ['accommodate', 'accord', 'be shamed', 'belly buster', 'belly flop', 'belly whopper', 'bend', 'bend the knee', 'bend the neck', 'bend to', 'bob', 'bootlick'],
    'stooped': ['couchant', 'crouched', 'debased', 'depressed', 'flat', 'knee-high', 'knocked flat', 'laid low', 'low', 'low-built', 'low-hung', 'low-level'],
    'stop': ['english horn', 'abandon', 'abjure', 'abort', 'afterthought', 'allophone', 'alveolar', 'anchorage', 'apico-alveolar', 'apico-dental', 'arrest', 'arrestation'],
    'stop light': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'beacon', 'beacon fire', 'bell', 'bell buoy', 'blinker', 'blue peter', 'buoy'],
    'stopgap': ['action', 'ad hoc', 'ad hoc measure', 'ad lib', 'ad libitum', 'ad-lib', 'ad-libbing', 'alternate', 'alternative', 'answer', 'arrangement', 'artifice'],
    'stoppage': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'afterthought', 'akinetic epilepsy', 'apodosis', 'apoplexy', 'arrest'],
    'stopped': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'arrested', 'articulated', 'assimilated', 'back', 'backward', 'barytone', 'behindhand'],
    'stopper': ['ko', 'bar', 'bind', 'block', 'block up', 'blockade', 'bonnet', 'bung', 'cap', 'caulk', 'ceil', 'check valve'],
    'stopping place': ['anchorage', 'apodosis', 'bourn', 'catastrophe', 'ceasing', 'cessation', 'coda', 'conclusion', 'consummation', 'crack of doom', 'culmination', 'curtain'],
    'stopple': ['bar', 'bind', 'block', 'block up', 'blockade', 'bung', 'caulk', 'check valve', 'chink', 'choke', 'choke off', 'choke up'],
    'storage': ['ram', 'admission', 'admission fee', 'allocation', 'anchorage', 'archives', 'armory', 'arsenal', 'assignment', 'attic', 'bank', 'basement'],
    'store': ['indian reservation', 'acceptation', 'acception', 'accommodate', 'accumulate', 'accumulation', 'acquiescence', 'afford', 'aggregate', 'amass', 'archives', 'armory'],
    'stored': ['accumulated', 'amassed', 'backlogged', 'collected', 'extra', 'fresh', 'garnered', 'gathered', 'held back', 'held in reserve', 'held out', 'hoarded'],
    'storehouse': ['fort knox', 'archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box'],
    'storekeeper': ['caterer', 'chandler', 'commissariat', 'commissary', 'dealer', 'distributor', 'donor', 'furnisher', 'importer', 'jobber', 'manciple', 'marketer'],
    'storeroom': ['archives', 'armory', 'arsenal', 'attic', 'attic room', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box'],
    'stork': ['accouchement', 'birth', 'birth throes', 'birthing', 'blessed event', 'childbearing', 'childbed', 'childbirth', 'confinement', 'delivery', 'genesis', 'giving birth'],
    'storm': ['access', 'agitation', 'assail', 'assault', 'attack', 'ball the jack', 'barbarize', 'barrage', 'barrel', 'batter', 'be angry', 'be excitable'],
    'storm cellar': ['abri', 'air-raid shelter', 'basement', 'bomb shelter', 'bombproof', 'bunker', 'cave', 'cellar', 'cellarage', 'coal bin', 'concealment', 'cover'],
    'storm clouds': ['cloudcuckooland', 'alto-cumulus', 'alto-stratus', 'angry clouds', 'anvil cloud', 'banner cloud', 'billowy cloud', 'black cat', 'black clouds', 'breakers ahead', 'broken mirror', 'cap cloud'],
    'storm troops': ['gurkhas', 'ss', 'special forces', 'waffen-ss', 'armed force', 'armed service', 'army', 'array', 'career soldiers', 'elite corps', 'elite troops', 'fighting machine'],
    'storming': ['abandoned', 'amok', 'anarchic', 'angry', 'bellowing', 'berserk', 'blustering', 'blusterous', 'blustery', 'boisterous', 'bullying', 'carried away'],
    'stormy': ['acheronian', 'acherontic', 'cimmerian', 'stygian', 'anarchic', 'angry', 'bad', 'blustering', 'blusterous', 'blustery', 'castellatus', 'chaotic'],
    'stormy petrel': ['ancestor', 'angry clouds', 'announcer', 'antecedent', 'avant-garde', 'avifauna', 'baby bird', 'bellwether', 'bird', 'bird of jove', 'bird of juno', 'bird of minerva'],
    'stormy weather': ['bad times', 'bust', 'calm weather', 'cat-and-dog weather', 'climate', 'clime', 'cold weather', 'cyclone', 'depression', 'dirty weather', 'economic stagnation', 'evil day'],
    'story': ['clio', 'muse of history', 'account', 'action', 'adventures', 'alibi', 'allegation', 'allegory', 'anagnorisis', 'anecdotage', 'anecdote', 'angle'],
    'storybook': ['airy', 'autistic', 'best seller', 'book', 'bound book', 'classic', 'coloring book', 'definitive work', 'dereistic', 'folio', 'great work', 'hardback'],
    'storyteller': ['ananias', 'baron munchausen', 'father of lies', 'satan', 'sir john mandeville', 'advertising writer', 'anecdotist', 'annalist', 'art critic', 'author', 'authoress', 'belletrist'],
    'stout': ['adamantine', 'adipose', 'athletic', 'beefy', 'big', 'big-bellied', 'bloated', 'blowzy', 'bold', 'bold-spirited', 'bosomy', 'bouncing'],
    'stouthearted': ['bestow', 'bold', 'bold-spirited', 'brave', 'chivalric', 'chivalrous', 'courageous', 'doughty', 'gallant', 'greathearted', 'hardy', 'heroic'],
    'stove': ['seger cone', 'acid kiln', 'blast furnace', 'boiler', 'bottle-gas stove', 'brickkiln', 'burner', 'butane stove', 'calefactor', 'caliduct', 'cement kiln', 'coal furnace'],
    'stow': ['bag', 'bank', 'barrel', 'bottle', 'box', 'bundle', 'bundle away', 'burden', 'cache', 'can', 'coffer', 'conceal'],
    'stow away': ['bank', 'bosom', 'bottle up', 'bundle away', 'bury', 'cache', 'coffer', 'deposit', 'embosom', 'file', 'file and forget', 'hide away'],
    'stowage': ['accommodation', 'allocation', 'assignment', 'burden', 'capacity', 'cold storage', 'collocation', 'conservation', 'content', 'cordage', 'custody', 'dead storage'],
    'straddle': ['abstain', 'abut on', 'across', 'amble', 'astraddle', 'astride', 'barge', 'be based on', 'bear on', 'bestraddle', 'bestride', 'bowl along'],
    'stradivarius': ['a string', 'amati', 'cremona', 'd string', 'e string', 'g string', 'strad', 'stradivari', 'bass', 'bass viol', 'bow', 'bridge'],
    'strafe': ['aim at', 'air raid', 'barrage', 'blast', 'blitz', 'blitzkrieg', 'bombard', 'bombardment', 'cannon', 'cannonade', 'commence firing', 'enfilade'],
    'straggle': ['amble', 'barge', 'bat around', 'be lengthy', 'be prolonged', 'belong', 'bowl along', 'bum', 'bundle', 'clump', 'count ties', 'crane'],
    'straggling': ['aimless', 'amorphous', 'broadcast', 'capricious', 'casual', 'circumforaneous', 'desultory', 'diffuse', 'disarticulated', 'discontinuous', 'discrete', 'discursive'],
    'straight': ['ok', 'aboveboard', 'absolute', 'absolutely', 'accordant', 'accurate', 'accurately', 'ace', 'admitting no exception', 'agreed', 'air line', 'all right'],
    'straight face': ['anesthesia', 'autism', 'catatonia', 'chill', 'chilliness', 'cold blood', 'cold heart', 'coldheartedness', 'coldness', 'coolness', 'deadpan', 'decorousness'],
    'straight faced': ['decorous', 'demure', 'earnest', 'formal', 'frowning', 'grave', 'grim', 'grim-faced', 'grim-visaged', 'long-faced', 'sedate', 'serious'],
    'straight man': ['roscius', 'actor', 'actress', 'antagonist', 'bad guy', 'barnstormer', 'character', 'character actor', 'character man', 'character woman', 'child actor', 'diseur'],
    'straight out': ['absolute', 'admitting no exception', 'all-out', 'artless', 'bluff', 'blunt', 'broad', 'brusque', 'candid', 'categorical', 'clear', 'complete'],
    'straight shooting': ['aboveboard', 'authentic', 'bona fide', 'fair and square', 'foursquare', 'genuine', 'good-faith', 'on the level', 'on the square', 'on the up-and-up', 'open', 'open and aboveboard'],
    'straightaway': ['pdq', 'air line', 'all at once', 'all together', 'apace', 'at a blow', 'at a stroke', 'at once', 'at one blow', 'at one jump', 'at one stroke', 'at one swoop'],
    'straighten': ['adjust', 'arrange', 'clean up', 'clear up', 'correct', 'disentangle', 'neaten', 'organize', 'put in order', 'rearrange', 'rectify', 'reform'],
    'straighten out': ['accommodate', 'acculturate', 'adjust', 'admonish', 'advance', 'ameliorate', 'amend', 'arrange', 'better', 'boost', 'bring forward', 'bring to book'],
    'straightforward': ['attic', 'ciceronian', 'mickey mouse', 'spartan', 'aboveboard', 'apparent', 'artless', 'ascetic', 'austere', 'bald', 'bare', 'barefaced'],
    'straightjacket': ['oregon boat', 'bilbo', 'bond', 'bonds', 'bridle', 'camisole', 'chains', 'collar', 'cuffs', 'fetter', 'gag', 'gyves'],
    'straightlaced': ['dour', 'firm', 'fundamentalist', 'hard', 'hidebound', 'impliable', 'inexorable', 'inflexible', 'iron', 'ironbound', 'ironclad', 'ironhanded'],
    'strain': ['spenserian stanza', 'abrade', 'affectation', 'affiliation', 'agitation', 'aim', 'air', 'all-overs', 'anacrusis', 'ancestry', 'angst', 'animal kingdom'],
    'strained': ['herculean', 'agitated', 'all-overish', 'anxious', 'anxioused up', 'apprehensive', 'arduous', 'artificial', 'awkward', 'backbreaking', 'biased', 'bothered'],
    'strainer': ['clarifier', 'colander', 'cradle', 'cribble', 'cribriformity', 'cribrosity', 'filter', 'honeycomb', 'lixiviator', 'net', 'percolator', 'porosity'],
    'straining': ['bloat', 'bloating', 'bolting', 'breaking point', 'cautious', 'clarification', 'colature', 'coloring', 'confabulation', 'corruption', 'demurring', 'destructive distillation'],
    'strait': ['angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'arm', 'armlet', 'bay', 'bayou', 'belt', 'bight', 'bind', 'boca'],
    'straiten': ['arrest', 'bottle up', 'bound', 'box in', 'box up', 'bridle', 'cabin', 'casket', 'check', 'cloister', 'closet', 'coffin'],
    'straitened': ['lenten', 'spartan', 'abstemious', 'ascetic', 'austere', 'badly off', 'bound', 'bounded', 'conditioned', 'confined', 'copyrighted', 'cramped'],
    'straitjacket': ['oregon boat', 'anchor', 'bilbo', 'bind', 'bond', 'bonds', 'bridle', 'camisole', 'chain', 'chains', 'collar', 'cuffs'],
    'straitlaced': ['quakerish', 'sabbatarian', 'victorian', 'authoritarian', 'bigot', 'bigoted', 'borne', 'censorious', 'closed', 'constricted', 'cramped', 'creedbound'],
    'straits': ['arm', 'armlet', 'bay', 'bayou', 'belt', 'bight', 'bind', 'boca', 'broken fortune', 'clutch', 'complication', 'cove'],
    'strand': ['animal fiber', 'artificial fiber', 'bank', 'beach', 'berm', 'capillament', 'cast away', 'cilium', 'cirrus', 'coast', 'coastland', 'coastline'],
    'stranded': ['aground', 'anchored', 'beached', 'castaway', 'caught', 'chained', 'fast', 'fastened', 'fixed', 'foundered', 'grounded', 'held'],
    'strange': ['aberrant', 'able', 'abnormal', 'absurd', 'alien', 'amazing', 'anomalous', 'apart', 'astonishing', 'astounding', 'atypical', 'barbarian'],
    'strangeness': ['kern', 'nmr', 'aberration', 'abnormality', 'absurdity', 'alienation', 'alpha particle', 'anomaly', 'antibaryon', 'anticness', 'antilepton', 'antimeson'],
    'stranger': ['jim crow', 'uitlander', 'alien', 'apartheid', 'auslander', 'barbarian', 'color bar', 'deracine', 'displaced person', 'division', 'emigre', 'ethnocentrism'],
    'strangle': ['od', 'abbreviate', 'asphyxiate', 'bang', 'bar', 'barricade', 'batten', 'batten down', 'be killed', 'behead', 'block', 'block up'],
    'strangled': ['blurred', 'brassy', 'brazen', 'breathy', 'choked', 'choking', 'clamped', 'coarse', 'compressed', 'concentrated', 'condensed', 'consolidated'],
    'stranglehold': ['oregon boat', 'arrest', 'arrestation', 'arrestment', 'bear hug', 'bilbo', 'blockage', 'blocking', 'bond', 'bonds', 'bridle', 'camisole'],
    'strangler': ['cain', 'jack ketch', 'apache', 'assassin', 'assassinator', 'beheader', 'bloodletter', 'bloodshedder', 'bravo', 'burker', 'butcher', 'button man'],
    'strangling': ['asphyxia', 'asphyxiation', 'beheading', 'burking', 'burning', 'capital punishment', 'censorship', 'choke', 'choking', 'constrictive', 'contrary', 'counterproductive'],
    'strangulated': ['blank', 'blind', 'blind-alley', 'cecal', 'choked', 'choked off', 'clamped', 'closed', 'compressed', 'concentrated', 'condensed', 'consolidated'],
    'strangulation': ['abbreviation', 'abolishment', 'abolition', 'annihilation', 'annulment', 'asphyxia', 'asphyxiation', 'astriction', 'astringency', 'bar', 'barrier', 'beheading'],
    'strap': ['mystik tape', 'scotch tape', 'aculeate', 'acuminate', 'adhesive tape', 'anchor', 'band', 'bandage', 'barb', 'baste', 'bastinado', 'bathe'],
    'straphanger': ['adventurer', 'alpinist', 'astronaut', 'camper', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser', 'excursionist', 'explorer', 'fare'],
    'strapless': ['clothesless', 'decollete', 'disrobed', 'en deshabille', 'garbless', 'garmentless', 'half-clothed', 'in dishabille', 'low-cut', 'nudish', 'raimentless', 'topless'],
    'strapped': ['badly off', 'beat', 'beggared', 'bound', 'broke', 'busted', 'destitute', 'distressed', 'down to bedrock', 'embarrassed', 'feeling the pinch', 'fettered'],
    'strapping': ['adipose', 'bastinado', 'basting', 'battery', 'beating', 'beefy', 'belting', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'bouncing'],
    'stratagem': ['action', 'ad hoc measure', 'alibi', 'answer', 'apology', 'art', 'artful dodge', 'artifice', 'bag of tricks', 'blind', 'bluff', 'bosey'],
    'strategic': ['machiavellian', 'machiavellic', 'acute', 'arch', 'arranged', 'artful', 'astute', 'blueprinted', 'cagey', 'calculated', 'canny', 'cardinal'],
    'strategist': ['machiavellian', 'architect', 'behind-the-scenes operator', 'calculator', 'contriver', 'designer', 'developer', 'deviser', 'eminence grise', 'enterpriser', 'entrepreneur', 'finagler'],
    'strategy': ['aerial tactics', 'airborne tactics', 'applied tactics', 'approach', 'armored tactics', 'arrangement', 'art', 'artful dodge', 'artifice', 'attack', 'barrier tactics', 'blind'],
    'stratification': ['analysis', 'arrangement', 'cataloging', 'categorization', 'classification', 'codification', 'delamination', 'desquamation', 'division', 'exfoliation', 'filing', 'flakiness'],
    'stratified': ['assorted', 'cataloged', 'classified', 'filed', 'filmy', 'foliaceous', 'foliated', 'graded', 'grouped', 'hierarchic', 'in layers', 'indexed'],
    'stratosphere': ['appleton layer', 'cat', 'f layer', 'heaviside-kennelly layer', 'olympian heights', 'van allen belt', 'acme', 'aerial heights', 'aerospace', 'aerosphere', 'air hole', 'air pocket'],
    'stratum': ['appleton layer', 'f layer', 'heaviside-kennelly layer', 'van allen belt', 'band', 'bed', 'bedding', 'belt', 'blood', 'bracket', 'branch', 'caste'],
    'stratus': ['cloudcuckooland', 'alto-cumulus', 'alto-stratus', 'anvil cloud', 'banner cloud', 'billowy cloud', 'cap cloud', 'cirro-cumulus', 'cirro-fillum', 'cirro-nebula', 'cirro-stratus', 'cirro-velum'],
    'straw': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'adjutage', 'afterglow', 'afterimage', 'air', 'anthrophore', 'aureate', 'auric'],
    'straw boss': ['big brother', 'auditor', 'boatswain', 'boss', 'chief', 'comptroller', 'controller', 'floor manager', 'floorman', 'floorwalker', 'foreman', 'gaffer'],
    'straw vote': ['australian ballot', 'hare system', 'aye', 'ballot', 'barometer', 'canvass', 'canvassing', 'casting vote', 'counting heads', 'cumulative voting', 'deciding vote', 'division'],
    'strawberry mark': ['birthmark', 'blackhead', 'blaze', 'bleb', 'blemish', 'blister', 'blotch', 'brand', 'bulla', 'caste mark', 'check', 'checkmark'],
    'strawhat': ['broadway', 'burlesque', 'carnival', 'circus', 'drama', 'entertainment industry', 'legit', 'legitimate stage', 'off broadway', 'off-off-broadway', 'playland', 'repertory drama'],
    'stray': ['arab', 'abandoned', 'aberrant', 'aberrative', 'abnormal', 'accidental', 'aimless', 'amorphous', 'anomalistic', 'anomalous', 'bat around', 'be absent'],
    'straying': ['wanderjahr', 'aberrancy', 'aberrant', 'aberration', 'abnormal', 'abroad', 'adrift', 'afoot and lighthearted', 'all abroad', 'all off', 'all wrong', 'amiss'],
    'streak': ['x ray', 'actinic ray', 'actinism', 'animus', 'antelope', 'aptitude', 'arrow', 'atomic beam', 'atomic ray', 'band', 'bar', 'beam'],
    'streaked': ['banded', 'barred', 'brinded', 'brindle', 'brindled', 'cancellated', 'crossbarred', 'filigreed', 'grated', 'gridded', 'laced', 'lacelike'],
    'streaking': ['band', 'bar', 'belt', 'crack', 'craze', 'cross-hatching', 'dash', 'delineation', 'diagonal', 'dotted line', 'hachure', 'hairline'],
    'stream': ['brownian movement', 'x ray', 'zeitgeist', 'abound', 'abundance', 'actinic ray', 'actinism', 'advance', 'affluence', 'afflux', 'affluxion', 'air current'],
    'stream of consciousness': ['association', 'association by contiguity', 'association of ideas', 'chain of thought', 'clang association', 'controlled association', 'current of thought', 'flow of thought', 'free association', 'identification', 'inmost thoughts', 'mental linking'],
    'streamer': ['dannebrog', 'jolly roger', 'old glory', 'star-spangled banner', 'stars and stripes', 'union flag', 'union jack', 'x ray', 'actinic ray', 'actinism', 'and blue', 'atomic beam'],
    'streaming': ['affluent', 'aglow', 'ascending', 'axial', 'back', 'back-flowing', 'backward', 'bagging', 'baggy', 'beaming', 'beamy', 'blinding'],
    'streamline': ['air line', 'axis', 'beeline', 'boil down', 'chord', 'diagonal', 'diameter', 'direct line', 'directrix', 'distill', 'edge', 'great-circle course'],
    'streamlined': ['a la mode', 'advanced', 'aerodynamic', 'arrowlike', 'automated', 'avant-garde', 'compact', 'contemporary', 'curved', 'curvilinear', 'dead straight', 'direct'],
    'streamliner': ['amtrak', 'baggage train', 'cable railroad', 'choo-choo', 'cog railroad', 'cog railway', 'el', 'electric', 'electric train', 'elevated', 'express', 'express train'],
    'streamlining': ['clarification', 'disentanglement', 'disinvolvement', 'distillation', 'easing', 'expediting', 'expedition', 'facilitation', 'hastening', 'narrowing', 'purification', 'quickening'],
    'street': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'street arab': ['arab', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'dogie', 'gamin', 'gamine', 'guttersnipe', 'hobo'],
    'street fight': ['action', 'aerial combat', 'affray', 'armored combat', 'battle', 'battle royal', 'brush', 'bullfight', 'clash', 'clash of arms', 'cockfight', 'combat'],
    'streetcar line': ['branch', 'cable railway', 'cog railway', 'el', 'electric railway', 'elevated', 'elevated railway', 'embankment', 'feeder', 'feeder line', 'gravity-operated railway', 'horse railway'],
    'streetfighter': ['battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'combatant', 'competitor', 'contender'],
    'streetwalker': ['b-girl', 'cyprian', 'paphian', 'bawd', 'call girl', 'cruiser', 'daughter of joy', 'erring sister', 'fallen woman', 'fille de joie', 'harlot', 'hooker'],
    'streetwise': ['alive to', 'appreciative of', 'apprised of', 'awake to', 'aware of', 'behind the curtain', 'behind the scenes', 'cognizant of', 'conscious of', 'hep to', 'in the know', 'in the secret'],
    'strength': ['ability', 'amount', 'amperage', 'ampleness', 'amplitude', 'aptitude', 'arm', 'armipotence', 'asset', 'authoritativeness', 'authority', 'backbone'],
    'strengthen': ['accelerate', 'accrue', 'accumulate', 'add to', 'advance', 'affirm', 'aggravate', 'animate', 'anneal', 'appreciate', 'attest', 'augment'],
    'strengthened': ['accelerated', 'aggrandized', 'amplified', 'augmented', 'backed', 'beefed-up', 'bloated', 'boosted', 'broadened', 'calcified', 'callous', 'calloused'],
    'strengthener': ['advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'bearer', 'bra', 'brace', 'bracer'],
    'strengthening': ['accelerando', 'acceleration', 'affirmation', 'aggravation', 'analeptic', 'attestation', 'authentication', 'backing', 'backing up', 'bearing out', 'beefing-up', 'blowing up'],
    'strengthless': ['anemic', 'asthenic', 'bloodless', 'chicken', 'cowardly', 'debilitated', 'drooping', 'droopy', 'dull', 'effete', 'etiolated', 'faint'],
    'strenuous': ['herculean', 'active', 'arduous', 'breathless', 'burdensome', 'demanding', 'determined', 'difficult', 'dogged', 'dynamic', 'eager', 'earnest'],
    'strenuously': ['actively', 'animatedly', 'ardently', 'arduously', 'assiduously', 'bec et ongles', 'briskly', 'con brio', 'difficultly', 'diligently', 'effortfully', 'energetically'],
    'strep throat': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'streptococcus': ['adenovirus', 'aerobe', 'aerobic bacteria', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'bacillus', 'bacteria', 'bacterium', 'bug', 'coccus', 'echovirus'],
    'stress': ['alexandrine', 'accent', 'accentuate', 'accentuation', 'ache', 'aching', 'adverse circumstances', 'adversity', 'affliction', 'aggravation', 'ambivalence', 'ambivalence of impulse'],
    'stressed': ['accented', 'accentuated', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad'],
    'stressful': ['adverse', 'antagonistic', 'conflicting', 'contrary', 'counter', 'counteractive', 'detrimental', 'difficult', 'draining', 'exhausting', 'fatiguesome', 'fatiguing'],
    'stretch': ['adaptability', 'adaptable', 'adaptive', 'add to', 'aesthetic distance', 'aggrandize', 'airing', 'amble', 'amplify', 'amplitude', 'and quarter', 'answer'],
    'stretch out': ['adjourn', 'be lengthy', 'be prolonged', 'belong', 'carry', 'carry out', 'chatter', 'continue', 'cover', 'crane', 'dawdle', 'defer'],
    'stretch the truth': ['aggrandize', 'amplify', 'ballyhoo', 'be untruthful', 'build up', 'burlesque', 'caricature', 'carry too far', 'deceive', 'draw the longbow', 'equivocate', 'exaggerate'],
    'stretched': ['aggrandized', 'amplified', 'ballyhooed', 'disproportionate', 'dragged out', 'drawn', 'drawn out', 'elongated', 'exaggerated', 'excessive', 'exorbitant', 'extended'],
    'stretched out': ['deltoid', 'dragged out', 'drawn', 'drawn out', 'drawn-out', 'elongated', 'extended', 'fan-shape', 'fan-shaped', 'fanlike', 'fanned', 'fanning'],
    'stretcher bearer': ['aquarius', 'ganymede', 'hebe', 'bearer', 'bheesty', 'busboy', 'caddie', 'cargo handler', 'carrier', 'carrier pigeon', 'carter', 'common carrier'],
    'stretching': ['aggrandizement', 'amplification', 'ballyhoo', 'big talk', 'bloat', 'bloatedness', 'bloating', 'blowing up', 'breaking point', 'burlesque', 'caricature', 'diastole'],
    'stretchy': ['adaptable', 'adaptive', 'anesthetized', 'bouncy', 'buoyant', 'cataleptic', 'comatose', 'doped', 'dozy', 'dreamy', 'drowsy', 'drugged'],
    'strew': ['bestrew', 'broadcast', 'circulate', 'circumfuse', 'cover', 'deal out', 'diffract', 'diffuse', 'dispense', 'disperse', 'dispread', 'disseminate'],
    'striate': ['band', 'bar', 'bespangle', 'bespeckle', 'bespot', 'blaze', 'blaze a trail', 'blemish', 'blotch', 'brand', 'canal', 'canalize'],
    'striated': ['banded', 'barred', 'brinded', 'brindle', 'brindled', 'canaliculate', 'canaliculated', 'chamfered', 'channeled', 'corduroy', 'corduroyed', 'corrugate'],
    'striation': ['band', 'bar', 'belt', 'bezel', 'chamfer', 'chase', 'chink', 'corrugation', 'crack', 'cranny', 'craze', 'cross-hatching'],
    'stricken': ['affected', 'agonized', 'broken', 'broken-down', 'brokenhearted', 'crushed', 'cut up', 'dashed', 'deep-troubled', 'demoralized', 'desolate', 'desolated'],
    'strict': ['sabbatarian', 'spartan', 'spartanic', 'absolute', 'absolutist', 'absolutistic', 'accurate', 'arbitrary', 'aristocratic', 'arrogant', 'aspersion', 'astringent'],
    'strictly': ['absolutely', 'accurately', 'austerely', 'conscientiously', 'dead', 'definitely', 'directly', 'even', 'exactingly', 'exactly', 'expressly', 'exquisitely'],
    'strictness': ['sabbatarianism', 'absoluteness', 'accommodation', 'accord', 'accordance', 'accuracy', 'acquiescence', 'adaptation', 'adaption', 'adjustment', 'agreement', 'attention to detail'],
    'stricture': ['abbreviation', 'adverse criticism', 'anathema', 'animadversion', 'arraignment', 'arrest', 'arrestation', 'arrestment', 'aspersion', 'astriction', 'astringency', 'bad notices'],
    'stride': ['abut on', 'aesthetic distance', 'amble', 'ambulate', 'ankle', 'barge', 'be based on', 'bear on', 'bestraddle', 'bestride', 'bowl along', 'bundle'],
    'stridency': ['acerbity', 'acidity', 'acridity', 'acrimony', 'acuteness', 'arguteness', 'astringency', 'bite', 'bitterness', 'causticity', 'creakiness', 'edge'],
    'strident': ['absonant', 'acid', 'acidulous', 'acrid', 'acrimonious', 'astringent', 'atonal', 'biting', 'bitter', 'blatant', 'boisterous', 'cacophonous'],
    'stridor': ['acuteness', 'arguteness', 'atonalism', 'atonality', 'cacophony', 'clinker', 'creakiness', 'discord', 'discordance', 'discordancy', 'disharmony', 'dissonance'],
    'stridulation': ['animal noise', 'bark', 'barking', 'birdcall', 'call', 'chirk', 'chirking', 'chirp', 'chirrup', 'clang', 'creak', 'crick'],
    'strife': ['kilkenny cats', 'altercation', 'animosity', 'antagonism', 'arguing', 'argument', 'bad blood', 'bicker', 'bickering', 'blood feud', 'brawl', 'broil'],
    'strigose': ['banded', 'barbellate', 'barred', 'brinded', 'brindle', 'brindled', 'bristled', 'bristling', 'bristly', 'glochidiate', 'hairy', 'hirsute'],
    'strike': ['abbreviate', 'abridge', 'administer', 'adopt', 'advance against', 'advance upon', 'affect', 'afflict', 'aggravated assault', 'aggression', 'agree on', 'aim'],
    'strike a balance': ['accommodate', 'adjust', 'amortize', 'average', 'average out', 'avoid extremes', 'balance', 'balance the books', 'be conservative', 'be heavy', 'be moderate', 'be pacifistic'],
    'strike a bargain': ['accommodate', 'adjust', 'agree', 'agree on', 'agree on terms', 'agree to', 'agree with', 'bargain for', 'be a bargain', 'be a deal', 'be a go', 'be on'],
    'strike home': ['affect', 'come home to', 'evoke a response', 'get a reaction', 'get a response', 'hit', 'hit a nerve', 'hit home', 'hit the mark', 'impress', 'impress forcibly', 'make an impression'],
    'strike off': ['abbreviate', 'abridge', 'abscind', 'abstract', 'ad-lib', 'amputate', 'annihilate', 'ban', 'bar', 'blot out', 'blue-pencil', 'bob'],
    'strike out': ['abbreviate', 'abridge', 'abstract', 'be off', 'bear', 'bear for', 'bear up for', 'bear up to', 'beget', 'blot', 'blot out', 'blue-pencil'],
    'strikebreaker': ['apostate', 'backslider', 'blackleg', 'bolter', 'collaborationist', 'collaborator', 'convert', 'defector', 'deserter', 'fifth columnist', 'fink', 'mugwump'],
    'striking': ['abbreviation', 'abridgment', 'acid', 'agitating', 'amazing', 'appalling', 'armipotent', 'arrant', 'arresting', 'astonishing', 'astounding', 'authoritative'],
    'string': ['a string', 'amati', 'cremona', 'd string', 'e string', 'g string', 'indian file', 'strad', 'stradivari', 'stradivarius', 'age group', 'agree'],
    'string along': ['act with', 'align with', 'bamboozle', 'bedog', 'beguile', 'betray', 'blarney', 'bluff', 'butter', 'butter up', 'cajole', 'chase'],
    'string out': ['align', 'array', 'bank', 'chatter', 'continue', 'drag out', 'draw', 'draw out', 'elongate', 'extend', 'fill out', 'lengthen'],
    'string quartet': ['german band', 'nachtmusik', 'philharmonic', 'absolute music', 'adaptation', 'air varie', 'aleatory', 'aleatory music', 'arrangement', 'band', 'big band', 'brass'],
    'stringency': ['spartanism', 'acerbity', 'acidity', 'acridity', 'acrimony', 'astringency', 'austerity', 'authoritarianism', 'bite', 'bitterness', 'causticity', 'chinchiness'],
    'stringent': ['spartan', 'spartanic', 'acid', 'acidulous', 'acrid', 'acrimonious', 'astringent', 'austere', 'authoritarian', 'binding', 'biting', 'bitter'],
    'strings': ['byzantine intrigues', 'german band', 'philharmonic', 'backstairs influence', 'band', 'big band', 'brass', 'brass band', 'brass choir', 'brass quintet', 'brass section', 'brasses'],
    'stringy': ['adhesive', 'amylaceous', 'besprinkle', 'capillary', 'cartilaginous', 'chewy', 'cirrose', 'cirrous', 'clabbered', 'clammy', 'clotted', 'coagulated'],
    'strip': ['mystik tape', 'scotch tape', 'abscind', 'adhesive tape', 'airstrip', 'amputate', 'annihilate', 'apron', 'ban', 'band', 'bandage', 'bandeau'],
    'stripe': ['hershey bar', 'animus', 'aptitude', 'aviation badge', 'badge', 'band', 'bandeau', 'bar', 'baste', 'bastinado', 'beat', 'belabor'],
    'striped': ['banded', 'barred', 'brinded', 'brindle', 'brindled', 'cancellated', 'crossbarred', 'filigreed', 'grated', 'gridded', 'laced', 'lacelike'],
    'stripling': ['young turk', 'adolescent', 'arriviste', 'baby', 'boy', 'bright young man', 'comer', 'fledgling', 'hobbledehoy', 'hopeful', 'infant', 'junior'],
    'stripped': ['bared', 'beggared', 'beggarly', 'bereaved', 'bereaved of', 'bereft', 'cut off', 'denudated', 'denuded', 'deprived', 'deprived of', 'disadvantaged'],
    'stripper': ['analyzer', 'artist', 'artiste', 'bareness', 'belly dancer', 'birthday suit', 'breaker', 'burlesque queen', 'centrifuge', 'chorine', 'chorus boy', 'chorus girl'],
    'striptease': ['act', 'afterpiece', 'bit', 'chaser', 'curtain', 'curtain call', 'curtain raiser', 'disrobement', 'disrobing', 'divertimento', 'divertissement', 'epilogue'],
    'stripteaser': ['artist', 'artiste', 'bareness', 'belly dancer', 'birthday suit', 'burlesque queen', 'chorine', 'chorus boy', 'chorus girl', 'conjurer', 'coryphee', 'dancer'],
    'strive': ['agonize', 'aim', 'aim to', 'assay', 'attempt', 'attempt to', 'battle', 'be determined', 'box', 'brawl', 'broil', 'buffet'],
    'strive against': ['antagonize', 'battle', 'beat against', 'beat up against', 'breast the wave', 'buck', 'buffet', 'buffet the waves', 'challenge', 'close with', 'combat', 'compete with'],
    'striving': ['aim', 'ambition', 'animus', 'aspiration', 'battling', 'combat', 'competition', 'conflict', 'contending', 'contestant', 'contesting', 'counsel'],
    'stroke': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'abuse', 'access', 'accomplished fact', 'accomplishment', 'ache', 'achievement', 'aching', 'act', 'acta'],
    'stroll': ['airing', 'amble', 'andante', 'barge', 'bat around', 'bowl along', 'bum', 'bundle', 'claudicate', 'claudication', 'clump', 'constitutional'],
    'stroller': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'roscius', 'ulysses', 'actor', 'actress'],
    'strolling': ['ambling', 'ambulant', 'ambulation', 'ambulative', 'ambulatory', 'backpacking', 'cautious', 'circuit-riding', 'circumforaneous', 'circumspect', 'claudicant', 'crawling'],
    'strolling player': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'roscius', 'ulysses', 'actor', 'actress'],
    'strong': ['draconian', 'able', 'able-bodied', 'accented', 'acid', 'acrid', 'active', 'acute', 'adamantine', 'affluent', 'aggressive', 'aggressively'],
    'strong arm': ['amperage', 'argumentum baculinum', 'arm', 'armipotence', 'authority', 'battler', 'beef', 'belligerent', 'belted knight', 'bickerer', 'black power', 'blackjack'],
    'strong in': ['acquainted with', 'adept in', 'at home in', 'at home with', 'conversant with', 'expert at', 'familiar with', 'good at', 'handy at', 'informed in', 'intimate with', 'master of'],
    'strong language': ['bad language', 'billingsgate', 'bite', 'bitingness', 'blue language', 'colorful language', 'cursing', 'cussing', 'cuttingness', 'dirty language', 'dirty talk', 'drive'],
    'strong man': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'goliath', 'hercules', 'polyphemus', 'samson', 'superman', 'tarzan'],
    'strong minded': ['bright', 'conceptive', 'conceptual', 'controlled', 'discursive', 'firm-minded', 'forward', 'ideational', 'importunate', 'independent', 'intellectual', 'intelligent'],
    'strong point': ['ability', 'acropolis', 'area', 'bag', 'bastion', 'beachhead', 'blockhouse', 'bridgehead', 'bump', 'bunker', 'caliber', 'capability'],
    'strong room': ['fort knox', 'bank', 'bursary', 'cash register', 'cashbox', 'chest', 'coffer', 'coin box', 'depository', 'exchequer', 'fisc', 'gold depository'],
    'strong willed': ['balking', 'balky', 'beefy', 'bigoted', 'bouncing', 'bulldogged', 'bulletheaded', 'bullheaded', 'case-hardened', 'controlled', 'dogged', 'dogmatic'],
    'strongbox': ['fort knox', 'bank', 'bursary', 'cash register', 'cashbox', 'chest', 'coffer', 'coin box', 'depository', 'exchequer', 'fisc', 'gold depository'],
    'stronghold': ['acropolis', 'asylum', 'bastion', 'beachhead', 'bird sanctuary', 'blockhouse', 'bridgehead', 'bulwark', 'bunker', 'castle', 'citadel', 'donjon'],
    'strop': ['mystik tape', 'scotch tape', 'aculeate', 'acuminate', 'adhesive tape', 'band', 'bandage', 'barb', 'batten', 'belt', 'cellophane tape', 'cloth tape'],
    'strophe': ['spenserian stanza', 'antistrophe', 'book', 'burden', 'canto', 'chorus', 'couplet', 'distich', 'envoi', 'epode', 'heptastich', 'hexastich'],
    'structural': ['adjectival', 'adverbial', 'anatomic', 'architectonic', 'architectural', 'attributive', 'building', 'conjunctive', 'constructional', 'copulative', 'correct', 'descriptive'],
    'structure': ['dymaxion house', 'ic analysis', 'platonic form', 'platonic idea', 'white house', 'action', 'adobe house', 'aesthetic form', 'anagnorisis', 'anatomy', 'angle', 'appositive'],
    'structuring': ['allocation', 'allotment', 'anatomy', 'apportionment', 'architectonics', 'architecture', 'arrangement', 'array', 'arraying', 'assemblage', 'assembly', 'build'],
    'strudel': ['danish pastry', 'french pastry', 'baklava', 'blintz', 'chocolate eclair', 'cream puff', 'dowdy', 'eclair', 'pandowdy', 'pastry', 'pasty', 'patisserie'],
    'struggle': ['kilkenny cats', 'action', 'aerial combat', 'affray', 'agonize', 'aim', 'altercation', 'argument', 'armored combat', 'assay', 'attempt', 'battle'],
    'struggle against': ['antagonize', 'battle', 'beat against', 'beat up against', 'breast the wave', 'buck', 'buffet', 'buffet the waves', 'close with', 'combat', 'compete with', 'contend against'],
    'struggle with': ['a outrance', 'bandy with', 'battle', 'battle it out', 'bump heads', 'contend with', 'cope with', 'cross swords with', 'engage with', 'exchange shots', 'fight like devils', 'fight with'],
    'struggler': ['battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'combatant', 'competitor', 'contender'],
    'struggling': ['battling', 'contending', 'contestant', 'contesting', 'disputant', 'drudging', 'fighting', 'grinding', 'grubbing', 'hardworking', 'laboring', 'pegging'],
    'strumpet': ['jezebel', 'bad woman', 'baggage', 'bitch', 'broad', 'chippy', 'clitoromaniac', 'cocotte', 'coquette', 'drab', 'easy lay', 'easy woman'],
    'strung out': ['addicted', 'addicted to', 'asleep', 'cataleptic', 'catatonic', 'cold', 'comatose', 'dead', 'dependent', 'dependent on', 'doped', 'dragged out'],
    'strut': ['amble', 'barge', 'bounce', 'bowl along', 'brave show', 'bundle', 'clump', 'drag', 'droop', 'flaunt', 'flounce', 'foot'],
    'stub': ['thule', 'ultima thule', 'billhead', 'bitter end', 'book stamp', 'bookplate', 'bottom dollar', 'boundary', 'brand', 'broad arrow', 'brush', 'butt'],
    'stubble': ['vandyke', 'afterglow', 'afterimage', 'balance', 'barb', 'barbel', 'beard', 'beaver', 'bones', 'bristle', 'bristles', 'butt'],
    'stubbled': ['barbellate', 'bearded', 'bewhiskered', 'bristled', 'bristling', 'bristly', 'glochidiate', 'hairy', 'hirsute', 'hispid', 'setaceous', 'setose'],
    'stubborn': ['adamant', 'adamantine', 'adherent', 'adhesive', 'assiduous', 'balking', 'balky', 'bigoted', 'bulldogged', 'bulldoggish', 'bulldoggy', 'bulletheaded'],
    'stubbornness': ['adhesiveness', 'antipathy', 'application', 'assiduity', 'assiduousness', 'averseness', 'aversion', 'backwardness', 'balkiness', 'bigotry', 'bulldog tenacity', 'bullheadedness'],
    'stubby': ['blocky', 'chubby', 'chunky', 'dumpy', 'fat', 'heavyset', 'podgy', 'pudgy', 'pug', 'pugged', 'retrousse', 'snub-nosed'],
    'stuck': ['addled', 'adhering', 'agglutinate', 'aground', 'anchored', 'at a loss', 'at a nonplus', 'at a stand', 'at a standstill', 'at an impasse', 'baffled', 'bamboozled'],
    'stuck on': ['attached to', 'crazy about', 'devoted to', 'enamored of', 'far gone on', 'fond of', 'gone on', 'hipped on', 'in love with', 'mad about', 'nuts about', 'partial to'],
    'stuck up': ['aggressively self-confident', 'arrogant', 'big', 'biggety', 'bumptious', 'chesty', 'cocky', 'conceited', 'condescending', 'domineering', 'haughty', 'high-faluting'],
    'stud': ['houyhnhnm', 'ass', 'band', 'bar', 'bastard', 'bespangle', 'bespeckle', 'bespot', 'besprinkle', 'bilge', 'billy', 'billy goat'],
    'studbook': ['almanach de gotha', 'red book', 'royal kalendar', 'social register', 'atlas', 'blue book', 'calendar', 'casebook', 'catalog', 'catalogue raisonne', 'city directory', 'classified catalog'],
    'studded': ['ablaze', 'adorned', 'aglow', 'alight', 'alive with', 'barbellate', 'bathed with light', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled'],
    'student': ['academician', 'admirer', 'apprentice', 'bookman', 'classicist', 'clerk', 'colossus of knowledge', 'commentator', 'critic', 'devotee', 'disciple', 'evaluator'],
    'studied': ['gongoresque', 'gongoristic', 'marinistic', 'advised', 'affected', 'aforethought', 'aimed', 'aimed at', 'artificial', 'calculated', 'conscious', 'considered'],
    'studio': ['am station', 'fm station', 'rdf station', 'agency', 'atelier', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'butcher shop', 'clear-channel station', 'company'],
    'studious': ['absorbed', 'absorbed in', 'abstruse', 'academic', 'advised', 'aforethought', 'assiduous', 'attentive', 'autodidactic', 'bookish', 'buried in', 'careful'],
    'study': ['nachtmusik', 'pap test', 'walter mitty', 'absence of mind', 'absolute music', 'absorbed attention', 'absorption', 'abstractedness', 'abstraction', 'academic discipline', 'academic specialty', 'adaptation'],
    'stuff': ['abilities', 'accessories', 'accomplishments', 'addictive drug', 'air', 'aliment', 'allay', 'anhydrate', 'atom', 'atomic particles', 'atoms', 'attitude'],
    'stuff and nonsense': ['absurdity', 'absurdness', 'amphigory', 'babble', 'babblement', 'balderdash', 'bibble-babble', 'blabber', 'blather', 'bombast', 'claptrap', 'double-talk'],
    'stuffed': ['sro', 'allayed', 'awash', 'bloated', 'blocked', 'bound', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full'],
    'stuffiness': ['quakerishness', 'thi', 'airlessness', 'antiquation', 'aridity', 'aridness', 'authoritarianism', 'barrenness', 'bigotry', 'blind side', 'blind spot', 'blinders'],
    'stuffing': ['apician', 'abdomen', 'all-devouring', 'anhydration', 'anus', 'appendix', 'blast-freezing', 'blind gut', 'bolting', 'bonus', 'bottling', 'bowels'],
    'stuffy': ['quakerish', 'victorian', 'accordant', 'airless', 'anal', 'arid', 'arrogant', 'authoritarian', 'bad', 'bad-smelling', 'barren', 'bigot'],
    'stultify': ['annul', 'asphyxiate', 'befool', 'bottle up', 'bring to nothing', 'buffer', 'cancel', 'cancel out', 'censor', 'check', 'choke off', 'clamp down on'],
    'stumble': ['bad job', 'balk', 'barge', 'be all thumbs', 'bevue', 'blunder', 'blunder away', 'blunder into', 'blunder on', 'blunder upon', 'bobble', 'boggle'],
    'stumble upon': ['alight upon', 'arrive at', 'arrive upon', 'blunder upon', 'bump into', 'chance upon', 'come across', 'come at', 'come on', 'come up against', 'come upon', 'discover serendipitously'],
    'stumblebum': ['blunderbuss', 'blunderer', 'bungler', 'butterfingers', 'clumsy', 'dub', 'duffer', 'foozler', 'foul-up', 'fumble-fist', 'goof', 'goofball'],
    'stumbling block': ['bar', 'block', 'blockade', 'bottleneck', 'catch', 'cordon', 'curtain', 'determent', 'deterrent', 'difficulty', 'drawback', 'hamper'],
    'stump': ['thule', 'ultima thule', 'addle', 'address', 'afterglow', 'afterimage', 'air brush', 'amaze', 'amble', 'art paper', 'baffle', 'balance'],
    'stumped': ['addled', 'at a loss', 'at a nonplus', 'at a stand', 'at a standstill', 'at an impasse', 'baffled', 'bamboozled', 'beat', 'bewildered', 'buffaloed', 'confounded'],
    'stumper': ['chinese puzzle', 'baffling problem', 'brain twister', 'campaigner', 'crossword puzzle', 'crux', 'electioneer', 'enigma', 'enigmatic question', 'floorer', 'jigsaw puzzle', 'knot'],
    'stumps': ['ankle', 'bayonet legs', 'bowlegs', 'calf', 'cnemis', 'drumstick', 'foreleg', 'gamb', 'gambrel', 'gigot', 'ham', 'hind leg'],
    'stumpy': ['bandy', 'bandy-legged', 'blemished', 'bloated', 'blocky', 'bowlegged', 'cash', 'chubby', 'chunky', 'club-footed', 'couchant', 'crouched'],
    'stun': ['ko', 'amaze', 'anesthetize', 'appall', 'astonish', 'astound', 'awake the dead', 'awe', 'awestrike', 'bedaze', 'bedazzle', 'bemuse'],
    'stunned': ['aghast', 'appalled', 'ashen', 'astounded', 'awed', 'awestricken', 'awestruck', 'blanched', 'cowed', 'dazed', 'deadly pale', 'deaf'],
    'stunner': ['miss america', 'amazement', 'astonishing thing', 'astonishment', 'bathing beauty', 'beau ideal', 'beaut', 'beauty', 'beauty contest winner', 'beauty queen', 'belle', 'bunny'],
    'stunning': ['ok', 'ace-high', 'amazing', 'analgesic', 'anesthetic', 'astonishing', 'astounding', 'attractive', 'bad', 'bang-up', 'beaming', 'beauteous'],
    'stunt': ['abbreviate', 'abridge', 'abstract', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'acting', 'action', 'adventure', 'arrest'],
    'stunt man': ['aeronaut', 'aeroplaner', 'aeroplanist', 'air pilot', 'airplanist', 'astronaut', 'aviator', 'barnstormer', 'birdman', 'captain', 'cloud seeder', 'commercial pilot'],
    'stunted': ['lenten', 'lilliputian', 'spartan', 'tom thumb', 'abstemious', 'arrested', 'ascetic', 'austere', 'backward', 'coarse', 'crude', 'diminutive'],
    'stupa': ['antenna tower', 'arch', 'barbican', 'barrow', 'beehive tomb', 'belfry', 'bell tower', 'bone house', 'boundary stone', 'box grave', 'brass', 'burial'],
    'stupefied': ['laodicean', 'olympian', 'agape', 'aghast', 'agog', 'all agog', 'aloof', 'amazed', 'apathetic', 'appalled', 'ashen', 'astonished'],
    'stupefy': ['ko', 'addle', 'amaze', 'anesthetize', 'appall', 'astonish', 'astound', 'awe', 'awestrike', 'bedaze', 'bedazzle', 'bemuse'],
    'stupefying': ['analgesic', 'anesthetic', 'bloodcurdling', 'deadening', 'dulling', 'exceptional', 'extraordinary', 'fabulous', 'hair-raising', 'indescribable', 'ineffable', 'legendary'],
    'stupendous': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'amazing', 'amplitudinous', 'astonishing', 'astounding', 'astronomic'],
    'stupid': ['boeotian', 'absurd', 'addled', 'apish', 'asinine', 'backward', 'balmy', 'barmy', 'batty', 'beef-brained', 'beef-witted', 'beetleheaded'],
    'stupidity': ['absurdity', 'absurdness', 'act of folly', 'asininity', 'battiness', 'blockishness', 'blunder', 'boobishness', 'boorishness', 'bootlessness', 'botch', 'bovinity'],
    'stupor': ['ko', 'abstraction', 'abulia', 'acedia', 'alienation', 'aloofness', 'amnesia', 'anesthesia', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy'],
    'stuporous': ['anesthetized', 'cataleptic', 'comatose', 'doped', 'dozy', 'dreamy', 'drowsy', 'drugged', 'drugged with sleep', 'half asleep', 'heavy', 'heavy with sleep'],
    'sturdiness': ['body', 'concreteness', 'decisiveness', 'density', 'durability', 'endurance', 'energy', 'firmness', 'force', 'fortitude', 'guts', 'gutsiness'],
    'sturdy': ['adamantine', 'athletic', 'beefy', 'bouncing', 'brawny', 'bulky', 'burly', 'dense', 'determined', 'doughty', 'durable', 'enduring'],
    'stutter': ['balbuties', 'dysphemia', 'falter', 'faltering', 'halt', 'hammer', 'haw', 'hem', 'hem and haw', 'hesitate', 'hesitation', 'hum'],
    'stuttering': ['balbutient', 'balbuties', 'battology', 'ceaseless', 'ceaselessness', 'chattering', 'constancy', 'constant', 'constant flow', 'continual', 'continualness', 'continuity'],
    'sty': ['augean stables', 'sodom', 'abscess', 'amaurosis', 'aposteme', 'bed sore', 'birthmark', 'blackhead', 'blain', 'bleb', 'blemish', 'blepharitis'],
    'stygian': ['acheronian', 'acherontic', 'cimmerian', 'lethean', 'plutonian', 'plutonic', 'tartarean', 'chthonian', 'chthonic', 'clouded', 'cloudy', 'dark and gloomy'],
    'style': ['bauhaus', 'byzantine', 'corinthian', 'dadaism', 'doric', 'egyptian', 'english', 'fauvism', 'french', 'german', 'gothic', 'gothicism'],
    'styled': ['called', 'christened', 'couched', 'denominate', 'denominated', 'designated', 'dubbed', 'expressed', 'formulated', 'identified as', 'known as', 'named'],
    'stylish': ['daedalian', 'a la mode', 'adept', 'adroit', 'apt', 'artistic', 'authoritative', 'bravura', 'brilliant', 'chic', 'chichi', 'classy'],
    'stylist': ['dadaist', 'fauvist', 'action painter', 'actionist', 'activist', 'classicist', 'conventionalist', 'costume designer', 'couturier', 'cubist', 'designer', 'divisionist'],
    'stylistics': ['affectation', 'command of language', 'exaggeration', 'expression of ideas', 'fashion', 'feeling for words', 'form of speech', 'grace of expression', 'grandiloquence', 'inflation', 'literary style', 'manner'],
    'stylus': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'stymie': ['block', 'brake', 'confound', 'deadlock', 'defeat', 'flummox', 'foil', 'frustrate', 'halt', 'hinder', 'impede', 'nonplus'],
    'styptic': ['alum', 'astringent', 'clamp', 'collapsible', 'compactable', 'compressible', 'compressor', 'constrictor', 'constringent', 'consumptive', 'contractible', 'contractile'],
    'suasive': ['authoritative', 'cajoling', 'charismatic', 'charming', 'consequential', 'effective', 'effectual', 'efficacious', 'enchanting', 'estimable', 'exhortative', 'exhortatory'],
    'suave': ['affable', 'agreeable', 'bland', 'buttery', 'charming', 'civilized', 'cordial', 'cosmopolitan', 'courteous', 'courtly', 'cultivated', 'cultured'],
    'sub': ['u-boat', 'u-boot', 'unterseeboot', 'act for', 'agent', 'alternate', 'alternative', 'analogy', 'backup', 'change', 'change places with', 'changeling'],
    'sub rosa': ['behind the curtain', 'behind the scenes', 'behind the veil', 'by stealth', 'covertly', 'furtively', 'hugger-mugger', 'in a corner', 'in a whisper', 'in camera', 'in darkness', 'in hidlings'],
    'subaltern': ['adc', 'co', 'od', 'aide', 'aide-de-camp', 'brigadier', 'brigadier general', 'captain', 'chicken colonel', 'chief of staff', 'cog', 'colonel'],
    'subatomic': ['atomatic', 'atomic', 'atomiferous', 'atomistic', 'corpuscular', 'cyclic', 'diatomic', 'dibasic', 'embryonic', 'evanescent', 'germinal', 'granular'],
    'subaudible': ['barely audible', 'decrescendo', 'dim', 'distant', 'echoless', 'faint', 'faint-voiced', 'feeble', 'gentle', 'half-heard', 'hush as death', 'hushed'],
    'subclass': ['biotype', 'branch', 'class', 'family', 'genotype', 'genus', 'kingdom', 'order', 'phylum', 'section', 'series', 'species'],
    'subconscious': ['freudian', 'anima', 'coconscious', 'collective unconscious', 'conscience', 'conscious self', 'death instinct', 'deep-rooted', 'deepest mind', 'ego', 'ego ideal', 'ego-id conflict'],
    'subcutaneous': ['cortical', 'cutaneous', 'dermal', 'dermic', 'ecderonic', 'ectodermal', 'ectodermic', 'endermatic', 'endermic', 'epicarpal', 'epidermal', 'epidermic'],
    'subdeb': ['beau brummel', 'arbiter of fashion', 'babe', 'baby', 'broad', 'chick', 'clotheshorse', 'clubman', 'clubwoman', 'colleen', 'cutie', 'dame'],
    'subdivide': ['alphabetize', 'analyze', 'anatomize', 'apportion', 'arrange', 'assay', 'assort', 'bifurcate', 'bisect', 'branch', 'break down', 'break up'],
    'subdivision': ['abstraction', 'adjunct', 'alienation', 'analysis', 'analyzation', 'anatomizing', 'anatomy', 'arrangement', 'assay', 'assaying', 'assembly-line housing', 'bifidity'],
    'subdual': ['cadmean victory', 'ko', 'pyrrhic victory', 'waterloo', 'ascendancy', 'beating', 'breaking', 'censorship', 'championship', 'collapse', 'conquering', 'conquest'],
    'subdue': ['abate', 'allay', 'alleviate', 'anesthetize', 'appease', 'asphyxiate', 'assuage', 'attemper', 'baffle', 'bank the fire', 'bear down', 'beat down'],
    'subdued': ['attic', 'olympian', 'aesthetic', 'aloof', 'artistic', 'backward', 'barely audible', 'bashful', 'bated', 'blank', 'bowed-down', 'broken'],
    'subduer': ['champ', 'champion', 'conquering hero', 'conqueror', 'conquistador', 'defeater', 'easy winner', 'hero', 'master', 'pancratiast', 'runner-up', 'shoo-in'],
    'subduing': ['cadmean victory', 'ko', 'pyrrhic victory', 'waterloo', 'abating', 'allaying', 'alleviating', 'alleviative', 'analgesic', 'anesthetic', 'anodyne', 'ascendancy'],
    'subgroup': ['adjunct', 'blood', 'bracket', 'branch', 'caste', 'category', 'clan', 'class', 'component', 'contingent', 'cross section', 'detachment'],
    'subhead': ['banner', 'banner head', 'caption', 'drop head', 'dropline', 'epigraph', 'hanger', 'head', 'head up', 'heading', 'headline', 'jump head'],
    'subhuman': ['draconian', 'tartarean', 'animal', 'animalian', 'animalic', 'animalistic', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'beastlike', 'beastly'],
    'subject': ['ic analysis', 'above', 'academic specialty', 'action', 'actor', 'affair', 'agent', 'anagnorisis', 'angle', 'answerable to', 'application', 'appositive'],
    'subject matter': ['argument', 'basis', 'burden', 'case', 'chapter', 'concern', 'essence', 'focus of attention', 'focus of interest', 'gist', 'head', 'heading'],
    'subject to': ['according as', 'answerable for', 'apt to', 'based on', 'boxed in', 'capable of', 'circumscribed by', 'contingent', 'contingent on', 'dependent', 'dependent on', 'depending'],
    'subjection': ['acceptance', 'acquiescence', 'assent', 'back seat', 'complaisance', 'compliance', 'conquest', 'consent', 'deference', 'domination', 'enslavement', 'homage'],
    'subjective': ['abstract', 'biased', 'cerebral', 'conceptive', 'conceptual', 'deep-seated', 'egocentric', 'egoistic', 'endopsychic', 'esoteric', 'idiosyncratic', 'immanent'],
    'subjoin': ['add', 'adjoin', 'affix', 'agglutinate', 'annex', 'append', 'attach', 'burden', 'complicate', 'conjoin', 'decorate', 'encumber'],
    'subjoinder': ['parthian shot', 'address', 'affirmation', 'allegation', 'answer', 'apostrophe', 'assertion', 'averment', 'comment', 'crack', 'declaration', 'dictum'],
    'subjugate': ['adopt', 'appropriate', 'arrogate', 'assume', 'bear down', 'beat down', 'bend', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate'],
    'subjugated': ['bond', 'broken', 'captive', 'conquered', 'crushed', 'disenfranchised', 'enslaved', 'enthralled', 'felled', 'flattened', 'humbled', 'in bondage'],
    'subjugation': ['waterloo', 'absolutism', 'adoption', 'appropriation', 'arrogation', 'assumption', 'beating', 'bond service', 'bondage', 'captivity', 'collapse', 'colonization'],
    'sublease': ['adverse possession', 'alodium', 'bareboat charter', 'burgage', 'charter', 'claim', 'colony', 'de facto', 'de jure', 'dependency', 'derivative title', 'farm'],
    'sublet': ['charter', 'chartered', 'employed', 'farm', 'farm out', 'hire', 'hire out', 'hired', 'hireling', 'job', 'lease', 'lease out'],
    'sublimate': ['aerate', 'aerify', 'alluvion', 'alluvium', 'alter', 'ash', 'atomize', 'bolt', 'carbonate', 'channel', 'chlorinate', 'cinder'],
    'sublimation': ['aeration', 'aerification', 'alienation', 'atomization', 'autism', 'autistic thinking', 'avoidance mechanism', 'blame-shifting', 'block', 'blocking', 'bolting', 'clarification'],
    'sublime': ['elysian', 'olympian', 'abstract', 'aerate', 'aerial', 'aerify', 'aggrandize', 'aggrandized', 'airy', 'altitudinous', 'apotheosized', 'ascending'],
    'submarine': ['aqua-lung', 'u-boat', 'u-boot', 'unterseeboot', 'air cylinder', 'aquascope', 'bathyscaphe', 'bathysphere', 'benthoscope', 'buried', 'diving bell', 'diving boat'],
    'submerge': ['baptize', 'break water', 'bury', 'camouflage', 'cave', 'cave in', 'cloak', 'conceal', 'decline', 'deluge', 'descend', 'dip'],
    'submerged': ['awash', 'bathed', 'behind the curtain', 'behind the scenes', 'between the lines', 'buried', 'camouflaged', 'concealed', 'covert', 'cryptic', 'debased', 'delitescent'],
    'submerged in': ['absorbed', 'absorbed in', 'buried in', 'caught up in', 'contemplating', 'contemplative', 'devoted', 'devoted to', 'engaged', 'engrossed', 'engrossed in', 'enmeshed in'],
    'submergence': ['baptism', 'breaking water', 'burial', 'cadence', 'catenary', 'concavity', 'crash dive', 'de-escalation', 'debasement', 'decline', 'decurrence', 'degradation'],
    'submerging': ['collapsing', 'deciduous', 'declining', 'declivitous', 'decurrent', 'descendant', 'descending', 'down', 'down-reaching', 'downcoming', 'downfalling', 'downgoing'],
    'submersion': ['absorbed attention', 'absorption', 'affusion', 'alluvion', 'alluvium', 'application', 'aspergation', 'aspersion', 'baptism', 'bath', 'bathing', 'bedewing'],
    'submission': ['ok', 'quakerism', 'acceptance', 'accord', 'acquiescence', 'advance', 'affirmation', 'affirmative', 'affirmative voice', 'agreement', 'allegiance', 'amenability'],
    'submissive': ['abject', 'abused', 'accepting', 'accommodating', 'accordant', 'acquiescent', 'acquiescing', 'adaptable', 'adapting', 'adaptive', 'adjustable', 'adjusting'],
    'submit': ['accede', 'accede to', 'accept', 'acquiesce', 'advance', 'advise', 'advocate', 'affirm', 'agree to', 'allege', 'announce', 'annunciate'],
    'submittal': ['acceptance', 'acquiescence', 'assent', 'complaisance', 'compliance', 'consent', 'deference', 'homage', 'kneeling', 'nonopposal', 'nonopposition', 'nonresistance'],
    'subnormal': ['aberrant', 'abnormal', 'amorphous', 'anomalistic', 'anomalous', 'arrested', 'babbling', 'backward', 'blithering', 'burbling', 'crackbrained', 'cracked'],
    'suborder': ['biotype', 'blood', 'bracket', 'branch', 'caste', 'category', 'clan', 'class', 'division', 'estate', 'family', 'genotype'],
    'subordinate': ['accessory', 'adjuvant', 'aide', 'assistant', 'assort', 'auxiliary', 'below', 'beneath', 'bolt', 'categorize', 'classify', 'client'],
    'subordination': ['assortment', 'back seat', 'categorization', 'continuity', 'culling', 'degree', 'gradation', 'grouping', 'hierarchy', 'humbleness', 'humility', 'inferiority'],
    'subplot': ['action', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'argument', 'atmosphere', 'background', 'catastrophe', 'characterization', 'color', 'complication'],
    'subpoena': ['bid come', 'call', 'call away', 'call back', 'call for', 'call forth', 'call in', 'call out', 'call together', 'call up', 'certiorari', 'citation'],
    'subscribe': ['abet', 'accede', 'accept', 'acquiesce', 'advocate', 'agree', 'agree to', 'agree with', 'aid and abet', 'allow', 'approve', 'approve of'],
    'subscribe to': ['ok', 'abide by', 'accede', 'accept', 'acclaim', 'accredit', 'acquiesce', 'acquiesce in', 'affirm', 'agree', 'agree to', 'agree with'],
    'subscriber': ['maecenas', 'santa claus', 'almoner', 'almsgiver', 'angel', 'approver', 'assignor', 'awarder', 'backer', 'bestower', 'certifier', 'cheerful giver'],
    'subscript': ['ps', 'parthian shot', 'addendum', 'afterthought', 'appendix', 'back matter', 'chorus', 'coda', 'codicil', 'colophon', 'conclusion', 'consequence'],
    'subscription': ['john hancock', 'ok', 'acceptance', 'accommodation', 'accordance', 'affirmance', 'affirmation', 'alms', 'alms fee', 'approbation', 'approval', 'authentication'],
    'subsequent': ['after', 'appendant', 'attendant', 'cadet', 'consecutive', 'consequent', 'consequential', 'ensuing', 'following', 'future', 'junior', 'later'],
    'subsequently': ['after', 'after all', 'after that', 'afterward', 'afterwards', 'behind', 'by and by', 'ex post facto', 'in the aftermath', 'in the sequel', 'infra', 'later'],
    'subserve': ['act for', 'advance', 'assist', 'be found wanting', 'be inferior', 'be instrumental', 'come short', 'conduce to', 'contribute to', 'decide', 'determine', 'facilitate'],
    'subservience': ['abjectness', 'agreeability', 'agreeableness', 'back seat', 'baseness', 'biddability', 'compliableness', 'docility', 'ductility', 'facility', 'flexibility', 'helotism'],
    'subservient': ['abject', 'accepting', 'accessory', 'acquiescent', 'adjuvant', 'agential', 'agentival', 'agentive', 'agreeable', 'ancillary', 'appurtenant', 'assenting'],
    'subside': ['abate', 'ablate', 'advance', 'ascend', 'back', 'back up', 'bate', 'be eaten away', 'budge', 'calm', 'calm down', 'cave'],
    'subsidence': ['avalanche', 'cadence', 'catabasis', 'catenary', 'cessation', 'coast', 'collapse', 'crash', 'dead set', 'dead stand', 'dead stop', 'deadlock'],
    'subsidiary': ['accessory', 'accident', 'accidental', 'addendum', 'addition', 'additional', 'adjunct', 'adjuvant', 'adscititious', 'adventitious', 'ancillary', 'appendage'],
    'subsiding': ['at rest', 'calm', 'cloistered', 'collapsing', 'coming apart', 'contractive', 'cool', 'cracking', 'crumbling', 'decadent', 'deciduous', 'declining'],
    'subsidize': ['accommodate', 'afford', 'afford support', 'aid', 'angel', 'assist', 'back', 'back up', 'bankroll', 'bear', 'bear out', 'bear up'],
    'subsidy': ['tlc', 'accouterment', 'aid', 'alimony', 'allotment', 'allowance', 'annuity', 'armament', 'assistance', 'backing', 'bounty', 'bread'],
    'subsist': ['abide', 'be', 'be alive', 'be animate', 'be extant', 'be found', 'be in existence', 'be left', 'be met with', 'be present', 'be the case', 'be there'],
    'subsistence': ['lenten', 'spartan', 'tlc', 'abstemious', 'accommodation', 'accommodations', 'aliment', 'alimentation', 'alimony', 'ascetic', 'austere', 'bed'],
    'subsoil': ['acres', 'alluvion', 'alluvium', 'arable land', 'clay', 'clod', 'crust', 'dirt', 'dry land', 'dust', 'earth', 'freehold'],
    'substance': ['swiss bank account', 'actuality', 'affective meaning', 'affluence', 'air', 'amount', 'amplitude', 'assets', 'atom', 'atomic particles', 'atoms', 'axiom'],
    'substantial': ['ab ovo', 'able to pay', 'absolute', 'abundant', 'actual', 'adequate', 'affluent', 'allegorical', 'ample', 'appreciable', 'ascendant', 'associational'],
    'substantiality': ['abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'aplomb', 'authenticity', 'authoritativeness', 'authority', 'avalanche', 'balance', 'balanced personality'],
    'substantially': ['actually', 'adequately', 'all in all', 'almost entirely', 'amply', 'approximately', 'at bottom', 'at heart', 'at the core', 'au fond', 'basically', 'by and large'],
    'substantiate': ['adduce', 'affirm', 'anatomize', 'assay', 'atomize', 'attest', 'authenticate', 'back', 'back up', 'bear out', 'body', 'bolster'],
    'substantiated': ['actual', 'ascertained', 'attested', 'authenticated', 'borne out', 'categorically true', 'certain', 'certified', 'circumstantiated', 'confirmed', 'corroborated', 'demonstrated'],
    'substantive': ['ab ovo', 'abstract noun', 'adherent noun', 'adjectival', 'adverbial', 'appreciable', 'attributive', 'basal', 'basic', 'bedrock', 'central', 'collective noun'],
    'substitute': ['additional', 'advocate', 'agent', 'alter ego', 'alternate', 'alternative', 'amicus curiae', 'analogy', 'another', 'attorney', 'backup', 'backup man'],
    'substitute for': ['act for', 'answer for', 'appear for', 'back up', 'change places with', 'commission', 'crowd out', 'cut out', 'deputize', 'displace', 'double for', 'fill in for'],
    'substitution': ['agent', 'alienation', 'alternate', 'alternative', 'amends', 'analogy', 'atonement', 'autism', 'autistic thinking', 'avoidance mechanism', 'backup', 'balancing'],
    'substratum': ['air', 'atom', 'atomic particles', 'band', 'base', 'basement', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock', 'belly'],
    'substructure': ['base', 'basement', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock', 'bottom', 'floor', 'flooring', 'fond', 'footing'],
    'subsume': ['affect', 'assume', 'bring', 'call for', 'comprehend', 'comprise', 'contain', 'embody', 'embrace', 'encompass', 'entail', 'have'],
    'subtend': ['bump heads', 'confront', 'contend', 'contrapose', 'contraposit', 'contrast', 'counteract', 'face', 'front', 'lie opposite', 'match', 'meet head-on'],
    'subterfuge': ['airtight secrecy', 'alibi', 'apology', 'art', 'artful dodge', 'artifice', 'bag of tricks', 'bamboozlement', 'befooling', 'bickering', 'blind', 'bluff'],
    'subtile': ['byzantine', 'machiavellian', 'machiavellic', 'acute', 'adulterated', 'air-built', 'airy', 'arch', 'artful', 'astute', 'attenuate', 'attenuated'],
    'subtilize': ['adulterate', 'analyze', 'attenuate', 'contradistinguish', 'cut', 'demarcate', 'demark', 'dematerialize', 'differentiate', 'dilute', 'discriminate', 'disembody'],
    'subtitle': ['acknowledgments', 'back', 'back matter', 'banner', 'banner head', 'bastard title', 'bibliography', 'caption', 'catch line', 'catchword', 'colophon', 'contents'],
    'subtle': ['byzantine', 'machiavellian', 'machiavellic', 'abstruse', 'accurate', 'acute', 'adulterated', 'air-built', 'airy', 'analytic', 'analytical', 'appreciative'],
    'subtlety': ['italian hand', 'absoluteness', 'accuracy', 'acquired taste', 'acuteness', 'airiness', 'airy nothing', 'animal cunning', 'apparent soundness', 'appreciation', 'appreciation of differences', 'appreciation of excellence'],
    'subtract': ['abate', 'abrade', 'abrupt', 'abstract', 'add', 'algebraize', 'alienate', 'bate', 'calculate', 'cast', 'cast off', 'cast out'],
    'subtracted': ['absconded', 'absent', 'away', 'deleted', 'departed', 'disappeared', 'gone', 'lacking', 'missing', 'no longer present', 'nonattendant', 'nonexistent'],
    'subtraction': ['abatement', 'abridgment', 'absence', 'abstraction', 'addition', 'alienation', 'alleviation', 'approximation', 'attenuation', 'awayness', 'blank', 'contraction'],
    'subtropical': ['aestival', 'blood-hot', 'blood-warm', 'calid', 'equatorial', 'genial', 'luke', 'lukewarm', 'mild', 'room-temperature', 'summery', 'sunny'],
    'subtropics': ['antarctic zone', 'arctic circle', 'arctic zone', 'frigid zones', 'torrid zone', 'tropic of cancer', 'tropic of capricorn', 'variable zones', 'climate', 'clime', 'equator', 'furnace'],
    'suburb': ['stadt', 'banlieue', 'boom town', 'borough', 'bourg', 'burg', 'burgh', 'city', 'conurbation', 'exurb', 'exurbia', 'faubourg'],
    'suburban': ['ambient', 'average', 'bourgeois', 'burghal', 'circling', 'circumambient', 'circumferential', 'circumflex', 'circumfluent', 'circumfluous', 'circumjacent', 'citified'],
    'suburbanite': ['big-city man', 'bourgeois', 'burgess', 'burgher', 'city dweller', 'city man', 'city slicker', 'exurbanite', 'oppidan', 'townee', 'towner', 'townfolk'],
    'suburbia': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'middle america', 'stadt', 'west end', 'west side', 'banlieue', 'barrio'],
    'suburbs': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'alentours', 'ambience', 'ambit', 'barrio'],
    'subvention': ['tlc', 'accouterment', 'aid', 'alimony', 'allotment', 'allowance', 'annuity', 'armament', 'assistance', 'backing', 'bounty', 'bread'],
    'subversion': ['alienation', 'answer', 'bloodless revolution', 'bouleversement', 'brainwashing', 'breakdown', 'breakup', 'capsizal', 'capsize', 'cataclysm', 'catastrophe', 'clean slate'],
    'subversionary': ['baneful', 'calamitous', 'cataclysmal', 'cataclysmic', 'catastrophic', 'consuming', 'consumptive', 'deadly', 'demolishing', 'demolitionary', 'depredatory', 'desolating'],
    'subversive': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'cong', 'fenian', 'guevarist'],
    'subvert': ['accommodate', 'adapt', 'adjust', 'alienate', 'alter', 'ameliorate', 'answer', 'answer conclusively', 'argue down', 'arise', 'better', 'brainwash'],
    'subway': ['amtrak', 'abri', 'antre', 'baggage train', 'branch', 'bunker', 'burrow', 'cable railroad', 'cable railway', 'cave', 'cavern', 'choo-choo'],
    'subzero': ['siberian', 'algid', 'arctic', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'boreal', 'brisk', 'brumal', 'cold'],
    'succeed': ['accomplish', 'achieve', 'act for', 'advance', 'arrive', 'attain', 'attend', 'be a gas', 'be a hit', 'be a success', 'be blooded', 'be successful'],
    'succeeding': ['after', 'appendant', 'assured of success', 'attendant', 'cadet', 'coming', 'consecutive', 'consequent', 'crowned with success', 'ensuing', 'following', 'fortunate'],
    'success': ['cadmean victory', 'easy street', 'grand guignol', 'ko', 'passion play', 'pyrrhic victory', 'tom show', 'accomplished fact', 'accomplishment', 'achievement', 'affluence', 'antimasque'],
    'successful': ['affluent', 'ascendant', 'assured of success', 'bang', 'booming', 'celebrated', 'comfortable', 'comfortably situated', 'coming', 'conquering', 'crowned with success', 'defeating'],
    'succession': ['indian file', 'accession', 'affiliation', 'afterlife', 'alternation', 'ancestry', 'anointing', 'anointment', 'apparentation', 'appointment', 'array', 'arrogation'],
    'successive': ['after', 'alternating', 'appendant', 'attendant', 'cadet', 'catenary', 'consecutive', 'consequent', 'continual', 'continuous', 'ensuing', 'following'],
    'successor': ['adherent', 'aftermath', 'apparent heir', 'appendage', 'attendant', 'backup man', 'beneficiary heir', 'buff', 'cavaliere servente', 'conclusion', 'consequence', 'coparcener'],
    'succinct': ['spartan', 'abbreviated', 'abridged', 'aphoristic', 'aposiopestic', 'axiomatic', 'blunt', 'brief', 'brusque', 'clipped', 'close', 'compact'],
    'succor': ['abet', 'aid', 'alterative', 'analeptic', 'assist', 'assistance', 'avail', 'bail out', 'balm', 'balsam', 'bear a hand', 'befriend'],
    'succubus': ['baba yaga', 'dracula', 'frankenstein', 'lilith', 'satan', 'wolf-man', 'afreet', 'barghest', 'bogey', 'bogeyman', 'bugaboo', 'bugbear'],
    'succulent': ['agreeable', 'algae', 'ambrosial', 'autophyte', 'baccate', 'bean', 'bracken', 'brown algae', 'climber', 'comestible', 'conferva', 'confervoid'],
    'succumb': ['abandon', 'accede', 'accept', 'acquiesce', 'assent', 'be agreeable', 'be done for', 'be lost', 'be no more', 'bite the dust', 'black out', 'blow'],
    'such': ['aforementioned', 'aforesaid', 'akin', 'alike', 'ally', 'alter ego', 'analogon', 'analogous', 'analogue', 'associate', 'brother', 'close copy'],
    'suchlike': ['akin', 'alike', 'ally', 'alter ego', 'analogon', 'analogous', 'analogue', 'associate', 'brother', 'close copy', 'close match', 'cognate'],
    'suck': ['apple-polisher', 'aspirate', 'aspiration', 'ass-licker', 'backscratcher', 'backslapper', 'beverage', 'bib', 'bleed', 'bootlick', 'bootlicker', 'booze'],
    'suck dry': ['ablate', 'absorb', 'abuse', 'assimilate', 'bleed', 'bleed white', 'burn up', 'consume', 'denude', 'deplete', 'deplume', 'despoil'],
    'suck in': ['absorb', 'allure', 'aspirate', 'bait', 'bait the hook', 'beguile', 'betray', 'bib', 'bitch', 'blandish', 'booze', 'breathe in'],
    'suck up to': ['act up to', 'agree to anything', 'approach', 'break the ice', 'brown-nose', 'court', 'cultivate', 'curry favor', 'dance attendance on', 'fall all over', 'fall over', 'fawn upon'],
    'sucked dry': ['acarpous', 'arid', 'barren', 'celibate', 'childless', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'exhausted', 'fallow'],
    'sucker': ['babe', 'barnacle', 'beat', 'bilk', 'bine', 'bloodsucker', 'boob', 'bough', 'branch', 'branchedness', 'branchiness', 'burgeon'],
    'sucker for': ['addict', 'bug', 'collector', 'demon', 'eager beaver', 'energumen', 'enthusiast', 'faddist', 'fanatic', 'fiend', 'freak', 'great one for'],
    'suckle': ['aliment', 'aspirate', 'bib', 'booze', 'breast-feed', 'breathe in', 'care for', 'cherish', 'coddle', 'cosset', 'cradle', 'cultivate'],
    'suckling': ['babe', 'baby', 'baby bunting', 'bambino', 'incubator baby', 'infant', 'little angel', 'little darling', 'mewling infant', 'neonate', 'nursling', 'papoose'],
    'suction': ['aspiration', 'bleeding', 'bloodletting', 'broaching', 'cupping', 'drafting', 'drag', 'drainage', 'draining', 'drawing', 'emptying', 'favor'],
    'sudden': ['aback', 'abrupt', 'abruptly', 'accelerated', 'breakneck', 'breathless', 'brisk', 'electrifying', 'expeditious', 'extraordinary', 'fast', 'fleet'],
    'sudden thought': ['automatic response', 'blind impulse', 'brain wave', 'brainstorm', 'drive', 'fancy', 'flash', 'fleeting impulse', 'gut response', 'impulse', 'inspiration', 'instinct'],
    'suddenly': ['a corps perdu', 'aback', 'abruptly', 'all at once', 'bang', 'by surprise', 'dash', 'feverishly', 'fleetingly', 'forthwith', 'hastily', 'head over heels'],
    'suddenness': ['abruptness', 'alacrity', 'expeditiousness', 'feverishness', 'furiousness', 'haste', 'hastiness', 'hurriedness', 'impatience', 'impetuosity', 'impetuousness', 'impulsiveness'],
    'sudorific': ['ardent', 'baking', 'bathed in sweat', 'beaded with sweat', 'blistering', 'boiling', 'broiling', 'burning', 'burning hot', 'canicular', 'clammy', 'diaphoretic'],
    'suds': ['aerate', 'barmy beer', 'beat', 'beer', 'blues', 'breakers', 'collar', 'court', 'cream', 'dinge', 'dumps', 'foam'],
    'sue': ['address', 'angle for', 'apply to', 'beau', 'bid for', 'bring action against', 'bring into court', 'bring suit', 'bring to justice', 'bring to trial', 'call on', 'call upon'],
    'suffer': ['abide', 'abide with', 'accept', 'ache', 'acquiesce', 'admit', 'agonize', 'ail', 'allow', 'anguish', 'be affected with', 'be doubly punished'],
    'sufferance': ['acceptance', 'allowance', 'authorization', 'connivance', 'consent', 'endurance', 'forbearance', 'forbearing', 'forbearingness', 'fortitude', 'indulgence', 'leave'],
    'sufferer': ['apoplectic', 'arthritic', 'case', 'consumptive', 'dyspeptic', 'epileptic', 'incurable', 'inpatient', 'invalid', 'martyr', 'object of compassion', 'outpatient'],
    'suffering': ['schmerz', 'ache', 'aches and pains', 'aching', 'admissive', 'adversity', 'afflicted', 'affliction', 'agonized', 'agony', 'allowing', 'blow'],
    'suffice': ['advantage', 'answer', 'avail', 'be equal to', 'be handy', 'be of use', 'be satisfactory', 'bear', 'benefit', 'bestead', 'do', 'do it'],
    'sufficiency': ['ability', 'ableness', 'acceptability', 'adequacy', 'adequateness', 'admissibility', 'agreeability', 'caliber', 'capability', 'capableness', 'capacity', 'competence'],
    'sufficient': ['ok', 'acceptable', 'adequacy', 'adequate', 'admissible', 'agreeable', 'all right', 'ample', 'authoritative', 'barely sufficient', 'better than nothing', 'binding'],
    'suffix': ['ic analysis', 'ps', 'parthian shot', 'accidence', 'add', 'addendum', 'addition', 'adjoin', 'affix', 'affixation', 'afterthought', 'agglutinate'],
    'suffocate': ['od', 'asphyxiate', 'bake', 'bar', 'barricade', 'be in heat', 'be killed', 'blaze', 'block', 'block up', 'blockade', 'bloom'],
    'suffocating': ['airless', 'breathless', 'breezeless', 'censorship', 'close', 'crackdown', 'crushing', 'extinguishment', 'humid', 'ill-ventilated', 'muggy', 'nose-piercing'],
    'suffocation': ['abolishment', 'abolition', 'annihilation', 'annulment', 'asphyxia', 'asphyxiation', 'burking', 'choke', 'choking', 'choking off', 'deracination', 'drowning'],
    'suffrage': ['australian ballot', 'hare system', 'association', 'aye', 'ballot', 'canvass', 'canvassing', 'casting vote', 'choice', 'cochairmanship', 'complicity', 'condominium'],
    'suffuse': ['bathe', 'bespread', 'besprinkle', 'breathe', 'brew', 'color', 'cover', 'crawl with', 'creep with', 'decoct', 'diffuse', 'dredge'],
    'suffusion': ['blush', 'blushing', 'coloring', 'crimsoning', 'decoction', 'diffusion', 'flush', 'flushing', 'imbuement', 'impregnation', 'infiltration', 'infusion'],
    'sugar': ['ambrosia', 'angel', 'artificial sweetener', 'babe', 'baby', 'baby-doll', 'blackstrap', 'blunt', 'boodle', 'brass', 'bread', 'bucks'],
    'sugar daddy': ['casanova', 'don juan', 'lothario', 'maecenas', 'romeo', 'santa claus', 'almoner', 'almsgiver', 'amoroso', 'angel', 'assignor', 'awarder'],
    'sugary': ['ambrosial', 'bittersweet', 'candied', 'honeyed', 'honeysweet', 'melliferous', 'mellifluent', 'mellifluous', 'nectareous', 'nectarous', 'sacchariferous', 'sour-sweet'],
    'suggest': ['adumbrate', 'advance', 'advert', 'advise', 'advocate', 'allegorize', 'allude', 'allude to', 'ape', 'appear like', 'approach', 'approve'],
    'suggestible': ['accessible', 'amenable', 'fictile', 'impressible', 'impressionable', 'influenceable', 'malleable', 'movable', 'open', 'open-minded', 'persuadable', 'persuasible'],
    'suggestion': ['admonition', 'advice', 'advising', 'advocacy', 'allegory', 'allusion', 'arcane meaning', 'ascendancy', 'aspersion', 'assumption', 'authority', 'bare suggestion'],
    'suggestive': ['absolute', 'adducible', 'admissible', 'allegorical', 'allusive', 'allusory', 'associational', 'attestative', 'attestive', 'authentic', 'based on', 'bawdy'],
    'suggestive of': ['alike', 'aped', 'consimilar', 'copied', 'counterfeit', 'ersatz', 'fake', 'favoring', 'following', 'homogeneous', 'identical', 'imitated'],
    'sui generis': ['another', 'beyond compare', 'beyond comparison', 'breakaway', 'easily first', 'else', 'facile princeps', 'immortal', 'incomparable', 'inimitable', 'invincible', 'matchless'],
    'suicidal': ['baneful', 'bloodthirsty', 'bloody', 'bloody-minded', 'bowed-down', 'calamitous', 'cast down', 'cataclysmal', 'cataclysmic', 'catastrophic', 'consuming', 'consumptive'],
    'suicide': ['aborticide', 'car of jagannath', 'disembowelment', 'felo-de-se', 'fratricide', 'fungicide', 'genocide', 'germicide', 'hara-kiri', 'herbicide', 'homicide', 'infanticide'],
    'suit': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'accommodate', 'accommodate with', 'accord', 'accouter', 'accusal', 'accusation'],
    'suitability': ['ability', 'acceptability', 'admissibility', 'advantage', 'advantageousness', 'advisability', 'applicability', 'appositeness', 'appropriateness', 'aptitude', 'aptness', 'auspiciousness'],
    'suitable': ['a propos', 'acceptable', 'according to hoyle', 'ad rem', 'adapted', 'adequate', 'admissible', 'advantageous', 'advisable', 'ample', 'applicable', 'apposite'],
    'suitable for': ['accommodated to', 'according to', 'adapted to', 'adjusted to', 'after', 'agreeable to', 'agreeably to', 'answerable to', 'by', 'conformable to', 'congruent with', 'consistent with'],
    'suite': ['acid rock', 'adapted', 'apartment', 'array', 'attendance', 'attendant', 'attendants', 'avant-garde jazz', 'ballroom music', 'batch', 'battery', 'bebop'],
    'suited': ['a propos', 'able', 'ad rem', 'adapted', 'adjusted', 'applicable', 'apposite', 'appropriate', 'apropos', 'apt', 'au fait', 'becoming'],
    'suitor': ['accessory', 'accusant', 'accuser', 'addict', 'admirer', 'adorer', 'allegator', 'amorist', 'appellant', 'applicant', 'asker', 'aspirant'],
    'sukkah': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'ark', 'asperger', 'asperges', 'aspergillum', 'bambino', 'beadroll'],
    'sulfonate': ['acetify', 'acidify', 'acidulate', 'alkalify', 'alkalize', 'borate', 'carbonate', 'catalyze', 'chemical', 'chlorinate', 'electrolyze', 'ferment'],
    'sulfurous': ['acherontic', 'lethean', 'plutonian', 'plutonic', 'stygian', 'tartarean', 'alabastrine', 'asbestine', 'bad', 'bad-smelling', 'chthonian', 'chthonic'],
    'sulks': ['antipathy', 'averseness', 'aversion', 'backwardness', 'blahs', 'blue devils', 'blues', 'cursoriness', 'disagreement', 'disinclination', 'dismals', 'disobedience'],
    'sullen': ['antisocial', 'at odds', 'autistic', 'averse', 'bad-tempered', 'balking', 'balky', 'bashful', 'beetle-browed', 'bigoted', 'black', 'black-browed'],
    'sullied': ['bedraggled', 'befouled', 'besmirched', 'defiled', 'dirtied', 'drabbled', 'draggled', 'fouled', 'impure', 'indecent', 'maculate', 'smirched'],
    'sully': ['abuse', 'attaint', 'bedaub', 'befoul', 'benasty', 'besmear', 'besmirch', 'besmutch', 'besoil', 'bespatter', 'betray', 'black'],
    'sultanate': ['ally', 'archduchy', 'archdukedom', 'body politic', 'buffer state', 'caliphate', 'captive nation', 'chieftaincy', 'chieftainry', 'city-state', 'colony', 'commonweal'],
    'sultry': ['fescennine', 'rabelaisian', 'airless', 'baking', 'bawdy', 'blue', 'breathless', 'broiling', 'burning', 'close', 'damp', 'dirty'],
    'sum': ['account', 'add', 'add up', 'addend', 'affective meaning', 'aggregate', 'all', 'amount', 'amount of money', 'amplitude', 'batch', 'be-all and end-all'],
    'sum up': ['abbreviate', 'abridge', 'abstract', 'add up', 'battologize', 'bob', 'boil down', 'capsulize', 'cast up', 'cipher up', 'clip', 'compress'],
    'summarily': ['pdq', 'abruptly', 'apace', 'aphoristically', 'at once', 'briefly', 'brusquely', 'compendiously', 'concisely', 'crisply', 'curtly', 'decisively'],
    'summarize': ['abbreviate', 'abridge', 'abstract', 'add up', 'battologize', 'bob', 'boil down', 'brief', 'capsule', 'capsulize', 'cast up', 'cipher up'],
    'summary': ['spartan', 'abbreviated', 'abbreviation', 'abridged', 'abridgement', 'abridgment', 'abrupt', 'abstract', 'account', 'accounts', 'alert', 'apocope'],
    'summation': ['abbreviation', 'abridgment', 'abstract', 'account', 'accounts', 'addend', 'aggregate', 'amount', 'apocope', 'argument', 'body count', 'box score'],
    'summer': ['aestival', 'arctic', 'autumn', 'autumnal', 'boreal', 'broiling sun', 'brumal', 'buy time', 'canicular', 'canicular days', 'consume time', 'dog days'],
    'summer school': ['alternate', 'alternative school', 'blab school', 'boarding school', 'central school', 'consolidated school', 'continuation school', 'correspondence school', 'country day school', 'dame school', 'day school', 'evening school'],
    'summer stock': ['broadway', 'burlesque', 'carnival', 'circus', 'drama', 'entertainment industry', 'legit', 'legitimate stage', 'off broadway', 'off-off-broadway', 'playland', 'repertory drama'],
    'summerhouse': ['alcove', 'arbor', 'belvedere', 'bower', 'cloche', 'cold frame', 'conservatory', 'coolhouse', 'forcing bed', 'forcing house', 'forcing pit', 'gazebo'],
    'summery': ['aestival', 'arctic', 'autumn', 'autumnal', 'beryl-green', 'berylline', 'blood-hot', 'blood-warm', 'blue-green', 'bluish-green', 'boreal', 'brumal'],
    'summing up': ['account', 'accounts', 'argument', 'body count', 'capitulation', 'census', 'copy', 'count', 'critique', 'dwelling upon', 'elaboration', 'epitome'],
    'summit': ['acme', 'acme of perfection', 'all', 'apex', 'apogee', 'audience', 'bargaining', 'bargaining session', 'brow', 'cap', 'capstone', 'ceiling'],
    'summon': ['appeal', 'arouse', 'ask', 'assemble', 'attract', 'be attractive', 'beckon', 'bid', 'bid come', 'bring forth', 'bring out', 'bring to light'],
    'summon up': ['annoy', 'arouse', 'awake', 'awaken', 'bid come', 'blow the coals', 'blow up', 'bring about', 'bring back', 'bring forth', 'bring out', 'bring to light'],
    'summons': ['angelus', 'angelus bell', 'alarm', 'alarum', 'battle cry', 'beck', 'beck and call', 'bid', 'bid come', 'biddance', 'bidding', 'birdcall'],
    'sump': ['artificial lake', 'baygall', 'bayou lake', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'cesspool', 'cistern', 'cloaca', 'cloaca maxima'],
    'sumpter': ['siberian husky', 'ass', 'beast of burden', 'bidet', 'camel', 'carriage horse', 'cart horse', 'cavalry horse', 'draft animal', 'draft horse', 'dray horse', 'driving horse'],
    'sumptuous': ['babylonian', 'corinthian', 'awe-inspiring', 'awful', 'barbaric', 'bask', 'costly', 'dazzling', 'dear', 'dear-bought', 'deluxe', 'elaborate'],
    'sun': ['amen-ra', 'apollo', 'helios', 'hyperion', 'phoebus', 'phoebus apollo', 'ra', 'savitar', 'shamash', 'sol', 'surya', 'titan'],
    'sun worship': ['druidism', 'parsiism', 'sabaism', 'zoroastrianism', 'animal worship', 'demonism', 'demonolatry', 'devil worship', 'fetishism', 'fire worship', 'heathenism', 'hero worship'],
    'sun worshiper': ['druid', 'parsi', 'sabaist', 'zoroastrian', 'animal worshiper', 'anthropolater', 'arborolater', 'archaeolater', 'chthonian', 'demon worshiper', 'demonolater', 'dendrolater'],
    'sunbaked': ['adust', 'baked', 'burnt', 'corky', 'dehydrated', 'desiccated', 'dried', 'dried-up', 'evaporated', 'exsiccated', 'mummified', 'parched'],
    'sunbeam': ['broad day', 'dawn', 'day', 'day glow', 'daylight', 'dayshine', 'daytide', 'daytime', 'dusk', 'full sun', 'green flash', 'light of day'],
    'sunbelt': ['dixie', 'dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'middle west', 'new england', 'north', 'north central region', 'northeast', 'northwest'],
    'sunburn': ['brand', 'bronze', 'brown', 'burn', 'embrown', 'infuscate', 'mat burn', 'rust', 'scald', 'scorch', 'sear', 'second-degree burn'],
    'sunburned': ['titian', 'adust', 'ashen', 'ashy', 'auburn', 'bay', 'bay-colored', 'bayard', 'blistered', 'blooming', 'blowzed', 'blowzy'],
    'sunday': ['christmas', 'first day', 'sabbath', 'church calendar', 'day of rest', 'dies non', 'ecclesiastical calendar', 'fast', 'feast', 'go on furlough', 'go on leave', 'holiday'],
    'sunday driver': ['backseat driver', 'bus driver', 'busman', 'cabby', 'cabdriver', 'chauffeur', 'driver', 'hack', 'hackdriver', 'hackman', 'hacky', 'hit-and-run driver'],
    'sunder': ['amputate', 'atomize', 'ax', 'bisect', 'break to pieces', 'break up', 'butcher', 'carve', 'chop', 'cleave', 'cut', 'cut away'],
    'sundowner': ['arab', 'bowery bum', 'mickey', 'mickey finn', 'aperitif', 'beach bum', 'beachcomber', 'beggar', 'beggarly fellow', 'blighter', 'bo', 'budmash'],
    'sundries': ['assortment', 'bric-a-brac', 'collectanea', 'conglomerate', 'conglomeration', 'cosmetics', 'frippery', 'giftware', 'hodgepodge', 'knickknacks', 'medley', 'miscellanea'],
    'sundry': ['all and sundry', 'assorted', 'different', 'divers', 'diverse', 'diversified', 'heterogeneous', 'legion', 'many', 'many and various', 'miscellaneous', 'mixed'],
    'sunglasses': ['polaroid glasses', 'bifocals', 'blinkers', 'cheaters', 'colored glasses', 'contact lens', 'dark glasses', 'divided spectacles', 'eyeglass', 'eyeglasses', 'eyeshade', 'eyeshield'],
    'sunk': ['balled up', 'blue', 'boat-shaped', 'boatlike', 'bollixed up', 'bowl-shaped', 'bowllike', 'buggered', 'buggered up', 'cast down', 'cavelike', 'cavernous'],
    'sunken': ['boat-shaped', 'boatlike', 'bowl-shaped', 'bowllike', 'buried', 'cavelike', 'cavernous', 'concave', 'concaved', 'craterlike', 'cup-shaped', 'cupped'],
    'sunless': ['stygian', 'beamless', 'black', 'black as night', 'caliginous', 'cheerless', 'dark', 'dark as night', 'dark as pitch', 'darkling', 'darksome', 'depressing'],
    'sunlight': ['broad day', 'dawn', 'day', 'day glow', 'daylight', 'dayshine', 'daytide', 'daytime', 'dusk', 'full sun', 'green flash', 'light of day'],
    'sunlit': ['ablaze', 'aglow', 'alight', 'bathed with light', 'bespangled', 'brightened', 'candlelit', 'enlightened', 'firelit', 'gaslit', 'illuminated', 'in a blaze'],
    'sunny': ['leibnizian', 'saturnian', 'aestival', 'aglow', 'balmy', 'beaming', 'beamy', 'blithe', 'blithesome', 'blood-hot', 'blood-warm', 'blushing'],
    'sunrise': ['aurora', 'break of day', 'brightening', 'cardinal points', 'chanticleer', 'cockcrow', 'cocklight', 'compass card', 'compass rose', 'crack of dawn', 'dawn', 'dawning'],
    'sunset': ['cardinal points', 'close of day', 'cockshut', 'compass card', 'compass rose', 'degrees', 'east', 'eastward', 'eve', 'even', 'evening', 'evensong'],
    'sunshade': ['awning', 'beach umbrella', 'blind', 'brolly', 'bumbershoot', 'cover', 'curtain', 'drape', 'drapery', 'gamp', 'light shield', 'parasol'],
    'sunshine': ['saturnia regna', 'saturnian age', 'age of aquarius', 'beatification', 'beatitude', 'bewitchment', 'blessedness', 'bliss', 'blissfulness', 'broad day', 'cheer', 'cheerfulness'],
    'sunshiny': ['aestival', 'aglow', 'beaming', 'beamy', 'blood-hot', 'blood-warm', 'blushing', 'bright and sunny', 'burning', 'calid', 'candescent', 'clarion'],
    'sunstroke': ['minamata disease', 'altitude sickness', 'anoxemia', 'anoxia', 'anoxic anoxia', 'anthrax', 'black lung', 'caisson disease', 'calenture', 'chilblain', 'coup de soleil', 'decompression sickness'],
    'sunup': ['aurora', 'break of day', 'brightening', 'chanticleer', 'cockcrow', 'cocklight', 'crack of dawn', 'dawn', 'dawning', 'day-peep', 'daybreak', 'daylight'],
    'sup': ['beverage', 'bib', 'bite', 'board', 'booze', 'break bread with', 'breakfast', 'bumper', 'cast', 'cook out', 'dash', 'dine'],
    'super': ['big brother', 'a cut above', 'above', 'ahead', 'ascendant', 'auditor', 'better', 'bit player', 'boatswain', 'boss', 'capping', 'chief'],
    'superabound': ['exaggerate', 'exceed', 'fill', 'flood', 'go beyond', 'know no bounds', 'luxuriate', 'overabound', 'overbrim', 'overdo', 'overflow', 'overgo'],
    'superabundance': ['abundance', 'acres', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'avalanche', 'bags', 'barrels', 'bonanza', 'bountifulness', 'bountiousness'],
    'superabundant': ['abounding', 'abundant', 'affluent', 'alive with', 'all-sufficing', 'ample', 'aplenty', 'blooming', 'bottomless', 'bounteous', 'bountiful', 'bristling'],
    'superannuate': ['abdicate', 'age', 'antiquate', 'be pensioned', 'be superannuated', 'be superseded', 'become extinct', 'become obsolete', 'boot', 'bounce', 'break', 'bump'],
    'superannuated': ['gothic', 'victorian', 'abandoned', 'abjured', 'antediluvian', 'antiquated', 'antique', 'archaic', 'classical', 'deserted', 'discontinued', 'disused'],
    'superb': ['babylonian', 'corinthian', 'admirable', 'august', 'awe-inspiring', 'awful', 'bad', 'barbaric', 'best', 'boss', 'breathtaking', 'brilliant'],
    'superbly': ['ably', 'adeptly', 'adroitly', 'agilely', 'aptly', 'artfully', 'artistically', 'brilliantly', 'capably', 'cleverly', 'competently', 'cunningly'],
    'supercharged': ['bloated', 'burdened', 'bursting', 'charged', 'choked', 'congested', 'crammed', 'crowded', 'distended', 'drenched', 'filled to overflowing', 'fraught'],
    'supercilious': ['arrogant', 'cavalier', 'clannish', 'cliquish', 'condescending', 'contemptuous', 'contumelious', 'disdainful', 'dismissive', 'exclusive', 'haughty', 'high and mighty'],
    'supercooled': ['siberian', 'air-conditioned', 'air-cooled', 'algid', 'arctic', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'boreal', 'brisk'],
    'superego': ['i myself', 'alter', 'alter ego', 'alterum', 'anima', 'better self', 'censor', 'coconscious', 'collective unconscious', 'conscience', 'conscientiousness', 'conscious self'],
    'supereminent': ['aggrandized', 'apotheosized', 'arch', 'awesome', 'banner', 'beatified', 'big', 'canonized', 'capital', 'cardinal', 'central', 'champion'],
    'supererogatory': ['de trop', 'dispensable', 'excess', 'expendable', 'expletive', 'gratuitous', 'in excess', 'needless', 'nonessential', 'pleonastic', 'prolix', 'redundant'],
    'superficial': ['airy', 'amateur', 'amateurish', 'ankle-deep', 'apparent', 'appearing', 'arid', 'asinine', 'barren', 'birdbrained', 'birdwitted', 'blah'],
    'superficiality': ['a little learning', 'absentmindedness', 'amateurism', 'apparent character', 'appearance', 'appearances', 'aridity', 'barrenness', 'big deal', 'bloodlessness', 'carelessness', 'characterlessness'],
    'superficially': ['amain', 'apace', 'apparently', 'aridly', 'as it seems', 'at first sight', 'at once', 'barrenly', 'bloodlessly', 'by forced marches', 'colorlessly', 'cursorily'],
    'superfine': ['babylonian', 'corinthian', 'awe-inspiring', 'awful', 'barbaric', 'deluxe', 'divine', 'elaborate', 'elegant', 'exquisite', 'extravagant', 'fancy'],
    'superfluity': ['abundance', 'acres', 'amenity', 'amplitude', 'bags', 'barrels', 'bedizenment', 'bravery', 'bushel', 'chiffon', 'clinquant', 'cloud of words'],
    'superfluous': ['accessory', 'accidental', 'additional', 'adscititious', 'adventitious', 'aimless', 'appurtenant', 'ascititious', 'auxiliary', 'casual', 'circumstantial', 'collateral'],
    'superheat': ['animal heat', 'blood heat', 'body heat', 'burning', 'calidity', 'caloric', 'chafe', 'coal heat', 'convected heat', 'cook', 'electric heat', 'electric-heat'],
    'superhighway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'superhuman': ['christlike', 'christly', 'herculean', 'hercules', 'amazing', 'arcane', 'brave', 'celestial', 'courageous', 'dangerous', 'daring', 'death-defying'],
    'superimpose': ['apply to', 'blanket', 'block', 'canopy', 'cloak', 'clothe', 'cloud', 'cope', 'cover', 'cover up', 'cowl', 'curtain'],
    'superincumbent': ['beetle', 'beetle-browed', 'beetling', 'bridging', 'burdensome', 'cumbersome', 'cumbrous', 'demanding', 'exacting', 'exigent', 'greater', 'grievous'],
    'superintendent': ['big brother', 'g-man', 'mp', 'administrator', 'auditor', 'bailiff', 'beadle', 'beagle', 'boatswain', 'boss', 'bound bailiff', 'captain'],
    'superior': ['a per se', 'a cut above', 'above', 'above par', 'absolute', 'ace', 'ahead', 'appalling', 'arrogant', 'ascendant', 'astonishing', 'authoritarian'],
    'superiority': ['aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'accent', 'advantage', 'advantageousness', 'agreeableness', 'amorphism', 'amperage', 'anomalism'],
    'superlative': ['olympian', 'absolute', 'accomplished', 'ace', 'aerial', 'aggrandized', 'aggrandizement', 'airy', 'altitudinous', 'amplification', 'amplified', 'arrant'],
    'superman': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'goliath', 'hercules', 'polyphemus', 'samson', 'tarzan', 'titan'],
    'supermarket': ['appetizing store', 'bakery', 'bakeshop', 'bodega', 'boutique', 'butcher shop', 'chain store', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store'],
    'supernal': ['elysian', 'olympian', 'aerial', 'airy', 'altitudinous', 'ascending', 'aspiring', 'beatific', 'beatified', 'blessed', 'celestial', 'colossal'],
    'supernatural': ['christlike', 'christly', 'abnormal', 'airy', 'anagogic', 'arcane', 'asomatous', 'astral', 'bodiless', 'cabalic', 'cabalistic', 'celestial'],
    'supernaturalism': ['bodilessness', 'eeriness', 'elfdom', 'faerie', 'ghostliness', 'immateriality', 'immaterialness', 'impalpability', 'imponderability', 'incorporeality', 'incorporeity', 'inextension'],
    'supernova': ['beehive', 'cepheid variable', 'hertzsprung-russell diagram', 'hyades', 'messier catalog', 'ngc', 'pleiades', 'seven sisters', 'absolute magnitude', 'binary star', 'black hole', 'double star'],
    'superpatriot': ['bigot', 'chauvin', 'chauvinist', 'doctrinaire', 'dogmatist', 'fanatic', 'flag waver', 'hard hat', 'hundred-percent american', 'hundred-percenter', 'illiberal', 'intolerant'],
    'superpatriotic': ['antiblack', 'biased', 'chauvinist', 'chauvinistic', 'civic', 'colored', 'doctrinaire', 'dogmatic', 'flag-waving', 'influenced', 'interested', 'jaundiced'],
    'superphysical': ['arcane', 'eerie', 'esoteric', 'extramundane', 'extraterrestrial', 'fey', 'hypernormal', 'hyperphysical', 'mysterious', 'numinous', 'occult', 'otherworldly'],
    'superpower': ['ally', 'amperage', 'archduchy', 'archdukedom', 'armipotence', 'authority', 'beef', 'black power', 'body politic', 'brute force', 'buffer state', 'captive nation'],
    'supersaturate': ['allay', 'choke', 'cloy', 'congest', 'cram', 'crowd', 'drench', 'engorge', 'fill', 'fill up', 'glut', 'gluttonize'],
    'supersaturated': ['allayed', 'bloated', 'bursting', 'choked', 'cloyed', 'congested', 'crammed', 'crowded', 'disgusted', 'distended', 'drenched', 'engorged'],
    'superscribe': ['address', 'copy', 'copy out', 'direct', 'draft', 'draw up', 'edit', 'enface', 'engross', 'inscribe', 'make a recension', 'make out'],
    'superscription': ['address', 'banner', 'banner head', 'billhead', 'caption', 'destination', 'direction', 'drop head', 'dropline', 'epigraph', 'hanger', 'head'],
    'supersede': ['abandon', 'act for', 'change places with', 'crowd out', 'cut out', 'desert', 'discard', 'displace', 'double for', 'fill in for', 'forsake', 'ghost'],
    'superseded': ['abandoned', 'abjured', 'antiquated', 'antique', 'archaic', 'dead', 'deserted', 'discontinued', 'disused', 'done with', 'extinct', 'not worth saving'],
    'supersedure': ['agency', 'change', 'commutation', 'delegation', 'deputation', 'deputyship', 'displacement', 'exchange', 'power of attorney', 'quid pro quo', 'replacement', 'representation'],
    'supersensitive': ['allergic', 'anaphylactic', 'delicate', 'empathetic', 'empathic', 'goosy', 'hyperesthetic', 'hyperpathic', 'hypersensitive', 'irritable', 'itchy', 'nervous'],
    'supersonics': ['aerial photography', 'aeroballistics', 'aerodynamics', 'aerogeology', 'aerography', 'aerology', 'aeromechanics', 'aeromedicine', 'aerometry', 'aeronautical meteorology', 'aerophotography', 'aerophysics'],
    'superstar': ['a per se', 'ace', 'big name', 'boss', 'celebrity', 'champion', 'chief', 'commander', 'constellation', 'crackerjack', 'cynosure', 'danseur noble'],
    'superstitious': ['credulous', 'doting', 'easily taken in', 'easy of belief', 'fond', 'inclined to believe', 'infatuated', 'overconfiding', 'overcredulous', 'overtrustful', 'overtrusting', 'trustful'],
    'supervenient': ['accessory', 'accidental', 'additional', 'adscititious', 'adventitious', 'appurtenant', 'ascititious', 'auxiliary', 'casual', 'circumstantial', 'collateral', 'contingent'],
    'supervise': ['administer', 'administrate', 'be master', 'boss', 'captain', 'carry authority', 'chair', 'chaperon', 'command', 'conduct', 'control', 'crack the whip'],
    'supervision': ['accountability', 'administration', 'auspices', 'bossing', 'care', 'charge', 'civil government', 'conduct', 'direction', 'discipline', 'dispensation', 'disposition'],
    'supervisor': ['big brother', 'administrator', 'alderman', 'archon', 'auditor', 'bailie', 'boatswain', 'boss', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister'],
    'supinate': ['blow down', 'blow over', 'bowl down', 'bowl over', 'bring down', 'bulldog', 'cast down', 'chop down', 'convert', 'couch', 'cut down', 'dash down'],
    'supine': ['laodicean', 'olympian', 'abject', 'accepting', 'accumbent', 'acquiescent', 'agreeable', 'aloof', 'apathetic', 'assenting', 'benumbed', 'blah'],
    'supper': ['tv dinner', 'alfresco meal', 'barbecue', 'breakfast', 'brunch', 'buffet supper', 'clambake', 'coffee break', 'cookout', 'diner', 'dinner', 'elevenses'],
    'supplant': ['act for', 'bounce', 'cast out', 'change places with', 'crowd out', 'cut out', 'dismiss', 'displace', 'double for', 'eject', 'exchange', 'expel'],
    'supplanting': ['agency', 'change', 'commutation', 'delegation', 'deputation', 'deputyship', 'displacement', 'exchange', 'power of attorney', 'quid pro quo', 'replacement', 'representation'],
    'supple': ['machiavellian', 'machiavellic', 'able to adapt', 'accommodating', 'acquiescent', 'acute', 'adaptable', 'adjustable', 'agile', 'all-around', 'alterable', 'alterative'],
    'supplement': ['ps', 'parthian shot', 'accession', 'accessory', 'accident', 'accidental', 'accompaniment', 'add to', 'addenda', 'addendum', 'additament', 'addition'],
    'supplementary': ['accessory', 'accidental', 'added', 'additional', 'adjunct', 'adscititious', 'adventitious', 'ancillary', 'annexed', 'another', 'appended', 'appurtenant'],
    'supplementation': ['accession', 'addition', 'adjunct', 'adjunction', 'affixation', 'agglutination', 'annexation', 'attachment', 'augmentation', 'increase', 'joining', 'junction'],
    'suppliant': ['adorant', 'adorer', 'adoring', 'applicant', 'asker', 'aspirant', 'beadsman', 'beggar', 'begging', 'bidder', 'cadging', 'candidate'],
    'supplicant': ['appellant', 'applicant', 'asker', 'aspirant', 'beggar', 'begging', 'beseecher', 'beseeching', 'entreating', 'imploring', 'importunate', 'mendicant'],
    'supplicate': ['adjure', 'appeal', 'appeal to', 'beg', 'beseech', 'call for help', 'call on', 'call upon', 'clamor for', 'commune with god', 'conjure', 'crave'],
    'supplication': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'adjuration', 'aid prayer', 'appeal', 'application', 'beadroll', 'beads'],
    'supplicatory': ['adorant', 'adoring', 'begging', 'cadging', 'devotional', 'devout', 'imploring', 'in the dust', 'mendicant', 'mooching', 'on bended knee', 'petitionary'],
    'supplier': ['caterer', 'chandler', 'commissariat', 'commissary', 'donor', 'furnisher', 'manciple', 'merchant', 'patron', 'provider', 'provisioner', 'purveyor'],
    'supplies': ['abundance', 'accumulation', 'amassment', 'backlog', 'budget', 'canned foods', 'collection', 'commissariat', 'commissary', 'cornucopia', 'cumulation', 'dehydrated foods'],
    'supply': ['ability', 'accommodate', 'accommodate with', 'accouterment', 'accumulation', 'acting', 'ad interim', 'afford', 'armament', 'assets', 'available means', 'balance'],
    'supply depot': ['archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box', 'bunker'],
    'support': ['a-frame', 'maecenas', 'ok', 'tlc', 'abettor', 'abide', 'abide with', 'accept', 'acceptance', 'accession', 'accommodate', 'accredit'],
    'supportable': ['acceptable', 'apodictic', 'attestable', 'authenticatable', 'bearable', 'believable', 'checkable', 'confirmable', 'defensible', 'demonstrable', 'demonstratable', 'endurable'],
    'supporter': ['maecenas', 'santa claus', 'abettor', 'acquaintance', 'adherent', 'admirer', 'advocate', 'aficionado', 'aid', 'almoner', 'almsgiver', 'alpenstock'],
    'supporting': ['advocating', 'approving', 'back of', 'backing', 'bearing', 'behind', 'bolstering', 'bracing', 'burdened', 'buttressing', 'carrying', 'confirmative'],
    'supportive': ['assuring', 'auspicious', 'bearing', 'bolstering', 'bracing', 'bright with promise', 'burdened', 'buttressing', 'carrying', 'cheering', 'comforting', 'condolatory'],
    'suppose': ['account', 'account as', 'adjudge', 'adjudicate', 'allegorize', 'allow', 'allude to', 'assume', 'be afraid', 'be judicious', 'believe', 'bring to mind'],
    'supposed': ['academic', 'accounted as', 'alleged', 'assumed', 'assumptive', 'conjectural', 'conjectured', 'deemed', 'expected', 'given', 'granted', 'hinted'],
    'supposing': ['allowing that', 'although', 'as if', 'as though', 'assuming that', 'assumption', 'axiom', 'conjecture', 'guesswork', 'hypothesis', 'if', 'inference'],
    'supposition': ['allegory', 'allusion', 'apprehension', 'apriorism', 'arcane meaning', 'assumption', 'axiom', 'belief', 'coloration', 'conceit', 'concept', 'conception'],
    'suppositional': ['accounted as', 'alleged', 'arguable', 'assumed', 'assumptive', 'at issue', 'confutable', 'conjectural', 'conjectured', 'contestable', 'controversial', 'controvertible'],
    'supposititious': ['barmecidal', 'barmecide', 'accounted as', 'affected', 'airy', 'alleged', 'apocryphal', 'apparent', 'apparitional', 'artificial', 'assumed', 'assumptive'],
    'suppress': ['abate', 'absorb the shock', 'allay', 'alleviate', 'annihilate', 'arrest', 'asphyxiate', 'assuage', 'attemper', 'ban', 'bank the fire', 'bar'],
    'suppressed': ['lethean', 'olympian', 'absentminded', 'aloof', 'amnestic', 'arcane', 'backward', 'bashful', 'blank', 'blocked', 'bond', 'broken'],
    'suppression': ['eighteenth amendment', 'prohibition party', 'volstead act', 'abolishment', 'abolition', 'aloofness', 'annihilation', 'annulment', 'arrest', 'arrestation', 'arrestment', 'backwardness'],
    'suppressive': ['absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'authoritarian', 'authoritative', 'autocratic', 'bossy', 'choking', 'constraining'],
    'suppurate': ['break up', 'canker', 'corrupt', 'crumble', 'crumble into dust', 'decay', 'decompose', 'disintegrate', 'fall into decay', 'fall to pieces', 'fester', 'gangrene'],
    'supremacy': ['accent', 'acme', 'ascendance', 'ascendancy', 'ascendant', 'autarchy', 'authority', 'authorization', 'balance of power', 'be-all and end-all', 'blue ribbon', 'championship'],
    'supreme': ['absolute', 'acmatic', 'all-absorbing', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'apical', 'ascendant', 'at the head', 'authoritarian'],
    'surcease': ['abandonment', 'break', 'breakoff', 'breath', 'breather', 'breathing place', 'breathing space', 'breathing spell', 'breathing time', 'catharsis', 'cease', 'ceasing'],
    'surcharge': ['bale', 'bleed', 'bleed white', 'burden', 'burdening', 'burthen', 'cargo', 'charge', 'charging', 'choke', 'clip', 'congest'],
    'surd': ['gaussian integer', 'accented', 'algebraic number', 'algorismic', 'algorithmic', 'aliquot', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated'],
    'sure': ['ok', 'roger', 'abiding', 'absolute', 'absolutely', 'accurate', 'adducible', 'admissible', 'agape', 'agog', 'all agog', 'all right'],
    'sure enough': ['absolute', 'actual', 'apodictic', 'ascertained', 'attested', 'authentic', 'authenticated', 'bona fide', 'bound', 'candid', 'card-carrying', 'categorically true'],
    'sure sign': ['absolute indication', 'badge', 'banner', 'burden of proof', 'character', 'characteristic', 'conclusive evidence', 'damning evidence', 'demonstration', 'determination', 'device', 'differentia'],
    'sure thing': ['ok', 'roger', 'absolutely', 'all right', 'alright', 'alrighty', 'amen', 'as you say', 'assuredly', 'aye', 'best bet', 'by all means'],
    'surefire': ['assured of success', 'calculable', 'certain', 'coming', 'crowned with success', 'dependable', 'faithful', 'faithworthy', 'fast', 'firm', 'fortunate', 'invincible'],
    'surely': ['ok', 'roger', 'absolutely', 'all right', 'alright', 'alrighty', 'amen', 'and no mistake', 'as you say', 'assuredly', 'at all events', 'at any rate'],
    'sureness': ['absolute certainty', 'absoluteness', 'acceptation', 'acception', 'acquiescence', 'act of god', 'arrogance', 'assurance', 'assuredness', 'belief', 'certain knowledge', 'certainness'],
    'surety': ['absolute certainty', 'absoluteness', 'acceptation', 'acception', 'acquiescence', 'angel', 'arrogance', 'assurance', 'assuredness', 'backer', 'bail', 'bailsman'],
    'surf': ['billow', 'bore', 'breakers', 'chop', 'choppiness', 'chopping sea', 'collar', 'comb', 'comber', 'dirty water', 'eagre', 'foam'],
    'surface': ['acreage', 'ankle-deep', 'apparent', 'appear', 'appearing', 'area', 'arise', 'bail out', 'bob up', 'border', 'boundary', 'breadth'],
    'surfacing': ['arising', 'breaking water', 'carpet', 'coming', 'cover', 'crash dive', 'deck', 'discharge', 'dive', 'earth', 'emanating', 'emanation'],
    'surfeit': ['allay', 'amplitude', 'bellyful', 'brim', 'charge', 'chock', 'choke', 'cloy', 'congest', 'congestion', 'cram', 'crowd'],
    'surfeited': ['sro', 'allayed', 'bloated', 'brimful', 'brimming', 'bulging', 'bursting', 'capacity', 'chock-full', 'choked', 'chuck-full', 'cloyed'],
    'surfing': ['australian crawl', 'aquaplaning', 'aquatics', 'backstroke', 'balneation', 'bathe', 'bathing', 'breaststroke', 'butterfly', 'crawl', 'diving', 'dog paddle'],
    'surge': ['charybdis', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'affluence', 'afflux', 'affluxion'],
    'surgery': ['x ray', 'abscission', 'amputation', 'antiseptic surgery', 'aseptic surgery', 'blood bank', 'bloodless surgery', 'butchering', 'cauterization', 'cautery', 'charity ward', 'chiroplasty'],
    'surgical': ['allopathic', 'chiropodic', 'chiropractic', 'clinical', 'dental', 'exodontic', 'homeopathic', 'hydropathic', 'iatric', 'medical', 'naturopathic', 'neurological'],
    'surging': ['affluent', 'confluent', 'coursing', 'decurrent', 'defluent', 'diffluent', 'flowing', 'fluent', 'fluxional', 'fluxive', 'gulfy', 'gushing'],
    'surliness': ['abruptness', 'aggressiveness', 'bearishness', 'beastliness', 'bluntness', 'boorishness', 'bouderie', 'brashness', 'brusqueness', 'brusquerie', 'churlishness', 'crustiness'],
    'surly': ['abrupt', 'aggressive', 'argumentative', 'bad-tempered', 'bearish', 'beastly', 'beetle-browed', 'bilious', 'black', 'black-browed', 'bluff', 'blunt'],
    'surmise': ['account as', 'assume', 'assumption', 'axiom', 'be afraid', 'believe', 'blind guess', 'bold conjecture', 'conceive', 'conclude', 'conclusion', 'conjecture'],
    'surmount': ['beat', 'best', 'bestraddle', 'bestride', 'better', 'cap', 'clamber', 'clamber up', 'clear', 'climax', 'climb', 'climb over'],
    'surmountable': ['achievable', 'actable', 'assailable', 'attackable', 'attainable', 'beatable', 'compassable', 'conquerable', 'doable', 'expugnable', 'feasible', 'negotiable'],
    'surpass': ['bang', 'beat', 'best', 'better', 'cap', 'cob', 'ding', 'distance', 'eclipse', 'exceed', 'excel', 'get ahead of'],
    'surpassing': ['a cut above', 'above', 'absolute', 'ahead', 'arrant', 'ascendant', 'best', 'better', 'capping', 'champion', 'choice', 'chosen'],
    'surplus': ['accessory', 'additional', 'ancillary', 'another', 'as a bonus', 'auxiliary', 'balance', 'bonus', 'boot', 'bounce', 'break', 'bump'],
    'surprise': ['admiration', 'amaze', 'amazement', 'ambush', 'assail', 'assault', 'astonish', 'astonishment', 'astound', 'astoundment', 'attack', 'awe'],
    'surprised': ['ad-lib', 'agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled'],
    'surprising': ['abrupt', 'amazing', 'astonishing', 'astounding', 'breathtaking', 'confounding', 'electrifying', 'eye-opening', 'hasty', 'headlong', 'impetuous', 'impulsive'],
    'surprisingly': ['abruptly', 'abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'astoundingly', 'awesomely', 'bang', 'confoundingly', 'conspicuously', 'copiously'],
    'surrender': ['abalienate', 'abalienation', 'abandon', 'abandonment', 'abatement of differences', 'abdicate', 'abdication', 'abjuration', 'abjure', 'abjurement', 'accommodate', 'accommodation'],
    'surreptitious': ['artful', 'back-door', 'backstairs', 'calculating', 'chiseling', 'clandestine', 'collusive', 'concealed', 'covert', 'covinous', 'crafty', 'cunning'],
    'surrogate': ['advocate', 'agent', 'alter ego', 'alternate', 'alternative', 'amicus curiae', 'analogy', 'attorney', 'backup', 'backup man', 'champion', 'change'],
    'surround': ['ambiance', 'ambience', 'atmosphere', 'begird', 'beleaguer', 'beset', 'besiege', 'blockade', 'bound', 'box', 'box in', 'cage'],
    'surrounded': ['circumscribed', 'circumscript', 'compassed', 'defined', 'definite', 'delimited', 'demarcated', 'determinate', 'determined', 'encircled', 'enclosed', 'encompassed'],
    'surrounding': ['abutting', 'adjacent', 'adjoining', 'ambient', 'bordering', 'circling', 'circumambient', 'circumferential', 'circumflex', 'circumfluent', 'circumfluous', 'circumjacent'],
    'surroundings': ['alentours', 'ambience', 'ambit', 'borderlands', 'circle', 'circuit', 'circumambiencies', 'circumjacencies', 'circumstances', 'compass', 'context', 'entourage'],
    'surtax': ['assessment', 'cess', 'conscience money', 'contribution', 'direct tax', 'duty', 'graduated taxation', 'imposition', 'impost', 'indirect tax', 'joint return', 'levy'],
    'surveillance': ['accountability', 'ambuscade', 'ambush', 'ambushment', 'auspices', 'blind', 'booby trap', 'bossing', 'bugging', 'care', 'charge', 'cloak-and-dagger work'],
    'survey': ['abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'analysis', 'appraisal', 'appraise', 'appraisement', 'appreciate', 'approximation', 'article'],
    'surveying': ['altimetry', 'appraisal', 'appraisement', 'approximation', 'assessment', 'assize', 'assizement', 'bathymetry', 'biometrics', 'biometry', 'cadastration', 'calculation'],
    'surveyor': ['big brother', 'appraiser', 'assayer', 'assessor', 'auditor', 'boatswain', 'boss', 'cartographer', 'chief', 'chorographer', 'comptroller', 'controller'],
    'survival': ['abidingness', 'afterglow', 'afterimage', 'age', 'ancient manuscript', 'antique', 'antiquity', 'archaism', 'artifact', 'balance', 'butt', 'butt end'],
    'survive': ['abide', 'be left', 'be spared', 'bide', 'bounce back', 'carry on', 'carry through', 'cheat death', 'come around', 'come back', 'come round', 'come through'],
    'susceptibility': ['a thing for', 'ability', 'ableness', 'accessibility', 'adaptability', 'adequacy', 'affectibility', 'affection', 'affectionateness', 'affectivity', 'affinity', 'agreeability'],
    'susceptible': ['accessible', 'adaptable', 'affected', 'alive to', 'amenable', 'answerable for', 'apt', 'apt to', 'aroused', 'aware', 'bendable', 'bending'],
    'suspect': ['a bit thick', 'a bit thin', 'absurd', 'account as', 'accused', 'arguable', 'assume', 'at issue', 'awake a doubt', 'be afraid', 'be diffident', 'be doubtful'],
    'suspecting': ['pyrrhonic', 'agnostic', 'cagey', 'cautious', 'chary', 'disinclined to believe', 'disposed to doubt', 'distrustful', 'doubtful', 'doubting', 'dubious', 'from missouri'],
    'suspend': ['abolish', 'abrogate', 'adjourn', 'annul', 'arrest', 'attach', 'blackball', 'boot', 'bounce', 'break', 'break off', 'bump'],
    'suspended': ['abeyant', 'apathetic', 'broken', 'broken off', 'cascading', 'cataleptic', 'catatonic', 'chopped-off', 'choppy', 'dangling', 'dead', 'decousu'],
    'suspender': ['bar', 'belt', 'boom', 'braces', 'button', 'clotheshorse', 'clothespin', 'crane', 'gallows', 'galluses', 'garter', 'gibbet'],
    'suspense': ['abeyance', 'agitation', 'all-overs', 'angst', 'anticipation', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat', 'anxiousness'],
    'suspenseful': ['agitated', 'agitating', 'all-overish', 'anxious', 'anxioused up', 'apprehensive', 'at issue', 'bothered', 'breathtaking', 'charged', 'cliff-hanging', 'concerned'],
    'suspension': ['abandonment', 'abeyance', 'abjuration', 'abjurement', 'abolishment', 'abolition', 'abrogation', 'adaptation', 'afterthought', 'annulment', 'arrangement', 'bind'],
    'suspicion': ['pyrrhonism', 'apprehension', 'apprehensiveness', 'bare suggestion', 'broad hint', 'cageyness', 'cast', 'caution', 'cautiousness', 'chariness', 'clue', 'concern'],
    'suspicious': ['pyrrhonic', 'a bit thick', 'a bit thin', 'absurd', 'agnostic', 'amoral', 'apprehensive', 'arguable', 'at issue', 'beyond belief', 'borderline', 'cagey'],
    'sustain': ['abide', 'abide with', 'admit', 'advocate', 'affirm', 'afford support', 'allege in support', 'allow', 'answer', 'approve', 'argue for', 'assert'],
    'sustained': ['abiding', 'based on', 'bolstered', 'borne', 'braced', 'buttressed', 'ceaseless', 'changeless', 'chattering', 'constant', 'continual', 'continued'],
    'sustainer': ['maecenas', 'abettor', 'admirer', 'advocate', 'aficionado', 'alpenstock', 'angel', 'apologist', 'arm', 'athletic supporter', 'back', 'backbone'],
    'sustaining': ['aid', 'backing', 'bearing', 'bolstering', 'bracing', 'burdened', 'buttressing', 'carriage', 'carrying', 'holding', 'maintaining', 'maintenance'],
    'sustenance': ['tlc', 'aid', 'aliment', 'alimentation', 'alimony', 'backing', 'board', 'bread', 'bread and butter', 'care', 'carriage', 'carrying'],
    'susurration': ['aspiration', 'bated breath', 'breath', 'breathy voice', 'drone', 'droning', 'exhalation', 'gabble', 'gibber', 'gibbering', 'jabber', 'jibber'],
    'sutler': ['caterer', 'chandler', 'commissariat', 'commissary', 'donor', 'furnisher', 'manciple', 'merchant', 'patron', 'provider', 'provisioner', 'purveyor'],
    'sutra': ['adage', 'ana', 'analects', 'aphorism', 'apothegm', 'axiom', 'byword', 'catchword', 'collected sayings', 'current saying', 'dictate', 'dictum'],
    'suttee': ['blazing', 'blistering', 'branding', 'burning', 'burnt offering', 'calcination', 'car of jagannath', 'carbonization', 'cauterization', 'cautery', 'cineration', 'collection'],
    'suture': ['animal fiber', 'ankle', 'articulation', 'artificial fiber', 'boundary', 'butt', 'capillament', 'cervix', 'cilium', 'cirrus', 'clinch', 'closure'],
    'svelte': ['airy', 'attenuate', 'attenuated', 'boyish', 'delicate', 'diaphanous', 'diluted', 'ethereal', 'fine', 'fine-drawn', 'finespun', 'flimsy'],
    'svengali': ['mesmer', 'rasputin', 'vip', 'access', 'bad influence', 'big wheel', 'court', 'eminence grise', 'five-percenter', 'friend at court', 'good influence', 'gray eminence'],
    'swab': ['air-dry', 'anhydrate', 'bake', 'baptize', 'bath', 'bathe', 'blot', 'brush', 'burn', 'cure', 'dehumidify', 'dehydrate'],
    'swaddle': ['apparel', 'array', 'attire', 'band', 'bandage', 'bedeck', 'bedrape', 'belt', 'bend', 'bind', 'bind up', 'box'],
    'swag': ['angularity', 'arch', 'ascend', 'bag', 'bagging', 'baggy', 'ballooning', 'bank', 'bend', 'bend back', 'blackmail', 'bob'],
    'swagger': ['amble', 'arrogance', 'barge', 'bluff', 'bluster', 'bluster and bluff', 'blustering', 'boast', 'boastfulness', 'boasting', 'bombast', 'bounce'],
    'swagger stick': ['malacca cane', 'alpenstock', 'baton', 'cane', 'crook', 'crosier', 'cross', 'cross-staff', 'crutch', 'crutch-stick', 'handstaff', 'lituus'],
    'swaggerer': ['herod', 'blatherskite', 'bluff', 'bluffer', 'blusterer', 'boldface', 'braggart', 'bravo', 'brazenface', 'bucko', 'bully', 'bullyboy'],
    'swaggering': ['aweless', 'barefaced', 'blustering', 'blusterous', 'blustery', 'boisterous', 'bold', 'bold as brass', 'boldfaced', 'brassy', 'brazen', 'brazenfaced'],
    'swagman': ['arab', 'bowery bum', 'beach bum', 'beachcomber', 'beggar', 'beggarly fellow', 'blighter', 'bo', 'budmash', 'bum', 'bummer', 'caitiff'],
    'swain': ['casanova', 'don juan', 'lothario', 'romeo', 'amoroso', 'beau', 'bodyguard', 'boyfriend', 'caballero', 'cavalier', 'cavaliere servente', 'chaperon'],
    'swallow': ['abide', 'abjure', 'ablate', 'absorb', 'accede', 'accept', 'accept for gospel', 'accept implicitly', 'acquiesce', 'allow', 'and sinker', 'antelope'],
    'swallow up': ['ablate', 'absorb', 'assimilate', 'bleed white', 'bring to ruin', 'burn up', 'condemn', 'confound', 'consume', 'damn', 'deal destruction', 'decimate'],
    'swamp': ['baygall', 'be prodigal with', 'bind', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow', 'cascade', 'cataract', 'cesspool', 'cloaca'],
    'swamped': ['afloat', 'aground', 'at flood', 'awash', 'bathed', 'castaway', 'deluged', 'dipped', 'drenched', 'dribbling', 'dripping', 'dripping wet'],
    'swampy': ['boggish', 'boggy', 'damp', 'dampish', 'dank', 'dewy', 'fenny', 'humid', 'marish', 'marshy', 'mirish', 'miry'],
    'swan': ['alabaster', 'avifauna', 'baby bird', 'bird', 'bird of jove', 'bird of juno', 'bird of minerva', 'bird of night', 'bird of passage', 'bird of prey', 'birdie', 'birdlife'],
    'swan dive': ['belly buster', 'belly flop', 'belly whopper', 'cannonball', 'crash dive', 'dive', 'drop', 'fall', 'gainer', 'header', 'jackknife', 'nose dive'],
    'swan song': ['ps', 'parthian shot', 'addendum', 'afterthought', 'apodosis', 'appendix', 'back matter', 'benefit', 'bill', 'catastrophe', 'ceasing', 'cessation'],
    'swank': ['babylonian', 'corinthian', 'airs', 'awe-inspiring', 'awful', 'barbaric', 'bounce', 'brave show', 'braw', 'chic', 'chichi', 'classy'],
    'swanky': ['babylonian', 'corinthian', 'awe-inspiring', 'awful', 'barbaric', 'braw', 'chic', 'chichi', 'classy', 'clothes-conscious', 'cosmopolitan', 'dapper'],
    'swansdown': ['blubber', 'breeze', 'butter', 'clay', 'cushion', 'dough', 'down', 'eiderdown', 'feather bed', 'feathers', 'fleece', 'floss'],
    'swap': ['alternate', 'backscratching', 'bandy', 'bang', 'bargain', 'barter', 'bash', 'be quits with', 'belt', 'biff', 'blind bargain', 'bump'],
    'swapping': ['agency', 'backscratching', 'barter', 'bartering', 'brokerage', 'buying and selling', 'colossal', 'dealing', 'doing business', 'enormous', 'even trade', 'exchange'],
    'swarm': ['a mass of', 'a world of', 'abound', 'abound with', 'army', 'assemble', 'beset', 'bevy', 'bristle with', 'bunch', 'bunch up', 'burst with'],
    'swarm with': ['abound', 'abound with', 'be alive with', 'beset', 'bespread', 'bristle with', 'burst with', 'clutter', 'crawl with', 'creep with', 'crowd', 'diffuse'],
    'swarming': ['abounding', 'abundant', 'alive with', 'blooming', 'bountiful', 'bristling', 'bursting', 'bursting out', 'close', 'compact', 'copious', 'crammed'],
    'swarthiness': ['egyptian darkness', 'erebus', 'blackishness', 'blackness', 'dark', 'darkishness', 'darkness', 'darkness visible', 'darksomeness', 'dead of night', 'duskiness', 'duskness'],
    'swarthy': ['black', 'blackish', 'brunet', 'coal-black', 'dark', 'dark-colored', 'dark-skinned', 'darkish', 'darksome', 'dusk', 'dusky', 'ebon'],
    'swash': ['aqueduct', 'arroyo', 'asperge', 'babble', 'bed', 'bedew', 'bespatter', 'besprinkle', 'bounce', 'brave show', 'bubble', 'burble'],
    'swashbuckler': ['herod', 'battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'blatherskite', 'bluff', 'bluffer', 'blusterer', 'braggart', 'bravo'],
    'swashbuckling': ['adventurous', 'blustering', 'blusterous', 'blustery', 'boisterous', 'bold', 'bullying', 'daredevil', 'daring', 'dashing', 'flamboyant', 'hectoring'],
    'swastika': ['calvary cross', 'christogram', 'greek cross', 'jerusalem cross', 'latin cross', 'maltese cross', 'russian cross', 'amulet', 'ankh', 'armory', 'avellan cross', 'badge'],
    'swat': ['bang', 'bash', 'bat', 'beating', 'belt', 'biff', 'blow', 'bonk', 'chop', 'clap', 'clip', 'clobber'],
    'swath': ['indian file', 'array', 'articulation', 'bank', 'belt', 'buzz', 'catena', 'catenation', 'chain', 'chain reaction', 'chaining', 'concatenation'],
    'swathe': ['apparel', 'array', 'attire', 'band', 'bandage', 'bedeck', 'bedrape', 'belt', 'bend', 'bind', 'bind up', 'box'],
    'sway': ['acme', 'administration', 'affect', 'alternate', 'amplitude', 'angle', 'angle off', 'angularity', 'argue into', 'ascend', 'ascendancy', 'authority'],
    'swayable': ['accessible', 'amenable', 'impressionable', 'influenceable', 'malleable', 'movable', 'open', 'open-minded', 'persuadable', 'persuasible', 'pervious', 'plastic'],
    'swayback': ['bowlegs', 'camelback', 'cleft palate', 'clubfoot', 'crookback', 'defacement', 'deformation', 'deformity', 'disfigurement', 'flatfoot', 'freakishness', 'harelip'],
    'swaybacked': ['bandy', 'bandy-legged', 'blemished', 'bloated', 'bowlegged', 'club-footed', 'defaced', 'deformed', 'disfigured', 'dwarfed', 'flatfooted', 'grotesque'],
    'swayed': ['antiblack', 'biased', 'chauvinistic', 'colored', 'doctrinaire', 'dogmatic', 'influenced', 'interested', 'involved', 'jaundiced', 'know-nothing', 'nonobjective'],
    'swaying': ['ascendant', 'careening', 'dangling', 'dominant', 'in ascendancy', 'in the ascendant', 'lurching', 'on the throne', 'pitching', 'predominant', 'prepollent', 'preponderant'],
    'swear': ['abjure', 'abuse', 'acknowledge', 'adjure', 'administer an oath', 'affirm', 'agree', 'allege', 'and candle', 'assert', 'assert under oath', 'asseverate'],
    'swear off': ['abandon', 'abjure', 'break the habit', 'cede', 'discontinue', 'disgorge', 'dispense with', 'dispose of', 'do without', 'drop', 'dump', 'forgo'],
    'swear to': ['ok', 'accept', 'accredit', 'affirm', 'amen', 'and candle', 'approve', 'assert under oath', 'assure', 'attest', 'authenticate', 'authorize'],
    'swearing': ['affidavit', 'affirmation', 'attestation', 'bad language', 'billingsgate', 'blue language', 'certification', 'colorful language', 'cursing', 'cussing', 'deposition', 'dirty language'],
    'sweat': ['bo', 'abide', 'ado', 'agitation', 'agonize', 'aim', 'all-overs', 'anguish', 'anxiety', 'await', 'bake', 'be determined'],
    'sweat bath': ['finnish bath', 'japanese bath', 'russian bath', 'swedish bath', 'turkish bath', 'bath', 'bathe', 'cold shower', 'douche', 'fangotherapy', 'heat therapy', 'heliotherapy'],
    'sweat blood': ['aim', 'be determined', 'endeavor', 'haul', 'heave', 'labor', 'overexert', 'overextend', 'overstrain', 'overtax', 'press', 'pull'],
    'sweat it out': ['abide', 'await', 'bear up', 'bide', 'burn to', 'chafe', 'fret', 'fuss', 'get excited', 'hang in', 'hang tough', 'hardly wait'],
    'sweating': ['ardent', 'baking', 'bathed in sweat', 'beaded with sweat', 'blistering', 'boiling', 'broiling', 'burning', 'burning hot', 'canicular', 'clammy', 'condensation'],
    'sweatshop': ['agency', 'atelier', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'butcher shop', 'company', 'concern', 'corporation', 'desk', 'establishment'],
    'sweaty': ['ardent', 'baking', 'bathed in sweat', 'beaded with sweat', 'blistering', 'boiling', 'broiling', 'burning', 'burning hot', 'canicular', 'clammy', 'diaphoretic'],
    'sweep': ['derby', 'kentucky derby', 'preakness stakes', 's-curve', 'aberrancy', 'aberration', 'advance', 'airscape', 'ambit', 'arc', 'arch', 'ball the jack'],
    'sweep out': ['bleach', 'blow', 'blow out', 'bowdlerize', 'broom', 'brush', 'brush off', 'clean', 'clean out', 'clean up', 'cleanse', 'clear'],
    'sweeping': ['absolute', 'across the board', 'across-the-board', 'aleatoric', 'aleatory', 'all-comprehensive', 'all-embracing', 'all-encompassing', 'all-inclusive', 'all-out', 'all-pervading', 'amorphous'],
    'sweepings': ['afterglow', 'afterimage', 'balance', 'bones', 'butt', 'butt end', 'candle ends', 'chaff', 'culm', 'deadwood', 'debris', 'detritus'],
    'sweepstakes': ['academy award', 'derby', 'kentucky derby', 'nobel prize', 'oscar', 'preakness stakes', 'award', 'betting system', 'bingo', 'booby prize', 'card games', 'chase'],
    'sweet': ['jell-o', 'accommodating', 'achingly sweet', 'admirable', 'adorable', 'affable', 'aftertaste', 'agreeable', 'agreeable-sounding', 'ambrosial', 'amiable', 'amicable'],
    'sweet nothings': ['adulation', 'artful endearments', 'blandishment', 'blandishments', 'blarney', 'bunkum', 'cajolement', 'cajolery', 'caress', 'compliment', 'endearment', 'eyewash'],
    'sweet on': ['attached to', 'crazy about', 'devoted to', 'enamored of', 'far gone on', 'fond of', 'gone on', 'hipped on', 'in love with', 'mad about', 'nuts about', 'partial to'],
    'sweet potato': ['english horn', 'pandean pipe', 'aulos', 'basset horn', 'basset oboe', 'bassoon', 'bombard', 'clarinet', 'contrabassoon', 'contrafagotto', 'cromorne', 'double bassoon'],
    'sweet shop': ['antique store', 'apothecary', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'chemist', 'cigar store', 'clothiers', 'clothing store', 'confectionery', 'dress shop'],
    'sweet smelling': ['ambrosial', 'aromatic', 'balmy', 'essenced', 'flowery', 'fragrant', 'fruity', 'incense-breathing', 'musky', 'odorate', 'odoriferous', 'odorous'],
    'sweet talk': ['pecksniffery', 'tartuffery', 'tartuffism', 'adulation', 'advocate', 'allurement', 'artful endearments', 'be hypocritical', 'bill and coo', 'blandish', 'blandishment', 'blandishments'],
    'sweetbread': ['abatis', 'brains', 'breast of veal', 'chitterlings', 'cockscomb', 'foie de veau', 'fricandeau', 'giblets', 'gizzard', 'haslet', 'heart', 'kidneys'],
    'sweeten': ['allay', 'alleviate', 'appease', 'assuage', 'bleach', 'bowdlerize', 'brighten', 'candy', 'clean', 'clean out', 'clean up', 'cleanse'],
    'sweetener': ['trinkgeld', 'ambrosia', 'artificial sweetener', 'bait', 'blackstrap', 'bonus', 'bounty', 'bribe', 'calcium cyclamate', 'cane syrup', 'carrot', 'clover honey'],
    'sweetening': ['ambrosia', 'artificial sweetener', 'bait', 'blackstrap', 'bribe', 'calcium cyclamate', 'cane syrup', 'carrot', 'clover honey', 'comb honey', 'corn syrup', 'cyclamates'],
    'sweetheart': ['ace', 'admirer', 'angel', 'babe', 'baby', 'baby-doll', 'beau', 'beaut', 'beloved', 'betrothed', 'boyfriend', 'buttercup'],
    'sweetie': ['angel', 'babe', 'baby', 'baby-doll', 'beloved', 'buttercup', 'captive', 'catch', 'cherub', 'chick', 'chickabiddy', 'conquest'],
    'sweetmeat': ['jell-o', 'blancmange', 'candy', 'comfit', 'compote', 'confection', 'confectionery', 'confiture', 'conserve', 'frosting', 'gelatin', 'glaze'],
    'sweetness and light': ['bathos', 'bleeding heart', 'cloyingness', 'goo', 'hearts-and-flowers', 'maudlinness', 'mawkishness', 'mush', 'mushiness', 'namby-pamby', 'namby-pambyism', 'namby-pambyness'],
    'swell': ['babylonian', 'beau brummel', 'brahman', 'corinthian', 'ok', 'accent', 'accent mark', 'accrue', 'accumulate', 'ace-high', 'add to', 'advance'],
    'swelled headed': ['aggressively self-confident', 'biggety', 'bumptious', 'chesty', 'cocky', 'conceited', 'immodest', 'know-it-all', 'obtrusive', 'overwise', 'peacockish', 'peacocky'],
    'swelling': ['abscess', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'aggrandizement', 'amplification', 'aposteme'],
    'swelter': ['bo', 'thi', 'bake', 'be in heat', 'beaded brow', 'beads of sweat', 'blaze', 'bloom', 'body odor', 'boil', 'broil', 'burn'],
    'sweltering': ['ardent', 'baking', 'blistering', 'boiling', 'broiling', 'burning', 'burning hot', 'canicular', 'clammy', 'close', 'ebullient', 'feverish'],
    'swept up': ['absorbed', 'absorbed in', 'buried in', 'caught up in', 'contemplating', 'contemplative', 'devoted', 'devoted to', 'engaged', 'engrossed', 'engrossed in', 'immersed in'],
    'swerve': ['aberrancy', 'aberration', 'about ship', 'about the bush', 'alter', 'ameliorate', 'angle', 'angle off', 'apex', 'avoid', 'back and fill', 'be changed'],
    'swerving': ['aberrancy', 'aberrant', 'aberration', 'aberrative', 'bend', 'bias', 'branching off', 'circuitous', 'circuitousness', 'corner', 'crook', 'curve'],
    'swift': ['abrupt', 'agile', 'alacritous', 'alert', 'apt', 'breakneck', 'brief', 'brisk', 'cometary', 'cursory', 'dashing', 'decisive'],
    'swiftly': ['pdq', 'abruptly', 'agilely', 'amain', 'apace', 'at flank speed', 'at once', 'briefly', 'briskly', 'by forced marches', 'cursorily', 'decisively'],
    'swiftness': ['abruptness', 'agility', 'air speed', 'alacrity', 'bat', 'brevity', 'briefness', 'briskness', 'celerity', 'decisiveness', 'dispatch', 'expedition'],
    'swig': ['beverage', 'bib', 'booze', 'bumper', 'chug', 'chug-a-lug', 'draft', 'drag', 'drain', 'drain the cup', 'dram', 'drench'],
    'swill': ['barley', 'beverage', 'bib', 'bilge', 'bilgewater', 'bird seed', 'bones', 'booze', 'bran', 'bumper', 'carrion', 'cat food'],
    'swim': ['australian crawl', 'aquaplaning', 'aquatics', 'backstroke', 'balneation', 'bathe', 'bathing', 'bon ton', 'breaststroke', 'butterfly', 'convention', 'crawl'],
    'swim fins': ['aqua-lung', 'air cylinder', 'aquascope', 'bathyscaphe', 'bathysphere', 'benthoscope', 'diving bell', 'diving boat', 'diving chamber', 'diving goggles', 'diving helmet', 'diving hood'],
    'swimming': ['australian crawl', 'rugby', 'acrobatics', 'agonistics', 'aquaplaning', 'aquatic', 'aquatics', 'association football', 'athletics', 'backstroke', 'balneal', 'balneation'],
    'swimmingly': ['beyond all expectation', 'boomingly', 'easily', 'effortlessly', 'facilely', 'favorably', 'flourishingly', 'fortunately', 'handily', 'hands down', 'happily', 'lightly'],
    'swindle': ['abstract', 'abstraction', 'and', 'annex', 'annexation', 'appropriate', 'appropriation', 'bag', 'ballot-box stuffing', 'bamboozle', 'beat', 'beguile of'],
    'swindle sheet': ['budget', 'budget items', 'burden of expenditure', 'carrying charge', 'charges', 'cost', 'cost of living', 'cost-of-living allowance', 'cost-of-living index', 'costs', 'direct costs', 'disbursals'],
    'swindler': ['artful dodger', 'judas', 'philadelphia lawyer', 'yankee horse trader', 'betrayer', 'blackleg', 'body snatcher', 'booster', 'bunco steerer', 'charlatan', 'charmer', 'cheat'],
    'swine': ['berkshire', 'cyrenaic', 'duroc', 'duroc-jersey', 'heliogabalus', 'hereford', 'sardanapalus', 'wessex saddleback', 'yorkshire', 'animal', 'barrow', 'beast'],
    'swineherd': ['cattleman', 'cowboy', 'cowgirl', 'cowhand', 'cowherd', 'cowman', 'cowpuncher', 'drover', 'gaucho', 'goatherd', 'gooseboy', 'gooseherd'],
    'swing': ['alexandrine', 'ferris wheel', 'long melford', 'zeitgeist', 'accent', 'accentuation', 'acid rock', 'act', 'acting', 'action', 'activism', 'activity'],
    'swing shift': ['anchor watch', 'bit', 'day shift', 'dogwatch', 'full time', 'graveyard shift', 'half time', 'lobster trick', 'night shift', 'overtime', 'part time', 'relay'],
    'swingeing': ['draconian', 'bully', 'capital', 'champion', 'considerable', 'daunting', 'devastating', 'drastic', 'enormous', 'excessive', 'excruciating', 'exorbitant'],
    'swinger': ['beau brummel', 'bohemian', 'casanova', 'don juan', 'lothario', 'arbiter of fashion', 'beatnik', 'clotheshorse', 'clubman', 'clubwoman', 'dandy', 'deb'],
    'swinging': ['aberrancy', 'aberration', 'angular momentum', 'angular motion', 'angular velocity', 'axial motion', 'bend', 'bias', 'bowling', 'branching off', 'careen', 'careening'],
    'swinish': ['adamic', 'apician', 'circean', 'a hog for', 'acquisitive', 'all-devouring', 'animal', 'animalistic', 'asinine', 'avaricious', 'avid', 'beastlike'],
    'swipe': ['parthian shot', 'abstract', 'adverse criticism', 'and', 'animadversion', 'annex', 'appropriate', 'aspersion', 'back answer', 'bad notices', 'bad press', 'bag'],
    'swirl': ['charybdis', 'maelstrom', 'ado', 'agitate', 'agitation', 'back stream', 'backflow', 'backwash', 'backwater', 'beat', 'beat up', 'bluster'],
    'swirling': ['ado', 'agitation', 'angular momentum', 'angular motion', 'angular velocity', 'axial motion', 'bowling', 'brouhaha', 'bustle', 'centrifugation', 'circulation', 'circumgyration'],
    'swish': ['assibilate', 'assibilation', 'babble', 'bent', 'bubble', 'burble', 'buzz', 'campy', 'classy', 'crinkle', 'de rigueur', 'effeminate'],
    'switch': ['about-face', 'accommodation', 'action', 'adaptation', 'adjustment', 'agency', 'alchemy', 'alteration', 'alternate', 'amelioration', 'anagnorisis', 'angle'],
    'switch off': ['amplify', 'charge', 'close', 'cut', 'electrify', 'energize', 'galvanize', 'generate', 'kill', 'loop in', 'plug in', 'shock'],
    'switch over': ['about-face', 'alchemy', 'assimilation', 'assumption', 'becoming', 'change', 'change-over', 'conversion', 'flip-flop', 'growth', 'lapse', 'naturalization'],
    'switchback': ['branch', 'cable railway', 'chevron', 'cog railway', 'crankiness', 'crookedness', 'dogleg', 'el', 'electric railway', 'elevated', 'elevated railway', 'embankment'],
    'switchboard': ['a board', 'b board', 'pbx', 'acting area', 'apron', 'apron stage', 'backstage', 'band shell', 'bandstand', 'board', 'bridge', 'coulisse'],
    'swivel': ['arbor', 'axis', 'axle', 'axle bar', 'axle shaft', 'axle spindle', 'axle-tree', 'circle', 'circulate', 'circumrotate', 'circumvolute', 'come about'],
    'swivet': ['befuddlement', 'bewilderment', 'bother', 'botheration', 'chaos', 'cloud', 'confusion', 'daze', 'discombobulation', 'discomfiture', 'discomposure', 'disconcertion'],
    'swollen': ['sro', 'accelerated', 'adipose', 'aggrandized', 'amplified', 'augmented', 'aureate', 'beefed-up', 'beefy', 'bellied', 'big', 'big-bellied'],
    'swoon': ['ko', 'black out', 'blackout', 'catalepsy', 'catatonia', 'catatony', 'coma', 'crap out', 'die away', 'drop', 'drown', 'encephalitis lethargica'],
    'swoop': ['belly buster', 'belly flop', 'belly whopper', 'blow', 'cannonball', 'cascade', 'cataract', 'chute', 'collapse', 'come down', 'comedown', 'crash'],
    'swoop down upon': ['ambush', 'assail', 'assault', 'attack', 'blitz', 'bushwhack', 'catch at', 'come at', 'come down on', 'crack down on', 'descend on', 'descend upon'],
    'sword': ['excalibur', 'ax', 'battler', 'belligerent', 'belted knight', 'bickerer', 'bilbo', 'blade', 'bravo', 'brawler', 'broadsword', 'bully'],
    'sword of damocles': ['bulldozing', 'chanciness', 'commination', 'criticalness', 'delicacy', 'denunciation', 'doubtfulness', 'dubiousness', 'empty threat', 'foreboding', 'hazardousness', 'idle threat'],
    'sword side': ['affiliation', 'agnate', 'ancestry', 'apparentation', 'birth', 'blood', 'blood relation', 'blood relative', 'bloodline', 'branch', 'breed', 'clansman'],
    'swordsman': ['battler', 'belligerent', 'belted knight', 'bickerer', 'blade', 'bravo', 'brawler', 'bully', 'bullyboy', 'combatant', 'competitor', 'contender'],
    'sworn': ['affianced', 'affirmed', 'alleged', 'announced', 'asserted', 'asseverated', 'assured', 'attested', 'averred', 'avouched', 'avowed', 'betrothed'],
    'sworn off': ['apostolic', 'encratic', 'lenten', 'pythagorean', 'rechabite', 'shaker', 'spartan', 'stoic', 'abstemious', 'abstinent', 'ascetic', 'celibate'],
    'sworn statement': ['admission', 'affidavit', 'affirmation', 'allegation', 'assertion', 'asseveration', 'attest', 'attestation', 'authority', 'authorization', 'averment', 'avouchment'],
    'sworn to': ['accepted', 'acknowledged', 'admitted', 'affirmed', 'alleged', 'allowed', 'announced', 'approved', 'asserted', 'asseverated', 'attested', 'authenticated'],
    'swot': ['beast of burden', 'bone', 'commit to memory', 'con', 'contemplate', 'dig', 'drill', 'drudge', 'elucubrate', 'examine', 'fag', 'galley slave'],
    'swotting': ['application', 'boning', 'brainwork', 'conning', 'contemplation', 'cram', 'cramming', 'drill', 'engrossment', 'exercise', 'extensive study', 'grind'],
    'sybarite': ['cyrenaic', 'heliogabalus', 'sardanapalus', 'aesthete', 'bon vivant', 'carpet knight', 'epicure', 'epicurean', 'gastronome', 'gourmand', 'gourmet', 'hedonist'],
    'sycophancy': ['adulation', 'apple-polishing', 'ass-kissing', 'backbiting', 'backscratching', 'backstabbing', 'belittlement', 'blandishment', 'blarney', 'bootlicking', 'brown-nosing', 'bunkum'],
    'sycophant': ['adherent', 'adulator', 'apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'blarneyer', 'bootlick', 'bootlicker', 'bootlicking', 'brown-nose', 'brownie'],
    'sycophantic': ['abject', 'adulatory', 'backscratching', 'beggarly', 'bland', 'blandishing', 'blarneying', 'bootlicking', 'buttery', 'cajoling', 'complimentary', 'courtierly'],
    'syllabary': ['ipa', 'ita', 'initial teaching alphabet', 'alphabet', 'alphabetics', 'art', 'blueprint', 'charactering', 'characterization', 'chart', 'choreography', 'conventional representation'],
    'syllabic': ['accented', 'alphabetic character', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad'],
    'syllable': ['spenserian stanza', 'allophone', 'alveolar', 'antistrophe', 'antonym', 'apico-alveolar', 'apico-dental', 'articulation', 'aspiration', 'assimilation', 'atom', 'bilabial'],
    'syllabus': ['abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'brief', 'capsule', 'compend', 'condensation', 'condensed version', 'conspectus', 'digest'],
    'syllogism': ['aristotelian sorites', 'baconian method', 'goclenian sorites', 'a fortiori reasoning', 'a posteriori reasoning', 'a priori reasoning', 'analysis', 'categorical syllogism', 'deduction', 'deductive reasoning', 'dilemma', 'enthymeme'],
    'sylph': ['ariel', 'befind', 'corrigan', 'finnbeara', 'mab', 'oberon', 'titania', 'banshee', 'brownie', 'cluricaune', 'dwarf', 'elemental'],
    'sylphlike': ['airy', 'attenuate', 'attenuated', 'boyish', 'delicate', 'diaphanous', 'diluted', 'elfin', 'elfish', 'elflike', 'ethereal', 'faery'],
    'sylvan': ['afforestational', 'arboreous', 'back', 'back of beyond', 'back-country', 'backwood', 'backwoods', 'backwoodsy', 'bosky', 'braky', 'bushy', 'copsy'],
    'sylvan deity': ['cailleac', 'faunus', 'pan', 'priapus', 'vidar', 'vitharr', 'corn spirit', 'faun', 'fertility god', 'field spirit', 'forest god', 'panisc'],
    'symbiosis': ['accompaniment', 'accordance', 'agglomeration', 'agglutination', 'aggregation', 'agreement', 'alliance', 'articulation', 'association', 'bipartisanship', 'bond', 'bracketing'],
    'symbiotic': ['accompanying', 'accordant', 'affirmative', 'agreeable', 'agreeing', 'answerable', 'associate', 'associated', 'at one', 'at one with', 'coacting', 'coactive'],
    'symbol': ['abbreviation', 'accent', 'accent mark', 'acronym', 'agent', 'allegory', 'alphabet', 'alphabetic character', 'alternate', 'alternative', 'analogy', 'armory'],
    'symbolic': ['allegoric', 'allegorical', 'anagogic', 'associational', 'betokening', 'connotational', 'connotative', 'definable', 'demonstrative', 'denominative', 'denotational', 'denotative'],
    'symbolical': ['allegoric', 'allegorical', 'anagogic', 'associational', 'connotational', 'connotative', 'definable', 'demonstrative', 'denominative', 'denotational', 'denotative', 'designative'],
    'symbolism': ['sabbatarianism', 'allegory', 'allusion', 'anagoge', 'anagogics', 'anthroposophy', 'arcane meaning', 'assumption', 'cabala', 'cabalism', 'celebration', 'ceremonialism'],
    'symbolize': ['advert to', 'allude to', 'argue', 'be construed as', 'be taken as', 'bespeak', 'betoken', 'body forth', 'breathe', 'catch a likeness', 'character', 'characterize'],
    'symbolizing': ['apish', 'delineatory', 'depictive', 'echoic', 'embodying', 'figurative', 'graphic', 'ideographic', 'illustrational', 'illustrative', 'imitative', 'incarnating'],
    'symmetrical': ['apoise', 'arranged', 'balanced', 'businesslike', 'coequal', 'commensurable', 'commensurate', 'concinnate', 'concinnous', 'congruent', 'congruous', 'coordinate'],
    'symmetrize': ['assimilate to', 'balance', 'coordinate', 'damp', 'equalize', 'equilibrize', 'even', 'even up', 'flatten', 'harmonize', 'homogenize', 'integrate'],
    'symmetry': ['accord', 'accordance', 'affinity', 'agreement', 'arrangement', 'array', 'assent', 'balance', 'beauty', 'chorus', 'coequality', 'coextension'],
    'sympathetic': ['christian', 'christlike', 'christly', 'accordant', 'adductive', 'affectionate', 'affinitive', 'agreeable', 'agreeing', 'akin', 'allergic', 'alluring'],
    'sympathize with': ['accord', 'ache', 'agree', 'agree with', 'appreciate', 'assure', 'be affected', 'be in tune', 'be inspired', 'be involved', 'be moved', 'be sorry for'],
    'sympathizer': ['maecenas', 'abettor', 'accessory', 'accomplice', 'acquaintance', 'admirer', 'advocate', 'aficionado', 'ally', 'alter ego', 'angel', 'apologist'],
    'sympathy': ['abetment', 'accord', 'accordance', 'addition', 'adduction', 'adjunct', 'advocacy', 'aegis', 'affairs', 'affectionateness', 'affections', 'affective faculty'],
    'symphony': ['german band', 'philharmonic', 'accord', 'accordance', 'affinity', 'agape', 'agreement', 'amity', 'attune', 'attunement', 'band', 'big band'],
    'symposium': ['festschrift', 'airing', 'album', 'ana', 'analects', 'analysis', 'anthology', 'assemblee', 'assembly', 'assignation', 'at home', 'bacchanal'],
    'symptom': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'badge', 'banner', 'basis for belief'],
    'symptomatic': ['absolute', 'adducible', 'admissible', 'attestative', 'attestive', 'authentic', 'based on', 'certain', 'circumstantial', 'conclusive', 'connotative', 'convincing'],
    'synapse': ['afferent neuron', 'autonomic nervous system', 'axon', 'brain', 'central nervous system', 'cerebral cortex', 'craniosacral nervous system', 'dendrite', 'effector organ', 'efferent neuron', 'ganglion', 'gray matter'],
    'sync': ['accommodate', 'accord', 'accordance', 'adapt', 'adjust', 'adjust to', 'affinity', 'agreement', 'assent', 'assimilate', 'attune', 'chorus'],
    'synchromesh': ['hydromatic', 'automatic transmission', 'cogwheel', 'differential', 'differential gear', 'freewheel', 'gear', 'gear train', 'gearbox', 'gearing', 'gearshift', 'gearwheel'],
    'synchronism': ['accompaniment', 'accord', 'accordance', 'affinity', 'agreement', 'alliance', 'assent', 'association', 'attune', 'attunement', 'cahoots', 'chime'],
    'synchronize': ['accommodate', 'accompany', 'accord', 'adapt', 'adjust', 'adjust to', 'agree', 'assimilate', 'associate', 'assonate', 'atone', 'attune'],
    'synchronized': ['accordant', 'according', 'affirmative', 'agreeable', 'agreeing', 'aligned', 'answerable', 'arranged', 'arrayed', 'assonant', 'assonantal', 'assorted'],
    'synchronous': ['accompanying', 'accordant', 'according', 'affirmative', 'agreeable', 'agreeing', 'answerable', 'associate', 'associated', 'assonant', 'assonantal', 'at one'],
    'syncopation': ['acid rock', 'andante tempo', 'avant-garde jazz', 'ballroom music', 'beat', 'bebop', 'boogie-woogie', 'bop', 'compound time', 'country rock', 'dance music', 'dances'],
    'syncope': ['ko', 'abbreviation', 'abridgment', 'abstract', 'andante tempo', 'apocope', 'aposiopesis', 'beat', 'blackout', 'catalepsy', 'catatonia', 'catatony'],
    'syncretism': ['anschluss', 'addition', 'admixture', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'alloyage', 'amalgamation', 'assimilation', 'association'],
    'syndicalism': ['bolshevikism', 'bolshevism', 'carbonarism', 'castroism', 'jacobinism', 'maoism', 'new left', 'old left', 'sinn feinism', 'anarchism', 'anarcho-syndicalism', 'anarchy'],
    'syndicate': ['aktiengesellschaft', 'black hand', 'british cabinet', 'cosa nostra', 'mafia', 'sanhedrin', 'us cabinet', 'add', 'advisory body', 'affiliate', 'aktiebolag', 'ally'],
    'syndication': ['anschluss', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'amalgamation', 'assimilation', 'association', 'blend', 'blending'],
    'syndrome': ['abnormality', 'acute disease', 'affection', 'affliction', 'ailment', 'allergic disease', 'allergy', 'atrophy', 'bacterial disease', 'birth defect', 'blight', 'cardiovascular disease'],
    'synergistic': ['accompanying', 'accordant', 'agreeing', 'associate', 'associated', 'at one with', 'coacting', 'coactive', 'coadjutant', 'coadjuvant', 'coadunate', 'coefficient'],
    'synergy': ['accompaniment', 'accordance', 'agreement', 'alliance', 'association', 'bipartisanship', 'cahoots', 'co-working', 'coaction', 'coadjuvancy', 'coadministration', 'coagency'],
    'synod': ['british cabinet', 'council of nicaea', 'council of trent', 'lateran council', 'sanhedrin', 'us cabinet', 'vatican council', 'advisory body', 'archbishopric', 'archdiocese', 'assemblee', 'assembly'],
    'synonym': ['doppelganger', 'actual thing', 'antonym', 'articulation', 'carbon copy', 'copy', 'dead ringer', 'ditto', 'double', 'duplicate', 'equivalent', 'exact counterpart'],
    'synonymy': ['agreement', 'biographical dictionary', 'chemical dictionary', 'coequality', 'coincidence', 'congruence', 'correspondence', 'desk dictionary', 'dialect dictionary', 'dictionary', 'dictionary of quotations', 'electronics dictionary'],
    'synopsis': ['abbreviation', 'abbreviature', 'abrege', 'abridgement', 'abridgment', 'abstract', 'apercu', 'apocope', 'breviary', 'brief', 'capsule', 'compend'],
    'synoptic': ['across-the-board', 'all-comprehensive', 'all-inclusive', 'blanket', 'brief', 'compact', 'compendious', 'complete', 'comprehensive', 'concise', 'curt', 'curtal'],
    'syntactic': ['adjectival', 'adverbial', 'attributive', 'conjunctive', 'copulative', 'correct', 'descriptive', 'formal', 'functional', 'glossematic', 'glottochronological', 'grammatic'],
    'syntactics': ['ic analysis', 'appositive', 'attribute', 'attributive', 'bowwow theory', 'comparative linguistics', 'complement', 'construction modifier', 'cutting', 'deep structure', 'derivation', 'descriptive linguistics'],
    'syntax': ['ic analysis', 'allocation', 'allotment', 'apportionment', 'appositive', 'arrangement', 'array', 'arraying', 'attribute', 'attributive', 'collation', 'collocation'],
    'synthesis': ['anschluss', 'baconian method', 'a fortiori reasoning', 'a posteriori reasoning', 'a priori reasoning', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'amalgamation'],
    'synthesize': ['add', 'amalgamate', 'analyze', 'apply reason', 'arrange', 'assemble', 'assimilate', 'blend', 'build', 'build up', 'coalesce', 'combine'],
    'synthesized': ['amalgamated', 'assimilated', 'blended', 'combinative', 'combinatory', 'combined', 'conjoint', 'conjugate', 'conjunctive', 'connective', 'consolidated', 'eclectic'],
    'synthetic': ['adhesive', 'artificial', 'bogus', 'cast plastic', 'cellulose plastic', 'counterfeit', 'ersatz', 'extruded plastic', 'fake', 'false', 'imitation', 'laminate'],
    'syphilis': ['french disease', 'spanish pox', 'vd', 'acquired syphilis', 'balanitis gangrenosa', 'cerebral tabes', 'chancre', 'chancroid', 'clap', 'claps', 'climatic bubo', 'congenital syphilis'],
    'syphilitic': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'cancerous', 'chlorotic', 'colicky', 'consumptive', 'dropsical', 'dyspeptic', 'edematous'],
    'syringe': ['x-ray machine', 'aerosol', 'asperge', 'aspergil', 'aspergillum', 'aspirator', 'atomizer', 'baptize', 'bath', 'bathe', 'bedew', 'bedpan'],
    'syrup': ['adherent', 'adhesive', 'albumen', 'ambrosia', 'artificial sweetener', 'balm', 'balsam', 'barnacle', 'batter', 'blackstrap', 'bonnyclabber', 'bramble'],
    'syrupy': ['adhesive', 'ambrosial', 'amylaceous', 'bittersweet', 'candied', 'clabbered', 'clammy', 'clotted', 'coagulated', 'curdled', 'doughy', 'drippy'],
    'system': ['anschauung', 'copernican universe', 'einsteinian universe', 'mo', 'newtonian universe', 'ptolemaic universe', 'aggregation', 'algorithm', 'all', 'all being', 'all creation', 'allness'],
    'system components': ['actuator', 'amplifier', 'capacitator', 'clock', 'control relay', 'control resistor', 'converter', 'effector', 'feedback amplifier', 'generator', 'inductor', 'magnetic relay'],
    'systematic': ['accordant', 'alike', 'analytical', 'arranged', 'automatic', 'balanced', 'businesslike', 'consistent', 'consonant', 'constant', 'continuous', 'correspondent'],
    'systematically': ['always', 'at every turn', 'at regular intervals', 'at stated times', 'constantly', 'continually', 'every so often', 'harmoniously', 'intermittently', 'invariably', 'like clockwork', 'methodically'],
    'systematics': ['buddhology', 'mariolatry', 'mariology', 'mercersburg theology', 'antonomasia', 'apologetics', 'binomial nomenclature', 'biosystematics', 'biosystematy', 'canonics', 'class', 'classification'],
    'systematize': ['adjust', 'arrange', 'array', 'calculate', 'cast', 'chart', 'codify', 'concert', 'contrive', 'cool off', 'coordinate', 'cut out'],
    'systematized': ['aligned', 'arranged', 'arrayed', 'assorted', 'blueprinted', 'calculated', 'categorized', 'charted', 'classified', 'composed', 'constituted', 'contrived'],
    'systemic': ['acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bug bomb', 'carbamate insecticide', 'chemosterilant', 'contact poison', 'defoliant', 'disinfectant', 'eradicant', 'fumigant'],
    'systole': ['abbreviation', 'arsis', 'astriction', 'astringency', 'beat', 'bottleneck', 'bout', 'cervix', 'circle', 'circuit', 'circumscription', 'coarctation'],
    't group': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 'assertiveness training', 'behavior modification', 'behavior therapy', 'bioenergetics', 'biofeedback', 'confrontation therapy', 'conjoint therapy'],
    't man': ['bow street runner', 'fbi', 'fbi agent', 'federal', 'g-man', 'secret service', 'sherlock holmes', 'detective', 'fed', 'hotel detective', 'house detective', 'house dick'],
    'tab': ['a reckoning of', 'account', 'account of', 'act drop', 'afterpart', 'afterpiece', 'amount', 'appoint', 'asbestos', 'asbestos board', 'assign', 'backdrop'],
    'tabby': ['cheshire cat', 'chinchilla cat', 'maltese cat', 'a tale-bearing animal', 'alley cat', 'banded', 'barred', 'blue cat', 'brinded', 'brindle', 'brindled', 'busybody'],
    'tabernacle': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'ark', 'asperger', 'asperges', 'aspergillum', 'bambino', 'beadroll'],
    'tabes': ['french disease', 'spanish pox', 'vd', 'abscess', 'acquired syphilis', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma'],
    'table': ['domesday book', 'account', 'account book', 'address book', 'adjourn', 'adversaria', 'album', 'alkali flat', 'alluvial plain', 'ambo', 'annals', 'annual'],
    'table of contents': ['acknowledgments', 'back', 'back matter', 'bastard title', 'bibliography', 'blueprint', 'card index', 'catalog', 'catalogue raisonne', 'catch line', 'catchword', 'chart'],
    'tableau': ['grand guignol', 'passion play', 'tom show', 'abstract', 'abstraction', 'act drop', 'altarpiece', 'antimasque', 'arrangement', 'asbestos', 'asbestos board', 'audience success'],
    'tableland': ['alkali flat', 'alluvial plain', 'basin', 'bench', 'bottomland', 'bushveld', 'campo', 'champaign', 'champaign country', 'coastal plain', 'delta', 'desert'],
    'tablet': ['domesday book', 'account book', 'address book', 'adversaria', 'album', 'annual', 'appointment calendar', 'appointment schedule', 'arch', 'barrow', 'blankbook', 'blotter'],
    'tableware': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'cutlery', 'dining utensils', 'dinnerware', 'durable goods', 'durables', 'earthenware', 'enamelware'],
    'tabloid': ['daily', 'daily newspaper', 'even', 'extra', 'extra edition', 'flat', 'flattened', 'flush', 'gazette', 'homaloidal', 'horizontal', 'level'],
    'taboo': ['eighteenth amendment', 'prohibition party', 'volstead act', 'anathema', 'ban', 'banned', 'bar', 'bar out', 'barred', 'barring', 'blockade', 'boycott'],
    'tabula rasa': ['agnosticism', 'blank', 'blank mind', 'blankmindedness', 'blankness', 'bloodless revolution', 'bouleversement', 'breakdown', 'breakup', 'callowness', 'calm of mind', 'cataclysm'],
    'tabular': ['assorted', 'cataloged', 'classified', 'even', 'filed', 'flat', 'flattened', 'flush', 'graded', 'grouped', 'hierarchic', 'homaloidal'],
    'tabulate': ['alphabetize', 'analyze', 'arrange', 'assort', 'book', 'break down', 'calendar', 'carve', 'catalog', 'catalogue', 'categorize', 'chalk'],
    'tabulation': ['analysis', 'arrangement', 'booking', 'cataloging', 'categorization', 'chart', 'chronicling', 'classification', 'codification', 'division', 'enlistment', 'enrollment'],
    'tachycardia': ['abscess', 'ague', 'anemia', 'angina', 'angina pectoris', 'ankylosis', 'anoxia', 'aortic insufficiency', 'aortic stenosis', 'apnea', 'apoplectic stroke', 'apoplexy'],
    'tacit': ['assumed', 'implicit', 'implied', 'inarticulate', 'inferred', 'intimated', 'silent', 'suggested', 'taken for granted', 'undeclared', 'understood', 'unexpressed'],
    'taciturn': ['spartan', 'abbreviated', 'abridged', 'aposiopestic', 'brief', 'brooding', 'brusque', 'clipped', 'close', 'close-lipped', 'close-tongued', 'closemouthed'],
    'tack': ['mo', 'aberrancy', 'aberration', 'about ship', 'affix', 'algorithm', 'alter', 'alteration', 'ameliorate', 'annex', 'append', 'approach'],
    'tack on': ['add', 'adjoin', 'affix', 'agglutinate', 'annex', 'append', 'attach', 'burden', 'complicate', 'conjoin', 'decorate', 'encumber'],
    'tackle': ['accept', 'accouterments', 'amateur athlete', 'apparatus', 'appliances', 'appointments', 'approach', 'appurtenances', 'archer', 'armament', 'assume', 'athlete'],
    'tacky': ['mickey mouse', 'adherent', 'adhesive', 'amylaceous', 'base', 'beat-up', 'bedraggled', 'blowsy', 'blowzy', 'boggy', 'breakable', 'brittle'],
    'tact': ['ability', 'accommodatingness', 'acumen', 'acuteness', 'address', 'adeptness', 'adroitness', 'agreeableness', 'airmanship', 'allergy', 'amenity', 'anaphylaxis'],
    'tactful': ['daedalian', 'accommodating', 'accommodative', 'accurate', 'acute', 'adept', 'adroit', 'affable', 'agreeable', 'allergic', 'anaphylactic', 'appreciative'],
    'tactic': ['action', 'ad hoc measure', 'answer', 'art', 'artful dodge', 'artifice', 'blind', 'campaign', 'caper', 'chicanery', 'conspiracy', 'contrivance'],
    'tactical': ['machiavellian', 'machiavellic', 'acute', 'adept', 'adroit', 'advisable', 'arch', 'arranged', 'artful', 'astute', 'blueprinted', 'cagey'],
    'tactician': ['architect', 'calculator', 'campaigner', 'contriver', 'designer', 'developer', 'deviser', 'enterpriser', 'entrepreneur', 'framer', 'intriguer', 'machinator'],
    'tactics': ['action', 'actions', 'activity', 'acts', 'address', 'aerial tactics', 'affectation', 'air', 'airborne tactics', 'applied tactics', 'approach', 'armored tactics'],
    'tactless': ['abrupt', 'airy', 'awkward', 'blanket', 'bluff', 'blunt', 'boorish', 'brash', 'brusque', 'bungling', 'caddish', 'careless'],
    'tad': ['bairn', 'boy', 'cherub', 'child', 'chit', 'darling', 'innocent', 'kid', 'kitten', 'lad', 'laddie', 'lamb'],
    'tadpole': ['amphibian', 'batrachian', 'birdling', 'bullfrog', 'calf', 'catling', 'chick', 'chickling', 'chicky', 'colt', 'croaker', 'cub'],
    'tag': ['ps', 'parthian shot', 'thule', 'ultima thule', 'accompany', 'add', 'addendum', 'adjoin', 'affix', 'afterpart', 'afterpiece', 'afterthought'],
    'tag along': ['bedog', 'chase', 'come after', 'come behind', 'dog', 'follow', 'go after', 'go behind', 'heel', 'hound', 'move behind', 'pursue'],
    'tail': ['thule', 'ultima thule', 'acknowledgments', 'adherent', 'affix', 'aft', 'after', 'aftermost', 'afterpart', 'afterpiece', 'allonge', 'appendage'],
    'tail wind': ['cat', 'aerospace', 'aerosphere', 'air current', 'air hole', 'air pocket', 'airspace', 'backing wind', 'beam wind', 'bump', 'ceiling', 'crosscurrent'],
    'tailgate': ['around', 'bedog', 'chase', 'clasp', 'cling to', 'come after', 'come behind', 'dog', 'follow', 'follow close upon', 'go after', 'go behind'],
    'tailing': ['bugging', 'chasing', 'cloak-and-dagger work', 'counterespionage', 'counterintelligence', 'dogging', 'electronic surveillance', 'espial', 'espionage', 'following', 'heeling', 'hounding'],
    'tailor': ['accommodate', 'accord', 'accustom', 'adapt', 'adjust', 'adjust to', 'alter', 'assimilate', 'attune', 'block out', 'busheler', 'bushelman'],
    'tailored': ['a propos', 'ad rem', 'adapted', 'applicable', 'apposite', 'appropriate', 'apropos', 'apt', 'becoming', 'befitting', 'bespoke', 'custom-made'],
    'tailpiece': ['accession', 'accessory', 'accompaniment', 'addenda', 'addendum', 'additament', 'addition', 'additive', 'additory', 'additum', 'adjunct', 'adjuvant'],
    'taint': ['abuse', 'adulterate', 'aerial infection', 'afflict', 'aggrieve', 'airborne infection', 'alloy', 'aroma', 'aspersion', 'attaint', 'attribute', 'badge'],
    'tainted': ['abandoned', 'bad', 'bad for', 'bedraggled', 'befouled', 'besmirched', 'blackened', 'blown', 'cankered', 'contaminated', 'corrupt', 'corrupted'],
    'take': ['od', 'abduct', 'abide', 'absorb', 'abstract', 'accede', 'accede to', 'accept', 'accommodate', 'accompany', 'account as', 'accroach'],
    'take a powder': ['absquatulate', 'beat it', 'blow', 'decamp', 'dog it', 'duck and run', 'duck out', 'lam', 'make off', 'powder', 'scram', 'skedaddle'],
    'take aback': ['abash', 'appall', 'astound', 'bowl down', 'bowl over', 'confound', 'discomfit', 'disconcert', 'dismay', 'electrify', 'frighten', 'jar'],
    'take advantage of': ['abuse', 'benefit from', 'bleed', 'bleed white', 'capitalize on', 'carpe diem', 'cash in', 'cash in on', 'deceive', 'drain', 'exploit', 'foist on'],
    'take after': ['ape', 'appear like', 'approach', 'approximate', 'be like', 'be redolent of', 'bear resemblance', 'bring to mind', 'call to mind', 'call up', 'come close', 'come near'],
    'take apart': ['atomize', 'break to pieces', 'cleave', 'defoliate', 'demolish', 'denude', 'disassemble', 'disintegrate', 'dismantle', 'dismember', 'dismount', 'draw and quarter'],
    'take aside': ['accost', 'address', 'apostrophize', 'appeal to', 'approach', 'bespeak', 'breathe', 'buttonhole', 'call to', 'greet', 'hail', 'halloo'],
    'take away': ['abate', 'abrade', 'abridge', 'abstract', 'bate', 'belittle', 'bereave', 'bleed', 'carry away', 'carry off', 'cart away', 'curtail'],
    'take back': ['abjure', 'apologize', 'ask forgiveness', 'assert the contrary', 'back down', 'back out', 'backwater', 'beg indulgence', 'beg pardon', 'belie', 'bring back', 'climb down'],
    'take by storm': ['abduct', 'board', 'breeze', 'carry by storm', 'carry off', 'escalade', 'foray', 'inroad', 'inundate', 'invade', 'kidnap', 'make a raid'],
    'take care': ['attend to business', 'be alert', 'be careful', 'be cautious', 'be obsessed with', 'bend over backwards', 'beware', 'concentrate on', 'exercise care', 'fix on', 'focus on', 'give heed'],
    'take care of': ['accomplish', 'achieve', 'administer to', 'approach', 'attain', 'attend', 'attend on', 'attend to', 'baby-sit', 'be responsible for', 'blast', 'blot out'],
    'take chances': ['brave', 'chance', 'chance it', 'court destruction', 'dare', 'defy danger', 'face up to', 'forget the odds', 'gamble', 'gamble on', 'hazard', 'play with fire'],
    'take charge': ['active', 'acute', 'aggressive', 'animated', 'arrogate', 'assume', 'assume command', 'be able', 'be up to', 'brisk', 'can', 'can do'],
    'take cover': ['bar the gate', 'be incognito', 'bolt the door', 'burrow', 'claim sanctuary', 'disappear', 'drop from sight', 'fly to', 'go into hiding', 'go to ground', 'go underground', 'hide'],
    'take down': ['abase', 'abash', 'admonish', 'bear down', 'beat down', 'blow down', 'blow over', 'book', 'bowl down', 'bowl over', 'break down', 'bring down'],
    'take exception': ['agree to differ', 'agree to disagree', 'ban', 'be at variance', 'be in dissent', 'beg to differ', 'blackball', 'carp', 'catch at straws', 'categorically reject', 'cavil', 'cut up'],
    'take five': ['break', 'breathe', 'call a break', 'call time', 'declare a recess', 'interlude', 'intermit', 'interval', 'intervene', 'knock off', 'lay off', 'pause'],
    'take for': ['account as', 'assume', 'be afraid', 'believe', 'conceive', 'conclude', 'consider', 'daresay', 'deduce', 'deem', 'divine', 'dream'],
    'take for granted': ['accept', 'accept for gospel', 'accept implicitly', 'allegorize', 'allude to', 'anticipate', 'assume', 'be afraid', 'be caught napping', 'be certain', 'be neglectful', 'be negligent'],
    'take from': ['abate', 'abrade', 'abridge', 'abstract', 'bate', 'belittle', 'bereave', 'bleed', 'compress', 'curtail', 'cut', 'cut back'],
    'take home pay': ['base pay', 'compensation', 'consumer price index', 'cost of living', 'cost-of-living index', 'dismissal wage', 'earnings', 'escalator clause', 'escalator plan', 'financial remuneration', 'gross income', 'guaranteed annual wage'],
    'take in': ['abbreviate', 'abridge', 'absorb', 'abstract', 'accept', 'accouple', 'accumulate', 'acquire', 'admit', 'adsorb', 'affect', 'agglutinate'],
    'take into account': ['admit', 'admit exceptions', 'allow', 'allow for', 'assimilate', 'bear in mind', 'complete', 'comprehend', 'comprise', 'concede', 'consider', 'consider the circumstances'],
    'take issue with': ['abjure', 'agree to differ', 'agree to disagree', 'assert the contrary', 'be at cross-purposes', 'be at variance', 'be in dissent', 'beg to differ', 'belie', 'bicker over', 'contend about', 'contest'],
    'take it': ['accede', 'accept', 'account as', 'acquiesce', 'answer', 'assent', 'assume', 'avail', 'be afraid', 'be agreeable', 'be equal to', 'bear'],
    'take it easy': ['be careful', 'be cautious', 'bed', 'bed down', 'calm down', 'coast', 'collect oneself', 'compose oneself', 'cool it', 'cool off', 'couch', 'curl up'],
    'take liberties': ['abuse a privilege', 'be disrespectful', 'be overfamiliar with', 'bother', 'dare', 'deride', 'disesteem', 'disparage', 'disrespect', 'encroach upon', 'get fresh', 'get smart'],
    'take notice': ['animadvert', 'attend', 'bear in mind', 'have regard for', 'heed', 'hold in mind', 'keep in mind', 'keep in sight', 'keep in view', 'look', 'mark', 'mind'],
    'take off': ['abate', 'abscind', 'absquatulate', 'act', 'act a part', 'act as', 'act out', 'advance', 'allow', 'ameliorate', 'amend', 'amputate'],
    'take on': ['accept', 'ache', 'acquire', 'add', 'admit', 'adopt', 'agonize', 'air a grievance', 'annex', 'antagonize', 'append', 'appropriate'],
    'take out': ['abscind', 'amputate', 'annihilate', 'attend', 'avulse', 'ban', 'bar', 'bob', 'chaperon', 'clear away', 'clip', 'conduct'],
    'take over': ['accept', 'acquire', 'admit', 'adopt', 'annex', 'appropriate', 'arrogate', 'assume', 'assume command', 'colonize', 'come by', 'come in for'],
    'take place': ['be found', 'be met with', 'be realized', 'befall', 'betide', 'come', 'come about', 'come down', 'come off', 'come to pass', 'come true', 'eventuate'],
    'take shape': ['come together', 'crystallize', 'draw up', 'fall in', 'fall into line', 'fall into place', 'fall into rank', 'form', 'gather around', 'materialize', 'place itself', 'rally round'],
    'take sides': ['act with', 'align with', 'argue', 'argufy', 'back', 'back up', 'bandy words', 'bicker', 'cavil', 'champion', 'choplogic', 'contend'],
    'take steps': ['act on', 'act upon', 'bear a hand', 'clear the decks', 'consider every angle', 'do something', 'do something about', 'forearm', 'get with it', 'go', 'guard against', 'hedge'],
    'take the cake': ['bear the palm', 'beat', 'beat all hollow', 'best', 'capture', 'carry', 'carry away', 'carry it', 'carry off', 'carry the day', 'clobber', 'come out first'],
    'take time': ['abide', 'await', 'bide', 'bide the issue', 'buy time', 'consume time', 'dally', 'dawdle', 'delay', 'dillydally', 'hang about', 'hang around'],
    'take to': ['addict', 'adjust', 'aim at', 'be desirous of', 'be smitten', 'be used to', 'be wont', 'become attached to', 'bring into play', 'carry on', 'choose', 'conduct'],
    'take to task': ['accuse', 'admonish', 'allege', 'arraign', 'article', 'book', 'bring accusation', 'bring charges', 'bring to account', 'bring to book', 'call to account', 'castigate'],
    'take turns': ['alternate', 'cover', 'do a hitch', 'do a stint', 'do a tour', 'do time', 'enlist', 'fill in for', 'have a go', 'have tenure', 'hold office', 'keep a watch'],
    'take up': ['absorb', 'absorb the attention', 'accept', 'accumulate', 'admit', 'adopt', 'adsorb', 'affiliate', 'agglomerate', 'aggregate', 'aggroup', 'air'],
    'take up with': ['abide', 'abide with', 'advise with', 'associate with', 'assort with', 'bargain', 'bear', 'bear with', 'befriend', 'bide', 'brave', 'brook'],
    'taken unawares': ['ad-lib', 'astonished', 'caught napping', 'caught off balance', 'caught short', 'extemporaneous', 'extemporized', 'haphazard', 'hasty', 'impromptu', 'improvised', 'makeshift'],
    'taken with': ['as compared with', 'attached to', 'beside', 'by comparison with', 'charmed', 'comfortable', 'compared with', 'content', 'contented', 'cozy', 'crazy about', 'delighted'],
    'takeoff': ['alpha', 'anabasis', 'ascension', 'ascent', 'base', 'basis', 'beginning', 'blast-off', 'boarding', 'booster rocket', 'burlesque', 'caricature'],
    'taker': ['accepter', 'acquirer', 'addressee', 'audience', 'auditor', 'beholder', 'captor', 'capturer', 'catcher', 'consignee', 'getter', 'hearer'],
    'taking': ['acceptable', 'acceptance', 'acquisition', 'admission', 'admittance', 'adoption', 'adorable', 'agreeable', 'alluring', 'annexational', 'appealing', 'appetizing'],
    'taking away': ['ablation', 'abrasion', 'abstraction', 'acquisition', 'bereavement', 'claiming', 'cost', 'damage', 'dead loss', 'debit', 'deduction', 'denial'],
    'taking in': ['abduction', 'absorption', 'apprehension', 'arrest', 'arrestation', 'assimilation', 'capture', 'catch', 'catching', 'collaring', 'coup', 'digestion'],
    'taking over': ['accession', 'adoption', 'anointing', 'anointment', 'appointment', 'appropriation', 'arrogation', 'assignment', 'assumption', 'authorization', 'colonization', 'conquest'],
    'taking place': ['accidental', 'accompanying', 'ado', 'afloat', 'afoot', 'circumstantial', 'current', 'doing', 'eventuating', 'going on', 'happening', 'in hand'],
    'talcum powder': ['base', 'clown white', 'cold cream', 'compact', 'cosmetics', 'drugstore complexion', 'eye shadow', 'eyebrow pencil', 'foundation', 'foundation cream', 'greasepaint', 'hand cream'],
    'tale': ['account', 'aggregate', 'all', 'amount', 'anecdotage', 'anecdote', 'back-fence gossip', 'backbiting', 'backstabbing', 'be-all and end-all', 'belittlement', 'blague'],
    'talebearer': ['a tale-bearing animal', 'betrayer', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'busybody', 'canary', 'delator', 'fink', 'gossip', 'gossip columnist'],
    'talebearing': ['back-fence gossip', 'chitchat', 'gossip', 'gossiping', 'gossipmongering', 'gossipry', 'gossipy', 'groundless rumor', 'idle talk', 'newsmongering', 'newsy', 'piece of gossip'],
    'talent': ['geist', 'muse', 'ability', 'ableness', 'acuity', 'acuteness', 'adequacy', 'adroitness', 'afflatus', 'aptitude', 'aptness', 'art'],
    'talented': ['accomplished', 'ace', 'adept', 'adroit', 'apt', 'born for', 'brainy', 'bright', 'brilliant', 'clever', 'crack', 'crackerjack'],
    'taleteller': ['a tale-bearing animal', 'anecdotist', 'busybody', 'fableist', 'fabler', 'fabulist', 'fictionist', 'gossip', 'gossip columnist', 'gossiper', 'gossipmonger', 'mythmaker'],
    'talisman': ['amulet', 'charm', 'fetish', 'fylfot', 'gammadion', 'good-luck charm', 'hoodoo', 'juju', 'love charm', 'luck', 'lucky bean', 'lucky piece'],
    'talk': ['accent', 'accents', 'address', 'advertise', 'after-dinner speech', 'air', 'allocution', 'analyze', 'argot', 'assignment', 'babble', 'back-fence gossip'],
    'talk back': ['acknowledge', 'answer', 'answer back', 'come back', 'come back at', 'echo', 'flash back', 'give acknowledgment', 'give answer', 'lip', 'provoke', 'react'],
    'talk big': ['barnumize', 'aggrandize', 'amplify', 'ballyhoo', 'blow', 'blow off', 'blowhard', 'bombast', 'build up', 'burlesque', 'caricature', 'carry too far'],
    'talk down': ['alight', 'come down', 'come in', 'crash-land', 'descend', 'ditch', 'downwind', 'filibuster', 'land', 'level off', 'light', 'outlast'],
    'talk into': ['argue into', 'bring around', 'bring over', 'bring round', 'bring to reason', 'captivate', 'charm', 'con', 'convince', 'draw', 'draw over', 'gain'],
    'talk nonsense': ['babble', 'blab', 'blabber', 'blather', 'blether', 'bull', 'bullshit', 'chat', 'chatter', 'clack', 'clatter', 'dither'],
    'talk over': ['advise with', 'air', 'analyze', 'argue into', 'assure', 'bargain', 'be convincing', 'bring home to', 'bring over', 'bring round', 'bring to reason', 'call in'],
    'talk show': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger', 'closet drama'],
    'talk to': ['accost', 'address', 'apostrophize', 'appeal to', 'approach', 'bespeak', 'buttonhole', 'call down', 'call to', 'come down on', 'dress down', 'give it to'],
    'talkathon': ['address', 'after-dinner speech', 'allocution', 'chalk talk', 'cloture', 'committee consideration', 'debate', 'declamation', 'deliberation', 'diatribe', 'division', 'eulogy'],
    'talkative': ['accessible', 'all jaw', 'apocalyptic', 'approachable', 'articulate', 'betraying', 'candid', 'chatty', 'communicative', 'conversable', 'conversational', 'de longue haleine'],
    'talked about': ['acclaimed', 'afloat', 'bandied about', 'bruited about', 'celebrated', 'common', 'commonly known', 'commonplace', 'current', 'distinguished', 'fabled', 'famed'],
    'talkee talkee': ['beach-la-mar', 'kitchen kaffir', 'oregon jargon', 'sabir', 'abuse of terms', 'anacoluthon', 'auxiliary language', 'babble', 'babblement', 'bad grammar', 'bavardage', 'bibble-babble'],
    'talker': ['blatherskite', 'blowhard', 'blusterer', 'chatterbox', 'collocutor', 'colloquialist', 'conversational partner', 'conversationalist', 'converser', 'debater', 'declaimer', 'demagogue'],
    'talkie': ['cinemascope', 'cinerama', 'technicolor', 'western', 'animated cartoon', 'black-and-white film', 'cartoon', 'chiller', 'cinema', 'color film', 'creepie', 'documentary'],
    'talking': ['esp', 'accents', 'answer', 'articulate', 'chatter', 'comment', 'commerce', 'communication', 'communion', 'congress', 'connection', 'contact'],
    'talky': ['all jaw', 'candid', 'chatty', 'communicative', 'conversational', 'effusive', 'expansive', 'flip', 'fluent', 'frank', 'gabby', 'garrulous'],
    'tall': ['gongoresque', 'johnsonian', 'a bit thick', 'a bit thin', 'a mile long', 'absurd', 'affected', 'altitudinous', 'bedizened', 'beyond belief', 'big', 'big-sounding'],
    'tall story': ['big talk', 'blague', 'bullshit', 'bunk', 'bunkum', 'cock-and-bull story', 'exaggeration', 'fairy tale', 'falsehood', 'falsity', 'fancy talk', 'farfetched story'],
    'tallow': ['animal oil', 'cerate', 'drying oil', 'essential oil', 'ester', 'fat', 'fatty oil', 'fixed oil', 'grease', 'hydrogenated fat', 'lipid', 'mineral oil'],
    'tallowy': ['adipose', 'blubbery', 'buttery', 'butyraceous', 'chrismal', 'chrismatory', 'fat', 'fatty', 'greasy', 'lardaceous', 'lardy', 'mucoid'],
    'tally': ['a reckoning of', 'accommodate', 'accommodate with', 'accord', 'accordance', 'account', 'account current', 'account of', 'account rendered', 'account stated', 'accounting', 'acta'],
    'talmud': ['gemara', 'masorah', 'mishnah', 'spiritus mundi', 'sunna', 'ancient wisdom', 'archetypal myth', 'archetypal pattern', 'common law', 'custom', 'folk motif', 'folklore'],
    'talons': ['administration', 'authority', 'claws', 'clutches', 'command', 'control', 'digits', 'disposition', 'domination', 'dominion', 'empery', 'empire'],
    'tambourine': ['bongo drum', 'conga', 'drum', 'drumhead', 'drumskin', 'drumstick', 'jazz stick', 'kettle', 'kettledrum', 'membranophone', 'side drum', 'snare'],
    'tame': ['abate', 'abeyant', 'acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'allay', 'alleviate', 'amenable', 'apathetic'],
    'tamed': ['broken', 'brought low', 'chastened', 'crushed', 'domesticated', 'dovelike', 'gentle', 'housebroke', 'housebroken', 'humble', 'humbled', 'humiliated'],
    'tamer': ['breaker', 'breeder', 'broncobuster', 'buckaroo', 'cattleman', 'cow keeper', 'cowman', 'dairy farmer', 'dairyman', 'equerry', 'farrier', 'grazier'],
    'taming': ['acclimation', 'acclimatization', 'accommodation', 'accustoming', 'adaption', 'adjustment', 'breaking', 'breaking-in', 'case hardening', 'conditioning', 'conquering', 'crushing'],
    'tammany hall': ['american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party', 'greenback party'],
    'tamp': ['assault', 'bear', 'bear upon', 'boost', 'buck', 'bull', 'bulldoze', 'bump', 'bump against', 'bunt', 'butt', 'butt against'],
    'tamper with': ['paul-pry', 'adulterate', 'approach', 'bastardize', 'bribe', 'busybody', 'butt in', 'buy', 'buy off', 'contaminate', 'cook', 'corrupt'],
    'tampon': ['ace bandage', 'band-aid', 'adhesive tape', 'application', 'band', 'bandage', 'bandaging', 'binder', 'brace', 'cast', 'cataplasm', 'compress'],
    'tan': ['arrange', 'beige', 'bronze', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'burn', 'chocolate', 'cinnamon', 'clear for action', 'clear the decks'],
    'tandem': ['back to back', 'behind', 'behind the scenes', 'equipage', 'four-in-hand', 'in back of', 'in the background', 'in the rear', 'pair', 'randem', 'rig', 'span'],
    'tang': ['aftertaste', 'aroma', 'attribute', 'badge', 'beesting', 'bite', 'bitter', 'brand', 'briskness', 'cachet', 'cast', 'character'],
    'tangent': ['abutter', 'adjoiner', 'air line', 'approach', 'asymptote', 'axis', 'beeline', 'borderer', 'bottleneck', 'bystander', 'chord', 'collision course'],
    'tangential': ['approaching', 'asymptotic', 'brushing', 'centripetal', 'centrolineal', 'concurrent', 'confluent', 'confocal', 'connivent', 'contacting', 'contingent', 'converging'],
    'tangibility': ['apparentness', 'body', 'clearness', 'concreteness', 'crystal-clearness', 'density', 'distinctness', 'durability', 'evidence', 'evidentness', 'firmness', 'manifestness'],
    'tangible': ['actual', 'apparent', 'appreciable', 'assessed valuation', 'assets', 'assets and liabilities', 'atoms', 'bodily', 'circumstances', 'clear', 'clear as crystal', 'concrete'],
    'tangle': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 'a outrance', 'absorb', 'allure', 'bag', 'bait the hook', 'ball up', 'bandy with', 'battle', 'battle it out'],
    'tangled': ['byzantine', 'balled up', 'complex', 'complicated', 'confounded', 'confused', 'convoluted', 'crabbed', 'daedal', 'devious', 'elaborate', 'embrangled'],
    'tangy': ['brisk', 'burning', 'curried', 'high-seasoned', 'hot', 'hot as pepper', 'lively', 'nippy', 'peppery', 'racy', 'seasoned', 'snappy'],
    'tank': ['pullman', 'pullman car', 'archives', 'armory', 'arsenal', 'artificial lake', 'attic', 'bag', 'baggage car', 'bank', 'barrel', 'basement'],
    'tanked': ['afflicted', 'bent', 'boiled', 'bombed', 'boozy', 'canned', 'cockeyed', 'cockeyed drunk', 'crocked', 'crocko', 'disguised', 'drunk'],
    'tanker': ['argosy', 'ark', 'bathyscaphe', 'caravel', 'cargo ship', 'coast guard cutter', 'coaster', 'collier', 'derelict', 'dredge', 'fishing boat', 'freighter'],
    'tanned': ['beige', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'chocolate', 'cinnamon', 'cocoa', 'cocoa-brown', 'coffee', 'coffee-brown', 'drab'],
    'tannery': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery', 'brewery', 'brickyard', 'cannery'],
    'tantalize': ['affect the interest', 'allure', 'annoy', 'appeal', 'attract', 'badger', 'baffle', 'bait', 'balk', 'be attractive', 'becharm', 'beckon'],
    'tantalizing': ['acceptable', 'adorable', 'agitating', 'agreeable', 'alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'breathtaking'],
    'tantamount': ['alike', 'all one', 'all the same', 'analogous', 'answering', 'coequal', 'complemental', 'complementary', 'convertible', 'coordinate', 'correspondent', 'corresponding'],
    'tantrum': ['cat fit', 'conniption', 'conniption fit', 'convulsion', 'duck fit', 'eruption', 'explosion', 'fit', 'fit of anger', 'fit of temper', 'flare-up', 'fury'],
    'tap': ['gramophone', 'pa', 'pa system', 'victrola', 'abridge', 'adjutage', 'air hole', 'appoint', 'armhole', 'at hand', 'attend', 'attend to'],
    'tape': ['ace bandage', 'band-aid', 'mystik tape', 'scotch tape', 'accouple', 'accumulate', 'adhesive tape', 'agglutinate', 'amass', 'application', 'articulate', 'assemble'],
    'tape measure': ['mystik tape', 'scotch tape', 'adhesive tape', 'band', 'bandage', 'batten', 'belt', 'cellophane tape', 'cloth tape', 'fascia', 'fillet', 'friction tape'],
    'tape memory': ['mnemosyne', 'ram', 'affect memory', 'anterograde memory', 'atavism', 'collective memory', 'computer memory', 'disk memory', 'drum memory', 'emotional response', 'engram', 'high-speed memory'],
    'tape recorder': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'taper': ['abate', 'aculeate', 'acuminate', 'approach', 'barb', 'bate', 'bayberry candle', 'bougie', 'brand', 'butane lighter', 'candle', 'candlewick'],
    'tapered': ['acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'barbed', 'cone-shaped', 'cornuted', 'cusped'],
    'tapering': ['acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'barbed', 'coarctation', 'cone-shaped', 'constriction'],
    'tapestry': ['abstract', 'abstraction', 'altarpiece', 'block print', 'collage', 'color print', 'copy', 'cyclorama', 'daub', 'diptych', 'engraving', 'fresco'],
    'tapeworm': ['chilopoda', 'chordata', 'echiuroidea', 'ectoprocta', 'entoprocta', 'monoplacophora', 'nemertinea', 'phoronidea', 'angleworm', 'appetite', 'canine appetite', 'drought'],
    'tapping': ['aspiration', 'banging', 'blasting', 'bleeding', 'bloodletting', 'broaching', 'bursting', 'cracking', 'crashing', 'cupping', 'drafting', 'drainage'],
    'taproom': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'cabaret', 'cafe', 'cocktail lounge', 'dive'],
    'taproot': ['beginning', 'bulb', 'bulbil', 'commencement', 'conception', 'corm', 'derivation', 'genesis', 'grass roots', 'head', 'inception', 'origin'],
    'taps': ['angelus', 'angelus bell', 'alarm', 'alarum', 'battle cry', 'bay', 'beep', 'birdcall', 'blare', 'blast', 'blat', 'bray'],
    'tar': ['ab', 'amytal', 'amytal pill', 'ancient mariner', 'argonaut', 'demerol', 'dolophine', 'dylan', 'flying dutchman', 'luminal', 'luminal pill', 'mickey finn'],
    'tarantula': ['arachnid', 'arthropod', 'beetle', 'bug', 'caterpillar', 'centipede', 'chilopod', 'daddy longlegs', 'diplopod', 'fly', 'harvestman', 'hexapod'],
    'tardiness': ['anachronism', 'antedating', 'anticipation', 'belatedness', 'earliness', 'eleventh hour', 'high time', 'historical error', 'last minute', 'late hour', 'lateness', 'metachronism'],
    'tardy': ['ahead of time', 'anachronistic', 'antedated', 'arrested', 'back', 'backward', 'beforehand', 'behind', 'behind time', 'behindhand', 'belated', 'blocked'],
    'tare': ['abatement', 'agio', 'allowance', 'bank discount', 'bones', 'breakage', 'cash discount', 'chaff', 'chain discount', 'charge-off', 'concession', 'culm'],
    'target': ['aim', 'alpha decay', 'atom-chipping', 'atom-smashing', 'atomic disintegration', 'atomic reaction', 'atomization', 'beta decay', 'bombardment', 'breeding', 'bullet', 'butt'],
    'target date': ['a-day', 'd day', 'h hour', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bourn', 'break boundary', 'breakoff point', 'ceiling'],
    'tariff': ['vat', 'ad valorem duty', 'alcohol tax', 'amusement tax', 'assessment', 'assessment on default', 'bill of fare', 'capital gains tax', 'capitation', 'capitation tax', 'cess', 'charge'],
    'tarnish': ['achromatize', 'asperse', 'aspersion', 'attaint', 'badge of infamy', 'bar sinister', 'baton', 'bedaub', 'befoul', 'begrime', 'benasty', 'bend sinister'],
    'tarnished': ['bedraggled', 'befouled', 'besmirched', 'blackened', 'darkened', 'defiled', 'dirtied', 'discolored', 'drabbled', 'draggled', 'fouled', 'foxed'],
    'tarry': ['abide', 'await', 'be still', 'bide', 'bide the issue', 'carry on', 'cease not', 'coast', 'continue', 'continue to be', 'crawl', 'creep'],
    'tarrying': ['dalliance', 'dallying', 'dawdling', 'delaying', 'dilatoriness', 'dilatory', 'dillydallying', 'dolce far niente', 'dragging', 'goofing off', 'idling', 'lag'],
    'tarsus': ['ankle', 'bayonet legs', 'bowlegs', 'calf', 'cnemis', 'drumstick', 'foreleg', 'gamb', 'gambrel', 'gigot', 'ham', 'hind leg'],
    'tart': ['danish pastry', 'french pastry', 'jezebel', 'abusive', 'acerb', 'acerbate', 'acerbic', 'acescent', 'acetose', 'acetous', 'acid', 'acidic'],
    'tartan': ['armory', 'badge', 'badge of office', 'badges', 'baton', 'blazonry', 'brassard', 'button', 'cap and gown', 'chain', 'chain of office', 'check'],
    'tartuffe': ['holy willie', 'joseph surface', 'mawworm', 'pecksniff', 'pharisee', 'affecter', 'canter', 'canting hypocrite', 'dissembler', 'dissimulator', 'fair-weather friend', 'false friend'],
    'tarzan': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'goliath', 'hercules', 'polyphemus', 'samson', 'superman', 'titan'],
    'task': ['accuse', 'affair', 'agency', 'agentship', 'allege', 'arraign', 'article', 'assignment', 'attempt', 'authority', 'authorization', 'blame'],
    'task force': ['kp', 'naval construction battalion', 'rn', 'royal navy', 'seabees', 'usn', 'united states navy', 'argosy', 'armada', 'army', 'army group', 'battalion'],
    'taskmaster': ['big brother', 'simon legree', 'auditor', 'boatswain', 'boss', 'chief', 'comptroller', 'controller', 'floor manager', 'floorman', 'floorwalker', 'foreman'],
    'taste': ['atticism', 'affection', 'affinity', 'appetence', 'appetite', 'appreciate', 'appreciation', 'appreciation of differences', 'appreciativeness', 'apprehend', 'appropriateness', 'aroma'],
    'taste maker': ['beau brummel', 'arbiter of fashion', 'clotheshorse', 'clubman', 'clubwoman', 'dandy', 'deb', 'debutante', 'fashion plate', 'fashionable', 'fop', 'man-about-town'],
    'tasteful': ['attic', 'ciceronian', 'aesthetic', 'appetizing', 'art-conscious', 'artistic', 'arty', 'beautiful', 'charming', 'chaste', 'choice', 'classic'],
    'tastefully': ['aesthetically', 'artistically', 'becomingly', 'decently', 'decorously', 'discriminately', 'discriminatingly', 'discriminatively', 'elegantly', 'genteelly', 'gracefully', 'in good taste'],
    'tasteless': ['doric', 'arid', 'barbarian', 'barbaric', 'barbarous', 'barren', 'base', 'blah', 'bland', 'blank', 'bloodless', 'boorish'],
    'tasting': ['appetite', 'cannibalism', 'carnivorism', 'carnivority', 'carnivorousness', 'chewing', 'compotation', 'consumption', 'cropping', 'deglutition', 'devouring', 'devourment'],
    'tasty': ['agreeable', 'ambrosial', 'appetizing', 'dainty', 'delectable', 'delicate', 'delicious', 'delightful', 'exquisite', 'flavorful', 'flavorous', 'flavorsome'],
    'tater': ['irish potato', 'kraut', 'aubergine', 'beans', 'cabbage', 'eggplant', 'greens', 'legumes', 'love apple', 'mad apple', 'pieplant', 'potato'],
    'tatter': ['ablate', 'abrade', 'barrel', 'beeline', 'bit', 'bits', 'bullet', 'butt', 'chip', 'chunk', 'clip', 'clipping'],
    'tattered': ['beat-up', 'bedraggled', 'blowzy', 'broken-down', 'careless', 'chintzy', 'cleft', 'cloven', 'cracked', 'cut', 'dilapidated', 'dingy'],
    'tattle': ['babble', 'back-fence gossip', 'be indiscreet', 'be unguarded', 'bear witness against', 'betray', 'betray a confidence', 'blab', 'blabber', 'blather', 'blether', 'blow the whistle'],
    'tattletale': ['a tale-bearing animal', 'betrayer', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'busybody', 'delator', 'fink', 'gossip', 'gossip columnist', 'gossiper'],
    'tattoo': ['band', 'bang', 'bar', 'barrage', 'bash', 'bat', 'bay', 'beat', 'beating', 'beep', 'belt', 'bespangle'],
    'tatty': ['base', 'common', 'dowdy', 'down-at-heel', 'down-at-the-heels', 'frayed', 'frazzled', 'full of holes', 'holey', 'in rags', 'in shreds', 'in tatters'],
    'taunt': ['bronx cheer', 'parthian shot', 'accuse', 'affront', 'allege', 'annoy', 'arraign', 'article', 'aspersion', 'atrocity', 'back answer', 'banter'],
    'taunting': ['banter', 'bantering', 'booing', 'catcalling', 'chaffing', 'derision', 'derisive', 'derisory', 'fleering', 'flippancy', 'flippant', 'fooling'],
    'taupe': ['quaker-colored', 'acier', 'ashen', 'ashy', 'beige', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'canescent', 'chocolate', 'cinereous'],
    'taut': ['all ataunto', 'anxious', 'apprehensive', 'ataunt', 'bungup and bilge-free', 'close', 'dragged out', 'drawn', 'drawn out', 'elongated', 'extended', 'firm'],
    'tauten': ['continue', 'crank', 'crank in', 'drag out', 'draw', 'draw in', 'draw out', 'draw taut', 'elongate', 'extend', 'lengthen', 'lengthen out'],
    'tautologous': ['abundant', 'battological', 'copious', 'de trop', 'diffuse', 'diffusive', 'dispensable', 'duplicative', 'echoic', 'echoing', 'effusive', 'excess'],
    'tautology': ['abundance', 'amplitude', 'battology', 'bedizenment', 'circumambages', 'circumbendibus', 'circumlocution', 'cloud of words', 'copiousness', 'diffuseness', 'diffusion', 'diffusiveness'],
    'tavern': ['alehouse', 'amusement park', 'automat', 'ballroom', 'bar', 'barrel house', 'barroom', 'beanery', 'beer garden', 'beer parlor', 'bistro', 'blind tiger'],
    'tawdry': ['blatant', 'brazen', 'brazenfaced', 'brummagem', 'cheap', 'cheapjack', 'chintzy', 'colorful', 'common', 'crude', 'extravagant', 'flagrant'],
    'tawny': ['beige', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'chocolate', 'cinnamon', 'cocoa', 'cocoa-brown', 'coffee', 'coffee-brown', 'drab'],
    'tax': ['accuse', 'allege', 'arraign', 'article', 'ask', 'assess', 'assessment', 'bear hard upon', 'blackmail', 'boodle', 'book', 'bring accusation'],
    'tax collector': ['internal revenue service', 'accumulator', 'assessor', 'bill collector', 'collection agent', 'collector', 'connoisseur', 'customhouse', 'customs', 'douanier', 'dunner', 'exciseman'],
    'tax exemption': ['assessment', 'cess', 'conscience money', 'contribution', 'direct tax', 'duty', 'graduated taxation', 'imposition', 'impost', 'indirect tax', 'joint return', 'levy'],
    'tax return': ['assessment', 'cess', 'conscience money', 'contribution', 'direct tax', 'duty', 'graduated taxation', 'imposition', 'impost', 'indirect tax', 'joint return', 'levy'],
    'taxation': ['assessment', 'cess', 'conscience money', 'contribution', 'direct tax', 'duty', 'graduated taxation', 'imposition', 'impost', 'indirect tax', 'joint return', 'levy'],
    'taxed': ['accused', 'arraigned', 'blamed', 'burdened', 'charged', 'cited', 'cumbered', 'denounced', 'encumbered', 'fraught', 'freighted', 'hampered'],
    'taxi': ['autobus', 'become airborne', 'bicycle', 'bike', 'bus', 'cab', 'catch a train', 'chartered bus', 'chauffeur', 'clear', 'cycle', 'diligence'],
    'taxidermist': ['audubon society', 'national wildlife service', 'sierra club', 'animal physiologist', 'anthropologist', 'biologist', 'conchologist', 'conservationist', 'conservator', 'deliverer', 'ecologist', 'entomologist'],
    'taxidermy': ['anatomy', 'anhydration', 'animal physiology', 'anthropology', 'biology', 'blast-freezing', 'bottling', 'brining', 'canning', 'comparative anatomy', 'conchology', 'corning'],
    'taxidriver': ['sunday driver', 'backseat driver', 'bus driver', 'busman', 'cabby', 'cabdriver', 'chauffeur', 'driver', 'hack', 'hackdriver', 'hackman', 'hacky'],
    'taxing': ['accusal', 'accusation', 'accusing', 'allegation', 'allegement', 'arraignment', 'bale', 'bill of particulars', 'blackmail', 'blame', 'bother', 'bringing of charges'],
    'taxonomy': ['aerobiology', 'agrobiology', 'analysis', 'anatomy', 'animal physiology', 'anthropology', 'antonomasia', 'arrangement', 'assortment', 'astrobiology', 'bacteriology', 'binomial nomenclature'],
    'tea': ['det', 'dmt', 'lsd', 'mary', 'mary jane', 'stp', 'thc', 'tv dinner', 'acid', 'afternoon tea', 'alfresco meal', 'antidepressant'],
    'teach': ['broaden the mind', 'catechize', 'civilize', 'coach', 'communicate', 'demonstrate', 'direct', 'discipline', 'drill', 'edify', 'educate', 'enlighten'],
    'teach in': ['beef', 'bitch', 'boycott', 'challenge', 'complaint', 'compunction', 'demonstration', 'demur', 'demurrer', 'exception', 'expostulation', 'grievance'],
    'teachable': ['apt', 'bright', 'clever', 'docile', 'educable', 'facile', 'formable', 'homely', 'humble', 'humble-looking', 'humble-visaged', 'humblest'],
    'teacher': ['aaronic priesthood', 'dutch uncle', 'melchizedek priesthood', 'polonius', 'seventy', 'admonisher', 'adviser', 'advisor', 'apostle', 'backseat driver', 'bishop', 'boss'],
    'teaching': ['a belief', 'adage', 'ana', 'analects', 'aphorism', 'apothegm', 'article of faith', 'assignment', 'autodidactic', 'axiom', 'belief', 'byword'],
    'teachy': ['academic', 'donnish', 'moral', 'moralizing', 'pedagogic', 'pedantic', 'preachy', 'preceptorial', 'professorial', 'professorlike', 'schoolmastering', 'schoolmasterish'],
    'team': ['age group', 'band', 'battalion', 'bevy', 'body', 'both', 'brace', 'bracket', 'brigade', 'bunch', 'cabal', 'cast'],
    'team spirit': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'amity', 'bipartisanship', 'bonds of harmony', 'brotherly love', 'caritas', 'cement of friendship', 'charity'],
    'team up': ['act in concert', 'act together', 'act with', 'affiliate', 'affiliate with', 'align with', 'ally', 'amalgamate', 'associate', 'band', 'band together', 'be in cahoots'],
    'teamed': ['affiliate', 'affiliated', 'allied', 'associate', 'associated', 'cabalistic', 'confederate', 'confederated', 'conspiratorial', 'corporate', 'coupled', 'enleagued'],
    'teammate': ['ace', 'amigo', 'associate', 'bedfellow', 'bedmate', 'benchfellow', 'birthmate', 'bosom buddy', 'buddy', 'bunkie', 'bunkmate', 'butty'],
    'teamster': ['jehu', 'sunday driver', 'backseat driver', 'bullwhacker', 'bus driver', 'busman', 'cabby', 'cabdriver', 'cabman', 'cameleer', 'carter', 'cartman'],
    'teamwork': ['bipartisanship', 'coaction', 'coadjuvancy', 'coadministration', 'coagency', 'cochairmanship', 'codirectorship', 'collaboration', 'collaborativeness', 'collectivism', 'collusion', 'commensalism'],
    'tear': ['abrade', 'abrasion', 'amputate', 'assault', 'attack', 'autacoid', 'ax', 'bacchanal', 'bacchanalia', 'bacchanalian', 'ball the jack', 'barbarize'],
    'tear apart': ['atomize', 'break to pieces', 'carp', 'catch at straws', 'cavil', 'cleave', 'cut up', 'defoliate', 'demolish', 'denude', 'disassemble', 'disintegrate'],
    'tear down': ['annihilate', 'asperse', 'beat down', 'blow down', 'break down', 'bring down', 'bulldoze', 'burn down', 'calumniate', 'cast down', 'chop down', 'cut down'],
    'tear from': ['badger', 'blackmail', 'claim', 'demand', 'exact', 'extort', 'force from', 'levy blackmail', 'pry loose from', 'rend', 'rend from', 'rip'],
    'tear gas grenade': ['aerial bomb', 'antipersonnel bomb', 'bomb', 'bombshell', 'carcass', 'concussion grenade', 'depth bomb', 'depth charge', 'fire bomb', 'gas grenade', 'grenade', 'hand grenade'],
    'tear jerking': ['bathetic', 'beery', 'cloying', 'gooey', 'gushing', 'maudlin', 'mawkish', 'mushy', 'namby-pamby', 'nostalgic', 'nostomanic', 'oversentimental'],
    'tear loose': ['break loose', 'break out', 'clear', 'cut loose', 'disembarrass', 'disembroil', 'disengage', 'disentangle', 'disinvolve', 'dislodge', 'extricate', 'free'],
    'tear out': ['avulse', 'cut out', 'dash off', 'deracinate', 'dig out', 'dig up', 'disentangle', 'draw', 'draw out', 'dredge', 'dredge up', 'eradicate'],
    'tear to pieces': ['atomize', 'break to pieces', 'carp', 'catch at straws', 'cavil', 'cleave', 'cut up', 'defoliate', 'demolish', 'denude', 'disassemble', 'disintegrate'],
    'teardrop': ['bawling', 'bead', 'blubbering', 'chyle', 'colostrum', 'cry', 'crying', 'dewdrop', 'discharge', 'drop', 'droplet', 'fit of crying'],
    'tearful': ['aggrieved', 'anguished', 'blubbering', 'careworn', 'crying', 'dissolved in tears', 'doleful', 'dolorous', 'dumb with grief', 'grief-stricken', 'griefful', 'grieved'],
    'tearjerker': ['bathos', 'bleeding heart', 'cloyingness', 'goo', 'hearts-and-flowers', 'maudlinness', 'mawkishness', 'mush', 'mushiness', 'namby-pamby', 'namby-pambyism', 'namby-pambyness'],
    'tearoom': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop'],
    'teary': ['bathetic', 'beery', 'blubbering', 'cloying', 'crying', 'dissolved in tears', 'gooey', 'gushing', 'in tears', 'lachrymal', 'lachrymose', 'lacrimatory'],
    'tease': ['artful dodger', 'casanova', 'don juan', 'machiavel', 'machiavelli', 'machiavellian', 'actor', 'aggravate', 'annoy', 'annoyer', 'appeal', 'apply pressure'],
    'teaser': ['artful dodger', 'casanova', 'circe', 'don juan', 'gordian knot', 'lorelei', 'machiavel', 'machiavelli', 'machiavellian', 'parthenope', 'siren', 'act drop'],
    'teasing': ['aggravating', 'alluring', 'annoying', 'appealing', 'appetizing', 'attractive', 'bantering', 'beguiling', 'bewitching', 'blandishing', 'blandishment', 'booing'],
    'teat': ['bag', 'boobs', 'bosom', 'breast', 'breasts', 'brisket', 'bust', 'chest', 'crop', 'dug', 'knockers', 'mama'],
    'teatime': ['tv dinner', 'alfresco meal', 'barbecue', 'breakfast', 'brunch', 'buffet supper', 'clambake', 'coffee break', 'cookout', 'diner', 'dinner', 'elevenses'],
    'technical': ['accomplished', 'applied', 'at concert pitch', 'authoritative', 'back-burner', 'career', 'coached', 'complex', 'complicated', 'confined', 'conversant', 'detailed'],
    'technicality': ['a little thing', 'area', 'bag', 'complexity', 'complexness', 'complication', 'convolution', 'crabbedness', 'cup of tea', 'entanglement', 'field', 'forte'],
    'technician': ['admirable crichton', 'adept', 'aficionado', 'amateur', 'apprentice', 'artificer', 'artisan', 'artist', 'attache', 'authority', 'buff', 'connaisseur'],
    'technicolor': ['cinemascope', 'cinerama', 'western', 'animated cartoon', 'black-and-white film', 'bright color', 'brightness', 'brilliance', 'cartoon', 'chiller', 'cinema', 'color'],
    'technics': ['academic discipline', 'academic specialty', 'acquaintance', 'applied science', 'area', 'arena', 'art', 'concern', 'corpus', 'craft', 'data', 'datum'],
    'technique': ['mo', 'sop', 'ability', 'acquaintance', 'address', 'adeptness', 'adroitness', 'airmanship', 'algorithm', 'approach', 'aptitude', 'arrangement'],
    'technology': ['academic discipline', 'academic specialty', 'applied science', 'area', 'arena', 'art', 'concern', 'craft', 'department of knowledge', 'discipline', 'domain', 'field'],
    'tectology': ['anatomist', 'anatomy', 'angiography', 'angiology', 'anthropotomy', 'geomorphology', 'histologist', 'histology', 'morphologist', 'morphology', 'myography', 'myology'],
    'tectonics': ['anatomy', 'architectonics', 'architecture', 'arrangement', 'build', 'building', 'composition', 'conformation', 'constitution', 'construction', 'creation', 'fabric'],
    'tedious': ['alliterating', 'alliterative', 'arid', 'assonant', 'automatic', 'banal', 'barren', 'belabored', 'betwixt and between', 'blah', 'blank', 'bloodless'],
    'tedium': ['alliteration', 'angst', 'anguish', 'anxiety', 'assonance', 'banality', 'boredom', 'changelessness', 'cheerlessness', 'chime', 'colorlessness', 'dingdong'],
    'tee hee': ['homeric laughter', 'be in stitches', 'belly laugh', 'boff', 'boffola', 'break up', 'burst into laughter', 'burst of laughter', 'burst out', 'burst out laughing', 'burst with laughter', 'bust a gut'],
    'teem': ['abound', 'abound with', 'be alive with', 'be fruitful', 'be productive', 'beget', 'bespread', 'bristle', 'bristle with', 'burst with', 'bustle', 'clutter'],
    'teeming': ['abounding', 'abundant', 'affluent', 'alive with', 'all-sufficing', 'ample', 'anticipating', 'aplenty', 'beset', 'big with child', 'big-laden', 'blooming'],
    'teenager': ['adolescent', 'baby', 'boy', 'fledgling', 'girl', 'hopeful', 'infant', 'junior', 'juvenal', 'juvenile', 'kid', 'minor'],
    'teens': ['sexagesima', 'awkward age', 'boxcar', 'boxcars', 'dozen', 'duodecimo', 'eighty', 'eleven', 'fifteen', 'fifty', 'five and twenty', 'fortnight'],
    'teenybopper': ['babbitt', 'middle american', 'philistine', 'adolescent', 'anal character', 'babe', 'baby', 'bourgeois', 'broad', 'burgher', 'chick', 'colleen'],
    'teeter': ['lissajous figure', 'alternate', 'alternation', 'back and fill', 'back-and-forth', 'balance', 'battledore and shuttlecock', 'change', 'come and go', 'coming and going', 'cower', 'dither'],
    'teeter totter': ['ferris wheel', 'lissajous figure', 'alternate', 'alternation', 'back and fill', 'back-and-forth', 'battledore and shuttlecock', 'carousel', 'chute-the-chutes', 'chutes', 'come and go', 'coming and going'],
    'teetering': ['lissajous figure', 'alternation', 'back-and-forth', 'coming and going', 'dilapidated', 'doddering', 'ebb and flow', 'fluctuation', 'flux and reflux', 'groggy', 'oscillation', 'pendulation'],
    'teeth': ['acerbity', 'acidity', 'acridity', 'acrimony', 'alveolar ridge', 'alveolus', 'apex', 'arytenoid cartilages', 'astringency', 'back', 'bird cage', 'bite'],
    'telecast': ['tv show', 'accessible', 'affirmed', 'announced', 'broadcast', 'brought to notice', 'canned show', 'circulated', 'colorcast', 'common knowledge', 'common property', 'current'],
    'telecommunication': ['communication engineering', 'communication explosion', 'communication technology', 'communication theory', 'communications', 'communications engineer', 'communications industry', 'communications medium', 'communications network', 'electrical communication', 'electronic communication', 'electronic communications'],
    'telegram': ['teletype', 'advice', 'cable', 'cablegram', 'communication', 'communique', 'day letter', 'dispatch', 'embassy', 'express', 'fast telegram', 'flash'],
    'telegraph': ['teletype', 'cable', 'cablegram', 'day letter', 'facsimile telegraph', 'fast telegram', 'flash', 'heliograph', 'multiplex', 'night letter', 'quadruplex', 'radio'],
    'telegraphy': ['telautography', 'teletype', 'teletype network', 'teletyping', 'closed-circuit telegraphy', 'code', 'duplex telegraphy', 'electricity', 'facsimile telegraph', 'interrupter', 'key', 'multiplex telegraphy'],
    'telemetry': ['appraisal', 'appraisement', 'approximation', 'assessment', 'assize', 'assizement', 'bioinstrumentation', 'calculation', 'computation', 'correction', 'determination', 'estimate'],
    'telepathic': ['answering', 'automatist', 'clairaudient', 'clairsentient', 'clairvoyant', 'communicating', 'communicational', 'communional', 'conversational', 'extrasensory', 'interacting', 'interactional'],
    'telepathy': ['esp', 'answer', 'commerce', 'communication', 'communion', 'congress', 'connection', 'contact', 'conversation', 'converse', 'correspondence', 'dealing'],
    'telephone': ['blower', 'buzz', 'call', 'call box', 'call up', 'carbon telephone', 'coin telephone', 'desk telephone', 'dial', 'dial telephone', 'extension', 'give a ring'],
    'telephone book': ['baedeker', 'yellow pages', 'atlas', 'bibliography', 'business directory', 'calendar', 'casebook', 'catalog', 'catalogue raisonne', 'checklist', 'city directory', 'classified catalog'],
    'telephone booth': ['call box', 'coin telephone', 'desk telephone', 'dial telephone', 'extension', 'mouthpiece', 'pay station', 'phone', 'public telephone', 'push-button telephone', 'receiver', 'telephone'],
    'telephonic': ['teletype', 'wirephoto', 'communication', 'communicational', 'communications', 'facsimile', 'magnetotelephonic', 'microtelephonic', 'monotelephonic', 'phototelegraphic', 'radio', 'radiotelegraphic'],
    'telephonics': ['call box', 'coin telephone', 'desk telephone', 'dial telephone', 'extension', 'mouthpiece', 'pay station', 'phone', 'public telephone', 'push-button telephone', 'receiver', 'telephone'],
    'telephoto': ['photoradiogram', 'wirephoto', 'aerial photograph', 'black-and-white photograph', 'candid photograph', 'cheesecake', 'chronophotograph', 'color photograph', 'color print', 'diapositive', 'facsimile', 'heliochrome'],
    'teleplay': ['grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque show', 'charade', 'cliff hanger', 'closet drama'],
    'teleran': ['var', 'airborne radar', 'astronavigation', 'aviation radar', 'celestial navigation', 'consolan', 'electronic navigation', 'loran', 'navar', 'navigation', 'omnidirectional range', 'omnirange'],
    'telescope': ['cassegrainian telescope', 'newtonian telescope', 'oao', 'oso', 'abbreviate', 'abridge', 'abstract', 'astronomical observatory', 'astronomical telescope', 'binoculars', 'bob', 'boil down'],
    'teletype': ['telautography', 'teletype network', 'teletyping', 'wirephoto', 'cable', 'closed-circuit telegraphy', 'code', 'communication', 'communicational', 'communications', 'duplex telegraphy', 'electricity'],
    'televiewer': ['tv-viewer', 'beholder', 'bird-watcher', 'bystander', 'drugstore cowboy', 'eyewitness', 'gaper', 'gazer', 'gazer-on', 'girl-watcher', 'goggler', 'kibitzer'],
    'television': ['tv', 'advice', 'adviser', 'announcer', 'annunciator', 'authority', 'automation', 'avionics', 'box', 'broadcast journalism', 'channel', 'communicant'],
    'telex': ['telautography', 'teletype', 'teletype network', 'teletyping', 'cable', 'cablegram', 'closed-circuit telegraphy', 'code', 'day letter', 'duplex telegraphy', 'electricity', 'facsimile telegraph'],
    'tell': ['acknowledge', 'acquaint', 'admit', 'advertise', 'advertise of', 'advise', 'affect', 'air', 'allegorize', 'amount to something', 'announce', 'apprise'],
    'tell fortunes': ['cast a horoscope', 'cast a nativity', 'divine', 'dope', 'dope out', 'dowse for water', 'forebode', 'forecast', 'foresee', 'foretell', 'fortune-tell', 'guess'],
    'tell off': ['bawl out', 'berate', 'call down', 'chew out', 'come down on', 'denounce', 'dress down', 'give it to', 'jaw', 'jump all over', 'jump on', 'rail'],
    'tell on': ['babble', 'be indiscreet', 'be unguarded', 'bear witness against', 'betray', 'betray a confidence', 'blab', 'blabber', 'blow the whistle', 'blurt', 'blurt out', 'fink'],
    'tell the truth': ['acknowledge', 'admit', 'admit everything', 'allow', 'avow', 'awaken', 'break the spell', 'burst the bubble', 'come clean', 'concede', 'confess', 'cop a plea'],
    'teller': ['adviser', 'announcer', 'annunciator', 'authority', 'bank clerk', 'bank manager', 'bank officer', 'bank president', 'banker', 'banking executive', 'bill broker', 'cambist'],
    'telling': ['absolute', 'accounting', 'acid', 'adducible', 'admissible', 'agitating', 'announcement', 'armipotent', 'attestative', 'attestive', 'authentic', 'authoritative'],
    'telltale': ['a tale-bearing animal', 'babbling', 'betrayal', 'betrayer', 'blab', 'blabber', 'blabberer', 'blabbering', 'blabbermouth', 'blabbing', 'broad hint', 'busybody'],
    'telltale sign': ['babbling', 'badge', 'banner', 'betrayal', 'blabbering', 'blabbing', 'character', 'characteristic', 'communication leak', 'dead giveaway', 'device', 'differentia'],
    'tellurian': ['adamite', 'adamitic', 'anthropocentric', 'anthropological', 'being', 'body', 'cat', 'chap', 'character', 'creature', 'customer', 'duck'],
    'tellus': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'temblor': ['apoplexy', 'breakup', 'cataclysm', 'climax', 'convulsion', 'diastrophism', 'disaster', 'fit', 'overthrow', 'paroxysm', 'quake', 'quaker'],
    'temerity': ['assurance', 'audacity', 'brashness', 'brass', 'brazen boldness', 'cheek', 'chutzpah', 'daring', 'foolhardiness', 'gall', 'hardihood', 'hardiness'],
    'temper': ['irish', 'abate', 'adjust', 'adjust to', 'allay', 'alleviate', 'alter', 'anger', 'animus', 'anneal', 'appease', 'aptitude'],
    'tempera': ['aquarelle', 'canvas', 'chromogen', 'coat', 'coat of paint', 'coating', 'color', 'color filter', 'color gelatin', 'colorant', 'coloring', 'dead-color'],
    'temperament': ['animus', 'aptitude', 'bent', 'bias', 'body-build', 'brand', 'cast', 'character', 'characteristic', 'characteristics', 'chromatic scale', 'compass'],
    'temperamental': ['affective', 'arbitrary', 'atavistic', 'bluff', 'bodily', 'born', 'brusque', 'capricious', 'changeable', 'characteristic', 'coeval', 'congenital'],
    'temperance': ['rechabitism', 'abnegation', 'abstemiousness', 'abstinence', 'asceticism', 'austerity', 'calm', 'calmness', 'cardinal virtues', 'charity', 'conservatism', 'constraint'],
    'temperate': ['abstemious', 'abstentious', 'abstinent', 'aestival', 'ascetic', 'austere', 'bland', 'blood-hot', 'blood-warm', 'bracing', 'calid', 'calm'],
    'tempered': ['aged', 'annealed', 'chastened', 'conditioned', 'constrained', 'controlled', 'developed', 'full-blown', 'full-fledged', 'full-grown', 'fully developed', 'hardened'],
    'tempering': ['abatement', 'abating', 'ability', 'aging', 'allaying', 'allayment', 'alleviating', 'alleviation', 'arteriosclerosis', 'assuagement', 'assuaging', 'atherosclerosis'],
    'tempest': ['agitation', 'black squall', 'blaze', 'blizzard', 'blow', 'brouhaha', 'burst', 'chaos', 'commotion', 'convulsion', 'cyclone', 'dirty weather'],
    'tempestuous': ['anarchic', 'angry', 'blustering', 'blusterous', 'blustery', 'boisterous', 'chaotic', 'clamorous', 'cloudy', 'coarse', 'cyclonic', 'dirty'],
    'temple': ['bank', 'beam', 'border', 'broadside', 'cathedral', 'chapel', 'cheek', 'chop', 'church', 'coast', 'dewal', 'fane'],
    'tempo': ['andante tempo', 'arrhythmia', 'beat', 'beating', 'cadence', 'compound time', 'drumming', 'duple time', 'flutter', 'heartbeat', 'heartthrob', 'largo'],
    'temporal': ['philistine', 'annalistic', 'banausic', 'bodily', 'brittle', 'calendarial', 'calendric', 'capricious', 'carnal', 'carnal-minded', 'changeable', 'chronogrammatic'],
    'temporary': ['acting', 'ad hoc', 'ad interim', 'alternate', 'alternative', 'backup', 'band-aid', 'blue-collar worker', 'breadwinner', 'brittle', 'capricious', 'casual'],
    'temporize': ['be a timeserver', 'be dilatory', 'continue', 'dawdle', 'drag out', 'draw out', 'dwell on', 'extend', 'filibuster', 'gain time', 'hang', 'hang back'],
    'tempt': ['allure', 'appeal', 'attract', 'bait', 'be attractive', 'becharm', 'beckon', 'bewitch', 'bring', 'cajole', 'captivate', 'carry'],
    'tempt providence': ['bell the cat', 'brave', 'chance', 'court danger', 'court destruction', 'dare', 'defy danger', 'face up to', 'flirt with death', 'forget the odds', 'gamble', 'go for broke'],
    'temptation': ['agacerie', 'allure', 'allurement', 'ambition', 'appeal', 'attraction', 'attractiveness', 'bait', 'beguilement', 'beguiling', 'bewitchery', 'bewitchment'],
    'tempter': ['circe', 'don juan', 'lorelei', 'parthenope', 'siren', 'abettor', 'actuator', 'animator', 'cajoler', 'charmer', 'coax', 'coaxer'],
    'tempting': ['circean', 'acceptable', 'adorable', 'agreeable', 'alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling'],
    'temptress': ['aspasia', 'circe', 'delilah', 'don juan', 'jezebel', 'lorelei', 'messalina', 'parthenope', 'phryne', 'siren', 'thais', 'adventuress'],
    'ten': ['big dick', 'decalogue', 'ten commandments', 'blow', 'breath', 'breather', 'breathing', 'decade', 'decagon', 'decagram', 'decahedron', 'decaliter'],
    'ten commandments': ['big dick', 'decalogue', 'zeitgeist', 'axiology', 'behavioral norm', 'business ethics', 'code', 'code of ethics', 'code of morals', 'decade', 'decagon', 'decagram'],
    'tenable': ['ok', 'acceptable', 'admissible', 'agreeable', 'all right', 'alright', 'arguable', 'believable', 'colorable', 'conceivable', 'condonable', 'credible'],
    'tenacious': ['adamant', 'adherent', 'adhesive', 'amylaceous', 'assiduous', 'balking', 'balky', 'bigoted', 'bound', 'bound and determined', 'bulldogged', 'bulldoggish'],
    'tenacity': ['adhesiveness', 'application', 'assiduity', 'assiduousness', 'balkiness', 'bigotry', 'bottling up', 'bulldog courage', 'bulldog tenacity', 'bullheadedness', 'clabbering', 'clamminess'],
    'tenancy': ['abiding', 'abode', 'adverse possession', 'alodium', 'burgage', 'claim', 'cohabitation', 'colony', 'commorancy', 'de facto', 'de jure', 'dependency'],
    'tenant': ['abide', 'addressee', 'artist-in-residence', 'berth', 'board-and-roomer', 'boarder', 'bunk', 'cohabit', 'denizen', 'domicile', 'domiciliate', 'doss down'],
    'tenant farmer': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'coffee-planter', 'collective farm worker', 'crofter', 'cropper', 'cultivator', 'dirt farmer', 'dry farmer'],
    'tend': ['administer to', 'aim', 'animadvert', 'attend', 'attend on', 'attend to', 'baby-sit', 'bear', 'bed', 'bed down', 'bend to', 'bias'],
    'tend toward': ['be disposed to', 'choose rather', 'favor', 'feel about it', 'have a bias', 'have preference', 'have rather', 'honor before', 'incline toward', 'lean toward', 'lean towards', 'like better'],
    'tendency': ['affinity', 'aim', 'an ear for', 'an eye for', 'animus', 'aptitude', 'aptness', 'azimuth', 'bag', 'bearing', 'bent', 'bias'],
    'tender': ['christian', 'christlike', 'christly', 'ganymede', 'hebe', 'pullman', 'pullman car', 'accepting', 'accord', 'aching', 'administer', 'adoring'],
    'tender age': ['bloom', 'budtime', 'early years', 'florescence', 'flowering time', 'jeunesse', 'juvenescence', 'juvenility', 'my burning youth', 'my green age', 'prime of life', 'salad days'],
    'tender loving care': ['tlc', 'anticipation', 'attention', 'bread', 'care', 'carefulness', 'caution', 'circumspection', 'circumspectness', 'concern', 'consideration', 'daily bread'],
    'tender spot': ['ache', 'aching', 'affront', 'apple of discord', 'blow', 'bone of contention', 'bone to pick', 'casus belli', 'cramp', 'crow to pick', 'crow to pluck', 'cut'],
    'tenderfoot': ['abecedarian', 'alphabetarian', 'apprentice', 'arriviste', 'articled clerk', 'baby', 'beginner', 'boot', 'catechumen', 'colt', 'conscript', 'dabbler'],
    'tenderhearted': ['christian', 'christlike', 'christly', 'affectionate', 'benign', 'benignant', 'bleeding', 'brotherly', 'charitable', 'clement', 'commiserative', 'compassionate'],
    'tenderize': ['cushion', 'ease', 'fluff', 'gentle', 'knead', 'laxate', 'limber', 'limber up', 'loosen', 'mash', 'massage', 'mellow'],
    'tenderloin': ['bowery', 'chateaubriand', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'bagnio', 'barrio', 'bawdyhouse'],
    'tenderly': ['adoringly', 'affectionately', 'amorously', 'ardently', 'assiduously', 'carefully', 'cautiously', 'circumspectly', 'compliantly', 'considerately', 'dearly', 'delicately'],
    'tenderness': ['acceptance', 'airiness', 'algesia', 'allergy', 'anaphylaxis', 'ascent', 'bleeding heart', 'bloom', 'bowels of compassion', 'bubbliness', 'budtime', 'buoyancy'],
    'tendon': ['bone', 'braid', 'brail', 'cable', 'cartilage', 'cord', 'ligament', 'ligation', 'ligature', 'line', 'ossicle', 'rope'],
    'tendril': ['animal fiber', 'appendage', 'arm', 'artificial fiber', 'bine', 'bough', 'branch', 'branchedness', 'branchiness', 'burgeon', 'capillament', 'cilium'],
    'tenebrous': ['ambiguous', 'amphibological', 'beamless', 'black', 'black as night', 'caliginous', 'dark', 'dark as night', 'dark as pitch', 'darkling', 'darksome', 'dim'],
    'tenement': ['augean stables', 'acres', 'apartment', 'apartment house', 'chambers', 'chattels real', 'cold-water flat', 'condominium', 'cooperative apartment house', 'demesne', 'domain', 'dump'],
    'tenement district': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'barrio', 'black ghetto', 'blighted area', 'business district'],
    'tenet': ['a belief', 'article of faith', 'axiom', 'belief', 'canon', 'code', 'commandment', 'convention', 'conviction', 'credo', 'creed', 'dictum'],
    'tenor': ['heldentenor', 'meistersinger', 'zeitgeist', 'accompaniment', 'affective meaning', 'aim', 'alto', 'apograph', 'aria singer', 'azimuth', 'baritenor', 'baritone'],
    'tense': ['accented', 'agitated', 'all-overish', 'alveolar', 'antsy', 'anxious', 'anxioused up', 'aorist', 'apical', 'apico-alveolar', 'apico-dental', 'apprehensive'],
    'tensility': ['adaptability', 'agreeability', 'amenability', 'bendability', 'ductibility', 'ductility', 'elasticity', 'extendibility', 'extensibility', 'facility', 'fictility', 'flexibility'],
    'tension': ['discordia', 'eris', 'agitation', 'all-overs', 'angst', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat', 'anxiousness'],
    'tent': ['a-tent', 'ace bandage', 'band-aid', 'adhesive tape', 'application', 'band', 'bandage', 'bandaging', 'big top', 'binder', 'bivouac', 'brace'],
    'tentative': ['acting', 'ad hoc', 'ad interim', 'alternate', 'alternative', 'ambling', 'analytic', 'apprehensive', 'awkward', 'backup', 'band-aid', 'blankminded'],
    'tented': ['armored', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'coped', 'covered', 'covert', 'cowled', 'curtained', 'eclipsed'],
    'tenuous': ['adulterated', 'aerial', 'air-built', 'airy', 'aloof', 'atomic', 'attenuate', 'attenuated', 'boyish', 'broken', 'chimerical', 'cloud-built'],
    'tenure': ['adverse possession', 'alodium', 'appointment', 'berth', 'billet', 'burgage', 'claim', 'clamp', 'clasp', 'clench', 'clinch', 'clutch'],
    'tenured': ['blessed with', 'enfeoffed', 'having', 'having and holding', 'holding', 'in possession of', 'landed', 'landholding', 'landowning', 'master of', 'occupying', 'owning'],
    'tepid': ['laodicean', 'aestival', 'apathetic', 'arid', 'blase', 'blood-hot', 'blood-warm', 'calid', 'cold', 'colorless', 'cool', 'dim'],
    'teratism': ['aberrance', 'aberrancy', 'aberration', 'abnormality', 'abnormity', 'abortion', 'absurdity', 'amorphism', 'anomalism', 'anomalousness', 'anomaly', 'anticness'],
    'teratology': ['bowlegs', 'camelback', 'cleft palate', 'clubfoot', 'crookback', 'defacement', 'deformation', 'deformity', 'disfigurement', 'flatfoot', 'freakishness', 'harelip'],
    'tercentenary': ['anniversary', 'annual holiday', 'bicentenary', 'bicentennial', 'biennial', 'birthday', 'bissextile day', 'cental', 'centare', 'centenarian', 'centenary', 'centennial'],
    'tergiversate': ['alternate', 'apostatize', 'around the bush', 'back and fill', 'beat about', 'beg the question', 'bicker', 'boggle', 'cavil', 'change', 'choplogic', 'come round'],
    'tergiversation': ['about-face', 'amphibology', 'apostasy', 'denial', 'desertion', 'disavowal', 'double entendre', 'double meaning', 'equivocality', 'equivocation', 'equivoque', 'falseness'],
    'term': ['abundant year', 'academic year', 'adjectival phrase', 'administration', 'agree', 'annum', 'antonym', 'apodosis', 'appellation', 'arrange', 'articles', 'articulation'],
    'term paper': ['article', 'causerie', 'descant', 'discourse', 'discussion', 'disquisition', 'dissertation', 'essay', 'etude', 'examination', 'excursus', 'exposition'],
    'termagant': ['jezebel', 'mafioso', 'xanthippe', 'young turk', 'amazon', 'battle-ax', 'beast', 'beldam', 'berserk', 'berserker', 'bitch', 'bitch-kitty'],
    'terminal': ['crt', 'anchorage', 'apodosis', 'bad', 'beyond recall', 'beyond remedy', 'bordering', 'borderline', 'boundary', 'bounding', 'bourn', 'branch'],
    'terminal case': ['apoplectic', 'arthritic', 'case', 'consumptive', 'dead duck', 'dying', 'dyspeptic', 'epileptic', 'gone goose', 'goner', 'gosling', 'hopeless case'],
    'terminate': ['abandon', 'abolish', 'abort', 'attend', 'ax', 'become of', 'belay', 'boot out', 'bounce', 'button up', 'cancel', 'cap'],
    'terminated': ['sol', 'all bets off', 'all off', 'all over', 'all up', 'at an end', 'canceled', 'cleaned up', 'complete', 'completed', 'concluded', 'dead'],
    'termination': ['abandonment', 'abortion', 'apodosis', 'bitter end', 'breakoff', 'catastrophe', 'cease', 'ceasing', 'cessation', 'climax', 'close', 'closing'],
    'terminology': ['antonomasia', 'argot', 'binomial nomenclature', 'biosystematics', 'biosystematy', 'cant', 'class', 'classification', 'dictionary', 'family', 'gazetteer', 'genus'],
    'terminus': ['anchorage', 'apodosis', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bourn', 'branch', 'break boundary', 'breakoff point', 'cable railway'],
    'termless': ['all-comprehensive', 'all-inclusive', 'boundless', 'countless', 'endless', 'eternal', 'exhaustless', 'extending everywhere', 'illimitable', 'illimited', 'immeasurable', 'immense'],
    'terms': ['accommodation', 'adjustment', 'arrangement', 'boundary condition', 'catch', 'clause', 'composition of differences', 'compromise', 'condition', 'donnee', 'escalator clause', 'escape clause'],
    'ternary': ['clover', 'deuce-ace', 'leash', 'set of three', 'shamrock', 'tercet', 'tern', 'ternal', 'ternate', 'ternion', 'terzetto', 'three'],
    'terpsichore': ['apollo', 'apollo musagetes', 'calliope', 'clio', 'erato', 'euterpe', 'melpomene', 'orpheus', 'pierides', 'polyhymnia', 'polymnia', 'thalia'],
    'terra cotta': ['titian', 'adust', 'auburn', 'bay', 'bay-colored', 'bayard', 'brazen', 'bronze', 'bronze-colored', 'bronzed', 'brownish-red', 'cast'],
    'terra firma': ['acres', 'alluvion', 'alluvium', 'arable land', 'base', 'basement', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock', 'carpet'],
    'terra incognita': ['dark horse', 'enigma', 'frontier', 'frontiers of knowledge', 'matter of ignorance', 'mystery', 'puzzle', 'riddle', 'sealed book', 'the incalculable', 'the strange', 'the unfamiliar'],
    'terrace': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'balcony'],
    'terrain': ['lebensraum', 'acres', 'agora', 'air space', 'airspace', 'alluvion', 'alluvium', 'amphitheater', 'arable land', 'area', 'arena', 'athletic field'],
    'terrestrial': ['cynthian', 'philistine', 'anagalactic', 'asteroidal', 'astral', 'astrologic', 'astrologistic', 'astrologous', 'astronomic', 'astrophysical', 'carnal', 'carnal-minded'],
    'terrible': ['aberrant', 'abnormal', 'abominable', 'acute', 'alarming', 'appalling', 'arduous', 'arrant', 'ashamed', 'astounding', 'atrocious', 'awe-inspiring'],
    'terribly': ['abominably', 'agonizingly', 'alarmingly', 'almighty', 'appallingly', 'astoundingly', 'atrociously', 'awfully', 'baldly', 'balefully', 'banefully', 'basely'],
    'terrific': ['ace', 'agitating', 'appalling', 'astounding', 'awe-inspiring', 'awesome', 'awful', 'breathtaking', 'deadly', 'dire', 'direful', 'disquieting'],
    'terrifically': ['alarmingly', 'almighty', 'appallingly', 'astoundingly', 'awfully', 'disconcertingly', 'dismayingly', 'divinely', 'dreadfully', 'exceedingly', 'exquisitely', 'fearfully'],
    'terrified': ['aghast', 'anxious', 'appalled', 'ashen', 'astounded', 'awed', 'awestricken', 'awestruck', 'blanched', 'cowed', 'deadly pale', 'fearful'],
    'terrify': ['affright', 'alarm', 'appall', 'awe', 'freeze', 'fright', 'frighten', 'horrify', 'paralyze', 'petrify', 'scare', 'scare stiff'],
    'terrifying': ['alarming', 'bloodcurdling', 'frightening', 'grim', 'grisly', 'gruesome', 'hair-raising', 'hideous', 'horrible', 'horrid', 'horrifying', 'macabre'],
    'territory': ['kreis', 'lebensraum', 'acres', 'air space', 'airspace', 'alluvion', 'alluvium', 'ally', 'ambit', 'arable land', 'archbishopric', 'archdiocese'],
    'terror': ['dracula', 'frankenstein', 'mafioso', 'wolf-man', 'young turk', 'abject fear', 'affright', 'alarm', 'anxiety', 'awe', 'beast', 'beldam'],
    'terrorism': ['bolshevikism', 'bolshevism', 'carbonarism', 'castroism', 'jacobinism', 'maoism', 'sinn feinism', 'acuteness', 'anarchism', 'animality', 'argumentum baculinum', 'atrocity'],
    'terrorist': ['bolshevik', 'bolshevist', 'bolshie', 'carbonarist', 'carbonaro', 'castroist', 'castroite', 'charley', 'communist', 'cong', 'fenian', 'guevarist'],
    'terroristic': ['bolshevik', 'bolshevist', 'carbonarist', 'castroist', 'castroite', 'communist', 'fenian', 'guevarist', 'jacobinic', 'leninist', 'maoist', 'marxist'],
    'terrorize': ['affright', 'alarm', 'assault', 'attack', 'awe', 'barbarize', 'batter', 'beat down', 'bludgeon', 'bluster', 'bluster out of', 'break'],
    'terrorizing': ['abusive', 'bludgeoning', 'blustering', 'browbeating', 'bulldozing', 'bullying', 'comminatory', 'denunciatory', 'fear-inspiring', 'foreboding', 'hectoring', 'imminent'],
    'terse': ['attic', 'ciceronian', 'spartan', 'abbreviated', 'abridged', 'abrupt', 'aphoristic', 'aposiopestic', 'axiomatic', 'bluff', 'blunt', 'brief'],
    'tertiary': ['maxwell triangle', 'munsell scale', 'chromatic circle', 'chromatic spectrum', 'chromaticity diagram', 'color circle', 'color cycle', 'color index', 'color mixture curve', 'color solid', 'color spectrum', 'color system'],
    'tessellate': ['band', 'bar', 'bespangle', 'bespeckle', 'bespot', 'blotch', 'check', 'checker', 'dapple', 'dot', 'fit in', 'flake'],
    'tessera': ['id card', 'badge', 'calligram', 'calling card', 'card', 'check', 'checker', 'checkerboard', 'checkerwork', 'chessboard', 'colors in patches', 'countermark'],
    'test': ['binet-simon test', 'brown personality inventory', 'goldstein-sheerer test', 'iq', 'iq test', 'kent mental test', 'minnesota preschool scale', 'olympic games', 'olympics', 'oseretsky test', 'pap test', 'rorschach test'],
    'test case': ['acid test', 'assay', 'blank determination', 'brouillon', 'criterion', 'crucial test', 'crucible', 'determination', 'docimasy', 'essay', 'feeling out', 'first draft'],
    'test flight': ['gedankenexperiment', 'airlift', 'audition', 'bench test', 'dry run', 'flight', 'flight test', 'hearing', 'hop', 'jump', 'pilot plan', 'practical test'],
    'test pilot': ['aeronaut', 'aeroplaner', 'aeroplanist', 'air pilot', 'airplanist', 'analyst', 'analyzer', 'assayer', 'astronaut', 'aviator', 'barnstormer', 'birdman'],
    'test tube': ['bunsen burner', 'erlenmeyer flask', 'kipp generator', 'alembic', 'anvil', 'aspirator', 'beaker', 'blowpipe', 'burette', 'caldron', 'capillary tube', 'condenser'],
    'testable': ['absolute', 'actual', 'admitting no question', 'confirmable', 'demonstrable', 'demonstratable', 'factual', 'historical', 'inappealable', 'incontestable', 'incontrovertible', 'indisputable'],
    'testator': ['maecenas', 'santa claus', 'almoner', 'almsgiver', 'angel', 'assignor', 'awarder', 'backer', 'bestower', 'cheerful giver', 'conferrer', 'consignor'],
    'tested': ['ascertained', 'assured', 'attested', 'certified', 'committed', 'confirmed', 'constant', 'decided', 'dedicated', 'dependable', 'determinate', 'determined'],
    'tester': ['analyst', 'analyzer', 'assayer', 'essayer', 'examinant', 'examiner', 'experimenter', 'inspector', 'investigator', 'observer', 'research worker', 'researcher'],
    'testes': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'testicles': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'testify': ['acknowledge', 'affirm', 'allege', 'announce', 'argue', 'assert', 'assert under oath', 'asseverate', 'assure', 'attest', 'aver', 'avouch'],
    'testify against': ['bear witness against', 'betray', 'blab', 'blow the whistle', 'fink', 'inform against', 'inform on', 'narc', 'peach', 'rat', 'sell out', 'snitch'],
    'testimonial': ['admission', 'advocacy', 'advocating', 'advocation', 'affidavit', 'affirmation', 'allegation', 'anniversaries', 'appreciation', 'arch', 'assertion', 'asseveration'],
    'testimony': ['admission', 'affidavit', 'affirmation', 'allegation', 'argument', 'assertion', 'asseveration', 'attest', 'attestation', 'authentication', 'averment', 'avouchment'],
    'testiness': ['bearishness', 'bitchiness', 'cantankerousness', 'churlishness', 'crabbedness', 'crankiness', 'crossness', 'crustiness', 'cussedness', 'disagreeability', 'excitability', 'fractiousness'],
    'testing': ['r and d', 'analytic', 'control', 'control experiment', 'controlled experiment', 'cut and try', 'cut-and-try', 'empirical', 'empiricism', 'examinational', 'examinatorial', 'examining'],
    'testy': ['bad-tempered', 'bearish', 'bitchy', 'cankered', 'cantankerous', 'captious', 'choleric', 'churlish', 'contentious', 'crabbed', 'crabby', 'cranky'],
    'tetanus': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'acute articular rheumatism'],
    'tetched': ['abnormal', 'bereft of reason', 'brainsick', 'crackbrained', 'cracked', 'crazed', 'crazy', 'daft', 'deluded', 'demented', 'deprived of reason', 'deranged'],
    'tetchy': ['allergic', 'anaphylactic', 'cantankerous', 'choleric', 'cranky', 'cross', 'delicate', 'empathetic', 'empathic', 'goosy', 'high-strung', 'hyperesthetic'],
    'tether': ['oregon boat', 'anchor', 'batten', 'batten down', 'belay', 'bilbo', 'bind', 'bond', 'bonds', 'bridle', 'camisole', 'chain'],
    'tethered': ['aground', 'anchored', 'bound', 'caught', 'chained', 'fast', 'fastened', 'fettered', 'fixed', 'grounded', 'hampered', 'handcuffed'],
    'text': ['abecedarium', 'abecedary', 'abstract', 'acknowledgments', 'adage', 'advance sheets', 'advertising matter', 'alphabet book', 'ana', 'analects', 'aphorism', 'apothegm'],
    'textbook': ['abecedarium', 'abecedary', 'alphabet book', 'battledore', 'casebook', 'exercise book', 'gradus', 'grammar', 'hornbook', 'manual', 'manual of instruction', 'primer'],
    'textile': ['braided', 'cloth', 'drapery', 'dry goods', 'enlaced', 'entwined', 'etoffe', 'fabric', 'felt', 'fretted', 'goods', 'handwoven'],
    'textual': ['biblical', 'christian', 'gospel', 'mosaic', 'new-testament', 'old-testament', 'accepted', 'apocalyptic', 'apostolic', 'approved', 'authentic', 'authoritative'],
    'texture': ['anatomy', 'arabesque', 'architectonics', 'architecture', 'arrangement', 'basketry', 'basketwork', 'being', 'braiding', 'build', 'building', 'cancellation'],
    'textured': ['broken', 'bumpy', 'choppy', 'coarse', 'coarse-grained', 'corrugated', 'cross-grained', 'grainy', 'granulated', 'homespun', 'horripilant', 'inequal'],
    'thalia': ['calliope', 'clio', 'erato', 'euterpe', 'melpomene', 'polyhymnia', 'terpsichore', 'arlequinade', 'artistic imagination', 'black comedy', 'broad comedy', 'burlesque'],
    'than': ['alias', 'as compared with', 'aside from', 'bar', 'barring', 'beside', 'besides', 'by comparison with', 'compared with', 'contrarily', 'else', 'elsewise'],
    'thanatosis': ['anaphylactic shock', 'battle fatigue', 'catalepsy', 'coma', 'combat fatigue', 'encephalitis lethargica', 'high', 'hypoglycemic shock', 'lethargy', 'mental shock', 'narcohypnosis', 'narcolepsy'],
    'thank': ['acknowledge', 'appreciation', 'because of', 'blame', 'bless', 'by reason of', 'credit', 'due to', 'give credit', 'give thanks', 'gratefulness', 'gratitude'],
    'thankless': ['bitter', 'bootless', 'careless', 'despised', 'disagreeable', 'dislikable', 'disliked', 'displeasing', 'distasteful', 'fruitless', 'futile', 'heedless'],
    'thanks': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'acknowledgment', 'aid prayer', 'appeal', 'beadroll', 'beads', 'benediction'],
    'thanks to': ['after', 'because of', 'by', 'by dint of', 'by means of', 'by reason of', 'by use of', 'by virtue of', 'by way of', 'considering', 'due to', 'hereby'],
    'thanksgiving': ['angelus', 'ave', 'ave maria', 'hail mary', 'kyrie eleison', 'paternoster', 'acknowledgment', 'aid prayer', 'appeal', 'beadroll', 'beads', 'benediction'],
    'thatch': ['board', 'brick', 'clapboard', 'crop', 'face', 'fleece', 'glass', 'glaze', 'head', 'head of hair', 'lath', 'locks'],
    'thaumaturgy': ['alchemy', 'bewitchery', 'bewitchment', 'charm', 'divination', 'enchantment', 'fetishism', 'glamour', 'gramarye', 'hoodoo', 'incantation', 'juju'],
    'thaw': ['bend', 'colliquate', 'cut', 'decoagulate', 'decoct', 'defrost', 'deliquesce', 'dissolve', 'fluidify', 'fluidize', 'flux', 'forbear'],
    'thawing': ['colliquation', 'colliquative', 'decoagulation', 'deliquescence', 'deliquium', 'dissolution', 'dissolutional', 'dissolutive', 'dissolving', 'fluidification', 'fluidization', 'fusibility'],
    'theater': ['broadway', 'dmz', 'elizabethan theater', 'globe theatre', 'greek theater', 'aceldama', 'agora', 'amphitheater', 'amusement park', 'arena', 'arena theater', 'assembly hall'],
    'theatergoer': ['aficionado', 'attender', 'audience', 'buff', 'claqueur', 'deadhead', 'fan', 'frequenter', 'groundling', 'habitue', 'haunter', 'hired applauder'],
    'theatre': ['acting', 'area', 'arena', 'auditorium', 'coliseum', 'drama', 'dramaturgy', 'hippodrome', 'histrionics', 'melodrama', 'opera house', 'performance'],
    'theatrical': ['roscius', 'thespian art', 'actor', 'actor-proof', 'actress', 'affected', 'all-star', 'amateur theatricals', 'antagonist', 'artificial', 'bad guy', 'ballet'],
    'theatrics': ['thespian art', 'amateur theatricals', 'blazon', 'blood and thunder', 'bravura', 'brilliancy', 'daring', 'dash', 'demonstration', 'demonstrativeness', 'display', 'dramatic art'],
    'theft': ['acquisition', 'appropriation', 'boosting', 'burglary', 'caper', 'claiming', 'embezzlement', 'filch', 'filching', 'grab', 'heist', 'hijacking'],
    'theism': ['acosmism', 'adoration', 'allotheism', 'anthropolatry', 'anthropomorphism', 'anthropotheism', 'autotheism', 'churchgoing', 'conformity', 'cosmotheism', 'cultism', 'deism'],
    'theist': ['christian', 'god-fearing man', 'accepter', 'allotheist', 'anthropolater', 'anthropotheist', 'autotheist', 'believer', 'catechumen', 'churchgoer', 'churchite', 'churchman'],
    'theistic': ['christian', 'christianlike', 'christianly', 'cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'adoring', 'animist', 'animistic', 'anthropomorphic'],
    'them': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'bureaucracy', 'directorate', 'ego', 'ethical self', 'he', 'her', 'herself'],
    'theme': ['ic analysis', 'accidence', 'action', 'affix', 'affixation', 'allomorph', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'argument', 'article'],
    'theme and variations': ['nachtmusik', 'absolute music', 'adaptation', 'air varie', 'aleatory', 'aleatory music', 'arrangement', 'chamber music', 'chamber orchestra', 'composition', 'descant', 'electronic music'],
    'theme song': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'alba', 'anthem', 'art song', 'aubade', 'ballad', 'ballade', 'ballata'],
    'themselves': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'ego', 'ethical self', 'he', 'her', 'herself', 'him', 'himself'],
    'then': ['above', 'accordingly', 'additionally', 'aforetime', 'after', 'after all', 'after that', 'afterwards', 'again', 'all included', 'also', 'altogether'],
    'then and there': ['all at once', 'all together', 'at a blow', 'at a stroke', 'at once', 'at one blow', 'at one jump', 'at one stroke', 'at one swoop', 'at one time', 'forthwith', 'in a hurry'],
    'thence': ['accordingly', 'away', 'because of that', 'because of this', 'consequently', 'ergo', 'for that', 'for that cause', 'for that reason', 'for this cause', 'for this reason', 'for which reason'],
    'theocracy': ['absolute monarchy', 'aristocracy', 'autarchy', 'autocracy', 'autonomy', 'coalition government', 'colonialism', 'commonwealth', 'constitutional government', 'constitutional monarchy', 'democracy', 'dictatorship'],
    'theophany': ['christophany', 'masan', 'satanophany', 'afflatus', 'angelophany', 'apocalypse', 'apparition', 'appearance', 'appearing', 'arising', 'astral', 'astral spirit'],
    'theorem': ['a priori principle', 'a priori truth', 'affirmation', 'apriorism', 'assertion', 'assumed position', 'assumption', 'axiom', 'basis', 'brocard', 'categorical proposition', 'conjecture'],
    'theoretical': ['abstract', 'academic', 'analytical', 'armchair', 'closet', 'conceptual', 'conjectural', 'debatable', 'fanciful', 'hypothetic', 'hypothetical', 'ideal'],
    'theorize': ['analyze', 'apply reason', 'conjecture', 'deduce', 'entertain a theory', 'espouse a theory', 'generalize', 'guess', 'have a theory', 'hypothesize', 'infer', 'intellectualize'],
    'theory': ['apprehension', 'assumption', 'attitude', 'base', 'basis', 'body of theory', 'climate of opinion', 'common belief', 'community sentiment', 'conceit', 'concept', 'conception'],
    'theosophy': ['anagoge', 'anagogics', 'anthroposophy', 'cabala', 'cabalism', 'esotericism', 'esoterics', 'esoterism', 'esotery', 'hocus-pocus', 'mumbo jumbo', 'mystery'],
    'therapeutic': ['adjuvant', 'aidful', 'alterative', 'analeptic', 'beneficial', 'conducive', 'constructive', 'contributory', 'corrective', 'curative', 'furthersome', 'good for'],
    'therapist': ['advisor', 'analyst', 'bonesetter', 'chiropractor', 'healer', 'homeopath', 'homeopathist', 'medic', 'midwife', 'oculist', 'optometrist', 'osteopath'],
    'therapy': ['medicaid', 'medicare', 'x ray', 'aerospace medicine', 'aid', 'analysis', 'assistance', 'benefit', 'biomedicine', 'blood bank', 'charity ward', 'clinic'],
    'thereabouts': ['about', 'along toward', 'around', 'at close quarters', 'at hand', 'close', 'close about', 'close at hand', 'close by', 'fast by', 'hard', 'hard by'],
    'thereafter': ['after', 'after all', 'after that', 'afterwards', 'ex post facto', 'from here in', 'from now on', 'from then on', 'from this point', 'henceforth', 'henceforward', 'henceforwards'],
    'thereby': ['by', 'by dint of', 'by means of', 'by use of', 'by virtue of', 'by way of', 'hereby', 'herewith', 'in virtue of', 'on', 'per', 'thanks to'],
    'therefore': ['according to circumstances', 'accordingly', 'after all', 'all things considered', 'and so', 'as a consequence', 'as a result', 'as it is', 'as matters stand', 'at that rate', 'because of that', 'because of this'],
    'thermal': ['aestival', 'blood-hot', 'blood-warm', 'calid', 'equatorial', 'fire storm', 'genial', 'hot air', 'luke', 'lukewarm', 'mild', 'room-temperature'],
    'thermodynamics': ['newtonian physics', 'acoustics', 'aerodynamics', 'aerophysics', 'applied physics', 'astrophysics', 'barodynamics', 'basic conductor physics', 'biodynamics', 'biophysics', 'calorimetry', 'chemical physics'],
    'thermometer': ['calorimeter', 'clinical thermometer', 'cryometer', 'electric thermometer', 'galvanothermometer', 'gas thermometer', 'glass', 'meat thermometer', 'mercury', 'pyrometer', 'pyrometric cone', 'resistance pyrometer'],
    'thesaurus': ['armory', 'arsenal', 'biographical dictionary', 'cache', 'chemical dictionary', 'desk dictionary', 'dialect dictionary', 'dictionary', 'dictionary of quotations', 'electronics dictionary', 'etymological dictionary', 'foreign-language dictionary'],
    'thesis': ['alexandrine', 'a priori principle', 'accent', 'accentuation', 'affirmation', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antispast', 'apriorism', 'argument'],
    'thespian': ['roscius', 'actor', 'actor-proof', 'actress', 'all-star', 'antagonist', 'bad guy', 'ballet', 'balletic', 'barnstormer', 'character', 'character actor'],
    'theurgy': ['alchemy', 'bewitchery', 'charm', 'divination', 'enchantment', 'fetishism', 'glamour', 'gramarye', 'hoodoo', 'juju', 'jujuism', 'magic'],
    'thews': ['beef', 'beefiness', 'brawn', 'brawniness', 'elasticity', 'heftiness', 'huskiness', 'involuntary muscle', 'muscle', 'muscularity', 'musculature', 'physique'],
    'they': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'bureaucracy', 'directorate', 'ego', 'ethical self', 'he', 'her', 'herself'],
    'thick': ['boeotian', 'a bit thick', 'a bit thin', 'absurd', 'abundant', 'accented', 'adhesive', 'alive', 'alive with', 'alveolar', 'ample', 'amylaceous'],
    'thick skin': ['philistinism', 'analgesia', 'anesthesia', 'armature', 'armor', 'armor plate', 'body armor', 'buckler', 'bulletproof vest', 'callosity', 'callousness', 'callus'],
    'thick skinned': ['philistine', 'asleep', 'benumbed', 'callous', 'calloused', 'case-hardened', 'dead', 'deadened', 'dull', 'flinty', 'hard', 'hardened'],
    'thick witted': ['asleep', 'beef-witted', 'benumbed', 'blear-witted', 'blockish', 'blunt', 'blunt-witted', 'callous', 'dead', 'deadened', 'dense', 'dim'],
    'thick-skinned': ['callous', 'case-hardened', 'dull', 'hard-boiled', 'hardened', 'impervious', 'insensate', 'insensitive', 'inured', 'numbed', 'obtuse', 'pachydermatous'],
    'thicken': ['add to', 'aggrandize', 'amplify', 'augment', 'beat up', 'boost', 'broaden', 'build', 'build up', 'cake', 'candy', 'churn'],
    'thickened': ['adhesive', 'amylaceous', 'caked', 'cakey', 'clabbered', 'clammy', 'clotted', 'coagulated', 'congealed', 'curded', 'curdled', 'doughy'],
    'thickening': ['adhesiveness', 'clabbering', 'clamminess', 'clotting', 'coagulation', 'colloidality', 'concretion', 'congealment', 'congelation', 'curdling', 'doughiness', 'gelatination'],
    'thicket': ['batch', 'boscage', 'bosket', 'brake', 'bunch', 'canebrake', 'ceja', 'chamisal', 'chaparral', 'clump', 'cluster', 'coppice'],
    'thickheaded': ['beetleheaded', 'blockheaded', 'blunt', 'blunt-witted', 'chuckleheaded', 'dim', 'dim-witted', 'dopey', 'dull', 'dull of mind', 'dull-headed', 'dull-pated'],
    'thickness': ['adhesiveness', 'band', 'bed', 'bedding', 'belt', 'bodily size', 'body', 'bulk', 'cacophony', 'clabbering', 'clamminess', 'closeness'],
    'thickset': ['able-bodied', 'adipose', 'athletic', 'beefy', 'big-bellied', 'bloated', 'blocky', 'blowzy', 'bosomy', 'brawny', 'broad-bodied', 'broad-shouldered'],
    'thief': ['judas', 'bad person', 'bandit', 'betrayer', 'booster', 'brigand', 'buccaneer', 'burglar', 'cat burglar', 'cat man', 'charlatan', 'cheat'],
    'thieve': ['abstract', 'and', 'annex', 'appropriate', 'bag', 'boost', 'borrow', 'cop', 'crib', 'defraud', 'embezzle', 'extort'],
    'thievery': ['abstraction', 'annexation', 'appropriation', 'boosting', 'conversion', 'conveyance', 'embezzlement', 'filching', 'fraud', 'graft', 'larceny', 'liberation'],
    'thieving': ['brigandish', 'burglarious', 'fraudulent', 'kleptomaniac', 'larcenous', 'larceny', 'light-fingered', 'pinch', 'piratelike', 'piratic', 'purloining', 'steal'],
    'thigh': ['ankle', 'bayonet legs', 'bowlegs', 'breast', 'calf', 'chicken foot', 'cnemis', 'dark meat', 'drumstick', 'foreleg', 'gamb', 'gambrel'],
    'thimblerig': ['beat', 'beguile of', 'bilk', 'boiler room', 'bucket shop', 'bunco', 'bunco game', 'burn', 'cheat', 'chisel', 'chouse', 'chouse out of'],
    'thin': ['lenten', 'sanforize', 'sanforized', 'spartan', 'a bit thick', 'a bit thin', 'abate', 'abrade', 'abstemious', 'abstract', 'absurd', 'acute'],
    'thin ice': ['breakers ahead', 'cardhouse', 'cause for alarm', 'crisis', 'danger', 'dangerous ground', 'emergency', 'endangerment', 'gaping chasm', 'gathering clouds', 'hazard', 'house of cards'],
    'thin skinned': ['allergic', 'anaphylactic', 'delicate', 'empathetic', 'empathic', 'goosy', 'high-strung', 'hyperesthetic', 'hyperpathic', 'hypersensitive', 'irritable', 'itchy'],
    'thing': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'activities', 'activity', 'adventure', 'affair', 'affairs', 'affection'],
    'things': ['accessories', 'accouterments', 'appanages', 'apparatus', 'appendages', 'appliances', 'appointments', 'appurtenances', 'armament', 'belongings', 'caparison', 'choses'],
    'thingumabob': ['affair', 'article', 'artifact', 'dingus', 'dofunny', 'dohickey', 'dojigger', 'dojiggy', 'domajig', 'domajigger', 'doodad', 'dowhacky'],
    'think': ['account as', 'aim', 'aim at', 'anticipate', 'appreciate', 'aspire after', 'aspire to', 'assess', 'assume', 'be afraid', 'be after', 'be concerned'],
    'think back': ['bring back', 'bring to mind', 'call back', 'call to mind', 'call up', 'conjure up', 'evoke', 'go back', 'go back over', 'hark back', 'look back', 'mind'],
    'think nothing of': ['abandon', 'be above', 'be contemptuous of', 'belittle', 'brush aside', 'brush off', 'care nothing for', 'carry through', 'contemn', 'cool it', 'de-emphasize', 'deprecate'],
    'think of': ['account', 'adjudge', 'adjudicate', 'allow', 'be judicious', 'be thoughtful of', 'bear in mind', 'bring back', 'bring to mind', 'call back', 'call to mind', 'call up'],
    'think over': ['brood over', 'chew over', 'con over', 'contemplate', 'deliberate over', 'deliberate upon', 'digest', 'excogitate', 'meditate upon', 'mind', 'mull over', 'muse on'],
    'think twice': ['back down', 'balance', 'be careful', 'be cautious', 'debate', 'deliberate', 'demur', 'dither', 'falter', 'fear', 'go on tiptoe', 'hang back'],
    'think up': ['beget', 'breed', 'bring forth', 'bring into being', 'call into being', 'coin', 'conceit', 'conceive', 'conceptualize', 'concoct', 'contrive', 'cook up'],
    'thinkable': ['believable', 'cogitable', 'conceivable', 'conceivably possible', 'contingent', 'credible', 'fanciable', 'feasible', 'humanly possible', 'imaginable', 'likely', 'plausible'],
    'thinker': ['brahmin', 'nestor', 'solomon', 'authority', 'brainworker', 'casuist', 'cosmologist', 'dialectician', 'doctor', 'egghead', 'elder', 'elder statesman'],
    'thinking': ['abstract thought', 'act of thought', 'assessment', 'assumption', 'attitude', 'belief', 'brainwork', 'cerebral', 'cerebration', 'climate of opinion', 'cogitation', 'cogitative'],
    'thinned': ['adulterated', 'airy', 'attenuate', 'attenuated', 'cut', 'dilute', 'diluted', 'ethereal', 'fine', 'flimsy', 'gaseous', 'insubstantial'],
    'thinner': ['anticoagulant', 'chromogen', 'coat', 'coat of paint', 'coating', 'color', 'color filter', 'color gelatin', 'colorant', 'coloring', 'dead-color', 'diluent'],
    'thinness': ['lenten fare', 'admission of light', 'airiness', 'airy nothing', 'airy texture', 'attenuation', 'austerity', 'bodilessness', 'chinchiness', 'chintziness', 'clarity', 'clearness'],
    'thinning': ['sanforizing', 'abatement', 'adulteration', 'atrophy', 'attenuation', 'attrition', 'blunting', 'consumption', 'contour plowing', 'cultivating', 'cultivation', 'culture'],
    'third': ['consecutive intervals', 'degree', 'diapason', 'diatessaron', 'diatonic interval', 'diatonic semitone', 'divide in thirds', 'enharmonic diesis', 'enharmonic interval', 'fifth', 'fourth', 'half step'],
    'third class': ['mickey mouse', 'base', 'cheap', 'cheesy', 'coarse', 'common', 'fourth-class', 'inferior', 'irregular', 'low-class', 'low-grade', 'low-quality'],
    'third degree': ['cross-examination', 'cross-examine', 'cross-interrogate', 'cross-interrogation', 'cross-question', 'cross-questioning', 'direct examination', 'extract information', 'go over', 'grill', 'grilling', 'inquisition'],
    'third estate': ['bourgeoisie', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty', 'commoners', 'commons', 'laborers', 'linendrapers', 'lower classes'],
    'third party': ['american party', 'anti-monopoly party', 'bull moose party', 'communist party', 'conservative party', 'constitutional union party', 'democratic party', 'democratic-republican party', 'farmer-labor party', 'federalist party', 'free soil party', 'greenback party'],
    'third rate': ['mickey mouse', 'base', 'cheap', 'cheesy', 'coarse', 'common', 'fourth-class', 'inferior', 'irregular', 'low-class', 'low-grade', 'low-quality'],
    'third string': ['agent', 'alternate', 'alternative', 'analogy', 'back seat', 'backup', 'cast', 'change', 'changeling', 'company', 'comparison', 'complement'],
    'third world': ['laodicean', 'anythingarian', 'apathetic', 'autarchic', 'autarkic', 'autonomous', 'centrist', 'even', 'fence-sitter', 'fifty-fifty', 'free lance', 'free spirit'],
    'thirst': ['ache', 'an universal wolf', 'appetence', 'appetency', 'appetite', 'appetition', 'aridity', 'aridness', 'avidity', 'be ravenous', 'canine appetite', 'corkiness'],
    'thirst quencher': ['alcoholic drink', 'beverage', 'drink', 'drinkable', 'frosted', 'frosted shake', 'liquid', 'liquor', 'malt', 'pop', 'potable', 'potation'],
    'thirsty': ['saharan', 'absorbent', 'adsorbent', 'agog', 'anhydrous', 'anxious', 'ardent', 'arid', 'assimilative', 'athirst', 'avaricious', 'avid'],
    'thistle': ['armory', 'badge', 'badge of office', 'badges', 'baton', 'blazonry', 'bramble', 'brassard', 'brier', 'bristle', 'burr', 'button'],
    'thong': ['belt', 'blacksnake', 'braid', 'brail', 'bullwhack', 'bullwhip', 'cable', 'cat', 'cord', 'cowhide', 'crop', 'flagellum'],
    'thor': ['aesir', 'balder', 'bor', 'bori', 'bragi', 'donar', 'forseti', 'frey', 'freya', 'freyja', 'freyr', 'frigg'],
    'thorax': ['bag', 'boobs', 'bosom', 'breast', 'breasts', 'brisket', 'bust', 'chest', 'crop', 'dug', 'knockers', 'mama'],
    'thorn': ['adherent', 'adhesive', 'affliction', 'annoyance', 'bane', 'barb', 'barnacle', 'bitter cup', 'bitter draft', 'bitter draught', 'bitter pill', 'bother'],
    'thorny': ['herculean', 'abstruse', 'acanaceous', 'acanthoid', 'aciculate', 'aculeolate', 'arduous', 'barbed', 'barbellate', 'brambly', 'briery', 'bristly'],
    'thorough': ['absolute', 'all-embracing', 'all-encompassing', 'all-inclusive', 'all-out', 'all-pervading', 'arrant', 'assiduous', 'blow-by-blow', 'born', 'broad-based', 'canny'],
    'thoroughbred': ['american trotter', 'appaloosa', 'arabian', 'barb', 'barbary horse', 'belgian', 'brahman', 'cleveland bay', 'french coach horse', 'galloway', 'hambletonian', 'shetland'],
    'thoroughfare': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'thoroughly': ['absolutely', 'altogether', 'assiduously', 'backwards and forwards', 'carefully', 'cautiously', 'circumspectly', 'completely', 'comprehensively', 'conscientiously', 'considerately', 'definitely'],
    'thoroughness': ['assiduity', 'assiduousness', 'calculation', 'canniness', 'care', 'careful consideration', 'carefulness', 'caution', 'cautiousness', 'circumspection', 'completeness', 'comprehensiveness'],
    'though': ['admitting that', 'after all', 'again', 'albeit', 'all the same', 'allowing that', 'although', 'at all events', 'at any rate', 'but', 'even', 'even so'],
    'thought': ['parthian shot', 'accommodatingness', 'address', 'admonition', 'advertence', 'advertency', 'advice', 'advising', 'advocacy', 'affirmation', 'agreeableness', 'alertness'],
    'thought provoking': ['exciting', 'interesting', 'inviting', 'juicy', 'lively', 'piquant', 'provocative', 'provoking', 'racy', 'readable', 'rich', 'spicy'],
    'thoughtful': ['accommodating', 'accommodative', 'affable', 'agreeable', 'analytical', 'attentive', 'brainy', 'brooding', 'calculating', 'careful', 'caring', 'cautious'],
    'thoughtfulness': ['tlc', 'absorption', 'abstraction', 'accommodatingness', 'affability', 'agreeableness', 'amenity', 'anticipation', 'attention', 'attentiveness', 'brown study', 'care'],
    'thoughtless': ['absent-minded', 'airy', 'apish', 'arbitrary', 'artless', 'asinine', 'batty', 'befooled', 'beguiled', 'besotted', 'blank', 'blankminded'],
    'thoughtlessness': ['abandon', 'absentmindedness', 'asininity', 'battiness', 'brainlessness', 'buffoonery', 'callowness', 'caprice', 'careless abandon', 'carelessness', 'casualness', 'childishness'],
    'thousand': ['a billion', 'a crore', 'a lakh', 'a million', 'a myriad', 'a nonillion', 'a quadrillion', 'a thousand', 'a zillion', 'billion', 'chiliad', 'chiliagon'],
    'thrall': ['absolutism', 'bond service', 'bondage', 'bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'captive', 'captivity', 'chattel', 'chattel slave'],
    'thrash': ['bang', 'baste', 'bastinado', 'batter', 'beat', 'beat all hollow', 'beat hollow', 'belabor', 'belt', 'best', 'birch', 'bolt'],
    'thrash about': ['agonize over', 'be at sea', 'be uncertain', 'beat about', 'blunder', 'careen', 'career', 'doubt', 'falter', 'feel unsure', 'flounce', 'flounder'],
    'thrash out': ['agitate', 'appraise', 'argue', 'argufy', 'assess', 'bandy words', 'bicker', 'canvass', 'catalog', 'categorize', 'cavil', 'choplogic'],
    'thrashing': ['waterloo', 'assault', 'bastinado', 'basting', 'battering', 'battery', 'beating', 'belting', 'buffeting', 'caning', 'castigation', 'chastisement'],
    'thread': ['aralac', 'avisco', 'celanese', 'chemstrand', 'dacron', 'dynel', 'indian file', 'lastex', 'manila', 'orlon', 'terylene', 'velon'],
    'threadbare': ['back-number', 'banal', 'bare', 'bathetic', 'bewhiskered', 'boring', 'bromidic', 'cliche', 'cliche-ridden', 'cliched', 'common', 'commonplace'],
    'threadlike': ['airy', 'attenuate', 'attenuated', 'boyish', 'capillary', 'cirrose', 'cirrous', 'delicate', 'diaphanous', 'diluted', 'ethereal', 'fibered'],
    'threads': ['apparel', 'array', 'attire', 'bedizenment', 'clothes', 'clothing', 'costume', 'drapery', 'dress', 'dressing', 'duds', 'fashion'],
    'threat': ['admonishment', 'admonition', 'alarm', 'breakers ahead', 'cardhouse', 'cause for alarm', 'caution', 'caveat', 'commination', 'crisis', 'danger', 'dangerous ground'],
    'threaten': ['abuse', 'admonish', 'advise', 'afflict', 'aggrieve', 'alert', 'anticipate', 'apprehend', 'approach', 'augur', 'await', 'be destined'],
    'threatened': ['augured', 'between two fires', 'cornered', 'endangered', 'foreshadowed', 'foreshown', 'foretokened', 'imperiled', 'in a predicament', 'in danger', 'in desperate case', 'in extremis'],
    'threatening': ['about to be', 'abusive', 'alarming', 'already in sight', 'apocalyptic', 'approaching', 'at hand', 'bad', 'baleful', 'baneful', 'black', 'bludgeoning'],
    'three dimensional': ['broad-bodied', 'bulky', 'bullnecked', 'coarse', 'corpulent', 'crass', 'cubic', 'deltoid', 'dense', 'dimensional', 'fat', 'flat'],
    'threesome': ['bout', 'clover', 'contest', 'decathlon', 'deuce-ace', 'double-header', 'doubles', 'event', 'foursome', 'game', 'games of chance', 'go'],
    'thresh': ['bang', 'baste', 'batter', 'beat', 'bolt', 'buffet', 'cordon', 'cordon off', 'cull out', 'divide', 'drub', 'flail'],
    'threshold': ['french door', 'archway', 'back door', 'barway', 'beginning', 'border line', 'bound', 'boundary', 'boundary condition', 'boundary line', 'bourn', 'break boundary'],
    'thrift': ['austerity', 'austerity program', 'canniness', 'care', 'carefulness', 'chariness', 'economic planning', 'economicalness', 'economizing', 'economy', 'economy of means', 'false economy'],
    'thrift shop': ['antique store', 'apothecary', 'automobile showroom', 'bookstore', 'bootery', 'candy store', 'chemist', 'cigar store', 'clothiers', 'clothing store', 'confectionery', 'dress shop'],
    'thriftiness': ['austerity', 'austerity program', 'canniness', 'care', 'carefulness', 'chariness', 'economic planning', 'economicalness', 'economy', 'economy of means', 'false economy', 'forehandedness'],
    'thrifty': ['scotch', 'blooming', 'booming', 'burgeoning', 'canny', 'careful', 'chary', 'cheap', 'cheeseparing', 'conserving', 'economic', 'economical'],
    'thrill': ['ache', 'acute pain', 'agonize', 'ail', 'anguish', 'animate', 'arouse', 'bang', 'becharm', 'bewitch', 'bite', 'blanch'],
    'thrilled': ['agog', 'aquiver', 'aroused', 'atingle', 'atwitter', 'bursting', 'carried away', 'charmed', 'comfortable', 'content', 'contented', 'cozy'],
    'thriller': ['cinemascope', 'cinerama', 'marchen', 'technicolor', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'animated cartoon', 'apologue', 'bedtime story'],
    'thrilling': ['agitating', 'animating', 'appealing', 'arousing', 'attractive', 'bewitching', 'breathtaking', 'captivating', 'charged', 'charming', 'cliff-hanging', 'delightful'],
    'thrive': ['advance', 'arrive', 'batten', 'be energetic', 'be vigorous', 'bloom', 'blossom', 'boom', 'brew', 'burgeon', 'burst with energy', 'come on'],
    'thriving': ['abundance', 'abundant', 'advancing', 'balmy', 'blooming', 'blossoming', 'booming', 'bountiful', 'budding', 'burgeoning', 'bursting', 'bursting out'],
    'throat': ['bottleneck', 'canal', 'channel', 'defile', 'esophagus', 'fauces', 'goozle', 'gorge', 'gullet', 'guzzle', 'hals', 'isthmus'],
    'throaty': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'blurred', 'brassy'],
    'throb': ['ache', 'agonize', 'ail', 'anguish', 'arrhythmia', 'bar beat', 'barrage', 'beat', 'beat a ruffle', 'beat a tattoo', 'beating', 'bicker'],
    'throbbing': ['aching', 'achy', 'arrhythmia', 'backachy', 'barrage', 'beat', 'beating', 'cadenced', 'cadent', 'clicking', 'colicky', 'didder'],
    'throes': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'ache', 'aching', 'acquired epilepsy', 'activated epilepsy', 'acute pain', 'affect epilepsy', 'akinetic epilepsy', 'apoplexy'],
    'thrombosis': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'akinetic epilepsy', 'angina', 'angina pectoris', 'aortic insufficiency', 'aortic stenosis'],
    'throne': ['peacock throne', 'aggrandize', 'anoint', 'apotheose', 'apotheosize', 'beatify', 'bedpan', 'can', 'canonize', 'chair', 'chamber', 'chamber pot'],
    'throng': ['a mass of', 'a world of', 'abound with', 'army', 'assemblage', 'assemble', 'assembly', 'be alive with', 'bevy', 'bristle with', 'bunch', 'bunch up'],
    'throttle': ['abduct', 'arrest', 'asphyxiate', 'backpedal', 'backwater', 'bottle up', 'brake', 'burke', 'carry off', 'censor', 'check', 'choke'],
    'throttling': ['asphyxia', 'asphyxiation', 'burking', 'censorship', 'choke', 'choking', 'crackdown', 'crushing', 'drowning', 'extinguishment', 'garrote', 'putting down'],
    'through': ['sol', 'all bets off', 'all off', 'all over', 'all through', 'all up', 'around', 'at about', 'at an end', 'because of', 'breadthwise', 'broad side foremost'],
    'through and through': ['absolute', 'ad infinitum', 'all over', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'at all points', 'at full length', 'born', 'broad-based', 'clean'],
    'throughout': ['ad infinitum', 'all over', 'all through', 'amid', 'around', 'at about', 'at all points', 'at full length', 'at large', 'completely', 'diffusely', 'dispersedly'],
    'throw': ['abandon', 'addle', 'agitate', 'amaze', 'apply', 'assume', 'baffle', 'bake', 'bamboozle', 'be confined', 'be sick', 'bear'],
    'throw away': ['abandon', 'abjure', 'blow', 'blunder away', 'boot out', 'bounce', 'brush aside', 'cashier', 'cast', 'cast aside', 'cast away', 'cast off'],
    'throw down': ['beat down', 'blow down', 'blow over', 'bowl down', 'bowl over', 'break down', 'bring', 'bring down', 'bulldog', 'bulldoze', 'burn down', 'cast down'],
    'throw in': ['contribute', 'drag in', 'ease in', 'edge in', 'fill in', 'foist in', 'fudge in', 'implant in', 'infuse', 'inject', 'inject in', 'inoculate'],
    'throw in with': ['act with', 'affiliate', 'align with', 'ally', 'associate', 'band together', 'be in cahoots', 'bunch', 'bunch up', 'cabal', 'cement a union', 'centralize'],
    'throw off': ['abandon', 'abrupt', 'ad-lib', 'addle', 'alienate', 'articulate', 'ball up', 'bat out', 'befuddle', 'bewilder', 'blow', 'botch'],
    'throw out': ['abandon', 'abjure', 'abrupt', 'addle', 'alienate', 'ball up', 'befuddle', 'bewilder', 'blow out', 'boot out', 'bounce', 'bring out'],
    'throw over': ['abandon', 'abstract', 'back out', 'beg off', 'cast', 'cast aside', 'cast away', 'cast off', 'cast out', 'chuck', 'clear', 'clear away'],
    'throw stick': ['irish confetti', 'arbalest', 'ballista', 'bola', 'bolt', 'boomerang', 'brickbat', 'catapult', 'countermissile', 'missile', 'projectile', 'rock'],
    'throw together': ['ad-lib', 'admix', 'alloy', 'amalgamate', 'bat out', 'bemingle', 'blend', 'botch', 'bungle', 'coalesce', 'combine', 'commingle'],
    'throw up': ['abandon', 'abdicate', 'abjure', 'acknowledge defeat', 'barf', 'be seasick', 'be sick', 'boost', 'bring up', 'buoy up', 'cast up', 'cease'],
    'throwaway': ['castaway', 'castoff', 'consumable', 'deep six', 'discard', 'discarding', 'disposable', 'disposal', 'dumping', 'elimination', 'expendable', 'jettison'],
    'throwback': ['atavism', 'backset', 'backsliding', 'backward deviation', 'backward motion', 'backward step', 'check', 'comedown', 'descent', 'down', 'falling back', 'lapse'],
    'thrum': ['barrage', 'beat', 'beat a ruffle', 'beat a tattoo', 'beat the drum', 'beat time', 'beating', 'birr', 'bombilate', 'bombinate', 'boom', 'bum'],
    'thrumming': ['beating', 'birring', 'bombilation', 'bombinating', 'bombination', 'booming', 'burring', 'buzzing', 'clicking', 'droning', 'drumming', 'fluttering'],
    'thrush': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'philomel', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax'],
    'thrust': ['acceleration', 'actuate', 'advance', 'advance against', 'advance upon', 'afterburner', 'aggressiveness', 'animate', 'assault', 'atomic power', 'bang', 'bear'],
    'thrust aside': ['abandon', 'brush aside', 'brush off', 'dismiss', 'drop the subject', 'forget', 'forget about it', 'forget it', 'lay aside', 'let it go', 'let slip', 'push aside'],
    'thrust back': ['beat back', 'brush off', 'chase', 'chase away', 'chase off', 'cut', 'dismiss', 'drive away', 'drive back', 'fend off', 'hold off', 'keep off'],
    'thrust in': ['admit', 'barge in', 'be admitted', 'break in', 'break in upon', 'breeze in', 'burst in', 'bust in', 'butt in', 'charge in', 'come barging in', 'come between'],
    'thrust out': ['ban', 'banish', 'blackball', 'boot out', 'bounce', 'carry', 'cast', 'cast out', 'chuck out', 'cover', 'cut', 'defenestrate'],
    'thruway': ['autobahn', 'us highway', 'alley', 'alleyway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada', 'avenue', 'belt highway'],
    'thud': ['beat', 'bump', 'chink', 'click', 'clink', 'clop', 'clump', 'clunk', 'crump', 'dull thud', 'flick', 'flump'],
    'thug': ['cain', 'judas', 'mafioso', 'adherent', 'apache', 'assassin', 'assassinator', 'bandit', 'battler', 'belligerent', 'belted knight', 'betrayer'],
    'thumb': ['ok', 'accept', 'all thumbs', 'annulary', 'approve of', 'awkward', 'be contemptuous of', 'catch a ride', 'clumsy', 'come in contact', 'contemn', 'dactylion'],
    'thumb through': ['browse', 'dip into', 'examine cursorily', 'flip', 'give the once-over', 'glance at', 'glance over', 'glance through', 'page through', 'pass over lightly', 'run over', 'run through'],
    'thumbnail sketch': ['abbreviation', 'abbreviature', 'abrege', 'abridgment', 'abstract', 'brief', 'capsule', 'compend', 'condensation', 'condensed version', 'conspectus', 'digest'],
    'thumbprint': ['boss', 'bump', 'colophon', 'concavity', 'convexity', 'dactylogram', 'dactylograph', 'dent', 'dint', 'embossment', 'excrescence', 'fingerprint'],
    'thumbs down': ['abnegation', 'ban', 'blackball', 'blackballing', 'complaint', 'contradiction', 'declension', 'declination', 'declinature', 'declining', 'denial', 'deprivation'],
    'thump': ['bang', 'bash', 'baste', 'bastinado', 'bat', 'batter', 'beat', 'beat a ruffle', 'beat a tattoo', 'beat the drum', 'beat time', 'beating'],
    'thumping': ['awful', 'banging', 'barrage', 'beat', 'beating', 'behemoth', 'bumping', 'clicking', 'colossal', 'complete', 'deadly', 'dreadful'],
    'thunder': ['bedlam let loose', 'donar', 'indra', 'jupiter tonans', 'thor', 'awake the dead', 'bark', 'bawl', 'bedlam', 'bellow', 'blare', 'blare forth'],
    'thunderbolt': ['jupiter fulgur', 'thor', 'antelope', 'arrow', 'astonishment', 'ball lightning', 'blockbuster', 'blow', 'blue darter', 'blue streak', 'bolt', 'bolt of lightning'],
    'thundercloud': ['cloudcuckooland', 'alto-cumulus', 'alto-stratus', 'angry clouds', 'anvil cloud', 'banner cloud', 'billowy cloud', 'black cat', 'black clouds', 'broken mirror', 'cap cloud', 'cirro-cumulus'],
    'thundering': ['donar', 'indra', 'jupiter tonans', 'thor', 'anathema', 'ban', 'banging', 'blasphemy', 'boom', 'booming', 'bumping', 'cannonading'],
    'thunderous': ['booming', 'cannonading', 'deafening', 'ear-piercing', 'ear-rending', 'ear-splitting', 'earthshaking', 'forte', 'fortissimo', 'full', 'fulminating', 'loud'],
    'thunderstorm': ['donar', 'indra', 'jupiter tonans', 'thor', 'cyclone', 'deep', 'dirty weather', 'dread rattling thunder', 'foul weather', 'hurricane', 'line squall', 'peal of thunder'],
    'thunderstruck': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled', 'bewildered'],
    'thus': ['accordingly', 'after this fashion', 'along these lines', 'and so', 'as', 'as a consequence', 'as a result', 'as an example', 'as an instance', 'at what price', 'because of that', 'because of this'],
    'thus far': ['after a fashion', 'already', 'appreciably', 'as yet', 'at any rate', 'at best', 'at least', 'at most', 'at the outside', 'at worst', 'by this time', 'comparatively'],
    'thwack': ['bang', 'bash', 'bat', 'beating', 'belt', 'biff', 'blow', 'bonk', 'bop', 'bump', 'burst', 'bust'],
    'thwart': ['across', 'across the grain', 'annul', 'athwart', 'athwartships', 'baffle', 'balk', 'beat', 'bench', 'bendwise', 'bias', 'biased'],
    'thwarted': ['baffled', 'balked', 'betrayed', 'bilked', 'blasted', 'blighted', 'chapfallen', 'crestfallen', 'crossed', 'crushed', 'dashed', 'defeated'],
    'thwarting': ['annulment', 'bafflement', 'balk', 'balking', 'buck-passing', 'cancellation', 'check', 'checkmate', 'circumvention', 'confounding', 'counterbalancing', 'defeat'],
    'tiara': ['anklet', 'armlet', 'bangle', 'beads', 'bijou', 'bracelet', 'breastpin', 'brooch', 'cap of dignity', 'cap of maintenance', 'chain', 'chaplet'],
    'tic': ['abstraction', 'abulia', 'agitation', 'alienation', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'apprehensiveness', 'attack of nerves', 'bob', 'bobble'],
    'tick': ['act', 'arachnid', 'arthropod', 'bank credit', 'be effective', 'be in action', 'beat', 'bedbug', 'beetle', 'birthmark', 'blaze', 'blaze a trail'],
    'tick off': ['admonish', 'anger', 'blaze', 'blaze a trail', 'blemish', 'blotch', 'brand', 'call down', 'chalk', 'chalk up', 'check', 'check off'],
    'ticked off': ['angered', 'angry', 'browned-off', 'cross', 'incensed', 'indignant', 'irate', 'ireful', 'livid', 'mad', 'pissed', 'pissed-off'],
    'ticker': ['american stock exchange', 'amex', 'big ben', 'telautography', 'teletype', 'teletype network', 'teletyping', 'wall street', 'abdomen', 'anus', 'appendix', 'blind gut'],
    'ticker tape': ['american stock exchange', 'amex', 'mystik tape', 'scotch tape', 'wall street', 'adhesive tape', 'band', 'bandage', 'batten', 'belt', 'board', 'bourse'],
    'ticket': ['australian ballot', 'indiana ballot', 'massachusetts ballot', 'ok', 'absentee ballot', 'admission', 'affidavit', 'allowance', 'attestation', 'authority', 'authorization', 'baggage check'],
    'tickle': ['affect the interest', 'agitate', 'amuse', 'appeal', 'arouse', 'attract', 'be attractive', 'beak', 'becharm', 'beckon', 'beguile', 'bewitch'],
    'tickled': ['amused', 'attracted', 'cathectic', 'charmed', 'comfortable', 'concerned', 'content', 'contented', 'cozy', 'curious', 'delighted', 'diverted'],
    'tickling': ['alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching', 'charismatic', 'charming'],
    'ticklish': ['herculean', 'abstruse', 'allergic', 'anaphylactic', 'arduous', 'awkward', 'brutal', 'capricious', 'changeable', 'complex', 'critical', 'dangerous'],
    'tidal': ['affluent', 'aquatic', 'balneal', 'confluent', 'coursing', 'decurrent', 'deep-sea', 'defluent', 'diffluent', 'estuarine', 'flowing', 'fluent'],
    'tidal wave': ['amplitude', 'antinode', 'apoplexy', 'billow', 'bore', 'breakers', 'breakup', 'cataclysm', 'chop', 'choppiness', 'chopping sea', 'climax'],
    'tidbit': ['ambrosia', 'bonne bouche', 'cate', 'character assassination', 'choice morsel', 'dainty', 'delicacy', 'dessert', 'dirt', 'goody', 'gossip column', 'juicy morsel'],
    'tiddly': ['addled', 'beery', 'bemused', 'besotted', 'blind drunk', 'boozy', 'canned', 'crapulent', 'crapulous', 'disguised', 'dizzy', 'drenched'],
    'tide': ['affluence', 'afflux', 'affluxion', 'big drink', 'blue water', 'chronology', 'concourse', 'confluence', 'conflux', 'continuity', 'course', 'crosscurrent'],
    'tide gate': ['aboideau', 'air lock', 'direct tide', 'dock gate', 'ebb', 'ebb and flow', 'ebb tide', 'flood', 'flood tide', 'flood-hatch', 'floodgate', 'flow'],
    'tide over': ['abide', 'be safe', 'bide', 'carry on', 'come through', 'continue', 'continue to be', 'defeat time', 'defy time', 'dwell', 'endure', 'exist'],
    'tidewater': ['bank', 'bayed', 'beach', 'berm', 'coast', 'coastland', 'coastline', 'direct tide', 'ebb', 'ebb and flow', 'ebb tide', 'embankment'],
    'tidings': ['advice', 'broadcast journalism', 'information', 'intelligence', 'journalism', 'news', 'news agency', 'news medium', 'news service', 'newsiness', 'newsletter', 'newsmagazine'],
    'tidy': ['ok', 'acceptable', 'adequate', 'admissible', 'all right', 'ample', 'anal', 'arrange', 'better than nothing', 'big', 'bleach', 'bowdlerize'],
    'tidy sum': ['a mass of', 'a world of', 'army', 'batch', 'bevy', 'bunch', 'cloud', 'clutter', 'considerable', 'covey', 'deal', 'flight'],
    'tie': ['roman collar', 'tweedledum and tweedledee', 'accent', 'accent mark', 'accord', 'accouple', 'accumulate', 'addition', 'adherence', 'adhesion', 'adjunct', 'affairs'],
    'tie in': ['accord', 'act in concert', 'act together', 'addition', 'adjunct', 'affairs', 'affect', 'affiliate', 'affiliation', 'affinity', 'agglomeration', 'agglutination'],
    'tie up': ['anschluss', 'act in concert', 'act together', 'addition', 'affiliate', 'affiliation', 'afterthought', 'agglomeration', 'agglutination', 'aggregation', 'agreement', 'alight'],
    'tied': ['affiliate', 'affiliated', 'aground', 'alike', 'allied', 'anchored', 'assembled', 'associate', 'associated', 'at par', 'au pair', 'banded together'],
    'tied up': ['absorbed in', 'at it', 'at work', 'bound', 'burdened with debt', 'busy', 'caught up in', 'deep in debt', 'embarrassed', 'employed', 'encumbered', 'engaged'],
    'tier': ['indian file', 'array', 'articulation', 'band', 'bank', 'bed', 'bedding', 'belt', 'buzz', 'category', 'catena', 'catenation'],
    'tiff': ['altercate', 'altercation', 'argument', 'bicker', 'bickering', 'blood feud', 'brawl', 'broil', 'caterwaul', 'contention', 'controversy', 'differ'],
    'tiger': ['achilles', 'david', 'hector', 'leo', 'mafioso', 'roland', 'samson', 'siberian tiger', 'young turk', 'a man', 'animal', 'anthropophagite'],
    'tight': ['spartan', 'abbreviated', 'abridged', 'afflicted', 'airtight', 'all ataunto', 'anal', 'angustifoliate', 'angustirostrate', 'angustisellate', 'angustiseptal', 'aposiopestic'],
    'tight lipped': ['brief', 'brusque', 'close', 'close-tongued', 'closemouthed', 'concise', 'curt', 'dumb', 'economical of words', 'indisposed to talk', 'laconic', 'mum'],
    'tight spot': ['bind', 'clutch', 'complication', 'crunch', 'cubby', 'cubbyhole', 'doghouse', 'embarrassing position', 'embarrassment', 'fine how-do-you-do', 'hell to pay', 'hobble'],
    'tight squeeze': ['bind', 'broken fortune', 'close call', 'close shave', 'close squeak', 'closeness', 'clutch', 'complication', 'confinement', 'crowdedness', 'crunch', 'cubby'],
    'tighten': ['affix', 'anchor', 'annex', 'attach', 'back', 'belay', 'box', 'box in', 'box up', 'brace', 'cement', 'cinch'],
    'tightening': ['accelerando', 'acceleration', 'aggravation', 'beefing-up', 'blowing up', 'blowup', 'clamping', 'clamping down', 'compression', 'concentration', 'condensation', 'consolidation'],
    'tightness': ['jim crow', 'adhesiveness', 'alien', 'apartheid', 'avarice', 'bullheadedness', 'cheapness', 'chinchiness', 'chintziness', 'closefistedness', 'closeness', 'cohesiveness'],
    'tightrope walker': ['acrobat', 'aerialist', 'bareback rider', 'circus artist', 'clown', 'contortionist', 'equestrian director', 'equilibrist', 'flier', 'funambulist', 'gymnast', 'high wire artist'],
    'tigress': ['jezebel', 'mafioso', 'partlet', 'young turk', 'battle-ax', 'beast', 'beldam', 'berserk', 'berserker', 'biddy', 'bitch', 'bitch-kitty'],
    'tile': ['tarmac', 'tarvia', 'adobe', 'ashlar', 'asphalt', 'biscuit', 'bisque', 'bitumen', 'bituminous macadam', 'blacktop', 'board', 'bowl'],
    'tiling': ['adobe', 'ashlar', 'biscuit', 'bisque', 'bowl', 'brick', 'bricks and mortar', 'carpet', 'carpeting', 'cement', 'ceramic ware', 'ceramics'],
    'till': ['fort knox', 'backset', 'bank', 'before', 'blackmail', 'boodle', 'booty', 'bursary', 'cash register', 'cashbox', 'chest', 'coffer'],
    'tiller': ['bauer', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'coffee-planter', 'collective farm worker', 'crofter', 'cropper', 'cultivator', 'dirt farmer', 'dry farmer'],
    'tilt': ['olympic games', 'olympics', 'a outrance', 'altercation', 'angle', 'angularity', 'argument', 'ascend', 'attack', 'bandy with', 'bank', 'battle'],
    'tilting': ['aslant', 'aslope', 'atilt', 'bevel', 'beveled', 'bias', 'biased', 'canting', 'careening', 'inclinational', 'inclinatory', 'inclined'],
    'timbale': ['danish pastry', 'french pastry', 'baklava', 'blintz', 'chocolate eclair', 'cream puff', 'dowdy', 'eclair', 'pandowdy', 'pastry', 'pasty', 'patisserie'],
    'timber': ['afforestation', 'arboretum', 'balk', 'bare pole', 'beam', 'beams', 'billet', 'board', 'boarding', 'boards', 'boondocks', 'bush'],
    'timbered': ['afforestational', 'arboreous', 'bosky', 'braky', 'bushy', 'copsy', 'dendrologic', 'forest', 'forestal', 'forested', 'reforestational', 'scrubby'],
    'timberland': ['afforestation', 'arboretum', 'boondocks', 'bush', 'bushveld', 'chase', 'climax forest', 'cloud forest', 'dendrology', 'forest', 'forest land', 'forest preserve'],
    'timbre': ['klangfarbe', 'clang color', 'color', 'coloring', 'manner of speaking', 'mode of expression', 'mood', 'resonance', 'spirit', 'tonality', 'tone', 'tone color'],
    'timbrel': ['bongo drum', 'conga', 'drum', 'drumhead', 'drumskin', 'drumstick', 'jazz stick', 'kettle', 'kettledrum', 'membranophone', 'side drum', 'snare'],
    'timbuktu': ['china', 'darkest africa', 'god knows where', 'greenland', 'north pole', 'outer mongolia', 'pago pago', 'pillars of hercules', 'siberia', 'south pole', 'thule', 'tierra del fuego'],
    'time': ['archean', 'archeozoic', 'cambrian', 'carboniferous', 'cenozoic', 'comanchean', 'cretaceous', 'devonian', 'eocene', 'glacial', 'holocene', 'international date line'],
    'time bomb': ['aerial bomb', 'antipersonnel bomb', 'bomb', 'bombshell', 'carcass', 'concussion grenade', 'depth bomb', 'depth charge', 'fire bomb', 'gas grenade', 'grenade', 'hand grenade'],
    'time immemorial': ['ancient history', 'ancient times', 'ancientness', 'and night', 'antiquity', 'day after day', 'distance of time', 'distant past', 'enduringly', 'for an age', 'for life', 'for long'],
    'time lag': ['afterthought', 'bind', 'block', 'blockage', 'bureaucratic delay', 'day', 'delay', 'delayage', 'delayed reaction', 'detention', 'double take', 'dragging'],
    'time off': ['alternate', 'break', 'coffee break', 'cover', 'do a hitch', 'do a stint', 'do a tour', 'do time', 'downtime', 'enlist', 'fill in for', 'furlough'],
    'time out': ['break', 'breath', 'breather', 'breathing place', 'breathing space', 'breathing spell', 'breathing time', 'check in', 'check off', 'check out', 'cigarette break', 'clock in'],
    'time saving': ['scotch', 'canny', 'careful', 'chary', 'cheeseparing', 'conserving', 'economic', 'economizing', 'forehanded', 'frugal', 'labor-saving', 'money-saving'],
    'time sheet': ['annals', 'check sheet', 'chronicle', 'chronology', 'clock card', 'date slip', 'datebook', 'daybook', 'diary', 'journal', 'log', 'record'],
    'time signature': ['accent', 'accent mark', 'bar', 'cancel', 'character', 'custos', 'direct', 'dot', 'expression mark', 'fermata', 'hold', 'key signature'],
    'time study': ['annals', 'check sheet', 'chronicle', 'chronology', 'clock card', 'date slip', 'datebook', 'daybook', 'diary', 'efficiency engineering', 'efficiency expert', 'industrial engineering'],
    'time zone': ['alaska time', 'atlantic time', 'central time', 'eastern time', 'gmt', 'greenwich mean time', 'greenwich time', 'mountain time', 'yukon time', 'apparent time', 'civil time', 'daylight-saving time'],
    'time-honored': ['accepted', 'acknowledged', 'admitted', 'age-old', 'august', 'awe-inspiring', 'awesome', 'awful', 'conformable', 'consuetudinary', 'conventional', 'current'],
    'time-worn': ['ageing', 'ancient', 'antiquated', 'antique', 'archaic', 'broken-down', 'dated', 'decrepit', 'dilapidated', 'dog-eared', 'hackneyed', 'moth-eaten'],
    'timecard': ['annals', 'check sheet', 'chronicle', 'chronology', 'clock card', 'date slip', 'datebook', 'daybook', 'diary', 'journal', 'log', 'record'],
    'timekeeper': ['big ben', 'accountant', 'amanuensis', 'annalist', 'archivist', 'bookkeeper', 'calendar maker', 'calendarist', 'chronicler', 'chronographer', 'chronologer', 'chronologist'],
    'timekeeping': ['annalistic', 'calendar-making', 'calendarial', 'calendric', 'chronogrammatic', 'chronographic', 'chronologic', 'chronology', 'chronoscopic', 'chronoscopy', 'clock-making', 'clocking'],
    'timeless': ['abiding', 'age-old', 'ageless', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'ancient', 'antique', 'auld', 'boundless'],
    'timelessness': ['ceaselessness', 'coeternity', 'constancy', 'continualness', 'continuance', 'durability', 'endlessness', 'eternalness', 'eternity', 'ever-duringness', 'everlastingness', 'everness'],
    'timeliness': ['advantage', 'advantageousness', 'advisability', 'appropriateness', 'beneficialness', 'convenience', 'decency', 'desirability', 'expedience', 'expediency', 'feasibility', 'fitness'],
    'timely': ['advantageous', 'advisable', 'appropriate', 'auspicious', 'becoming', 'befitting', 'betimes', 'congruous', 'convenient', 'decent', 'desirable', 'expedient'],
    'timepiece': ['big ben', 'alarm clock', 'alarm watch', 'astronomical clock', 'atomic clock', 'box chronometer', 'calendar clock', 'calendar watch', 'chronograph', 'chronometer', 'chronopher', 'chronoscope'],
    'timer': ['big ben', 'annalist', 'automatic switch', 'calendar maker', 'calendarist', 'channel selector', 'check valve', 'chronicler', 'chronographer', 'chronologer', 'chronologist', 'chronometer'],
    'times': ['affairs', 'circumstances', 'concerns', 'condition of things', 'conditions', 'contemporaneity', 'contemporaneousness', 'dealings', 'doings', 'goings-on', 'historical present', 'life'],
    'timeserver': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'quisling', 'vicar of bray', 'apple-polisher', 'archtraitor', 'ass-licker', 'backscratcher', 'backslapper', 'betrayer'],
    'timetable': ['agenda', 'annals', 'calendar', 'card', 'check sheet', 'chronicle', 'chronology', 'clock card', 'curriculum', 'date slip', 'datebook', 'daybook'],
    'timeworn': ['age-old', 'aged', 'anile', 'antediluvian', 'antique', 'back-number', 'banal', 'bare', 'bewhiskered', 'bromidic', 'cliched', 'common'],
    'timid': ['afraid', 'apprehensive', 'bashful', 'cautious', 'chicken', 'chickenhearted', 'confused', 'conscious', 'coward', 'cowardly', 'cowed', 'coy'],
    'timidity': ['afraidness', 'bashfulness', 'chicken-liveredness', 'chickenheartedness', 'confusion', 'cowardice', 'cowardliness', 'coyness', 'demureness', 'demurity', 'diffidence', 'embarrassment'],
    'timing': ['ability', 'accommodation', 'accord', 'accordance', 'adaptation', 'address', 'adeptness', 'adjustment', 'adroitness', 'affinity', 'agreement', 'airmanship'],
    'timorous': ['afraid', 'bashful', 'chicken', 'chickenhearted', 'confused', 'conscious', 'coward', 'cowardly', 'cowed', 'coy', 'daunted', 'demure'],
    'timpani': ['bongo drum', 'conga', 'drum', 'drumhead', 'drumskin', 'drumstick', 'jazz stick', 'kettle', 'kettledrum', 'membranophone', 'side drum', 'snare'],
    'tin': ['affected', 'apocryphal', 'artificial', 'assumed', 'aureate', 'bag', 'barrel', 'basket', 'bastard', 'bogus', 'bottle', 'box'],
    'tincture': ['achievement', 'achromatism', 'alerion', 'animal charge', 'annulet', 'apply paint', 'argent', 'armorial bearings', 'armory', 'arms', 'azure', 'bandeau'],
    'tined': ['acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'barbed', 'cornuted', 'cusped', 'cuspidate'],
    'tinge': ['achromatism', 'affect', 'allegory', 'allusion', 'apply paint', 'arcane meaning', 'assumption', 'bedaub', 'bedizen', 'begild', 'bend', 'besmear'],
    'tingle': ['ache', 'agonize', 'ail', 'anguish', 'bang', 'blanch', 'blench', 'boot', 'burn', 'burning', 'burning pain', 'change ringing'],
    'tingling': ['agog', 'algetic', 'angry', 'aquiver', 'aroused', 'atingle', 'atwitter', 'bang', 'boot', 'burn', 'burning', 'burning pain'],
    'tinhorn': ['middle america', 'adventurer', 'betting ring', 'bettor', 'boneshaker', 'bourgeoisie', 'burgherdom', 'cardshark', 'cardsharp', 'cardsharper', 'compulsive gambler', 'crap shooter'],
    'tinker': ['cobble', 'cobbler', 'commission', 'condition', 'coquet', 'dabble', 'dally', 'darn', 'do up', 'doctor', 'doodle', 'fiddle'],
    'tinkering': ['coquetry', 'dabbling', 'dalliance', 'dallying', 'fiddling', 'flirtation', 'fooling', 'fooling around', 'idling', 'jerking off', 'kidding around', 'loitering'],
    'tinkle': ['babble', 'bump', 'change ringing', 'chat', 'chatter', 'chime', 'chiming', 'chink', 'clack', 'clang', 'clanging', 'clangor'],
    'tinkling': ['change ringing', 'chime', 'chiming', 'chink', 'clang', 'clanging', 'clangor', 'clank', 'clanking', 'clink', 'ding', 'ding-a-ling'],
    'tinny': ['mickey mouse', 'aureate', 'base', 'brass', 'brassy', 'brazen', 'bronze', 'bronzy', 'cheap', 'cheesy', 'choked', 'coarse'],
    'tinsel': ['affected', 'apocryphal', 'apparent', 'artificial', 'assumed', 'bastard', 'bead', 'bejewel', 'beribbon', 'bespangle', 'blatant', 'blink'],
    'tinselly': ['blinking', 'blinky', 'coruscant', 'coruscating', 'glimmering', 'glimmerous', 'glimmery', 'glistening', 'glistering', 'glittering', 'glittery', 'scintillant'],
    'tint': ['munsell chroma', 'achromatism', 'affect', 'apply paint', 'bedaub', 'bedizen', 'begild', 'besmear', 'brightness', 'brush on paint', 'burr', 'calcimine'],
    'tiny': ['lilliputian', 'bantam', 'bitsy', 'bitty', 'cursory', 'dainty', 'delicate', 'depthless', 'diminutive', 'dwarf', 'dwarfish', 'elfin'],
    'tip': ['thule', 'trinkgeld', 'ultima thule', 'acme', 'aculeus', 'acumination', 'admonish', 'advice', 'advise', 'alert', 'alerting', 'alveolar ridge'],
    'tip off': ['admonish', 'admonishment', 'admonition', 'advice', 'advise', 'alarm', 'alert', 'alerting', 'breathe', 'buzz', 'catchword', 'caution'],
    'tip top': ['acmatic', 'acme', 'apex', 'apical', 'apogee', 'best', 'brow', 'cap', 'capital', 'chief', 'climax', 'cloud nine'],
    'tipped': ['aslant', 'aslope', 'atilt', 'bevel', 'beveled', 'bias', 'biased', 'canting', 'capped', 'careening', 'crested', 'crowned'],
    'tipping': ['aslant', 'aslope', 'atilt', 'bevel', 'beveled', 'bias', 'biased', 'canting', 'careening', 'inclinational', 'inclinatory', 'inclined'],
    'tipple': ['aqua vitae', 'bib', 'booze', 'budge', 'drain the cup', 'dram', 'drink', 'drink bottoms-up', 'drink deep', 'drink hard', 'drink in', 'drink off'],
    'tipster': ['adventurer', 'adviser', 'announcer', 'annunciator', 'authority', 'betrayer', 'betting ring', 'bettor', 'boneshaker', 'canary', 'cardshark', 'cardsharp'],
    'tipsy': ['addled', 'aslant', 'aslope', 'atilt', 'beery', 'bemused', 'besotted', 'bevel', 'beveled', 'bias', 'biased', 'blind drunk'],
    'tiptoe': ['above', 'abovestairs', 'airward', 'all fours', 'aloft', 'aloof', 'atiptoe', 'be careful', 'be cautious', 'couch', 'crawl', 'crawling'],
    'tirade': ['abundance', 'abuse', 'address', 'after-dinner speech', 'allocution', 'amplitude', 'assailing', 'assault', 'attack', 'bawl', 'berating', 'bitter words'],
    'tire': ['annoy', 'apparel', 'array', 'attire', 'balloon tire', 'be infinitely repetitive', 'be tedious', 'beat', 'bedeck', 'bedrape', 'belted bias tire', 'belted radial tire'],
    'tired': ['all in', 'appareled', 'arrayed', 'attired', 'ausgespielt', 'beat', 'beat up', 'beaten', 'bedecked', 'blase', 'bone-weary', 'breeched'],
    'tired of': ['allayed', 'blase', 'cloyed', 'crammed', 'disgusted', 'dispirited', 'engorged', 'fed-up', 'full', 'full of', 'glutted', 'good and tired'],
    'tireless': ['active', 'ardent', 'assiduous', 'constant', 'continuing', 'determined', 'diligent', 'dogged', 'dynamic', 'enduring', 'energetic', 'enthusiastic'],
    'tiresome': ['aggravating', 'annoying', 'bland', 'boresome', 'boring', 'bothering', 'bothersome', 'burdensome', 'common', 'commonplace', 'difficult', 'disagreeable'],
    'tiring': ['boresome', 'boring', 'draining', 'drudging', 'exhausting', 'fatiguesome', 'fatiguing', 'grueling', 'irksome', 'killing', 'punishing', 'straining'],
    'tisane': ['balm', 'balsam', 'drops', 'drug', 'electuary', 'elixir', 'ethical drug', 'generic name', 'herbs', 'inhalant', 'lincture', 'linctus'],
    'tissue': ['accumulation', 'all that lives', 'anatomy', 'arabesque', 'architectonics', 'architecture', 'arrangement', 'basketry', 'basketwork', 'biosphere', 'biota', 'braiding'],
    'tit': ['bag', 'bantam', 'banty', 'boobs', 'bosom', 'breast', 'breasts', 'brisket', 'bust', 'button', 'chest', 'chit'],
    'tit for tat': ['agency', 'alternation', 'balance', 'ballast', 'battledore and shuttlecock', 'blow for blow', 'change', 'coaction', 'commutation', 'complementary distribution', 'concurrence', 'consideration'],
    'titan': ['amen-ra', 'antaean', 'antaeus', 'apollo', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'goliath', 'helios', 'herculean'],
    'titania': ['ariel', 'befind', 'corrigan', 'finnbeara', 'mab', 'oberon', 'banshee', 'brownie', 'cluricaune', 'dwarf', 'elf', 'fairy'],
    'titanic': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'amplitudinous', 'astronomic', 'astronomical', 'awesome', 'boundless'],
    'tithe': ['alms', 'alms fee', 'ask', 'assess', 'assessment', 'cess', 'charge', 'charge for', 'charity', 'collection', 'conscience money', 'contribution'],
    'titian': ['titian-red', 'adust', 'auburn', 'bay', 'bay-colored', 'bayard', 'brazen', 'bricky', 'bronze', 'bronze-colored', 'bronzed', 'brownish-red'],
    'titillate': ['affect the interest', 'amuse', 'appeal', 'attract', 'be attractive', 'becharm', 'beckon', 'beguile', 'bewitch', 'captivate', 'carry away', 'charm'],
    'titillating': ['alluring', 'amusing', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'blandishing', 'cajoling', 'captivating', 'catching', 'charismatic'],
    'titivate': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'belie', 'blazon', 'camouflage', 'color', 'dandify', 'deck', 'deck out'],
    'title': ['absolute interest', 'acknowledgments', 'adverse possession', 'alodium', 'appellation', 'appellative', 'appurtenance', 'argument', 'authority', 'back', 'back matter', 'banner'],
    'title page': ['acknowledgments', 'back', 'back matter', 'banner', 'banner head', 'bastard title', 'bibliography', 'billhead', 'book stamp', 'bookplate', 'brand', 'broad arrow'],
    'titled': ['aristocratic', 'called', 'chivalrous', 'christened', 'denominate', 'denominated', 'designated', 'dubbed', 'ducal', 'exalted', 'genteel', 'gentle'],
    'titleholder': ['beneficiary', 'cestui', 'cestui que trust', 'cestui que use', 'deedholder', 'feoffee', 'feudatory', 'householder', 'laird', 'landlady', 'landlord', 'lord'],
    'titter': ['homeric laughter', 'be in stitches', 'belly laugh', 'boff', 'boffola', 'break up', 'burst into laughter', 'burst of laughter', 'burst out', 'burst out laughing', 'burst with laughter', 'bust a gut'],
    'tittle': ['ace', 'atom', 'birthmark', 'bit', 'blaze', 'blemish', 'blotch', 'brand', 'caste mark', 'check', 'checkmark', 'cicatrix'],
    'tittle tattle': ['babble', 'babblement', 'back-fence gossip', 'backchat', 'bavardage', 'be closeted with', 'beauty-parlor chitchat', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather'],
    'titular': ['byname', 'cognominal', 'diminutive', 'epithetic', 'formal', 'honorific', 'hypocoristic', 'in name only', 'nominal', 'nominative', 'putative', 'quasi'],
    'tizzy': ['befuddlement', 'bewilderment', 'bother', 'botheration', 'chaos', 'cloud', 'confusion', 'daze', 'discombobulation', 'discomfiture', 'discomposure', 'disconcertion'],
    'tlc': ['anticipation', 'attention', 'bread', 'care', 'carefulness', 'caution', 'circumspection', 'circumspectness', 'concern', 'consideration', 'daily bread', 'economic support'],
    'to': ['against', 'as far as', 'en route to', 'for', 'headed for', 'in', 'in consideration of', 'in contemplation of', 'in order to', 'in passage to', 'in transit to', 'into'],
    'to a degree': ['a bit', 'a little', 'after a fashion', 'appositely', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least', 'at the most', 'at the outside'],
    'to and fro': ['alternately', 'back and forth', 'backward and forward', 'backwards and forwards', 'by turns', 'capriciously', 'changeably', 'desultorily', 'erratically', 'every other', 'hitch and hike', 'in and out'],
    'to be expected': ['according to expectation', 'any day', 'any hour', 'any minute', 'any moment', 'any time', 'any time now', 'as a rule', 'as expected', 'as may be', 'as per usual', 'as things go'],
    'to blame': ['accountable', 'accusable', 'amenable', 'answerable', 'arraignable', 'at fault', 'blamable', 'blameworthy', 'censurable', 'chargeable', 'criminal', 'culpable'],
    'to come': ['about to be', 'advancing', 'already in sight', 'approaching', 'approximate', 'approximative', 'at hand', 'attracted to', 'billed', 'booked', 'brewing', 'close'],
    'to do': ['ado', 'agitation', 'bluster', 'bobbery', 'boil', 'boiling', 'bother', 'botheration', 'brawl', 'broil', 'brouhaha', 'burst'],
    'to spare': ['de trop', 'dispensable', 'excess', 'expendable', 'expletive', 'extra', 'fresh', 'gratuitous', 'held back', 'held in reserve', 'held out', 'in abeyance'],
    'to the hilt': ['ad infinitum', 'all over', 'altogether', 'at all points', 'at full length', 'completely', 'comprehensively', 'entirely', 'every bit', 'every inch', 'every whit', 'exhaustively'],
    'to the letter': ['absolutely', 'dead', 'definitely', 'directly', 'even', 'exactly', 'expressly', 'faithfully', 'in all respects', 'in every respect', 'ipsissimis verbis', 'just'],
    'to the point': ['spartan', 'a propos', 'abbreviated', 'abridged', 'ad rem', 'adapted', 'admissible', 'aposiopestic', 'appertaining', 'applicable', 'applying', 'apposite'],
    'toad': ['amphibian', 'apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'batrachian', 'bootlick', 'bootlicker', 'brown-nose', 'brownie', 'bullfrog', 'clawback'],
    'toadstool': ['algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'diatom', 'fern', 'fruits and vegetables'],
    'toady': ['apple-polish', 'apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bend the knee', 'bootlick', 'bootlicker', 'bow', 'bow and scrape', 'brown-nose', 'brownie'],
    'toadying': ['abject', 'apple-polishing', 'ass-kissing', 'backscratching', 'beggarly', 'bootlicking', 'brown-nosing', 'cowering', 'crawling', 'cringing', 'crouching', 'fawnery'],
    'toast': ['french bread', 'irish soda bread', 'italian bread', 'anniversaries', 'appreciation', 'bake', 'barbecue', 'baste', 'be in heat', 'beige', 'belle', 'bib'],
    'toasty': ['aestival', 'blood-hot', 'blood-warm', 'calid', 'equatorial', 'genial', 'luke', 'lukewarm', 'mild', 'room-temperature', 'subtropical', 'summery'],
    'tobacconist': ['antique store', 'apothecary', 'automobile showroom', 'baker', 'bookdealer', 'bookseller', 'bookstore', 'bootery', 'butcher', 'candy store', 'chandler', 'chemist'],
    'tocsin': ['klaxon', 'mayday', 'sos', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal', 'alarum', 'alert', 'all clear', 'beacon'],
    'today': ['as of now', 'as things are', 'at present', 'at this juncture', 'at this moment', 'at this point', 'at this time', 'but now', 'contemporaneity', 'contemporaneousness', 'even now', 'for the nonce'],
    'toddle': ['amble', 'barge', 'bowl along', 'bundle', 'claudicate', 'clump', 'crawl', 'creep', 'dogtrot', 'drag', 'drag along', 'drag out'],
    'toddle along': ['amble', 'be getting along', 'buzz off', 'claudicate', 'come away', 'crawl', 'creep', 'depart', 'dogtrot', 'drag', 'drag along', 'drag out'],
    'toddler': ['babe', 'baby', 'baby bunting', 'bambino', 'incubator baby', 'infant', 'little angel', 'little darling', 'mewling infant', 'neonate', 'nursling', 'papoose'],
    'toddling': ['ambling', 'ambulation', 'backpacking', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'deliberate', 'easy', 'faltering'],
    'toe': ['arch', 'base', 'baseboard', 'basement', 'chassis', 'clubfoot', 'dado', 'digit', 'dog', 'extremity', 'fetlock', 'foot'],
    'toe the mark': ['attend to orders', 'comply', 'conform', 'defer to', 'fall in with', 'fall into line', 'fit in', 'follow the book', 'follow the crowd', 'follow the fashion', 'follow the rule', 'get in line'],
    'toehold': ['advantage', 'bear hug', 'bite', 'clamp', 'clasp', 'clench', 'clinch', 'cling', 'clinging', 'clutch', 'death grip', 'embrace'],
    'toft': ['acres', 'ancestral halls', 'arable land', 'arena', 'barnyard', 'barton', 'cattle ranch', 'chattels real', 'chicken farm', 'chimney corner', 'cincture', 'close'],
    'tog': ['apparel', 'array', 'attire', 'bedeck', 'bedrape', 'bundle up', 'clothe', 'deck', 'dight', 'drape', 'dress', 'dud'],
    'together': ['accordant', 'ad infinitum', 'again and again', 'agreeable', 'agreeing', 'akin', 'all agreeing', 'all at once', 'all there', 'all together', 'amicable', 'as one'],
    'together with': ['added to', 'along with', 'amid', 'amidst', 'among', 'amongst', 'as well as', 'attended by', 'coupled with', 'in addition to', 'in agreement with', 'in association with'],
    'toggle': ['ankle', 'articulate', 'articulation', 'batten', 'batten down', 'bolt', 'boundary', 'buckle', 'butt', 'button', 'cervix', 'clasp'],
    'togs': ['apparel', 'array', 'attire', 'bedizenment', 'clothes', 'clothing', 'costume', 'drapery', 'dress', 'dressing', 'duds', 'fashion'],
    'toil': ['bait', 'be employed', 'birdlime', 'bola', 'burden', 'carry on business', 'cobweb', 'cramp', 'cripple', 'cumber', 'dig', 'dirty work'],
    'toiler': ['blue-collar worker', 'bourgeoisie', 'breadwinner', 'casual', 'casual laborer', 'common laborer', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty'],
    'toilet': ['wc', 'backhouse', 'basement', 'bathroom', 'bedpan', 'bog', 'can', 'chamber', 'chamber pot', 'chemical closet', 'chemical toilet', 'closet'],
    'toilette': ['apparel', 'array', 'attire', 'bedizenment', 'clothes', 'clothing', 'costume', 'drapery', 'dress', 'dressing', 'duds', 'fashion'],
    'toilsome': ['herculean', 'abstruse', 'arduous', 'backbreaking', 'brutal', 'burdensome', 'complex', 'critical', 'crushing', 'delicate', 'demanding', 'difficile'],
    'token': ['account', 'adumbration', 'affect', 'agent', 'allegory', 'alternate', 'alternative', 'analogy', 'annals', 'aroma', 'attribute', 'augur'],
    'token payment': ['bail', 'bond', 'earnest', 'earnest money', 'escrow', 'gage', 'handsel', 'hock', 'hostage', 'mainprise', 'pawn', 'pignus'],
    'tokenism': ['pecksniffery', 'tartuffery', 'tartuffism', 'cant', 'empty gesture', 'false piety', 'hypocrisy', 'hypocriticalness', 'lip service', 'mealymouthedness', 'mouthing', 'mummery'],
    'tolerable': ['ok', 'acceptable', 'adequate', 'admissible', 'all right', 'allowable', 'average', 'bearable', 'better than nothing', 'betwixt and between', 'common', 'decent'],
    'tolerably': ['acceptably', 'adequately', 'admissibly', 'after a fashion', 'agreeably', 'amply', 'appreciably', 'at any rate', 'at best', 'at least', 'at most', 'at the least'],
    'tolerance': ['a habit', 'acceptance', 'acquired tolerance', 'acute alcoholism', 'addictedness', 'addiction', 'admissibility', 'admission', 'alcoholism', 'allowance', 'ample scope', 'approximation'],
    'tolerant': ['spartan', 'accepting', 'accommodating', 'accommodative', 'admissive', 'advanced', 'agreeable', 'allowing', 'armed with patience', 'attentive', 'benevolent', 'broad'],
    'tolerate': ['abide', 'abide with', 'accept', 'admit', 'allow', 'be big', 'be content with', 'be easy with', 'bear', 'bear with', 'bide', 'blink at'],
    'toll': ['admission', 'admission fee', 'allure', 'anchorage', 'assessment', 'bait', 'bell', 'bong', 'brokerage', 'carfare', 'cellarage', 'cess'],
    'tollbooth': ['nissen hut', 'pow camp', 'quonset hut', 'bastille', 'black hole', 'booth', 'borstal', 'borstal institution', 'bridewell', 'brig', 'cell', 'concentration camp'],
    'tollgate': ['french door', 'archway', 'back door', 'barway', 'bulkhead', 'carriage entrance', 'cellar door', 'cellarway', 'door', 'doorjamb', 'doorpost', 'doorway'],
    'tolling': ['change ringing', 'chime', 'chiming', 'chink', 'clang', 'clanging', 'clangor', 'clank', 'clanking', 'clink', 'death bell', 'ding'],
    'tom': ['bantam', 'cheshire cat', 'chinchilla cat', 'maltese cat', 'alley cat', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'billy', 'billy goat', 'blue cat'],
    'tom tom': ['barrage', 'beat', 'beating', 'bongo drum', 'conga', 'drum', 'drum music', 'drumbeat', 'drumfire', 'drumhead', 'drumming', 'drumskin'],
    'tomato': ['irish potato', 'jane', 'kraut', 'aubergine', 'babe', 'baby', 'bawd', 'beans', 'biddy', 'bird', 'bitch', 'broad'],
    'tomb': ['arch', 'barrow', 'beehive tomb', 'bone house', 'boundary stone', 'box', 'box grave', 'brass', 'burial', 'burial chamber', 'burial mound', 'bust'],
    'tomblike': ['cinerary', 'dirgelike', 'dismal', 'epitaphic', 'exequial', 'feral', 'funebrial', 'funebrious', 'funebrous', 'funeral', 'funerary', 'funereal'],
    'tomboy': ['amazon', 'androgyne', 'babe', 'baby', 'broad', 'butch', 'chick', 'colleen', 'cutie', 'dame', 'damoiselle', 'damsel'],
    'tombstone': ['arch', 'barrow', 'boundary stone', 'brass', 'bust', 'cairn', 'cenotaph', 'column', 'cromlech', 'cross', 'cup', 'cyclolith'],
    'tomcat': ['cheshire cat', 'chinchilla cat', 'maltese cat', 'alley cat', 'billy', 'billy goat', 'blue cat', 'boar', 'bubbly-jock', 'buck', 'bull', 'bullock'],
    'tome': ['best seller', 'book', 'bound book', 'classic', 'coloring book', 'definitive work', 'folio', 'great work', 'hardback', 'juvenile', 'juvenile book', 'limp-cover book'],
    'tomfool': ['absurd', 'ass', 'balmy', 'born fool', 'buffoon', 'clown', 'crazy', 'donkey', 'doodle', 'egregious ass', 'fantastic', 'figure of fun'],
    'tomfoolery': ['antic', 'balderdash', 'baloney', 'banter', 'blatherskite', 'buffoonery', 'caper', 'claptrap', 'clownishness', 'foolery', 'fooling', 'frolic'],
    'tommy': ['anzac', 'aussie', 'boche', 'fritz', 'gi', 'heinie', 'hun', 'jerry', 'johnny', 'kraut', 'yank', 'askari'],
    'tonal': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'tonality': ['french pitch', 'klangfarbe', 'arc lighting', 'black and white', 'chiaroscuro', 'clang color', 'classical pitch', 'color', 'coloring', 'contrast', 'decorative lighting', 'depth'],
    'tone': ['french pitch', 'munsell chroma', 'zeitgeist', 'accent', 'accidental', 'achromatism', 'action', 'actions', 'activity', 'acts', 'adaptability', 'address'],
    'tone down': ['abate', 'achromatize', 'allay', 'alleviate', 'assuage', 'atone', 'attemper', 'attune', 'baffle', 'bank the fire', 'blanch', 'bleach'],
    'tone up': ['atone', 'attune', 'brighten up', 'brush up', 'chord', 'fix', 'freshen', 'furbish', 'furbish up', 'polish', 'polish up', 'put in tune'],
    'toneless': ['achromatic', 'achromic', 'anemic', 'ashen', 'ashy', 'bled white', 'bloodless', 'cadaverous', 'chloranemic', 'colorless', 'dead', 'deadly pale'],
    'tongue': ['maypole', 'abatis', 'aftertaste', 'alveolar ridge', 'alveolus', 'apex', 'argot', 'articulation', 'arytenoid cartilages', 'back', 'bagpipe', 'bar'],
    'tongue in cheek': ['casuistic', 'casuistry', 'crossed fingers', 'dishonest', 'disingenuous', 'disingenuousness', 'emptiness', 'empty', 'hollow', 'hollow mockery', 'hollowness', 'insincere'],
    'tongue lash': ['abuse', 'bark at', 'bawl out', 'berate', 'betongue', 'blacken', 'bless', 'execrate', 'fulminate against', 'jaw', 'load with reproaches', 'rag'],
    'tongue lashing': ['abuse', 'assailing', 'assault', 'attack', 'berating', 'bitter words', 'blackening', 'contumely', 'diatribe', 'execration', 'hard words', 'invective'],
    'tongue tied': ['anaudic', 'aphasic', 'aphonic', 'breathless', 'brief', 'brusque', 'close', 'close-tongued', 'closemouthed', 'concise', 'curt', 'dumb'],
    'tonic': ['accented', 'activating', 'activator', 'alcoholic drink', 'alveolar', 'analeptic', 'animating', 'animative', 'animator', 'apical', 'apico-alveolar', 'apico-dental'],
    'tonight': ['as of now', 'as things are', 'at present', 'at this juncture', 'at this moment', 'at this point', 'at this time', 'but now', 'even now', 'for the nonce', 'for this occasion', 'here'],
    'tonnage': ['accommodation', 'argosy', 'avoirdupois', 'beef', 'beefiness', 'bottoms', 'burden', 'capacity', 'carriage', 'cartage', 'content', 'cordage'],
    'tons': ['abundance', 'acres', 'bags', 'barrels', 'bushel', 'copiousness', 'countlessness', 'flood', 'load', 'mass', 'mountain', 'much'],
    'tonsilitis': ['asiatic flu', 'hong kong flu', 'acute bronchitis', 'adenoiditis', 'adrenitis', 'aluminosis', 'amygdalitis', 'anthracosilicosis', 'anthracosis', 'appendicitis', 'arteritis', 'arthritis deformans'],
    'tonsillectomy': ['adenoidectomy', 'appendectomy', 'arteriectomy', 'castration', 'cholecystectomy', 'craniectomy', 'cricoidectomy', 'cystectomy', 'enterectomy', 'gastrectomy', 'hemorrhoidectomy', 'hysterectomy'],
    'tonus': ['adaptability', 'bounce', 'bounciness', 'buoyance', 'buoyancy', 'elasticity', 'extensibility', 'flexibility', 'give', 'liveliness', 'rebound', 'resilience'],
    'tony': ['a la mode', 'ambitious', 'chic', 'classy', 'exclusive', 'fancy', 'fashionable', 'flossy', 'high-flown', 'high-flying', 'high-toned', 'highfalutin'],
    'too': ['above', 'additionally', 'again', 'all included', 'along', 'also', 'altogether', 'among other things', 'and all', 'and also', 'and so', 'as well'],
    'too bad': ['abominable', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beneath contempt', 'beneath one', 'blameworthy', 'brutal', 'cheap', 'contemptible'],
    'too much': ['a bit much', 'abandon', 'abandoned', 'at the height', 'at the limit', 'bibulous', 'boundless', 'boundlessness', 'crapulence', 'crapulency', 'crapulent', 'crapulous'],
    'too soon': ['a bit previous', 'advanced', 'far ahead', 'forward', 'half-baked', 'half-cocked', 'hasty', 'ill-considered', 'ill-seasoned', 'ill-timed', 'improper', 'impulsive'],
    'tool': ['charlie mccarthy', 'federal', 't square', 'adz', 'agency', 'agent', 'aid', 'amanuensis', 'ancilla', 'apparatus', 'apple-polisher', 'appliance'],
    'tooled': ['carved', 'creased', 'cut', 'enchased', 'engraved', 'furrowed', 'glyphic', 'graved', 'graven', 'grooved', 'impressed', 'imprinted'],
    'tooling': ['burr', 'chiseling', 'cross-hatching', 'demitint', 'engravement', 'engraving', 'etch', 'etching', 'gem-engraving', 'glass-cutting', 'glyptic', 'graving'],
    'toot': ['advertise', 'announce', 'annunciate', 'bacchanal', 'bacchanalia', 'bacchanalian', 'bagpipe', 'bat', 'bay', 'beep', 'bell', 'bender'],
    'tooth': ['vandyke', 'aftertaste', 'asperity', 'baby tooth', 'bicuspid', 'bitter', 'blaze', 'bucktooth', 'bumpiness', 'canine', 'chop', 'choppiness'],
    'tooth and nail': ['arduously', 'atrociously', 'barbarously', 'bec et ongles', 'bestially', 'brutally', 'brutishly', 'committedly', 'decidedly', 'decisively', 'determinedly', 'devotedly'],
    'toothache': ['ache', 'aching', 'angina', 'backache', 'bellyache', 'cephalalgia', 'colic', 'collywobbles', 'earache', 'fret', 'gnawing', 'gripe'],
    'toothed': ['acanthoid', 'acanthous', 'acicular', 'acuate', 'aculeate', 'aculeiform', 'acuminate', 'acute', 'barbed', 'battlemented', 'bicuspid', 'chopped'],
    'toothpaste': ['abstergent', 'cathartic', 'cleaner', 'cleaning agent', 'cleaning solvent', 'cleanser', 'cleansing cream', 'cold cream', 'cream', 'dentifrice', 'depurant', 'detergent'],
    'toothsome': ['acceptable', 'adorable', 'agreeable', 'ambrosial', 'appetizing', 'attractive', 'dainty', 'delectable', 'delicate', 'delicious', 'delightful', 'desirable'],
    'tootle': ['bagpipe', 'bay', 'beep', 'bell', 'blare', 'blast', 'blat', 'blow', 'blow a horn', 'blow the horn', 'bray', 'bugle'],
    'tootsy': ['arch', 'clubfoot', 'digit', 'dog', 'extremity', 'fetlock', 'foot', 'forefoot', 'forepaw', 'harefoot', 'heel', 'hoof'],
    'top': ['establishment', 'vip', 'acmatic', 'acme', 'acme of perfection', 'agate', 'all', 'apex', 'apical', 'apogee', 'ball', 'baron'],
    'top brass': ['adc', 'co', 'establishment', 'od', 'vip', 'aide', 'aide-de-camp', 'baron', 'big gun', 'big man', 'big name', 'bigwig'],
    'top dog': ['a per se', 'ace', 'boss', 'champ', 'champion', 'chief', 'commander', 'conquering hero', 'conqueror', 'conquistador', 'dean', 'defeater'],
    'top heavy': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'canted', 'chubby', 'chunky'],
    'top notch': ['best', 'capital', 'fine', 'first-chop', 'first-class', 'first-rate', 'first-string', 'greatest', 'highest', 'maximal', 'maximum', 'most'],
    'top off': ['accomplish', 'brim', 'bring to completion', 'bring to fruition', 'bunker', 'button up', 'cap', 'carry to completion', 'cater', 'charge', 'chock', 'clean up'],
    'top priority': ['antecedence', 'antecedency', 'anteposition', 'anteriority', 'dominion', 'front position', 'precedence', 'precedency', 'preceding', 'precession', 'precursor', 'preference'],
    'top secret': ['arcane', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'cryptic', 'dark', 'enigmatic', 'esoteric', 'hermetic'],
    'top sergeant': ['nco', 'acting corporal', 'acting sergeant', 'centurion', 'chief warrant officer', 'color sergeant', 'corporal', 'first sergeant', 'havildar', 'lance corporal', 'lance sergeant', 'master sergeant'],
    'top shape': ['eupepsia', 'fine fettle', 'fine shape', 'fine whack', 'glowing health', 'good condition', 'good constitution', 'good digestion', 'good health', 'good shape', 'good trim', 'healthfulness'],
    'tope': ['antenna tower', 'arch', 'barbican', 'barrow', 'beehive tomb', 'belfry', 'bell tower', 'bib', 'bocage', 'bone house', 'booze', 'bosk'],
    'topflight': ['arch', 'banner', 'capital', 'cardinal', 'central', 'champion', 'chief', 'crowning', 'dominant', 'first', 'first-chop', 'first-class'],
    'topic': ['action', 'anagnorisis', 'angle', 'architectonics', 'architecture', 'argument', 'atmosphere', 'background', 'bone of contention', 'catastrophe', 'catechism', 'characterization'],
    'topical': ['actual', 'as is', 'being', 'confined', 'contemporaneous', 'contemporary', 'current', 'existent', 'existing', 'extant', 'fresh', 'geographically limited'],
    'topknot': ['braid', 'bun', 'cap', 'capsheaf', 'caput', 'chignon', 'coil', 'crest', 'crown', 'cue', 'feather', 'hackle'],
    'topless': ['olympian', 'aerial', 'airy', 'altitudinous', 'ascending', 'aspiring', 'bare-ankled', 'bare-armed', 'bare-backed', 'bare-breasted', 'bare-chested', 'bare-handed'],
    'toplofty': ['olympian', 'aerial', 'airy', 'altitudinous', 'arrogant', 'ascending', 'aspiring', 'big', 'cavalier', 'clannish', 'cliquish', 'colossal'],
    'topmost': ['acmatic', 'all-absorbing', 'apical', 'best', 'capital', 'cardinal', 'chief', 'consummate', 'controlling', 'dominant', 'first-class', 'first-rate'],
    'topographer': ['lambert conformal projection', 'mercator projection', 'miller projection', 'aeronautical chart', 'appraiser', 'assayer', 'assessor', 'astronomical chart', 'atlas', 'azimuthal projection', 'cartographer', 'cartography'],
    'topographic': ['approximative', 'areal', 'cartographic', 'chorographic', 'estimative', 'geodetic', 'geographic', 'geographical', 'hypsographic', 'locational', 'measuring', 'mensural'],
    'topography': ['lambert conformal projection', 'mercator projection', 'miller projection', 'aeronautical chart', 'altimetry', 'astronomical chart', 'atlas', 'azimuthal projection', 'bathymetry', 'biometrics', 'biometry', 'cadastration'],
    'topping': ['olympian', 'a cut above', 'abacus', 'above', 'acanthus', 'aerial', 'ahead', 'airy', 'altitudinous', 'annulet', 'architrave', 'ascendant'],
    'topping off': ['accomplishment', 'close', 'closure', 'completing', 'completion', 'conclusion', 'consummation', 'culmination', 'end', 'ending', 'finish', 'finishing'],
    'topple': ['ataxia', 'bite the dust', 'blow down', 'blow over', 'bowl down', 'bowl over', 'break down', 'break up', 'bring down', 'bulldog', 'capsize', 'careen'],
    'tops': ['champion', 'choice', 'chosen', 'cream', 'elect', 'elite', 'fat', 'first-chop', 'first-class', 'first-rate', 'flower', 'nonesuch'],
    'topside': ['aboard', 'afloat', 'all aboard', 'aloft', 'at the head', 'at the top', 'athwart the hawse', 'athwarthawse', 'before the mast', 'clerestory', 'in sail', 'on board'],
    'topsoil': ['acres', 'alluvion', 'alluvium', 'arable land', 'band', 'bed', 'bedding', 'belt', 'clay', 'clod', 'couche', 'course'],
    'topsy turvy': ['a rebours', 'against the grain', 'anarchic', 'arsy-varsy', 'ass over elbows', 'ass-backwards', 'back-to-front', 'backwards', 'balled up', 'bollixed up', 'bottom side up', 'bottom up'],
    'topsy-turvy': ['backwards', 'chaotic', 'confused', 'disordered', 'disorderly', 'disorganized', 'every which way', 'head over heels', 'higgledy-piggledy', 'in a muddle', 'inverted', 'jumbled'],
    'tor': ['everest', 'olympus', 'alp', 'crest', 'hilltop', 'hump', 'knoll', 'lofty mountains', 'lofty peak', 'mount', 'mountain', 'mountaintop'],
    'torah': ['apocrypha', 'chumash', 'hagiographa', 'hexateuch', 'major prophets', 'nebiim', 'octateuch', 'old testament', 'pentateuch', 'sefer torah', 'tenach', 'torah scroll'],
    'torch': ['acetylene welder', 'angle', 'arsonist', 'bait the hook', 'bank', 'blast lamp', 'blowpipe', 'blowtorch', 'bob', 'brand', 'burn', 'burner'],
    'torch singer': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso profundo', 'blues singer'],
    'torch song': ['brautlied', 'christmas carol', 'kunstlied', 'liebeslied', 'volkslied', 'alba', 'anthem', 'art song', 'aubade', 'ballad', 'ballade', 'ballata'],
    'torchbearer': ['mahdi', 'bell cow', 'bell mare', 'bellwether', 'born leader', 'charismatic leader', 'choirmaster', 'choragus', 'conductor', 'coryphaeus', 'duce', 'file leader'],
    'torment': ['abuse', 'afflict', 'affliction', 'aggravate', 'aggrieve', 'agonize', 'agonizingness', 'agony', 'ail', 'anguish', 'annoy', 'annoyance'],
    'tormented': ['afflicted', 'agonized', 'badgered', 'baited', 'bedeviled', 'beset', 'bugged', 'bullyragged', 'chivied', 'convulsed', 'crucified', 'deviled'],
    'tormenting': ['acute', 'afflictive', 'aggravating', 'agonizing', 'annoying', 'atrocious', 'biting', 'bothering', 'bothersome', 'chafing', 'consuming', 'cramping'],
    'tormentor': ['act drop', 'annoyer', 'asbestos', 'asbestos board', 'backdrop', 'badgerer', 'batten', 'border', 'bully', 'cloth', 'coulisse', 'counterweight'],
    'torn': ['affected', 'aggravated', 'agonized', 'alienated', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped', 'cleft', 'cloven'],
    'tornado': ['baguio', 'blaze', 'burst', 'convulsion', 'cyclone', 'dirty weather', 'dust devil', 'eruption', 'explosion', 'fit', 'flare-up', 'foul weather'],
    'torpedo': ['cain', 'irish confetti', 'ko', 'aerial torpedo', 'aim at', 'apache', 'assassin', 'assassinator', 'atomic warhead', 'bangalore torpedo', 'barrage', 'bird'],
    'torpid': ['laodicean', 'olympian', 'abeyant', 'abiding', 'aloof', 'apathetic', 'benumbed', 'blah', 'blase', 'bored', 'cataleptic', 'catatonic'],
    'torpor': ['abeyance', 'abidingness', 'acedia', 'aloofness', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'boredom', 'catalepsy'],
    'torque': ['anklet', 'armlet', 'bangle', 'beads', 'bijou', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet', 'charm', 'chatelaine'],
    'torrent': ['niagara', 'antelope', 'arrow', 'belch', 'blue darter', 'blue streak', 'burst', 'cannonball', 'cascade', 'cataclysm', 'cataract', 'courser'],
    'torrid': ['amorous', 'ardent', 'arid', 'baking', 'blazing', 'blistering', 'blistery', 'boiling', 'broiling', 'burning', 'burning hot', 'canicular'],
    'torrid zone': ['antarctic zone', 'arctic circle', 'arctic zone', 'frigid zones', 'tropic of cancer', 'tropic of capricorn', 'variable zones', 'climate', 'clime', 'equator', 'furnace', 'hell'],
    'torsion': ['ambages', 'anamorphism', 'anamorphosis', 'anfractuosity', 'asymmetry', 'buckle', 'circuitousness', 'circumambages', 'circumbendibus', 'circumlocution', 'circumvolution', 'contortion'],
    'torsional': ['ambagious', 'anfractuous', 'circuitous', 'circumlocutory', 'contortional', 'contortive', 'convolutional', 'distortive', 'flexuose', 'flexuous', 'involute', 'involuted'],
    'torso': ['anatomy', 'body', 'bones', 'carcass', 'clay', 'clod', 'corpus', 'figure', 'flesh', 'form', 'frame', 'hulk'],
    'tort': ['atrocity', 'breach', 'crime', 'crime against humanity', 'deadly sin', 'delict', 'delinquency', 'dereliction', 'diablerie', 'enormity', 'error', 'evil'],
    'tortoise': ['alligator', 'crocodile', 'crocodilian', 'dawdle', 'dawdler', 'dinosaur', 'drone', 'foot-dragger', 'gator', 'goldbrick', 'goof-off', 'laggard'],
    'tortoise shell': ['dalmatian', 'antigorite', 'burele', 'butterfly', 'candy cane', 'chameleon', 'chatoyant', 'cheetah', 'chrysotile', 'confetti', 'crazy quilt', 'firedog'],
    'tortuous': ['gongoresque', 'johnsonian', 'affected', 'ambagious', 'ambiguous', 'anamorphous', 'anfractuous', 'askew', 'asymmetric', 'bedizened', 'bent', 'big-sounding'],
    'torture': ['procrustean bed', 'abuse', 'afflict', 'aggrieve', 'agonize', 'agonizingness', 'agony', 'ail', 'anguish', 'atrocious pain', 'bed of procrustes', 'befoul'],
    'tortured': ['affected', 'afflicted', 'agonized', 'biased', 'clawed', 'convulsed', 'cooked', 'crucified', 'devoured by', 'distressed', 'doctored', 'garbled'],
    'torturing': ['abuse of terms', 'agonizing', 'catachresis', 'contorting', 'corruption', 'distortion', 'eisegesis', 'error', 'false coloring', 'garbling', 'gloss', 'harrowing'],
    'torturous': ['acute', 'afflictive', 'agonizing', 'atrocious', 'biting', 'consuming', 'cramping', 'cruel', 'desolating', 'distressing', 'excruciating', 'gnawing'],
    'tory': ['bircher', 'bourbon', 'conservative', 'democrat', 'labourite', 'republican', 'whig', 'conservatist', 'conservative', 'diehard', 'extreme right-winger', 'hard hat'],
    'toss': ['agitate', 'agonize', 'be poised', 'billow', 'blind bargain', 'blunder', 'bob', 'bobble', 'bowl', 'break', 'bung', 'call'],
    'toss and turn': ['be vigilant', 'blunder', 'careen', 'career', 'count sheep', 'falter', 'fidget', 'flip out', 'flounce', 'flounder', 'flutter', 'freak out on'],
    'toss off': ['ad-lib', 'bat out', 'bib', 'booze', 'botch', 'bungle', 'cook up', 'dash off', 'do anyhow', 'do by halves', 'do carelessly', 'do offhand'],
    'toss out': ['ad-lib', 'bat out', 'boot out', 'botch', 'bounce', 'bungle', 'cast', 'cast out', 'chuck out', 'cook up', 'dash off', 'defenestrate'],
    'toss up': ['blind bargain', 'borderline case', 'chance', 'chance at odds', 'contingency', 'double contingency', 'even break', 'even chance', 'fair shake', 'fifty-fifty', 'gamble', 'gambling chance'],
    'tot': ['add', 'bairn', 'beverage', 'bumper', 'cast', 'cherub', 'child', 'chit', 'darling', 'draft', 'dram', 'drench'],
    'total': ['absolute', 'account', 'accumulative', 'across-the-board', 'add', 'add up', 'add up to', 'addend', 'admitting no exception', 'aggregate', 'aggregate to', 'all'],
    'total loss': ['bereavement', 'bomb', 'breakdown', 'breaking up', 'breakup', 'bust', 'cataclysm', 'catastrophe', 'cave', 'cave-in', 'collapse', 'cost'],
    'totalitarian': ['absolute', 'absolutist', 'arbitrary', 'aristocratic', 'ascendant', 'authoritarian', 'authoritative', 'authorized', 'autocratic', 'autonomous', 'bureaucratic', 'civic'],
    'totality': ['copernican universe', 'einsteinian universe', 'newtonian universe', 'ptolemaic universe', 'aggregate', 'all', 'all being', 'all creation', 'all hands', 'all the world', 'allness', 'alpha and omega'],
    'totally': ['a outrance', 'absolutely', 'across the board', 'all', 'all in all', 'all out', 'all put together', 'altogether', 'as a body', 'as a whole', 'at large', 'beyond all bounds'],
    'tote': ['add', 'add up', 'aggregate', 'all', 'be-all and end-all', 'bear', 'buck', 'carry', 'cart', 'cast', 'compute', 'conduct'],
    'tote up': ['add up', 'add up to', 'aggregate', 'aggregate to', 'amount to', 'cast up', 'cipher up', 'come to', 'comprise', 'compute', 'contain', 'count up'],
    'totem': ['allegory', 'ancestral spirits', 'angel', 'animal kingdom', 'ashram', 'attendant godling', 'blood', 'body', 'breed', 'brood', 'caste', 'charactery'],
    'totter': ['age', 'alternate', 'amble', 'back and fill', 'barge', 'blunder', 'bowl along', 'break down', 'bundle', 'capsize', 'careen', 'career'],
    'tottering': ['lissajous figure', 'alternation', 'ambling', 'ambulation', 'anile', 'back-and-forth', 'backpacking', 'cautious', 'circumspect', 'claudicant', 'collapsing', 'coming and going'],
    'tottery': ['anile', 'battered', 'beat-up', 'beaten up', 'broken-down', 'crabbed', 'debilitated', 'decrepit', 'derelict', 'dilapidated', 'doddered', 'doddering'],
    'touch': ['esp', 'roman candle', 'ability', 'abut', 'access', 'adjoin', 'adroitness', 'affect', 'aid to navigation', 'alarm', 'alight', 'allegory'],
    'touch and go': ['blind bargain', 'borderline case', 'chance', 'chance at odds', 'contingency', 'double contingency', 'even break', 'even chance', 'fair shake', 'fifty-fifty', 'gamble', 'gambling chance'],
    'touch bottom': ['become suicidal', 'come down', 'decline', 'degenerate', 'despair', 'despond', 'deteriorate', 'die', 'droop', 'ebb', 'fade', 'fail'],
    'touch off': ['backfire', 'bank', 'blast', 'blow out', 'blow up', 'burn', 'burst', 'bust', 'conflagrate', 'detonate', 'discharge', 'enkindle'],
    'touch up': ['brighten up', 'brush up', 'do up', 'fix', 'fix up', 'freshen', 'furbish', 'furbish up', 'improve', 'perfect', 'polish', 'polish up'],
    'touch upon': ['address to', 'affect', 'allude to', 'answer to', 'appertain to', 'apply to', 'bear on', 'bear upon', 'belong to', 'blink', 'bring to attention', 'bring to notice'],
    'touched': ['abject', 'abnormal', 'affected', 'agonized', 'apologetic', 'bereft of reason', 'brainsick', 'contrite', 'crackbrained', 'cracked', 'crazed', 'crazy'],
    'touching': ['about', 'abutting', 'adjoining', 'affecting', 'afflictive', 'against', 'anent', 'apropos of', 'as for', 'as regards', 'as respects', 'as to'],
    'touchstone': ['acid test', 'assay', 'barometer', 'benchmark', 'blank determination', 'brouillon', 'canon', 'check', 'criterion', 'crucial test', 'crucible', 'degree'],
    'touchy': ['agitable', 'allergic', 'anaphylactic', 'argumentative', 'bad-tempered', 'bearish', 'cantankerous', 'captious', 'chancy', 'choleric', 'close', 'contentious'],
    'tough': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'goliath', 'herculean', 'hercules', 'mafioso', 'ok', 'polyphemus'],
    'tough guy': ['antaeus', 'atlas', 'briareus', 'brobdingnagian', 'charles atlas', 'cyclops', 'goliath', 'hercules', 'mafioso', 'polyphemus', 'samson', 'superman'],
    'tough it out': ['bear up', 'come up fighting', 'hang in', 'hang in there', 'hang on', 'hang tough', 'hold fast', 'hold on', 'hold out', 'hold up', 'live through it', 'live with it'],
    'tough proposition': ['augean task', 'chinese puzzle', 'herculean task', 'backbreaker', 'baffling problem', 'ballbuster', 'bitch', 'brain twister', 'chore', 'crossword puzzle', 'crux', 'dead lift'],
    'toughen': ['acclimate', 'acclimatize', 'anneal', 'be tough', 'beef up', 'brace', 'brace up', 'buttress', 'calcify', 'callous', 'case harden', 'confirm'],
    'toughened': ['annealed', 'backed', 'calcified', 'callous', 'calloused', 'case-hardened', 'crusted', 'crusty', 'crystallized', 'fossilized', 'granulated', 'hardened'],
    'toughness': ['spartanism', 'abstruseness', 'adamantness', 'adhesiveness', 'arduousness', 'astringency', 'austerity', 'authoritarianism', 'backbone', 'body', 'bothersomeness', 'bottom'],
    'tour': ['air lane', 'ambit', 'anchor watch', 'antenna tower', 'assignment', 'barbican', 'beat', 'belfry', 'bell tower', 'bit', 'booking', 'borscht circuit'],
    'tour de force': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adventure', 'blow', 'classic', 'coup', 'dealings', 'deed'],
    'tour of duty': ['anchor watch', 'bit', 'day shift', 'dogwatch', 'full time', 'graveyard shift', 'half time', 'lobster trick', 'night shift', 'overtime', 'part time', 'relay'],
    'touring': ['ambulant', 'ambulative', 'ambulatory', 'circuit-riding', 'expeditionary', 'globe-girdling', 'globe-trotting', 'going', 'itinerant', 'itinerary', 'journeying', 'locomotive'],
    'tourism': ['commutation', 'course', 'crossing', 'globe-trotting', 'going', 'journeying', 'locomotion', 'motion', 'movement', 'moving', 'passage', 'progress'],
    'tourist': ['adventurer', 'alpinist', 'astronaut', 'camper', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser', 'excursionist', 'explorer', 'fare'],
    'touristy': ['ambulant', 'ambulative', 'ambulatory', 'circuit-riding', 'expeditionary', 'globe-girdling', 'globe-trotting', 'going', 'itinerant', 'itinerary', 'journeying', 'locomotive'],
    'tournament': ['highland games', 'olympiad', 'olympic games', 'olympics', 'bout', 'carousel', 'competition', 'concours', 'contest', 'derby', 'encounter', 'engagement'],
    'tourney': ['highland games', 'olympiad', 'olympic games', 'olympics', 'battle', 'bout', 'box', 'brawl', 'broil', 'carousel', 'clash', 'close'],
    'tourniquet': ['ace bandage', 'band-aid', 'adhesive tape', 'application', 'band', 'bandage', 'bandaging', 'binder', 'brace', 'cast', 'cataplasm', 'compress'],
    'tout': ['acclaim', 'adherent', 'adventurer', 'adviser', 'advocate', 'aggrandize', 'amplify', 'announcer', 'annunciator', 'applauder', 'appreciator', 'authority'],
    'touted': ['aggrandized', 'amplified', 'ballyhooed', 'disproportionate', 'exaggerated', 'excessive', 'exorbitant', 'extravagant', 'extreme', 'grandiloquent', 'high-flown', 'hyperbolic'],
    'towage': ['admission', 'admission fee', 'anchorage', 'attraction', 'brokerage', 'carfare', 'cellarage', 'charge', 'charges', 'cover charge', 'demand', 'dockage'],
    'toward': ['about', 'across', 'advantageous', 'against', 'anent', 'as', 'beneficial', 'brave', 'confronting', 'en route to', 'facing', 'favorable'],
    'towel': ['air-dry', 'anhydrate', 'bake', 'blot', 'brush', 'burn', 'cure', 'dehumidify', 'dehydrate', 'desiccate', 'drain', 'dry'],
    'tower': ['texas tower', 'acropolis', 'antenna tower', 'architecture', 'arise', 'ascend', 'barbican', 'bastion', 'beachhead', 'beacon', 'bedrock', 'belfry'],
    'tower above': ['best', 'bestraddle', 'bestride', 'better', 'bulk', 'bulk large', 'cap', 'clear', 'command', 'dominate', 'exceed', 'excel'],
    'towering': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'olympian', 'abysmal', 'aerial', 'airy', 'altitudinous', 'ascending'],
    'town': ['kreis', 'archbishopric', 'archdiocese', 'arrondissement', 'bailiwick', 'bishopric', 'borough', 'burgh', 'burghal', 'canton', 'citified', 'city'],
    'town hall': ['city hall', 'community center', 'county building', 'county courthouse', 'court', 'courthouse', 'courtroom', 'dock', 'fire station', 'firehouse', 'jury box', 'municipal building'],
    'town meeting': ['airing', 'analysis', 'assembly', 'bicameral legislature', 'board of aldermen', 'buzz session', 'canvassing', 'chamber of deputies', 'city board', 'city council', 'collective farm', 'collectivism'],
    'townee': ['big-city man', 'bourgeois', 'burgess', 'burgher', 'city dweller', 'city man', 'city slicker', 'exurbanite', 'oppidan', 'suburbanite', 'towner', 'townfolk'],
    'township': ['kreis', 'stadt', 'archbishopric', 'archdiocese', 'arrondissement', 'bailiwick', 'banlieue', 'bishopric', 'boom town', 'borough', 'bourg', 'burg'],
    'townspeople': ['big-city man', 'bourgeois', 'burgess', 'burgher', 'city dweller', 'city man', 'city slicker', 'exurbanite', 'oppidan', 'suburbanite', 'townee', 'towner'],
    'towpath': ['alameda', 'beaten path', 'beaten track', 'berm', 'bicycle path', 'boardwalk', 'bridle path', 'catwalk', 'esplanade', 'fastwalk', 'foot pavement', 'footpath'],
    'toxic': ['baleful', 'baneful', 'catching', 'communicable', 'contagious', 'corroding', 'corrosive', 'corrupting', 'corruptive', 'counterproductive', 'damaging', 'deadly'],
    'toxicity': ['balefulness', 'banefulness', 'communicability', 'contagiousness', 'deadliness', 'destructiveness', 'detrimentalness', 'harmfulness', 'hurtfulness', 'infectiousness', 'infectivity', 'injuriousness'],
    'toxicology': ['acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bug bomb', 'carbamate insecticide', 'chemosterilant', 'contact poison', 'defoliant', 'disinfectant', 'eradicant', 'fumigant'],
    'toxin': ['abomination', 'acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'atrocity', 'bad', 'bane', 'befoulment', 'blight', 'bug bomb', 'carbamate insecticide'],
    'toy': ['charlie mccarthy', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'agate', 'agent', 'ancilla', 'appliance', 'babe', 'baby'],
    'toy with': ['be abstracted', 'be innocent of', 'brood', 'chew the cud', 'consider', 'contemplate', 'coquet', 'coquet with', 'dabble', 'dally', 'debate', 'deliberate'],
    'trace': ['crt spot', 'dm display', 'doppler signal', 'if signal', 'im display', 'photostat', 'rf echoes', 'xerox', 'account', 'afterglow', 'afterimage', 'annals'],
    'traceable': ['accountable', 'alleged', 'ascribable', 'assignable', 'attributable', 'attributed', 'charged', 'credited', 'derivable from', 'derivational', 'derivative', 'due'],
    'tracer': ['alpha radiator', 'atom', 'atomic cocktail', 'atomic model', 'ball', 'bar shot', 'beta radiator', 'bird shot', 'buckshot', 'bullet', 'cannon shot', 'cannonball'],
    'tracery': ['arabesque', 'arc', 'basketry', 'basketwork', 'bow', 'cancellation', 'catacaustic', 'catenary', 'caustic', 'circle', 'conchoid', 'crook'],
    'trachoma': ['ablepsia', 'amaurosis', 'benightedness', 'blepharitis', 'blind side', 'blind spot', 'blindfolding', 'blinding', 'blindness', 'blurring the eyes', 'cataract', 'cecity'],
    'tracing': ['apograph', 'black and white', 'brouillon', 'carbon', 'carbon copy', 'cartoon', 'charcoal', 'charcoal drawing', 'chiaroscuro', 'companion', 'copy', 'crayon'],
    'track': ['rugby', 'a reckoning of', 'account of', 'acrobatics', 'afterclap', 'aftercrop', 'aftereffect', 'afterglow', 'aftergrowth', 'afterimage', 'aftermath', 'aftertaste'],
    'track down': ['determine', 'discover', 'find', 'find out', 'follow', 'follow a clue', 'follow up', 'get', 'hit', 'hunt down', 'invent', 'locate'],
    'tracking': ['automatic tracking', 'chase', 'data transmission', 'dogging', 'flector tuning', 'follow', 'follow-up', 'following', 'hue and cry', 'hunting', 'locking on', 'locking signals'],
    'tracking station': ['cic', 'combat information center', 'advance base', 'beacon station', 'bunker', 'control center', 'control station', 'direction-finder station', 'display station', 'fixed station', 'home station', 'impact area'],
    'tract': ['acreage', 'amplitude', 'area', 'article', 'assembly-line housing', 'belt', 'billeting', 'block', 'booklet', 'breadth', 'brochure', 'causerie'],
    'tractability': ['acquiescence', 'adaptability', 'agreeability', 'agreeableness', 'alacrity', 'amenability', 'ardor', 'bendability', 'biddability', 'cheerful consent', 'compliableness', 'compliance'],
    'tractable': ['acquiescent', 'adaptable', 'adaptive', 'adjustable', 'agreeable', 'alacritous', 'amenable', 'ardent', 'bendable', 'bending', 'biddable', 'complaisant'],
    'traction': ['adduction', 'adhesion', 'advantage', 'affinity', 'allurement', 'attractance', 'attraction', 'attractiveness', 'attractivity', 'capillarity', 'capillary attraction', 'centripetal force'],
    'tractor': ['cat', 'caterpillar', 'dukw', 'rome plow', 'amphibian', 'bulldozer', 'calfdozer', 'crawler', 'creeper', 'double-prop', 'duck', 'go-devil'],
    'trade': ['abalienate', 'agency', 'alien', 'alienate', 'alternate', 'amortize', 'argue', 'art', 'assign', 'backscratching', 'balance of trade', 'bandy'],
    'trade book': ['back number', 'best seller', 'book', 'bound book', 'classic', 'collection', 'coloring book', 'copy', 'definitive work', 'edition', 'folio', 'great work'],
    'trade in': ['bargain', 'barter', 'be in', 'blind bargain', 'buy and sell', 'carry', 'change', 'deal', 'deal in', 'dicker', 'do business', 'exchange'],
    'trade route': ['air lane', 'beat', 'circuit', 'course', 'flight path', 'itinerary', 'line', 'orbit', 'path', 'primrose path', 'road', 'round'],
    'trademark': ['acknowledgment', 'billhead', 'book stamp', 'bookplate', 'brand', 'broad arrow', 'by-line', 'cachet', 'certificate of invention', 'check', 'citation', 'colophon'],
    'trader': ['broker', 'businessman', 'buyer', 'chandler', 'dealer', 'distributor', 'importer', 'jobber', 'marketer', 'merchandiser', 'merchant', 'middleman'],
    'trading': ['abalienation', 'agency', 'alienation', 'amortization', 'amortizement', 'assignation', 'assignment', 'backscratching', 'bargain and sale', 'barter', 'bartering', 'bequeathal'],
    'trading post': ['boutique', 'chain store', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dime store', 'discount house', 'discount store', 'emporium'],
    'tradition': ['mishnah', 'spiritus mundi', 'sunna', 'talmud', 'ancient wisdom', 'archetypal myth', 'archetypal pattern', 'belief', 'birthright', 'bon ton', 'charm', 'common law'],
    'traditional': ['christian', 'accepted', 'accustomed', 'acknowledged', 'admitted', 'ancestral', 'approved', 'authentic', 'authoritative', 'autobiographical', 'being done', 'biographical'],
    'traditionalism': ['mishnah', 'spiritus mundi', 'sunna', 'talmud', 'accommodation', 'accord', 'accordance', 'acquiescence', 'adaptation', 'adaption', 'adjustment', 'agreement'],
    'traditionalist': ['methuselah', 'antediluvian', 'antique', 'back number', 'conservative', 'dad', 'dodo', 'elder', 'fogy', 'fossil', 'fud', 'fuddy-duddy'],
    'traditionally': ['according to use', 'anally', 'as is proper', 'comme il faut', 'complaisantly', 'compliantly', 'compulsively', 'conformably', 'conformingly', 'conventionally', 'correctly', 'customarily'],
    'traffic': ['esp', 'answer', 'balance of trade', 'bargain', 'barter', 'be in', 'big business', 'black-market', 'bootleg', 'business', 'business dealings', 'buy and sell'],
    'traffic light': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'beacon', 'beacon fire', 'bell', 'bell buoy', 'blinker', 'blue peter', 'buoy'],
    'traffic with': ['be in connection', 'be in contact', 'commerce with', 'commune with', 'communicate', 'converse', 'deal with', 'do business with', 'have dealings with', 'have intercourse', 'have truck with', 'hold communication'],
    'trafficking': ['agency', 'barter', 'bartering', 'brokerage', 'buying and selling', 'dealing', 'doing business', 'exchange', 'give-and-take', 'horse trading', 'interchange', 'jobbing'],
    'tragedian': ['choreographer', 'comedian', 'dramatist', 'dramatizer', 'dramaturge', 'farcer', 'farceur', 'farceuse', 'farcist', 'gagman', 'joke writer', 'jokesmith'],
    'tragedy': ['aeschylean tragedy', 'euripidean tragedy', 'greek tragedy', 'melpomene', 'renaissance tragedy', 'senecan tragedy', 'sophoclean tragedy', 'accident', 'adversity', 'blow', 'buskin', 'calamity'],
    'tragic': ['appalling', 'atrocious', 'awful', 'baneful', 'beastly', 'black', 'buskined', 'calamitous', 'cataclysmal', 'cataclysmic', 'catastrophic', 'cheerless'],
    'tragicomedy': ['thalia', 'arlequinade', 'black comedy', 'broad comedy', 'burlesque', 'burletta', 'camp', 'comedie bouffe', 'comedie larmoyante', 'comedie rosse', 'comedietta', 'comedy'],
    'trail': ['afterclap', 'aftercrop', 'aftereffect', 'afterglow', 'aftergrowth', 'afterimage', 'aftermath', 'afterpart', 'afterpiece', 'aftertaste', 'alameda', 'aroma'],
    'trailblazer': ['adventurer', 'alpinist', 'ancestor', 'announcer', 'antecedent', 'astronaut', 'avant-garde', 'bellwether', 'buccinator', 'bushwhacker', 'camper', 'climber'],
    'trailer': ['cinemascope', 'cinerama', 'technicolor', 'western', 'afterpart', 'afterpiece', 'animated cartoon', 'black-and-white film', 'camp trailer', 'camper', 'caravan', 'cartoon'],
    'trailing': ['bugging', 'chase', 'chasing', 'cloak-and-dagger work', 'consecutive', 'counterespionage', 'counterintelligence', 'dogging', 'electronic surveillance', 'espial', 'espionage', 'follow'],
    'train': ['amtrak', 'indian file', 'kp', 'acclimate', 'acclimatize', 'accommodate', 'accustom', 'adapt', 'adjust', 'afterpart', 'afterpiece', 'aim'],
    'trainable': ['aimable', 'aimed', 'apt', 'bright', 'clever', 'directed', 'directional', 'directive', 'dirigible', 'docile', 'educable', 'facile'],
    'trained': ['abreast of', 'acclimated', 'acclimatized', 'accommodated', 'accomplished', 'accustomed', 'adapted', 'adjusted', 'at concert pitch', 'au courant', 'briefed', 'career'],
    'trainee': ['apprentice', 'auditor', 'autodidact', 'baby', 'beginner', 'boot', 'catechumen', 'conscript', 'deb', 'debutant', 'draft', 'drafted man'],
    'trainer': ['link trainer', 'athletic coach', 'breaker', 'breeder', 'broncobuster', 'buckaroo', 'cattleman', 'coach', 'cow keeper', 'cowman', 'crew trainer', 'dairy farmer'],
    'training': ['acclimation', 'acclimatization', 'accommodation', 'accustoming', 'adaption', 'adjustment', 'apprenticeship', 'arrangement', 'basic training', 'breaking', 'breaking-in', 'breeding'],
    'training school': ['pow camp', 'bastille', 'black hole', 'borstal', 'borstal institution', 'borstal school', 'bridewell', 'brig', 'cell', 'concentration camp', 'condemned cell', 'death cell'],
    'trainman': ['baggage man', 'bakehead', 'brakeman', 'brakie', 'butcher', 'conductor', 'dispatcher', 'fireman', 'footplate man', 'guard', 'lineman', 'porter'],
    'traipse': ['airing', 'amble', 'ambulate', 'ankle', 'barge', 'bat around', 'bowl along', 'bum', 'bundle', 'circumambulate', 'claudicate', 'clump'],
    'trait': ['acculturation', 'affection', 'air', 'aroma', 'attribute', 'badge', 'banner', 'bearing', 'birthmark', 'brand', 'brow', 'cachet'],
    'traitor': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'quisling', 'agitator', 'apostate', 'archtraitor', 'backslider', 'betrayer', 'bolter', 'brawler'],
    'traitorous': ['judas-like', 'trojan-horse', 'alienated', 'apostate', 'betraying', 'breakaway', 'collaborative', 'deceitful', 'degenerate', 'disaffected', 'disloyal', 'double-crossing'],
    'trajectory': ['air lane', 'altitude peak', 'aphelion', 'apogee', 'astronomical longitude', 'automatic control', 'autumnal equinox', 'beat', 'blast-off', 'burn', 'burnout', 'ceiling'],
    'tram': ['branch', 'cable railway', 'cog railway', 'el', 'electric', 'electric car', 'electric railway', 'elevated', 'elevated railway', 'embankment', 'feeder', 'feeder line'],
    'trammel': ['oregon boat', 'anchor', 'arrest', 'bar', 'bearing rein', 'bilbo', 'bind', 'bit', 'block', 'bond', 'bonds', 'brake'],
    'tramp': ['arab', 'bowery bum', 'airing', 'alien', 'amble', 'backpack', 'baggage', 'bat around', 'beach bum', 'beachcomber', 'beggar', 'beggarly fellow'],
    'tramping': ['ambling', 'ambulation', 'backpacking', 'footing', 'footing it', 'footwork', 'going on foot', 'hiking', 'hitchhiking', 'hitching', 'hoofing', 'legwork'],
    'trample': ['break down', 'clop', 'clump', 'contemn', 'crush', 'damage', 'defy', 'destroy', 'disdain', 'disregard', 'drub', 'extinguish'],
    'trampoline': ['indian club', 'lastex', 'baleen', 'barbell', 'battledore', 'chewing gum', 'dumbbell', 'elastic', 'elastomer', 'exerciser', 'gum', 'gum elastic'],
    'trance': ['walter mitty', 'absence of mind', 'absentmindedness', 'absorption', 'abstractedness', 'abstraction', 'amnesia', 'animal hypnosis', 'autohypnosis', 'bemusement', 'brown study', 'castle-building'],
    'tranquil': ['at peace', 'at rest', 'blank', 'blankminded', 'bloodless', 'calm', 'cloistered', 'collected', 'composed', 'concordant', 'cool', 'coolheaded'],
    'tranquilize': ['allay', 'appease', 'arrange', 'array', 'balm', 'becalm', 'calm', 'calm down', 'cease', 'compose', 'conciliate', 'cool'],
    'tranquilizer': ['amytal', 'amytal pill', 'det', 'dmt', 'demerol', 'dolophine', 'lsd', 'librium', 'luminal', 'luminal pill', 'mary jane', 'mickey finn'],
    'tranquilizing': ['analgesic', 'anodyne', 'appeasing', 'calmant', 'calmative', 'calming', 'cradling', 'depressant', 'dreamy', 'drowsy', 'gentling', 'hushing'],
    'tranquillity': ['buddha-like composure', 'oriental calm', 'abnegation', 'abstinence', 'arrangement', 'array', 'ataraxia', 'ataraxy', 'awful silence', 'blank mind', 'blankmindedness', 'blankness'],
    'transact': ['abide by', 'accomplish', 'adhere to', 'administer', 'carry on', 'carry out', 'carry through', 'complete', 'conclude', 'conduct', 'cope with', 'deal with'],
    'transaction': ['accomplished fact', 'accomplishment', 'accord', 'achievement', 'act', 'acta', 'action', 'administration', 'adventure', 'affair', 'agreement', 'annals'],
    'transactional analysis': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'assertiveness training', 'behavior modification', 'behavior therapy', 'bioenergetics', 'biofeedback', 'confrontation therapy'],
    'transanimation': ['avatar', 'catabolism', 'catalysis', 'consubstantiation', 'displacement', 'heterotopia', 'metabolism', 'metagenesis', 'metamorphism', 'metamorphosis', 'metastasis', 'metathesis'],
    'transcend': ['beat', 'best', 'better', 'bulk', 'bulk large', 'cap', 'exceed', 'excel', 'go beyond', 'go one better', 'improve on', 'loom'],
    'transcendent': ['christlike', 'christly', 'a cut above', 'above', 'absolute', 'accomplished', 'ahead', 'amorphous', 'ascendant', 'better', 'blind', 'boundless'],
    'transcendental': ['elysian', 'olympian', 'a cut above', 'above', 'abstract', 'abstruse', 'ahead', 'airy', 'algorismic', 'algorithmic', 'alien', 'aliquot'],
    'transcendental meditation': ['arica movement', 'erhard seminars training', 'new consciousness', 'pentothal interview', 'sat', 't-group', 'assertiveness training', 'behavior modification', 'behavior therapy', 'bioenergetics', 'biofeedback', 'confrontation therapy'],
    'transcendentalism': ['eeriness', 'elfdom', 'faerie', 'miraculousness', 'mysteriousness', 'mystery', 'numinousness', 'otherworldliness', 'preternaturalism', 'superhumanity', 'supernaturalism', 'supernaturality'],
    'transcendentalist': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'adept', 'animist', 'animistic', 'anthroposophist', 'atomistic', 'cabalist', 'cosmotheistic'],
    'transcending': ['a cut above', 'above', 'ahead', 'ascendant', 'better', 'capping', 'chosen', 'distinguished', 'eclipsing', 'eminent', 'exceeding', 'excellent'],
    'transcribe': ['english', 'photostat', 'xerox', 'adapt', 'alphabet', 'alphabetize', 'arrange', 'capitalize', 'character', 'clone', 'compose', 'construe'],
    'transcriber': ['amanuensis', 'calligrapher', 'chirographer', 'clerk', 'copier', 'copyist', 'ink spiller', 'inkslinger', 'letterer', 'pen', 'pencil driver', 'penman'],
    'transcript': ['photostat', 'apograph', 'arrangement', 'article', 'autograph', 'brainchild', 'carbon', 'carbon copy', 'composition', 'computer printout', 'copy', 'document'],
    'transcription': ['adaptation', 'amplification', 'apograph', 'arrangement', 'article', 'autograph', 'bilingual text', 'brainchild', 'carbon', 'carbon copy', 'cartridge', 'cassette'],
    'transept': ['easter sepulcher', 'ambry', 'apse', 'baptistery', 'blindstory', 'chancel', 'choir', 'cloisters', 'confessional', 'confessionary', 'cross bitt', 'crossarm'],
    'transfer': ['abalienate', 'accredit', 'alien', 'alienate', 'amortize', 'announcement', 'apograph', 'assign', 'authorize', 'barter', 'bequeath', 'bring'],
    'transferable': ['alienable', 'assignable', 'bequeathable', 'communicable', 'conductive', 'consignable', 'contagious', 'conveyable', 'devisable', 'expressable', 'heritable', 'impartable'],
    'transference': ['abalienation', 'alienation', 'amortization', 'amortizement', 'announcement', 'assignation', 'assignment', 'association', 'association by contiguity', 'association of ideas', 'bargain and sale', 'barter'],
    'transfiguration': ['avatar', 'catabolism', 'catalysis', 'consubstantiation', 'displacement', 'heterotopia', 'metabolism', 'metagenesis', 'metamorphism', 'metamorphosis', 'metastasis', 'metathesis'],
    'transfigure': ['acculturate', 'advance', 'ameliorate', 'amend', 'better', 'boost', 'bring forward', 'change', 'civilize', 'commute', 'convert', 'edify'],
    'transfix': ['auger', 'balance', 'ballast', 'bayonet', 'bewitch', 'bite', 'bore', 'broach', 'counterbalance', 'countersink', 'dagger', 'dirk'],
    'transform': ['acculturate', 'advance', 'alter', 'ameliorate', 'amend', 'assimilate to', 'become', 'better', 'boost', 'bring forward', 'bring to', 'change'],
    'transformation': ['fabianism', 'about-face', 'act drop', 'addition', 'alchemy', 'alteration', 'approximation', 'asbestos', 'asbestos board', 'assimilation', 'assumption', 'avatar'],
    'transformed': ['advanced', 'altered', 'ameliorated', 'assimilated', 'beautified', 'better', 'bettered', 'changeable', 'changed', 'civilized', 'converted', 'cultivated'],
    'transformer': ['agent', 'alembic', 'alterant', 'alterative', 'alterer', 'anvil', 'caldron', 'catalyst', 'catalytic agent', 'crucible', 'engine', 'ferment'],
    'transfuse': ['assign', 'bespread', 'besprinkle', 'bleed', 'breathe', 'brew', 'carry over', 'charge', 'color', 'communicate', 'consign', 'crawl with'],
    'transfusion': ['arterial transfusion', 'blood bank', 'blood donor', 'blood donor center', 'blood transfusion', 'bloodmobile', 'communication', 'conduction', 'contagion', 'convection', 'delivery', 'deportation'],
    'transgress': ['advance upon', 'breach', 'breach the law', 'break', 'break bounds', 'break the law', 'care naught for', 'circumvent the law', 'commit a crime', 'commit sin', 'contravene', 'defy'],
    'transgression': ['atrocity', 'bad faith', 'breach', 'breach of contract', 'breach of faith', 'breach of law', 'breach of privilege', 'breach of promise', 'breach of trust', 'breaking', 'civil disobedience', 'contravention'],
    'transgressor': ['bad person', 'criminal', 'crook', 'culprit', 'deceiver', 'delinquent', 'evil man', 'evil person', 'evildoer', 'felon', 'gangster', 'lawbreaker'],
    'transience': ['adaptability', 'adjustability', 'alterability', 'brevity', 'briefness', 'changeability', 'changeableness', 'changefulness', 'compactness', 'compendiousness', 'conciseness', 'curtness'],
    'transient': ['able to adapt', 'adaptable', 'adjustable', 'adventurer', 'alpinist', 'alterable', 'alterative', 'arising', 'astronaut', 'board-and-roomer', 'boarder', 'brief'],
    'transit': ['about-face', 'alchemy', 'alteration', 'assimilation', 'assumption', 'astrolabe', 'azimuth circle', 'azimuth compass', 'becoming', 'bevel', 'bevel protractor', 'bevel square'],
    'transition': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'alchemy', 'alteration', 'amelioration', 'apostasy', 'assimilation', 'assumption', 'becoming', 'betterment'],
    'transitional': ['active', 'altering', 'changing', 'convertible', 'developing', 'driving', 'evolving', 'impelling', 'in motion', 'mobile', 'modifiable', 'motile'],
    'transitive': ['adjectival', 'adverbial', 'attributive', 'auxiliary', 'auxiliary verb', 'brittle', 'capricious', 'changeable', 'conjunctive', 'copula', 'copulative', 'correct'],
    'transitory': ['able to adapt', 'adaptable', 'adjustable', 'alterable', 'alterative', 'brief', 'brittle', 'capricious', 'changeable', 'checkered', 'circumforaneous', 'corruptible'],
    'translate': ['english', 'alter', 'assign', 'carry', 'carry over', 'change', 'communicate', 'consign', 'construe', 'convert', 'convey', 'decipher'],
    'translation': ['alteration', 'amplification', 'apotheosis', 'ascension', 'assumption', 'avatar', 'bilingual text', 'carrying', 'catabolism', 'catalysis', 'change', 'clavis'],
    'translator': ['allegorist', 'annotator', 'cicerone', 'clarifier', 'commentator', 'critic', 'cryptanalyst', 'cryptographer', 'cryptologist', 'decoder', 'definer', 'demonstrator'],
    'transliteration': ['amplification', 'bilingual text', 'clavis', 'crib', 'decipherment', 'decoding', 'epigraph', 'faithful translation', 'free translation', 'gloss', 'glossary', 'initialing'],
    'translucent': ['apparent', 'clean-cut', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'cloudless', 'coherent', 'connected', 'consistent', 'crisp', 'crystal'],
    'transmigrate': ['body', 'corporealize', 'corporify', 'embody', 'emigrate', 'expatriate', 'flit', 'immigrate', 'in-migrate', 'incarnate', 'incorporate', 'intermigrate'],
    'transmigration': ['avatar', 'catabolism', 'catalysis', 'communication', 'conduction', 'consubstantiation', 'contagion', 'convection', 'corporealization', 'delivery', 'deportation', 'diapedesis'],
    'transmigratory': ['circumforaneous', 'discursive', 'divagatory', 'drifting', 'errant', 'flitting', 'floating', 'footloose', 'footloose and fancy-free', 'fugitive', 'gadding', 'gypsy-like'],
    'transmission': ['fcc', 'fm broadcasting', 'hydromatic', 'abalienation', 'account', 'acquaintance', 'alienation', 'amortization', 'amortizement', 'announcement', 'assignation', 'assignment'],
    'transmit': ['abalienate', 'add a codicil', 'address', 'air-express', 'airfreight', 'airmail', 'alien', 'alienate', 'amortize', 'assign', 'barter', 'beam'],
    'transmittable': ['assignable', 'communicable', 'conductive', 'consignable', 'contagious', 'conveyable', 'expressable', 'impartable', 'interchangeable', 'mailable', 'metathetic', 'movable'],
    'transmittal': ['abalienation', 'alienation', 'amortization', 'amortizement', 'announcement', 'assignation', 'assignment', 'bargain and sale', 'barter', 'bequeathal', 'cession', 'communication'],
    'transmitter': ['am transmitter', 'fm transmitter', 'rt transmitter', 'telautography', 'teletype', 'teletype network', 'teletyping', 'amateur transmitter', 'beacon', 'call box', 'closed-circuit telegraphy', 'code'],
    'transmuted': ['altered', 'better', 'changeable', 'changed', 'converted', 'degenerate', 'deviant', 'divergent', 'improved', 'metamorphosed', 'metastasized', 'modified'],
    'transom': ['air duct', 'air hole', 'air passage', 'air shaft', 'air tube', 'airway', 'bay', 'bay window', 'blowhole', 'bow window', 'breathing hole', 'casement'],
    'transparency': ['celluloid', 'lucite', 'perspex', 'photostat', 'plexiglas', 'telephoto', 'wirephoto', 'xerox', 'xerox copy', 'aerial photograph', 'aquamarine', 'beryl'],
    'transparent': ['apparent', 'articulate', 'artless', 'bluff', 'blunt', 'broad', 'brusque', 'candid', 'clean-cut', 'clear', 'clear as crystal', 'clear as day'],
    'transparent things': ['celluloid', 'lucite', 'perspex', 'plexiglas', 'aquamarine', 'beryl', 'carnelian', 'cellophane', 'chalcedony', 'chiffon', 'chrysolite', 'citrine'],
    'transpicuous': ['clean-cut', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'coherent', 'connected', 'consistent', 'crisp', 'crystal', 'crystal-clear', 'crystalline'],
    'transpire': ['appear', 'arise', 'be found', 'be met with', 'be realized', 'be revealed', 'become known', 'befall', 'betide', 'bleed', 'break', 'break forth'],
    'transplant': ['amputation', 'anastomotic operation', 'assign', 'bed', 'bloodless operation', 'broadcast', 'capital operation', 'carry over', 'communicate', 'compensating operation', 'consign', 'corneal transplant'],
    'transport': ['elysium', 'abandon', 'agitate', 'air express', 'airfreight', 'airlift', 'ardor', 'asportation', 'ban', 'banish', 'bear', 'bearing'],
    'transportable': ['assignable', 'communicable', 'conductive', 'consignable', 'contagious', 'conveyable', 'expressable', 'impartable', 'interchangeable', 'mailable', 'metathetic', 'movable'],
    'transportation': ['air express', 'airfreight', 'airlift', 'asportation', 'banishment', 'bearing', 'blackballing', 'carriage', 'carry', 'carrying', 'cartage', 'conveyance'],
    'transported': ['abandoned', 'absent', 'absentminded', 'absorbed', 'abstracted', 'amok', 'bellowing', 'bemused', 'berserk', 'bursting with happiness', 'carried away', 'castle-building'],
    'transporter': ['aquarius', 'ganymede', 'hebe', 'bearer', 'bheesty', 'busboy', 'caddie', 'cargo handler', 'carrier', 'carrier pigeon', 'carter', 'common carrier'],
    'transpose': ['adapt', 'alternate', 'arrange', 'assign', 'bandy', 'be quits with', 'carry over', 'change', 'communicate', 'commute', 'compensate', 'compose'],
    'transposed': ['arsy-varsy', 'ass over elbows', 'back-to-front', 'backwards', 'capsized', 'changeable', 'chiastic', 'commutable', 'commutative', 'convertible', 'equal', 'equalizing'],
    'transposition': ['alternation', 'avatar', 'battledore and shuttlecock', 'catabolism', 'catalysis', 'communication', 'commutation', 'conduction', 'consubstantiation', 'contagion', 'convection', 'cooperation'],
    'transshipment': ['air express', 'airfreight', 'airlift', 'asportation', 'bearing', 'carriage', 'carry', 'carrying', 'cartage', 'conveyance', 'drayage', 'expressage'],
    'transude': ['bleed', 'discharge', 'effuse', 'egest', 'eliminate', 'emit', 'excrete', 'exfiltrate', 'extravasate', 'exudate', 'exude', 'filter'],
    'transverse': ['across', 'across the grain', 'athwart', 'athwartships', 'bar', 'bend', 'bendwise', 'bias', 'biased', 'biaswise', 'catercorner', 'catercornered'],
    'transvestite': ['ac-dc', 'amphierotic', 'autoerotic', 'bisexed', 'bisexual', 'bugger', 'butch', 'coprophiliac', 'deviant', 'effeminate', 'erotomaniac', 'exhibitionist'],
    'trap': ['dionaea', 'french door', 'john law', 'allure', 'allurement', 'ambuscade', 'ambush', 'ambushment', 'archway', 'artifice', 'back door', 'bag'],
    'trap door': ['french door', 'archway', 'back door', 'barway', 'bulkhead', 'carriage entrance', 'cellar door', 'cellarway', 'door', 'doorjamb', 'doorpost', 'doorway'],
    'trapezoid': ['cube-shaped', 'cubed', 'cubic', 'cubiform', 'cuboid', 'diced', 'foursquare', 'oblong', 'orthogonal', 'quadrangular', 'quadrate', 'quadriform'],
    'trappings': ['accessories', 'accouterments', 'adornments', 'appanages', 'apparatus', 'appendages', 'appointments', 'appurtenances', 'back band', 'backstrap', 'bearing rein', 'bellyband'],
    'trapshooting': ['archery', 'casting', 'chucking', 'firing', 'flinging', 'gunnery', 'heaving', 'hurling', 'jaculation', 'lobbing', 'musketry', 'pitching'],
    'trash': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'balls', 'baloney', 'bibble-babble', 'bilge', 'blabber', 'blather', 'bombast'],
    'trashy': ['ng', 'pickwickian', 'absurd', 'base', 'beggarly', 'beneath contempt', 'cheap', 'cheesy', 'common', 'contemptible', 'crummy', 'despicable'],
    'trattoria': ['automat', 'beanery', 'bistro', 'buffet', 'buvette', 'cafe', 'cafeteria', 'canteen', 'cantina', 'chophouse', 'chuck wagon', 'coffee shop'],
    'trauma': ['abrasion', 'ambivalence', 'ambivalence of impulse', 'anaphylactic shock', 'battle fatigue', 'blemish', 'blow', 'break', 'burn', 'chafe', 'check', 'chip'],
    'traumatize': ['abrade', 'affect', 'bark', 'blemish', 'bloody', 'break', 'burn', 'chafe', 'check', 'chip', 'claw', 'come home to'],
    'travail': ['accouchement', 'be confined', 'bear', 'bear a child', 'bear young', 'birth', 'birth throes', 'birthing', 'blessed event', 'calve', 'cast', 'childbearing'],
    'travel': ['advance', 'advancement', 'advancing', 'ascend', 'associate', 'back', 'back up', 'budge', 'career', 'change', 'change place', 'circle'],
    'traveling': ['active', 'ambulant', 'ambulative', 'ambulatory', 'circuit-riding', 'commutation', 'course', 'crossing', 'driving', 'expeditionary', 'globe-girdling', 'globe-trotting'],
    'traverse': ['across', 'across the grain', 'athwart', 'athwartships', 'bar', 'be at cross-purposes', 'be contrary to', 'belie', 'boat', 'bridge', 'buck', 'call into question'],
    'travesty': ['atticism', 'aggrandize', 'aggrandizement', 'agile wit', 'amplification', 'amplify', 'anamorphosis', 'ape', 'bad likeness', 'ballyhoo', 'belie', 'big talk'],
    'trawl': ['angle', 'bait', 'bait the hook', 'birdlime', 'bob', 'bola', 'clam', 'cobweb', 'dap', 'dib', 'dibble', 'drag'],
    'treacherous': ['machiavellian', 'punic', 'ambidextrous', 'artful', 'calculating', 'chancy', 'chiseling', 'collusive', 'covinous', 'crafty', 'crooked', 'cunning'],
    'treachery': ['machiavellianism', 'ambidexterity', 'artifice', 'bad faith', 'cunning', 'danger', 'deceitfulness', 'desultoriness', 'dirty pool', 'dirty trick', 'dirty work', 'dishonesty'],
    'treacle': ['albumen', 'ambrosia', 'artificial sweetener', 'batter', 'blackstrap', 'bonnyclabber', 'butter', 'calcium cyclamate', 'cane syrup', 'clabber', 'clover honey', 'comb honey'],
    'tread': ['amble', 'ambulate', 'amount', 'ankle', 'caliber', 'career', 'circumambulate', 'clip', 'clop', 'clump', 'compass', 'cut'],
    'tread upon': ['beat down', 'break', 'browbeat', 'bulldoze', 'bully', 'castrate', 'clamp down on', 'coerce', 'compel', 'cow', 'daunt', 'despotize'],
    'tread water': ['abide', 'bathe', 'be still', 'coast', 'dive', 'float', 'freeze', 'go in swimming', 'go in wading', 'keep quiet', 'lie still', 'mark time'],
    'treadle': ['advance', 'bar', 'beam', 'boom', 'bowl', 'bunt', 'butt', 'cant hook', 'claw bar', 'crank', 'crow', 'crowbar'],
    'treadmill': ['beat', 'beaten path', 'branks', 'broken record', 'bureaucracy', 'bureaucratism', 'chinoiserie', 'clockwork regularity', 'constancy', 'crank', 'cucking stool', 'daily grind'],
    'treason': ['golconda', 'machiavellianism', 'apostasy', 'backsliding', 'betrayal', 'bolt', 'breach of trust', 'breakaway', 'collaboration', 'crossing-over', 'deceit', 'deceitfulness'],
    'treasonable': ['judas-like', 'trojan-horse', 'apostate', 'betraying', 'breakaway', 'collaborative', 'degenerate', 'disloyal', 'double-crossing', 'extreme', 'extremistic', 'factious'],
    'treasure': ['festschrift', 'swiss bank account', 'abundance', 'accumulate', 'accumulation', 'admire', 'adore', 'affluence', 'amass', 'amassment', 'ana', 'anthology'],
    'treasure house': ['fort knox', 'golconda', 'archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase'],
    'treasure trove': ['bonus', 'bringing to light', 'buried treasure', 'casual discovery', 'catching', 'chance discovery', 'detection', 'determination', 'determining', 'disclosure', 'discovery', 'distinguishment'],
    'treasured': ['accumulated', 'admired', 'adored', 'amassed', 'backlogged', 'beloved', 'cherished', 'collected', 'darling', 'dear', 'dearly beloved', 'esteemed'],
    'treasurer': ['accountant', 'archon', 'auditor', 'bookkeeper', 'bursar', 'cashier', 'cashkeeper', 'chamberlain', 'chancellor', 'chief executive', 'chief executive officer', 'compensator'],
    'treasury': ['fort knox', 'golconda', 'abundance', 'account', 'accumulation', 'advise', 'amassment', 'appraise', 'archives', 'armory', 'arsenal', 'attend'],
    'treasury note': ['federal reserve note', 'assignat', 'bank note', 'bill', 'callable securities', 'cats and dogs', 'certificate of deposit', 'corporation securities', 'dollar bill', 'fiat money', 'foreign securities', 'fractional note'],
    'treat': ['act on', 'act toward', 'act upon', 'affect', 'air', 'ambrosia', 'analyze', 'arrange', 'attend', 'bandage', 'banquet', 'bathe'],
    'treat with': ['act between', 'arbitrate', 'bargain', 'go between', 'intercede', 'intermediate', 'interpose', 'intervene', 'judge', 'make terms', 'mediate', 'meet halfway'],
    'treatment': ['airing', 'analysis', 'arrangement', 'article', 'atmosphere', 'balance', 'basic training', 'briefing', 'brushwork', 'buzz session', 'canvassing', 'care'],
    'treaty': ['nato', 'seato', 'accord', 'agreement', 'alliance', 'arrangement', 'bargain', 'capitulation', 'cartel', 'charter', 'compact', 'concord'],
    'treble': ['accompaniment', 'air', 'alto', 'aria', 'baritone', 'bass', 'basso continuo', 'basso ostinato', 'bassus', 'bourdon', 'bravura', 'burden'],
    'tree': ['stammbaum', 'acacia', 'ailanthus', 'alder', 'alligator pear', 'allspice', 'almond', 'apple', 'apricot', 'ash', 'aspen', 'avocado'],
    'treelike': ['v-shaped', 'y-shaped', 'arborary', 'arboreal', 'arboreous', 'arborescent', 'arboresque', 'arborical', 'arboriform', 'biforked', 'bifurcate', 'bifurcated'],
    'trefoil': ['clover', 'deuce-ace', 'leash', 'set of three', 'shamrock', 'tercet', 'ternary', 'ternion', 'terzetto', 'three', 'threesome', 'tierce'],
    'trek': ['campaign', 'circuit', 'course', 'cruise', 'emigrate', 'emigration', 'excursion', 'expatriate', 'expatriation', 'expedition', 'fare', 'flight'],
    'trellis': ['arabesque', 'basketry', 'basketwork', 'cancellation', 'cross-hatching', 'crossing-out', 'filigree', 'fret', 'fretwork', 'grate', 'grating', 'grid'],
    'tremble': ['bebung', 'all-overs', 'be cold', 'bob', 'bobble', 'bounce', 'bump', 'chatter', 'chill', 'cold shivers', 'cold sweat', 'cower'],
    'trembling': ['agitated', 'ague', 'all shook up', 'all-overish', 'aquiver', 'aspen', 'bashful', 'bumpiness', 'chattering', 'chorea', 'cold shivers', 'cowardly'],
    'tremendous': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'amazing', 'amplitudinous', 'appalling', 'astounding', 'astronomic'],
    'tremendously': ['alarmingly', 'appallingly', 'astoundingly', 'awfully', 'colossally', 'disconcertingly', 'dismayingly', 'divinely', 'dreadfully', 'enormously', 'exquisitely', 'fearfully'],
    'tremolo': ['bebung', 'english horn', 'bassoon', 'block flute', 'bombard', 'bourdon', 'cello', 'claribel', 'clarinet', 'clarion', 'concert flute', 'cornet'],
    'tremor': ['bebung', 'aphonia', 'artificial voice', 'bang', 'bob', 'bobble', 'boot', 'bounce', 'broken speech', 'broken tones', 'broken voice', 'bump'],
    'tremulous': ['afraid', 'agitated', 'aguish', 'all shook up', 'all-overish', 'anxious', 'aquiver', 'aspen', 'bashful', 'blurred', 'breathy', 'chattering'],
    'trench': ['bassalia', 'abri', 'abysm', 'abyss', 'abyssal zone', 'adit', 'air-raid shelter', 'approach', 'approach trench', 'aqueduct', 'arroyo', 'barge in'],
    'trench foot': ['minamata disease', 'altitude sickness', 'anoxemia', 'anoxia', 'anoxic anoxia', 'anthrax', 'black lung', 'caisson disease', 'chilblain', 'decompression sickness', 'frostbite', 'immersion foot'],
    'trench mouth': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'trenchant': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'active', 'acute', 'aggressive'],
    'trencherman': ['brillat-savarin', 'lucullus', 'belly-god', 'board-and-roomer', 'boarder', 'bon vivant', 'cannibal', 'carnivore', 'connoisseur of food', 'consumer', 'cormorant', 'diner'],
    'trend': ['brownian movement', 'zeitgeist', 'advance', 'affluence', 'afflux', 'affluxion', 'aim', 'angular motion', 'ascending', 'ascent', 'axial motion', 'azimuth'],
    'trend setter': ['beau brummel', 'arbiter of fashion', 'clotheshorse', 'clubman', 'clubwoman', 'dandy', 'deb', 'debutante', 'fashion plate', 'fashionable', 'fop', 'man-about-town'],
    'trendy': ['a la mode', 'all the rage', 'all the thing', 'coxcomb', 'current', 'exhibitionist', 'fashionable', 'flash', 'grandstander', 'groovy', 'hip', 'hot'],
    'trepidation': ['agitation', 'alarm', 'apprehensiveness', 'attack of nerves', 'bluster', 'bobbery', 'boil', 'boiling', 'brouhaha', 'buck fever', 'bustle', 'case of nerves'],
    'trespass': ['adopt', 'adoption', 'advance upon', 'appropriate', 'appropriation', 'arrogate', 'arrogation', 'assume', 'assumption', 'atrocity', 'bad faith', 'barge in'],
    'trespassing': ['adoption', 'appropriation', 'arrogation', 'assumption', 'breach of law', 'contravention', 'encroachment', 'entrance', 'entrenchment', 'impingement', 'imposition', 'incursion'],
    'trestle': ['branch', 'buck', 'cable railway', 'clotheshorse', 'cog railway', 'el', 'electric railway', 'elevated', 'elevated railway', 'embankment', 'feeder', 'feeder line'],
    'triable': ['actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'black-market', 'bootleg', 'chargeable', 'contraband', 'contrary to law', 'criminal', 'felonious'],
    'triad': ['arpeggio', 'broken chord', 'chord', 'clover', 'common chord', 'concento', 'concord', 'consonant chord', 'deuce-ace', 'diminished seventh chord', 'dominant chord', 'enharmonic'],
    'trial': ['olympic games', 'olympics', 'r and d', 'acid test', 'adverse circumstances', 'adversity', 'affliction', 'aggravation', 'agony', 'anguish', 'annoyance', 'approach'],
    'trial and error': ['r and d', 'approach', 'assay', 'attempt', 'bid', 'control', 'control experiment', 'controlled experiment', 'crack', 'cut and try', 'effort', 'empiricism'],
    'trial balloon': ['barometer', 'bone of contention', 'catechism', 'cross-interrogatory', 'cross-question', 'debating point', 'demand', 'feeler', 'inquiry', 'interrogation', 'interrogative', 'interrogatory'],
    'trial run': ['gedankenexperiment', 'audition', 'bench test', 'dry run', 'experimentation', 'flight test', 'hearing', 'pilot plan', 'practical test', 'practice', 'rehearsal', 'road test'],
    'triangle': ['platonic body', 't square', 'acute-angled triangle', 'adulterous affair', 'adultery', 'affair', 'amour', 'battery', 'bell', 'bells', 'bones', 'branks'],
    'triangular': ['cuneate', 'cuneated', 'cuneiform', 'deltoid', 'fan-shaped', 'oxygonal', 'three', 'three-cornered', 'three-dimensional', 'three-footed', 'three-in-one', 'three-pronged'],
    'triangulate': ['allocate', 'appraise', 'appreciate', 'assay', 'assess', 'assign', 'calculate', 'calibrate', 'caliper', 'check a parameter', 'collocate', 'compute'],
    'triangulation': ['appraisal', 'appraisement', 'approximation', 'assessment', 'assize', 'assizement', 'automatic tracking', 'calculation', 'computation', 'correction', 'data transmission', 'determination'],
    'tribe': ['age group', 'animal kingdom', 'band', 'battalion', 'bevy', 'biotype', 'blood', 'body', 'branch', 'brand', 'breed', 'brigade'],
    'tribesman': ['agnate', 'ancestry', 'blood', 'blood relation', 'blood relative', 'clansman', 'cognate', 'collateral', 'collateral relative', 'connections', 'consanguinean', 'distaff side'],
    'tribulation': ['adverse circumstances', 'adversity', 'affliction', 'aggravation', 'annoyance', 'blight', 'bummer', 'calvary', 'care', 'cross', 'crucible', 'curse'],
    'tribunal': ['british cabinet', 'sanhedrin', 'us cabinet', 'advisory body', 'assembly', 'association', 'balcony', 'bar', 'bench', 'board', 'body of advisers', 'borough council'],
    'tribune': ['areopagite', 'archon', 'balcony', 'catafalque', 'dais', 'deemster', 'dempster', 'doomsman', 'doomster', 'emplacement', 'estrade', 'floor'],
    'tributary': ['accessory', 'affluent', 'bayou', 'beck', 'billabong', 'branch', 'brook', 'burn', 'client', 'collateral', 'confluent', 'confluent stream'],
    'tribute': ['christmas present', 'acclaim', 'acclamation', 'accolade', 'account', 'acknowledgment', 'adulation', 'allowance', 'anniversaries', 'apotheosis', 'appreciation', 'assessment'],
    'trice': ['breath', 'coup', 'crack', 'flash', 'half a jiffy', 'half a mo', 'half a second', 'half a shake', 'instant', 'jiff', 'jiffy', 'microsecond'],
    'trick': ['ability', 'accomplishment', 'ace', 'action', 'ad hoc measure', 'affectation', 'airy nothing', 'alibi', 'anchor watch', 'answer', 'antic', 'apology'],
    'trick out': ['adorn', 'array', 'beautify', 'bedeck', 'bedizen', 'belie', 'blazon', 'camouflage', 'color', 'convolute', 'dandify', 'deck'],
    'trickery': ['art', 'artful dodge', 'artfulness', 'artifice', 'blind', 'bravery', 'cheat', 'cheating', 'chicane', 'chicanery', 'chiffon', 'clinquant'],
    'trickle': ['a few', 'condensation', 'condense', 'distill', 'distillation', 'dribble', 'drip', 'dripping', 'drippings', 'dripple', 'drizzle', 'drop'],
    'trickster': ['artful dodger', 'philadelphia lawyer', 'yankee horse trader', 'charmer', 'cheat', 'cheater', 'con man', 'conjurer', 'crafty rascal', 'defrauder', 'diddler', 'dodger'],
    'tricky': ['herculean', 'machiavellian', 'machiavellic', 'abstruse', 'acute', 'ambidextrous', 'amoral', 'arch', 'arduous', 'artful', 'astute', 'awkward'],
    'tricolor': ['dannebrog', 'jolly roger', 'old glory', 'star-spangled banner', 'stars and stripes', 'union flag', 'union jack', 'and blue', 'banderole', 'banner', 'banneret', 'bicolor'],
    'trident': ['branch', 'clover', 'crotch', 'crutch', 'delta', 'deltoid', 'deuce-ace', 'fan', 'fork', 'furcula', 'furculum', 'groin'],
    'tried and true': ['acknowledged', 'admitted', 'blase', 'committed', 'confirmed', 'constant', 'conventional', 'cosmopolitan', 'cosmopolite', 'customary', 'dedicated', 'dependable'],
    'triennial': ['amphibian', 'angiosperm', 'anniversary', 'annual', 'annual holiday', 'aquatic plant', 'biannual', 'bicentenary', 'bicentennial', 'biennial', 'bimonthly', 'birthday'],
    'trifle': ['charlotte', 'danish pastry', 'french pastry', 'a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'abandon', 'bagatelle', 'baklava', 'bauble'],
    'trifle with': ['bat out', 'be disrespectful', 'be overfamiliar with', 'botch', 'bungle', 'dash off', 'disesteem', 'disparage', 'disrespect', 'do anyhow', 'do by halves', 'do carelessly'],
    'trifler': ['sunday painter', 'amateur', 'bungler', 'clock watcher', 'coquet', 'criticaster', 'dabbler', 'dabster', 'dallier', 'dawdle', 'dawdler', 'diddler'],
    'trifling': ['mickey mouse', 'airy', 'asinine', 'banal', 'bickering', 'brimful', 'brimming', 'captious', 'catchpenny', 'caviling', 'chic', 'chipper'],
    'trifurcate': ['v-shaped', 'y-shaped', 'arboreal', 'arborescent', 'arboriform', 'biforked', 'bifurcate', 'bifurcated', 'branched', 'branching', 'branchlike', 'crotched'],
    'trig': ['all ataunto', 'anal', 'ataunt', 'braw', 'bungup and bilge-free', 'chic', 'classy', 'clothes-conscious', 'cosmopolitan', 'dapper', 'dashing', 'dinky'],
    'trigger happy': ['aggressive', 'antagonistic', 'bashful', 'battling', 'bellicose', 'belligerent', 'bloodthirsty', 'bloody', 'bloody-minded', 'chauvinist', 'chauvinistic', 'combative'],
    'trigger man': ['cain', 'apache', 'assassin', 'assassinator', 'bloodletter', 'bloodshedder', 'bravo', 'bruiser', 'burker', 'butcher', 'button man', 'cannibal'],
    'trigonometry': ['boolean algebra', 'euclidean geometry', 'fourier analysis', 'lagrangian function', 'algebra', 'algebraic geometry', 'analysis', 'analytic geometry', 'arithmetic', 'associative algebra', 'binary arithmetic', 'calculus'],
    'trilateral': ['bifacial', 'bilateral', 'cuneate', 'cuneated', 'cuneiform', 'deltoid', 'dihedral', 'flanked', 'handed', 'lateral', 'many-sided', 'multilateral'],
    'trill': ['bebung', 'anthem', 'babble', 'ballad', 'bubble', 'burble', 'cackle', 'call', 'carol', 'caw', 'chant', 'chatter'],
    'trilogy': ['clover', 'deuce-ace', 'leash', 'set of three', 'shamrock', 'tercet', 'ternary', 'ternion', 'terzetto', 'three', 'threesome', 'tierce'],
    'trim': ['attic', 'ciceronian', 'abbreviate', 'ability', 'abridge', 'abstain', 'abstract', 'adjoin', 'adjunct', 'adjustment', 'adorn', 'adornment'],
    'trimester': ['abundant year', 'academic year', 'annum', 'bissextile year', 'calendar month', 'calendar year', 'century', 'clover', 'common year', 'day', 'decade', 'decennary'],
    'trimmed': ['abbreviated', 'abridged', 'abstracted', 'adorned', 'all up with', 'beaded', 'beat', 'beaten', 'bedecked', 'bedizened', 'befrilled', 'bejeweled'],
    'trimming': ['smyth sewing', 'waterloo', 'adjunct', 'adornment', 'arrangement', 'backing', 'beading', 'beating', 'bibliopegy', 'binder board', 'binding', 'bonus'],
    'trinity': ['clover', 'deuce-ace', 'leash', 'set of three', 'shamrock', 'tercet', 'ternary', 'ternion', 'terzetto', 'three', 'threeness', 'threesome'],
    'trinket': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'agate', 'bagatelle', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble'],
    'trio': ['german band', 'nachtmusik', 'philharmonic', 'absolute music', 'adaptation', 'air varie', 'aleatory', 'aleatory music', 'arrangement', 'band', 'big band', 'bipartisanship'],
    'trip': ['airlift', 'airy nothing', 'allure', 'amble', 'antic', 'apparition', 'army', 'atrocity', 'autism', 'backslide', 'bad job', 'bait the hook'],
    'tripartite': ['deltoid', 'three-cornered', 'three-dimensional', 'three-footed', 'three-pronged', 'three-sided', 'triangular', 'triangulate', 'triarch', 'trichotomous', 'tricorn', 'tricornered'],
    'tripe': ['abatis', 'abdomen', 'anus', 'appendix', 'baloney', 'bilge', 'blah', 'blah-blah', 'blind gut', 'bop', 'bosh', 'bowels'],
    'triple': ['accelerate', 'aggravate', 'beef up', 'blow up', 'complicate', 'concentrate', 'condense', 'consolidate', 'cube', 'deepen', 'deltoid', 'double'],
    'triplet': ['spenserian stanza', 'accidental', 'andante tempo', 'antistrophe', 'beat', 'book', 'breve', 'burden', 'canto', 'chorus', 'clover', 'compound time'],
    'triplex': ['deltoid', 'fan-shaped', 'tern', 'ternal', 'ternary', 'ternate', 'three', 'three-in-one', 'three-ply', 'threefold', 'treble', 'triadic'],
    'triplicate': ['photostat', 'xerox', 'clone', 'copy', 'counterpart', 'cube', 'ditto', 'double', 'dupe', 'duplicate', 'duplication', 'facsimile'],
    'tripper': ['lsd user', 'acidhead', 'addict', 'adventurer', 'alcoholic', 'alpinist', 'astronaut', 'camper', 'chain smoker', 'climber', 'cocaine sniffer', 'cokie'],
    'tripping': ['balanced', 'concinnate', 'concinnous', 'delirium tremens', 'dream', 'easy', 'elegant', 'euphonic', 'euphonical', 'euphonious', 'facile', 'flowing'],
    'triptych': ['domesday book', 'abstract', 'abstraction', 'account book', 'address book', 'adversaria', 'album', 'altarpiece', 'annual', 'appointment calendar', 'appointment schedule', 'blankbook'],
    'triste': ['black', 'bleak', 'dark', 'depressing', 'dismal', 'drear', 'drearisome', 'dreary', 'funebrial', 'funereal', 'gloomy', 'grave'],
    'trite': ['airy', 'asinine', 'automatic', 'back-number', 'banal', 'bathetic', 'beaten', 'bedridden', 'bewhiskered', 'bromidic', 'catchpenny', 'chain'],
    'triton': ['davy', 'davy jones', 'dylan', 'neptune', 'nereid', 'nereus', 'oceanid', 'oceanus', 'poseidon', 'thetis', 'varuna', 'fresh-water nymph'],
    'triumph': ['cadmean victory', 'ko', 'pyrrhic victory', 'accomplishment', 'achievement', 'anniversaries', 'ascendancy', 'attainment', 'be victorious', 'bear the palm', 'beat', 'beat all hollow'],
    'triumphant': ['ascendant', 'assured of success', 'cock-a-hoop', 'coming', 'conquering', 'crowing', 'crowned with success', 'defeating', 'dominant', 'elate', 'elated', 'exultant'],
    'trivet': ['andiron', 'chain', 'clover', 'coal tongs', 'crane', 'crook', 'damper', 'deuce-ace', 'fire hook', 'fire tongs', 'firedog', 'grate'],
    'trivia': ['ace', 'atom', 'bit', 'bric-a-brac', 'chaff', 'chicken feed', 'chickenshit', 'dab', 'details', 'dole', 'dot', 'dram'],
    'trivial': ['mickey', 'ng', 'airy', 'ankle-deep', 'asinine', 'base', 'bickering', 'captious', 'casual', 'catchpenny', 'caviling', 'cheap'],
    'triviality': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'absurdity', 'aimlessness', 'asininity', 'bagatelle', 'baseness', 'battiness', 'bauble'],
    'trivialize': ['beggar', 'belittle', 'decry', 'denigrate', 'deprecate', 'depreciate', 'dismiss', 'disparage', 'lessen', 'make light of', 'minimize', 'misprize'],
    'trochee': ['alexandrine', 'accent', 'accentuation', 'amphibrach', 'amphimacer', 'anacrusis', 'anapest', 'antispast', 'arsis', 'bacchius', 'beat', 'cadence'],
    'troglodyte': ['bronze age man', 'goth', 'hominidae', 'iron age man', 'neanderthal', 'stone age man', 'aboriginal', 'aborigine', 'ancient', 'animal', 'antediluvian', 'anthropoid'],
    'troika': ['bipartisanship', 'clover', 'coaction', 'coadjuvancy', 'coadministration', 'coagency', 'cochairmanship', 'codirectorship', 'collaboration', 'collaborativeness', 'collectivism', 'collusion'],
    'troll': ['argus', 'briareus', 'cerberus', 'charybdis', 'cyclops', 'echidna', 'gorgon', 'harpy', 'hydra', 'loch ness monster', 'medusa', 'minotaur'],
    'trollop': ['jezebel', 'backslider', 'bad egg', 'bad lot', 'bad woman', 'baggage', 'bitch', 'black sheep', 'broad', 'chippy', 'clitoromaniac', 'cocotte'],
    'trombone': ['english horn', 'alpenhorn', 'alphorn', 'althorn', 'alto horn', 'ballad horn', 'baritone', 'bass horn', 'bassoon', 'block flute', 'bombard', 'bourdon'],
    'troop': ['kp', 'age group', 'ambulate', 'armed forces', 'army', 'army group', 'assemblage', 'assembly', 'band', 'battalion', 'battery', 'battle group'],
    'trooper': ['cheka', 'fbi', 'g-man', 'gestapo', 'interpol', 'mp', 'mvd', 'mounties', 'nkvd', 'ogpu', 'rcmp', 'sp'],
    'troops': ['armed force', 'armed service', 'army', 'array', 'career soldiers', 'fighting force', 'fighting machine', 'firepower', 'forces', 'ground forces', 'ground troops', 'hands'],
    'trophy': ['old mug', 'ambition', 'arch', 'award', 'barrow', 'bays', 'boast', 'booty', 'boundary stone', 'brass', 'bust', 'cairn'],
    'tropical': ['aestival', 'blood-hot', 'blood-warm', 'calid', 'equatorial', 'genial', 'hot', 'luke', 'lukewarm', 'mild', 'room-temperature', 'subtropical'],
    'tropics': ['antarctic zone', 'arctic circle', 'arctic zone', 'frigid zones', 'torrid zone', 'tropic of cancer', 'tropic of capricorn', 'variable zones', 'climate', 'clime', 'equator', 'furnace'],
    'tropism': ['a thing for', 'affinity', 'aptitude', 'aptness', 'bent', 'bias', 'cast', 'conatus', 'conduciveness', 'delight', 'diathesis', 'disposition'],
    'tropological': ['allusive', 'constructional', 'constructive', 'definitional', 'descriptive', 'diagnostic', 'exegetic', 'figurative', 'figured', 'flowery', 'hermeneutic', 'interpretational'],
    'troposphere': ['appleton layer', 'cat', 'f layer', 'heaviside-kennelly layer', 'van allen belt', 'aerospace', 'aerosphere', 'air hole', 'air pocket', 'airspace', 'belt', 'bump'],
    'trot': ['alliteration', 'amble', 'amplification', 'assonance', 'bag', 'bat', 'beldam', 'biddy', 'bilingual text', 'bound', 'bring out', 'burst'],
    'trot out': ['affect', 'betoken', 'brandish', 'breathe', 'bring forth', 'bring forward', 'bring into view', 'bring out', 'bring to notice', 'dangle', 'demonstrate', 'develop'],
    'troth': ['adherence', 'adhesion', 'affiance', 'allegiance', 'assurance', 'assure', 'attachment', 'avouch', 'avouchment', 'banns', 'banns of matrimony', 'become engaged'],
    'trots': ['bm', 'bloody flux', 'bowel movement', 'cardialgia', 'catharsis', 'cholera morbus', 'colic', 'constipation', 'costiveness', 'crap', 'defecation', 'dejection'],
    'trotter': ['ambler', 'ankle', 'arch', 'bacon', 'bayonet legs', 'bowlegs', 'butt', 'calf', 'chitterlings', 'clubfoot', 'cnemis', 'cob'],
    'troubadour': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'meistersinger', 'odysseus', 'oisin', 'ossian', 'parnassian', 'ulysses', 'arch-poet'],
    'trouble': ['dutch', 'abuse a privilege', 'ado', 'adverse circumstances', 'adversity', 'afflict', 'affliction', 'aggravate', 'aggravation', 'agitate', 'agitation', 'ail'],
    'troubled': ['abashed', 'afflicted', 'aggravated', 'agitated', 'all-overish', 'angry', 'annoyed', 'anxious', 'anxioused up', 'apprehensive', 'beset', 'bothered'],
    'troublemaker': ['agent provocateur', 'agitator', 'agitprop', 'catalyst', 'demagogue', 'exciter', 'firebrand', 'fomenter', 'gadfly', 'incendiary', 'inciter', 'inflamer'],
    'troublesome': ['herculean', 'adverse', 'aggravating', 'alarming', 'annoying', 'antagonistic', 'arduous', 'awkward', 'backbreaking', 'besetting', 'bothering', 'bothersome'],
    'troubling': ['aggravating', 'agitating', 'annoying', 'bothering', 'bothersome', 'breathtaking', 'charged', 'cliff-hanging', 'disquieting', 'distracting', 'disturbing', 'electric'],
    'troublous': ['adverse', 'agitated', 'anarchic', 'angry', 'antagonistic', 'blustering', 'blusterous', 'blustery', 'chaotic', 'conflicting', 'contrary', 'counter'],
    'trough': ['adit', 'aerospace', 'aerosphere', 'air hole', 'air pocket', 'airspace', 'alveolation', 'alveolus', 'amplitude', 'antinode', 'antrum', 'aqueduct'],
    'trounce': ['assail', 'attack', 'baste', 'bastinado', 'bear the palm', 'beat', 'beat all hollow', 'beat hollow', 'belabor', 'belt', 'best', 'birch'],
    'trouncing': ['waterloo', 'bastinado', 'basting', 'battery', 'beating', 'belting', 'buffeting', 'caning', 'clubbing', 'collapse', 'conquering', 'conquest'],
    'troupe': ['act', 'act as foil', 'acting company', 'age group', 'appear', 'band', 'barnstorm', 'battalion', 'bevy', 'body', 'brigade', 'bunch'],
    'trouper': ['roscius', 'actor', 'actress', 'antagonist', 'artiste', 'bad guy', 'barnstormer', 'character', 'character actor', 'character man', 'character woman', 'child actor'],
    'trove': ['agglomeration', 'aggregation', 'amassment', 'bonus', 'bringing to light', 'buried treasure', 'casual discovery', 'catching', 'chance discovery', 'collection', 'colluvies', 'conglomeration'],
    'truancy': ['awol', 'french leave', 'abscondence', 'absence', 'absence without leave', 'absentation', 'absenteeism', 'absenting', 'clock-watching', 'cut', 'day off', 'default'],
    'truant': ['awol', 'bowery bum', 'absent', 'absent without leave', 'absentee', 'beachcomber', 'beggar', 'beggarly fellow', 'blighter', 'budmash', 'bum', 'bummer'],
    'truce': ['pax dei', 'pax romana', 'peace of god', 'abeyance', 'accord', 'agreement', 'armistice', 'break', 'breather', 'breathing spell', 'buffer zone', 'caesura'],
    'truck': ['dukw', 'esp', 'pullman', 'pullman car', 'answer', 'autotruck', 'baggage car', 'baked goods', 'balance of trade', 'bargain', 'barge', 'barter'],
    'truck farm': ['arable land', 'barnyard', 'barton', 'cattle ranch', 'chicken farm', 'collective farm', 'cotton plantation', 'croft', 'dairy farm', 'demesne', 'demesne farm', 'dry farm'],
    'truck farming': ['agrarianism', 'agricultural geology', 'agriculture', 'agrology', 'agronomics', 'agronomy', 'contour farming', 'cultivation', 'culture', 'dirt farming', 'dry farming', 'dryland farming'],
    'truckage': ['air express', 'airfreight', 'airlift', 'asportation', 'bearing', 'carriage', 'carry', 'carrying', 'cartage', 'conveyance', 'drayage', 'expressage'],
    'trucker': ['aquarius', 'ganymede', 'hebe', 'sunday driver', 'backseat driver', 'bearer', 'bheesty', 'bus driver', 'busboy', 'busman', 'cabby', 'cabdriver'],
    'truckle': ['apple-polish', 'bootlick', 'bow', 'brown-nose', 'butter up', 'cower', 'crawl', 'cringe', 'defer', 'fall all over', 'fawn upon', 'follow'],
    'truckle to': ['bend', 'bend the neck', 'bend to', 'bow', 'bow and scrape', 'bow down', 'bow to', 'cater to', 'cringe to', 'crouch', 'crouch before', 'curtsy'],
    'truckler': ['apple-polisher', 'ass-licker', 'backscratcher', 'backslapper', 'bootlick', 'bootlicker', 'brown-nose', 'brownie', 'clawback', 'courtier', 'creature', 'cringer'],
    'truckling': ['abject', 'apple-polishing', 'ass-kissing', 'backscratching', 'beggarly', 'bootlicking', 'brown-nosing', 'cowering', 'crawling', 'cringing', 'crouching', 'fawnery'],
    'truckman': ['jehu', 'sunday driver', 'backseat driver', 'bullwhacker', 'bus driver', 'busman', 'cabby', 'cabdriver', 'cabman', 'cameleer', 'carter', 'cartman'],
    'truculence': ['abruptness', 'aggression', 'aggressiveness', 'animality', 'antagonism', 'atrociousness', 'barbarity', 'barbarousness', 'bearishness', 'beastliness', 'bellicism', 'bellicosity'],
    'truculent': ['draconian', 'tartarean', 'abrupt', 'aggressive', 'animal', 'antagonistic', 'anthropophagous', 'atrocious', 'bad-tempered', 'barbaric', 'barbarous', 'battling'],
    'trudge': ['airing', 'amble', 'andante', 'barge', 'bowl along', 'bundle', 'chug on', 'claudication', 'clump', 'constitutional', 'crawl', 'creep'],
    'trudging': ['ambling', 'ambulation', 'backpacking', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'deliberate', 'easy', 'faltering'],
    'true': ['christian', 'absolute', 'acceptable', 'accepted', 'accommodate', 'accord', 'accurate', 'accurately', 'active', 'actual', 'adapt', 'adjust'],
    'true blue': ['christian', 'accepted', 'acknowledged', 'adherence', 'adhesion', 'admitted', 'allegiance', 'approved', 'attachment', 'authentic', 'authoritative', 'bona fides'],
    'true to form': ['appropriate', 'characteristic', 'distinctive', 'distinguished', 'distinguishing', 'exemplary', 'idiocratic', 'idiosyncratic', 'in character', 'intrinsic', 'marked', 'natural'],
    'true to life': ['authentic', 'bona fide', 'breathing', 'candid', 'card-carrying', 'delineative', 'depictive', 'descriptive', 'dinkum', 'expositive', 'expressive', 'faithful'],
    'truism': ['a priori truth', 'abstraction', 'aphorism', 'apothegm', 'axiom', 'banality', 'brocard', 'bromide', 'cliche', 'commonplace', 'dictate', 'dictum'],
    'truly': ['ok', 'roger', 'absolutely', 'accurately', 'actually', 'all right', 'alright', 'alrighty', 'amen', 'and no mistake', 'as you say', 'assuredly'],
    'trump': ['ace', 'action', 'ad hoc measure', 'answer', 'artifice', 'beat', 'best', 'best bower', 'better', 'bower', 'brick', 'cap'],
    'trumped up': ['concocted', 'cooked-up', 'fabricated', 'fabulous', 'fancied', 'fantasied', 'fantastic', 'fictional', 'fictitious', 'figmental', 'forged', 'hatched'],
    'trumpery': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'base', 'bibble-babble', 'bilge', 'blabber', 'blather', 'bombast', 'bravery'],
    'trumpet': ['english horn', 'adulate', 'advertise', 'air', 'alpenhorn', 'alphorn', 'althorn', 'alto horn', 'apotheosize', 'bagpipe', 'ballad horn', 'ballyhoo'],
    'truncate': ['abbreviate', 'abridge', 'abscind', 'abstract', 'amputate', 'annihilate', 'ban', 'bar', 'blemish', 'bob', 'boil down', 'capsulize'],
    'truncated': ['spartan', 'abbreviated', 'abridged', 'aposiopestic', 'bandy', 'bandy-legged', 'blemished', 'bloated', 'bowlegged', 'brief', 'brusque', 'butchered'],
    'trundle': ['advance', 'bowl', 'bunt', 'butt', 'drive', 'forward', 'furl', 'impel', 'move', 'pedal', 'pole', 'propel'],
    'trunk': ['wats', 'wats line', 'anatomy', 'anthrophore', 'antlia', 'axis', 'baluster', 'balustrade', 'banister', 'barrel', 'base', 'beak'],
    'trunk line': ['wats', 'wats line', 'branch', 'cable', 'cable railway', 'co-ax', 'coaxial cable', 'cog railway', 'concentric cable', 'el', 'electric railway', 'elevated'],
    'truss': ['bale', 'band', 'bandage', 'belt', 'bend', 'bind', 'bind up', 'bindle', 'bolt', 'bouquet', 'brace', 'budget'],
    'trust': ['aktiengesellschaft', 'absolute interest', 'accept', 'accept for gospel', 'accept implicitly', 'acceptation', 'acception', 'acquiescence', 'agency', 'agentship', 'aktiebolag', 'arrogance'],
    'trust company': ['bank of england', 'bank of france', 'federal reserve bank', 'international monetary fund', 'lombard street bank', 'swiss bank', 'world bank', 'bank', 'branch bank', 'central bank', 'clearing house', 'commercial bank'],
    'trustee': ['accepter', 'accountant', 'acquirer', 'addressee', 'audience', 'auditor', 'beholder', 'bookkeeper', 'bursar', 'cashier', 'cashkeeper', 'chamberlain'],
    'trusteeship': ['agency', 'agentship', 'assignment', 'authority', 'authorization', 'brevet', 'care', 'charge', 'commission', 'commissioning', 'commitment', 'consignment'],
    'truster': ['christian', 'god-fearing man', 'accepter', 'believer', 'catechumen', 'churchgoer', 'churchite', 'churchman', 'communicant', 'convert', 'daily communicant', 'devotee'],
    'trusting': ['artless', 'bluff', 'blunt', 'born yesterday', 'candid', 'childlike', 'confident', 'confiding', 'credulous', 'dependent', 'depending', 'direct'],
    'trusting soul': ['babe', 'boob', 'chump', 'cinch', 'credulous person', 'cull', 'dupe', 'easy mark', 'easy pickings', 'fall guy', 'fish', 'fool'],
    'trustworthy': ['accurate', 'authoritative', 'believable', 'calculable', 'colorable', 'conceivable', 'convincing', 'credible', 'dependable', 'ethical', 'exact', 'fail-safe'],
    'trusty': ['pow', 'believable', 'cageling', 'calculable', 'captive', 'chain gang', 'childlike', 'colorable', 'con', 'conceivable', 'confiding', 'convict'],
    'truth': ['a priori truth', 'absolute certainty', 'absolute credibility', 'absoluteness', 'accomplished fact', 'accuracy', 'actuality', 'actually', 'assurance', 'assuredness', 'authenticity', 'axiom'],
    'truthful': ['accurate', 'actual', 'ascertained', 'attested', 'authenticated', 'candid', 'categorically true', 'certain', 'certified', 'confirmed', 'corroborated', 'demonstrated'],
    'try': ['acid test', 'agonize', 'aim', 'annoy', 'appraise', 'approach', 'arbitrate', 'aspire', 'assay', 'attempt', 'bear hard upon', 'bid'],
    'try out': ['arrange', 'assay', 'be a gas', 'be a hit', 'bill', 'bomb', 'bring to test', 'clear for action', 'clear the decks', 'confirm', 'cure', 'cut and try'],
    'trying': ['adverse', 'analytic', 'annoying', 'antagonistic', 'arduous', 'backbreaking', 'besetting', 'bothersome', 'burdensome', 'conflicting', 'contrary', 'counter'],
    'tryout': ['gedankenexperiment', 'arrangement', 'attention', 'audience', 'audition', 'basic training', 'bench test', 'benefit', 'bill', 'briefing', 'bugging', 'clearing the decks'],
    'tsunami': ['apoplexy', 'billow', 'bore', 'breakers', 'breakup', 'cataclysm', 'chop', 'choppiness', 'chopping sea', 'climax', 'comb', 'comber'],
    'tub': ['finnish bath', 'japanese bath', 'russian bath', 'swedish bath', 'turkish bath', 'aquamanile', 'argosy', 'auto', 'autocar', 'automatic dishwasher', 'automobile', 'baptize'],
    'tub thumper': ['debater', 'declaimer', 'demagogue', 'haranguer', 'jawsmith', 'panelist', 'public speaker', 'rabble-rouser', 'ranter', 'speaker', 'speecher', 'speechifier'],
    'tuba': ['alpenhorn', 'alphorn', 'althorn', 'alto horn', 'ballad horn', 'baritone', 'bass horn', 'brass choir', 'brass wind', 'brass-wind instrument', 'brasses', 'bugle'],
    'tubby': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blocky', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky'],
    'tube': ['amtrak', 'photronic cell', 'adjutage', 'amplifier', 'anode', 'attenuator', 'audio-frequency tube', 'baggage train', 'ballast regulator', 'ballast tube', 'barrel', 'base'],
    'tubercle': ['abscess', 'aposteme', 'bed sore', 'bilge', 'blain', 'bleb', 'blister', 'blob', 'boil', 'boss', 'bow', 'bubble'],
    'tubercular': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bilious', 'burled', 'cancerous', 'chlorotic', 'colicky', 'consumptive', 'dropsical', 'dyspeptic'],
    'tuberculosis': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'tb', 'acute articular rheumatism', 'aerogenic tuberculosis', 'ague', 'alkali disease', 'ambulatory plague', 'amebiasis'],
    'tuberosity': ['bas-relief', 'bellying', 'boldness', 'bulging', 'camber', 'convexedness', 'convexity', 'convexness', 'embossment', 'eminence', 'excrescence', 'excrescency'],
    'tuberous': ['botanic', 'bulbous', 'burled', 'cereal', 'farinaceous', 'fruitlike', 'fruity', 'gnarled', 'gnarly', 'herbaceous', 'herbal', 'herbose'],
    'tubing': ['adjutage', 'catheter', 'drainpipe', 'efflux tube', 'fire hose', 'flue pipe', 'funnel', 'garden hose', 'gas pipe', 'hose', 'hosepipe', 'nipple'],
    'tuck': ['birr', 'bread', 'chow', 'crease', 'creasing', 'crimp', 'crisp', 'dog-ear', 'double', 'double over', 'doubling', 'duplicature'],
    'tuck in': ['bed', 'consume', 'cradle', 'devour', 'dispatch', 'dispose of', 'down', 'ease in', 'eat up', 'get away with', 'get down', 'infuse'],
    'tucked': ['creased', 'crimped', 'dog-eared', 'doubled', 'flexible', 'flounced', 'fluted', 'foldable', 'folded', 'folding', 'gathered', 'plaited'],
    'tucker': ['c ration', 'k ration', 'allotment', 'allowance', 'apron', 'beat', 'bib', 'board', 'bread', 'bread and butter', 'bugger', 'burn out'],
    'tuckered out': ['all in', 'beat', 'beat up', 'beaten', 'bone-weary', 'bushed', 'dead', 'dead-and-alive', 'dead-tired', 'deadbeat', 'dog-tired', 'dog-weary'],
    'tuft': ['vandyke', 'bang', 'bangs', 'batch', 'beard', 'beaver', 'bristles', 'bunch', 'clump', 'cluster', 'copse', 'crest'],
    'tug': ['adduct', 'adduction', 'affinity', 'allurement', 'attract', 'attractance', 'attraction', 'attractiveness', 'attractivity', 'back band', 'backstrap', 'battle'],
    'tug-of-war': ['action', 'aerial combat', 'affray', 'armored combat', 'attraction', 'battle', 'battle royal', 'brush', 'bullfight', 'clash', 'clash of arms', 'cockfight'],
    'tuition': ['catechization', 'coaching', 'didactics', 'direction', 'edification', 'education', 'enlightenment', 'guidance', 'illumination', 'information', 'instruction', 'pedagogics'],
    'tumble': ['alight upon', 'apprehend', 'arsy-varsiness', 'ball up', 'bite the dust', 'blow down', 'blow over', 'blunder', 'blunder upon', 'blur', 'blur distinctions', 'bollix up'],
    'tumbledown': ['battered', 'beat-up', 'beaten up', 'broken-down', 'collapsing', 'crumbling', 'deciduous', 'declining', 'declivitous', 'decrepit', 'decurrent', 'derelict'],
    'tumbler': ['acrobat', 'aerialist', 'bareback rider', 'circus artist', 'clown', 'contortionist', 'equestrian director', 'equilibrist', 'flier', 'funambulist', 'gymnast', 'high wire artist'],
    'tumescence': ['access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'aggrandizement', 'amplification', 'appreciation', 'ascent'],
    'tumid': ['aureate', 'bellied', 'bloated', 'blown up', 'bombastic', 'bug-eyed', 'bulged', 'dilated', 'distended', 'dropsical', 'edematous', 'enchymatous'],
    'tummy': ['abdomen', 'abomasum', 'bay window', 'beerbelly', 'belly', 'breadbasket', 'craw', 'crop', 'diaphragm', 'embonpoint', 'first stomach', 'gizzard'],
    'tumor': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'benign tumor'],
    'tumorous': ['allergic', 'anemic', 'apoplectic', 'arthritic', 'bellied', 'bilious', 'bug-eyed', 'bulged', 'cancerous', 'chlorotic', 'colicky', 'consumptive'],
    'tumult': ['bedlam let loose', 'ado', 'affray', 'agitation', 'bedlam', 'blast', 'bluster', 'bobbery', 'boil', 'boiling', 'bother', 'botheration'],
    'tumultuous': ['agitated', 'anarchic', 'angry', 'blaring', 'blatant', 'blatting', 'blustering', 'blusterous', 'blustery', 'boisterous', 'brassy', 'brawling'],
    'tundra': ['alaska', 'antarctic zone', 'antarctica', 'arctic circle', 'arctic zone', 'frigid zones', 'greenland', 'iceland', 'lower slobbovia', 'north pole', 'novaya zemlya', 'siberia'],
    'tune': ['french pitch', 'accommodate', 'accord', 'accordance', 'adapt', 'adjust', 'adjust to', 'agreement', 'air', 'align', 'aria', 'assimilate'],
    'tune down': ['abate', 'abridge', 'allay', 'alleviate', 'assuage', 'attemper', 'bank the fire', 'blunt', 'chasten', 'compress', 'constrain', 'control'],
    'tuned': ['accordant', 'according', 'assonant', 'assonantal', 'attuned', 'blended', 'blending', 'chiming', 'concordant', 'consonant', 'harmonic', 'harmonious'],
    'tuneful': ['achingly sweet', 'agreeable', 'agreeable-sounding', 'appealing', 'ariose', 'arioso', 'canorous', 'cantabile', 'catchy', 'dulcet', 'euphonic', 'euphonious'],
    'tuneless': ['absonant', 'atonal', 'cacophonous', 'cracked', 'diaphonic', 'disconsonant', 'discordant', 'disharmonic', 'disharmonious', 'dissonant', 'flat', 'grating'],
    'tunnel': ['abri', 'access', 'adit', 'aisle', 'alley', 'ambulatory', 'antre', 'aperture', 'approach trench', 'arcade', 'artery', 'avenue'],
    'tuppence': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'bagatelle', 'bauble', 'bawbee', 'bean', 'bibelot', 'bit', 'brass farthing'],
    'turbid': ['adiaphanous', 'amiss', 'askew', 'awry', 'cloudy', 'cockeyed', 'convulsed', 'dark', 'deranged', 'dirty', 'disarranged', 'discomfited'],
    'turbidity': ['adiaphanousness', 'agitation', 'bluster', 'bobbery', 'boil', 'boiling', 'brouhaha', 'bustle', 'churn', 'cloudiness', 'commotion', 'conturbation'],
    'turbulence': ['cat', 'ado', 'aerospace', 'aerosphere', 'agitation', 'air flow', 'air hole', 'air pocket', 'airspace', 'asperity', 'babel', 'bluster'],
    'turbulent': ['agitated', 'amiss', 'anarchic', 'angry', 'askew', 'awry', 'blaring', 'blatant', 'blatting', 'blustering', 'blusterous', 'blustery'],
    'turd': ['bm', 'sob', 'bastard', 'bowel movement', 'buffalo chips', 'bugger', 'ca-ca', 'coprolite', 'coprolith', 'cow chips', 'cow flops', 'cow pats'],
    'turf': ['alcohol', 'ambit', 'archery ground', 'area', 'athletic field', 'backyard', 'badminton court', 'bailiwick', 'banish', 'baseball field', 'basketball court', 'benzine'],
    'turgid': ['latinate', 'aureate', 'awkward', 'bellied', 'bloated', 'blown up', 'bombastic', 'bug-eyed', 'bulged', 'cramped', 'cumbrous', 'dilated'],
    'turkey': ['bantam', 'cornish hen', 'banty', 'barn-door fowl', 'barnyard fowl', 'biddy', 'bomb', 'broiler', 'brooder', 'broody hen', 'bust', 'caille'],
    'turkish bath': ['finnish bath', 'japanese bath', 'russian bath', 'swedish bath', 'bath', 'bathe', 'cold shower', 'douche', 'hip bath', 'hummum', 'needle bath', 'plunge bath'],
    'turmoil': ['ado', 'agitation', 'ailment', 'anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism', 'anxiety', 'anxiousness', 'arsy-varsiness', 'bluster', 'bobbery'],
    'turn': ['charybdis', 'platonic form', 'platonic idea', 's-curve', 'a thing for', 'aberrancy', 'aberration', 'about ship', 'about-face', 'access', 'acciaccatura', 'accommodation'],
    'turn about': ['alternately', 'au pair', 'break back', 'by turns', 'change back', 'come about', 'consecutively', 'convert', 'cry back', 'do a flip-flop', 'do an about-face', 'even'],
    'turn around': ['break back', 'change back', 'circle', 'circulate', 'circumrotate', 'circumvolute', 'come about', 'convert', 'crank', 'cry back', 'do a flip-flop', 'do an about-face'],
    'turn aside': ['alter', 'ameliorate', 'anticipate', 'avert', 'avoid', 'bar', 'be changed', 'be converted into', 'be renewed', 'bear off', 'beat off', 'bend'],
    'turn away': ['abjure', 'avert', 'bear off', 'blunt', 'bow out', 'brush aside', 'bundle', 'bundle off', 'chill', 'chuck', 'chuck out', 'contemn'],
    'turn away from': ['abandon', 'avert the eyes', 'avoid', 'brush aside', 'brush off', 'cold-shoulder', 'dismiss', 'drop the subject', 'fight shy of', 'forget', 'forget about it', 'forget it'],
    'turn back': ['about ship', 'assimilate to', 'avert', 'back and fill', 'bear away', 'bear off', 'bear to starboard', 'beat', 'beat about', 'beat back', 'become', 'box off'],
    'turn down': ['be unmoved', 'be unwilling', 'beg off', 'convert', 'decline', 'decline to accept', 'disagree', 'disallow', 'disapprove', 'disclaim', 'dismiss', 'dissent'],
    'turn in': ['bed', 'betray', 'convert', 'crash', 'crawl in', 'doss down', 'double-cross', 'evert', 'flop', 'hit the hay', 'hit the sack', 'inform on'],
    'turn inside out': ['comb', 'convert', 'evert', 'introvert', 'intussuscept', 'invaginate', 'inverse', 'invert', 'look all over', 'look everywhere', 'pronate', 'rake'],
    'turn into': ['english', 'alter', 'alter into', 'ameliorate', 'assimilate to', 'be changed', 'be converted into', 'be renewed', 'become', 'bottom out', 'break', 'bring to'],
    'turn off': ['amplify', 'ax', 'blunt', 'boot', 'boot out', 'bounce', 'bow out', 'break', 'bump', 'bundle', 'bundle off', 'bust'],
    'turn on': ['accrue from', 'amplify', 'annoy', 'arise from', 'arouse', 'awake', 'awaken', 'be based on', 'be contingent on', 'be dependent on', 'be due to', 'be predicated on'],
    'turn out': ['abjure', 'accouter', 'appoint', 'arise', 'arm', 'attain fulfillment', 'attend', 'be so', 'be such', 'bear', 'become of', 'boot'],
    'turn over': ['abalienate', 'alien', 'alienate', 'amortize', 'assign', 'barter', 'be lost', 'bequeath', 'break', 'brood over', 'capsize', 'careen'],
    'turn red': ['blanch', 'blush', 'change color', 'color', 'color up', 'crimson', 'darken', 'flame', 'flush', 'glow', 'grow red', 'look black'],
    'turn tail': ['abscond', 'absquatulate', 'beat a retreat', 'bolt', 'clear out', 'come about', 'cut and run', 'decamp', 'depart', 'desert', 'elope', 'fetch about'],
    'turn the corner': ['alter', 'ameliorate', 'be changed', 'be converted into', 'be renewed', 'bottom out', 'brace up', 'break', 'change', 'checker', 'chop', 'chop and change'],
    'turn the tables': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'be listened to', 'be recognized', 'better', 'break up', 'change', 'change the preponderance', 'come back at'],
    'turn the trick': ['accomplish', 'achieve', 'attain', 'bring off', 'bring through', 'carry off', 'compass', 'consummate', 'crown with success', 'deal with', 'discharge', 'dispatch'],
    'turn to': ['accept', 'advert to', 'alter into', 'assume', 'attack', 'attempt', 'attend to', 'be aware of', 'be converted into', 'be engrossed in', 'become', 'begin'],
    'turn up': ['abandon', 'accomplish', 'achieve', 'appear', 'appear unexpectedly', 'approach', 'arise', 'arrive', 'arrive at', 'arrive in', 'assister', 'attain'],
    'turn upside down': ['accommodate', 'adapt', 'adjust', 'alter', 'ameliorate', 'better', 'break up', 'capsize', 'careen', 'change', 'comb', 'convert'],
    'turnabout': ['about-face', 'about-turn', 'accommodation', 'adaptation', 'adjustment', 'afterthoughts', 'alteration', 'amelioration', 'apostasy', 'apostate', 'back track', 'back trail'],
    'turnaround': ['about-face', 'about-turn', 'afterthoughts', 'back track', 'back trail', 'backing', 'backing off', 'backing out', 'backing up', 'backup', 'better thoughts', 'change of mind'],
    'turncoat': ['benedict arnold', 'brutus', 'judas', 'judas iscariot', 'judas-like', 'quisling', 'trojan-horse', 'vicar of bray', 'apostate', 'archtraitor', 'backslider', 'betrayer'],
    'turndown': ['abnegation', 'contradiction', 'declension', 'declination', 'declinature', 'declining', 'denial', 'deprivation', 'disagreement', 'disallowance', 'disclaimer', 'disclamation'],
    'turned around': ['abashed', 'abroad', 'adrift', 'astray', 'at sea', 'back', 'backward', 'backwards', 'bewildered', 'bothered', 'bottom side up', 'bottom up'],
    'turned off': ['against', 'apathetic', 'ataractic', 'blase', 'careless', 'casual', 'con', 'disapprobatory', 'disapproving', 'discontented', 'disenchanted', 'disgruntled'],
    'turned on': ['agog', 'ape about', 'aquiver', 'aroused', 'atingle', 'attracted', 'atwitter', 'bugs on', 'bursting', 'carried away', 'cathectic', 'concerned'],
    'turned up': ['blocky', 'chubby', 'chunky', 'dumpy', 'fat', 'podgy', 'pudgy', 'pug', 'pugged', 'retrousse', 'snub-nosed', 'squat'],
    'turning': ['s-curve', 'aberrancy', 'aberrant', 'aberration', 'aberrative', 'about-face', 'ambages', 'ambagious', 'anfractuosity', 'anfractuous', 'angle', 'angular momentum'],
    'turning point': ['bench mark', 'cardinal point', 'chief thing', 'climacteric', 'climax', 'clutch', 'contingency', 'convergence of events', 'core', 'cornerstone', 'crisis', 'critical juncture'],
    'turnout': ['gnp', 'accouterments', 'apparatus', 'apparel', 'assemblage', 'assemblee', 'assembly', 'assignation', 'at home', 'attendance', 'audience', 'ball'],
    'turnover': ['danish pastry', 'french pastry', 'baklava', 'bill of sale', 'blintz', 'capsizal', 'capsize', 'chocolate eclair', 'cream puff', 'culbute', 'demand', 'dowdy'],
    'turnpike': ['autobahn', 'french door', 'us highway', 'alley', 'alleyway', 'archway', 'arterial', 'arterial highway', 'arterial street', 'artery', 'autoroute', 'autostrada'],
    'turnstile': ['french door', 'archway', 'back door', 'barway', 'bulkhead', 'carriage entrance', 'cellar door', 'cellarway', 'door', 'doorjamb', 'doorpost', 'doorway'],
    'turntable': ['gramophone', 'pa', 'pa system', 'victrola', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer'],
    'turntail': ['apostate', 'backslider', 'bolter', 'collaborationist', 'collaborator', 'convert', 'defector', 'deserter', 'fifth columnist', 'mugwump', 'proselyte', 'quisling'],
    'turpentine': ['chromogen', 'coat', 'coat of paint', 'coating', 'color', 'color filter', 'color gelatin', 'colorant', 'coloring', 'dead-color', 'distemper', 'drier'],
    'turpitude': ['abandon', 'abandonment', 'abjection', 'baseness', 'chicanery', 'corruptedness', 'corruption', 'corruptness', 'debasement', 'decadence', 'decadency', 'degeneracy'],
    'turret': ['antenna tower', 'barbican', 'belfry', 'bell tower', 'campanile', 'colossus', 'column', 'cupola', 'derrick', 'dome', 'fire tower', 'lantern'],
    'turtlelike': ['ambling', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'deliberate', 'easy', 'faltering', 'flagging', 'foot-dragging'],
    'tush': ['arse', 'ass', 'baby tooth', 'bicuspid', 'bucktooth', 'bum', 'can', 'canine', 'cheeks', 'crown', 'cuspid', 'cutter'],
    'tusk': ['baby tooth', 'bicuspid', 'bucktooth', 'canine', 'crown', 'cuspid', 'cutter', 'deciduous tooth', 'dent', 'denticle', 'denticulation', 'dentil'],
    'tussle': ['action', 'aerial combat', 'affray', 'agonize', 'altercation', 'argument', 'armored combat', 'battle', 'battle royal', 'bicker', 'blood feud', 'box'],
    'tutelage': ['abetment', 'administration', 'advocacy', 'aegis', 'auspices', 'backing', 'care', 'catechization', 'chair', 'chair of english', 'championship', 'charge'],
    'tutelary': ['ancestral spirits', 'angel', 'attendant godling', 'control', 'covering', 'custodial', 'daemon', 'defensive', 'demon', 'fairy godmother', 'familiar', 'familiar spirit'],
    'tutor': ['privatdocent', 'privatdozent', 'advise', 'assistant', 'assistant professor', 'associate', 'associate professor', 'coach', 'coacher', 'cram', 'cram with facts', 'crammer'],
    'tutorial': ['academic', 'donnish', 'pedagogic', 'pedantic', 'preceptorial', 'professorial', 'professorlike', 'schoolmastering', 'schoolmasterish', 'schoolmasterlike', 'schoolmasterly', 'schoolmistressy'],
    'tutorship': ['catechization', 'chair', 'chair of english', 'coaching', 'didactics', 'direction', 'edification', 'education', 'enlightenment', 'fellowship', 'guidance', 'illumination'],
    'tutti frutti': ['jell-o', 'blancmange', 'candy', 'comfit', 'compote', 'confection', 'confectionery', 'confiture', 'conserve', 'frosting', 'gelatin', 'glaze'],
    'tv dinner': ['alfresco meal', 'barbecue', 'breakfast', 'brunch', 'buffet supper', 'clambake', 'coffee break', 'cookout', 'diner', 'dinner', 'elevenses', 'fish fry'],
    'twaddle': ['absurdity', 'amphigory', 'babble', 'babblement', 'balderdash', 'bavardage', 'bibble-babble', 'blab', 'blabber', 'blah-blah', 'blather', 'blether'],
    'twang': ['accent', 'aphonia', 'artificial voice', 'bark', 'bawl', 'belch', 'bellow', 'blare', 'blat', 'blubber', 'boom', 'bray'],
    'twangy': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'blurred', 'breathy'],
    'tweak': ['acute pain', 'afflict', 'agonize', 'ail', 'bite', 'bob', 'boring pain', 'burn', 'chafe', 'charley horse', 'clamp', 'clamping'],
    'tweedle': ['anthem', 'bagpipe', 'ballad', 'bay', 'beep', 'bell', 'blare', 'blast', 'blat', 'blow', 'blow a horn', 'blow the horn'],
    'tweedledum and tweedledee': ['castor and pollux', 'gemini', 'siamese twins', 'twin stars', 'dead heat', 'deadlock', 'draw', 'even break', 'exact mates', 'fair shake', 'fraternal twins', 'identical twins'],
    'tweet': ['cackle', 'call', 'carol', 'caw', 'chatter', 'cheep', 'chip', 'chipper', 'chirk', 'chirm', 'chirp', 'chirr'],
    'tweeter': ['acoustical network', 'capacitor speaker', 'coaxial speaker', 'cone', 'crossover network', 'diaphragm', 'dynamic speaker', 'earphone', 'electrodynamic speaker', 'electromagnetic speaker', 'electrostatic speaker', 'excited-field speaker'],
    'twentieth century': ['a la mode', 'advanced', 'avant-garde', 'contemporary', 'far out', 'fashionable', 'forward-looking', 'in', 'mod', 'modern', 'modernistic', 'modernized'],
    'twice told': ['cliche', 'cliched', 'doubled', 'duplicated', 'echoed', 'hackneyed', 'old hat', 'plagiarized', 'quoted', 'rechauffe', 'redoubled', 'reduplicated'],
    'twice told tale': ['joe miller', 'banality', 'bromide', 'chestnut', 'cliche', 'commonplace', 'commonplace expression', 'corn', 'familiar tune', 'hackneyed saying', 'joke with whiskers', 'lieu commun'],
    'twiddle': ['babble', 'cackle', 'chat', 'chatter', 'come in contact', 'coquet', 'dabble', 'dally', 'do nothing', 'feel', 'feel of', 'fiddle'],
    'twig': ['accept', 'appendage', 'arm', 'bine', 'bough', 'branch', 'branchedness', 'branchiness', 'burgeon', 'catch', 'catch on', 'comprehend'],
    'twiggy': ['attenuate', 'barebones', 'bean pole', 'beanstalk', 'bony', 'bowery', 'branched', 'branching', 'branchy', 'broomstick', 'clothes pole', 'corpse'],
    'twilight': ['afterglow', 'alpenglow', 'aurora', 'bad light', 'brown of dusk', 'brownness', 'candlelight', 'candlelighting', 'cocklight', 'crepuscular', 'crepuscule', 'dark'],
    'twill': ['braid', 'crease', 'crimp', 'crisp', 'dog-ear', 'double', 'double over', 'enfold', 'enlace', 'entwine', 'flounce', 'flute'],
    'twin': ['doppelganger', 'janus-like', 'accessory', 'accompanying', 'actual thing', 'alike', 'all one', 'all the same', 'ally', 'alter ego', 'ambidextrous', 'analogon'],
    'twine': ['band', 'begird', 'belt', 'belt in', 'braid', 'brail', 'cable', 'cincture', 'circle', 'coil', 'contort', 'cord'],
    'twinge': ['ache', 'acute pain', 'agonize', 'ail', 'anguish', 'bite', 'blanch', 'blench', 'boring pain', 'charley horse', 'cramp', 'cramps'],
    'twinkle': ['bat', 'blink', 'blinking', 'breath', 'coruscate', 'coruscating', 'coruscation', 'coup', 'crack', 'dance', 'dancing', 'dazzle'],
    'twinkling': ['blink', 'blinking', 'blinky', 'breath', 'coruscant', 'coruscating', 'coruscation', 'coup', 'crack', 'firefly', 'flash', 'glimmer'],
    'twirl': ['charybdis', 'maelstrom', 'back stream', 'backflow', 'backwash', 'backwater', 'centrifugate', 'centrifuge', 'cirrus', 'coil', 'contort', 'convolution'],
    'twist': ['a thing for', 'aberrancy', 'aberration', 'action', 'adulterate', 'affinity', 'afflict', 'agonize', 'ail', 'alloy', 'alter', 'alteration'],
    'twisted': ['byzantine', 'abnormal', 'affected', 'afflicted', 'agonized', 'anamorphous', 'anomalous', 'antiblack', 'apocryphal', 'artificial', 'askew', 'assumed'],
    'twister': ['apple fritter', 'baguio', 'beignet', 'beignet aux pommes', 'bismarck', 'cheat', 'con man', 'confidence man', 'crook', 'cruller', 'cyclone', 'deceiver'],
    'twisting': ['aberrant', 'aberrative', 'abstractionism', 'abuse of terms', 'ambages', 'ambagious', 'anfractuosity', 'anfractuous', 'bending', 'braiding', 'catachresis', 'circuitous'],
    'twisty': ['ambagious', 'anfractuous', 'bendy', 'chevronwise', 'chevrony', 'circuitous', 'circumlocutory', 'convolutional', 'crankled', 'crooked', 'curvy', 'flexuose'],
    'twit': ['parthian shot', 'accuse', 'allege', 'anthem', 'arraign', 'article', 'ass', 'back answer', 'badinage', 'ballad', 'banter', 'barrack'],
    'twitch': ['ache', 'acute pain', 'agonize', 'ail', 'anguish', 'bite', 'blanch', 'blench', 'bob', 'bobble', 'boring pain', 'bounce'],
    'twitching': ['abstraction', 'abulia', 'agitation', 'alienation', 'anxiety', 'anxiety equivalent', 'anxiety state', 'apathy', 'apprehensiveness', 'attack of nerves', 'buck fever', 'case of nerves'],
    'twitchy': ['agitated', 'all shook up', 'all-overish', 'convulsive', 'eclamptic', 'fidgeting', 'fidgety', 'fitful', 'fluttery', 'in a quiver', 'jerking', 'jerky'],
    'twitter': ['ado', 'agitation', 'anthem', 'babble', 'ballad', 'banterer', 'bluster', 'bob', 'bobbery', 'bobble', 'boil', 'boiling'],
    'twitting': ['banter', 'bantering', 'booing', 'catcalling', 'chaffing', 'derision', 'derisive', 'derisory', 'fleering', 'flippancy', 'flippant', 'fooling'],
    'two': ['biform', 'bifurcated', 'bilateral', 'bipartisan', 'bipartite', 'both', 'brace', 'couple', 'couplet', 'dichotomous', 'distich', 'double'],
    'two bits': ['c-note', 'g-note', 'buck', 'cartwheel', 'cent', 'century', 'copper', 'dime', 'dollar', 'dollar bill', 'farthing', 'fifty cents'],
    'two faced': ['janus-like', 'machiavellian', 'ambidextrous', 'artful', 'bifacial', 'bifold', 'biform', 'bilateral', 'binary', 'binate', 'biparous', 'bivalent'],
    'two ply': ['janus-like', 'ambidextrous', 'bifacial', 'bifold', 'biform', 'bilateral', 'binary', 'binate', 'biparous', 'bivalent', 'conduplicate', 'disomatous'],
    'two shakes': ['a breath', 'bit', 'breath', 'coup', 'crack', 'flash', 'half a jiffy', 'half a mo', 'half a second', 'half a shake', 'instant', 'jiff'],
    'two sided': ['janus-like', 'ambidextrous', 'bifacial', 'bifold', 'biform', 'bifurcated', 'bilateral', 'binary', 'binate', 'biparous', 'bipartisan', 'bipartite'],
    'two time': ['bamboozle', 'beguile', 'betray', 'bluff', 'cajole', 'cheat on', 'circumvent', 'conjure', 'deceive', 'delude', 'diddle', 'double-cross'],
    'two timer': ['judas', 'betrayer', 'blackleg', 'cheat', 'cheater', 'chiseler', 'convict', 'cozener', 'criminal', 'crook', 'deceiver', 'defrauder'],
    'twofold': ['janus-like', 'ambidextrous', 'as much again', 'bifacial', 'bifold', 'biform', 'bilateral', 'binary', 'binate', 'biparous', 'bivalent', 'conduplicate'],
    'twopenny': ['beggarly', 'beneath contempt', 'cheap', 'cheesy', 'common', 'contemptible', 'crummy', 'despicable', 'gaudy', 'gimcracky', 'mean', 'meretricious'],
    'twosome': ['both', 'bout', 'brace', 'contest', 'couple', 'couplet', 'decathlon', 'distich', 'double harness', 'double-header', 'doubles', 'doublet'],
    'tycoon': ['dalai lama', 'establishment', 'holy roman emperor', 'inca', 'kaiser', 'vip', 'ardri', 'banker', 'baron', 'bey', 'big boss', 'big businessman'],
    'tympanum': ['eustachian tube', 'allantoic membrane', 'amnion', 'amniotic sac', 'anvil', 'arachnoid membrane', 'auditory apparatus', 'auditory canal', 'auditory meatus', 'auditory nerve', 'auditory ossicles', 'auditory tube'],
    'type': ['platonic form', 'platonic idea', 'adumbration', 'aesthetic form', 'affinity', 'alien', 'allegory', 'alphabetize', 'analyze', 'animus', 'antetype', 'antitype'],
    'typeface': ['ascender', 'back', 'bastard type', 'beard', 'belly', 'bevel', 'black letter', 'body', 'cap', 'capital', 'case', 'counter'],
    'typescript': ['article', 'autograph', 'brainchild', 'composed matter', 'composition', 'computer printout', 'copy', 'dead matter', 'document', 'draft', 'edited version', 'engrossment'],
    'typesetting machine': ['composaline', 'diatype', 'elrod', 'fotomatic', 'fotosetter', 'fototronic', 'intertype', 'linotype', 'monotype', 'photon', 'zip', 'cold-type typesetting'],
    'typhoid fever': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'typhoon': ['baguio', 'black squall', 'blizzard', 'blow', 'cyclone', 'dirty weather', 'dust devil', 'equinoctial', 'foul weather', 'gale', 'half a gale', 'heavy blow'],
    'typhus': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'typical': ['absolute', 'archetypal', 'categorical', 'characteristic', 'classic', 'classical', 'classificational', 'classificatory', 'common', 'commonplace', 'connotative', 'consummate'],
    'typify': ['advert to', 'allude to', 'augur', 'be taken as', 'betoken', 'body forth', 'characterize', 'denominate', 'denote', 'designate', 'divine', 'emblematize'],
    'typifying': ['apish', 'delineatory', 'depictive', 'echoic', 'embodying', 'figurative', 'graphic', 'ideographic', 'illustrational', 'illustrative', 'imitative', 'incarnating'],
    'typo': ['clerical error', 'corrigendum', 'erratum', 'error', 'failure', 'fault', 'faute', 'human error', 'misapprehension', 'miscalculation', 'miscarriage', 'misconception'],
    'typographical error': ['clerical error', 'corrigendum', 'erratum', 'error', 'failure', 'fault', 'faute', 'human error', 'misapprehension', 'miscalculation', 'miscarriage', 'misconception'],
    'typography': ['albertype', 'book printing', 'chromotypography', 'chromotypy', 'chromoxylography', 'collotype', 'color printing', 'electronography', 'electrostatic printing', 'graphic arts', 'gravure', 'halftone engraving'],
    'typology': ['analysis', 'arrangement', 'cataloging', 'categorization', 'classification', 'codification', 'division', 'filing', 'grading', 'grouping', 'indexing', 'pigeonholing'],
    'tyr': ['aesir', 'ares', 'athena', 'balder', 'bellona', 'bor', 'bori', 'bragi', 'donar', 'enyo', 'forseti', 'frey'],
    'tyrannical': ['absolute', 'absolutist', 'absolutistic', 'arbitrary', 'aristocratic', 'arrogant', 'autarchic', 'authoritarian', 'authoritative', 'autocratic', 'bossy', 'brutal'],
    'tyrannize': ['beat down', 'bend', 'break', 'break down', 'bring low', 'bring to terms', 'browbeat', 'bulldoze', 'bully', 'castrate', 'clamp down on', 'coerce'],
    'tyranny': ['caesarism', 'nazism', 'stalinism', 'absolute monarchy', 'absolutism', 'arbitrariness', 'argumentum baculinum', 'aristocracy', 'autarchy', 'authoritarianism', 'autocracy', 'autonomy'],
    'tyrant': ['simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'authoritarian', 'autocrat', 'bully', 'caesar', 'commissar', 'czar'],
    'tyro': ['abecedarian', 'alphabetarian', 'apprentice', 'articled clerk', 'baby', 'beginner', 'boot', 'catechumen', 'colt', 'dabbler', 'deb', 'debutant'],
    'ubiquitous': ['absolute', 'all-embracing', 'all-encompassing', 'all-knowing', 'all-out', 'all-pervading', 'all-powerful', 'all-present', 'all-seeing', 'all-wise', 'almighty', 'bizarre'],
    'ubiquity': ['completeness', 'comprehensiveness', 'entireness', 'entirety', 'eternity', 'everywhereness', 'exhaustiveness', 'glory', 'holiness', 'immutability', 'inclusiveness', 'infinite goodness'],
    'udder': ['bag', 'boobs', 'bosom', 'breast', 'breasts', 'brisket', 'bust', 'chest', 'crop', 'dug', 'knockers', 'mama'],
    'ugliness': ['bearishness', 'bitchiness', 'cacophony', 'cantankerousness', 'churlishness', 'coarseness', 'crabbedness', 'cracked voice', 'crankiness', 'crossness', 'crustiness', 'cussedness'],
    'ugly': ['abominable', 'alarming', 'awkward', 'bad', 'bad-tempered', 'base', 'bearish', 'beautiless', 'bitchy', 'bitter', 'blemished', 'blotted'],
    'ugly customer': ['mafioso', 'tartar', 'young turk', 'bear', 'beast', 'beldam', 'berserk', 'berserker', 'bomber', 'bruiser', 'brute', 'crank'],
    'uhf': ['af', 'cps', 'ehf', 'hf', 'hz', 'mf', 'rf', 'shf', 'vhf', 'vlf', 'audio frequency', 'carrier frequency'],
    'ukase': ['announcement', 'annunciation', 'appointment', 'brevet', 'bull', 'bulletin board', 'circular', 'communique', 'declaration', 'decree', 'decree-law', 'decreement'],
    'ukulele': ['dobro guitar', 'f-hole guitar', 'spanish guitar', 'archlute', 'balalaika', 'banjo', 'banjo-uke', 'banjo-ukulele', 'banjo-zither', 'banjorine', 'banjuke', 'bass guitar'],
    'ulcer': ['abdominal hernia', 'abscess', 'aposteme', 'bane', 'bed sore', 'blain', 'bleb', 'blight', 'blister', 'boil', 'bubo', 'bulla'],
    'ulcerated': ['bad', 'cankered', 'carious', 'contaminated', 'corrupt', 'decayed', 'decomposed', 'diseased', 'festering', 'foul', 'gangrened', 'gangrenous'],
    'ulterior': ['accessory', 'additional', 'alien', 'ambiguous', 'ancillary', 'another', 'arcane', 'auxiliary', 'barbarian', 'barbaric', 'barbarous', 'beyond'],
    'ultimate': ['absolute', 'acmatic', 'acme', 'acme of perfection', 'apical', 'apotheosis', 'approaching', 'basic', 'binding', 'boundary', 'capital', 'categorical'],
    'ultimately': ['as things go', 'as times go', 'at bottom', 'at last', 'at length', 'at long last', 'at the end', 'at the last', 'basically', 'conclusively', 'essentially', 'eventually'],
    'ultimatum': ['admonishment', 'admonition', 'alarm', 'blackmail', 'boundary condition', 'call', 'call for', 'catch', 'caution', 'caveat', 'claim', 'clause'],
    'ultra': ['bolshevik', 'jacobin', 'wobbly', 'anarchist', 'anarcho-syndicalist', 'at the height', 'at the limit', 'extreme', 'extreme left-winger', 'extremist', 'fanatic', 'far out'],
    'ultraconservative': ['bircher', 'bourbon', 'tory', 'anarchistic', 'anarcho-syndicalist', 'backward', 'conservationist', 'conservatist', 'conservative', 'die-hard', 'diehard', 'extreme'],
    'ultramodern': ['a la mode', 'advanced', 'avant-garde', 'contemporary', 'far out', 'fashionable', 'forward-looking', 'in', 'mod', 'modern', 'modernistic', 'modernized'],
    'ultraviolet ray': ['x ray', 'actinic ray', 'actinism', 'atomic beam', 'atomic ray', 'beam', 'beam of light', 'gamma ray', 'gleam', 'infrared ray', 'invisible radiation', 'leam'],
    'ululate': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'bewail', 'blare', 'blat', 'blate', 'bleat', 'bray', 'call'],
    'ulysses': ['ahasuerus', 'ancient mariner', 'argonaut', 'flying dutchman', 'goliard', 'odysseus', 'oisin', 'ossian', 'bird of passage', 'drifter', 'floater', 'gad'],
    'uma': ['agni', 'asvins', 'avalokita', 'bhairava', 'bhairavi', 'brahma', 'chandi', 'daksha', 'devaki', 'devi', 'dharma', 'dharti mai'],
    'umber': ['beige', 'brown', 'brownish', 'brownish-yellow', 'brunet', 'chocolate', 'cinnamon', 'cocoa', 'cocoa-brown', 'coffee', 'coffee-brown', 'drab'],
    'umbilicus': ['axis', 'center', 'center of action', 'center of gravity', 'centroid', 'centrum', 'core', 'dead center', 'epicenter', 'heart', 'hub', 'kernel'],
    'umbra': ['adumbration', 'dark shade', 'eidolon', 'ghost', 'gloom', 'haunt', 'mere shadow', 'penumbra', 'phantasm', 'phantom', 'revenant', 'shade'],
    'umbrage': ['adumbration', 'angry look', 'annoyance', 'dark shade', 'dirty look', 'dudgeon', 'enrage', 'exasperation', 'foliage', 'foliation', 'frondage', 'frown'],
    'umbrella': ['aegis', 'agency', 'air cover', 'air raid', 'air support', 'arm guard', 'awning', 'backstop', 'beach umbrella', 'blind', 'bombing', 'brolly'],
    'umpire': ['jp', 'justice', 'act between', 'adjudge', 'adjudicate', 'adjudicator', 'arbiter', 'arbitrate', 'arbitrator', 'bargain', 'bencher', 'critic'],
    'unabashed': ['arrant', 'aweless', 'barefaced', 'blatant', 'bold', 'bold as brass', 'boldfaced', 'brassy', 'brazen', 'brazenfaced', 'exhibitionistic', 'flagrant'],
    'unabated': ['going strong', 'in full force', 'in full swing', 'unallayed', 'unbated', 'undiminished', 'unexhausted', 'unextinguished', 'unfaded', 'unflagging', 'unmitigated', 'unquelled'],
    'unable': ['ill-qualified', 'impotent', 'inadequate', 'incapable', 'incapable of', 'incompetent', 'ineffective', 'ineffectual', 'inefficient', 'inept', 'inferior', 'maladjusted'],
    'unaccented': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'unacceptable': ['bad', 'disagreeable', 'discommendable', 'distasteful', 'exceptionable', 'ill-favored', 'illaudable', 'impossible', 'improper', 'inadmissible', 'inappropriate', 'indefensible'],
    'unaccommodating': ['beefing', 'bellyaching', 'bitching', 'complaining', 'complaintful', 'crabbing', 'crabby', 'cranky', 'croaking', 'disappointed', 'discontented', 'discourteous'],
    'unaccompanied': ['a cappella', 'alienated', 'alone', 'aloof', 'apart', 'companionless', 'detached', 'friendless', 'homeless', 'insular', 'isolate', 'isolated'],
    'unaccomplished': ['amateurish', 'arcane', 'cabalistic', 'impenetrable', 'inscrutable', 'mystic', 'neglected', 'numinous', 'semiskilled', 'unachieved', 'unattained', 'unbusinesslike'],
    'unaccountable': ['adrift', 'afloat', 'agnostic', 'aimless', 'alternating', 'ambiguous', 'amorphous', 'antic', 'baffling', 'bizarre', 'capricious', 'casual'],
    'unaccustomed': ['a novice at', 'a stranger to', 'callow', 'curious', 'disaccustomed', 'fresh', 'green', 'green as grass', 'ignorant', 'immature', 'inexperienced', 'new'],
    'unacknowledged': ['anonymous', 'cryptonymic', 'cryptonymous', 'forgotten', 'ignored', 'ill-requited', 'ill-rewarded', 'incognito', 'innominate', 'nameless', 'neglected', 'uncredited'],
    'unacquainted with': ['a novice at', 'a stranger to', 'awkward', 'blankminded', 'callow', 'disaccustomed', 'dumb', 'empty', 'empty-headed', 'fresh', 'gauche', 'green'],
    'unadapted': ['disqualified', 'ill-adapted', 'ill-assorted', 'ill-chosen', 'ill-equipped', 'ill-fitted', 'ill-furnished', 'ill-matched', 'ill-provided', 'ill-qualified', 'ill-sorted', 'ill-suited'],
    'unadorned': ['spartan', 'arcadian', 'ascetic', 'austere', 'bald', 'bare', 'basic', 'blank', 'bucolic', 'candid', 'chaste', 'common'],
    'unadulterated': ['absolute', 'authentic', 'bald', 'bare', 'beyond all praise', 'blank', 'bleached', 'bona fide', 'bright', 'candid', 'card-carrying', 'chaste'],
    'unadventurous': ['canny', 'careful', 'cautious', 'circumspect', 'deliberate', 'discreet', 'gingerly', 'guarded', 'heedful', 'hesitant', 'judicious', 'leaving out nothing'],
    'unadvised': ['automatic', 'brash', 'casual', 'gut', 'hasty', 'hotheaded', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-gauged', 'ill-judged'],
    'unaesthetic': ['beautiless', 'blemished', 'blotted', 'cacophonic', 'cacophonous', 'defaced', 'disfigured', 'dysphemistic', 'dysphemized', 'homely', 'inelegant', 'marred'],
    'unaffected': ['attic', 'bohemian', 'ciceronian', 'spartan', 'adamant', 'adamantine', 'aesthetic', 'affable', 'arcadian', 'artistic', 'artless', 'ascetic'],
    'unaffectionate': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity', 'cold-blooded', 'coldhearted'],
    'unaffiliated': ['alien', 'apart', 'detached', 'disconnected', 'discrete', 'disjunct', 'disrelated', 'dissociated', 'exotic', 'extraneous', 'foreign', 'incommensurable'],
    'unafraid': ['arrogant', 'assured', 'audacious', 'aweless', 'bold', 'cocksure', 'composed', 'confident', 'convinced', 'cool', 'courageous', 'dauntless'],
    'unaided': ['alienated', 'alone', 'aloof', 'apart', 'companionless', 'detached', 'friendless', 'homeless', 'insular', 'isolated', 'kithless', 'lone'],
    'unalienable': ['deep-seated', 'esoteric', 'immanent', 'implanted', 'implicit', 'inalienable', 'indwelling', 'infixed', 'ingrained', 'inherent', 'inner', 'internal'],
    'unalike': ['contrasting', 'counter', 'different', 'disparate', 'dissimilar', 'divergent', 'diverse', 'hardly like', 'nonuniform', 'odd', 'off', 'offbeat'],
    'unallayed': ['going strong', 'in full force', 'in full swing', 'unabated', 'unbated', 'undiminished', 'unexhausted', 'unextinguished', 'unfaded', 'unflagging', 'unmitigated', 'unquelled'],
    'unallied': ['alien', 'apart', 'detached', 'disconnected', 'discrete', 'disjunct', 'disrelated', 'dissociated', 'exotic', 'extraneous', 'foreign', 'incommensurable'],
    'unallowed': ['actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'banned', 'barred', 'black-market', 'bootleg', 'chargeable', 'contraband', 'contrary to law'],
    'unalloyed': ['absolute', 'bare', 'clarified', 'clear', 'distilled', 'naked', 'neat', 'perfect', 'purified', 'rectified', 'sheer', 'simple'],
    'unalluring': ['bitter', 'disagreeable', 'dislikable', 'displeasing', 'distasteful', 'homely', 'sour', 'thankless', 'ugly', 'unappealing', 'unappetizing', 'unattractive'],
    'unalterable': ['adamant', 'adamantine', 'cast-iron', 'changeless', 'constant', 'dour', 'firm', 'fixed', 'flinty', 'grim', 'hard', 'hard-core'],
    'unaltered': ['abiding', 'changeless', 'constant', 'continuing', 'durable', 'enduring', 'firm', 'fixed', 'frozen', 'immobile', 'immutable', 'incommutable'],
    'unambiguous': ['absolute', 'ambiguous', 'apodictic', 'apparent', 'bound', 'categorical', 'certain', 'clean-cut', 'clear', 'clear and distinct', 'clear as crystal', 'clear as day'],
    'unambitious': ['desireless', 'humble', 'inappetent', 'loveless', 'meek', 'modest', 'nirvanic', 'passionless', 'unaspiring', 'unassuming', 'unattracted', 'unboastful'],
    'unamiable': ['chill', 'chilly', 'cold', 'cool', 'disaccordant', 'disagreeable', 'frosty', 'icy', 'ill', 'incompatible', 'inhospitable', 'inimical'],
    'unamicable': ['chill', 'chilly', 'cold', 'cool', 'disaccordant', 'frosty', 'icy', 'incompatible', 'inhospitable', 'inimical', 'strained', 'tense'],
    'unanimity': ['acclamation', 'accord', 'accordance', 'agreement', 'agreement of all', 'chorus', 'common assent', 'common consent', 'concert', 'concord', 'concordance', 'concurrence'],
    'unanimous': ['accordant', 'affirmative', 'agreeable', 'agreed', 'agreeing', 'answerable', 'at one', 'at one with', 'carried by acclamation', 'coexistent', 'coexisting', 'coherent'],
    'unanimously': ['agreeably', 'all agreeing', 'all together', 'as one', 'as one man', 'back to back', 'by acclamation', 'by consensus', 'coactively', 'coefficiently', 'collectively', 'combinedly'],
    'unannounced': ['extraordinary', 'improbable', 'more than expected', 'out-of-the-way', 'past expectation', 'sudden', 'unanticipated', 'undivined', 'unexpected', 'unforeseeable', 'unforeseen', 'unguessed'],
    'unanswerable': ['absolute', 'actual', 'admitting no question', 'chartered', 'confirmable', 'demonstrable', 'demonstratable', 'excepted', 'excused', 'exempt', 'exempted', 'factual'],
    'unanticipated': ['abrupt', 'electrifying', 'extraordinary', 'hasty', 'headlong', 'impetuous', 'improbable', 'impulsive', 'more than expected', 'nerve-shattering', 'out-of-the-way', 'past expectation'],
    'unappealing': ['bitter', 'disagreeable', 'dislikable', 'displeasing', 'distasteful', 'sour', 'thankless', 'ugly', 'unalluring', 'unappetizing', 'unattractive', 'undelectable'],
    'unappeasable': ['a hog for', 'acquisitive', 'all-devouring', 'avaricious', 'avenging', 'avid', 'bottomless', 'coveting', 'covetous', 'devouring', 'esurient', 'gluttonous'],
    'unappetizing': ['bitter', 'disagreeable', 'dislikable', 'displeasing', 'distasteful', 'flat', 'flavorless', 'foul-tasting', 'ill-flavored', 'insipid', 'savorless', 'sour'],
    'unappreciative': ['against', 'con', 'disappointed', 'disapprobatory', 'disapproving', 'discontented', 'disenchanted', 'disgruntled', 'disillusioned', 'displeased', 'dissatisfied', 'dissenting'],
    'unapproachable': ['olympian', 'aloof', 'antipodean', 'austere', 'back of beyond', 'backward', 'bashful', 'beyond compare', 'beyond comparison', 'beyond reach', 'blank', 'chilled'],
    'unapproved': ['albigensian', 'arian', 'catharist', 'donatist', 'ebionitist', 'erastian', 'gnostic', 'jansenist', 'jansenistic', 'jovinianist', 'jovinianistic', 'lollard'],
    'unapproving': ['against', 'con', 'disappointed', 'disapprobatory', 'disapproving', 'discontented', 'disenchanted', 'disgruntled', 'disillusioned', 'displeased', 'dissatisfied', 'dissenting'],
    'unapt': ['artless', 'half-assed', 'ill-adapted', 'ill-assorted', 'ill-chosen', 'ill-fitted', 'ill-matched', 'ill-sorted', 'ill-suited', 'ill-timed', 'improper', 'inadept'],
    'unarmed': ['bare-handed', 'defenseless', 'disqualified', 'guardless', 'helpless', 'ill-equipped', 'ill-fitted', 'ill-furnished', 'ill-provided', 'incapable', 'incompetent', 'unadapted'],
    'unaroused': ['abeyant', 'apathetic', 'cataleptic', 'catatonic', 'dead', 'dopey', 'dormant', 'dull', 'flat', 'foul', 'groggy', 'heavy'],
    'unarranged': ['ad-lib', 'aimless', 'amorphous', 'capricious', 'casual', 'caught napping', 'caught off balance', 'caught short', 'desultory', 'disarticulated', 'discontinuous', 'disjunct'],
    'unashamed': ['bold', 'brazen', 'brazenfaced', 'exhibitionistic', 'flagrant', 'forward', 'griefless', 'immodest', 'notorious', 'regretless', 'remorseless', 'shameless'],
    'unashamedly': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly', 'damnably', 'deadly'],
    'unasked': ['abandoned', 'arbitrary', 'arrogant', 'autonomous', 'deserted', 'discretional', 'discretionary', 'disregarded', 'elective', 'free', 'free will', 'gratuitous'],
    'unaspiring': ['desireless', 'humble', 'inappetent', 'loveless', 'meek', 'modest', 'nirvanic', 'passionless', 'unambitious', 'unassuming', 'unattracted', 'unboastful'],
    'unassailable': ['impenetrable', 'impregnable', 'incontestable', 'indomitable', 'inexpugnable', 'insuperable', 'invincible', 'inviolable', 'invulnerable', 'irresistible', 'overpowering', 'overwhelming'],
    'unassertive': ['abject', 'accepting', 'acquiescent', 'agreeable', 'assenting', 'backward', 'bashful', 'complaisant', 'compliable', 'compliant', 'complying', 'consenting'],
    'unassisted': ['alienated', 'alone', 'aloof', 'apart', 'companionless', 'detached', 'friendless', 'homeless', 'insular', 'isolated', 'kithless', 'lone'],
    'unassociated': ['alien', 'apart', 'asunder', 'bipartite', 'detached', 'dichotomous', 'disconnected', 'discontinuous', 'discrete', 'disjunct', 'disrelated', 'dissociated'],
    'unassuming': ['bohemian', 'affable', 'arcadian', 'authentic', 'bona fide', 'bucolic', 'candid', 'card-carrying', 'casual', 'cordial', 'degage', 'dinkum'],
    'unassured': ['backward', 'bashful', 'diffident', 'insecure', 'modest', 'rabbity', 'retiring', 'self-effacing', 'shy', 'timid', 'unassertive', 'unconfident'],
    'unastonished': ['aweless', 'calm', 'composed', 'cool', 'expected', 'expecting', 'inexcitable', 'unamazed', 'unastounded', 'unawed', 'unbewildered', 'undazed'],
    'unattached': ['afoot and lighthearted', 'apart', 'asunder', 'at large', 'at liberty', 'autonomous', 'bipartite', 'clear', 'detached', 'dichotomous', 'discontinuous', 'discrete'],
    'unattainable': ['beyond one', 'beyond reach', 'closed forever to', 'closed to', 'impenetrable', 'impervious', 'impracticable', 'impractical', 'inaccessible', 'infeasible', 'inoperable', 'insuperable'],
    'unattended': ['abandoned', 'alienated', 'alone', 'aloof', 'apart', 'asunder', 'bare-handed', 'bipartite', 'companionless', 'defenseless', 'deserted', 'detached'],
    'unattired': ['clothesless', 'decollete', 'disrobed', 'en deshabille', 'garbless', 'garmentless', 'half-clothed', 'in dishabille', 'low-cut', 'nudish', 'raimentless', 'strapless'],
    'unattractive': ['beautiless', 'bitter', 'blemished', 'blotted', 'cacophonic', 'cacophonous', 'defaced', 'disagreeable', 'disfigured', 'dislikable', 'displeasing', 'distasteful'],
    'unauthentic': ['albigensian', 'arian', 'catharist', 'donatist', 'ebionitist', 'erastian', 'gnostic', 'jansenist', 'jansenistic', 'jovinianist', 'jovinianistic', 'lollard'],
    'unauthenticated': ['apocryphal', 'groundless', 'inconclusive', 'indecisive', 'nonofficial', 'not following', 'not proved', 'unascertained', 'unattested', 'unauthentic', 'unauthoritative', 'uncertified'],
    'unauthoritative': ['albigensian', 'arian', 'catharist', 'donatist', 'ebionitist', 'erastian', 'gnostic', 'jansenist', 'jansenistic', 'jovinianist', 'jovinianistic', 'lollard'],
    'unauthorized': ['actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'banned', 'barred', 'black-market', 'bootleg', 'chargeable', 'contraband', 'contrary to law'],
    'unavailable': ['abortive', 'beyond reach', 'bootless', 'closed forever to', 'closed to', 'fruitless', 'impenetrable', 'impervious', 'inaccessible', 'ineffective', 'ineffectual', 'lost to'],
    'unavailing': ['abortive', 'aimless', 'barren', 'bootless', 'counterproductive', 'effete', 'empty', 'etiolated', 'fatuitous', 'fatuous', 'feckless', 'fruitless'],
    'unavoidable': ['certain', 'definite', 'destined', 'determined', 'fated', 'fateful', 'fixed', 'indefeasible', 'ineluctable', 'ineludible', 'inescapable', 'inevasible'],
    'unaware': ['a stranger to', 'aback', 'asleep', 'blind to', 'caught napping', 'dead to', 'deaf to', 'heedless', 'ignorant', 'impercipient', 'in ignorance of', 'incognizant'],
    'unawares': ['aback', 'abruptly', 'accidentally', 'bang', 'by accident', 'by surprise', 'dash', 'guiltlessly', 'hastily', 'ignorantly', 'impetuously', 'implausibly'],
    'unawed': ['aweless', 'calm', 'composed', 'cool', 'expected', 'expecting', 'inexcitable', 'unabashed', 'unamazed', 'unappalled', 'unastonished', 'unastounded'],
    'unbalance': ['aberration', 'abnormality', 'alienation', 'asymmetry', 'brain damage', 'brainsickness', 'clouded mind', 'contrariety', 'craze', 'craziness', 'daftness', 'dement'],
    'unbalanced': ['abnormal', 'asymmetric', 'asymmetrical', 'batty', 'bereft of reason', 'bonkers', 'brainsick', 'canted', 'certifiable', 'crackbrained', 'cracked', 'crazed'],
    'unbearable': ['a bit much', 'absolute', 'arrant', 'classical', 'complete', 'consummate', 'crass', 'decided', 'definitive', 'downright', 'egregious', 'flagrant'],
    'unbeatable': ['beyond compare', 'beyond comparison', 'easily first', 'excellent', 'facile princeps', 'immortal', 'impenetrable', 'impregnable', 'incomparable', 'incontestable', 'indomitable', 'inexpugnable'],
    'unbeaten': ['callow', 'dewy', 'ever-new', 'evergreen', 'extra', 'firsthand', 'fledgling', 'fresh', 'green', 'held back', 'held in reserve', 'held out'],
    'unbeautiful': ['beautiless', 'blemished', 'blotted', 'cacophonic', 'cacophonous', 'defaced', 'disfigured', 'dysphemistic', 'dysphemized', 'hideous', 'homely', 'ill-favored'],
    'unbecoming': ['awkward', 'beneath one', 'cheap', 'chintzy', 'clumsy', 'debasing', 'degrading', 'demeaning', 'deplorable', 'disgraceful', 'gauche', 'gutter'],
    'unbefitting': ['bad', 'futile', 'ill-adapted', 'ill-advised', 'ill-assorted', 'ill-chosen', 'ill-considered', 'ill-fitted', 'ill-matched', 'ill-seasoned', 'ill-sorted', 'ill-suited'],
    'unbeknown': ['able', 'enigmatic', 'incalculable', 'incognizable', 'mysterious', 'puzzling', 'sealed', 'strange', 'unapparent', 'unapprehended', 'unascertained', 'uncharted'],
    'unbelief': ['apprehension', 'atheism', 'disbelief', 'distrust', 'doubt', 'dubiety', 'faithlessness', 'gentilism', 'incredulity', 'infidelity', 'minimifidianism', 'misgiving'],
    'unbelievable': ['a bit thick', 'a bit thin', 'absurd', 'antic', 'beyond belief', 'doubtable', 'doubtful', 'dubious', 'dubitable', 'fanciful', 'fantastic', 'flimsy'],
    'unbeliever': ['pyrrhonist', 'sabbath-breaker', 'apostate', 'atheist', 'backslider', 'blasphemer', 'deserter', 'disbeliever', 'doubter', 'doubting thomas', 'gentile', 'giaour'],
    'unbelieving': ['atheist', 'atheistic', 'creedless', 'disbelieving', 'distrustful', 'doubting', 'faithless', 'gentile', 'goyish', 'heathen', 'heretical', 'incredulous'],
    'unbend': ['abate', 'bate', 'bend', 'disentangle', 'ease', 'ease off', 'ease up', 'extend', 'flatten', 'give', 'give way', 'let down'],
    'unbending': ['adamant', 'adamantine', 'aloof', 'arrowlike', 'cast-iron', 'constant', 'dead straight', 'direct', 'distant', 'dour', 'even', 'firm'],
    'unbent': ['arrowlike', 'dead straight', 'direct', 'even', 'flat', 'horizontal', 'in a line', 'level', 'lineal', 'linear', 'rectilineal', 'rectilinear'],
    'unbiased': ['olympian', 'aloof', 'candid', 'detached', 'disinterested', 'dispassionate', 'equal', 'equitable', 'evenhanded', 'fair', 'impartial', 'impersonal'],
    'unbidden': ['arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'nonmandatory', 'offered', 'optional'],
    'unbigoted': ['broad', 'broad-gauged', 'broad-minded', 'catholic', 'cosmopolitan', 'ecumenical', 'ecumenistic', 'freethinking', 'latitudinarian', 'liberal', 'libertarian', 'libertine'],
    'unbind': ['cast off', 'detach', 'discharge', 'disengage', 'doff', 'emancipate', 'free', 'liberate', 'loose', 'loosen', 'manumit', 'release'],
    'unblemished': ['christian', 'absolute', 'beyond all praise', 'blameless', 'bleached', 'blotless', 'bright', 'chaste', 'clean', 'cleanly', 'creditable', 'dainty'],
    'unblenching': ['audacious', 'bold', 'calm', 'coolheaded', 'courageous', 'dauntless', 'fearless', 'inexcitable', 'intrepid', 'nerveless', 'relaxed', 'rock-steady'],
    'unblessed': ['badly off', 'depressed', 'dire', 'donsie', 'doomful', 'evil-starred', 'fatal', 'fleshly', 'fortuneless', 'funest', 'hapless', 'ill off'],
    'unblinking': ['agile', 'alert', 'alive', 'attentive', 'awake', 'bright', 'calm', 'coolheaded', 'inexcitable', 'keen', 'nerveless', 'nimble'],
    'unblock': ['aid', 'bare', 'clear', 'clear the way', 'deobstruct', 'disclose', 'ease', 'expedite', 'explain', 'expose', 'facilitate', 'free'],
    'unbolt': ['cast off', 'detach', 'disengage', 'doff', 'free', 'liberate', 'loose', 'loosen', 'release', 'remove', 'take off', 'unbar'],
    'unbound': ['absolute', 'adrift', 'afloat', 'clear', 'delivered', 'emancipated', 'extricated', 'floating', 'free', 'freed', 'full', 'illimitable'],
    'unbounded': ['absolute', 'all-comprehensive', 'all-inclusive', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'boundless', 'changeless', 'countless', 'creating'],
    'unbowed': ['arrowlike', 'dead straight', 'direct', 'even', 'flat', 'horizontal', 'in a line', 'level', 'lineal', 'linear', 'rectilineal', 'rectilinear'],
    'unbridled': ['a bit much', 'abandoned', 'bibulous', 'boundless', 'crapulent', 'crapulous', 'debauched', 'disobedient', 'disorderly', 'dissipated', 'dissolute', 'egregious'],
    'unbroken': ['accordant', 'alike', 'arrowlike', 'articulated', 'automatic', 'balanced', 'bright', 'catenated', 'ceaseless', 'chattering', 'concatenated', 'connected'],
    'unbuckle': ['cast off', 'detach', 'disengage', 'doff', 'free', 'liberate', 'loose', 'loosen', 'release', 'remove', 'take off', 'unbar'],
    'unburden': ['alleviate', 'be light', 'break bulk', 'clear', 'disburden', 'discharge', 'disembarrass', 'disencumber', 'dump', 'ease', 'have little weight', 'kick the beam'],
    'unbusinesslike': ['amateurish', 'semiskilled', 'unaccomplished', 'uncoached', 'unendowed', 'unfinished', 'ungifted', 'uninitiated', 'unpolished', 'unprepared', 'unprimed', 'unprofessional'],
    'unbutton': ['cast off', 'detach', 'disengage', 'doff', 'free', 'liberate', 'loose', 'loosen', 'release', 'remove', 'take off', 'unbar'],
    'uncalculated': ['automatic', 'casual', 'gut', 'ill-advised', 'ill-considered', 'ill-devised', 'inadvertent', 'indeliberate', 'involuntary', 'reflex', 'reflexive', 'snap'],
    'uncalculating': ['arbitrary', 'capricious', 'careless', 'guileless', 'heedless', 'inadvertent', 'inconsiderate', 'reasonless', 'thoughtless', 'unaffected', 'unassumed', 'unassuming'],
    'uncalled for': ['absurd', 'arbitrary', 'autonomous', 'biggety', 'bluff', 'bottomless', 'brash', 'cheeky', 'chutzpadik', 'cocky', 'contemptuous', 'crusty'],
    'uncandid': ['artful', 'calculating', 'casuistic', 'crafty', 'deceitful', 'dishonest', 'disingenuous', 'empty', 'falsehearted', 'forsworn', 'hollow', 'insincere'],
    'uncanny': ['awe-inspiring', 'awesome', 'awful', 'awing', 'bizarre', 'blue', 'cadaverous', 'corpselike', 'creepy', 'deadly', 'deathlike', 'deathly'],
    'uncared for': ['abandoned', 'deserted', 'despised', 'disliked', 'disregarded', 'half-done', 'ignored', 'laid aside', 'left undone', 'lowly', 'misprized', 'missed'],
    'uncaused': ['accidental', 'adventitious', 'aleatory', 'casual', 'causeless', 'chance', 'chancy', 'contingent', 'destinal', 'dicey', 'fatal', 'fatidic'],
    'unceasing': ['abiding', 'ageless', 'articulated', 'catenated', 'ceaseless', 'chattering', 'coeternal', 'concatenated', 'connected', 'constant', 'continual', 'continued'],
    'uncelebrated': ['ignotus', 'inglorious', 'little known', 'nameless', 'no credit to', 'obscure', 'renownless', 'undistinguished', 'unfamed', 'unglorified', 'unheard-of', 'unhonored'],
    'unceremonious': ['bohemian', 'affable', 'casual', 'cordial', 'degage', 'easy', 'easygoing', 'familiar', 'folksy', 'free and easy', 'gracious', 'haymish'],
    'uncertain': ['pyrrhonic', 'adrift', 'afloat', 'agnostic', 'alternating', 'ambiguous', 'ambitendent', 'ambivalent', 'amorphous', 'amphibological', 'amphibolous', 'at a loss'],
    'uncertainty': ['pyrrhonism', 'accidentality', 'actuarial calculation', 'adventitiousness', 'agitation', 'ambiguity', 'ambiguousness', 'ambitendency', 'ambivalence', 'amphibology', 'anxiety', 'apprehension'],
    'uncertified': ['apocryphal', 'groundless', 'inconclusive', 'indecisive', 'nonofficial', 'not following', 'not proved', 'unascertained', 'unattested', 'unauthentic', 'unauthenticated', 'unauthoritative'],
    'unchain': ['cast off', 'detach', 'discharge', 'disengage', 'doff', 'emancipate', 'free', 'liberate', 'loose', 'loosen', 'manumit', 'release'],
    'unchallengeable': ['deep-seated', 'esoteric', 'immanent', 'implanted', 'implicit', 'inalienable', 'indwelling', 'infixed', 'ingrained', 'inherent', 'inner', 'internal'],
    'unchallenged': ['agreeing', 'at one', 'at one with', 'beyond question', 'carried by acclamation', 'concordant', 'concurrent', 'consentaneous', 'doubtless', 'in agreement', 'indubious', 'like-minded'],
    'unchangeable': ['abiding', 'accordant', 'adamant', 'adamantine', 'alike', 'automatic', 'balanced', 'cast-iron', 'changeless', 'consistent', 'consonant', 'constant'],
    'unchanging': ['abiding', 'accordant', 'alike', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'automatic', 'balanced', 'boundless', 'ceaseless'],
    'unchaperoned': ['abandoned', 'deserted', 'disregarded', 'half-done', 'ignored', 'laid aside', 'left undone', 'missed', 'neglected', 'omitted', 'overlooked', 'passed by'],
    'uncharitable': ['authoritarian', 'bigot', 'bigoted', 'borne', 'closed', 'constricted', 'cramped', 'creedbound', 'deaf', 'deaf to reason', 'fanatical', 'hidebound'],
    'uncharted': ['able', 'enigmatic', 'incalculable', 'incognizable', 'mysterious', 'puzzling', 'sealed', 'strange', 'trackless', 'unapparent', 'unapprehended', 'unascertained'],
    'unchary': ['brash', 'brazen', 'brazenfaced', 'hubristic', 'improvident', 'imprudent', 'impudent', 'incautious', 'indiscreet', 'injudicious', 'insolent', 'overbold'],
    'unchaste': ['adamic', 'cyprian', 'cyrenaic', 'fescennine', 'rabelaisian', 'appetitive', 'backsliding', 'bawdy', 'bent on pleasure', 'besmirched', 'blue', 'carnal'],
    'unchastity': ['cyrenaic hedonism', 'cyrenaicism', 'amorality', 'appetite', 'appetitiveness', 'backsliding', 'carnality', 'criminality', 'delinquency', 'epicureanism', 'epicurism', 'ethical hedonism'],
    'unchecked': ['abandoned', 'abiding', 'apocryphal', 'artless', 'bluff', 'blunt', 'broad', 'brusque', 'candid', 'changeless', 'constant', 'continuing'],
    'uncheerful': ['cassandra-like', 'cassandran', 'cassandrian', 'cheerless', 'cynical', 'defeatist', 'discontented', 'dismal', 'downbeat', 'gloomy', 'grim', 'humorless'],
    'unchristian': ['draconian', 'tartarean', 'animal', 'anthropophagous', 'atheist', 'atheistic', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bestial', 'bloodthirsty'],
    'uncircumscribed': ['absolute', 'admitting no exception', 'all-comprehensive', 'all-inclusive', 'all-out', 'boundless', 'categorical', 'clear', 'complete', 'conclusive', 'countless', 'decided'],
    'uncivil': ['gothic', 'neanderthal', 'animal', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'brutal', 'brutish', 'coarse', 'crass', 'crude'],
    'uncivilized': ['draconian', 'gothic', 'neanderthal', 'tartarean', 'animal', 'anthropophagous', 'atrocious', 'barbarian', 'barbaric', 'barbarous', 'beastly', 'bestial'],
    'unclad': ['clothesless', 'decollete', 'disrobed', 'en deshabille', 'garbless', 'garmentless', 'half-clothed', 'in dishabille', 'low-cut', 'naked', 'nude', 'nudish'],
    'unclasp': ['cast off', 'detach', 'disengage', 'doff', 'free', 'leave go', 'let go', 'let loose of', 'liberate', 'loose', 'loosen', 'release'],
    'unclassified': ['able', 'aimless', 'amorphous', 'bald', 'bare', 'capricious', 'casual', 'desultory', 'disarticulated', 'disclosed', 'discontinuous', 'disjunct'],
    'uncle': ['aunt', 'auntie', 'blood brother', 'brethren', 'brother', 'bub', 'bubba', 'bud', 'buddy', 'country cousin', 'cousin', 'cousin once removed'],
    'unclean': ['adamic', 'fescennine', 'rabelaisian', 'abominable', 'arrant', 'atrocious', 'awful', 'backsliding', 'base', 'bawdy', 'beastly', 'beneath contempt'],
    'unclear': ['aleatoric', 'aleatory', 'ambiguous', 'amorphic', 'amorphous', 'amphibological', 'anarchic', 'baggy', 'barely audible', 'blear', 'bleared', 'bleary'],
    'unclench': ['bare', 'clear', 'deobstruct', 'disclose', 'expose', 'free', 'manifest', 'patefy', 'reveal', 'unblock', 'uncase', 'unclog'],
    'unclog': ['aid', 'bare', 'blow', 'blow out', 'clean out', 'clear', 'clear away', 'clear off', 'clear out', 'clear the decks', 'clear the way', 'defecate'],
    'unclogged': ['bald', 'bare', 'clear', 'cleared', 'disclosed', 'disembarrassed', 'exposed', 'free', 'naked', 'open', 'unburdened', 'unclosed'],
    'unclothed': ['clothesless', 'decollete', 'disrobed', 'en deshabille', 'garbless', 'garmentless', 'half-clothed', 'in dishabille', 'low-cut', 'naked', 'nude', 'nudish'],
    'unclouded': ['apparent', 'beholdable', 'clarion', 'clear', 'clear as crystal', 'cloudless', 'crystal', 'crystal-clear', 'crystalline', 'detectable', 'diaphane', 'diaphanous'],
    'unclutter': ['clarify', 'clear', 'clear up', 'disburden', 'disembarrass', 'disembroil', 'disencumber', 'disengage', 'disentangle', 'disintricate', 'disinvolve', 'extricate'],
    'uncluttered': ['austere', 'bare', 'basic', 'chaste', 'chipper', 'elementary', 'essential', 'fundamental', 'groomed', 'homely', 'homespun', 'homogeneous'],
    'uncoached': ['amateurish', 'semiskilled', 'unaccomplished', 'unbusinesslike', 'unendowed', 'unfinished', 'ungifted', 'uninitiated', 'unpolished', 'unprepared', 'unprimed', 'unprofessional'],
    'uncoerced': ['abandoned', 'arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'go-go', 'gratuitous', 'immoderate', 'incontinent'],
    'uncoil': ['clarify', 'clear up', 'disembroil', 'disentangle', 'disintricate', 'disinvolve', 'ravel', 'sort out', 'unbraid', 'unclutter', 'unfold', 'unfurl'],
    'uncollectible': ['accounts payable', 'accounts receivable', 'amount due', 'bad debt', 'bad debts', 'bill', 'bills', 'borrowing', 'charges', 'chits', 'debt', 'default'],
    'uncolored': ['achromatic', 'achromic', 'anemic', 'ashen', 'ashy', 'authentic', 'bled white', 'bloodless', 'bona fide', 'cadaverous', 'candid', 'card-carrying'],
    'uncombed': ['gothic', 'neanderthal', 'animal', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'brutal', 'brutish', 'disheveled', 'ill-bred', 'impolite'],
    'uncomely': ['beautiless', 'blemished', 'blotted', 'cacophonic', 'cacophonous', 'defaced', 'disfigured', 'dysphemistic', 'dysphemized', 'hideous', 'homely', 'ill-favored'],
    'uncomfortable': ['abashed', 'affecting', 'afflicted', 'afflictive', 'agitated', 'beset', 'bitter', 'bleak', 'bothered', 'cast down', 'chagrined', 'chapfallen'],
    'uncommitted': ['laodicean', 'afoot and lighthearted', 'apathetic', 'at large', 'at liberty', 'centrist', 'clear', 'detached', 'disengaged', 'easygoing', 'emancipated', 'even'],
    'uncommon': ['almost unheard-of', 'appalling', 'astonishing', 'at a premium', 'breakaway', 'conspicuous', 'different', 'egregious', 'exceptional', 'extraordinary', 'extremely', 'fabulous'],
    'uncommonly': ['abnormally', 'abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'at infrequent intervals', 'awesomely', 'conspicuously', 'copiously', 'eminently', 'emphatically'],
    'uncommunicative': ['aloof', 'autistic', 'bashful', 'canny', 'careful', 'cautious', 'circumspect', 'close', 'close-lipped', 'close-tongued', 'closemouthed', 'dark'],
    'uncompassionate': ['bowelless', 'callous', 'coldhearted', 'cruel', 'disagreeable', 'dog-eat-dog', 'flinty', 'hard', 'hard-boiled', 'hardhearted', 'harsh', 'heartless'],
    'uncompelled': ['abandoned', 'arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'go-go', 'gratuitous', 'immoderate', 'incontinent'],
    'uncomplaining': ['abject', 'accepting', 'accommodating', 'acquiescent', 'adapting', 'adaptive', 'adjusting', 'agreeable', 'amenable', 'assenting', 'at ease', 'comfortable'],
    'uncompliant': ['contrary', 'deaf to', 'declinatory', 'deviant', 'disobedient', 'disregardful', 'dissenting', 'dissident', 'inattentive', 'inconstant', 'indocile', 'inexorable'],
    'uncomplicated': ['mickey mouse', 'bald', 'bare', 'blank', 'casual', 'clear', 'cushy', 'easy', 'easy as pie', 'effortless', 'facile', 'glib'],
    'uncomplimentary': ['against', 'con', 'depreciative', 'depreciatory', 'detracting', 'disadvantageous', 'disappointed', 'disapprobatory', 'disapproving', 'discontented', 'disenchanted', 'disgruntled'],
    'uncomprehending': ['awkward', 'blankminded', 'blind', 'blindfold', 'blindfolded', 'callow', 'dim-sighted', 'dumb', 'empty', 'empty-headed', 'gauche', 'green'],
    'uncompromising': ['adamant', 'adamantine', 'cast-iron', 'dour', 'firm', 'flinty', 'fundamentalist', 'grim', 'hard', 'hard-core', 'hard-line', 'hidebound'],
    'unconcealed': ['apparent', 'beholdable', 'candid', 'detectable', 'discernible', 'disclosed', 'evident', 'exposed', 'exposed to view', 'hanging out', 'in evidence', 'in full view'],
    'unconcern': ['accidia', 'acedia', 'aloofness', 'apathy', 'ataraxia', 'ataraxy', 'benumbedness', 'blah', 'blahs', 'boredom', 'carelessness', 'casualness'],
    'unconcerned': ['laodicean', 'olympian', 'aloof', 'apathetic', 'ataractic', 'benumbed', 'blah', 'blase', 'bored', 'careless', 'casual', 'collected'],
    'unconditional': ['absolute', 'admitting no exception', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'born', 'broad-based', 'categorical', 'clean', 'clear', 'complete'],
    'unconditionally': ['a outrance', 'absolutely', 'all out', 'altogether', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure', 'completely', 'comprehensively', 'dead', 'downright'],
    'unconfident': ['creedless', 'disbelieving', 'faithless', 'heretical', 'incredulous', 'insecure', 'irreligious', 'minimifidian', 'nonbelieving', 'nullifidian', 'repudiative', 'unassured'],
    'unconfined': ['absolute', 'free', 'full', 'illimitable', 'limitless', 'loose', 'no strings', 'open', 'perfect', 'plenary', 'unbound', 'unbounded'],
    'unconfirmed': ['apocryphal', 'groundless', 'inconclusive', 'indecisive', 'nonofficial', 'not following', 'not proved', 'unascertained', 'unattested', 'unauthentic', 'unauthenticated', 'unauthoritative'],
    'unconfused': ['clean-cut', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'coherent', 'connected', 'consistent', 'crisp', 'crystal-clear', 'crystalline', 'defined'],
    'unconfuted': ['actual', 'ascertained', 'attested', 'authenticated', 'categorically true', 'certain', 'certified', 'confirmed', 'corroborated', 'demonstrated', 'determined', 'documentary'],
    'uncongenial': ['olympian', 'abhorrent', 'aloof', 'antagonistic', 'antipathetic', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'autistic', 'backward'],
    'unconnected': ['greek to one', 'absonant', 'alien', 'aloof', 'ambiguous', 'apart', 'asunder', 'beyond understanding', 'bipartite', 'broken', 'broken off', 'chopped-off'],
    'unconquerable': ['assiduous', 'constant', 'continuing', 'diligent', 'dogged', 'enduring', 'faithful', 'immutable', 'impassable', 'impenetrable', 'impregnable', 'inalterable'],
    'unconscientious': ['amoral', 'conscienceless', 'corrupt', 'corrupted', 'criminal', 'crooked', 'dark', 'devious', 'dishonest', 'dishonorable', 'doubtful', 'dubious'],
    'unconscionable': ['a bit much', 'abandoned', 'absolute', 'acute', 'amoral', 'arrant', 'barbarous', 'boundless', 'classical', 'complete', 'conscienceless', 'consummate'],
    'unconscious': ['a stranger to', 'abiotic', 'absent', 'absentminded', 'absorbed', 'abstracted', 'anima', 'asleep', 'automatic', 'azoic', 'bemused', 'blind'],
    'unconsenting': ['at odds', 'averse', 'cursory', 'deaf to', 'declinatory', 'differing', 'disagreeing', 'disinclined', 'disobedient', 'forced', 'fractious', 'indisposed'],
    'unconsidered': ['abandoned', 'aimless', 'automatic', 'brash', 'casual', 'deserted', 'designless', 'desultory', 'disregarded', 'gut', 'half-done', 'haphazard'],
    'unconsolidated': ['aloof', 'broken', 'detached', 'disconnected', 'discontinuous', 'discrete', 'gapped', 'incoherent', 'inconsistent', 'nonadherent', 'nonadhesive', 'noncoherent'],
    'unconstitutional': ['actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'black-market', 'bootleg', 'chargeable', 'contraband', 'contrary to law', 'criminal', 'felonious'],
    'unconstrained': ['bohemian', 'abandoned', 'accessible', 'affable', 'approachable', 'artless', 'bibulous', 'bluff', 'blunt', 'broad', 'brusque', 'candid'],
    'unconstraint': ['bohemianism', 'abandon', 'abandonment', 'accessibility', 'affability', 'approachability', 'artlessness', 'bluffness', 'bluntness', 'broadness', 'brusqueness', 'candidness'],
    'uncontaminated': ['absolute', 'beyond all praise', 'chaste', 'defectless', 'faultless', 'flawless', 'ideal', 'immaculate', 'impeccable', 'indefectible', 'indefective', 'infallible'],
    'uncontested': ['accepted', 'agreeing', 'at one', 'at one with', 'believed', 'beyond question', 'carried by acclamation', 'concordant', 'concurrent', 'consentaneous', 'credited', 'doubtless'],
    'uncontrived': ['ad-lib', 'caught napping', 'caught off balance', 'caught short', 'extemporaneous', 'extemporized', 'haphazard', 'hasty', 'impromptu', 'improvised', 'makeshift', 'precipitate'],
    'uncontrollable': ['dionysiac', 'abandoned', 'amok', 'bacchic', 'bellowing', 'berserk', 'beyond control', 'breachy', 'carried away', 'certain', 'contumacious', 'corybantic'],
    'uncontrolled': ['abandoned', 'adrift', 'afloat', 'alternating', 'amorphous', 'bibulous', 'boisterous', 'capricious', 'changeable', 'changeful', 'crapulent', 'crapulous'],
    'unconventional': ['bohemian', 'abnormal', 'affable', 'anomalous', 'beat', 'breakaway', 'casual', 'cordial', 'crank', 'crankish', 'cranky', 'crotchety'],
    'unconvinced': ['agnostic', 'ambiguous', 'capricious', 'chancy', 'changeable', 'creedless', 'dicey', 'disbelieving', 'doubting', 'equivocal', 'erratic', 'faithless'],
    'unconvincing': ['a bit thick', 'a bit thin', 'absurd', 'beyond belief', 'doubtable', 'doubtful', 'dubious', 'dubitable', 'flimsy', 'hard of belief', 'hard to believe', 'implausible'],
    'uncooperative': ['adversary', 'adversative', 'adverse', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'balking', 'balky', 'bigoted', 'bulldogged'],
    'uncordial': ['chill', 'chilly', 'closed', 'cold', 'cool', 'disaccordant', 'disagreeable', 'frosty', 'icy', 'ill', 'incompatible', 'inhospitable'],
    'uncork': ['bare', 'clear', 'deobstruct', 'disclose', 'expose', 'free', 'manifest', 'patefy', 'reveal', 'unblock', 'uncase', 'unclench'],
    'uncorroborated': ['apocryphal', 'groundless', 'inconclusive', 'indecisive', 'nonofficial', 'not following', 'not proved', 'unascertained', 'unattested', 'unauthentic', 'unauthenticated', 'unauthoritative'],
    'uncorrupted': ['christian', 'absolute', 'angelic', 'bare', 'blameless', 'childlike', 'clarified', 'clean', 'clear', 'creditable', 'decent', 'distilled'],
    'uncounted': ['at issue', 'conditional', 'conditioned', 'contingent', 'countless', 'dependent', 'depending', 'endless', 'immeasurable', 'in question', 'in suspense', 'in the balance'],
    'uncouple': ['abrupt', 'abstract', 'alienate', 'cast off', 'cast out', 'cut adrift', 'cut off', 'cut out', 'delete', 'depart', 'disarticulate', 'disconnect'],
    'uncouth': ['doric', 'gothic', 'neanderthal', 'abandoned', 'all thumbs', 'animal', 'awkward', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'bizarre'],
    'uncover': ['accost', 'address', 'bare', 'betray', 'bid good day', 'bid good morning', 'bow to', 'break the seal', 'bring to light', 'clear', 'curtsy', 'denudate'],
    'uncovered': ['bald', 'bare', 'bare-handed', 'bared', 'clear', 'cleared', 'defenseless', 'denudated', 'denuded', 'disclosed', 'divested', 'exposed'],
    'uncovering': ['apocalypse', 'baring', 'bringing to light', 'casual discovery', 'catching', 'chance discovery', 'denudation', 'desquamation', 'detection', 'determination', 'determining', 'disclosing'],
    'uncritical': ['adulatory', 'blanket', 'careless', 'casual', 'credulous', 'cursory', 'depthless', 'doting', 'easily taken in', 'easy of belief', 'fond', 'fulsome'],
    'uncrown': ['break', 'bust', 'cashier', 'deconsecrate', 'defrock', 'depose', 'dethrone', 'disbar', 'discrown', 'disenthrone', 'dismiss', 'displace'],
    'uncrystallized': ['a bit previous', 'advanced', 'far ahead', 'forward', 'half-baked', 'half-cocked', 'hasty', 'ill-considered', 'impulsive', 'not firm', 'overhasty', 'oversoon'],
    'unction': ['tartuffery', 'tartuffism', 'affectation', 'anointment', 'balm', 'balsam', 'brilliantine', 'cant', 'cerate', 'chrism', 'chrismal', 'chrismation'],
    'unctuous': ['pecksniffian', 'tartuffian', 'tartuffish', 'adipose', 'adulatory', 'affected', 'bland', 'blandishing', 'blarneying', 'blubbery', 'buttery', 'butyraceous'],
    'uncultivated': ['gothic', 'neanderthal', 'philistine', 'acarpous', 'agrarian', 'animal', 'arid', 'arrested', 'backward', 'barbarian', 'barbaric', 'barbarous'],
    'uncultured': ['gothic', 'neanderthal', 'philistine', 'animal', 'arrested', 'backward', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'bookless', 'boorish'],
    'uncurbed': ['abandoned', 'disobedient', 'go-go', 'headstrong', 'heady', 'immoderate', 'incontinent', 'indulgent', 'insubordinate', 'intemperate', 'irrepressible', 'irresponsible'],
    'uncustomary': ['breakaway', 'extraordinary', 'offbeat', 'rare', 'recherche', 'singular', 'sui generis', 'uncommon', 'undreamed-of', 'unexpected', 'unfamiliar', 'unheard-of'],
    'uncut': ['arrested', 'backward', 'coarse', 'complete', 'crude', 'developed', 'embryonic', 'entire', 'full', 'full-fledged', 'full-grown', 'full-scale'],
    'undamaged': ['bright', 'flawless', 'fresh', 'harmless', 'immune', 'immunized', 'insured', 'intact', 'inviolate', 'mint', 'pristine', 'protected'],
    'undaunted': ['assiduous', 'audacious', 'bold', 'constant', 'continuing', 'courageous', 'dauntless', 'diligent', 'dogged', 'enduring', 'faithful', 'fearless'],
    'undeceitful': ['guileless', 'unaffected', 'unassumed', 'unassuming', 'unbeguileful', 'unbeguiling', 'uncalculating', 'undeceiving', 'undeceptive', 'undesigning', 'undisguised', 'undisguising'],
    'undeceived': ['alive to', 'appreciative of', 'apprised of', 'awake to', 'aware of', 'behind the curtain', 'behind the scenes', 'blase', 'cognizant of', 'conscious of', 'disabused', 'disappointed'],
    'undeceptive': ['guileless', 'unaffected', 'unassumed', 'unassuming', 'unbeguileful', 'unbeguiling', 'uncalculating', 'undeceitful', 'undeceiving', 'undesigning', 'undisguised', 'undisguising'],
    'undecided': ['ambitendent', 'ambivalent', 'at issue', 'at loose ends', 'borderline', 'capricious', 'changeable', 'conditional', 'conditioned', 'contingent', 'dependent', 'depending'],
    'undeclared': ['implicit', 'implied', 'inferred', 'silent', 'understood', 'unexpressed', 'unmentioned', 'unproclaimed', 'unpronounced', 'unpublished', 'unrecorded', 'unsaid'],
    'undecorated': ['bald', 'bare', 'blank', 'homely', 'naked', 'nude', 'simple', 'unadorned', 'unadulterated', 'unarrayed', 'uncomplicated', 'undecked'],
    'undefended': ['bare-handed', 'defenseless', 'guardless', 'helpless', 'unarmed', 'unarmored', 'unattended', 'uncovered', 'unfortified', 'ungarrisoned', 'unguarded', 'unprotected'],
    'undefiled': ['christian', 'angelic', 'blameless', 'bleached', 'blotless', 'bright', 'chaste', 'childlike', 'clean', 'cleanly', 'clear', 'creditable'],
    'undefined': ['aleatoric', 'aleatory', 'all-knowing', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'amorphic', 'amorphous', 'anarchic', 'anonymous', 'baggy'],
    'undeliberate': ['automatic', 'casual', 'gut', 'ill-advised', 'ill-considered', 'ill-devised', 'inadvertent', 'indeliberate', 'involuntary', 'reflex', 'reflexive', 'snap'],
    'undemanding': ['blanket', 'casual', 'flexible', 'general', 'imprudent', 'indiscreet', 'indiscriminate', 'indiscriminative', 'insensitive', 'nonjudgmental', 'pliant', 'promiscuous'],
    'undemonstrated': ['apocryphal', 'groundless', 'inconclusive', 'indecisive', 'nonofficial', 'not following', 'not proved', 'unascertained', 'unattested', 'unauthentic', 'unauthenticated', 'unauthoritative'],
    'undemonstrative': ['olympian', 'actual', 'aloof', 'aseptic', 'backward', 'bashful', 'blank', 'chill', 'chilled', 'chilly', 'cold', 'constrained'],
    'undeniability': ['actuality', 'confirmability', 'demonstratability', 'doubtlessness', 'factuality', 'incontestability', 'incontrovertibility', 'indisputability', 'indubitability', 'indubitableness', 'irrefragability', 'irrefutability'],
    'undeniable': ['absolute', 'actual', 'admitting no question', 'arrant', 'authentic', 'classical', 'complete', 'confirmable', 'consummate', 'crass', 'de facto', 'decided'],
    'undeniably': ['actually', 'admittedly', 'assuredly', 'beyond doubt', 'beyond question', 'certainly', 'clearly', 'decidedly', 'demonstrably', 'doubtless', 'doubtlessly', 'for a certainty'],
    'undenied': ['actual', 'ascertained', 'attested', 'authenticated', 'categorically true', 'certain', 'certified', 'confirmed', 'corroborated', 'demonstrated', 'determined', 'documentary'],
    'undependable': ['adrift', 'afloat', 'alternating', 'amorphous', 'capricious', 'changeable', 'changeful', 'coquettish', 'dangerous', 'desultory', 'deviable', 'dizzy'],
    'under': ['answerable to', 'at a disadvantage', 'at the nadir', 'below', 'below deck', 'below par', 'below the mark', 'belowstairs', 'beneath', 'collateral', 'dependent', 'down'],
    'under attack': ['accused', 'arraigned', 'blamed', 'charged', 'cited', 'denounced', 'impeached', 'implicated', 'impugned', 'in complicity', 'incriminated', 'inculpated'],
    'under construction': ['brewing', 'forthcoming', 'going on', 'in embryo', 'in hand', 'in preparation', 'in process', 'in production', 'in progress', 'in the oven', 'in the works', 'on foot'],
    'under control': ['arrested', 'bridled', 'constrained', 'controlled', 'curbed', 'guarded', 'in check', 'in hand', 'in leading strings', 'in remission', 'inhibited', 'on leash'],
    'under no circumstances': ['god forbid', 'at no hand', 'au contraire', 'by no means', 'far from it', 'in no case', 'in no respect', 'in no wise', 'never', 'no matter what', 'nohow', 'not a bit'],
    'under the impression': ['assured', 'believing', 'certain', 'confident', 'convinced', 'devout', 'dogmatic', 'doubtless', 'faithful', 'fideistic', 'impressed with', 'persuaded'],
    'under the influence': ['addled', 'beery', 'bemused', 'besotted', 'blind drunk', 'crapulent', 'crapulous', 'dizzy', 'drenched', 'drunk', 'drunken', 'far-gone'],
    'under the sun': ['all over', 'all over hell', 'all round', 'and everywhere', 'being', 'below', 'beneath the sky', 'current', 'everywhere', 'everywheres', 'existent', 'existing'],
    'under way': ['accepted', 'accidental', 'accompanying', 'ado', 'afloat', 'afoot', 'assumed', 'astir', 'at sea', 'brewing', 'chanced', 'circumstantial'],
    'under wraps': ['abstruse', 'arcane', 'beclouded', 'blind', 'buried', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'clouded', 'concealed'],
    'underage': ['budding', 'callow', 'defalcation', 'deficiency', 'deficit', 'dewy', 'green', 'growing', 'immature', 'impubic', 'inadequacy', 'inexperienced'],
    'underbelly': ['abdomen', 'abomasum', 'bay window', 'bed', 'bedrock', 'beerbelly', 'belly', 'bottom', 'bottom side', 'breadbasket', 'breech', 'buttocks'],
    'undercoat': ['chromogen', 'coat', 'coat of paint', 'coating', 'color', 'color filter', 'color gelatin', 'colorant', 'coloring', 'dead-color', 'distemper', 'drier'],
    'undercover': ['above water', 'abstruse', 'armored', 'at anchor', 'back-door', 'backstairs', 'beclouded', 'behind the curtain', 'behind the scenes', 'behind the veil', 'blind', 'buried'],
    'undercurrent': ['affect', 'affection', 'affluence', 'afflux', 'affluxion', 'air current', 'allegory', 'allusion', 'ambiance', 'ambience', 'arcane meaning', 'assumption'],
    'undercut': ['belie', 'blow sky-high', 'blow up', 'close out', 'convert into cash', 'cut away', 'cut out', 'cut under', 'deflate', 'disconfirm', 'discredit', 'disprove'],
    'underdeveloped': ['arrested', 'backward', 'behindhand', 'callow', 'coarse', 'crude', 'defective', 'deficient', 'embryonic', 'failing', 'hypoplastic', 'immature'],
    'underdog': ['also-ran', 'booby', 'casualty', 'defeatee', 'duck', 'fall guy', 'game loser', 'good loser', 'good sport', 'little fellow', 'little guy', 'loser'],
    'underestimate': ['belittle', 'deprecate', 'depreciate', 'discount', 'disparage', 'make light of', 'make little of', 'make nothing of', 'minimize', 'miscalculate', 'misestimate', 'misjudge'],
    'underfed': ['attenuated', 'bare-handed', 'beggarly', 'cadaverous', 'corpselike', 'emacerated', 'emaciate', 'emaciated', 'empty-handed', 'famished', 'haggard', 'half-starved'],
    'undergarments': ['balmoral', 'skivvies', 'bloomers', 'body clothes', 'body stocking', 'bodywear', 'brassiere', 'briefs', 'bustle', 'camisole', 'chemise', 'combination'],
    'undergird': ['affirm', 'afford support', 'attest', 'authenticate', 'back', 'back up', 'bear', 'bear out', 'bear up', 'bed on', 'beef up', 'bolster'],
    'undergo': ['abide', 'afford', 'be exposed to', 'be subjected to', 'bear', 'bow', 'defer', 'encounter', 'endure', 'experience', 'feel', 'go through'],
    'undergraduate': ['autodidactic', 'bookish', 'cadet', 'college-bred', 'collegiate', 'freshman', 'graduate', 'junior', 'learned', 'midshipman', 'plebe', 'postgraduate'],
    'underground': ['amtrak', 'charley', 'trojan horse', 'vc', 'vietcong', 'abstruse', 'agreement to disagree', 'alienated', 'alienation', 'alternative', 'antiestablishment', 'apostasy'],
    'underhand': ['crafty', 'crooked', 'cunning', 'deceitful', 'devious', 'dishonest', 'duplicitous', 'furtive', 'guileful', 'hangdog', 'indirect', 'insidious'],
    'underhanded': ['amoral', 'artful', 'back-door', 'backstairs', 'calculating', 'chiseling', 'clandestine', 'collusive', 'conscienceless', 'corrupt', 'corrupted', 'covert'],
    'underlayer': ['band', 'bed', 'bedding', 'bedrock', 'belly', 'belt', 'bottom', 'bottom side', 'breech', 'buttocks', 'couche', 'course'],
    'underlie': ['afford support', 'back', 'back up', 'be latent', 'bear', 'bear up', 'bed on', 'bolster', 'bolster up', 'bottom on', 'brace', 'build on'],
    'underline': ['accent', 'accentuate', 'band', 'bar', 'belabor', 'blaze', 'blaze a trail', 'blemish', 'blotch', 'brand', 'chalk', 'chalk up'],
    'underling': ['assistant', 'cog', 'commonality', 'commonalty', 'creature', 'dependent', 'employee', 'feudatory', 'flunky', 'follower', 'hanger-on', 'helper'],
    'underlying': ['ab ovo', 'basal', 'basic', 'basilar', 'between the lines', 'bottom', 'cardinal', 'constituent', 'constitutive', 'covert', 'critical', 'crucial'],
    'undermanned': ['bare-handed', 'beggarly', 'empty-handed', 'famished', 'half-starved', 'ill off', 'ill-equipped', 'ill-furnished', 'ill-provided', 'impoverished', 'on short commons', 'pauperized'],
    'undermine': ['abate', 'answer', 'answer conclusively', 'argue down', 'attenuate', 'blunt', 'bugger up', 'confound', 'confute', 'contradict', 'controvert', 'cramp'],
    'undermining': ['answer', 'complete answer', 'confounding', 'confutation', 'contradiction', 'controversion', 'demolition', 'denial', 'discrediting', 'effective rejoinder', 'overthrow', 'overthrowal'],
    'underneath': ['bed', 'bedrock', 'belly', 'below', 'beneath', 'bottom', 'bottom side', 'breech', 'buttocks', 'clandestine', 'covert', 'downside'],
    'undernourished': ['attenuated', 'bare-handed', 'beggarly', 'cadaverous', 'corpselike', 'emacerated', 'emaciate', 'emaciated', 'empty-handed', 'famished', 'haggard', 'half-starved'],
    'underpass': ['access', 'aisle', 'alley', 'ambulatory', 'aperture', 'arcade', 'artery', 'avenue', 'channel', 'cloister', 'colonnade', 'communication'],
    'underpinning': ['base', 'basement', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock', 'brace', 'buttress', 'column', 'floor', 'flooring'],
    'underpinnings': ['ankle', 'bayonet legs', 'bowlegs', 'calf', 'cnemis', 'drumstick', 'foreleg', 'gamb', 'gambrel', 'gigot', 'ham', 'hind leg'],
    'underplay': ['abate', 'allay', 'alleviate', 'assuage', 'attemper', 'bank the fire', 'bedwarf', 'belittle', 'blunt', 'chasten', 'constrain', 'control'],
    'underplayed': ['actor-proof', 'all-star', 'ballet', 'balletic', 'cinematic', 'cinematographic', 'dramatic', 'dramatical', 'dramaturgic', 'film', 'filmic', 'ham'],
    'underprivileged': ['badly off', 'beggared', 'beggarly', 'bereaved', 'bereft', 'chronic poor', 'chronic poverty area', 'common', 'demeaning', 'depressed', 'depressed class', 'depressed population'],
    'underrate': ['belittle', 'decry', 'deprecate', 'depreciate', 'devaluate', 'devalue', 'disparage', 'lower', 'make light of', 'make little of', 'make nothing of', 'mark down'],
    'underripe': ['adolescent', 'at half cock', 'callow', 'fledgling', 'green', 'half-baked', 'half-cocked', 'half-grown', 'ill-digested', 'immature', 'impubic', 'juvenile'],
    'underscore': ['accent', 'accentuate', 'band', 'bar', 'belabor', 'blaze', 'blaze a trail', 'blemish', 'blotch', 'brand', 'chalk', 'chalk up'],
    'undersecretary': ['alderman', 'archon', 'bailie', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'chancellor', 'city councilman', 'city father', 'city manager', 'commissar'],
    'undersell': ['close out', 'convert into cash', 'cut under', 'dump', 'effect a sale', 'job', 'make a sale', 'market', 'merchandise', 'move', 'resell', 'retail'],
    'undersexed': ['amorous', 'carnal', 'cold', 'erogenic', 'erogenous', 'erotic', 'erotogenic', 'fleshly', 'gamic', 'heterosexual', 'inhibited', 'libidinal'],
    'underside': ['bed', 'bedrock', 'belly', 'bottom', 'bottom side', 'breech', 'buttocks', 'downside', 'fundament', 'hardpan', 'lower side', 'lowest layer'],
    'undersign': ['ok', 'accept', 'accredit', 'affirm', 'amen', 'approve', 'assure', 'attest', 'authenticate', 'authorize', 'autograph', 'back'],
    'undersized': ['lilliputian', 'tom thumb', 'bantam', 'bony', 'dumpy', 'dwarf', 'dwarfed', 'dwarfish', 'elfin', 'flat', 'flat-chested', 'fleshless'],
    'understand': ['absorb', 'accept', 'agree', 'allow', 'appreciate', 'apprehend', 'arrange', 'assimilate', 'assume', 'be acquainted with', 'be afraid', 'be apprised of'],
    'understandable': ['appreciable', 'apprehensible', 'articulate', 'ascertainable', 'clear-cut', 'cognizable', 'comprehensible', 'conceivable', 'discernible', 'discoverable', 'distinguishable', 'easily understood'],
    'understanding': ['iq', 'spartan', 'vernunft', 'abatement of differences', 'acceptation', 'accepting', 'acclamation', 'accommodation', 'accord', 'accordance', 'accordant', 'acute'],
    'understate': ['belie', 'burlesque', 'camouflage', 'caricature', 'color', 'disguise', 'distort', 'dress up', 'embellish', 'embroider', 'exaggerate', 'falsify'],
    'understated': ['attic', 'aesthetic', 'artistic', 'basic', 'chaste', 'choice', 'classic', 'excellent', 'in good taste', 'low-key', 'of choice', 'of quality'],
    'understatement': ['abstractionism', 'coloring', 'deformation', 'distortion', 'exaggeration', 'expressionism', 'false coloring', 'falsification', 'garbling', 'hyperbole', 'inaccuracy', 'injustice'],
    'understood': ['accepted', 'accounted as', 'acknowledged', 'admitted', 'agreed', 'alleged', 'appreciated', 'apprehended', 'arranged', 'ascertained', 'assumed', 'assumptive'],
    'understructure': ['base', 'basement', 'basis', 'bearing wall', 'bed', 'bedding', 'bedrock', 'bottom', 'floor', 'flooring', 'fond', 'footing'],
    'understudy': ['act for', 'advocate', 'agent', 'alter ego', 'alternate', 'alternative', 'amicus curiae', 'analogy', 'answer for', 'appear for', 'attorney', 'back up'],
    'undertake': ['accept', 'accept obligation', 'agree', 'agree to', 'answer for', 'approach', 'assay', 'assume', 'attack', 'attempt', 'bargain', 'bargain for'],
    'undertaken': ['accepted', 'agreed', 'arranged', 'assumed', 'chanced', 'compacted', 'contracted', 'covenanted', 'engaged', 'in hand', 'in process', 'in progress'],
    'undertaking': ['accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'activities', 'activity', 'adventure', 'affair', 'affairs', 'agreement'],
    'undertone': ['affective meaning', 'air', 'allegory', 'allusion', 'arcane meaning', 'aspiration', 'assumption', 'atmosphere', 'aura', 'bated breath', 'bearing', 'breath'],
    'undertow': ['affluence', 'afflux', 'affluxion', 'concourse', 'confluence', 'conflux', 'coral heads', 'course', 'crosscurrent', 'current', 'defluxion', 'downflow'],
    'undervalue': ['belittle', 'decry', 'deprecate', 'depreciate', 'devaluate', 'devalue', 'disparage', 'lower', 'make light of', 'make little of', 'make nothing of', 'mark down'],
    'underweight': ['avoirdupois', 'bantamweight', 'beef', 'beefiness', 'boniness', 'bony', 'deadweight', 'fatness', 'featherweight', 'flat', 'flat-chested', 'fleshless'],
    'underworld': ['abaddon', 'black hand', 'cosa nostra', 'dis', 'gehenna', 'hades', 'hell', 'naraka', 'orcus', 'pandemonium', 'sheol', 'tophet'],
    'underwrite': ['ok', 'accede to', 'accept', 'accredit', 'affirm', 'agree to', 'amen', 'approve', 'arm', 'armor', 'assure', 'attest'],
    'underwriter': ['accident insurance', 'actuary', 'annuity', 'approver', 'assurance', 'aviation insurance', 'bail bond', 'bailsman', 'bond', 'bondsman', 'business life insurance', 'casualty insurance'],
    'undeserved': ['illegal', 'inequitable', 'iniquitous', 'nonmeritorious', 'not coming', 'not outstanding', 'outrageous', 'preposterous', 'unbalanced', 'undeserving', 'undue', 'unearned'],
    'undesigned': ['automatic', 'casual', 'gut', 'ill-advised', 'ill-considered', 'ill-devised', 'inadvertent', 'indeliberate', 'involuntary', 'reflex', 'reflexive', 'snap'],
    'undesigning': ['arcadian', 'bucolic', 'genuine', 'guileless', 'homespun', 'honest', 'inartificial', 'native', 'natural', 'naturelike', 'pastoral', 'real'],
    'undesirable': ['dp', 'ishmael', 'bad', 'bad child', 'bad example', 'bad man', 'bad news', 'bad person', 'bad woman', 'bitter', 'castaway', 'declasse'],
    'undestroyed': ['abiding', 'bright', 'changeless', 'constant', 'continuing', 'durable', 'enduring', 'firm', 'fixed', 'fresh', 'frozen', 'harmless'],
    'undetached': ['antiblack', 'biased', 'chauvinistic', 'colored', 'doctrinaire', 'dogmatic', 'influenced', 'interested', 'involved', 'jaundiced', 'know-nothing', 'nonobjective'],
    'undetermined': ['accidental', 'adventitious', 'aleatoric', 'aleatory', 'ambitendent', 'ambivalent', 'amorphous', 'at issue', 'at loose ends', 'bleary', 'blobby', 'blurred'],
    'undeveloped': ['a novice at', 'a stranger to', 'adulterated', 'archaic', 'arrested', 'backward', 'behindhand', 'blemished', 'budding', 'callow', 'coarse', 'crude'],
    'undeviating': ['accordant', 'alike', 'arrowlike', 'automatic', 'balanced', 'changeless', 'close', 'consistent', 'consonant', 'constant', 'continuous', 'correspondent'],
    'undevised': ['ad-lib', 'caught napping', 'caught off balance', 'caught short', 'extemporaneous', 'extemporized', 'haphazard', 'hasty', 'impromptu', 'improvised', 'inadvertent', 'makeshift'],
    'undifferentiated': ['abstract', 'accordant', 'agnate', 'akin', 'alike', 'analogous', 'articulated', 'austere', 'automatic', 'balanced', 'bare', 'basic'],
    'undigested': ['adolescent', 'at half cock', 'callow', 'fledgling', 'green', 'half-baked', 'half-cocked', 'half-grown', 'ill-digested', 'immature', 'impubic', 'juvenile'],
    'undignified': ['doric', 'barbaric', 'barbarous', 'cacophonous', 'chintzy', 'clumsy', 'coarse', 'crude', 'doggerel', 'dysphemistic', 'graceless', 'gross'],
    'undiluted': ['absolute', 'bare', 'clarified', 'clear', 'distilled', 'naked', 'neat', 'perfect', 'plain', 'pure', 'purified', 'rectified'],
    'undiminished': ['complete', 'developed', 'entire', 'full', 'full-fledged', 'full-grown', 'full-scale', 'global', 'going strong', 'in full force', 'in full swing', 'intact'],
    'undine': ['davy', 'davy jones', 'neptune', 'nereid', 'oceanid', 'oceanus', 'poseidon', 'thetis', 'triton', 'elemental', 'elemental spirit', 'fresh-water nymph'],
    'undiplomatic': ['airy', 'brash', 'careless', 'casual', 'cursory', 'degage', 'disregardant', 'disregardful', 'easygoing', 'flippant', 'forgetful', 'free and easy'],
    'undirected': ['aberrant', 'aberrative', 'aimless', 'amorphous', 'capricious', 'casual', 'causeless', 'circuitous', 'departing', 'designless', 'desultory', 'deviant'],
    'undiscerning': ['ableptical', 'amaurotic', 'benighted', 'bereft of light', 'blind', 'blindfold', 'blindfolded', 'color-blind', 'dark', 'dim-sighted', 'eyeless', 'hemeralopic'],
    'undisciplined': ['adrift', 'afloat', 'alternating', 'amorphous', 'bad', 'bibulous', 'capricious', 'changeable', 'changeful', 'crapulent', 'crapulous', 'desultory'],
    'undisclosable': ['arcane', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'cryptic', 'dark', 'enigmatic', 'esoteric', 'hermetic'],
    'undisclosed': ['able', 'arcane', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'cryptic', 'dark', 'enigmatic', 'esoteric'],
    'undiscoverable': ['able', 'beyond reach', 'closed forever to', 'closed to', 'enigmatic', 'impenetrable', 'impervious', 'inaccessible', 'incalculable', 'incognizable', 'lost to', 'mysterious'],
    'undiscovered': ['able', 'enigmatic', 'incalculable', 'incognizable', 'invisible', 'mysterious', 'puzzling', 'sealed', 'strange', 'unapparent', 'unapprehended', 'unascertained'],
    'undiscriminating': ['apathetic', 'ataractic', 'blanket', 'blase', 'careless', 'casual', 'devil-may-care', 'disinterested', 'dispassionate', 'disregardful', 'easygoing', 'general'],
    'undisguised': ['apparent', 'authentic', 'beholdable', 'bona fide', 'candid', 'card-carrying', 'clear', 'detectable', 'dinkum', 'discernible', 'disclosed', 'evident'],
    'undisputed': ['accepted', 'acknowledged', 'admitted', 'believed', 'beyond question', 'certain', 'clear', 'conclusive', 'credited', 'definite', 'doubtless', 'explicit'],
    'undissembling': ['arcadian', 'bucolic', 'candid', 'genuine', 'guileless', 'homespun', 'inartificial', 'native', 'natural', 'naturelike', 'open', 'openhearted'],
    'undistinguished': ['alike', 'common', 'commonplace', 'everyday', 'homely', 'homespun', 'humble', 'humble-looking', 'humble-visaged', 'humblest', 'ignotus', 'indifferent'],
    'undistorted': ['arrowlike', 'authentic', 'bona fide', 'candid', 'card-carrying', 'dead straight', 'dinkum', 'direct', 'even', 'faithful', 'flat', 'following the letter'],
    'undisturbed': ['at rest', 'calm', 'cloistered', 'cool', 'dwindling', 'ebbing', 'even-tenored', 'halcyon', 'hushed', 'impassive', 'isolated', 'moldering'],
    'undivided': ['a certain', 'allied', 'an', 'any', 'any one', 'assembled', 'associated', 'atomic', 'banded together', 'bound', 'bracketed', 'collected'],
    'undo': ['ko', 'abate', 'abolish', 'abrogate', 'annihilate', 'annul', 'answer', 'atomize', 'bare', 'beat', 'beat all hollow', 'beat hollow'],
    'undoing': ['waterloo', 'abasement', 'affliction', 'annulment', 'bane', 'beating', 'blight', 'bloodbath', 'blue ruin', 'breakup', 'cancellation', 'carnage'],
    'undone': ['abandoned', 'adrift', 'afloat', 'aghast', 'all up with', 'appalled', 'ashen', 'astounded', 'ausgespielt', 'awed', 'awestricken', 'awestruck'],
    'undoubted': ['accepted', 'actual', 'ascertained', 'attested', 'authenticated', 'believed', 'beyond question', 'bona fide', 'categorically true', 'certain', 'certified', 'confirmed'],
    'undoubtedly': ['actually', 'admittedly', 'assuredly', 'beyond doubt', 'beyond question', 'certainly', 'clearly', 'definitely', 'doubtless', 'doubtlessly', 'easily', 'explicitly'],
    'undoubting': ['absolute', 'admitting no exception', 'all-out', 'arrogant', 'assured', 'believing', 'categorical', 'certain', 'clear', 'cocksure', 'complete', 'conclusive'],
    'undreamed of': ['breakaway', 'imageless', 'offbeat', 'rare', 'recherche', 'sui generis', 'uncommon', 'unconceived', 'unconceptualized', 'unconsidered', 'uncustomary', 'unexpected'],
    'undress': ['baldness', 'bareness', 'beauty unadorned', 'casual clothes', 'debunk', 'denude', 'disarray', 'discover', 'dishabille', 'dismantle', 'disrobe', 'do a strip-tease'],
    'undressed': ['bald', 'bare', 'blank', 'clothesless', 'crude', 'decollete', 'disrobed', 'en deshabille', 'garbless', 'garmentless', 'half-clothed', 'in dishabille'],
    'undue': ['a bit much', 'abandoned', 'aberrant', 'abnormal', 'abominable', 'atrocious', 'boundless', 'criminal', 'cutthroat', 'delinquent', 'deviant', 'disgraceful'],
    'undulant': ['alternate', 'beating', 'bent', 'billowing', 'billowy', 'circling', 'curvaceous', 'curvate', 'curvated', 'curve', 'curved', 'curvesome'],
    'undulate': ['alternate', 'bank', 'be here again', 'be poised', 'billow', 'brandish', 'break', 'circle', 'comb', 'come again', 'come and go', 'come around'],
    'unduly': ['abominably', 'agonizingly', 'awfully', 'baldly', 'balefully', 'bitterly', 'blatantly', 'brashly', 'confoundedly', 'cruelly', 'damnably', 'deadly'],
    'undurable': ['brittle', 'capricious', 'changeable', 'corruptible', 'deciduous', 'dying', 'ephemeral', 'evanescent', 'fading', 'fickle', 'fleeting', 'flitting'],
    'undutiful': ['laodicean', 'apostate', 'atheistic', 'backsliding', 'blasphemous', 'disobedient', 'fallen', 'fallen from grace', 'froward', 'impious', 'indevotional', 'indevout'],
    'undying': ['abiding', 'amaranthine', 'continuing', 'continuous', 'deathless', 'embalmed', 'ever-fresh', 'everlasting', 'fadeless', 'frozen', 'immortal', 'imperishable'],
    'uneager': ['afraid', 'averse', 'backward', 'desireless', 'hesitant', 'inappetent', 'indisposed', 'loath', 'loveless', 'nirvanic', 'passionless', 'reluctant'],
    'unearth': ['ascertain', 'avulse', 'bring to light', 'catch on', 'come across', 'cut out', 'delve', 'deracinate', 'determine', 'dig', 'dig out', 'dig up'],
    'unearthly': ['christlike', 'christly', 'elysian', 'god-fearing', 'olympian', 'a bit thick', 'a bit thin', 'abnormal', 'absurd', 'airy', 'angelic', 'arcane'],
    'uneasiness': ['faustianism', 'abashment', 'agitation', 'all-overs', 'angst', 'anguish', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern', 'anxious seat'],
    'uneasy': ['abashed', 'afflicted', 'agitated', 'all nerves', 'all-overish', 'ambiguous', 'anguished', 'antsy', 'antsy-pantsy', 'anxious', 'anxioused up', 'apprehensive'],
    'uneducated': ['gothic', 'philistine', 'barbarous', 'benighted', 'bookless', 'colloquial', 'common', 'conversational', 'deceived', 'empty-headed', 'everyday', 'familiar'],
    'unelevated': ['couchant', 'crouched', 'debased', 'depressed', 'flat', 'knee-high', 'knocked flat', 'laid low', 'low', 'low-built', 'low-hung', 'low-level'],
    'unembarrassed': ['bold', 'brazen', 'brazenfaced', 'clear', 'disembarrassed', 'exhibitionistic', 'flagrant', 'forward', 'immodest', 'notorious', 'shameless', 'unabashed'],
    'unembellished': ['arcadian', 'bald', 'bare', 'blank', 'bucolic', 'common', 'commonplace', 'dull', 'flat', 'genuine', 'homespun', 'humdrum'],
    'unembodied': ['airy', 'asomatous', 'astral', 'bodiless', 'decarnate', 'decarnated', 'discarnate', 'disembodied', 'ethereal', 'extramundane', 'ghostly', 'immaterial'],
    'unemotional': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'callous', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity', 'cold-blooded'],
    'unemployable': ['at leisure', 'at liberty', 'at loose ends', 'available', 'disengaged', 'fallow', 'free', 'functionless', 'idle', 'in disrepair', 'inapplicable', 'inoperable'],
    'unemployed': ['at a standstill', 'at anchor', 'at leisure', 'at liberty', 'at loose ends', 'available', 'beggar', 'bummer', 'cadger', 'coupon clippers', 'dead-still', 'disengaged'],
    'unending': ['ageless', 'amaranthine', 'articulated', 'catenated', 'ceaseless', 'coeternal', 'concatenated', 'connected', 'constant', 'continual', 'continued', 'continuing'],
    'unendowed': ['amateurish', 'incapable', 'incapable of', 'incompetent', 'ineffective', 'inefficient', 'inept', 'inferior', 'semiskilled', 'unable', 'unable to', 'unaccomplished'],
    'unenjoyable': ['bitter', 'disagreeable', 'dislikable', 'displeasing', 'distasteful', 'sour', 'thankless', 'ugly', 'unalluring', 'unamusing', 'unappealing', 'unappetizing'],
    'unenlightened': ['ableptical', 'amaurotic', 'awkward', 'benighted', 'bereft of light', 'blankminded', 'blind', 'callow', 'color-blind', 'dark', 'dim-sighted', 'dumb'],
    'unenterprising': ['bone-lazy', 'cadging', 'canny', 'careful', 'cautious', 'circumspect', 'deliberate', 'dilatory', 'discreet', 'do-nothing', 'doless', 'dronish'],
    'unenthusiastic': ['apathetic', 'backward', 'balking', 'balky', 'blase', 'cold', 'cool', 'desireless', 'dilatory', 'grudging', 'halfhearted', 'inappetent'],
    'unequal': ['assorted', 'asymmetric', 'at odds', 'at variance', 'broken', 'capricious', 'careening', 'catchy', 'changeable', 'changing', 'choppy', 'contrary'],
    'unequaled': ['beyond compare', 'beyond comparison', 'easily first', 'facile princeps', 'immortal', 'incomparable', 'inimitable', 'invincible', 'matchless', 'nulli secundus', 'only', 'peerless'],
    'unequipped': ['disqualified', 'ill-equipped', 'ill-fitted', 'ill-furnished', 'ill-provided', 'ill-qualified', 'inadequate', 'incapable', 'incompetent', 'ineffective', 'ineffectual', 'ineligible'],
    'unequivocal': ['absolute', 'admitting no exception', 'all-out', 'apodictic', 'apparent', 'arrant', 'artless', 'bluff', 'blunt', 'bound', 'broad', 'brusque'],
    'unerring': ['close', 'constant', 'delicate', 'direct', 'even', 'exact', 'express', 'faithful', 'fine', 'incorrupt', 'incorrupted', 'inerrable'],
    'unescorted': ['alienated', 'alone', 'aloof', 'apart', 'companionless', 'detached', 'friendless', 'homeless', 'insular', 'isolated', 'kithless', 'lone'],
    'unessential': ['accessory', 'accident', 'accidental', 'addendum', 'addition', 'additional', 'adjunct', 'adrift', 'adscititious', 'adventitious', 'aleatory', 'appendage'],
    'unestablished': ['at issue', 'conditional', 'conditioned', 'contingent', 'dependent', 'depending', 'exiled', 'groundless', 'homeless', 'houseless', 'in question', 'in suspense'],
    'unethical': ['amoral', 'conscienceless', 'corrupt', 'corrupted', 'criminal', 'crooked', 'dark', 'devious', 'dishonest', 'dishonorable', 'doubtful', 'dubious'],
    'uneuphonious': ['doric', 'barbaric', 'barbarous', 'cacophonous', 'clumsy', 'coarse', 'crude', 'doggerel', 'dysphemistic', 'graceless', 'gross', 'harsh'],
    'uneven': ['adulterated', 'asperous', 'asymmetric', 'blemished', 'broken', 'bumpy', 'capricious', 'careening', 'catchy', 'changeable', 'changing', 'choppy'],
    'unevenly': ['at irregular intervals', 'at random', 'brokenly', 'by catches', 'by fits', 'by jerks', 'by snatches', 'capriciously', 'chaotically', 'choppily', 'desultorily', 'disconnectedly'],
    'unevenness': ['adulteration', 'arrhythmia', 'asperity', 'asymmetry', 'brokenness', 'bumpiness', 'capriciousness', 'changeability', 'changeableness', 'choppiness', 'contrariety', 'cragginess'],
    'uneventful': ['blah', 'broken-record', 'commonplace', 'drearisome', 'dreary', 'dry', 'dryasdust', 'dull', 'dusty', 'everlasting', 'harping', 'humdrum'],
    'unexacting': ['blanket', 'casual', 'flexible', 'general', 'imprudent', 'inaccurate', 'indiscreet', 'indiscriminate', 'indiscriminative', 'inexact', 'insensitive', 'nonjudgmental'],
    'unexaggerated': ['authentic', 'bona fide', 'candid', 'card-carrying', 'dinkum', 'following the letter', 'genuine', 'good', 'honest', 'honest-to-god', 'inartificial', 'lawful'],
    'unexampled': ['alone', 'exceptional', 'extraordinary', 'fabulous', 'indescribable', 'ineffable', 'legendary', 'lone', 'marvelous', 'mythical', 'noteworthy', 'phenomenal'],
    'unexcelled': ['beyond compare', 'beyond comparison', 'easily first', 'facile princeps', 'immortal', 'incomparable', 'inimitable', 'invincible', 'matchless', 'nulli secundus', 'peerless', 'second to none'],
    'unexceptionable': ['ok', 'above suspicion', 'acceptable', 'adequate', 'admirable', 'admissible', 'agreeable', 'all right', 'alright', 'believable', 'better than nothing', 'beyond all praise'],
    'unexceptional': ['acceptable', 'adequate', 'all right', 'average', 'bourgeois', 'common', 'commonplace', 'conventional', 'garden', 'garden-variety', 'general', 'middle-class'],
    'unexercised': ['extra', 'fresh', 'held back', 'held in reserve', 'held out', 'in abeyance', 'in hand', 'mint', 'new', 'original', 'pristine', 'put aside'],
    'unexpected': ['abrupt', 'accidental', 'adventitious', 'aleatory', 'antic', 'breakaway', 'casual', 'causeless', 'chance', 'chancy', 'contingent', 'destinal'],
    'unexpectedness': ['abruptness', 'improbability', 'inexpectance', 'inexpectancy', 'inexpectation', 'no expectation', 'nonexpectation', 'precipitance', 'precipitancy', 'precipitateness', 'precipitatousness', 'suddenness'],
    'unexplained': ['able', 'enigmatic', 'incalculable', 'incognizable', 'invisible', 'mysterious', 'puzzling', 'sealed', 'strange', 'unapparent', 'unapprehended', 'unascertained'],
    'unexplored': ['able', 'enigmatic', 'incalculable', 'incognizable', 'invisible', 'mysterious', 'puzzling', 'sealed', 'strange', 'unapparent', 'unapprehended', 'unascertained'],
    'unexposed': ['able', 'enigmatic', 'incalculable', 'incognizable', 'invisible', 'mysterious', 'puzzling', 'sealed', 'strange', 'unapparent', 'unapprehended', 'unascertained'],
    'unexpressed': ['implicit', 'implied', 'inferred', 'silent', 'tacit', 'undeclared', 'understood', 'unmentioned', 'unproclaimed', 'unpronounced', 'unpublished', 'unrecorded'],
    'unexpurgated': ['complete', 'developed', 'entire', 'full', 'full-fledged', 'full-grown', 'full-scale', 'global', 'intact', 'mature', 'matured', 'ripe'],
    'unextended': ['airy', 'asomatous', 'astral', 'bodiless', 'decarnate', 'decarnated', 'discarnate', 'disembodied', 'ethereal', 'extramundane', 'ghostly', 'immaterial'],
    'unextinguished': ['ablaze', 'afire', 'aflame', 'aflicker', 'aglow', 'alight', 'ardent', 'blazing', 'burning', 'candent', 'candescent', 'comburent'],
    'unfacile': ['artless', 'half-assed', 'inadept', 'inapt', 'inattentive', 'inefficient', 'inept', 'inexpert', 'mediocre', 'pedestrian', 'poor', 'skill-less'],
    'unfactual': ['aberrant', 'abroad', 'adrift', 'all abroad', 'all off', 'all wrong', 'amiss', 'approximate', 'approximative', 'askew', 'astray', 'at fault'],
    'unfaded': ['bright', 'crude', 'fresh', 'going strong', 'harmless', 'impure', 'in full force', 'in full swing', 'inviolate', 'mint', 'native', 'pristine'],
    'unfading': ['abiding', 'age-long', 'aged', 'amaranthine', 'ancient', 'antique', 'changeless', 'chronic', 'colorfast', 'constant', 'continuing', 'deathless'],
    'unfailing': ['abiding', 'assiduous', 'calculable', 'certain', 'changeless', 'consistent', 'constant', 'continuing', 'dependable', 'devoted', 'diligent', 'dogged'],
    'unfaithful': ['derelict', 'disaffected', 'disloyal', 'disregardful', 'faithless', 'false', 'fickle', 'inattentive', 'inconstant', 'inobservant', 'negligent', 'nonadherent'],
    'unfaithfulness': ['punic faith', 'adulterous affair', 'adultery', 'affair', 'amour', 'bad faith', 'barratry', 'breach of faith', 'breach of promise', 'breach of trust', 'cuckoldry', 'dereliction'],
    'unfaltering': ['abiding', 'arrogant', 'assiduous', 'assured', 'calm', 'cocksure', 'confident', 'constant', 'continuing', 'convinced', 'coolheaded', 'decided'],
    'unfamiliar': ['able', 'awkward', 'bizarre', 'blankminded', 'breakaway', 'callow', 'curious', 'different', 'dumb', 'empty', 'empty-headed', 'enigmatic'],
    'unfamiliar with': ['a novice at', 'a stranger to', 'callow', 'disaccustomed', 'fresh', 'green', 'green as grass', 'ignorant', 'immature', 'inexperienced', 'new to', 'raw'],
    'unfamiliarity': ['agnosticism', 'amateurishness', 'amateurism', 'blankmindedness', 'brand-newness', 'callowness', 'dewiness', 'disaccustomedness', 'empty-headedness', 'freshness', 'gloss of novelty', 'greenhornism'],
    'unfanciful': ['arid', 'authentic', 'barren', 'bona fide', 'candid', 'card-carrying', 'dinkum', 'dry', 'dull', 'earthbound', 'following the letter', 'genuine'],
    'unfashionable': ['bohemian', 'back-number', 'beat', 'behind the times', 'breakaway', 'dated', 'far out', 'free and easy', 'fringy', 'has-been', 'heretical', 'heterodox'],
    'unfasten': ['cast off', 'detach', 'disengage', 'doff', 'free', 'liberate', 'loose', 'loosen', 'release', 'remove', 'take off', 'unbar'],
    'unfathomable': ['greek to one', 'abysmal', 'abyssal', 'all-comprehensive', 'all-inclusive', 'ambiguous', 'beyond understanding', 'bottomless', 'boundless', 'cavernous', 'countless', 'deep as hell'],
    'unfathomed': ['able', 'abysmal', 'abyssal', 'bottomless', 'cavernous', 'colossal', 'deep as hell', 'enigmatic', 'enormous', 'fathomless', 'gaping', 'immense'],
    'unfavorable': ['adversary', 'adversative', 'adverse', 'against', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'apocalyptic', 'bad', 'baleful'],
    'unfavorably': ['afield', 'amiss', 'askance', 'askant', 'astray', 'awry', 'badly', 'captiously', 'censoriously', 'conflictingly', 'contrarily', 'critically'],
    'unfearful': ['audacious', 'aweless', 'bold', 'confident', 'courageous', 'dauntless', 'dreadless', 'fearless', 'intrepid', 'unafraid', 'unapprehensive', 'unbashful'],
    'unfeasible': ['beyond one', 'impracticable', 'impractical', 'infeasible', 'inoperable', 'insuperable', 'insurmountable', 'too much for', 'unachievable', 'unattainable', 'uncompassable', 'undoable'],
    'unfed': ['lenten', 'bare-handed', 'beggarly', 'empty-handed', 'famished', 'fasting', 'half-starved', 'ill off', 'ill-equipped', 'ill-furnished', 'ill-provided', 'impoverished'],
    'unfeeling': ['abiotic', 'affectless', 'analgesia', 'anesthesia', 'anesthetized', 'arctic', 'asleep', 'autistic', 'azoic', 'benumbed', 'blunt', 'bowelless'],
    'unfeigning': ['arcadian', 'authentic', 'bona fide', 'bucolic', 'candid', 'card-carrying', 'dinkum', 'direct', 'following the letter', 'genuine', 'good', 'guileless'],
    'unfelt': ['asleep', 'benumbed', 'callous', 'dead', 'deadened', 'dull', 'impassible', 'imperceptive', 'impercipient', 'insensate', 'insensible', 'insensitive'],
    'unfeminine': ['boorish', 'caddish', 'coarse', 'crude', 'hoyden', 'ill-bred', 'inconsiderate', 'insensitive', 'loutish', 'louty', 'mannified', 'mannish'],
    'unfetter': ['cast off', 'detach', 'disengage', 'doff', 'free', 'liberate', 'loose', 'loosen', 'release', 'remove', 'take off', 'unbar'],
    'unfilled': ['abandoned', 'available', 'deserted', 'dog-hungry', 'empty', 'famished', 'famishing', 'fasting', 'forsaken', 'free', 'godforsaken', 'half-famished'],
    'unfinish': ['callowness', 'coarseness', 'crudeness', 'crudity', 'greenness', 'immatureness', 'immaturity', 'nondevelopment', 'oversimplicity', 'oversimplification', 'rawness', 'reductionism'],
    'unfinished': ['adulterated', 'amateurish', 'arrested', 'backward', 'blemished', 'coarse', 'crude', 'dabbling', 'damaged', 'defective', 'deficient', 'dilettante'],
    'unfit': ['aberrant', 'abnormal', 'abominable', 'atrocious', 'bad', 'criminal', 'delinquent', 'deviant', 'discordant', 'disgraceful', 'disqualified', 'evil'],
    'unfixed': ['adrift', 'afloat', 'alternating', 'amorphous', 'at issue', 'capricious', 'changeable', 'changeful', 'clear', 'conditional', 'conditioned', 'contingent'],
    'unflagging': ['ardent', 'assiduous', 'constant', 'continuing', 'diligent', 'dogged', 'enduring', 'energetic', 'faithful', 'fervent', 'going strong', 'hard'],
    'unflappable': ['balanced', 'bovine', 'collected', 'composed', 'constant', 'cool', 'dispassionate', 'dull', 'easy', 'even-tempered', 'fast', 'fiducial'],
    'unflattering': ['authentic', 'bona fide', 'candid', 'card-carrying', 'dinkum', 'following the letter', 'genuine', 'good', 'guileless', 'harsh', 'honest', 'honest-to-god'],
    'unflavored': ['dead', 'dilute', 'diluted', 'fade', 'flat', 'flavorless', 'gruelly', 'inane', 'indifferent', 'insipid', 'jejune', 'mild'],
    'unflawed': ['absolute', 'beyond all praise', 'chaste', 'defectless', 'faultless', 'flawless', 'ideal', 'immaculate', 'impeccable', 'indefectible', 'indefective', 'infallible'],
    'unfledged': ['a novice at', 'a stranger to', 'adolescent', 'at half cock', 'budding', 'callow', 'dewy', 'ever-new', 'evergreen', 'firsthand', 'fledgling', 'fresh'],
    'unflinching': ['assiduous', 'balanced', 'calm', 'constant', 'continuing', 'cool', 'coolheaded', 'diligent', 'dogged', 'enduring', 'faithful', 'fast'],
    'unfold': ['account for', 'affect', 'allegorize', 'amplify', 'attend', 'bare', 'be revealed', 'become of', 'betoken', 'branch', 'branch out', 'brandish'],
    'unfolding': ['advancing', 'amplification', 'anthesis', 'apocalypse', 'apparition', 'appearance', 'appearing', 'arising', 'avatar', 'baring', 'bloom', 'blooming'],
    'unforced': ['a beneplacito', 'a discretion', 'abandoned', 'ad arbitrium', 'ad lib', 'ad libitum', 'al piacere', 'arbitrary', 'at choice', 'at pleasure', 'at will', 'autonomous'],
    'unforeseeable': ['accidental', 'adventitious', 'agnostic', 'aleatory', 'ambiguous', 'capricious', 'casual', 'causeless', 'chance', 'chancy', 'changeable', 'contingent'],
    'unforeseen': ['abrupt', 'accidental', 'adventitious', 'aleatory', 'casual', 'causeless', 'chance', 'chancy', 'contingent', 'destinal', 'dicey', 'electrifying'],
    'unforgettable': ['celebrated', 'conspicuous', 'distinguished', 'eminent', 'esteemed', 'estimable', 'exceptional', 'extraordinary', 'haunting', 'indelible', 'marked', 'memorable'],
    'unforgivable': ['abominable', 'arrant', 'atrocious', 'bad', 'base', 'black', 'blamable', 'blameworthy', 'criminal', 'damnable', 'dark', 'disgraceful'],
    'unforgiving': ['bowelless', 'cruel', 'dog-eat-dog', 'flinty', 'hard', 'harsh', 'heartless', 'inclement', 'inexorable', 'merciless', 'pitiless', 'relentless'],
    'unformed': ['amorphous', 'arrested', 'backward', 'budding', 'callow', 'coarse', 'crude', 'dewy', 'embryonic', 'green', 'growing', 'immature'],
    'unfortified': ['absolute', 'bare', 'bare-handed', 'clarified', 'clear', 'defenseless', 'distilled', 'guardless', 'helpless', 'naked', 'neat', 'purified'],
    'unfortunate': ['abortive', 'afflictive', 'apocalyptic', 'awful', 'awkward', 'bad', 'badly off', 'baleful', 'baneful', 'black', 'bodeful', 'boding'],
    'unfortunately': ['by ill hap', 'by ill luck', 'impolitically', 'impoliticly', 'in adverse circumstances', 'inadvisably', 'inappropriately', 'inaptly', 'inauspiciously', 'incongruously', 'inconveniently', 'ineptly'],
    'unfounded': ['barmecidal', 'barmecide', 'airy', 'apparent', 'apparitional', 'autistic', 'baseless', 'bottomless', 'chimeric', 'contrary to fact', 'deceptive', 'delusional'],
    'unfrequented': ['apart', 'detached', 'in a backwater', 'insular', 'isolated', 'out-of-the-way', 'out-of-the-world', 'quarantined', 'remote', 'removed', 'retired', 'secluded'],
    'unfriendliness': ['aggression', 'aggressiveness', 'antagonism', 'autism', 'bashfulness', 'bellicism', 'bellicosity', 'belligerence', 'belligerency', 'chauvinism', 'chill', 'chilliness'],
    'unfriendly': ['adversary', 'adversative', 'adverse', 'aggressive', 'alien', 'allergic', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'autistic', 'averse'],
    'unfrock': ['boot', 'bounce', 'break', 'bring into discredit', 'bring low', 'bring shame upon', 'bump', 'bust', 'can', 'cashier', 'cast reproach upon', 'debase'],
    'unfrozen': ['aestival', 'blood-hot', 'blood-warm', 'calid', 'equatorial', 'genial', 'luke', 'lukewarm', 'mild', 'room-temperature', 'subtropical', 'summery'],
    'unfruitful': ['acarpous', 'arid', 'barren', 'celibate', 'childless', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'effete', 'exhausted'],
    'unfulfilled': ['anguished', 'anxious', 'beefing', 'bellyaching', 'bitching', 'bored', 'cheerless', 'complaining', 'complaintful', 'crabbing', 'crabby', 'cranky'],
    'unfurl': ['bare', 'break the seal', 'bring to light', 'develop', 'disclose', 'discover', 'dismask', 'draw the veil', 'expose', 'impart', 'lay bare', 'lay open'],
    'unfussy': ['spartan', 'austere', 'casual', 'common', 'degage', 'inaccurate', 'inexact', 'informal', 'inornate', 'low-pressure', 'relaxed', 'severe'],
    'ungag': ['loose', 'loosen', 'unbar', 'unbind', 'unbolt', 'unbridle', 'unbuckle', 'uncage', 'unchain', 'unfetter', 'unhandcuff', 'unhobble'],
    'ungainly': ['all thumbs', 'awkward', 'blunderheaded', 'blundering', 'boorish', 'bumbling', 'bungling', 'butterfingered', 'careless', 'clownish', 'clumsy', 'clumsy-fisted'],
    'ungallant': ['discourteous', 'disrespectful', 'gritless', 'gutless', 'heartless', 'impolite', 'inaffable', 'insolent', 'pluckless', 'rude', 'spiritless', 'spunkless'],
    'ungenerous': ['authoritarian', 'avaricious', 'bigot', 'bigoted', 'borne', 'cheap', 'close', 'closed', 'closefisted', 'constricted', 'cramped', 'creedbound'],
    'ungentlemanly': ['boorish', 'caddish', 'coarse', 'crude', 'ill-bred', 'inconsiderate', 'insensitive', 'loutish', 'louty', 'nasty', 'offensive', 'tactless'],
    'ungenuine': ['affected', 'apocryphal', 'artificial', 'assumed', 'bastard', 'bogus', 'brummagem', 'colorable', 'colored', 'counterfeit', 'counterfeited', 'distorted'],
    'ungettable': ['beyond reach', 'closed forever to', 'closed to', 'impenetrable', 'impervious', 'inaccessible', 'lost to', 'out of reach', 'un-come-at-able', 'unaccessible', 'unapproachable', 'unattainable'],
    'ungiving': ['adamant', 'adamantine', 'cast-iron', 'close', 'dour', 'firm', 'flinty', 'grim', 'hard', 'hard-core', 'immovable', 'immutable'],
    'unglorified': ['ignotus', 'inglorious', 'little known', 'nameless', 'no credit to', 'obscure', 'renownless', 'uncelebrated', 'undistinguished', 'unfamed', 'unheard-of', 'unhonored'],
    'unglue': ['cast off', 'detach', 'diffuse', 'disengage', 'disjoin', 'disperse', 'doff', 'ease', 'ease off', 'free', 'let go', 'let up'],
    'ungodliness': ['amorality', 'backsliding', 'carnality', 'criminality', 'delinquency', 'evil', 'evil nature', 'godlessness', 'immorality', 'impiety', 'impurity', 'irreligion'],
    'ungodly': ['adamic', 'a bit thick', 'a bit thin', 'absurd', 'appalling', 'atheistic', 'awful', 'backsliding', 'bad', 'barbarous', 'beastly', 'beyond belief'],
    'ungovernable': ['beyond control', 'breachy', 'contumacious', 'defiant', 'disobedient', 'fractious', 'incorrigible', 'indocile', 'indomitable', 'insuppressible', 'intractable', 'irrepressible'],
    'ungoverned': ['abandoned', 'anguished', 'anxious', 'beefing', 'bellyaching', 'bitching', 'bored', 'cheerless', 'complaining', 'complaintful', 'crabbing', 'crabby'],
    'ungraceful': ['doric', 'all thumbs', 'asymmetrical', 'awkward', 'barbaric', 'barbarous', 'blunderheaded', 'blundering', 'boorish', 'bumbling', 'bungling', 'butterfingered'],
    'ungracious': ['abrupt', 'bluff', 'brusque', 'churlish', 'closed', 'disagreeable', 'discourteous', 'disrespectful', 'gauche', 'gruff', 'ill', 'ill-bred'],
    'ungraded': ['aimless', 'amorphous', 'capricious', 'casual', 'desultory', 'disarticulated', 'discontinuous', 'disjunct', 'disordered', 'dispersed', 'disproportionate', 'erratic'],
    'ungrounded': ['baseless', 'built on sand', 'empty', 'groundless', 'idle', 'ill-founded', 'not well-founded', 'unbased', 'unfounded', 'unsupportable', 'unsupported', 'unsustainable'],
    'ungrudging': ['accordant', 'acquiescent', 'affirmative', 'agreeable', 'agreeing', 'approving', 'assenting', 'bighearted', 'bounteous', 'bountiful', 'compliable', 'compliant'],
    'unguarded': ['arbitrary', 'artless', 'asleep', 'bare-handed', 'bluff', 'blunt', 'born yesterday', 'broad', 'brusque', 'candid', 'capricious', 'careless'],
    'unguent': ['adipose', 'balm', 'balsam', 'blubbery', 'brilliantine', 'buttery', 'butyraceous', 'cerate', 'chrism', 'chrismal', 'chrismatory', 'cold cream'],
    'unguessed': ['arcane', 'cabalistic', 'extraordinary', 'impenetrable', 'improbable', 'inscrutable', 'more than expected', 'mystic', 'numinous', 'out-of-the-way', 'past expectation', 'sudden'],
    'ungulate': ['amphibian', 'aquatic', 'asinine', 'biped', 'bovid', 'bovine', 'canine', 'cannibal', 'caprid', 'caprine', 'carnivore', 'clawed'],
    'unhallowed': ['demoniac', 'demonic', 'devilish', 'diabolic', 'fleshly', 'irreverent', 'mundane', 'nonsacred', 'profane', 'reprobate', 'satanic', 'secular'],
    'unhampered': ['absolute', 'accessible', 'admitting no exception', 'all-out', 'approachable', 'candid', 'categorical', 'clear', 'communicative', 'complete', 'conclusive', 'conversable'],
    'unhand': ['cast loose', 'demobilize', 'discharge', 'dismiss', 'go bail for', 'grant bail to', 'leave go', 'let go', 'let go free', 'let loose', 'let loose of', 'let off'],
    'unhandsome': ['beautiless', 'blemished', 'blotted', 'cacophonic', 'cacophonous', 'defaced', 'discourteous', 'disfigured', 'disrespectful', 'dysphemistic', 'dysphemized', 'homely'],
    'unhandy': ['all thumbs', 'awkward', 'blunderheaded', 'blundering', 'boorish', 'bulky', 'bumbling', 'bungling', 'butterfingered', 'careless', 'clownish', 'clumsy'],
    'unhappiness': ['faustianism', 'angst', 'anguish', 'anxiety', 'ban', 'blackball', 'blackballing', 'blues', 'boredom', 'cheerlessness', 'cold comfort', 'complaint'],
    'unhappy': ['sad', 'against', 'anguished', 'anxious', 'awkward', 'bad', 'badly off', 'beefing', 'bellyaching', 'bitching', 'black', 'bleak'],
    'unhappy about': ['ashamed', 'conscience-smitten', 'conscience-stricken', 'full of remorse', 'regretful', 'remorseful', 'repining', 'rueful', 'self-accusing', 'self-condemning', 'self-convicting', 'self-debasing'],
    'unharmed': ['bright', 'fresh', 'harmless', 'immune', 'immunized', 'insured', 'intact', 'inviolate', 'mint', 'pristine', 'protected', 'safe'],
    'unharnessing': ['demobilization', 'discharge', 'dismissal', 'parole', 'release', 'unbinding', 'unbolting', 'unbridling', 'unbuckling', 'uncaging', 'unchaining', 'unfettering'],
    'unhatched': ['ad-lib', 'caught napping', 'caught off balance', 'caught short', 'extemporaneous', 'extemporized', 'haphazard', 'hasty', 'impromptu', 'improvised', 'makeshift', 'precipitate'],
    'unhealthful': ['bad', 'bad for', 'contaminated', 'foul', 'harmful', 'injurious', 'insalubrious', 'insanitary', 'morbific', 'noisome', 'noxious', 'pathogenic'],
    'unhealthy': ['ailing', 'bad', 'bad for', 'cachectic', 'chancy', 'contaminated', 'corrupt', 'damaging', 'dangerous', 'debilitated', 'degenerate', 'depraved'],
    'unhearable': ['echoless', 'hush as death', 'hushed', 'inaudible', 'mousy', 'noiseless', 'quiescent', 'quiet', 'silent', 'soundless', 'still', 'still as death'],
    'unheard of': ['able', 'beguiling', 'bewildering', 'breakaway', 'different', 'enigmatic', 'exceptional', 'extraordinary', 'fabulous', 'fantastic', 'fascinating', 'ignotus'],
    'unheard-of': ['disgraceful', 'extreme', 'inconceivable', 'nameless', 'obscure', 'offensive', 'outlandish', 'outrageous', 'shocking', 'unbelievable', 'unfamiliar', 'unidentified'],
    'unhearing': ['a stranger to', 'asleep', 'blind to', 'caught napping', 'dead to', 'deaf', 'deaf and dumb', 'deaf to', 'deaf-eared', 'deaf-mute', 'deafened', 'dull-eared'],
    'unheedful': ['airy', 'careless', 'casual', 'cursory', 'degage', 'disregardant', 'disregardful', 'distracted', 'distrait', 'easygoing', 'flippant', 'forgetful'],
    'unhelpful': ['disregardful', 'forgetful', 'functionless', 'heedless', 'in disrepair', 'inapplicable', 'inconsiderate', 'inoperable', 'inoperative', 'mindless', 'nonfunctional', 'nonutilitarian'],
    'unheralded': ['extraordinary', 'improbable', 'more than expected', 'out-of-the-way', 'past expectation', 'sudden', 'surprise', 'unannounced', 'unanticipated', 'undivined', 'unexpected', 'unforeseeable'],
    'unhesitating': ['absolute', 'admitting no exception', 'all-out', 'arrogant', 'assured', 'categorical', 'clear', 'cocksure', 'complete', 'conclusive', 'confident', 'convinced'],
    'unhidden': ['apparent', 'bald', 'bare', 'beholdable', 'clear', 'cleared', 'detectable', 'discernible', 'disclosed', 'evident', 'exposed', 'exposed to view'],
    'unhinge': ['agitate', 'bother', 'craze', 'dement', 'derange', 'disarrange', 'disarticulate', 'disjoint', 'dislocate', 'disorder', 'displace', 'disquiet'],
    'unhinged': ['abnormal', 'bereft of reason', 'brainsick', 'crackbrained', 'cracked', 'crazed', 'crazy', 'daft', 'deluded', 'demented', 'deprived of reason', 'deranged'],
    'unholiness': ['godlessness', 'impiety', 'irreligion', 'profaneness', 'profanity', 'reprobation', 'sinfulness', 'un-christliness', 'unangelicalness', 'unblessedness', 'unchristianliness', 'ungodliness'],
    'unholy': ['amiss', 'barbarous', 'blamable', 'blameful', 'censurable', 'culpable', 'fleshly', 'godless', 'guilty', 'impious', 'irreligious', 'irreverent'],
    'unholy mess': ['arsy-varsiness', 'bind', 'clutch', 'clutter', 'complication', 'crunch', 'embarrassing position', 'embarrassment', 'farrago', 'fine how-do-you-do', 'hash', 'hell to pay'],
    'unhoped for': ['extraordinary', 'improbable', 'more than expected', 'out-of-the-way', 'past expectation', 'sudden', 'unannounced', 'unanticipated', 'undivined', 'unexpected', 'unforeseeable', 'unforeseen'],
    'unhorse': ['alight', 'buck off', 'climb down', 'depose', 'deracinate', 'dislodge', 'dismount', 'get down', 'get off', 'land', 'light', 'overset'],
    'unhostile': ['agreeable', 'amiable', 'amicable', 'brotherly', 'civilian', 'conciliatory', 'congenial', 'dovish', 'favorable', 'fraternal', 'friendlike', 'friendly'],
    'unhuman': ['draconian', 'tartarean', 'animal', 'anthropophagous', 'arcane', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bestial', 'bloodthirsty', 'bloody'],
    'unhurried': ['ambling', 'calm', 'casual', 'cautious', 'circumspect', 'claudicant', 'crawling', 'creeping', 'creeping like snail', 'deliberate', 'dilatory', 'easy'],
    'unhurt': ['bright', 'entire', 'fresh', 'harmless', 'immune', 'immunized', 'insured', 'intact', 'inviolate', 'mint', 'perfect', 'pristine'],
    'unhygienic': ['bad', 'bad for', 'contaminated', 'foul', 'harmful', 'injurious', 'insalubrious', 'insanitary', 'morbific', 'noisome', 'noxious', 'pathogenic'],
    'unicameral': ['bicameral', 'congressional', 'deliberative', 'lawmaking', 'legislative', 'legislatorial', 'monadal', 'monadic', 'one-piece', 'one-sided', 'parliamentary', 'senatorial'],
    'unicellular': ['cellular', 'cellulous', 'corpuscular', 'monadal', 'monadic', 'multicellular', 'one-piece', 'one-sided', 'uniangulate', 'unibivalent', 'unibranchiate', 'unicameral'],
    'unicorn': ['argus', 'briareus', 'cerberus', 'charybdis', 'cyclops', 'echidna', 'gorgon', 'harpy', 'hydra', 'loch ness monster', 'medusa', 'minotaur'],
    'unidealistic': ['common', 'commonplace', 'down-to-earth', 'dull', 'earthy', 'flat', 'hard', 'hard-boiled', 'hardheaded', 'humdrum', 'insipid', 'matter-of-fact'],
    'unidentical': ['contrasting', 'counter', 'different', 'disparate', 'dissimilar', 'divergent', 'diverse', 'hardly like', 'nonuniform', 'odd', 'off', 'offbeat'],
    'unidentified': ['able', 'anonymous', 'cryptonymic', 'cryptonymous', 'enigmatic', 'incalculable', 'incognito', 'incognizable', 'innominate', 'mysterious', 'nameless', 'puzzling'],
    'unidimensional': ['monadal', 'monadic', 'one-piece', 'one-sided', 'uniangulate', 'unibivalent', 'unibranchiate', 'unicameral', 'unicellular', 'unicuspid', 'unidentate', 'unidigitate'],
    'unidirectional': ['direct', 'immediate', 'irreversible', 'monadal', 'monadic', 'one-piece', 'one-sided', 'one-way', 'straight', 'straightaway', 'straightforward', 'straightway'],
    'unification': ['anschluss', 'addition', 'affiliation', 'agglomeration', 'agglutination', 'aggregation', 'agreement', 'alignment', 'alliance', 'amalgamation', 'articulation', 'assimilation'],
    'unified': ['coherent', 'cohesive', 'composite', 'impartible', 'indiscerptible', 'indissoluble', 'indissolvable', 'indivisible', 'infrangible', 'infusible', 'inseparable', 'insoluble'],
    'uniform': ['od', 'a certain', 'accordant', 'affirmative', 'agnate', 'agreeable', 'agreeing', 'akin', 'alike', 'an', 'analogous', 'answerable'],
    'uniformity': ['accommodation', 'accord', 'accordance', 'acquiescence', 'adaptation', 'adaption', 'adjustment', 'affinity', 'agreement', 'aplomb', 'arrangement', 'array'],
    'unify': ['accouple', 'accumulate', 'add', 'agglutinate', 'amalgamate', 'amass', 'arrange', 'articulate', 'assemble', 'assimilate', 'associate', 'band'],
    'unilateral': ['bifacial', 'bilateral', 'dihedral', 'flanked', 'handed', 'lateral', 'many-sided', 'monadal', 'monadic', 'multilateral', 'one-piece', 'one-sided'],
    'unilluminated': ['awkward', 'beamless', 'black', 'black as night', 'blankminded', 'caliginous', 'callow', 'dark', 'dark as night', 'dark as pitch', 'darkling', 'darksome'],
    'unimaginable': ['a bit thick', 'a bit thin', 'absurd', 'antic', 'barred', 'beguiling', 'bewildering', 'beyond belief', 'closed-out', 'contrary to reason', 'doubtable', 'doubtful'],
    'unimaginative': ['spartan', 'arid', 'ascetic', 'austere', 'bald', 'bare', 'barren', 'candid', 'common', 'commonplace', 'direct', 'dry'],
    'unimagined': ['authentic', 'bona fide', 'candid', 'card-carrying', 'dinkum', 'following the letter', 'genuine', 'good', 'honest', 'honest-to-god', 'imageless', 'inartificial'],
    'unimitated': ['authentic', 'bona fide', 'candid', 'card-carrying', 'dinkum', 'following the letter', 'genuine', 'good', 'honest', 'honest-to-god', 'inartificial', 'lawful'],
    'unimpaired': ['bright', 'entire', 'fresh', 'harmless', 'intact', 'inviolate', 'mint', 'perfect', 'pristine', 'scatheless', 'sound', 'unbroken'],
    'unimpassioned': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity', 'cold-blooded', 'coldhearted'],
    'unimpeachable': ['christian', 'above suspicion', 'absolute', 'actual', 'admitting no question', 'believable', 'blameless', 'clean', 'colorable', 'conceivable', 'confirmable', 'credible'],
    'unimpeded': ['clear', 'disembarrassed', 'free', 'open', 'unblocked', 'unburdened', 'unchecked', 'unclogged', 'unconstrained', 'unembarrassed', 'unencumbered', 'unhampered'],
    'unimportance': ['daintiness', 'delicacy', 'diminutiveness', 'exiguity', 'exiguousness', 'fewness', 'homeliness', 'humbleness', 'humility', 'inconsequentiality', 'inconsiderableness', 'ingloriousness'],
    'unimportant': ['casual', 'homely', 'humble', 'humble-looking', 'humble-visaged', 'humblest', 'inconsiderable', 'inferior', 'inglorious', 'innocuous', 'insignificant', 'least'],
    'unimpressed': ['aweless', 'calm', 'composed', 'cool', 'expected', 'expecting', 'inexcitable', 'unaffected', 'unamazed', 'unanimated', 'unastonished', 'unastounded'],
    'unimpressive': ['back-burner', 'dinky', 'dispensable', 'immaterial', 'inappreciable', 'inconsequential', 'inconsiderable', 'inessential', 'inferior', 'insignificant', 'irrelevant', 'little'],
    'uninfluenced': ['olympian', 'arbitrary', 'autonomous', 'candid', 'detached', 'discretional', 'discretionary', 'disinterested', 'dispassionate', 'elective', 'equitable', 'evenhanded'],
    'uninformed': ['awkward', 'blankminded', 'callow', 'dumb', 'empty', 'empty-headed', 'gauche', 'green', 'groping', 'ignorant', 'inane', 'incognizant'],
    'uninhabited': ['abandoned', 'available', 'deserted', 'forsaken', 'free', 'godforsaken', 'open', 'tenantless', 'unfilled', 'unmanned', 'unoccupied', 'unpeopled'],
    'uninhibited': ['abandoned', 'go-go', 'immoderate', 'incontinent', 'indulgent', 'intemperate', 'irrepressible', 'lax', 'licentious', 'loose', 'nonrestrictive', 'out of control'],
    'uninitiated': ['a novice at', 'a stranger to', 'amateurish', 'awkward', 'blankminded', 'callow', 'dumb', 'empty', 'empty-headed', 'fresh', 'gauche', 'green'],
    'uninjured': ['bright', 'entire', 'fresh', 'harmless', 'intact', 'inviolate', 'mint', 'perfect', 'pristine', 'scatheless', 'sound', 'unbroken'],
    'uninquisitive': ['aloof', 'apathetic', 'bored', 'careless', 'detached', 'disinterested', 'distant', 'heedless', 'impassive', 'incurious', 'indifferent', 'insouciant'],
    'uninspired': ['arid', 'barren', 'dry', 'dull', 'earthbound', 'elephantine', 'handed', 'heavy', 'infecund', 'infertile', 'literal', 'mundane'],
    'uninstructed': ['gothic', 'philistine', 'barbarous', 'benighted', 'bookless', 'deceived', 'empty-headed', 'functionally illiterate', 'grammarless', 'heathen', 'hoodwinked', 'ill-educated'],
    'unintelligence': ['agnosticism', 'blank mind', 'blankmindedness', 'blankness', 'callowness', 'calm of mind', 'childishness', 'emptiness of mind', 'empty-headedness', 'fallow mind', 'fatuity', 'foolishness'],
    'unintelligent': ['artless', 'awkward', 'blankminded', 'brainless', 'callow', 'dumb', 'empty', 'empty-headed', 'fatuous', 'foolish', 'gauche', 'green'],
    'unintelligible': ['greek to one', 'ambiguous', 'amphibological', 'beyond understanding', 'equivocal', 'impenetrable', 'inarticulate', 'incognizable', 'incoherent', 'incomprehensible', 'inscrutable', 'numinous'],
    'unintentional': ['automatic', 'blind', 'casual', 'causeless', 'chance', 'compulsive', 'conditioned', 'forced', 'gut', 'haphazard', 'ill-advised', 'ill-considered'],
    'uninterested': ['laodicean', 'olympian', 'aloof', 'apathetic', 'ataractic', 'benumbed', 'blah', 'blase', 'bored', 'bored stiff', 'bored to death', 'bored to tears'],
    'unintermittent': ['articulated', 'catenated', 'ceaseless', 'chattering', 'concatenated', 'connected', 'constant', 'continual', 'continued', 'continuing', 'continuous', 'cyclical'],
    'uninterrupted': ['ageless', 'arrowlike', 'articulated', 'assiduous', 'catenated', 'ceaseless', 'chattering', 'coeternal', 'concatenated', 'connected', 'consecutive', 'consistent'],
    'uninventive': ['arid', 'barren', 'derivative', 'dry', 'dull', 'earthbound', 'infecund', 'infertile', 'literal', 'mundane', 'noncreative', 'nongerminal'],
    'uninvited': ['arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'nonmandatory', 'offered', 'optional'],
    'uninviting': ['abhorrent', 'bitter', 'disagreeable', 'dislikable', 'displeasing', 'distasteful', 'foul-tasting', 'ill-flavored', 'intolerable', 'mislikable', 'odious', 'sour'],
    'uninvolved': ['laodicean', 'afoot and lighthearted', 'aloof', 'apathetic', 'at large', 'at liberty', 'bored', 'careless', 'centrist', 'clear', 'detached', 'disengaged'],
    'union': ['anschluss', 'bund', 'rochdale cooperative', 'abutment', 'abuttal', 'accompaniment', 'accord', 'accordance', 'addition', 'adjoiningness', 'adjunct', 'affairs'],
    'union jack': ['dannebrog', 'jolly roger', 'old glory', 'star-spangled banner', 'stars and stripes', 'union flag', 'and blue', 'banderole', 'banner', 'banneret', 'black flag', 'blue ensign'],
    'unionize': ['affiliate', 'ally', 'associate', 'band together', 'be in cahoots', 'bunch', 'bunch up', 'cabal', 'cement a union', 'centralize', 'club', 'club together'],
    'unipartite': ['monadal', 'monadic', 'one-piece', 'one-sided', 'uniangulate', 'unibivalent', 'unibranchiate', 'unicameral', 'unicellular', 'unicuspid', 'unidentate', 'unidigitate'],
    'unique': ['a certain', 'absolute', 'almost unheard-of', 'alone', 'an', 'another', 'any', 'any one', 'appropriate', 'atomic', 'authentic', 'avant-garde'],
    'unison': ['acclamation', 'accompaniment', 'accord', 'accordance', 'affinity', 'agape', 'agreement', 'agreement of all', 'amity', 'assent', 'attune', 'attunement'],
    'unit': ['kp', 'abampere', 'abcoulomb', 'abfarad', 'abhenry', 'abohm', 'abvolt', 'ace', 'ampere', 'ampere-foot', 'ampere-hour', 'ampere-minute'],
    'unitary': ['a certain', 'an', 'any', 'any one', 'atomic', 'composite', 'either', 'exclusive', 'individual', 'indivisible', 'integral', 'integrant'],
    'unite': ['accord', 'accouple', 'accumulate', 'act in concert', 'act together', 'add', 'adhere', 'affiliate', 'agglutinate', 'agree', 'ally', 'amalgamate'],
    'united': ['accompanying', 'accordant', 'agreeable', 'agreed', 'agreeing', 'akin', 'allied', 'amalgamated', 'amicable', 'assembled', 'assimilated', 'associate'],
    'united states': ['america', 'columbia', 'dixie', 'dixieland', 'down east', 'east', 'east coast', 'land of liberty', 'middle atlantic', 'middle west', 'new england', 'north'],
    'uniting': ['accession', 'accompanying', 'accordant', 'addition', 'adjunct', 'adjunction', 'affixation', 'agglutination', 'agreeing', 'annexation', 'approaching', 'associate'],
    'unity': ['accord', 'accordance', 'affinity', 'agape', 'agreement', 'amity', 'bonds of harmony', 'brotherly love', 'calm', 'caritas', 'cement of friendship', 'charity'],
    'universal': ['berkeleianism', 'geistesgeschichte', 'hegelian idea', 'hegelianism', 'kantian idea', 'kantianism', 'neoplatonism', 'platonic form', 'platonic idea', 'platonism', 'absolute', 'absolute idealism'],
    'universality': ['all-comprehensiveness', 'all-inclusiveness', 'boundlessness', 'catholicity', 'completeness', 'comprehensiveness', 'cosmopolitanism', 'countlessness', 'ecumenicalism', 'ecumenicity', 'endlessness', 'entireness'],
    'universally': ['all over', 'all over hell', 'all round', 'always', 'and everywhere', 'cosmically', 'everywhere', 'everywheres', 'galactically', 'here', 'high and low', 'in all creation'],
    'universe': ['anschauung', 'angle', 'angle of vision', 'bailiwick', 'basis', 'circle', 'corner', 'cosmos', 'creation', 'domain', 'eye', 'footing'],
    'university': ['academe', 'academia', 'academic', 'alma mater', 'classroom', 'college', 'college of engineering', 'collegiate', 'community college', 'degree-granting institution', 'extramural', 'four-year college'],
    'univocal': ['absolute', 'apodictic', 'apparent', 'bound', 'certain', 'clean-cut', 'clear', 'clear and distinct', 'clear as crystal', 'clear as day', 'clear-cut', 'coherent'],
    'unjaundiced': ['detached', 'disinterested', 'dispassionate', 'equitable', 'evenhanded', 'fair', 'impartial', 'impersonal', 'indifferent', 'just', 'neutral', 'objective'],
    'unjoined': ['aimless', 'amorphous', 'apart', 'asunder', 'bipartite', 'broken', 'broken off', 'capricious', 'casual', 'chopped-off', 'choppy', 'decousu'],
    'unkempt': ['gothic', 'neanderthal', 'animal', 'barbarian', 'barbaric', 'barbarous', 'beat-up', 'bedraggled', 'bestial', 'blowzy', 'broken', 'brutal'],
    'unkind': ['callous', 'cruel', 'disagreeable', 'flinty', 'hard', 'harsh', 'heartless', 'ill', 'inconsiderate', 'inflexible', 'inhospitable', 'inhuman'],
    'unknowable': ['greek to one', 'able', 'ambiguous', 'arcane', 'beyond understanding', 'cabalistic', 'enigmatic', 'impenetrable', 'inarticulate', 'incalculable', 'incognizable', 'incoherent'],
    'unknowing': ['a stranger to', 'asleep', 'awkward', 'blankminded', 'blind to', 'callow', 'caught napping', 'dead to', 'deaf to', 'dumb', 'empty', 'empty-headed'],
    'unknown': ['heaven', 'paradise', 'a better place', 'able', 'abstruse', 'afterlife', 'afterworld', 'anonymous', 'beclouded', 'blind', 'buried', 'close'],
    'unlabored': ['attic', 'ciceronian', 'arrested', 'backward', 'chaste', 'classic', 'clear', 'coarse', 'crude', 'direct', 'easy', 'elegant'],
    'unlace': ['cast off', 'detach', 'disengage', 'doff', 'free', 'liberate', 'loose', 'loosen', 'release', 'remove', 'take off', 'unbar'],
    'unladylike': ['boorish', 'caddish', 'coarse', 'crude', 'ill-bred', 'inconsiderate', 'insensitive', 'loutish', 'louty', 'nasty', 'offensive', 'tactless'],
    'unlatch': ['bare', 'cast off', 'clear', 'deobstruct', 'detach', 'disclose', 'disengage', 'doff', 'expose', 'free', 'liberate', 'loose'],
    'unlawful': ['aberrant', 'abnormal', 'abominable', 'actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'atrocious', 'banned', 'barred', 'black-market'],
    'unlawfulness': ['aberrance', 'aberrancy', 'abnormality', 'anarchy', 'anomie', 'criminalism', 'criminality', 'delinquency', 'deviance', 'deviancy', 'illegality', 'illegitimacy'],
    'unlearned': ['gothic', 'philistine', 'automatic', 'barbarous', 'bookless', 'deceived', 'functionally illiterate', 'grammarless', 'heathen', 'hoodwinked', 'ill-educated', 'illiterate'],
    'unleash': ['cast off', 'detach', 'diffuse', 'disengage', 'disjoin', 'disperse', 'doff', 'ease', 'ease off', 'free', 'let go', 'let up'],
    'unless': ['aside from', 'bar', 'barring', 'beside', 'besides', 'but', 'ex', 'except', 'except for', 'except that', 'excepting', 'excluding'],
    'unlettered': ['gothic', 'philistine', 'barbarous', 'benighted', 'bookless', 'deceived', 'empty-headed', 'functionally illiterate', 'grammarless', 'heathen', 'hoodwinked', 'ill-educated'],
    'unlicensed': ['banned', 'barred', 'contraband', 'forbade', 'forbid', 'forbidden', 'illegal', 'illicit', 'nonpermissible', 'not permitted', 'off limits', 'out of bounds'],
    'unlicked': ['gothic', 'neanderthal', 'animal', 'arrested', 'backward', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'brutal', 'brutish', 'budding'],
    'unlikable': ['abhorrent', 'bitter', 'despiteful', 'detestable', 'disagreeable', 'dislikable', 'displeasing', 'distasteful', 'foul-tasting', 'hateful', 'ill-flavored', 'intolerable'],
    'unlike': ['assorted', 'at odds', 'at variance', 'atypical', 'contrary', 'contrasted', 'contrasting', 'counter', 'departing', 'deviating', 'deviative', 'different'],
    'unlikelihood': ['bare possibility', 'dark horse', 'doubtfulness', 'dubiousness', 'faint likelihood', 'fighting chance', 'gambling chance', 'hardly a chance', 'hundred-to-one shot', 'implausibility', 'improbability', 'incredibility'],
    'unlikely': ['distasteful', 'doubtable', 'doubtful', 'dubious', 'dubitable', 'hardly possible', 'implausible', 'improbable', 'inappropriate', 'inauspicious', 'inconceivable', 'incredible'],
    'unlimited': ['absolute', 'admitting no exception', 'all-comprehensive', 'all-inclusive', 'all-knowing', 'all-out', 'all-powerful', 'all-seeing', 'all-wise', 'almighty', 'bibulous', 'boundless'],
    'unlit': ['beamless', 'black', 'black as night', 'caliginous', 'dark', 'dark as night', 'dark as pitch', 'darkling', 'darksome', 'ebon', 'ebony', 'eclipsed'],
    'unliterary': ['gothic', 'philistine', 'barbarous', 'bookless', 'colloquial', 'common', 'conversational', 'deceived', 'everyday', 'familiar', 'functionally illiterate', 'grammarless'],
    'unload': ['alleviate', 'be light', 'break bulk', 'clear the trade', 'close out', 'convert', 'convert into cash', 'cut under', 'debark', 'disburden', 'discharge', 'disembark'],
    'unloading': ['alleviation', 'cleaning out', 'clearance', 'clearing', 'defecation', 'depletion', 'disburdening', 'discharging cargo', 'disembarrassment', 'disencumberment', 'disencumbrance', 'drainage'],
    'unlock': ['account for', 'allegorize', 'answer', 'bare', 'bottom', 'cast off', 'clarify', 'clear', 'clear up', 'crack', 'debug', 'decipher'],
    'unlooked for': ['abrupt', 'accidental', 'adventitious', 'aleatory', 'casual', 'causeless', 'chance', 'chancy', 'contingent', 'destinal', 'dicey', 'electrifying'],
    'unloosen': ['cast off', 'detach', 'disengage', 'doff', 'free', 'liberate', 'loose', 'loosen', 'release', 'remove', 'take off', 'unbar'],
    'unloosing': ['demobilization', 'discharge', 'dismissal', 'parole', 'release', 'unbinding', 'unbolting', 'unbridling', 'unbuckling', 'uncaging', 'unchaining', 'unfettering'],
    'unlovely': ['beautiless', 'blemished', 'blotted', 'cacophonic', 'cacophonous', 'defaced', 'disfigured', 'dysphemistic', 'dysphemized', 'homely', 'inelegant', 'marred'],
    'unloving': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity', 'cold-blooded', 'coldhearted'],
    'unloyal': ['derelict', 'disaffected', 'disloyal', 'disregardful', 'faithless', 'false', 'fickle', 'inattentive', 'inconstant', 'inobservant', 'negligent', 'nonadherent'],
    'unlucky': ['apocalyptic', 'bad', 'badly off', 'baleful', 'baneful', 'black', 'bodeful', 'boding', 'calamitous', 'cataclysmic', 'catastrophic', 'dark'],
    'unlucky day': ['friday', 'friday the thirteenth', 'appointed lot', 'astral influences', 'astrology', 'bad time', 'book of fate', 'constellation', 'contretemps', 'cup', 'destination', 'destiny'],
    'unmade': ['ad-lib', 'caught napping', 'caught off balance', 'caught short', 'extemporaneous', 'extemporized', 'haphazard', 'hasty', 'impromptu', 'improvised', 'makeshift', 'precipitate'],
    'unmake': ['atomize', 'break to pieces', 'cleave', 'decimate', 'demolish', 'dethrone', 'disassemble', 'discrown', 'disenthrone', 'disintegrate', 'dismantle', 'displace'],
    'unman': ['abase', 'abate', 'affright', 'alarm', 'attenuate', 'beat down', 'bend', 'blunt', 'break', 'break down', 'bring low', 'bring to terms'],
    'unmanageability': ['awkwardness', 'boorishness', 'bulkiness', 'bumblingness', 'clownishness', 'clumsiness', 'contumaciousness', 'contumacy', 'cumbersomeness', 'defiance', 'fractiousness', 'gawkiness'],
    'unmanageable': ['awkward', 'beyond control', 'breachy', 'bulky', 'clumsy', 'contrary', 'contumacious', 'crosswise', 'cumbersome', 'defiant', 'fractious', 'hulking'],
    'unmanly': ['afraid', 'chicken', 'chickenhearted', 'coward', 'cowardly', 'cowed', 'craven', 'daunted', 'dismayed', 'effeminate', 'epicene', 'fainthearted'],
    'unmanned': ['abandoned', 'afraid', 'aghast', 'appalled', 'ashen', 'astounded', 'available', 'awed', 'awestricken', 'awestruck', 'blanched', 'castrated'],
    'unmarked': ['bright', 'fresh', 'harmless', 'inviolate', 'mint', 'pristine', 'scatheless', 'unbroken', 'unbruised', 'unconsidered', 'undamaged', 'undefaced'],
    'unmarred': ['bright', 'entire', 'fresh', 'harmless', 'intact', 'inviolate', 'mint', 'perfect', 'pristine', 'scatheless', 'sound', 'unbroken'],
    'unmarried': ['bachelor', 'bachelorlike', 'celibataire', 'celibate', 'free', 'husbandless', 'maiden', 'maidenly', 'misogamist', 'misogynist', 'monastic', 'monk'],
    'unmask': ['bare', 'break the seal', 'bring to light', 'debunk', 'develop', 'disclose', 'discover', 'dismask', 'draw the veil', 'expose', 'impart', 'lay bare'],
    'unmasking': ['apocalypse', 'baring', 'disclosing', 'disclosure', 'discovering', 'discovery', 'expose', 'exposition', 'exposure', 'laying bare', 'manifestation', 'patefaction'],
    'unmatched': ['best', 'beyond compare', 'beyond comparison', 'champion', 'choice', 'contrasting', 'counter', 'different', 'disparate', 'dissimilar', 'divergent', 'diverse'],
    'unmatured': ['a bit previous', 'a novice at', 'a stranger to', 'advanced', 'callow', 'far ahead', 'forward', 'fresh', 'green', 'green as grass', 'half-baked', 'half-cocked'],
    'unmeasured': ['abandoned', 'absolute', 'all-comprehensive', 'all-inclusive', 'bibulous', 'boundless', 'countless', 'crapulent', 'crapulous', 'endless', 'eternal', 'excessive'],
    'unmelodious': ['absonant', 'atonal', 'cacophonous', 'cracked', 'diaphonic', 'disconsonant', 'discordant', 'disharmonic', 'disharmonious', 'dissonant', 'flat', 'grating'],
    'unmentionable': ['abject', 'abominable', 'appalling', 'arrant', 'atrocious', 'base', 'beggarly', 'cheesy', 'contemptible', 'crummy', 'debased', 'degraded'],
    'unmerciful': ['barbarous', 'bowelless', 'brutal', 'brutish', 'callous', 'calloused', 'cold', 'cold of heart', 'coldblooded', 'coldhearted', 'cruel', 'dog-eat-dog'],
    'unmerited': ['illegal', 'inequitable', 'iniquitous', 'nonmeritorious', 'not coming', 'not outstanding', 'outrageous', 'preposterous', 'unbalanced', 'undeserved', 'undeserving', 'undue'],
    'unmethodical': ['aimless', 'amorphous', 'broken', 'capricious', 'careening', 'casual', 'catchy', 'choppy', 'desultory', 'deviative', 'disarticulated', 'disconnected'],
    'unmindful': ['lethean', 'a stranger to', 'absentminded', 'airy', 'aloof', 'amnestic', 'apathetic', 'asleep', 'ataractic', 'blase', 'blind to', 'blocked'],
    'unmingled': ['absolute', 'bare', 'clarified', 'clear', 'distilled', 'naked', 'neat', 'purified', 'rectified', 'sheer', 'straight', 'unadulterated'],
    'unmistakable': ['absolute', 'admitting no exception', 'all-out', 'apodictic', 'apparent', 'bound', 'categorical', 'certain', 'clean-cut', 'clear', 'clear and distinct', 'clear as crystal'],
    'unmistaken': ['actual', 'ascertained', 'attested', 'authenticated', 'categorically true', 'certain', 'certified', 'confirmed', 'corroborated', 'demonstrated', 'determined', 'documentary'],
    'unmitigated': ['absolute', 'admitting no exception', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'altered', 'arrant', 'better', 'born', 'broad-based', 'categorical'],
    'unmixed': ['absolute', 'bare', 'beyond all praise', 'chaste', 'clarified', 'clear', 'defectless', 'distilled', 'faultless', 'flawless', 'ideal', 'immaculate'],
    'unmovable': ['adamant', 'adamantine', 'at a standstill', 'closed to', 'firm', 'frozen', 'immobile', 'immotile', 'immotive', 'immovable', 'impersuadable', 'impersuasible'],
    'unmoved': ['adamant', 'adamantine', 'aloof', 'apathetic', 'at a standstill', 'at anchor', 'at rest', 'aweless', 'calm', 'cast-iron', 'cloistered', 'collected'],
    'unmusical': ['absonant', 'atonal', 'cacophonous', 'cracked', 'diaphonic', 'disconsonant', 'discordant', 'disharmonic', 'disharmonious', 'dissonant', 'flat', 'grating'],
    'unmuzzled': ['abandoned', 'go-go', 'immoderate', 'incontinent', 'indulgent', 'intemperate', 'irrepressible', 'lax', 'licentious', 'loose', 'nonrestrictive', 'out of control'],
    'unnatural': ['gongoresque', 'gongoristic', 'marinistic', 'aberrant', 'abnormal', 'affected', 'amorphous', 'anomalistic', 'anomalous', 'apocryphal', 'artificial', 'assumed'],
    'unnecessary': ['de trop', 'dispensable', 'disposable', 'excess', 'expendable', 'expletive', 'gratuitous', 'in excess', 'inessential', 'needless', 'nonessential', 'pleonastic'],
    'unneeded': ['de trop', 'dispensable', 'excess', 'expendable', 'expletive', 'gratuitous', 'in excess', 'needless', 'nonessential', 'pleonastic', 'prolix', 'redundant'],
    'unnerve': ['abate', 'affright', 'agitate', 'alarm', 'attenuate', 'blunt', 'castrate', 'cramp', 'cripple', 'crush', 'curdle the blood', 'damp'],
    'unnerved': ['aghast', 'anemic', 'appalled', 'ashen', 'asthenic', 'astounded', 'awed', 'awestricken', 'awestruck', 'blanched', 'bloodless', 'castrated'],
    'unnoted': ['ignotus', 'inglorious', 'little known', 'nameless', 'no credit to', 'obscure', 'renownless', 'uncelebrated', 'unconsidered', 'undescried', 'undistinguished', 'unfamed'],
    'unnoteworthy': ['average', 'back-burner', 'bourgeois', 'common', 'commonplace', 'conventional', 'dinky', 'dispensable', 'garden', 'garden-variety', 'immaterial', 'inappreciable'],
    'unnoticed': ['behind the curtain', 'behind the scenes', 'camouflaged', 'concealed', 'disguised', 'hidden', 'ignotus', 'imperceptible', 'indiscernible', 'inglorious', 'insensible', 'invisible'],
    'unnumbered': ['all-comprehensive', 'all-inclusive', 'boundless', 'countless', 'endless', 'eternal', 'exhaustless', 'extending everywhere', 'illimitable', 'illimited', 'immeasurable', 'immense'],
    'unobjectionable': ['ok', 'above suspicion', 'acceptable', 'adequate', 'admissible', 'adorable', 'agreeable', 'all right', 'allowable', 'alright', 'appetizing', 'attractive'],
    'unobscured': ['clear', 'cloudless', 'diaphanous', 'light', 'lightish', 'lightsome', 'lucent', 'lucid', 'luculent', 'pellucid', 'relucent', 'serene'],
    'unobservant': ['careless', 'disregardant', 'disregardful', 'distracted', 'distrait', 'heedless', 'inadvertent', 'inattentive', 'inconstant', 'incurious', 'indifferent', 'inobservant'],
    'unobserved': ['behind the curtain', 'behind the scenes', 'camouflaged', 'concealed', 'disguised', 'hidden', 'imperceptible', 'indiscernible', 'insensible', 'invisible', 'latent', 'out of sight'],
    'unobserving': ['ableptical', 'amaurotic', 'benighted', 'bereft of light', 'blind', 'careless', 'color-blind', 'dark', 'dim-sighted', 'disregardant', 'disregardful', 'distracted'],
    'unobstructed': ['bald', 'bare', 'clear', 'cleared', 'disclosed', 'disembarrassed', 'exposed', 'free', 'naked', 'open', 'unburdened', 'unclogged'],
    'unobtainable': ['beyond reach', 'closed forever to', 'closed to', 'impenetrable', 'impervious', 'inaccessible', 'lost to', 'out of reach', 'un-come-at-able', 'unaccessible', 'unapproachable', 'unattainable'],
    'unobtrusive': ['attic', 'aesthetic', 'artistic', 'back-door', 'backstairs', 'chaste', 'choice', 'clandestine', 'classic', 'covert', 'excellent', 'feline'],
    'unoccupied': ['abandoned', 'at leisure', 'at liberty', 'at loose ends', 'available', 'blank', 'blankminded', 'calm', 'deserted', 'disengaged', 'empty', 'empty-headed'],
    'unofficial': ['bohemian', 'actionable', 'affable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'apocryphal', 'black-market', 'bootleg', 'casual', 'chargeable'],
    'unopposed': ['agreeing', 'at one', 'at one with', 'carried by acclamation', 'concordant', 'concurrent', 'consentaneous', 'in agreement', 'like-minded', 'of a piece', 'of one accord', 'of one mind'],
    'unordered': ['aimless', 'amorphic', 'amorphous', 'anarchic', 'baggy', 'blobby', 'blurred', 'blurry', 'capricious', 'casual', 'chaotic', 'characterless'],
    'unordinary': ['breakaway', 'extraordinary', 'offbeat', 'rare', 'recherche', 'singular', 'sui generis', 'uncommon', 'uncustomary', 'undreamed-of', 'unexpected', 'unfamiliar'],
    'unorganized': ['ad-lib', 'aimless', 'amorphic', 'amorphous', 'anarchic', 'baggy', 'blobby', 'blurred', 'blurry', 'capricious', 'casual', 'caught napping'],
    'unoriginal': ['and', 'arid', 'back-number', 'banal', 'barren', 'bewhiskered', 'bromidic', 'common', 'commonplace', 'corny', 'cut-and-dried', 'derivative'],
    'unoriginality': ['aridity', 'aridness', 'banality', 'banalness', 'barrenness', 'cliche', 'commonness', 'commonplaceness', 'corniness', 'dearth of ideas', 'dryness', 'dullness'],
    'unornamented': ['bald', 'bare', 'blank', 'dry', 'naked', 'nude', 'simple', 'unadorned', 'unadulterated', 'unarrayed', 'uncomplicated', 'undecked'],
    'unorthodox': ['albigensian', 'arian', 'bohemian', 'catharist', 'donatist', 'ebionitist', 'erastian', 'gnostic', 'jansenist', 'jansenistic', 'jovinianist', 'jovinianistic'],
    'unorthodoxy': ['bohemianism', 'aberrancy', 'aberration', 'ambiguity', 'ambivalence', 'antinomy', 'asymmetry', 'beatnikism', 'capriciousness', 'changeability', 'changeableness', 'choppiness'],
    'unowing': ['above water', 'all clear', 'all straight', 'clear', 'free and clear', 'nonmeritorious', 'not coming', 'not outstanding', 'out of debt', 'outrageous', 'preposterous', 'solvent'],
    'unpack': ['bare', 'break bulk', 'break the seal', 'bring to light', 'develop', 'disburden', 'discharge', 'disclose', 'discover', 'dismask', 'draw the veil', 'dump'],
    'unpaid': ['back', 'due', 'freewill', 'gratuitous', 'honorary', 'in arrear', 'in arrears', 'mature', 'outstanding', 'overdue', 'owed', 'owing'],
    'unpalatable': ['afflictive', 'bitter', 'disagreeable', 'dislikable', 'displeasing', 'distasteful', 'flat', 'flavorless', 'foul-tasting', 'galling', 'grievous', 'ill-flavored'],
    'unparalleled': ['best', 'beyond compare', 'beyond comparison', 'champion', 'choice', 'consummate', 'easily first', 'elect', 'elite', 'exceptional', 'extraordinary', 'fabulous'],
    'unpardonable': ['abominable', 'arrant', 'atrocious', 'bad', 'base', 'black', 'blamable', 'blameworthy', 'criminal', 'damnable', 'dark', 'disgraceful'],
    'unparticular': ['blanket', 'casual', 'general', 'imprudent', 'inaccurate', 'indiscreet', 'indiscriminate', 'indiscriminative', 'inexact', 'insensitive', 'nonjudgmental', 'promiscuous'],
    'unpayable': ['costly', 'dear', 'dear-bought', 'expensive', 'fancy', 'high', 'high-priced', 'inconvertible', 'irredeemable', 'luxurious', 'not affordable', 'of great cost'],
    'unpeaceful': ['aggressive', 'agitated', 'antagonistic', 'battling', 'bellicose', 'belligerent', 'bloodthirsty', 'bloody', 'bloody-minded', 'chauvinist', 'chauvinistic', 'combative'],
    'unpen': ['loose', 'loosen', 'unbar', 'unbind', 'unbolt', 'unbridle', 'unbuckle', 'uncage', 'unchain', 'unfetter', 'ungag', 'unhandcuff'],
    'unpeopled': ['abandoned', 'available', 'deserted', 'forsaken', 'free', 'godforsaken', 'open', 'tenantless', 'unfilled', 'uninhabited', 'unmanned', 'unoccupied'],
    'unperceived': ['able', 'behind the curtain', 'behind the scenes', 'camouflaged', 'concealed', 'disguised', 'enigmatic', 'hidden', 'imperceptible', 'incalculable', 'incognizable', 'indiscernible'],
    'unperceptive': ['asleep', 'benumbed', 'blind', 'blindfold', 'blindfolded', 'callous', 'dead', 'deadened', 'dim-sighted', 'dull', 'impassible', 'imperceptive'],
    'unperfected': ['adulterated', 'blemished', 'damaged', 'defective', 'deficient', 'erroneous', 'fallible', 'faulty', 'found wanting', 'immature', 'impaired', 'imperfect'],
    'unpersuadable': ['blind', 'cautious', 'closed to', 'deaf', 'disinclined to believe', 'disposed to doubt', 'dogmatic', 'guarded', 'hard of belief', 'impersuadable', 'impersuasible', 'impervious'],
    'unpersuaded': ['agnostic', 'ambiguous', 'capricious', 'chancy', 'changeable', 'dicey', 'doubting', 'equivocal', 'erratic', 'fickle', 'hesitant', 'hesitating'],
    'unperturbed': ['at rest', 'calm', 'cloistered', 'cool', 'dwindling', 'ebbing', 'even-tenored', 'halcyon', 'hushed', 'impassive', 'isolated', 'moldering'],
    'unphysical': ['airy', 'asomatous', 'astral', 'bodiless', 'decarnate', 'decarnated', 'discarnate', 'disembodied', 'ethereal', 'extramundane', 'ghostly', 'immaterial'],
    'unplanned': ['ad-lib', 'aimless', 'caught napping', 'caught off balance', 'caught short', 'designless', 'desultory', 'extemporaneous', 'extemporized', 'haphazard', 'hasty', 'hit-or-miss'],
    'unpleasant': ['abhorrent', 'bad', 'bitter', 'disagreeable', 'dislikable', 'displeasing', 'distasteful', 'foul-tasting', 'ill-flavored', 'intolerable', 'mislikable', 'odious'],
    'unpleasantness': ['discordia', 'eris', 'badness', 'clash', 'clashing', 'conflict', 'contention', 'damnability', 'disaccord', 'disaffinity', 'discord', 'discordance'],
    'unpleasure': ['faustianism', 'cold comfort', 'disappointment', 'discontent', 'discontentedness', 'discontentment', 'disgruntlement', 'dissatisfaction', 'dissatisfiedness', 'divine discontent', 'envy', 'ill humor'],
    'unpliable': ['adamant', 'adamantine', 'bullheaded', 'closed to', 'headstrong', 'immovable', 'immutable', 'impersuadable', 'impersuasible', 'impervious', 'inductile', 'inelastic'],
    'unplowed': ['acarpous', 'arid', 'barren', 'celibate', 'childless', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'exhausted', 'fallow'],
    'unplug': ['bare', 'clear', 'deobstruct', 'disclose', 'expose', 'free', 'manifest', 'patefy', 'reveal', 'unblock', 'uncase', 'unclench'],
    'unplumbed': ['able', 'all-comprehensive', 'all-inclusive', 'boundless', 'countless', 'endless', 'enigmatic', 'eternal', 'exhaustless', 'extending everywhere', 'illimitable', 'illimited'],
    'unpoetical': ['spartan', 'arid', 'ascetic', 'austere', 'bald', 'bare', 'barren', 'candid', 'common', 'commonplace', 'direct', 'dry'],
    'unpointed': ['abrupt', 'bluff', 'blunt', 'blunt-edged', 'blunt-ended', 'blunt-pointed', 'blunted', 'bluntish', 'dull', 'dull-edged', 'dull-pointed', 'dulled'],
    'unpolished': ['doric', 'gothic', 'neanderthal', 'amateurish', 'animal', 'arrested', 'backward', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'boorish'],
    'unpolluted': ['bleached', 'bright', 'clean', 'cleanly', 'dainty', 'dirt-free', 'fair', 'fastidious', 'fresh', 'immaculate', 'kosher', 'nonpolluted'],
    'unpopular': ['avoided', 'despised', 'disliked', 'friendless', 'ignored', 'ignotus', 'in bad odor', 'inglorious', 'little known', 'lowly', 'misprized', 'misunderstood'],
    'unpopulated': ['abandoned', 'available', 'deserted', 'forsaken', 'free', 'godforsaken', 'open', 'tenantless', 'unfilled', 'uninhabited', 'unmanned', 'unoccupied'],
    'unpossessed of': ['bankrupt in', 'bare of', 'bereft of', 'denuded of', 'deprived of', 'destitute of', 'devoid of', 'empty of', 'for want of', 'forlorn of', 'in default of', 'in want of'],
    'unpossessive': ['altruistic', 'committed', 'consecrated', 'dedicated', 'devoted', 'disinterested', 'humble', 'modest', 'sacrificing', 'self-abasing', 'self-abnegating', 'self-abnegatory'],
    'unpractical': ['airy', 'autistic', 'dereistic', 'idealistic', 'impractical', 'in the clouds', 'nonrealistic', 'otherworldly', 'poetic', 'quixotic', 'romancing', 'romantic'],
    'unpracticed': ['a novice at', 'a stranger to', 'callow', 'disaccustomed', 'fresh', 'green', 'green as grass', 'ignorant', 'immature', 'inexperienced', 'new to', 'raw'],
    'unpraiseworthy': ['derogatory', 'discommendable', 'discreditable', 'dishonorable', 'disreputable', 'exceptionable', 'ignoble', 'ignominious', 'illaudable', 'infamous', 'inglorious', 'notorious'],
    'unprecedented': ['beguiling', 'bewildering', 'enigmatic', 'exceptional', 'extraordinary', 'fabulous', 'fantastic', 'fascinating', 'incomprehensible', 'inconceivable', 'incredible', 'indescribable'],
    'unpredictable': ['accidental', 'adrift', 'adventitious', 'afloat', 'agnostic', 'aleatory', 'alternating', 'ambiguous', 'amorphous', 'capricious', 'casual', 'causeless'],
    'unpredicted': ['abrupt', 'electrifying', 'extraordinary', 'hasty', 'headlong', 'impetuous', 'improbable', 'impulsive', 'more than expected', 'nerve-shattering', 'out-of-the-way', 'past expectation'],
    'unprejudiced': ['detached', 'disinterested', 'dispassionate', 'equitable', 'evenhanded', 'fair', 'fair-minded', 'impartial', 'impersonal', 'indifferent', 'just', 'liberal'],
    'unpremeditated': ['a bit previous', 'ad lib', 'ad-lib', 'advanced', 'automatic', 'casual', 'caught napping', 'caught off balance', 'caught short', 'coincidental', 'extemporaneous', 'extemporary'],
    'unprepared': ['a bit previous', 'ad-lib', 'advanced', 'airy', 'amateurish', 'asleep', 'careless', 'casual', 'caught napping', 'caught off balance', 'caught short', 'cursory'],
    'unpreparedness': ['abandon', 'belatedness', 'careless abandon', 'carelessness', 'casualness', 'cursoriness', 'disregardfulness', 'easiness', 'eleventh hour', 'forgetfulness', 'hastiness', 'heedlessness'],
    'unprepossessed': ['detached', 'disinterested', 'dispassionate', 'equitable', 'evenhanded', 'fair', 'impartial', 'impersonal', 'indifferent', 'just', 'neutral', 'objective'],
    'unpressured': ['arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'nonmandatory', 'offered', 'optional'],
    'unpretentious': ['altruistic', 'arcadian', 'bucolic', 'candid', 'committed', 'consecrated', 'dedicated', 'devoted', 'direct', 'discreet', 'disinterested', 'genuine'],
    'unpreventable': ['certain', 'fated', 'fateful', 'indefeasible', 'ineluctable', 'inescapable', 'inevasible', 'inevitable', 'inexorable', 'inflexible', 'irresistible', 'irrevocable'],
    'unprincipled': ['amoral', 'conscienceless', 'corrupt', 'corrupted', 'criminal', 'crooked', 'dark', 'devious', 'dishonest', 'dishonorable', 'dissolute', 'doubtful'],
    'unprintable': ['fescennine', 'rabelaisian', 'bawdy', 'blue', 'dirty', 'filthy', 'foul', 'foul-mouthed', 'foul-spoken', 'foul-tongued', 'fulsome', 'impure'],
    'unprocessed': ['arrested', 'backward', 'coarse', 'crude', 'embryonic', 'in embryo', 'in ovo', 'in the rough', 'oversimple', 'reductionistic', 'reductive', 'rough'],
    'unprocurable': ['beyond reach', 'closed forever to', 'closed to', 'impenetrable', 'impervious', 'inaccessible', 'lost to', 'out of reach', 'un-come-at-able', 'unaccessible', 'unapproachable', 'unattainable'],
    'unproductive': ['abortive', 'acarpous', 'arid', 'barren', 'bootless', 'celibate', 'childless', 'desert', 'desolate', 'drained', 'dried-up', 'dry'],
    'unproductiveness': ['absurdity', 'aimlessness', 'bootlessness', 'emptiness', 'fatuity', 'fecklessness', 'fruitlessness', 'futility', 'hollowness', 'impotence', 'inanity', 'ineffectiveness'],
    'unprofessional': ['amateur', 'amateurish', 'everyday', 'improper', 'incompetent', 'inefficient', 'inexperienced', 'inexpert', 'inferior', 'lax', 'lay', 'low-quality'],
    'unproficient': ['artless', 'half-assed', 'inadept', 'inapt', 'inattentive', 'inefficient', 'inept', 'inexpert', 'mediocre', 'pedestrian', 'poor', 'skill-less'],
    'unprofitable': ['abortive', 'barren', 'bootless', 'deleterious', 'detrimental', 'disadvantageous', 'disserviceable', 'fruitless', 'futile', 'gainless', 'harmful', 'ineffective'],
    'unprofound': ['ankle-deep', 'birdbrained', 'birdwitted', 'cursory', 'depthless', 'epidermal', 'featherbrained', 'flighty', 'fluffy', 'frivolous', 'frothy', 'jejune'],
    'unprogressive': ['backward', 'behindhand', 'benighted', 'conservative', 'die-hard', 'fogyish', 'ignorant', 'nonprogressive', 'old-fashioned', 'old-fogyish', 'old-line', 'opposed to change'],
    'unpromising': ['adverse', 'apocalyptic', 'bad', 'baleful', 'baneful', 'black', 'bodeful', 'boding', 'dark', 'dire', 'doomful', 'doubtable'],
    'unprompted': ['arbitrary', 'automatic', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous', 'impulsive', 'independent', 'instinctive'],
    'unpronounced': ['echoless', 'hush as death', 'hushed', 'inaudible', 'mousy', 'noiseless', 'quiescent', 'quiet', 'silent', 'soundless', 'still', 'still as death'],
    'unpropitious': ['adversary', 'adversative', 'adverse', 'alien', 'antagonistic', 'anti', 'antipathetic', 'antithetic', 'apocalyptic', 'bad', 'baleful', 'baneful'],
    'unprosperous': ['badly off', 'broke', 'depressed', 'destitute', 'dire', 'distressed', 'donsie', 'doomful', 'down to bedrock', 'embarrassed', 'evil-starred', 'fatal'],
    'unprotected': ['aidless', 'bare-handed', 'defenseless', 'fatherless', 'friendless', 'guardless', 'guideless', 'helpless', 'insecure', 'leaderless', 'motherless', 'pregnable'],
    'unprovable': ['agnostic', 'ambiguous', 'capricious', 'chancy', 'changeable', 'controvertible', 'dicey', 'doubting', 'equivocal', 'erratic', 'fickle', 'hesitant'],
    'unproved': ['aberrant', 'abroad', 'adrift', 'all abroad', 'all off', 'all wrong', 'amiss', 'apocryphal', 'askew', 'astray', 'at fault', 'awry'],
    'unprovided': ['bare-handed', 'beggarly', 'disqualified', 'empty-handed', 'famished', 'half-starved', 'ill off', 'ill-equipped', 'ill-fitted', 'ill-furnished', 'ill-provided', 'impoverished'],
    'unprovidential': ['badly off', 'depressed', 'dire', 'donsie', 'doomful', 'evil-starred', 'fatal', 'fortuneless', 'funest', 'hapless', 'ill off', 'ill-starred'],
    'unqualified': ['abiding', 'absolute', 'admitting no exception', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'arrant', 'authentic', 'blasted', 'blessed', 'bona fide'],
    'unquelled': ['unabated', 'unallayed', 'unbeaten', 'unbowed', 'unbroken', 'unconquered', 'undefeated', 'unenthralled', 'unextinguished', 'ungoverned', 'unmitigated', 'unquenched'],
    'unquenchable': ['a hog for', 'acquisitive', 'all-devouring', 'avaricious', 'avid', 'bottomless', 'coveting', 'covetous', 'deathless', 'devouring', 'esurient', 'gluttonous'],
    'unquestionable': ['absolute', 'actual', 'admitting no question', 'ascertained', 'attested', 'authenticated', 'believable', 'bona fide', 'categorically true', 'certain', 'certified', 'clear'],
    'unquestioned': ['accepted', 'believed', 'beyond question', 'credited', 'doubtless', 'indubious', 'past dispute', 'questionless', 'received', 'trusted', 'unchallenged', 'uncontested'],
    'unquestioning': ['abiding', 'absolute', 'admitting no exception', 'all-out', 'categorical', 'clear', 'complete', 'conclusive', 'decided', 'decisive', 'definite', 'definitive'],
    'unquiet': ['agitated', 'anguished', 'antsy', 'antsy-pantsy', 'anxious', 'bored', 'breathless', 'bustling', 'chafing', 'cheerless', 'depressed', 'discomposed'],
    'unravel': ['account for', 'allegorize', 'answer', 'avulse', 'bottom', 'break', 'break loose', 'break out', 'carry away', 'clarify', 'clear', 'clear up'],
    'unraveling': ['accomplishment', 'answer', 'ascertainment', 'breaking out', 'clearing', 'clearing up', 'cracking', 'decipherment', 'decoding', 'denouement', 'determination', 'disembarrassment'],
    'unreachable': ['beyond reach', 'closed forever to', 'closed to', 'impenetrable', 'impervious', 'inaccessible', 'lost to', 'out of reach', 'un-come-at-able', 'unaccessible', 'unapproachable', 'unattainable'],
    'unread': ['gothic', 'philistine', 'barbarous', 'bookless', 'deceived', 'functionally illiterate', 'grammarless', 'heathen', 'hoodwinked', 'ill-educated', 'illiterate', 'led astray'],
    'unready': ['ad-lib', 'airy', 'arrested', 'asleep', 'back', 'backward', 'behindhand', 'belated', 'blocked', 'careless', 'casual', 'caught napping'],
    'unreal': ['barmecidal', 'barmecide', 'affected', 'air-built', 'airy', 'apocryphal', 'apparent', 'apparitional', 'artificial', 'assumed', 'autistic', 'bastard'],
    'unrealistic': ['airy', 'autistic', 'delusional', 'delusive', 'delusory', 'dereistic', 'fanciful', 'idealistic', 'illogical', 'illusory', 'imaginary', 'immaterial'],
    'unreality': ['prospero', 'absence', 'airiness', 'appearance', 'autism', 'autistic thinking', 'bodilessness', 'delusiveness', 'deprivation', 'dereism', 'dereistic thinking', 'dreamery'],
    'unrealizable': ['beyond one', 'impracticable', 'impractical', 'infeasible', 'inoperable', 'insuperable', 'insurmountable', 'too much for', 'unachievable', 'unattainable', 'uncompassable', 'undoable'],
    'unrealized': ['behind the curtain', 'behind the scenes', 'camouflaged', 'concealed', 'disguised', 'hidden', 'imperceptible', 'indiscernible', 'insensible', 'invisible', 'latent', 'neglected'],
    'unreason': ['callowness', 'childishness', 'immaturity', 'imprudence', 'inadvisability', 'inattention', 'inconsideration', 'indiscreetness', 'indiscretion', 'inexpedience', 'injudiciousness', 'irrationality'],
    'unreasonable': ['a bit much', 'abandoned', 'absonant', 'absurd', 'arbitrary', 'bigoted', 'blind', 'boundless', 'brainless', 'capricious', 'contradictory', 'contrary to reason'],
    'unreasonableness': ['abandon', 'antilogy', 'boundlessness', 'callowness', 'childishness', 'egregiousness', 'enormousness', 'exaggeration', 'excess', 'excessiveness', 'exorbitance', 'exorbitancy'],
    'unreasoning': ['arbitrary', 'blank', 'blankminded', 'brainless', 'calm', 'capricious', 'careless', 'emotionalistic', 'emotive', 'empty', 'empty-headed', 'fatuous'],
    'unreceptive': ['closed', 'closed to', 'impersuadable', 'impersuasible', 'impervious', 'inflexible', 'inhospitable', 'obstinate', 'unamenable', 'uncordial', 'unfriendly', 'ungracious'],
    'unrecognizable': ['blear', 'bleared', 'bleary', 'blurred', 'blurry', 'confused', 'dark', 'dim', 'faint', 'feeble', 'filmy', 'foggy'],
    'unrefined': ['doric', 'gothic', 'neanderthal', 'philistine', 'animal', 'arrested', 'awkward', 'backward', 'barbarian', 'barbaric', 'barbarous', 'bestial'],
    'unreflecting': ['arbitrary', 'capricious', 'careless', 'heedless', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-gauged', 'ill-judged', 'impolitic', 'imprudent'],
    'unrefreshed': ['debilitated', 'drooping', 'droopy', 'enervated', 'enfeebled', 'fagged', 'faint', 'fainting', 'fatigued', 'feeling faint', 'flagging', 'footsore'],
    'unrefutable': ['absolute', 'actual', 'admitting no question', 'confirmable', 'demonstrable', 'demonstratable', 'factual', 'historical', 'inappealable', 'incontestable', 'incontrovertible', 'indisputable'],
    'unrefuted': ['actual', 'ascertained', 'attested', 'authenticated', 'categorically true', 'certain', 'certified', 'confirmed', 'corroborated', 'demonstrated', 'determined', 'documentary'],
    'unregarded': ['abandoned', 'deserted', 'disregarded', 'half-done', 'ignored', 'laid aside', 'left undone', 'missed', 'neglected', 'omitted', 'overlooked', 'passed by'],
    'unregenerate': ['balking', 'balky', 'bigoted', 'bulldogged', 'bulletheaded', 'bullheaded', 'case-hardened', 'damned', 'dogged', 'dogmatic', 'fanatic', 'fleshly'],
    'unreined': ['abandoned', 'disobedient', 'go-go', 'headstrong', 'heady', 'immoderate', 'incontinent', 'indulgent', 'insubordinate', 'intemperate', 'irrepressible', 'irresponsible'],
    'unrelated': ['alien', 'apart', 'detached', 'different', 'disconnected', 'discrete', 'disjunct', 'disrelated', 'dissimilar', 'dissociated', 'distinct', 'exotic'],
    'unrelaxed': ['firm', 'pokerlike', 'ramrodlike', 'renitent', 'rigid', 'rodlike', 'starched', 'starchy', 'stiff', 'stiff as buckram', 'strained', 'stretched tight'],
    'unrelenting': ['adamant', 'adamantine', 'assiduous', 'cast-iron', 'constant', 'continuing', 'de longue haleine', 'diligent', 'dogged', 'dour', 'endless', 'enduring'],
    'unreliability': ['capriciousness', 'chanciness', 'changeableness', 'coquettishness', 'credibility gap', 'criticalness', 'danger', 'delicacy', 'desultoriness', 'deviability', 'doubtfulness', 'dubiousness'],
    'unreliable': ['adrift', 'afloat', 'alternating', 'amorphous', 'capricious', 'changeable', 'changeful', 'coquettish', 'dangerous', 'desultory', 'deviable', 'disreputable'],
    'unrelieved': ['absolute', 'arrant', 'articulated', 'bare', 'barren', 'bland', 'blank', 'bleached', 'boring', 'catenated', 'ceaseless', 'characterless'],
    'unremarkable': ['average', 'bourgeois', 'common', 'commonplace', 'conventional', 'garden', 'garden-variety', 'middle-class', 'no great shakes', 'normal', 'ordinary', 'plastic'],
    'unremitting': ['abiding', 'ageless', 'ardent', 'articulated', 'assiduous', 'catenated', 'ceaseless', 'changeless', 'chattering', 'coeternal', 'concatenated', 'connected'],
    'unremorseful': ['bowelless', 'cruel', 'dog-eat-dog', 'flinty', 'griefless', 'hard', 'harsh', 'heartless', 'impenitent', 'inclement', 'inexorable', 'merciless'],
    'unrenowned': ['ignotus', 'inglorious', 'little known', 'nameless', 'no credit to', 'obscure', 'renownless', 'uncelebrated', 'undistinguished', 'unfamed', 'unglorified', 'unheard-of'],
    'unrepeatable': ['fescennine', 'rabelaisian', 'alone', 'bawdy', 'blue', 'dirty', 'filthy', 'foul', 'foul-mouthed', 'foul-spoken', 'foul-tongued', 'fulsome'],
    'unrepentant': ['callous', 'hard', 'hardened', 'impenitent', 'insolent', 'obdurate', 'recidivist', 'recidivistic', 'recidivous', 'regretless', 'remorseless', 'unabject'],
    'unrepressed': ['abandoned', 'accessible', 'approachable', 'candid', 'communicative', 'conversable', 'demonstrative', 'effusive', 'expansive', 'extroverted', 'frank', 'free'],
    'unrequested': ['arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'nonmandatory', 'offered', 'optional'],
    'unrequired': ['arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'inessential', 'needless', 'nonessential'],
    'unresemblance': ['bad copy', 'bad likeness', 'camouflage', 'contrast', 'difference', 'disguise', 'disparity', 'dissemblance', 'dissimilarity', 'dissimilation', 'dissimilitude', 'divergence'],
    'unresembling': ['contrasting', 'counter', 'different', 'disparate', 'dissimilar', 'divergent', 'diverse', 'hardly like', 'nonuniform', 'odd', 'off', 'offbeat'],
    'unreserve': ['abandon', 'abandonment', 'accessibility', 'approachability', 'artlessness', 'bluffness', 'bluntness', 'broadness', 'brusqueness', 'candidness', 'candor', 'communicativeness'],
    'unreserved': ['abandoned', 'absolute', 'accessible', 'admitting no exception', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'approachable', 'artless', 'bluff', 'blunt'],
    'unresolved': ['ambitendent', 'ambivalent', 'arguable', 'at loose ends', 'capricious', 'changeable', 'debatable', 'double-minded', 'dubious', 'faltering', 'fence-sitting', 'fence-straddling'],
    'unrespectable': ['derogatory', 'discreditable', 'disgraceful', 'dishonorable', 'disreputable', 'ignoble', 'ignominious', 'infamous', 'inglorious', 'notorious', 'seamy', 'shabby'],
    'unresponsive': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'callous', 'calloused', 'catatonic', 'chill', 'chilly', 'closed to', 'cold'],
    'unrest': ['activity', 'actuation', 'agitation', 'agony', 'ailment', 'anguish', 'anxiety', 'anxiousness', 'bluster', 'bobbery', 'boil', 'boiling'],
    'unrestrained': ['a bit much', 'abandoned', 'ablaze', 'accessible', 'adrift', 'afire', 'afloat', 'alternating', 'amorphous', 'approachable', 'ardent', 'artless'],
    'unrestraint': ['abandon', 'abandonment', 'accessibility', 'approachability', 'artlessness', 'bluffness', 'bluntness', 'broadness', 'brusqueness', 'candidness', 'candor', 'carelessness'],
    'unrestricted': ['absolute', 'accessible', 'admitting no exception', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'approachable', 'bald', 'bare', 'born', 'broad-based'],
    'unreticent': ['accessible', 'approachable', 'candid', 'communicative', 'conversable', 'demonstrative', 'effusive', 'expansive', 'extroverted', 'frank', 'free', 'free-speaking'],
    'unreturnable': ['changeless', 'constant', 'immutable', 'incommutable', 'inconvertible', 'indefeasible', 'inert', 'insusceptible of change', 'intransmutable', 'invariable', 'irretrievable', 'irreversible'],
    'unrevealed': ['able', 'arcane', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'cryptic', 'dark', 'enigmatic', 'esoteric'],
    'unrewarding': ['abortive', 'barren', 'bootless', 'deleterious', 'detrimental', 'disadvantageous', 'disserviceable', 'fruitless', 'gainless', 'harmful', 'injurious', 'nonremunerative'],
    'unrhythmical': ['broken', 'capricious', 'careening', 'catchy', 'choppy', 'desultory', 'deviative', 'disconnected', 'discontinuous', 'eccentric', 'erratic', 'fitful'],
    'unriddle': ['answer', 'bottom', 'break', 'clear up', 'crack', 'debug', 'decipher', 'decode', 'disentangle', 'divine', 'do', 'dope'],
    'unrighteous': ['adamic', 'aberrant', 'abnormal', 'abominable', 'atrocious', 'backsliding', 'carnal', 'criminal', 'delinquent', 'deviant', 'disgraceful', 'erring'],
    'unripe': ['a bit previous', 'a novice at', 'a stranger to', 'acerb', 'acerbate', 'acerbic', 'acescent', 'adolescent', 'advanced', 'at half cock', 'awkward', 'blankminded'],
    'unrivaled': ['beyond compare', 'beyond comparison', 'easily first', 'facile princeps', 'immortal', 'incomparable', 'inimitable', 'invincible', 'matchless', 'nulli secundus', 'only', 'peerless'],
    'unrobed': ['clothesless', 'decollete', 'disrobed', 'en deshabille', 'garbless', 'garmentless', 'half-clothed', 'in dishabille', 'low-cut', 'nudish', 'raimentless', 'strapless'],
    'unroll': ['bare', 'break the seal', 'bring to light', 'clear', 'deobstruct', 'develop', 'disclose', 'discover', 'dismask', 'draw the veil', 'expose', 'free'],
    'unromantic': ['arid', 'authentic', 'barren', 'bona fide', 'candid', 'card-carrying', 'common', 'commonplace', 'dinkum', 'down-to-earth', 'dry', 'dull'],
    'unruffled': ['accordant', 'alike', 'at rest', 'automatic', 'balanced', 'calm', 'cloistered', 'collected', 'composed', 'consistent', 'consonant', 'constant'],
    'unruliness': ['abandon', 'abandonment', 'anarchism', 'anarcho-syndicalism', 'anarchy', 'antinomianism', 'assault', 'attack', 'battering', 'butchery', 'chaos', 'confusion'],
    'unruly': ['abandoned', 'anarchial', 'anarchic', 'anarchistic', 'antinomian', 'beyond control', 'boisterous', 'breachy', 'chaotic', 'contrary', 'contumacious', 'defiant'],
    'unsaddle': ['break', 'buck off', 'bust', 'cashier', 'deconsecrate', 'defrock', 'depose', 'deracinate', 'dethrone', 'disbar', 'discrown', 'disenthrone'],
    'unsaid': ['implicit', 'implied', 'inferred', 'silent', 'tacit', 'undeclared', 'understood', 'unexpressed', 'unmentioned', 'unproclaimed', 'unpronounced', 'unpublished'],
    'unsaintly': ['adamic', 'backsliding', 'carnal', 'erring', 'fallen', 'fleshly', 'frail', 'godless', 'impious', 'impure', 'infirm', 'irreligious'],
    'unsalvageable': ['beyond recall', 'beyond remedy', 'cureless', 'gone', 'immedicable', 'incorrigible', 'incurable', 'inoperable', 'irreclaimable', 'irrecoverable', 'irredeemable', 'irreformable'],
    'unsanctioned': ['banned', 'barred', 'contraband', 'forbade', 'forbid', 'forbidden', 'illegal', 'illicit', 'nonpermissible', 'not permitted', 'off limits', 'out of bounds'],
    'unsanitary': ['bad', 'bad for', 'contaminated', 'foul', 'harmful', 'injurious', 'insalubrious', 'insanitary', 'morbific', 'noisome', 'noxious', 'pathogenic'],
    'unsated': ['a hog for', 'acquisitive', 'all-devouring', 'avaricious', 'avid', 'bottomless', 'coveting', 'covetous', 'devouring', 'esurient', 'gluttonous', 'gobbling'],
    'unsatisfactory': ['amiss', 'bad', 'bum', 'crappy', 'defective', 'deficient', 'disappointing', 'disheartening', 'displeasing', 'dissatisfactory', 'failing', 'falling short'],
    'unsatisfied': ['a hog for', 'acquisitive', 'all-devouring', 'anguished', 'anxious', 'avaricious', 'avid', 'beefing', 'bellyaching', 'bitching', 'bored', 'bottomless'],
    'unsatisfying': ['defective', 'deficient', 'disappointing', 'disheartening', 'displeasing', 'dissatisfactory', 'failing', 'found wanting', 'imperfect', 'inadequate', 'incommensurate', 'incompetent'],
    'unsavory': ['amoral', 'bitter', 'conscienceless', 'corrupt', 'corrupted', 'criminal', 'crooked', 'dark', 'dead', 'derogatory', 'devious', 'dilute'],
    'unsay': ['abjure', 'back down', 'back out', 'backwater', 'climb down', 'crawfish out', 'deny', 'disavow', 'disclaim', 'disown', 'eat crow', 'eat humble pie'],
    'unsaying': ['abjuration', 'abjurement', 'denial', 'disavowal', 'disclaimer', 'disclamation', 'disowning', 'disownment', 'expatriation', 'forswearing', 'palinode', 'palinody'],
    'unscarred': ['bright', 'fresh', 'harmless', 'inviolate', 'mint', 'pristine', 'scatheless', 'unbroken', 'unbruised', 'undamaged', 'undefaced', 'undeformed'],
    'unscathed': ['as new', 'bright', 'fresh', 'harmless', 'immune', 'immunized', 'insured', 'intact', 'inviolate', 'like new', 'mint', 'pristine'],
    'unscholarly': ['gothic', 'philistine', 'barbarous', 'bookless', 'callow', 'deceived', 'functionally illiterate', 'grammarless', 'green', 'heathen', 'hoodwinked', 'ill-educated'],
    'unschooled': ['gothic', 'philistine', 'amateurish', 'artless', 'barbarous', 'benighted', 'bookless', 'deceived', 'disembarrass', 'disembroil', 'disencumber', 'disentangle'],
    'unscientific': ['absonant', 'contradictory', 'contrary to reason', 'fallacious', 'faulty', 'flawed', 'illogical', 'inauthentic', 'inconclusive', 'incongruous', 'inconsequent', 'inconsequential'],
    'unscramble': ['answer', 'bottom', 'clarify', 'clear', 'clear up', 'crack', 'debug', 'decipher', 'decode', 'disburden', 'disembarrass', 'disembroil'],
    'unscratched': ['bright', 'fresh', 'harmless', 'inviolate', 'mint', 'pristine', 'scatheless', 'unbroken', 'unbruised', 'undamaged', 'undefaced', 'undeformed'],
    'unscrupulous': ['amoral', 'artful', 'conscienceless', 'corrupt', 'corrupted', 'crafty', 'criminal', 'crooked', 'cunning', 'dark', 'deceitful', 'devious'],
    'unseasonable': ['ahead of time', 'anachronistic', 'antedated', 'bad', 'beforehand', 'behind time', 'behindhand', 'dated', 'deplorable', 'early', 'foredated', 'futile'],
    'unseasoned': ['a novice at', 'a stranger to', 'adolescent', 'at half cock', 'budding', 'callow', 'dewy', 'disaccustomed', 'fledgling', 'fresh', 'green', 'green as grass'],
    'unseat': ['break', 'buck off', 'bust', 'cashier', 'deconsecrate', 'defrock', 'depose', 'deracinate', 'dethrone', 'disarticulate', 'disbar', 'discrown'],
    'unsecurable': ['beyond reach', 'closed forever to', 'closed to', 'impenetrable', 'impervious', 'inaccessible', 'lost to', 'out of reach', 'un-come-at-able', 'unaccessible', 'unapproachable', 'unattainable'],
    'unseeing': ['a stranger to', 'ableptical', 'amaurotic', 'asleep', 'benighted', 'bereft of light', 'blind', 'blind to', 'caught napping', 'color-blind', 'dark', 'dead to'],
    'unseemly': ['doric', 'aberrant', 'abnormal', 'abominable', 'atrocious', 'awkward', 'bad', 'barbaric', 'barbarous', 'cacophonous', 'chintzy', 'clumsy'],
    'unseen': ['behind the curtain', 'behind the scenes', 'camouflaged', 'concealed', 'disguised', 'hidden', 'imperceptible', 'indiscernible', 'insensible', 'invisible', 'latent', 'out of sight'],
    'unselective': ['blanket', 'casual', 'general', 'imprudent', 'indiscreet', 'indiscriminate', 'indiscriminative', 'insensitive', 'nonjudgmental', 'promiscuous', 'tactless', 'uncritical'],
    'unselfish': ['olympian', 'altruistic', 'bighearted', 'bounteous', 'bountiful', 'candid', 'charitable', 'committed', 'consecrated', 'dedicated', 'detached', 'devoted'],
    'unselfishness': ['olympian detachment', 'bigheartedness', 'bounteousness', 'bountifulness', 'bounty', 'detachment', 'disinterest', 'disinterestedness', 'dispassion', 'dispassionateness', 'easy purse strings', 'free hand'],
    'unsentimental': ['down-to-earth', 'earthy', 'hard', 'hard-boiled', 'hardheaded', 'matter-of-fact', 'positivistic', 'practical', 'practical-minded', 'pragmatic', 'rational', 'realist'],
    'unserviceable': ['functionless', 'impractical', 'in disrepair', 'inapplicable', 'inoperable', 'inoperative', 'nonfunctional', 'nonutilitarian', 'otiose', 'out of order', 'out of whack', 'unconducive'],
    'unsettle': ['addle', 'addle the wits', 'agitate', 'ball up', 'becloud', 'bedazzle', 'befuddle', 'bewilder', 'bother', 'bug', 'cloud', 'confuse'],
    'unsettled': ['abnormal', 'adrift', 'afloat', 'agitated', 'alternating', 'ambitendent', 'ambivalent', 'amiss', 'amorphous', 'askew', 'at issue', 'at loose ends'],
    'unsettling': ['agitating', 'breathtaking', 'charged', 'cliff-hanging', 'disconcerting', 'disquieting', 'distracting', 'disturbing', 'electric', 'exciting', 'exhilarating', 'galvanic'],
    'unsexed': ['asexual', 'castrated', 'cold', 'debilitated', 'demasculinized', 'devitalized', 'effeminized', 'emasculate', 'emasculated', 'enervated', 'eunuchized', 'frigid'],
    'unshackle': ['discharge', 'emancipate', 'liberate', 'loose', 'loosen', 'manumit', 'release', 'unbar', 'unbind', 'unbolt', 'unbridle', 'unbuckle'],
    'unshakable': ['abiding', 'balanced', 'cool', 'fast', 'fiducial', 'firm', 'firm as gibraltar', 'fixed', 'imperturbable', 'in equilibrium', 'predictable', 'reliable'],
    'unshaken': ['abiding', 'calm', 'constant', 'coolheaded', 'failing', 'firm', 'fixed', 'flinty', 'going strong', 'immovable', 'in full force', 'in full swing'],
    'unsharpened': ['abrupt', 'bluff', 'blunt', 'blunt-edged', 'blunt-ended', 'blunt-pointed', 'blunted', 'bluntish', 'dull', 'dull-edged', 'dull-pointed', 'dulled'],
    'unsheathe': ['bare', 'break the seal', 'bring to light', 'clear', 'denudate', 'denude', 'deobstruct', 'develop', 'disclose', 'discover', 'dismask', 'divest'],
    'unsheltered': ['bare-handed', 'defenseless', 'guardless', 'helpless', 'unarmed', 'unarmored', 'unattended', 'uncovered', 'undefended', 'unfortified', 'ungarrisoned', 'unguarded'],
    'unshorn': ['bristly', 'bushy', 'cirrose', 'complete', 'fleecy', 'flocculent', 'furry', 'fuzzy', 'hairy', 'hirsute', 'hispid', 'lanate'],
    'unshrinking': ['accessible', 'approachable', 'calm', 'candid', 'communicative', 'conversable', 'coolheaded', 'demonstrative', 'effusive', 'expansive', 'extroverted', 'frank'],
    'unsightly': ['beat-up', 'beautiless', 'bedraggled', 'blemished', 'blotted', 'blowzy', 'cacophonic', 'cacophonous', 'careless', 'chintzy', 'defaced', 'dilapidated'],
    'unskilled': ['a novice at', 'a stranger to', 'amateurish', 'callow', 'dabbling', 'dilettante', 'dilettantish', 'fresh', 'green', 'green as grass', 'ignorant', 'immature'],
    'unskillful': ['alert', 'artless', 'bad', 'base', 'black', 'criminal', 'deficient', 'evil', 'half-assed', 'ill', 'imperfect', 'improper'],
    'unslakeable': ['a hog for', 'acquisitive', 'all-devouring', 'avaricious', 'avid', 'bottomless', 'coveting', 'covetous', 'devouring', 'esurient', 'gluttonous', 'gobbling'],
    'unsmiling': ['cheerless', 'decorous', 'demure', 'discontented', 'earnest', 'formal', 'frowning', 'grave', 'grim', 'grim-faced', 'grim-visaged', 'humorless'],
    'unsmooth': ['asperous', 'broken', 'bumpy', 'choppy', 'coarse', 'coarse-grained', 'corrugated', 'craggy', 'cross-grained', 'grainy', 'granulated', 'harsh'],
    'unsnarl': ['arrange', 'break loose', 'break out', 'clarify', 'clear', 'clear up', 'cut loose', 'disburden', 'disembarrass', 'disembroil', 'disencumber', 'disengage'],
    'unsociable': ['timonistic', 'aloof', 'antisocial', 'autistic', 'bashful', 'chill', 'chilly', 'close', 'cold', 'cool', 'cynical', 'disaccordant'],
    'unsocial': ['aloof', 'anchoretic', 'anchoritic', 'antisocial', 'autistic', 'bashful', 'chilly', 'close', 'cold', 'cool', 'detached', 'dissociable'],
    'unsoftened': ['callous', 'hard', 'hardened', 'impenitent', 'insolent', 'obdurate', 'unabated', 'unabject', 'unallayed', 'uncontrite', 'unextinguished', 'unmelted'],
    'unsoiled': ['bleached', 'blotless', 'bright', 'chaste', 'clean', 'cleanly', 'dainty', 'dirt-free', 'fair', 'fastidious', 'fresh', 'immaculate'],
    'unsolicited': ['abandoned', 'arbitrary', 'autonomous', 'deserted', 'discretional', 'discretionary', 'disregarded', 'elective', 'free', 'free will', 'gratuitous', 'half-done'],
    'unsolicitous': ['airy', 'apathetic', 'ataractic', 'blase', 'boorish', 'caddish', 'careless', 'casual', 'coarse', 'crude', 'cursory', 'degage'],
    'unsophisticated': ['absolute', 'artless', 'authentic', 'bald', 'bare', 'blank', 'bluff', 'blunt', 'bona fide', 'born yesterday', 'callow', 'candid'],
    'unsophistication': ['artlessness', 'baldness', 'bareness', 'beauty unadorned', 'bluffness', 'bluntness', 'candor', 'childlikeness', 'cullibility', 'deceivability', 'directness', 'dupability'],
    'unsorted': ['aimless', 'amorphous', 'assorted', 'capricious', 'casual', 'crude', 'desultory', 'disarticulated', 'discontinuous', 'disjunct', 'disordered', 'dispersed'],
    'unsought': ['arbitrary', 'autonomous', 'discretional', 'discretionary', 'elective', 'free', 'free will', 'gratuitous', 'independent', 'nonmandatory', 'offered', 'optional'],
    'unsound': ['albigensian', 'arian', 'catharist', 'donatist', 'ebionitist', 'erastian', 'gnostic', 'jansenist', 'jansenistic', 'jovinianist', 'jovinianistic', 'lollard'],
    'unsparing': ['spartan', 'spartanic', 'ardent', 'assiduous', 'astringent', 'austere', 'authoritarian', 'bighearted', 'bounteous', 'bountiful', 'demanding', 'diligent'],
    'unspeakable': ['abominable', 'abusive', 'appalling', 'arrant', 'atrocious', 'awesome', 'awful', 'backhand', 'backhanded', 'bad', 'baneful', 'base'],
    'unspecified': ['abstract', 'aleatoric', 'aleatory', 'amorphous', 'anonymous', 'bland', 'blobby', 'blurred', 'blurry', 'broad', 'chance', 'chancy'],
    'unspectacular': ['average', 'bourgeois', 'common', 'commonplace', 'conventional', 'garden', 'garden-variety', 'middle-class', 'no great shakes', 'normal', 'ordinary', 'plastic'],
    'unspent': ['extra', 'fresh', 'held back', 'held in reserve', 'held out', 'in abeyance', 'in hand', 'mint', 'new', 'original', 'pristine', 'put aside'],
    'unspiritual': ['adamic', 'circean', 'philistine', 'animal', 'animalistic', 'beastlike', 'beastly', 'bestial', 'bodily', 'brutal', 'brute', 'brutish'],
    'unspoiled': ['absolute', 'arcadian', 'arrant', 'bright', 'bucolic', 'classical', 'complete', 'conserved', 'consummate', 'crass', 'decided', 'definitive'],
    'unspoken': ['arcane', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'cryptic', 'dark', 'enigmatic', 'esoteric', 'hermetic'],
    'unspotted': ['christian', 'absolute', 'beyond all praise', 'blameless', 'bleached', 'blotless', 'bright', 'chaste', 'clean', 'cleanly', 'creditable', 'dainty'],
    'unstable': ['adrift', 'afloat', 'alternating', 'ambiguous', 'amorphous', 'borderline', 'brittle', 'buoyant', 'canted', 'capricious', 'changeable', 'changeful'],
    'unstaffed': ['abandoned', 'available', 'deserted', 'forsaken', 'free', 'godforsaken', 'open', 'tenantless', 'unfilled', 'uninhabited', 'unmanned', 'unoccupied'],
    'unstained': ['christian', 'blameless', 'bleached', 'blotless', 'bright', 'chaste', 'clean', 'cleanly', 'creditable', 'dainty', 'decent', 'dirt-free'],
    'unsteadfast': ['adrift', 'afloat', 'alternating', 'amorphous', 'capricious', 'changeable', 'changeful', 'dangerous', 'derelict', 'desultory', 'deviable', 'disaffected'],
    'unsteady': ['adrift', 'afloat', 'alternating', 'amorphous', 'broken', 'canted', 'capricious', 'careening', 'catchy', 'changeable', 'changeful', 'changing'],
    'unstick': ['cast off', 'detach', 'diffuse', 'disengage', 'disjoin', 'disperse', 'doff', 'ease', 'ease off', 'free', 'let go', 'let up'],
    'unstinting': ['bighearted', 'bounteous', 'bountiful', 'free', 'freehanded', 'freehearted', 'generous', 'giving', 'gracious', 'greathearted', 'handsome', 'hospitable'],
    'unstop': ['bare', 'clear', 'deobstruct', 'disclose', 'expose', 'free', 'manifest', 'ope', 'patefy', 'reveal', 'unblock', 'uncase'],
    'unstoppable': ['certain', 'fated', 'fateful', 'indefeasible', 'ineluctable', 'inescapable', 'inevasible', 'inevitable', 'inexorable', 'inflexible', 'irresistible', 'irrevocable'],
    'unstopped': ['articulated', 'bald', 'bare', 'catenated', 'ceaseless', 'chattering', 'clear', 'cleared', 'concatenated', 'connected', 'constant', 'continual'],
    'unstrained': ['calm', 'coolheaded', 'inexcitable', 'nerveless', 'relaxed', 'rock-steady', 'steady', 'steady-handed', 'steady-nerved', 'steel-nerved', 'strong-nerved', 'unblenching'],
    'unstrap': ['cast off', 'detach', 'disengage', 'doff', 'free', 'liberate', 'loose', 'loosen', 'release', 'remove', 'take off', 'unbar'],
    'unstressed': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad', 'cacuminal'],
    'unstrung': ['aghast', 'anemic', 'appalled', 'ashen', 'asthenic', 'astounded', 'awed', 'awestricken', 'awestruck', 'blanched', 'bloodless', 'chicken'],
    'unstudied': ['bohemian', 'ad-lib', 'affable', 'artless', 'automatic', 'casual', 'caught napping', 'caught off balance', 'caught short', 'colloquial', 'common', 'conversational'],
    'unsturdy': ['abortive', 'bootless', 'crumbling', 'decrepit', 'disintegrating', 'failed', 'failing', 'fruitless', 'futile', 'ineffective', 'ineffectual', 'inefficacious'],
    'unsubject': ['chartered', 'excepted', 'excused', 'exempt', 'exempted', 'favored', 'immune', 'irresponsible', 'let off', 'licensed', 'permitted', 'privileged'],
    'unsubmissive': ['beyond control', 'breachy', 'complaining', 'contrary', 'contumacious', 'defiant', 'deviant', 'disputatious', 'disputing', 'dissentient', 'dissenting', 'dissident'],
    'unsubstantial': ['barmecidal', 'barmecide', 'adulterated', 'airy', 'apparent', 'apparitional', 'asomatous', 'astral', 'attenuate', 'attenuated', 'autistic', 'bodiless'],
    'unsubstantiated': ['groundless', 'inconclusive', 'indecisive', 'not following', 'not proved', 'unascertained', 'unattested', 'unauthenticated', 'uncertified', 'unconfirmed', 'uncorroborated', 'undemonstrated'],
    'unsubtle': ['blanket', 'casual', 'general', 'imprudent', 'indiscreet', 'indiscriminate', 'indiscriminative', 'insensitive', 'nonjudgmental', 'promiscuous', 'tactless', 'uncritical'],
    'unsuccessful': ['abortive', 'balked', 'beaten', 'bootless', 'cursed', 'defeated', 'foiled', 'fruitless', 'frustrated', 'hapless', 'ineffective', 'ineffectual'],
    'unsuitability': ['babbittry', 'aberrance', 'aberrancy', 'abnormality', 'ad lib', 'anomaly', 'bad taste', 'bourgeois taste', 'camp', 'campiness', 'criminality', 'delinquency'],
    'unsuitable': ['aberrant', 'abnormal', 'abominable', 'atrocious', 'bad', 'chintzy', 'criminal', 'delinquent', 'deviant', 'disgraceful', 'evil', 'exceptionable'],
    'unsuited': ['disappointing', 'disqualified', 'ill-adapted', 'ill-assorted', 'ill-chosen', 'ill-equipped', 'ill-fitted', 'ill-furnished', 'ill-matched', 'ill-provided', 'ill-sorted', 'ill-suited'],
    'unsullied': ['christian', 'artless', 'blameless', 'bleached', 'blotless', 'bright', 'chaste', 'clean', 'cleanly', 'creditable', 'dainty', 'decent'],
    'unsung': ['anonymous', 'despised', 'disliked', 'disregarded', 'ignotus', 'inconspicuous', 'inglorious', 'insignificant', 'little known', 'lowly', 'misprized', 'misunderstood'],
    'unsupplied': ['bare-handed', 'beggarly', 'empty-handed', 'famished', 'half-starved', 'ill off', 'ill-equipped', 'ill-furnished', 'ill-provided', 'impoverished', 'on short commons', 'pauperized'],
    'unsupportable': ['baseless', 'controvertible', 'empty', 'groundless', 'idle', 'ill-founded', 'insupportable', 'intolerable', 'unattestable', 'unbased', 'unbearable', 'unconfirmable'],
    'unsupported': ['alienated', 'alone', 'aloof', 'apart', 'baseless', 'companionless', 'detached', 'empty', 'friendless', 'groundless', 'homeless', 'idle'],
    'unsuppressed': ['abandoned', 'accessible', 'approachable', 'candid', 'communicative', 'conversable', 'demonstrative', 'effusive', 'expansive', 'extroverted', 'frank', 'free'],
    'unsure': ['agnostic', 'ambiguous', 'awkward', 'blankminded', 'borderline', 'callow', 'capricious', 'chancy', 'changeable', 'dangerous', 'desultory', 'dicey'],
    'unsurpassed': ['best', 'beyond compare', 'beyond comparison', 'champion', 'choice', 'easily first', 'elect', 'elite', 'facile princeps', 'for the best', 'greatest', 'handpicked'],
    'unsurprised': ['agape', 'agog', 'all agog', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'awaiting', 'aweless', 'calm', 'certain', 'composed'],
    'unsusceptible': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'catatonic', 'changeless', 'chill', 'chilly', 'closed to', 'cold', 'cold as charity'],
    'unsuspected': ['able', 'accepted', 'believed', 'credited', 'enigmatic', 'incalculable', 'incognizable', 'mysterious', 'puzzling', 'received', 'sealed', 'strange'],
    'unsuspecting': ['a stranger to', 'asleep', 'bare-handed', 'blind to', 'caught napping', 'childlike', 'confiding', 'credulous', 'dead to', 'deaf to', 'defenseless', 'dependent'],
    'unsuspicious': ['artless', 'bluff', 'blunt', 'born yesterday', 'candid', 'childlike', 'confiding', 'credulous', 'dependent', 'depending', 'direct', 'doting'],
    'unsustainable': ['baseless', 'controvertible', 'empty', 'groundless', 'idle', 'ill-founded', 'unattestable', 'unbased', 'unconfirmable', 'undemonstrable', 'undemonstratable', 'unfounded'],
    'unsustained': ['baseless', 'empty', 'feeble', 'flimsy', 'groundless', 'idle', 'ill-founded', 'inconclusive', 'indecisive', 'insubstantial', 'not following', 'not proved'],
    'unswayed': ['olympian', 'candid', 'detached', 'disinterested', 'dispassionate', 'equitable', 'evenhanded', 'fair', 'impartial', 'impersonal', 'indifferent', 'just'],
    'unsweet': ['acerb', 'acerbate', 'acerbic', 'acescent', 'crab', 'crabbed', 'dry', 'green', 'pickled', 'pungent', 'sec', 'sour'],
    'unswerving': ['arrowlike', 'assiduous', 'constant', 'continuing', 'dead straight', 'diligent', 'direct', 'dogged', 'enduring', 'even', 'faithful', 'firm'],
    'unsymmetrical': ['aimless', 'amorphous', 'anamorphous', 'askew', 'asymmetric', 'bent', 'bowed', 'capricious', 'casual', 'cockeyed', 'contorted', 'crazy'],
    'unsympathetic': ['affectless', 'anesthetized', 'arctic', 'autistic', 'blunt', 'bowelless', 'callous', 'catatonic', 'chill', 'chilly', 'cold', 'cold as charity'],
    'unsystematic': ['aimless', 'amorphous', 'broken', 'capricious', 'careening', 'casual', 'catchy', 'changeable', 'changing', 'choppy', 'desultory', 'deviating'],
    'untactful': ['airy', 'blanket', 'brash', 'careless', 'casual', 'cursory', 'degage', 'disregardant', 'disregardful', 'easygoing', 'flippant', 'forgetful'],
    'untainted': ['absolute', 'beyond all praise', 'bleached', 'blotless', 'bright', 'chaste', 'clean', 'cleanly', 'conserved', 'dainty', 'defectless', 'dirt-free'],
    'untaken': ['abandoned', 'available', 'deserted', 'forsaken', 'free', 'godforsaken', 'open', 'tenantless', 'unfilled', 'uninhabited', 'unmanned', 'unoccupied'],
    'untalented': ['amateurish', 'brainless', 'foolish', 'headless', 'ignorant', 'incapable', 'incapable of', 'incompetent', 'ineffective', 'inefficient', 'inept', 'inferior'],
    'untalkative': ['brief', 'brusque', 'close', 'close-tongued', 'closemouthed', 'concise', 'curt', 'dumb', 'economical of words', 'indisposed to talk', 'laconic', 'mum'],
    'untamable': ['beyond control', 'breachy', 'contumacious', 'defiant', 'fractious', 'incorrigible', 'indocile', 'indomitable', 'insuppressible', 'intractable', 'irrepressible', 'obstreperous'],
    'untamed': ['gothic', 'neanderthal', 'animal', 'atrocious', 'barbarian', 'barbaric', 'barbarous', 'bestial', 'bloody', 'brutal', 'brutish', 'feral'],
    'untangle': ['answer', 'bottom', 'break loose', 'break out', 'clarify', 'clear', 'clear up', 'crack', 'cut loose', 'debug', 'decipher', 'decode'],
    'untangling': ['accomplishment', 'answer', 'ascertainment', 'breaking out', 'clearing', 'clearing up', 'cracking', 'decipherment', 'decoding', 'denouement', 'determination', 'disembarrassment'],
    'untapped': ['extra', 'fresh', 'held back', 'held in reserve', 'held out', 'in abeyance', 'in hand', 'mint', 'new', 'original', 'pristine', 'put aside'],
    'untarnished': ['christian', 'blameless', 'bleached', 'blotless', 'bright', 'chaste', 'clean', 'cleanly', 'creditable', 'dainty', 'decent', 'dirt-free'],
    'untaught': ['gothic', 'philistine', 'amateurish', 'barbarous', 'benighted', 'bookless', 'deceived', 'empty-headed', 'functionally illiterate', 'grammarless', 'heathen', 'hoodwinked'],
    'unteachable': ['boeotian', 'asinine', 'beef-brained', 'beef-witted', 'blockish', 'bovine', 'chumpish', 'cloddish', 'cowish', 'crass', 'dense', 'doltish'],
    'untenable': ['aidless', 'baseless', 'defenseless', 'empty', 'exceptionable', 'fatherless', 'faulty', 'flawed', 'friendless', 'groundless', 'guideless', 'helpless'],
    'untenanted': ['abandoned', 'available', 'deserted', 'forsaken', 'free', 'godforsaken', 'open', 'tenantless', 'unfilled', 'uninhabited', 'unmanned', 'unoccupied'],
    'untended': ['abandoned', 'available', 'deserted', 'disregarded', 'forsaken', 'free', 'godforsaken', 'half-done', 'ignored', 'laid aside', 'left undone', 'missed'],
    'untested': ['groundless', 'inconclusive', 'indecisive', 'not following', 'not proved', 'unascertained', 'unattested', 'unauthenticated', 'uncertified', 'unconfirmed', 'uncorroborated', 'undemonstrated'],
    'untether': ['loose', 'loosen', 'unbar', 'unbind', 'unbolt', 'unbridle', 'unbuckle', 'uncage', 'unchain', 'unfetter', 'ungag', 'unhandcuff'],
    'unthinkable': ['a bit thick', 'a bit thin', 'absurd', 'barred', 'beyond belief', 'closed-out', 'contrary to reason', 'doubtable', 'doubtful', 'dubious', 'dubitable', 'excluded'],
    'unthinking': ['airy', 'arbitrary', 'automatic', 'blank', 'blankminded', 'blind', 'brainless', 'calm', 'capricious', 'careless', 'casual', 'compulsive'],
    'unthought of': ['breakaway', 'imageless', 'involuntary', 'offbeat', 'rare', 'recherche', 'sui generis', 'uncommon', 'unconceived', 'unconceptualized', 'unconscious', 'unconsidered'],
    'unthoughtful': ['arbitrary', 'capricious', 'careless', 'disregardful', 'forgetful', 'heedless', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised', 'ill-gauged', 'ill-judged'],
    'untidy': ['beat-up', 'bedraggled', 'blowzy', 'botched', 'bungling', 'careless', 'chaotic', 'chintzy', 'clumsy', 'cluttered', 'deficient', 'dilapidated'],
    'untie': ['cast off', 'detach', 'disembarrass', 'disembroil', 'disencumber', 'disengage', 'disentangle', 'doff', 'free', 'liberate', 'loose', 'loosen'],
    'untied': ['adrift', 'afloat', 'aweigh', 'cast-off', 'clear', 'delivered', 'emancipated', 'extricated', 'floating', 'free', 'freed', 'liberated'],
    'untilled': ['acarpous', 'arid', 'barren', 'celibate', 'childless', 'desert', 'desolate', 'drained', 'dried-up', 'dry', 'exhausted', 'fallow'],
    'untimely': ['a bit previous', 'advanced', 'arrested', 'back', 'backward', 'bad', 'behindhand', 'belated', 'blocked', 'delayed', 'delayed-action', 'detained'],
    'untiring': ['assiduous', 'cartilaginous', 'chewy', 'cohesive', 'constant', 'continuing', 'coriaceous', 'dedicated', 'determined', 'diligent', 'dogged', 'durable'],
    'untold': ['all-comprehensive', 'all-inclusive', 'arcane', 'at issue', 'boundless', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'conditional'],
    'untouchable': ['dp', 'ishmael', 'affectless', 'anesthetized', 'antipodean', 'arctic', 'autistic', 'awesome', 'awful', 'back of beyond', 'banned', 'barred'],
    'untouched': ['able', 'artless', 'bright', 'callous', 'callow', 'dewy', 'enigmatic', 'entire', 'ever-new', 'evergreen', 'extra', 'firsthand'],
    'untoward': ['adverse', 'annoying', 'antagonistic', 'apocalyptic', 'awkward', 'bad', 'baleful', 'baneful', 'black', 'bleak', 'bodeful', 'boding'],
    'untrained': ['a stranger to', 'amateurish', 'disaccustomed', 'ignorant', 'inexperienced', 'new to', 'rusty', 'semiskilled', 'unaccomplished', 'unaccustomed', 'unacquainted with', 'unbusinesslike'],
    'untreated': ['arrested', 'backward', 'coarse', 'crude', 'embryonic', 'in embryo', 'in ovo', 'in the rough', 'oversimple', 'reductionistic', 'reductive', 'rough'],
    'untried': ['a novice at', 'a stranger to', 'callow', 'dewy', 'ever-new', 'evergreen', 'firsthand', 'fledgling', 'fresh', 'green', 'green as grass', 'groundless'],
    'untrimmed': ['bald', 'bare', 'blank', 'guileless', 'naked', 'nude', 'unadorned', 'unadulterated', 'unaffected', 'unarrayed', 'unassumed', 'unassuming'],
    'untrodden': ['callow', 'dewy', 'ever-new', 'evergreen', 'extra', 'firsthand', 'fledgling', 'fresh', 'green', 'held back', 'held in reserve', 'held out'],
    'untroubled': ['at peace', 'at rest', 'bloodless', 'calm', 'cloistered', 'concordant', 'cool', 'dwindling', 'ebbing', 'even-tenored', 'halcyon', 'hushed'],
    'untrue': ['aberrant', 'abroad', 'adrift', 'all abroad', 'all off', 'all wrong', 'amiss', 'askew', 'astray', 'at fault', 'awry', 'beside the mark'],
    'untrusting': ['pyrrhonic', 'agnostic', 'distrustful', 'doubtful', 'doubting', 'dubious', 'from missouri', 'in doubt', 'leery', 'mistrustful', 'mistrusting', 'questioning'],
    'untrustworthy': ['dangerous', 'desultory', 'doubtful', 'dubious', 'fly-by-night', 'hazardous', 'infirm', 'insecure', 'insubstantial', 'irresponsible', 'perilous', 'precarious'],
    'untruth': ['aberrancy', 'aberration', 'blague', 'canard', 'cock-and-bull story', 'defectiveness', 'delusion', 'deviancy', 'distortion', 'errancy', 'erroneousness', 'error'],
    'untruthful': ['artful', 'calculating', 'crafty', 'deceitful', 'deceptive', 'delusive', 'delusory', 'dishonest', 'disingenuous', 'equivocal', 'false', 'falsehearted'],
    'untutored': ['gothic', 'philistine', 'amateurish', 'artless', 'barbarous', 'benighted', 'bookless', 'deceived', 'disembarrass', 'disembroil', 'disencumber', 'disentangle'],
    'untwist': ['answer', 'bottom', 'clarify', 'clear up', 'crack', 'debug', 'decipher', 'decode', 'disembroil', 'disentangle', 'disintricate', 'disinvolve'],
    'unusable': ['functionless', 'impractical', 'in disrepair', 'inapplicable', 'inoperable', 'inoperative', 'nonfunctional', 'nonutilitarian', 'otiose', 'out of order', 'out of whack', 'unconducive'],
    'unused': ['a stranger to', 'abandoned', 'as a bonus', 'callow', 'derelict', 'dewy', 'disaccustomed', 'disused', 'ever-new', 'evergreen', 'extra', 'firsthand'],
    'unused to': ['a novice at', 'a stranger to', 'callow', 'disaccustomed', 'fresh', 'green', 'green as grass', 'ignorant', 'immature', 'inexperienced', 'new to', 'raw'],
    'unusual': ['almost unheard-of', 'atypical', 'bizarre', 'breakaway', 'curious', 'different', 'eccentric', 'exceptional', 'extraordinary', 'extremely', 'freakish', 'infrequent'],
    'unusually': ['abnormally', 'abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'conspicuously', 'copiously', 'eminently', 'emphatically', 'exceptionally'],
    'unutterable': ['arcane', 'awesome', 'awful', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'cryptic', 'dark', 'divine'],
    'unuttered': ['arcane', 'cabalistic', 'censored', 'classified', 'close', 'closed', 'concealed', 'cryptic', 'dark', 'echoless', 'enigmatic', 'esoteric'],
    'unvalued': ['despised', 'disliked', 'lowly', 'misprized', 'misunderstood', 'out of favor', 'thankless', 'unappreciated', 'uncared-for', 'underestimated', 'underrated', 'undervalued'],
    'unvarnished': ['spartan', 'arcadian', 'ascetic', 'austere', 'authentic', 'bald', 'bare', 'blank', 'bona fide', 'bucolic', 'candid', 'card-carrying'],
    'unvarying': ['abiding', 'accordant', 'alike', 'automatic', 'balanced', 'blah', 'broken-record', 'ceaseless', 'changeless', 'chattering', 'consistent', 'consonant'],
    'unveil': ['bare', 'betray', 'break the seal', 'bring to light', 'clear', 'denudate', 'denude', 'deobstruct', 'develop', 'disclose', 'discover', 'dismask'],
    'unveiling': ['apocalypse', 'baring', 'coming out', 'curtain raiser', 'debut', 'demonstration', 'disclosing', 'disclosure', 'discovering', 'discovery', 'display', 'embarkation'],
    'unventilated': ['airless', 'blank', 'blind', 'blind-alley', 'breathless', 'breezeless', 'cecal', 'choked', 'choked off', 'close', 'closed', 'constricted'],
    'unverified': ['apocryphal', 'groundless', 'inconclusive', 'indecisive', 'nonofficial', 'not following', 'not proved', 'unascertained', 'unattested', 'unauthentic', 'unauthenticated', 'unauthoritative'],
    'unversed': ['a novice at', 'a stranger to', 'awkward', 'blankminded', 'callow', 'dumb', 'empty', 'empty-headed', 'fresh', 'gauche', 'green', 'green as grass'],
    'unvirtuous': ['adamic', 'backsliding', 'besmirched', 'carnal', 'defiled', 'erring', 'fallen', 'fleshly', 'frail', 'impure', 'indecent', 'infirm'],
    'unvoiced': ['echoless', 'hush as death', 'hushed', 'inaudible', 'mousy', 'noiseless', 'quiescent', 'quiet', 'silent', 'soundless', 'still', 'still as death'],
    'unwarned': ['bare-handed', 'defenseless', 'guardless', 'helpless', 'inexpectant', 'nonexpectant', 'unadmonished', 'unadvised', 'unanticipating', 'unanticipative', 'unarmed', 'unarmored'],
    'unwarrantable': ['actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'black-market', 'bootleg', 'chargeable', 'contraband', 'contrary to law', 'criminal', 'felonious'],
    'unwarranted': ['actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'apocryphal', 'baseless', 'black-market', 'bootleg', 'bottomless', 'chargeable', 'contraband'],
    'unwary': ['artless', 'asleep', 'bluff', 'blunt', 'born yesterday', 'brash', 'brazen', 'brazenfaced', 'candid', 'careless', 'childlike', 'confiding'],
    'unwashed': ['base', 'baseborn', 'canaille', 'contaminated', 'corrupted', 'dirty', 'dregs', 'humble', 'impure', 'infected', 'low', 'lowborn'],
    'unwatched': ['abandoned', 'bare-handed', 'defenseless', 'deserted', 'disregarded', 'guardless', 'half-done', 'helpless', 'ignored', 'laid aside', 'left undone', 'missed'],
    'unwatchful': ['asleep', 'culpably negligent', 'derelict', 'goofing off', 'inadvertent', 'inattentive', 'incautious', 'laissez-faire', 'lax', 'loose', 'napping', 'neglectful'],
    'unwavering': ['abiding', 'arrogant', 'assiduous', 'assured', 'balanced', 'calm', 'cocksure', 'confident', 'constant', 'continuing', 'convinced', 'cool'],
    'unwearied': ['ardent', 'assiduous', 'constant', 'continuing', 'diligent', 'dogged', 'enduring', 'energetic', 'faithful', 'fervent', 'hard', 'hardworking'],
    'unweave': ['answer', 'bottom', 'clarify', 'clear up', 'crack', 'debug', 'decipher', 'decode', 'disembroil', 'disentangle', 'disintricate', 'disinvolve'],
    'unweeded': ['dense', 'exuberant', 'flourishing', 'gross', 'heavy', 'impenetrable', 'jungled', 'jungly', 'lush', 'luxuriant', 'overgrown', 'overrun'],
    'unwelcome': ['anathema', 'bitter', 'disagreeable', 'dislikable', 'displeasing', 'distasteful', 'exceptionable', 'excluded', 'ill-favored', 'inadmissible', 'obnoxious', 'persona non grata'],
    'unwell': ['ailing', 'bad', 'below par', 'critically ill', 'donsie', 'down', 'faint', 'faintish', 'feeble', 'feeling awful', 'feeling faint', 'feeling something terrible'],
    'unwholesome': ['bad', 'bad for', 'baneful', 'contaminated', 'deleterious', 'detrimental', 'diseased', 'disgusting', 'foul', 'harmful', 'hideous', 'horrible'],
    'unwieldy': ['latinate', 'all thumbs', 'awkward', 'blunderheaded', 'blundering', 'bombastic', 'boorish', 'bulky', 'bumbling', 'bungling', 'burdensome', 'butterfingered'],
    'unwilling': ['afraid', 'at odds', 'automatic', 'averse', 'backward', 'blind', 'compulsive', 'conditioned', 'cursory', 'deaf to', 'declinatory', 'differing'],
    'unwind': ['calm down', 'clarify', 'clear up', 'collect oneself', 'compose oneself', 'cool it', 'cool off', 'disembroil', 'disentangle', 'disintricate', 'disinvolve', 'ease'],
    'unwise': ['bad', 'brainless', 'childish', 'fatuous', 'foolish', 'futile', 'headless', 'ignorant', 'ill-advised', 'ill-considered', 'ill-contrived', 'ill-devised'],
    'unwitting': ['a stranger to', 'asleep', 'automatic', 'blind', 'blind to', 'caught napping', 'compulsive', 'conditioned', 'dead to', 'deaf to', 'forced', 'impercipient'],
    'unwonted': ['a stranger to', 'abnormal', 'atypical', 'breakaway', 'disaccustomed', 'extraordinary', 'ignorant', 'inexperienced', 'infrequent', 'irregular', 'new to', 'odd'],
    'unworkable': ['beyond one', 'functionless', 'impracticable', 'impractical', 'in disrepair', 'inapplicable', 'infeasible', 'inoperable', 'inoperative', 'insuperable', 'insurmountable', 'nonfunctional'],
    'unworldly': ['christlike', 'christly', 'elysian', 'god-fearing', 'olympian', 'airy', 'angelic', 'arcane', 'artless', 'asomatous', 'astral', 'beatific'],
    'unworthy': ['abominable', 'arrant', 'atrocious', 'bad', 'bad child', 'bad example', 'bad man', 'bad news', 'bad person', 'bad woman', 'base', 'beneath notice'],
    'unwrap': ['bare', 'break the seal', 'bring to light', 'cast off', 'clear', 'deobstruct', 'develop', 'disclose', 'discover', 'dismask', 'doff', 'douse'],
    'unwritten': ['acknowledged', 'admitted', 'articulated', 'conventional', 'customary', 'enunciated', 'established', 'fixed', 'folk', 'hallowed', 'handed down', 'heroic'],
    'unyielding': ['adamant', 'adamantine', 'at a standstill', 'bowelless', 'bulky', 'bullheaded', 'cast-iron', 'certain', 'closed to', 'complaining', 'constant', 'cruel'],
    'up': ['above', 'abovestairs', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'add to', 'addition', 'advance', 'against'],
    'up and down': ['alternately', 'aplomb', 'at right angles', 'back and forth', 'backward and forward', 'backwards and forwards', 'by turns', 'completely', 'every other', 'exhaustively', 'hitch and hike', 'in and out'],
    'up country': ['back', 'back country', 'back of beyond', 'back-country', 'backcountry', 'backwash', 'backwater', 'backwood', 'backwoods', 'backwoodsy', 'boondock', 'boondocks'],
    'up in arms': ['against the grain', 'against the tide', 'against the wind', 'all ready', 'all set', 'armed', 'armed and ready', 'at cross-purposes', 'at daggers', 'at daggers drawn', 'at feud', 'at issue'],
    'up on': ['abreast of', 'acquainted with', 'adept in', 'at home in', 'at home with', 'au courant', 'briefed', 'conversant with', 'educated', 'enlightened', 'expert at', 'familiar with'],
    'up to': ['byzantine', 'machiavellian', 'able', 'adequate', 'alert for', 'ample', 'au fait', 'barely sufficient', 'before', 'calculating', 'capable', 'collusive'],
    'up-and-down': ['alternate', 'back-and-forth', 'orthodiagonal', 'orthogonal', 'perpendicular', 'plumb', 'plunging', 'precipitous', 'reciprocal', 'reciprocative', 'right-angle', 'right-angled'],
    'up-and-up': ['aboveboard', 'authentic', 'bona fide', 'fair and square', 'foursquare', 'genuine', 'good-faith', 'on the level', 'on the square', 'on the up-and-up', 'open', 'open and aboveboard'],
    'up-to-the-minute': ['a la mode', 'actual', 'advanced', 'all the rage', 'all the thing', 'as is', 'avant-garde', 'being', 'contemporaneous', 'contemporary', 'current', 'existent'],
    'upbeat': ['great leap forward', 'leibnizian', 'advance', 'advancement', 'amelioration', 'amendment', 'arsis', 'ascent', 'bar beat', 'beat', 'bettering', 'betterment'],
    'upbraid': ['admonish', 'bawl out', 'berate', 'bring to book', 'call to account', 'castigate', 'censure', 'chastise', 'chew out', 'chide', 'correct', 'dress down'],
    'upbringing': ['apprenticeship', 'basic training', 'breaking', 'breeding', 'conditioning', 'cultivation', 'development', 'discipline', 'drill', 'drilling', 'education', 'exercise'],
    'upcast': ['elevated', 'erect', 'exalted', 'high', 'lifted', 'lofty', 'on stilts', 'raised', 'rampant', 'retrousse', 'stilted', 'sublime'],
    'upchuck': ['barf', 'be nauseated', 'be seasick', 'be sick', 'bring up', 'choke on', 'chuck up', 'disgorge', 'egest', 'feed the fish', 'feel disgust', 'gag'],
    'upcoming': ['about to be', 'advancing', 'already in sight', 'anabatic', 'approaching', 'approximate', 'approximative', 'ascendant', 'ascending', 'ascensional', 'ascensive', 'at hand'],
    'update': ['antedate', 'backdate', 'be dated', 'bear date', 'date', 'date at', 'date-stamp', 'dateline', 'datemark', 'make a date', 'modernize', 'postdate'],
    'updraft': ['air current', 'anabasis', 'ascension', 'ascent', 'clamber', 'climb', 'climbing', 'crosscurrent', 'current', 'current of air', 'downdraft', 'draft'],
    'upend': ['beat', 'cast up', 'clobber', 'drub', 'elevate', 'erect', 'honeycomb', 'lick', 'lift up', 'overset', 'overthrow', 'overturn'],
    'upgrade': ['abruptness', 'acclinate', 'acclivitous', 'acclivity', 'acculturate', 'advance', 'aggrandize', 'ameliorate', 'amend', 'anabasis', 'anabatic', 'ascendant'],
    'upheaval': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'alteration', 'amelioration', 'apoplexy', 'apostasy', 'apotheosis', 'ascent', 'assumption', 'beatification'],
    'upheave': ['arise', 'ascend', 'boost', 'bring to ruin', 'bristle', 'buoy up', 'cast up', 'cock up', 'come up', 'condemn', 'confound', 'consume'],
    'uphill': ['herculean', 'abruptness', 'abstruse', 'acclinate', 'acclivitous', 'acclivity', 'anabasis', 'anabatic', 'arduous', 'ascendant', 'ascending', 'ascension'],
    'uphold': ['ok', 'accept', 'admire', 'advocate', 'affirm', 'afford support', 'aid', 'allege in support', 'answer', 'approve', 'approve of', 'argue for'],
    'upholder': ['maecenas', 'abettor', 'admirer', 'advocate', 'aficionado', 'alpenstock', 'angel', 'apologist', 'approver', 'arm', 'athletic supporter', 'back'],
    'upholstery': ['blanketing', 'blocking', 'blotting out', 'cementwork', 'cloaking', 'clouding', 'coating', 'coverage', 'covering', 'curtaining', 'eclipse', 'eclipsing'],
    'upkeep': ['tlc', 'aid', 'backing', 'bread', 'care', 'carriage', 'carrying', 'conservancy', 'conservation', 'conservationism', 'daily bread', 'economic support'],
    'upland': ['arcadian', 'agrarian', 'agrestic', 'agricultural', 'agricultural region', 'alkali flat', 'alluvial plain', 'arable land', 'basin', 'black belt', 'bottomland', 'bucolic'],
    'uplift': ['great leap forward', 'abruptness', 'acclivity', 'acculturate', 'advance', 'advancement', 'aggrandize', 'ameliorate', 'amelioration', 'amend', 'amendment', 'anabasis'],
    'uplifted': ['olympian', 'aerial', 'airy', 'altitudinous', 'ascending', 'aspiring', 'colossal', 'dominating', 'elevated', 'eminent', 'erect', 'ethereal'],
    'uplifting': ['apotheosis', 'ascent', 'assumption', 'beatification', 'canonization', 'deification', 'elevating', 'elevation', 'elevatory', 'enshrinement', 'erectile', 'erecting'],
    'upmost': ['above', 'acmatic', 'acme', 'apex', 'apical', 'apogee', 'brow', 'cap', 'capital', 'chief', 'climax', 'cloud nine'],
    'upon': ['about', 'above', 'after which', 'against', 'anent', 'apropos of', 'as for', 'as regards', 'as respects', 'as to', 'atop', 'by'],
    'upper': ['benzedrine', 'benzedrine pill', 'dexamyl', 'dexamyl pill', 'dexedrine', 'dexedrine pill', 'methedrine', 'a cut above', 'above', 'advantage', 'ahead', 'amphetamine'],
    'upper case': ['abecedarian', 'allographic', 'alphabetic', 'ascender', 'back', 'bastard type', 'beard', 'belly', 'bevel', 'black letter', 'blackface', 'body'],
    'upper class': ['ffvs', 'ancienne noblesse', 'aristocracy', 'baronage', 'baronetage', 'barons', 'blue blood', 'chivalry', 'cream', 'elect', 'elite', 'establishment'],
    'upper crust': ['ffvs', 'vanity fair', 'ancienne noblesse', 'aristocracy', 'baronage', 'baronetage', 'barons', 'beau monde', 'beautiful people', 'best people', 'blue blood', 'cafe society'],
    'upper hand': ['advantage', 'ascendance', 'ascendancy', 'authority', 'balance of power', 'bulge', 'charisma', 'charm', 'clout', 'coign of vantage', 'consequence', 'control'],
    'upper house': ['austria', 'barbados', 'belgium', 'brazil', 'canada', 'chile', 'colombia', 'dominican republic', 'ecuador', 'ethiopia', 'fiji', 'france'],
    'uppermost': ['above', 'acmatic', 'all-absorbing', 'apical', 'best', 'capital', 'cardinal', 'chief', 'consummate', 'controlling', 'dominant', 'first'],
    'uppish': ['affected', 'brash', 'conceited', 'forward', 'high and mighty', 'highfalutin', 'hoity-toity', 'overweening', 'presuming', 'pushful', 'pushing', 'putting on airs'],
    'uppity': ['arrogant', 'audacious', 'big', 'brash', 'bumptious', 'cold', 'condescending', 'contumelious', 'cool', 'disdainful', 'domineering', 'familiar'],
    'upraise': ['bear up', 'boost', 'buck up', 'buoy', 'buoy up', 'cast up', 'cheer', 'console', 'elevate', 'erect', 'escalate', 'float'],
    'upraised': ['bolt upright', 'downright', 'elevated', 'erect', 'exalted', 'high', 'lifted', 'lofty', 'on stilts', 'raised', 'rampant', 'rearing'],
    'uprear': ['aggrandize', 'arise', 'ascend', 'aspire', 'boost', 'bristle', 'buoy up', 'cast up', 'cock up', 'construct', 'dignify', 'distinguish'],
    'upright': ['christian', 'klavier', 'samson post', 'steinway', 'angelic', 'arrowlike', 'at attention', 'azimuth circle', 'baby grand', 'baluster', 'balustrade', 'banister'],
    'uprise': ['olympian heights', 'abruptness', 'acclivity', 'acme', 'aerial heights', 'anabasis', 'apex', 'arise', 'ascend', 'ascension', 'ascent', 'bank'],
    'uprising': ['abruptness', 'acclinate', 'acclivitous', 'acclivity', 'anabasis', 'anabatic', 'ascendant', 'ascending', 'ascension', 'ascensional', 'ascensive', 'ascent'],
    'uproar': ['bedlam let loose', 'ado', 'affray', 'agitation', 'babel', 'bedlam', 'blast', 'bluster', 'bobbery', 'bother', 'brawl', 'broil'],
    'uproarious': ['anarchic', 'angry', 'blaring', 'blatant', 'blatting', 'blustering', 'blusterous', 'blustery', 'boisterous', 'brassy', 'brawling', 'brazen'],
    'uproot': ['abate', 'abolish', 'annihilate', 'avulse', 'banish', 'blot out', 'buck off', 'cut out', 'demolish', 'depose', 'deracinate', 'destroy'],
    'ups and downs': ['lissajous figure', 'alternation', 'back-and-forth', 'chain of circumstances', 'chain reaction', 'chapter of accidents', 'coming and going', 'concatenation of events', 'ebb and flow', 'feast and famine', 'flux and reflux', 'ins and outs'],
    'upset': ['abash', 'abashed', 'abroad', 'addle', 'addle the wits', 'adrift', 'afflict', 'afflicted', 'afraid', 'agitate', 'agitated', 'agitation'],
    'upsetting': ['agitating', 'annoying', 'baffling', 'bewildering', 'bothering', 'bothersome', 'breathtaking', 'chafing', 'charged', 'cliff-hanging', 'confounding', 'confusing'],
    'upshot': ['accomplishment', 'aftereffect', 'aftermath', 'answer', 'ascertainment', 'backwash', 'burden', 'by-product', 'clearing up', 'climax', 'completion', 'conclusion'],
    'upside down': ['a rebours', 'against the grain', 'anarchic', 'arsy-varsy', 'ass over elbows', 'ass-backwards', 'back-to-front', 'backwards', 'balled up', 'bollixed up', 'bottom side up', 'bottom up'],
    'upstage': ['dr', 'act', 'act as foil', 'appear', 'arrogant', 'backstage', 'barnstorm', 'before an audience', 'before the footlights', 'behind the scenes', 'big', 'cold-shoulder'],
    'upstairs': ['above', 'abovestairs', 'airward', 'aloft', 'aloof', 'heavenward', 'high', 'high up', 'in the air', 'in the clouds', 'on high', 'on stilts'],
    'upstanding': ['christian', 'blameless', 'bolt upright', 'clean', 'creditable', 'decent', 'downright', 'erect', 'estimable', 'ethical', 'fair', 'full of integrity'],
    'upstart': ['babbitt', 'philistine', 'young turk', 'adventurer', 'arriviste', 'bob up', 'boldface', 'boor', 'bounder', 'bourgeois', 'bourgeois gentilhomme', 'brazenface'],
    'upsurge': ['access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'aggrandizement', 'amplification', 'anabasis', 'appreciation'],
    'upsweep': ['anabasis', 'ascension', 'ascent', 'clamber', 'climb', 'climbing', 'cock up', 'elevation', 'escalade', 'fountain', 'gush', 'gyring up'],
    'upswing': ['great leap forward', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'advancement', 'aggrandizement', 'amelioration'],
    'uptight': ['accordant', 'anal', 'bourgeois', 'compulsive', 'concordant', 'conformist', 'conventional', 'corresponding', 'edgy', 'formalistic', 'harmonious', 'in accord'],
    'uptown': ['bowery', 'chinatown', 'east end', 'east side', 'little hungary', 'little italy', 'west end', 'west side', 'barrio', 'black ghetto', 'blighted area', 'burghal'],
    'uptrend': ['great leap forward', 'access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'advancement', 'aggrandizement', 'amelioration'],
    'upturn': ['access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'advance', 'aggrandizement', 'amplification', 'appreciation', 'ascent'],
    'upward': ['above', 'abovestairs', 'airward', 'aloft', 'aloof', 'anabatic', 'ascendant', 'ascending', 'ascensional', 'ascensive', 'axial', 'back'],
    'upwind': ['alee', 'alight', 'arise', 'ascend', 'aweather', 'come down', 'come in', 'come up', 'crash-land', 'curl upwards', 'descend', 'ditch'],
    'uranology': ['astrogeology', 'astrognosy', 'astrography', 'astrolithology', 'astronomy', 'astrophotography', 'astrophysics', 'celestial mechanics', 'gravitational astronomy', 'meteoritics', 'radar astronomy', 'radio astronomy'],
    'urban renewal': ['assembly-line housing', 'billeting', 'domiciliation', 'doss', 'face-lift', 'furbishment', 'hospitality', 'housing', 'housing bill', 'housing development', 'housing problem', 'living quarters'],
    'urbane': ['accommodating', 'affable', 'agreeable', 'amiable', 'appropriate', 'attentive', 'balanced', 'becoming', 'bland', 'civil', 'civilized', 'clubbable'],
    'urbanite': ['big-city man', 'bourgeois', 'burgess', 'burgher', 'city dweller', 'city man', 'city slicker', 'exurbanite', 'oppidan', 'suburbanite', 'townee', 'towner'],
    'urchin': ['arab', 'jd', 'beach bum', 'beachcomber', 'beggar', 'bo', 'brat', 'bum', 'bummer', 'cub', 'dickens', 'dogie'],
    'urge': ['accelerate', 'admonish', 'advise', 'advocate', 'affirm', 'allege', 'appetite', 'appetition', 'apply pressure', 'ardor', 'argue', 'ask'],
    'urgency': ['antecedence', 'antecedency', 'anteposition', 'anteriority', 'blandishment', 'buttonholing', 'cajolement', 'cajolery', 'case of need', 'clutch', 'coaxing', 'compulsion'],
    'urgent': ['active', 'actuating', 'acute', 'animating', 'ardent', 'begging', 'burning', 'cajoling', 'causal', 'causative', 'choiceless', 'clamant'],
    'urinal': ['wc', 'backhouse', 'basement', 'bathroom', 'bedpan', 'can', 'chamber', 'chamber pot', 'chemical closet', 'chemical toilet', 'closet', 'comfort station'],
    'urinalysis': ['pap test', 'anatomic diagnosis', 'biological diagnosis', 'biopsy', 'clinical diagnosis', 'cytodiagnosis', 'diagnosis', 'differential diagnosis', 'digital examination', 'electrocardiography', 'electroencephalography', 'electromyography'],
    'urine': ['chyle', 'colostrum', 'discharge', 'gleet', 'humor', 'ichor', 'lachryma', 'lactation', 'leukorrhea', 'lymph', 'matter', 'micturition'],
    'urn': ['adobe', 'biscuit', 'bisque', 'bone pot', 'bowl', 'brick', 'cement', 'ceramic ware', 'ceramics', 'china', 'cinerary urn', 'crock'],
    'urtext': ['antetype', 'antitype', 'archetype', 'biotype', 'classic example', 'criterion', 'epitome', 'fugleman', 'fugler', 'genotype', 'imitatee', 'lead'],
    'usage': ['acceptance', 'acceptation', 'acception', 'active use', 'adjectival phrase', 'antonym', 'appliance', 'application', 'articulation', 'automatism', 'bad habit', 'bon ton'],
    'use': ['ablation', 'absolute interest', 'abuse', 'account', 'act toward', 'adaptability', 'advantage', 'appliance', 'applicability', 'application', 'apply', 'appropriateness'],
    'use up': ['ablate', 'absorb', 'assimilate', 'beat', 'bestow', 'bleed white', 'burn out', 'burn up', 'consecrate to', 'consume', 'debilitate', 'dedicate to'],
    'used': ['ablated', 'acquainted with', 'adapted to', 'applied', 'by the board', 'cast-off', 'consumed', 'depleted', 'dissipated', 'down the drain', 'employed', 'eroded'],
    'used to': ['acclimated', 'acclimatized', 'accommodated', 'accustomed', 'adapted', 'addicted', 'addicted to', 'adjusted', 'at home in', 'at home with', 'case-hardened', 'conditioned'],
    'used up': ['ablated', 'all in', 'ausgespielt', 'beat', 'beat up', 'beaten', 'bleary', 'bone-weary', 'burned-out', 'burnt up', 'bushed', 'by the board'],
    'useful': ['advantageous', 'advisable', 'agential', 'agentival', 'agentive', 'aidful', 'appropriate', 'assisting', 'auspicious', 'banausic', 'becoming', 'befitting'],
    'usefulness': ['account', 'advantage', 'advantageousness', 'advisability', 'agreeableness', 'applicability', 'appropriateness', 'auspiciousness', 'availability', 'beneficialness', 'benefit', 'benevolence'],
    'useless': ['abortive', 'aimless', 'barren', 'bootless', 'counterproductive', 'deleterious', 'detrimental', 'disadvantageous', 'disserviceable', 'effete', 'empty', 'etiolated'],
    'uselessness': ['bankruptcy', 'bootlessness', 'counterproductiveness', 'counterproductivity', 'defeat', 'failure', 'fatuity', 'futility', 'ill success', 'impoliticalness', 'impoliticness', 'inadvisability'],
    'user': ['lsd user', 'acidhead', 'addict', 'alcoholic', 'buyer', 'chain smoker', 'cocaine sniffer', 'cokie', 'consumer', 'cubehead', 'dipsomaniac', 'dope fiend'],
    'usher': ['ganymede', 'hebe', 'mc', 'airline hostess', 'airline stewardess', 'attend', 'attendant', 'auteur', 'ballyhoo man', 'barker', 'batman', 'bellboy'],
    'usher in': ['announce', 'antecede', 'antedate', 'anticipate', 'be before', 'be early', 'blaze the trail', 'break the trail', 'bring up', 'broach', 'christen', 'come before'],
    'usual': ['accepted', 'accustomed', 'arranged', 'average', 'banal', 'besetting', 'bourgeois', 'businesslike', 'central', 'characteristic', 'chronic', 'common'],
    'usually': ['accustomedly', 'again and again', 'all in all', 'all things considered', 'altogether', 'as a rule', 'as a whole', 'as an approximation', 'as is usual', 'as per usual', 'as things go', 'as usual'],
    'usurious': ['cutthroat', 'exacting', 'excessive', 'exorbitant', 'extortionate', 'extravagant', 'fancy', 'gouging', 'grossly overpriced', 'immoderate', 'inflationary', 'inordinate'],
    'usurp': ['accroach', 'adopt', 'advance upon', 'appropriate', 'arrogate', 'assume', 'assume command', 'break bounds', 'colonize', 'commandeer', 'conquer', 'cut out'],
    'usurpation': ['accession', 'adoption', 'anointing', 'anointment', 'appointment', 'appropriation', 'arrogation', 'assignment', 'assumption', 'authorization', 'colonization', 'conquest'],
    'usurper': ['simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'autocrat', 'caesar', 'commissar', 'czar', 'despot', 'dictator'],
    'usury': ['cosa nostra', 'mafia', 'advance', 'advancement', 'advancing', 'bank rate', 'black market', 'bootlegging', 'compensatory interest', 'compound interest', 'discount rate', 'exorbitant interest'],
    'utensil': ['accouterments', 'apparatus', 'appliances', 'appointments', 'appurtenances', 'armament', 'container', 'contraption', 'contrivance', 'conveniences', 'device', 'duffel'],
    'uterine': ['affiliated', 'agnate', 'akin', 'allied', 'avuncular', 'cervical', 'clitoral', 'closely related', 'cognate', 'collateral', 'congeneric', 'consanguine'],
    'uterus': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'utilitarian': ['cyrenaic', 'eleatic', 'epicurean', 'megarian', 'stoic', 'advantageous', 'animist', 'animistic', 'appropriate', 'atomistic', 'banausic', 'beneficial'],
    'utility': ['aktiengesellschaft', 'account', 'advantage', 'advantageousness', 'aktiebolag', 'alternate', 'alternative', 'appliance', 'applicability', 'appropriateness', 'availability', 'backup'],
    'utilization': ['use', 'exercise', 'employment', 'usage', 'utilisation'],
    'utilize': ['apply', 'bestow', 'do with', 'employ', 'exercise', 'exert', 'exploit', 'handle', 'make use of', 'manage', 'manipulate', 'operate'],
    'utmost': ['acme', 'all', 'apex', 'apogee', 'at the height', 'at the limit', 'best', 'brow', 'cap', 'ceiling', 'climax', 'cloud nine'],
    'utopia': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley'],
    'utopian': ['arcadian', 'don quixote', 'edenic', 'fabian', 'leibnizian', 'leibnizian optimist', 'pollyanna', 'quixote', 'aspirant', 'aspirer', 'bright', 'celestial'],
    'utter': ['absolute', 'admitting no exception', 'air', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'arrant', 'articulate', 'bestrew', 'born', 'break it to'],
    'utterance': ['parthian shot', 'address', 'adjectival phrase', 'affirmance', 'affirmation', 'allegation', 'announcement', 'annunciation', 'answer', 'antonym', 'apostrophe', 'articulation'],
    'uttered': ['articulated', 'enunciated', 'lingual', 'linguistic', 'nuncupative', 'oral', 'parol', 'pronounced', 'said', 'sounded', 'speech', 'spoken'],
    'utterly': ['a outrance', 'a toute outrance', 'absolutely', 'all hollow', 'all out', 'all the way', 'altogether', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure', 'categorically'],
    'v shaped': ['y-shaped', 'akimbo', 'angular', 'arboreal', 'arborescent', 'arboriform', 'bent', 'biforked', 'bifurcate', 'bifurcated', 'branched', 'branching'],
    'vacancy': ['absence', 'absence of mind', 'appointment', 'bareness', 'barrenness', 'berth', 'billet', 'blank', 'blank mind', 'blankmindedness', 'blankness', 'bleakness'],
    'vacant': ['abandoned', 'absent-minded', 'available', 'bare', 'barren', 'bland', 'blank', 'blankminded', 'bleached', 'calm', 'characterless', 'clear'],
    'vacate': ['abandon', 'abdicate', 'abjure', 'abolish', 'abrogate', 'abscond', 'annul', 'back out', 'be pensioned', 'be superannuated', 'beat a retreat', 'beg off'],
    'vacation': ['awol', 'christmas', 'french leave', 'sunday', 'abeyance', 'abolishment', 'abolition', 'abrogation', 'abscondence', 'absence', 'absence without leave', 'absentation'],
    'vaccine': ['antitoxin', 'autogenous vaccine', 'bang', 'booster', 'booster shot', 'bovine vaccine', 'fix', 'hit', 'humanized vaccine', 'hypodermic', 'hypodermic injection', 'injection'],
    'vacillate': ['alternate', 'back and fill', 'bob', 'bobble', 'careen', 'change', 'changeable', 'chop and change', 'coggle', 'dally', 'dallying', 'dangle'],
    'vacillating': ['adrift', 'afloat', 'alternating', 'amorphous', 'capricious', 'changeable', 'changeful', 'coquettish', 'desultory', 'deviable', 'dizzy', 'eccentric'],
    'vacillation': ['alternation', 'capriciousness', 'chance', 'chanciness', 'changeableness', 'dallying', 'demurral', 'dillydallying', 'equivocation', 'erraticism', 'erraticness', 'fickleness'],
    'vacuity': ['bare', 'bareness', 'barrenness', 'blank', 'blankness', 'bleakness', 'cavity', 'clear', 'desolateness', 'dull', 'dullness', 'emptiness'],
    'vacuole': ['golgi apparatus', 'aster', 'basal body', 'cell membrane', 'central apparatus', 'central body', 'centriole', 'centroplasm', 'centrosome', 'centrosphere', 'chloroplast', 'chromoplast'],
    'vacuous': ['airy', 'asinine', 'awkward', 'bare', 'barren', 'bland', 'blank', 'blankminded', 'bleached', 'callow', 'calm', 'catchpenny'],
    'vacuum': ['absence', 'absence of mind', 'blank', 'blankness', 'broom', 'brush', 'brush off', 'clean slate', 'deprivation', 'emptiness', 'empty space', 'empty-headedness'],
    'vagabond': ['arab', 'bowery bum', 'arab', 'bat around', 'beach bum', 'beachcomber', 'beggar', 'beggarly fellow', 'bird of passage', 'blighter', 'bo', 'budmash'],
    'vagary': ['aberration', 'bee', 'boutade', 'brainstorm', 'capriccio', 'caprice', 'circuitousness', 'conceit', 'crank', 'craze', 'crazy idea', 'crosswiseness'],
    'vagina': ['eustachian tube', 'fallopian tube', 'bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'canal', 'cervix', 'clitoris', 'cod'],
    'vaginal': ['cervical', 'clitoral', 'genital', 'integumental', 'integumentary', 'ovarian', 'penial', 'penile', 'phallic', 'scrotal', 'seminal', 'spermatic'],
    'vagrancy': ['wanderjahr', 'afoot and lighthearted', 'bumming', 'dilatoriness', 'discursion', 'divagation', 'do-nothingness', 'drifting', 'ergophobia', 'errantry', 'faineancy', 'faineantise'],
    'vagrant': ['arab', 'bowery bum', 'aberrant', 'aberrative', 'adrift', 'afloat', 'aimless', 'alternating', 'amorphous', 'arbitrary', 'beach bum', 'beachcomber'],
    'vague': ['abstract', 'aimless', 'airy', 'aleatoric', 'aleatory', 'ambiguous', 'amorphic', 'amorphous', 'amphibological', 'anarchic', 'attenuate', 'attenuated'],
    'vaguely': ['absently', 'aimlessly', 'ambiguously', 'anarchically', 'broadly', 'chaotically', 'confusedly', 'confusingly', 'detachedly', 'dimly', 'dispersedly', 'distantly'],
    'vagueness': ['airiness', 'airy texture', 'amorphia', 'amorphism', 'amorphousness', 'anarchy', 'attenuation', 'bleariness', 'blobbiness', 'blur', 'blurriness', 'bodilessness'],
    'vain': ['gascon', 'abortive', 'absurd', 'airy', 'arrogant', 'asinine', 'barren', 'baseless', 'boastful', 'boasting', 'bootless', 'bootlessly'],
    'vainglorious': ['gascon', 'boastful', 'boasting', 'braggart', 'bragging', 'complacent', 'conceited', 'consequential', 'disdainful', 'fanfaron', 'fanfaronading', 'gasconading'],
    'vainglory': ['amour-propre', 'arrogance', 'autoeroticism', 'boastfulness', 'bombast', 'complacency', 'consequentiality', 'ego trip', 'egoism', 'egotism', 'exhibition', 'flaunting'],
    'valance': ['beading', 'binding', 'bordering', 'bordure', 'edging', 'fimbria', 'fimbriation', 'flounce', 'frill', 'frilling', 'fringe', 'furbelow'],
    'vale': ['earth', 'gaea', 'ge', 'tellus', 'terra', 'biosphere', 'bottom', 'bottom glade', 'bottoms', 'combe', 'dale', 'dell'],
    'valedictory': ['godspeed', 'address', 'adieu', 'after-dinner speech', 'allocution', 'aloha', 'chalk talk', 'conge', 'debate', 'declamation', 'departing', 'diatribe'],
    'valet': ['administer to', 'attend', 'attend on', 'boy', 'butler', 'care for', 'chauffeur', 'chore', 'coachman', 'dance attendance upon', 'do for', 'do service to'],
    'valetudinarian': ['alcoholic', 'alternating personality', 'antisocial personality', 'apoplectic', 'arthritic', 'cachectic', 'case', 'consumptive', 'debilitated', 'disordered personality', 'disturbed personality', 'double personality'],
    'valiant': ['achilles', 'david', 'hector', 'roland', 'samson', 'a man', 'audacious', 'bold', 'bold-spirited', 'brave', 'bulldog', 'chivalric'],
    'valid': ['absolute', 'acceptable', 'actionable', 'adducible', 'admissible', 'advantageous', 'applicable', 'armipotent', 'attestative', 'attested', 'attestive', 'auspicious'],
    'validate': ['ok', 'accept', 'accredit', 'affirm', 'amen', 'approve', 'assay', 'attest', 'audit', 'authenticate', 'authorize', 'autograph'],
    'validated': ['accepted', 'acknowledged', 'actual', 'admitted', 'affirmed', 'allowed', 'approved', 'ascertained', 'attested', 'authenticated', 'avowed', 'borne out'],
    'validity': ['actionability', 'admissibility', 'admissibleness', 'advantageousness', 'agreeableness', 'allowableness', 'amperage', 'applicability', 'armipotence', 'auspiciousness', 'authenticity', 'authoritativeness'],
    'valley': ['abysm', 'abyss', 'arroyo', 'bottom', 'bottom glade', 'bottoms', 'box canyon', 'breach', 'break', 'canyon', 'cavity', 'chap'],
    'valor': ['dutch courage', 'boldness', 'braveness', 'bravery', 'chivalrousness', 'chivalry', 'conspicuous gallantry', 'courage', 'courageousness', 'doughtiness', 'gallantness', 'gallantry'],
    'valorous': ['audacious', 'bold', 'bold-spirited', 'brave', 'chivalric', 'chivalrous', 'courageous', 'dauntless', 'doughty', 'fearless', 'gallant', 'greathearted'],
    'valuable': ['admired', 'appreciated', 'beyond price', 'costly', 'dear', 'esteemed', 'expensive', 'gainful', 'golden', 'good as gold', 'inestimable', 'invaluable'],
    'valuate': ['appraise', 'appreciate', 'assay', 'assess', 'calculate', 'calibrate', 'caliper', 'call', 'check a parameter', 'class', 'compute', 'dial'],
    'value': ['munsell chroma', 'accent', 'accord respect to', 'account', 'admire', 'adore', 'advantage', 'advantageousness', 'affective meaning', 'agreeableness', 'apotheosize', 'appraisal'],
    'valued': ['ad valorem', 'admeasured', 'admired', 'adored', 'appraised', 'appreciated', 'assessed', 'esteemed', 'evaluated', 'gauged', 'good for', 'held in respect'],
    'valueless': ['ng', 'beggarly', 'beneath contempt', 'cheap', 'cheesy', 'common', 'contemptible', 'crummy', 'despicable', 'gaudy', 'gimcracky', 'good-for-naught'],
    'valve': ['aerophone', 'ball cock', 'ball valve', 'bell', 'bung', 'bunghole', 'check valve', 'cock', 'cork', 'discharge tube', 'double reed', 'drain cock'],
    'vamoose': ['be off', 'beat it', 'begone', 'blow', 'clear out', 'decamp', 'dog it', 'duck and run', 'duck out', 'flake off', 'get', 'get going'],
    'vamp': ['aspasia', 'circe', 'delilah', 'don juan', 'jezebel', 'lorelei', 'messalina', 'parthenope', 'phryne', 'siren', 'thais', 'vorspiel'],
    'vampire': ['aspasia', 'baba yaga', 'circe', 'delilah', 'don juan', 'dracula', 'euryale', 'frankenstein', 'gorgon', 'jezebel', 'lilith', 'lorelei'],
    'van': ['conestoga wagon', 'pullman', 'pullman car', 'advance guard', 'airhead', 'anteposition', 'armed guard', 'avant-garde', 'baggage car', 'bank guard', 'battle line', 'beachhead'],
    'vandal': ['animal', 'annihilator', 'anthropophagite', 'arsonist', 'barbarian', 'beast', 'biblioclast', 'bomber', 'brute', 'burner', 'cannibal', 'demolisher'],
    'vandalism': ['acuteness', 'animality', 'atrociousness', 'atrocity', 'badness', 'barbarity', 'barbarousness', 'beastliness', 'bestiality', 'bloodbath', 'bloodiness', 'bloodlust'],
    'vandalize': ['assault', 'attack', 'barbarize', 'batter', 'bring to ruin', 'brutalize', 'burn', 'butcher', 'carry on', 'condemn', 'confound', 'consume'],
    'vanguard': ['advance guard', 'airhead', 'ancestor', 'announcer', 'antecedent', 'armed guard', 'avant-garde', 'bank guard', 'battle line', 'beachhead', 'bellwether', 'bridgehead'],
    'vanish': ['abandon', 'abscond', 'be annihilated', 'be consumed', 'be destroyed', 'be done for', 'be gone', 'be no more', 'be wiped out', 'beat a retreat', 'bow out', 'cease'],
    'vanished': ['absconded', 'absent', 'ago', 'all gone', 'annihilated', 'antiquated', 'antique', 'away', 'blown over', 'by', 'bygone', 'bypast'],
    'vanishing': ['blackout', 'blocking', 'dematerialization', 'departure', 'disappearance', 'disappearing', 'dispersion', 'dissipation', 'dissolution', 'dissolving', 'eclipse', 'elimination'],
    'vanity': ['absurdity', 'aimlessness', 'amour propre', 'arrogance', 'autotheism', 'big deal', 'bluster', 'boast', 'boastfulness', 'boasting', 'bombast', 'bootlessness'],
    'vanity case': ['base', 'clown white', 'cold cream', 'compact', 'cosmetics', 'drugstore complexion', 'eye shadow', 'eyebrow pencil', 'foundation', 'foundation cream', 'greasepaint', 'hand cream'],
    'vanquish': ['bear down', 'beat down', 'bend', 'break', 'conquer', 'crush', 'defeat', 'fell', 'flatten', 'humble', 'master', 'overpower'],
    'vanquisher': ['champ', 'champion', 'conquering hero', 'conqueror', 'conquistador', 'defeater', 'easy winner', 'hero', 'master', 'pancratiast', 'runner-up', 'shoo-in'],
    'vantage': ['advantage', 'allowance', 'ambit', 'angle', 'angle of vision', 'bailiwick', 'bulge', 'coign of vantage', 'constituency', 'deadwood', 'draw', 'drop'],
    'vapid': ['airy', 'arid', 'asinine', 'barren', 'betwixt and between', 'blah', 'bland', 'blank', 'bloodless', 'boring', 'catchpenny', 'changeable'],
    'vapor': ['barnumize', 'london fog', 'london special', 'old faithful', 'air', 'airy nothing', 'apparition', 'autism', 'babble', 'blabber', 'blather', 'blow'],
    'vapor trail': ['backwash', 'condensation trail', 'contrail', 'course', 'exhaust', 'line', 'path', 'piste', 'scent', 'signs', 'spoor', 'stream'],
    'vaporize': ['aerate', 'aerify', 'atomize', 'blow to pieces', 'blow up', 'brain', 'bring down', 'bring to ruin', 'burn to death', 'carbonate', 'chlorinate', 'condemn'],
    'vaporous': ['adulterated', 'aerial', 'aerodynamic', 'aerostatic', 'aery', 'air-built', 'airy', 'attenuate', 'attenuated', 'chimeric', 'chimerical', 'cloud-born'],
    'vaquero': ['broncobuster', 'buckaroo', 'caballero', 'cattleman', 'cavalier', 'cavalryman', 'chevalier', 'circus rider', 'cowboy', 'cowgirl', 'cowhand', 'cowherd'],
    'variability': ['arrhythmia', 'brokenness', 'capriciousness', 'changeability', 'changeableness', 'choppiness', 'dappleness', 'desultoriness', 'deviability', 'deviation', 'difference', 'differentiation'],
    'variable': ['able to adapt', 'adaptable', 'adjustable', 'adrift', 'afloat', 'agnostic', 'alterable', 'alterative', 'alternating', 'ambiguous', 'amorphous', 'broken'],
    'variably': ['at irregular intervals', 'at random', 'back and forth', 'brokenly', 'by catches', 'by fits', 'by jerks', 'by snatches', 'capriciously', 'changeably', 'desultorily', 'disconnectedly'],
    'variance': ['agreement to disagree', 'alienation', 'antagonism', 'apostasy', 'argument', 'argumentation', 'at variance', 'change', 'clashing', 'conflict', 'contention', 'contradiction'],
    'variant': ['altering', 'alternative', 'antagonistic', 'antipathetic', 'assorted', 'at cross-purposes', 'at loggerheads', 'at odds', 'at variance', 'at war', 'changing', 'clashing'],
    'variation': ['nachtmusik', 'proteus', 'aberrancy', 'aberration', 'about-face', 'absolute music', 'accommodation', 'adaptation', 'adjustment', 'air varie', 'aleatory', 'aleatory music'],
    'varied': ['amalgamated', 'ambiguous', 'ambivalent', 'amphibious', 'assorted', 'at odds', 'at variance', 'blended', 'combined', 'complex', 'composite', 'compound'],
    'variegate': ['band', 'bar', 'bespangle', 'bespeckle', 'bespot', 'blotch', 'break up', 'check', 'checker', 'dapple', 'differ', 'differentiate'],
    'variegated': ['assorted', 'at odds', 'at variance', 'bicolor', 'bicolored', 'brindled', 'calico', 'capricious', 'changeable', 'changing', 'checked', 'checkered'],
    'variegation': ['dalmatian', 'proteus', 'allotropism', 'allotropy', 'antigorite', 'butterfly', 'candy cane', 'capriciousness', 'chameleon', 'changeability', 'changeableness', 'cheetah'],
    'variety': ['broadway', 'proteus', 'a certain number', 'a few', 'about-face', 'accommodation', 'adaptation', 'adjustment', 'affiliation', 'allotropism', 'allotropy', 'alteration'],
    'variety store': ['boutique', 'chain store', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dime store', 'discount house', 'discount store', 'emporium'],
    'variform': ['capricious', 'changeable', 'changing', 'choppy', 'deviating', 'deviative', 'deviatory', 'different', 'disorderly', 'divaricate', 'divergent', 'diversified'],
    'various': ['assorted', 'at odds', 'at variance', 'capricious', 'certain', 'changeable', 'changing', 'choppy', 'composite', 'contrary', 'contrasted', 'contrasting'],
    'varmint': ['amphibian', 'animal', 'aquatic', 'beast', 'biped', 'brute', 'canine', 'cannibal', 'carnivore', 'cosmopolite', 'creature', 'creeping thing'],
    'varnish': ['acting', 'adorn', 'affectation', 'air brush', 'alibi', 'allow for', 'allowance', 'apology', 'appearance', 'apply paint', 'art paper', 'attitudinizing'],
    'varsity': ['academe', 'academia', 'alma mater', 'cast', 'college', 'college of engineering', 'community college', 'company', 'complement', 'crew', 'degree-granting institution', 'eight'],
    'vary': ['accommodate', 'adapt', 'adjust', 'agree to disagree', 'alter', 'alternate', 'ameliorate', 'analyze', 'anatomize', 'atomize', 'back and fill', 'be at cross-purposes'],
    'varying': ['assorted', 'at odds', 'at variance', 'capricious', 'changeable', 'changing', 'choppy', 'contrary', 'contrasted', 'contrasting', 'departing', 'deviating'],
    'vase': ['adobe', 'biscuit', 'bisque', 'bowl', 'brick', 'cement', 'ceramic ware', 'ceramics', 'china', 'crock', 'crockery', 'enamelware'],
    'vasectomy': ['adenoidectomy', 'appendectomy', 'arteriectomy', 'castration', 'cholecystectomy', 'craniectomy', 'cricoidectomy', 'cystectomy', 'enterectomy', 'gastrectomy', 'hemorrhoidectomy', 'hysterectomy'],
    'vassal': ['bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'captive', 'chattel', 'chattel slave', 'churl', 'client', 'concubine', 'creature'],
    'vassalage': ['absolutism', 'bond service', 'bondage', 'captivity', 'control', 'debt slavery', 'deprivation of freedom', 'disenfranchisement', 'disfranchisement', 'domination', 'enslavement', 'enthrallment'],
    'vast': ['atlantean', 'brobdingnagian', 'cyclopean', 'gargantuan', 'herculean', 'homeric', 'abysmal', 'ample', 'amplitudinous', 'astronomic', 'astronomical', 'awesome'],
    'vastly': ['abroad', 'almost entirely', 'broadly', 'colossally', 'considerably', 'enormously', 'exceedingly', 'extensively', 'extremely', 'far and near', 'far and wide', 'gigantically'],
    'vastness': ['ampleness', 'amplitude', 'boundlessness', 'bulk', 'enormity', 'enormousness', 'expanse', 'formidableness', 'fullness', 'gigantism', 'grandeur', 'grandness'],
    'vat': ['archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box', 'bunker'],
    'vaudeville': ['broadway', 'grand guignol', 'passion play', 'tom show', 'antimasque', 'audience success', 'ballet', 'bomb', 'broadcast drama', 'burlesque', 'burlesque show', 'carnival'],
    'vaudevillian': ['actor-proof', 'all-star', 'artist', 'artiste', 'ballet', 'balletic', 'belly dancer', 'burlesque queen', 'chorine', 'chorus boy', 'chorus girl', 'cinematic'],
    'vault': ['caelus', 'fort knox', 'highland fling', 'air', 'anabasis', 'and jump', 'apse', 'arcade', 'arcature', 'arch', 'arched roof', 'archives'],
    'vaulted': ['arched', 'arciform', 'arclike', 'arcual', 'bandy', 'bowed', 'bowlike', 'concave', 'convex', 'embowed', 'gibbose', 'gibbous'],
    'vaulter': ['broad jumper', 'bucking bronco', 'buckjumper', 'flea', 'frog', 'gazelle', 'goat', 'grasshopper', 'high jumper', 'hopper', 'hurdle racer', 'hurdler'],
    'vaulting': ['aduncity', 'apse', 'aquilinity', 'arcade', 'arcature', 'arch', 'arched roof', 'arching', 'archway', 'arcuation', 'aspiring', 'bouncing'],
    'vaunt': ['advertise', 'air', 'blazon', 'blazon forth', 'blow', 'bluster', 'boast', 'boastfulness', 'boasting', 'bombast', 'brag', 'braggadocio'],
    'vayu': ['agni', 'asvins', 'avalokita', 'bhairava', 'bhairavi', 'brahma', 'chandi', 'daksha', 'devaki', 'devi', 'dharma', 'dharti mai'],
    'vd': ['french disease', 'spanish pox', 'acquired syphilis', 'balanitis gangrenosa', 'cerebral tabes', 'chancre', 'chancroid', 'clap', 'claps', 'climatic bubo', 'congenital syphilis', 'constitutional syphilis'],
    'vector': ['aerial infection', 'air line', 'airborne infection', 'axis', 'azimuth', 'beeline', 'biological vector', 'carrier', 'chord', 'communicability', 'compass bearing', 'compass direction'],
    'veer': ['aberrancy', 'aberration', 'about ship', 'alter', 'ameliorate', 'angle', 'angle off', 'apex', 'avert', 'back and fill', 'be changed', 'be converted into'],
    'veering': ['aberrant', 'aberrative', 'broken', 'capricious', 'careening', 'catchy', 'choppy', 'circuitous', 'departing', 'desultory', 'deviant', 'deviating'],
    'vegetable': ['boston lettuce', 'chinese cabbage', 'french bean', 'irish potato', 'kraut', 'swiss chard', 'amphibian', 'angiosperm', 'annual', 'apathetic', 'aquatic plant', 'asparagus'],
    'vegetable kingdom': ['animal kingdom', 'botany', 'chain of being', 'class structure', 'domain', 'establishment', 'flora', 'flowerage', 'greenery', 'greens', 'herbage', 'hierarchy'],
    'vegetable oil': ['macassar oil', 'absinthe', 'animal oil', 'avocado oil', 'bay oil', 'beechnut oil', 'camphor', 'candlenut oil', 'carapa oil', 'castor oil', 'cedarwood oil', 'cerate'],
    'vegetarian': ['apostolic', 'apostolici', 'brillat-savarin', 'encratic', 'encratite', 'lenten', 'lucullus', 'pythagorean', 'pythagorist', 'rechabite', 'shaker', 'spartan'],
    'vegetarianism': ['encratism', 'friday', 'lenten fare', 'pythagoreanism', 'pythagorism', 'rechabitism', 'shakerism', 'spartan fare', 'stoicism', 'abstainment', 'abstemiousness', 'abstention'],
    'vegetate': ['be a sideliner', 'be still', 'blossom', 'brew', 'bud', 'burgeon', 'burst forth', 'coast', 'delay', 'develop', 'do nothing', 'drift'],
    'vegetation': ['a wise passiveness', 'abeyance', 'apathy', 'botany', 'budding', 'burgeoning', 'catalepsy', 'catatonia', 'contemplation', 'contemplative life', 'deadliness', 'deathliness'],
    'vehemence': ['alecto', 'megaera', 'nemesis', 'tisiphone', 'abandon', 'acerbity', 'acidity', 'acridity', 'acrimony', 'acuteness', 'amperage', 'animality'],
    'vehement': ['abandoned', 'acid', 'acidulous', 'acrid', 'acrimonious', 'acute', 'afire', 'ardent', 'assiduous', 'astringent', 'biting', 'bitter'],
    'vehicle': ['charlie mccarthy', 'grand guignol', 'passion play', 'tom show', 'agency', 'agent', 'ancilla', 'antimasque', 'appliance', 'audience success', 'backing', 'ballet'],
    'veil': ['alibi', 'apology', 'apply to', 'awning', 'bamboo curtain', 'barrier of secrecy', 'beach umbrella', 'becloud', 'befog', 'blackout', 'blanket', 'blind'],
    'veiled': ['aleatoric', 'aleatory', 'amorphous', 'armored', 'between the lines', 'blobby', 'blurred', 'blurry', 'broad', 'cased', 'ceiled', 'chance'],
    'vein': ['affectation', 'aorta', 'arteriole', 'artery', 'attitude', 'band', 'bar', 'bed', 'bespangle', 'bespeckle', 'bespot', 'blood vessel'],
    'veld': ['agricultural region', 'alkali flat', 'alluvial plain', 'arable land', 'basin', 'black belt', 'bottomland', 'bushveld', 'campo', 'champaign', 'champaign country', 'citrus belt'],
    'velocity': ['activity', 'actuation', 'alacrity', 'amble', 'bat', 'briskness', 'celerity', 'dispatch', 'drag', 'droop', 'dynamics', 'expedition'],
    'velvet': ['easy street', 'affluence', 'alabaster', 'bed of roses', 'billiard table', 'blubber', 'bowling alley', 'bowling green', 'breeze', 'butter', 'cinch', 'clay'],
    'velvety': ['attenuate', 'attenuated', 'buffed', 'burnished', 'cottony', 'dainty', 'delicate', 'downy', 'feathery', 'filmy', 'fine', 'fine-drawn'],
    'venal': ['a hog for', 'acquisitive', 'all-devouring', 'approachable', 'avaricious', 'avid', 'bent', 'bottomless', 'bribable', 'bribeable', 'buyable', 'corrupt'],
    'vendetta': ['acrimony', 'altercation', 'animosity', 'animus', 'argument', 'avengement', 'bad blood', 'bicker', 'bitter feeling', 'bitterness', 'blood feud', 'brawl'],
    'vending': ['consumer preference study', 'consumer research', 'consumer survey', 'direct-mail selling', 'hard sell', 'hawking', 'high-pressure salesmanship', 'huckstering', 'jobbing', 'low-pressure salesmanship', 'mail-order selling', 'market research'],
    'vendor': ['arab', 'automat', 'cadger', 'chapman', 'cheap-jack', 'cheap-john', 'cheapjack', 'coin machine', 'coin-operated machine', 'colporteur', 'coster', 'costermonger'],
    'veneer': ['appearance', 'aspect', 'board', 'brick', 'clapboard', 'coat', 'coating', 'collop', 'cover', 'covering', 'cursoriness', 'cut'],
    'venerable': ['acknowledged', 'admirable', 'admitted', 'advanced', 'advanced in life', 'advanced in years', 'age-old', 'aged', 'ageless', 'along in years', 'ancient', 'antediluvian'],
    'venerate': ['accord respect to', 'admire', 'adore', 'apotheosize', 'appreciate', 'defer to', 'deify', 'do homage to', 'do service', 'entertain respect for', 'esteem', 'exalt'],
    'veneration': ['admiration', 'adoration', 'apotheosis', 'appreciation', 'approbation', 'approval', 'awe', 'breathless adoration', 'churchgoing', 'co-worship', 'conformity', 'consideration'],
    'venerative': ['christian', 'christianlike', 'christianly', 'admiring', 'adorant', 'adoring', 'apotheosizing', 'awed', 'awestricken', 'awestruck', 'believing', 'cultish'],
    'venereal': ['amorous', 'aphrodisiac', 'aphroditous', 'arousing', 'carnal', 'erogenic', 'erogenous', 'erotic', 'eroticizing', 'erotogenic', 'fleshly', 'gamic'],
    'venereal disease': ['african lethargy', 'asiatic cholera', 'chagres fever', 'french disease', 'german measles', 'haverhill fever', 'spanish pox', 'vd', 'acquired syphilis', 'acute articular rheumatism', 'ague', 'alkali disease'],
    'venery': ['act of love', 'adultery', 'aphrodisia', 'ass', 'balling', 'beasts of venery', 'big game', 'carnal knowledge', 'chase', 'chevy', 'chivy', 'climax'],
    'vengeance': ['avengement', 'avenging', 'blood feud', 'counterblow', 'energetically', 'enthusiastically', 'ferociously', 'feud', 'fiercely', 'forcefully', 'furiously', 'getting even'],
    'venial': ['admissible', 'allowable', 'condonable', 'defensible', 'dispensable', 'excusable', 'exemptible', 'expiable', 'forgivable', 'harmless', 'inoffensive', 'insignificant'],
    'venire': ['blue-ribbon jury', 'certiorari', 'citation', 'country', 'garnishment', 'grand jury', 'habeas corpus', 'hung jury', 'impanelment', 'inquest', 'jury', 'jury list'],
    'venison': ['aspic', 'barbecue', 'boiled meat', 'bouilli', 'civet', 'flesh', 'forcemeat', 'game', 'hachis', 'hash', 'jerky', 'joint'],
    'venom': ['abomination', 'acaricide', 'acrimony', 'acuteness', 'animality', 'animosity', 'animus', 'antagonism', 'anthelmintic', 'antibiotic', 'antiseptic', 'atrocity'],
    'venomous': ['acerbic', 'acrid', 'acute', 'antagonistic', 'antipathetic', 'baleful', 'baneful', 'belligerent', 'bitter', 'catching', 'caustic', 'clashing'],
    'vent': ['air', 'air duct', 'air hole', 'air passage', 'air shaft', 'air tube', 'airway', 'announce', 'aperture', 'armhole', 'articulate', 'articulation'],
    'ventilate': ['aerate', 'air', 'air out', 'air-condition', 'air-cool', 'airify', 'analyze', 'break it to', 'break the news', 'breathe', 'bring up', 'broach'],
    'ventilation': ['aerage', 'aeration', 'air conditioning', 'air cooling', 'airing', 'analysis', 'bandying', 'book', 'broadcast', 'broadcasting', 'bruiting', 'bruiting about'],
    'ventilator': ['aerator', 'air conditioner', 'air cooler', 'air duct', 'air filter', 'air hole', 'air passage', 'air shaft', 'air tube', 'airway', 'blower', 'blowhole'],
    'venture': ['accept', 'advance', 'adventure', 'affair', 'agiotage', 'approach', 'arbitrage', 'assay', 'assume', 'attack', 'attempt', 'banter'],
    'venturesome': ['adventuresome', 'adventurous', 'aggressive', 'aleatory', 'ambitious', 'audacious', 'bold', 'brave', 'chancy', 'courageous', 'daredevil', 'daring'],
    'venus': ['adonis', 'agdistis', 'aldebaran', 'amor', 'aphrodite', 'apollo', 'apollo belvedere', 'apollon', 'ares', 'artemis', 'astarte', 'ate'],
    'veracious': ['actual', 'ascertained', 'attested', 'authenticated', 'categorically true', 'certain', 'certified', 'confirmed', 'corroborated', 'demonstrated', 'determined', 'direct'],
    'veracity': ['absolute credibility', 'accuracy', 'actuality', 'correctness', 'credibility', 'eternal verities', 'exactness', 'fact', 'factualness', 'frankness', 'good sooth', 'gospel'],
    'verbal': ['adjectival', 'adverbial', 'answering', 'articulated', 'attributive', 'authentic', 'bona fide', 'candid', 'card-carrying', 'colloquial', 'communicating', 'communicational'],
    'verbalize': ['air', 'articulate', 'breathe', 'chime', 'chorus', 'come out with', 'communicate', 'convey', 'couch in terms', 'deliver', 'disclose', 'emit'],
    'verbatim': ['absolutely', 'accurate', 'accurately', 'authentic', 'bona fide', 'candid', 'card-carrying', 'close', 'dead', 'definitely', 'dinkum', 'direct'],
    'verbiage': ['choice of words', 'circumambages', 'circumbendibus', 'circumlocution', 'cloud of words', 'composition', 'dialect', 'diction', 'expansiveness', 'expression', 'floridity', 'floridness'],
    'verbose': ['all jaw', 'candid', 'chatty', 'circumlocutory', 'communicative', 'conversational', 'de longue haleine', 'de trop', 'diffuse', 'dispensable', 'effusive', 'endless'],
    'verbosity': ['bedizenment', 'big mouth', 'bombast', 'candor', 'cloud of words', 'communicativeness', 'conversableness', 'duplication', 'duplication of effort', 'effusion', 'effusiveness', 'embellishment'],
    'verboten': ['banned', 'barred', 'contraband', 'disapproved', 'forbade', 'forbid', 'forbidden', 'illegal', 'illicit', 'nonpermissible', 'not permitted', 'off limits'],
    'verdant': ['aestival', 'beryl-green', 'berylline', 'blue-green', 'bluish-green', 'caespitose', 'chartreuse', 'chloranemic', 'chlorine', 'chlorotic', 'citrine', 'citrinous'],
    'verdict': ['acquittal', 'action', 'award', 'condemnation', 'consideration', 'decision', 'decree', 'deliverance', 'determination', 'diagnosis', 'dictum', 'doom'],
    'verdure': ['botany', 'chloranemia', 'chloremia', 'chlorophyll', 'chlorosis', 'flora', 'flowerage', 'glaucescence', 'glaucousness', 'green', 'greenery', 'greenishness'],
    'verge': ['about to', 'abut', 'abut on', 'adjoin', 'aim', 'approach', 'armory', 'badge', 'badge of office', 'badges', 'bank', 'baton'],
    'veridical': ['actual', 'faithful', 'indisputable', 'just', 'real', 'right', 'speaking', 'strict', 'true', 'true-tongued', 'truth', 'truth-telling'],
    'verifiable': ['absolute', 'actual', 'admitting no question', 'apodictic', 'attestable', 'authenticatable', 'checkable', 'confirmable', 'demonstrable', 'demonstratable', 'evincible', 'factual'],
    'verification': ['acid test', 'affirmation', 'ascertainment', 'assay', 'assurance', 'attestation', 'authentication', 'backing', 'backing up', 'bearing out', 'blank determination', 'bolstering'],
    'verified': ['actual', 'ascertained', 'attested', 'authenticated', 'borne out', 'categorically true', 'certain', 'certified', 'circumstantiated', 'confirmed', 'corroborated', 'demonstrated'],
    'verify': ['affirm', 'assay', 'attest', 'audit', 'authenticate', 'back', 'back up', 'balance', 'balance the books', 'bear out', 'bolster', 'bring to test'],
    'verily': ['actually', 'assuredly', 'certainly', 'clearly', 'decidedly', 'demonstrably', 'factually', 'for a certainty', 'for real', 'forsooth', 'historically', 'in all conscience'],
    'verisimilar': ['apt', 'authentic', 'bona fide', 'candid', 'card-carrying', 'dinkum', 'fair', 'following the letter', 'foreseeable', 'genuine', 'good', 'honest'],
    'veritable': ['aboveboard', 'absolute', 'actual', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'ascertained', 'attested', 'authentic', 'authenticated', 'bona fide'],
    'verity': ['absolute credibility', 'actuality', 'credibility', 'eternal verities', 'fact', 'good sooth', 'gospel', 'historical truth', 'historicity', 'reality', 'sooth', 'the true'],
    'vermicide': ['aborticide', 'acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bug bomb', 'carbamate insecticide', 'chemosterilant', 'contact poison', 'defoliant', 'disinfectant', 'eradicant'],
    'vermilion': ['titian', 'titian-red', 'bricky', 'cardinal', 'carmine', 'carnation', 'carnelian', 'cerise', 'cherry', 'cherry-colored', 'cherry-red', 'crimson'],
    'vermin': ['amphibian', 'animal', 'aquatic', 'beast', 'biped', 'canine', 'cannibal', 'carnivore', 'cattle', 'chaff', 'cosmopolite', 'cur'],
    'vernacular': ['babbittish', 'philistine', 'aboriginal', 'accustomed', 'ancient language', 'argot', 'austerity', 'autochthonous', 'average', 'baldness', 'bareness', 'bourgeois'],
    'vernal': ['aestival', 'arctic', 'autumn', 'autumnal', 'beryl-green', 'berylline', 'blue-green', 'bluish-green', 'boreal', 'brumal', 'budding', 'callow'],
    'vernal equinox': ['aphelion', 'apogee', 'astronomical longitude', 'autumnal equinox', 'celestial equator', 'celestial longitude', 'celestial meridian', 'circle', 'colures', 'ecliptic', 'equator', 'equinoctial'],
    'versatile': ['able', 'accessible', 'accomplished', 'adaptable', 'adjustable', 'adroit', 'all-around', 'ambidextrous', 'amphibious', 'at hand', 'available', 'changeable'],
    'versatility': ['renaissance man', 'renaissance versatility', 'adaptability', 'adjustability', 'all-roundedness', 'ambidexterity', 'capriciousness', 'changeability', 'changeableness', 'choppiness', 'dappleness', 'deviation'],
    'verse': ['english sonnet', 'horatian ode', 'italian sonnet', 'petrarchan sonnet', 'pindaric ode', 'sapphic ode', 'shakespearean sonnet', 'spenserian stanza', 'acquaint', 'adage', 'advertise', 'advertise of'],
    'versed in': ['acquainted with', 'adept in', 'at home in', 'at home with', 'conversant with', 'expert at', 'familiar with', 'good at', 'handy at', 'informed in', 'intimate with', 'master of'],
    'versification': ['stabreim', 'alliterative meter', 'ars poetica', 'measure', 'meter', 'metrical pattern', 'metrics', 'numbers', 'poetcraft', 'poetic justice', 'poetic language', 'poetic license'],
    'version': ['account', 'adaptation', 'affiliation', 'arrangement', 'article', 'autograph', 'body', 'brainchild', 'branch', 'burlesque', 'chronicle', 'church'],
    'verso': ['gospel side', 'acknowledgments', 'back', 'back matter', 'bastard title', 'bibliography', 'cantorial side', 'catch line', 'catchword', 'colophon', 'contents', 'contents page'],
    'versus': ['across', 'adverse to', 'against', 'at cross-purposes with', 'athwart', 'con', 'confronting', 'contra', 'counter to', 'dead against', 'en route to', 'facing'],
    'vertebrate': ['amphibian', 'aquatic', 'biped', 'canine', 'cannibal', 'carnivore', 'cetacean', 'chordate', 'cosmopolite', 'feline', 'gnawer', 'herbivore'],
    'vertex': ['acme', 'angle', 'apex', 'apogee', 'bend', 'bifurcation', 'bight', 'brow', 'cant', 'cap', 'chevron', 'climax'],
    'vertical': ['abrupt', 'acmatic', 'apical', 'arrowlike', 'azimuth circle', 'bluff', 'bold', 'bolt upright', 'breakneck', 'capital', 'chief', 'consummate'],
    'vertigo': ['abscess', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache', 'bleeding'],
    'verve': ['active fancy', 'aggressiveness', 'alacrity', 'animal spirits', 'animation', 'anxiety', 'anxiousness', 'appetite', 'ardency', 'ardor', 'avidity', 'avidness'],
    'very': ['a bit', 'a little', 'absolutely', 'actually', 'acutely', 'almighty', 'almost', 'altogether', 'awful', 'awfully', 'bare', 'barest'],
    'vesicle': ['air bubble', 'balloon', 'bilge', 'birthmark', 'blackhead', 'bladder', 'blain', 'bleb', 'blemish', 'blister', 'blob', 'blood blister'],
    'vesicular': ['arterial', 'beaten', 'blebby', 'blistered', 'blistering', 'blistery', 'bubbling', 'bubbly', 'burbling', 'burbly', 'camerated', 'capillary'],
    'vesper': ['mass', 'bedtime prayer', 'camp meeting', 'church', 'church service', 'close of day', 'cockshut', 'compline', 'crepuscular', 'devotions', 'divine service', 'dusk'],
    'vessel': ['eustachian tube', 'fallopian tube', 'lc', 'lsd', 'lsm', 'sc', 'aircraft carrier', 'aircraft tender', 'ammunition ship', 'argosy', 'ark', 'assault transport'],
    'vest': ['appertain', 'appertain to', 'authorize', 'base', 'belong to', 'bless with', 'build', 'build in', 'dower', 'empower', 'endow', 'endow with'],
    'vest pocket': ['baby', 'baby-sized', 'bantam', 'banty', 'compact', 'diminutive', 'duodecimo', 'handy', 'miniature', 'miniaturized', 'minikin', 'minimal'],
    'vesta': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'vestal': ['platonic', 'abstinent', 'bachelor girl', 'celibate', 'continent', 'feme sole', 'intact', 'lone woman', 'maid', 'maiden', 'maiden lady', 'maidenly'],
    'vested': ['appareled', 'arrayed', 'attired', 'bedecked', 'breeched', 'capped', 'chausse', 'clad', 'cloaked', 'clothed', 'coifed', 'confirmed'],
    'vested interest': ['black power', 'italian vote', 'jewish vote', 'polish power', 'white power', 'absolute interest', 'appurtenance', 'authority', 'benefit', 'birthright', 'black vote', 'claim'],
    'vestibule': ['eustachian tube', 'access', 'adit', 'air lock', 'antechamber', 'anteroom', 'anvil', 'approach', 'auditory apparatus', 'auditory canal', 'auditory meatus', 'auditory nerve'],
    'vestige': ['account', 'afterglow', 'afterimage', 'ancient manuscript', 'annals', 'antique', 'antiquity', 'archaism', 'artifact', 'balance', 'boss', 'bump'],
    'vestment': ['apparel', 'array', 'attire', 'bedizenment', 'blanket', 'canonicals', 'ceremonial attire', 'clericals', 'cloak', 'cloth', 'clothes', 'clothing'],
    'vestry': ['council of nicaea', 'council of trent', 'easter sepulcher', 'lateran council', 'vatican council', 'ambry', 'apse', 'baptistery', 'blindstory', 'chancel', 'chapter', 'choir'],
    'vet': ['bone', 'campaigner', 'canvass', 'check over', 'check up', 'con', 'contemplate', 'dig', 'drill', 'elucubrate', 'examine', 'examine thoroughly'],
    'vetch': ['algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'diatom', 'fern', 'fruits and vegetables'],
    'veteran': ['father time', 'methuselah', 'nestor', 'old paar', 'blase', 'campaigner', 'centenarian', 'cosmopolitan', 'cosmopolite', 'dotard', 'elder', 'experienced'],
    'veto': ['absolute veto', 'ban', 'block', 'constitute', 'decline', 'decree', 'defeat', 'denial', 'deny', 'disallow', 'disallowance', 'embargo'],
    'vetoed': ['banned', 'barred', 'contraband', 'forbade', 'forbid', 'forbidden', 'illegal', 'illicit', 'nonpermissible', 'not permitted', 'off limits', 'out of bounds'],
    'vex': ['abrade', 'aggravate', 'ail', 'anger', 'annoy', 'arouse', 'badger', 'bait', 'be at', 'be the matter', 'bedevil', 'beset'],
    'vexation': ['abomination', 'affliction', 'aggravation', 'agitation', 'all-overs', 'angst', 'annoyance', 'anxiety', 'anxiety hysteria', 'anxiety neurosis', 'anxious bench', 'anxious concern'],
    'vexatious': ['aggravating', 'annoying', 'backbreaking', 'besetting', 'bothering', 'bothersome', 'burdensome', 'crushing', 'disturbing', 'exasperating', 'galling', 'grueling'],
    'vexed': ['aggravated', 'angry', 'annoyed', 'anxious', 'beset', 'bothered', 'browned-off', 'bugged', 'burnt-up', 'chafed', 'distressed', 'disturbed'],
    'vexing': ['aggravating', 'annoying', 'bothering', 'bothersome', 'disturbing', 'exasperating', 'galling', 'harassing', 'harassment', 'importunate', 'importune', 'irking'],
    'vhf': ['af', 'cps', 'ehf', 'hf', 'hz', 'mf', 'rf', 'shf', 'uhf', 'vlf', 'audio frequency', 'carrier frequency'],
    'viability': ['acceptability', 'achievability', 'actability', 'activation', 'adequacy', 'admissibility', 'agreeability', 'animal spirits', 'animate existence', 'animation', 'attainability', 'being alive'],
    'viable': ['ok', 'aboveground', 'acceptable', 'achievable', 'actable', 'activating', 'admissible', 'agreeable', 'alive', 'alive and kicking', 'all right', 'alright'],
    'viaduct': ['bifrost', 'bascule bridge', 'bateau bridge', 'bridge', 'cantilever bridge', 'carrefour', 'catwalk', 'cloverleaf', 'crossing', 'crosspoint', 'crossroad', 'crosswalk'],
    'viands': ['board', 'bread', 'bread and butter', 'cheer', 'comestibles', 'creature comfort', 'cuisine', 'daily bread', 'eatables', 'eats', 'edibles', 'fare'],
    'vibes': ['battery', 'bells', 'bones', 'caring', 'castanets', 'celesta', 'chime', 'chimes', 'chord', 'clappers', 'concern', 'crash cymbal'],
    'vibrancy': ['bassness', 'deepness', 'fluctuation', 'frequency', 'frequency band', 'frequency spectrum', 'fullness', 'harmonic motion', 'hollowness', 'libration', 'lowness', 'mellowness'],
    'vibrant': ['active', 'acute', 'aggressive', 'animated', 'brisk', 'consonant', 'dynamic', 'energetic', 'enterprising', 'enthusiastic', 'forceful', 'forcible'],
    'vibraphone': ['battery', 'bells', 'bones', 'castanets', 'celesta', 'chime', 'chimes', 'clappers', 'crash cymbal', 'cymbals', 'finger cymbals', 'gamelan'],
    'vibrate': ['bob', 'bobble', 'bounce', 'bump', 'careen', 'chatter', 'coggle', 'continue', 'dangle', 'didder', 'falter', 'fluctuate'],
    'vibrating': ['aspen', 'ceaseless', 'chattering', 'constant', 'continual', 'fluctuant', 'fluctuating', 'fluctuational', 'full', 'harmonic', 'incessant', 'libratory'],
    'vibration': ['ague', 'bumpiness', 'caring', 'ceaselessness', 'chattering', 'chord', 'chorea', 'cold shivers', 'concern', 'constancy', 'constant flow', 'continualness'],
    'vibrato': ['bebung', 'english horn', 'bassoon', 'block flute', 'bombard', 'bourdon', 'cello', 'claribel', 'clarinet', 'clarion', 'concert flute', 'cornet'],
    'vibrator': ['agitator', 'beater', 'churn', 'eggbeater', 'facial', 'facial massage', 'jiggler', 'kneading', 'massage', 'massaging', 'massotherapy', 'metronome'],
    'vicar': ['grand penitentiary', 'holy father', 'abuna', 'advocate', 'agent', 'alter ego', 'alternate', 'alternative', 'amicus curiae', 'analogy', 'antipope', 'archbishop'],
    'vicarage': ['dymaxion house', 'white house', 'adobe house', 'advowson', 'benefice', 'building', 'care of souls', 'casa', 'charge', 'church house', 'clergy house', 'cliff dwelling'],
    'vicarious': ['alternate', 'alternative', 'assigned', 'backup', 'commissioned', 'counterfeit', 'delegated', 'dummy', 'equivalent', 'ersatz', 'fake', 'imitation'],
    'vice': ['advocate', 'alter ego', 'alternate', 'amicus curiae', 'as proxy for', 'as representing', 'attorney', 'backup', 'backup man', 'bad habit', 'badness', 'besetting sin'],
    'vice president': ['agent', 'alternate', 'alternative', 'analogy', 'archon', 'backup', 'chancellor', 'change', 'changeling', 'chief executive', 'chief executive officer', 'comparison'],
    'vice versa': ['a rebours', 'against the grain', 'alternately', 'arsy-varsy', 'back and forth', 'backward and forward', 'backwards', 'backwards and forwards', 'bottom side up', 'bottom up', 'by contraries', 'contra'],
    'viceroy': ['beg', 'beglerbeg', 'bey', 'burgrave', 'collector', 'dey', 'eparch', 'exarch', 'gauleiter', 'governor', 'governor-general', 'khedive'],
    'vichyssoise': ['bisque', 'borscht', 'bouillabaisse', 'bouillon', 'broth', 'burgoo', 'chicken soup', 'chowder', 'clam chowder', 'clear soup', 'consomme', 'egg drop soup'],
    'vicinity': ['airspace', 'alentours', 'ambience', 'ambit', 'approach', 'approximation', 'area', 'belt', 'borderlands', 'circle', 'circuit', 'circumambiencies'],
    'vicious': ['draconian', 'tartarean', 'abominable', 'acrimonious', 'amoral', 'animal', 'anthropophagous', 'arrant', 'atrocious', 'bad', 'baleful', 'baneful'],
    'vicious circle': ['absurdity', 'aimlessness', 'annular muscle', 'annulus', 'apparent soundness', 'areola', 'aureole', 'bootlessness', 'casuistry', 'chain of circumstances', 'chain reaction', 'chaplet'],
    'vicissitude': ['adverse circumstances', 'adversity', 'affliction', 'aggravation', 'alteration', 'alternation', 'annoyance', 'asperity', 'blight', 'bummer', 'care', 'chain of circumstances'],
    'victim': ['also-ran', 'babe', 'beasts of venery', 'big game', 'boob', 'booby', 'butt', 'byword', 'byword of reproach', 'casualty', 'chump', 'cinch'],
    'victimization': ['mccarthyism', 'bamboozlement', 'befooling', 'bluffing', 'calculated deception', 'circumvention', 'conning', 'deceiving', 'deception', 'deceptiveness', 'defrauding', 'delusion'],
    'victimize': ['bamboozle', 'beat', 'beguile of', 'beset', 'bilk', 'bleed', 'bleed white', 'bully', 'bunco', 'burn', 'cheat', 'chisel'],
    'victor': ['champ', 'champion', 'comer', 'conquering hero', 'conqueror', 'conquistador', 'defeater', 'easy winner', 'first', 'hero', 'master', 'pancratiast'],
    'victorian': ['gothic', 'quakerish', 'antediluvian', 'antiquated', 'antique', 'archaic', 'bluenose', 'censorious', 'classical', 'demure', 'fossil', 'fossilized'],
    'victory': ['accomplishment', 'advantage', 'command', 'conquest', 'control', 'crushing', 'dominion', 'fortunate outcome', 'go', 'mastery', 'overcoming', 'prosperity'],
    'victrola': ['gramophone', 'pa', 'pa system', 'audio sound system', 'audiophile', 'binaural system', 'bitch box', 'bullhorn', 'cartridge', 'ceramic pickup', 'changer', 'crystal pickup'],
    'victuals': ['board', 'bread', 'bread and butter', 'cheer', 'chow', 'comestibles', 'creature comfort', 'cuisine', 'daily bread', 'eatables', 'eats', 'edibles'],
    'videotape': ['tv show', 'book', 'bulletin board', 'calendar', 'canned show', 'card', 'carve', 'catalog', 'catalog card', 'chalk', 'chalk up', 'check in'],
    'vie': ['admit of comparison', 'antagonize', 'battle', 'be commensurable', 'be comparable', 'beat against', 'beat up against', 'breast the wave', 'buck', 'buffet', 'buffet the waves', 'challenge'],
    'view': ['anschauung', 'account', 'aim', 'airscape', 'ambition', 'analysis', 'analyzing', 'angle', 'angle of vision', 'animadvert', 'animus', 'appraisal'],
    'viewer': ['tv-viewer', 'accepter', 'acquirer', 'addressee', 'audience', 'auditor', 'beholder', 'bird-watcher', 'bystander', 'consignee', 'drugstore cowboy', 'eyewitness'],
    'viewpoint': ['anschauung', 'angle', 'angle of vision', 'aspect', 'attitude', 'base', 'basis', 'coign of vantage', 'configuration', 'context', 'direction', 'distance'],
    'vigil': ['mass', 'alertness', 'all-night vigil', 'bedtime prayer', 'camp meeting', 'church', 'church service', 'compline', 'consciousness', 'custodianship', 'custody', 'devotions'],
    'vigilance': ['alertness', 'attentiveness', 'caution', 'circumspection', 'custodianship', 'custody', 'eagle eye', 'guard', 'guardedness', 'guardianship', 'invigilation', 'lookout'],
    'vigilant': ['argus-eyed', 'acute', 'agog', 'alert', 'all ears', 'all eyes', 'all ready', 'all set', 'armed', 'armed and ready', 'attentive', 'aux aguets'],
    'vigilantes': ['cheka', 'fbi', 'gestapo', 'interpol', 'mp', 'mvd', 'mounties', 'nkvd', 'ogpu', 'rcmp', 'sp', 'scotland yard'],
    'vignette': ['bildungsroman', 'gothic novel', 'aquatint', 'autolithograph', 'black and white', 'block', 'block print', 'brouillon', 'cameo', 'cartoon', 'catalog', 'cataloging'],
    'vigor': ['amperage', 'animal spirits', 'animation', 'armipotence', 'authority', 'bang', 'beef', 'bite', 'bitingness', 'black power', 'bounce', 'brio'],
    'vigorous': ['ablaze', 'acid', 'active', 'acute', 'afire', 'aggressive', 'animated', 'ardent', 'armipotent', 'athletic', 'authoritative', 'balmy'],
    'vigorously': ['actively', 'alertly', 'boldly', 'briskly', 'dynamically', 'eagerly', 'energetically', 'firmly', 'forcefully', 'forcibly', 'hammer and tongs', 'hardily'],
    'viking': ['ab', 'ancient mariner', 'argonaut', 'blackbeard', 'captain hook', 'captain kidd', 'dylan', 'flying dutchman', 'henry morgan', 'jean lafitte', 'neptune', 'od'],
    'vile': ['fescennine', 'rabelaisian', 'abhorrent', 'abject', 'abominable', 'abusive', 'amoral', 'arrant', 'atrocious', 'awful', 'bad', 'bad-smelling'],
    'vilification': ['abuse', 'assailing', 'assault', 'attack', 'berating', 'bitter words', 'blackening', 'calumny', 'character assassination', 'contumely', 'defamation', 'defamation of character'],
    'vilify': ['abuse', 'asperse', 'assail', 'attaint', 'bad-mouth', 'bark at', 'berate', 'besmirch', 'bespatter', 'betongue', 'blacken', 'blackguard'],
    'vilifying': ['abusive', 'back-biting', 'backbiting', 'belittling', 'bitchy', 'blackening', 'blameful', 'calumniatory', 'calumnious', 'catty', 'censorious', 'condemnatory'],
    'village': ['kreis', 'archbishopric', 'archdiocese', 'arrondissement', 'bailiwick', 'bishopric', 'borough', 'burghal', 'canton', 'citified', 'city', 'civic'],
    'villager': ['big-city man', 'bourgeois', 'burgess', 'burgher', 'city dweller', 'city man', 'city slicker', 'exurbanite', 'oppidan', 'suburbanite', 'townee', 'towner'],
    'villain': ['roscius', 'sob', 'actor', 'actress', 'antagonist', 'antihero', 'bad guy', 'bad person', 'barnstormer', 'bastard', 'bit', 'bit part'],
    'villainous': ['abandoned', 'abominable', 'arrant', 'atrocious', 'awful', 'bad', 'base', 'beastly', 'beneath contempt', 'bent', 'black', 'blackguardly'],
    'villainy': ['abomination', 'atrocity', 'bad', 'baseness', 'chicanery', 'degradation', 'disgrace', 'error', 'evil', 'infamy', 'iniquity', 'knavery'],
    'villein': ['bondmaid', 'bondman', 'bondslave', 'bondsman', 'bondswoman', 'captive', 'chattel', 'chattel slave', 'churl', 'concubine', 'debt slave', 'galley slave'],
    'villenage': ['absolutism', 'adverse possession', 'alodium', 'bond service', 'bondage', 'burgage', 'captivity', 'claim', 'colony', 'control', 'de facto', 'de jure'],
    'vim': ['aggressiveness', 'amperage', 'animal spirits', 'animation', 'armipotence', 'authority', 'bang', 'beef', 'black power', 'breeziness', 'brio', 'briskness'],
    'vindicate': ['absolve', 'account for', 'acquit', 'advocate', 'amnesty', 'argue', 'assert', 'bear out', 'claim', 'clear', 'confute', 'contend'],
    'vindication': ['absolution', 'acquittal', 'acquittance', 'clearance', 'clearing', 'compurgation', 'destigmatization', 'destigmatizing', 'discharge', 'disculpation', 'dismissal', 'exculpation'],
    'vindicator': ['nemesis', 'advocate', 'apologete', 'apologist', 'apologizer', 'avenger', 'champion', 'defender', 'guard', 'justifier', 'paladin', 'pleader'],
    'vine': ['algae', 'autophyte', 'bean', 'bittersweet', 'bracken', 'brown algae', 'clematis', 'climber', 'conferva', 'confervoid', 'creeper', 'dewberry'],
    'vinegar': ['acid', 'acidulant', 'bread-and-butter pickle', 'brine', 'chokecherry', 'crab apple', 'dill pickle', 'embalming fluid', 'formaldehyde', 'green apple', 'lemon', 'lime'],
    'vinegarish': ['acerb', 'acerbate', 'acerbic', 'acescent', 'bearish', 'bilious', 'bitter', 'cankered', 'choleric', 'crab', 'crabbed', 'cranky'],
    'vineyard': ['japanese garden', 'alpine garden', 'arboretum', 'bed', 'bog garden', 'border', 'botanical garden', 'dry garden', 'flower bed', 'flower garden', 'garden', 'garden spot'],
    'vintage': ['aftermath', 'aged', 'antiquated', 'antique', 'archaic', 'bearing', 'best', 'better', 'bumper crop', 'bygone', 'choice', 'classic'],
    'vintner': ['baker', 'barkeep', 'barkeeper', 'barmaid', 'barman', 'bartender', 'bookdealer', 'bookseller', 'bootlegger', 'brewer', 'brewmaster', 'butcher'],
    'viol': ['baritone', 'bass viol', 'descant viol', 'rebec', 'tenor viol', 'treble viol', 'tromba marina', 'trumpet marine', 'vielle', 'viol family', 'viola bastarda', 'viola da braccio'],
    'viola': ['a string', 'amati', 'cremona', 'd string', 'e string', 'english horn', 'g string', 'strad', 'stradivari', 'stradivarius', 'bass', 'bass viol'],
    'violate': ['abuse', 'adulterate', 'afflict', 'aggrieve', 'alloy', 'assault', 'assault sexually', 'attack', 'barbarize', 'batter', 'befoul', 'betray'],
    'violation': ['aberrance', 'aberrancy', 'abnormality', 'abomination', 'abuse', 'abuse of office', 'abusing', 'assault', 'atrocity', 'attack', 'bad faith', 'battering'],
    'violence': ['alecto', 'megaera', 'nemesis', 'tisiphone', 'abuse', 'acerbity', 'acidity', 'acridity', 'acrimony', 'agitability', 'animality', 'argumentum baculinum'],
    'violent': ['dionysiac', 'mafioso', 'young turk', 'abandoned', 'acid', 'acidulous', 'acrid', 'acrimonious', 'acute', 'amok', 'astringent', 'bacchic'],
    'violently': ['all to pieces', 'deliriously', 'demonically', 'desperately', 'destructively', 'distractedly', 'fanatically', 'fiercely', 'frantically', 'frenetically', 'frenziedly', 'furiously'],
    'violet': ['amethystine', 'lavender', 'lilac', 'livid', 'magenta', 'mauve', 'mulberry', 'orchid', 'pansy-purple', 'plum-colored', 'plum-purple', 'purple'],
    'violin': ['a string', 'amati', 'cremona', 'd string', 'e string', 'g string', 'strad', 'stradivari', 'stradivarius', 'bass', 'bass viol', 'bow'],
    'vip': ['establishment', 'rasputin', 'svengali', 'access', 'aristocracy', 'bad influence', 'baron', 'barons', 'big cheese', 'big gun', 'big man', 'big name'],
    'viper': ['animal', 'beast', 'cur', 'dog', 'hound', 'hyena', 'insect', 'mongrel', 'ophidian', 'pig', 'pit viper', 'polecat'],
    'virago': ['jezebel', 'mafioso', 'xanthippe', 'young turk', 'amazon', 'androgyne', 'battle-ax', 'beast', 'beldam', 'berserk', 'berserker', 'bitch'],
    'virgin': ['platonic', 'able', 'abstinent', 'acarpous', 'arid', 'artless', 'babe', 'baby', 'bachelor girl', 'bachelorlike', 'back', 'back of beyond'],
    'virginal': ['platonic', 'abstinent', 'artless', 'bachelorlike', 'budding', 'callow', 'celibate', 'continent', 'dewy', 'ever-new', 'evergreen', 'firsthand'],
    'virginity': ['platonic love', 'abstinence', 'artlessness', 'bachelordom', 'bachelorhood', 'bachelorism', 'bachelorship', 'berry', 'brand-newness', 'callowness', 'celibacy', 'chasteness'],
    'virgule': ['band', 'bar', 'bend', 'bias', 'cross-hatching', 'dash', 'delineation', 'diagonal', 'dotted line', 'hachure', 'hairline', 'hatching'],
    'virile': ['broad-shouldered', 'decisive', 'driving', 'energetic', 'forceful', 'hairychested', 'he-mannish', 'macho', 'male', 'manful', 'manlike', 'manly'],
    'virility': ['adulthood', 'adultness', 'age of consent', 'amperage', 'armipotence', 'authority', 'beef', 'black power', 'brute force', 'charge', 'charisma', 'clout'],
    'virtu': ['aesthetics', 'art', 'art object', 'artistic skill', 'artistic taste', 'artistry', 'arty-craftiness', 'brainchild', 'bric-a-brac', 'classic', 'composition', 'connoisseurship'],
    'virtual': ['accepted', 'basic', 'between the lines', 'constructive', 'covert', 'cryptic', 'delitescent', 'dormant', 'effective', 'esoteric', 'essential', 'fundamental'],
    'virtually': ['absolutely', 'actually', 'all in all', 'almost', 'almost entirely', 'approximately', 'as good as', 'basically', 'by and large', 'chiefly', 'effectively', 'effectually'],
    'virtue': ['dutch courage', 'advantageousness', 'affection', 'agreeableness', 'amperage', 'arete', 'armipotence', 'asset', 'assured probity', 'attribute', 'auspiciousness', 'authority'],
    'virtuosity': ['ability', 'accomplishment', 'address', 'adeptness', 'adroitness', 'aesthetics', 'airmanship', 'artfulness', 'artisanship', 'artistic taste', 'artistry', 'ascendancy'],
    'virtuoso': ['a per se', 'daedalian', 'ace', 'adept', 'adroit', 'amateur', 'apt', 'arbiter', 'arbiter elegantiarum', 'arbiter of taste', 'artist', 'artiste'],
    'virtuous': ['christian', 'advantageous', 'angelic', 'auspicious', 'beneficial', 'benevolent', 'blameless', 'blotless', 'bon', 'bonny', 'braw', 'bueno'],
    'virulence': ['acerbity', 'acid', 'acidity', 'acidulousness', 'acridity', 'acrimony', 'acuteness', 'amperage', 'animality', 'animosity', 'animus', 'antagonism'],
    'virulent': ['acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'acute', 'antagonistic', 'antipathetic'],
    'virus': ['acaricide', 'adenovirus', 'aerial infection', 'aerobe', 'aerobic bacteria', 'aerobic organism', 'airborne infection', 'amoeba', 'anaerobe', 'anaerobic bacteria', 'anaerobic organism', 'anthelmintic'],
    'visa': ['john hancock', 'ok', 'acceptance', 'affidavit', 'affirmance', 'affirmation', 'approbation', 'approval', 'attestation', 'authentication', 'authority', 'authorization'],
    'visage': ['air', 'bearing', 'brow', 'carriage', 'cast', 'cast of countenance', 'color', 'complexion', 'countenance', 'demeanor', 'dial', 'expression'],
    'viscera': ['abdomen', 'anus', 'appendix', 'being', 'blind gut', 'bones', 'bosom', 'bowels', 'brain', 'breast', 'cecum', 'colon'],
    'visceral': ['abdominal', 'affectional', 'affective', 'anal', 'appendical', 'cardiac', 'cecal', 'colic', 'colonic', 'coronary', 'demonstrative', 'duodenal'],
    'viscid': ['adherent', 'adhesive', 'amylaceous', 'bulldogged', 'bulldoggish', 'bulldoggy', 'bullheaded', 'cartilaginous', 'chewy', 'clabbered', 'clammy', 'clingy'],
    'viscosity': ['adhesiveness', 'bullheadedness', 'clabbering', 'clamminess', 'closeness', 'clotting', 'coagulation', 'cohesiveness', 'colloidality', 'compactness', 'congestedness', 'congestion'],
    'viscount': ['brahman', 'archduke', 'aristocrat', 'armiger', 'baron', 'baronet', 'blue blood', 'count', 'daimio', 'duke', 'earl', 'esquire'],
    'viscous': ['adhesive', 'amylaceous', 'broad-bodied', 'bulky', 'bullnecked', 'clabbered', 'clammy', 'close', 'close-knit', 'close-textured', 'close-woven', 'clotted'],
    'vishnu': ['agni', 'asvins', 'atman', 'avalokita', 'bhairava', 'bhairavi', 'brahma', 'buddha', 'chandi', 'daksha', 'devaki', 'devi'],
    'visibility': ['cat', 'aerospace', 'aerosphere', 'air hole', 'air pocket', 'airspace', 'apparentness', 'bump', 'ceiling', 'clearness', 'crosswind', 'crystal-clearness'],
    'visible': ['apparent', 'appearing', 'beholdable', 'clear', 'clear as crystal', 'conspicuous', 'crystal-clear', 'detectable', 'discernible', 'disclosed', 'discoverable', 'distinct'],
    'visibly': ['actually', 'after a fashion', 'apparently', 'appreciably', 'as seen', 'assuredly', 'at a glance', 'at any rate', 'at best', 'at first sight', 'at least', 'at most'],
    'vision': ['masan', 'vorstellung', 'apocalypse', 'apparition', 'appearance', 'astral', 'astral spirit', 'bad dream', 'bamboozlement', 'banshee', 'befooling', 'bluffing'],
    'visionary': ['barmecidal', 'barmecide', 'don quixote', 'quixote', 'utopian', 'abstracted', 'addict', 'airy', 'apparent', 'apparitional', 'astral', 'autistic'],
    'visit': ['admit', 'affect', 'afflict', 'appear', 'assail', 'assister', 'attack', 'attend', 'avenge', 'barge in', 'be admitted', 'be at'],
    'visit upon': ['bring', 'bring to account', 'bring to book', 'bring upon', 'call to account', 'castigate', 'chasten', 'chastise', 'correct', 'deal with', 'discipline', 'do to'],
    'visitation': ['jacksonian epilepsy', 'rolandic epilepsy', 'abdominal epilepsy', 'access', 'acquired epilepsy', 'activated epilepsy', 'affect epilepsy', 'affliction', 'akinetic epilepsy', 'apoplexy', 'arrest', 'attack'],
    'visitor': ['big brother', 'aficionado', 'arrival', 'attender', 'audience', 'auditor', 'boatswain', 'boss', 'buff', 'caller', 'chief', 'comer'],
    'visor': ['bill', 'camouflage', 'dark glasses', 'disguise', 'domino', 'eyeshade', 'eyeshield', 'false colors', 'false face', 'false front', 'goggles', 'incognito'],
    'vista': ['airscape', 'cityscape', 'cloudscape', 'command', 'domination', 'eyereach', 'eyeshot', 'eyesight', 'field of view', 'field of vision', 'horizon', 'ken'],
    'visual': ['apparent', 'beholdable', 'detectable', 'discernible', 'disclosed', 'evident', 'exposed', 'exposed to view', 'eyeball', 'hanging out', 'in evidence', 'in full view'],
    'visualization': ['vorstellung', 'concept', 'conception', 'conceptualization', 'eidetic image', 'envisaging', 'envisioning', 'image', 'imagery', 'imagery study', 'imaging', 'imagism'],
    'visualize': ['anticipate', 'apprehend', 'bring to mind', 'call to mind', 'call up', 'conceive', 'conjure up', 'contemplate', 'divine', 'envisage', 'envision', 'fancy'],
    'vital': ['abiding', 'aboveground', 'acid', 'age-long', 'aged', 'agog', 'alacritous', 'alive', 'alive and kicking', 'all agog', 'among the living', 'ancient'],
    'vitality': ['alacrity', 'amperage', 'animal spirits', 'animate existence', 'animation', 'anxiety', 'anxiousness', 'appetite', 'armipotence', 'authority', 'avidity', 'avidness'],
    'vitalize': ['activate', 'animate', 'arouse', 'awaken', 'boost', 'breathe life into', 'brighten', 'bring into being', 'bring into existence', 'bring to life', 'buoy up', 'call into being'],
    'vitals': ['abdomen', 'anus', 'appendix', 'blind gut', 'bosom', 'bowels', 'brain', 'breast', 'cecum', 'center', 'center of life', 'colon'],
    'vitamin': ['adermin', 'adjuvant', 'aneurin', 'antiberi-beri factor', 'ascorbic acid', 'axerophthol', 'biotin', 'carminative', 'carotene', 'cholecalciferol', 'choline', 'cobalamin'],
    'vitamin deficiency': ['lombardy leprosy', 'anemia', 'ariboflavinosis', 'beriberi', 'cachexia', 'chlorosis', 'deficiency anemia', 'dermatitis', 'dietary deficiency', 'goiter', 'greensickness', 'keratomalacia'],
    'vitiate': ['abate', 'abolish', 'abrogate', 'adulterate', 'alloy', 'annihilate', 'annul', 'bastardize', 'blemish', 'bring to nothing', 'brutalize', 'buffer'],
    'vitrified': ['backed', 'calcified', 'callous', 'calloused', 'case-hardened', 'crusted', 'crusty', 'crystallized', 'fossilized', 'granulated', 'hardened', 'hornified'],
    'vitriol': ['acrimony', 'animosity', 'animus', 'bad blood', 'bitter feeling', 'bitterness', 'feud', 'gall', 'hard feelings', 'ill blood', 'ill feeling', 'ill will'],
    'vitriolic': ['acerbic', 'acid', 'acidulous', 'acrid', 'acrimonious', 'antagonistic', 'antipathetic', 'asperous', 'astringent', 'belligerent', 'biting', 'bitter'],
    'vittles': ['board', 'bread', 'bread and butter', 'cheer', 'comestibles', 'creature comfort', 'cuisine', 'daily bread', 'eatables', 'edibles', 'fare', 'fast food'],
    'vituperate': ['abuse', 'asperse', 'assail', 'attack', 'bark at', 'bawl out', 'berate', 'betongue', 'blacken', 'blackguard', 'blame', 'call names'],
    'vituperation': ['abuse', 'assailing', 'assault', 'attack', 'berating', 'billingsgate', 'bitter words', 'blackening', 'blame', 'calumny', 'censure', 'contumely'],
    'vituperative': ['rabelaisian', 'abusive', 'acid', 'belittling', 'biting', 'blackening', 'blameful', 'blasphemous', 'calumniatory', 'calumnious', 'castigatory', 'censorious'],
    'viva voce': ['articulate', 'articulated', 'enunciated', 'lingual', 'linguistic', 'nuncupative', 'oral', 'orally', 'parol', 'pronounced', 'said', 'sonant'],
    'vivacious': ['active', 'activist', 'activistic', 'acute', 'aggressive', 'agog', 'alacritous', 'alert', 'alive', 'all agog', 'animate', 'animated'],
    'vivacity': ['activity', 'alacrity', 'animal spirits', 'animate existence', 'animation', 'anxiety', 'anxiousness', 'appetite', 'ardor', 'avidity', 'avidness', 'being alive'],
    'vivid': ['active', 'acute', 'aggressive', 'agog', 'alacritous', 'alive', 'all agog', 'animate', 'animated', 'anxious', 'apish', 'avid'],
    'vivify': ['animate', 'brace', 'brace up', 'breathe life into', 'bring into being', 'bring into existence', 'bring to life', 'brisk', 'brisken', 'buck up', 'call into being', 'call into existence'],
    'vixen': ['jezebel', 'mafioso', 'partlet', 'xanthippe', 'young turk', 'amazon', 'battle-ax', 'beast', 'beldam', 'berserk', 'berserker', 'biddy'],
    'vocable': ['allophone', 'alveolar', 'antonym', 'apico-alveolar', 'apico-dental', 'articulation', 'aspiration', 'assimilation', 'bilabial', 'cacuminal', 'cerebral', 'check'],
    'vocabulary': ['argot', 'biographical dictionary', 'cant', 'chemical dictionary', 'desk dictionary', 'dialect dictionary', 'dictionary', 'dictionary of quotations', 'electronics dictionary', 'etymological dictionary', 'foreign-language dictionary', 'gazetteer'],
    'vocal': ['alto', 'articulate', 'articulated', 'baritone', 'bass', 'bravura', 'choral', 'choric', 'coloratura', 'dramatic', 'eloquent', 'enunciated'],
    'vocalist': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso profundo', 'blues singer'],
    'vocalization': ['articulation', 'attack', 'bel canto', 'bravura', 'choral singing', 'coloratura', 'croon', 'crooning', 'delivery', 'diction', 'enunciation', 'folk singing'],
    'vocalize': ['anthem', 'articulate', 'ballad', 'breathe', 'carol', 'chant', 'chatty', 'chime', 'chirp', 'chirrup', 'choir', 'chorus'],
    'vocation': ['ambition', 'apostleship', 'area', 'art', 'aspiration', 'bag', 'basis', 'business', 'call', 'calling', 'care of souls', 'career'],
    'vociferate': ['bellow out', 'call out', 'clamor', 'cry', 'cry out', 'holler', 'holler out', 'hollo', 'make an outcry', 'make an uproar', 'outcry', 'pipe up'],
    'vociferous': ['bawling', 'blaring', 'blatant', 'blatting', 'blustering', 'boanergean', 'boisterous', 'brassy', 'brawling', 'brazen', 'clamant', 'clamorous'],
    'vogue': ['a la mode', 'acceptance', 'acclaim', 'bon ton', 'celebrity', 'character', 'chic', 'convention', 'craze', 'cry', 'currency', 'custom'],
    'voice': ['australian ballot', 'hare system', 'heldentenor', 'meistersinger', 'ok', 'acceptance', 'accompaniment', 'active', 'active voice', 'adherence', 'admiration', 'agency'],
    'voiced': ['accented', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulate', 'articulated', 'assimilated', 'back', 'barytone', 'bilabial', 'broad'],
    'voiceless': ['accented', 'alveolar', 'anaudic', 'aphasic', 'aphonic', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'assimilated', 'back', 'bad'],
    'void': ['abandon', 'abbreviate', 'abnegate', 'abolish', 'abridge', 'abrogate', 'absence', 'abysm', 'abyss', 'acreage', 'annihilate', 'annul'],
    'voidance': ['bm', 'abolishment', 'abolition', 'abrogation', 'annulment', 'bloody flux', 'bowel movement', 'cancel', 'canceling', 'cancellation', 'cassation', 'catharsis'],
    'volatile': ['adrift', 'afloat', 'agitable', 'airy', 'alternating', 'amorphous', 'birdbrained', 'birdwitted', 'bouncy', 'brittle', 'bubbly', 'buoyant'],
    'volatility': ['airiness', 'animation', 'ascent', 'brainlessness', 'bubbliness', 'buoyancy', 'caducity', 'changeability', 'changeableness', 'coquettishness', 'corruptibility', 'daintiness'],
    'volatilize': ['aerate', 'aerify', 'atomize', 'attenuate', 'blow off', 'carbonate', 'cast forth', 'chlorinate', 'clear away', 'dilute', 'dispel', 'dissipate'],
    'volcanic': ['agitable', 'bursting', 'combustible', 'detonating', 'edgy', 'emotional', 'emotionally unstable', 'eruptive', 'excitable', 'explodable', 'explosible', 'explosive'],
    'volcano': ['belch', 'burst', 'cascade', 'debouchment', 'dissiliency', 'eructation', 'eruption', 'flare-up', 'gush', 'jet', 'outbreak', 'outburst'],
    'volition': ['alternativity', 'animus', 'appetence', 'appetency', 'appetite', 'choice', 'choosing', 'co-optation', 'co-option', 'command', 'conation', 'conatus'],
    'volley': ['antiaircraft barrage', 'arrow', 'arrowhead', 'badinage', 'bang', 'bantering', 'barb', 'bark', 'barrage', 'blast', 'bobtailed arrow', 'bolt'],
    'volplane': ['acrobatics', 'aerobatics', 'aeroplane', 'airlift', 'airplane', 'balloon', 'banking', 'be airborne', 'chandelle', 'crabbing', 'cruise', 'dive'],
    'volte face': ['about-face', 'about-turn', 'afterthoughts', 'alchemy', 'assimilation', 'assumption', 'back track', 'back trail', 'backing', 'backing off', 'backing out', 'backing up'],
    'volubility': ['big mouth', 'candor', 'communicativeness', 'conversableness', 'effusion', 'effusiveness', 'flow of words', 'flowing tongue', 'fluency', 'fluent tongue', 'flux de bouche', 'flux de paroles'],
    'voluble': ['all jaw', 'bombastic', 'candid', 'chatty', 'communicative', 'conversational', 'effusive', 'expansive', 'exuberant', 'flip', 'fluent', 'frank'],
    'volume': ['abundance', 'accommodation', 'acreage', 'acres', 'aggregate', 'amount', 'amplitude', 'area', 'armful', 'article', 'back number', 'bagful'],
    'voluminous': ['gargantuan', 'ample', 'amplitudinous', 'astronomical', 'awesome', 'big', 'billowing', 'boundless', 'broad', 'bulky', 'capacious', 'cavernous'],
    'voluntarily': ['advisedly', 'by choice', 'by design', 'calculatedly', 'consciously', 'contemplatedly', 'deliberately', 'designedly', 'electively', 'freely', 'gratis', 'gratuitously'],
    'voluntary': ['vorspiel', 'advised', 'aimed', 'aimed at', 'alternative', 'arbitrary', 'autonomous', 'avant-propos', 'breakthrough', 'calculated', 'chosen', 'conative'],
    'voluntary muscle': ['adductor', 'beef', 'beefiness', 'biceps', 'brawn', 'brawniness', 'buccinator', 'elasticity', 'gemellus', 'gluteus maximus', 'heftiness', 'huskiness'],
    'volunteer': ['arbitrary', 'autonomous', 'autonomousness', 'autonomy', 'come forward', 'discretional', 'discretionary', 'do independently', 'do voluntarily', 'elective', 'free', 'free will'],
    'voluptuous': ['cyrenaic', 'abandoned', 'alluring', 'amorous', 'appealing', 'appetitive', 'attractive', 'beautiful', 'bent on pleasure', 'bewitching', 'built', 'busty'],
    'volute': ['anfractuous', 'cirrus', 'cochlear', 'cochleate', 'coil', 'corkscrew', 'corkscrewy', 'curl', 'curlicue', 'evolute', 'gyre', 'helical'],
    'vomit': ['barf', 'be nauseated', 'be seasick', 'be sick', 'belch', 'blow open', 'blow out', 'break out', 'bring up', 'burst forth', 'burst out', 'cascade'],
    'vomiting': ['abscess', 'ague', 'airsickness', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy', 'backache'],
    'vomitory': ['avenue', 'blowhole', 'channel', 'chute', 'debouch', 'door', 'egress', 'ejaculative', 'ejective', 'emetic', 'emunctory', 'eructative'],
    'vomity': ['bad', 'barfy', 'brackish', 'bum', 'cheesy', 'cloying', 'crappy', 'creepy', 'crummy', 'dirty', 'disgusting', 'fecal'],
    'voodoo': ['jonah', 'alchemy', 'amulet', 'bad influence', 'bedevil', 'bewitch', 'bewitchery', 'cantrip', 'charm', 'conjurer', 'curse', 'demonize'],
    'voodooism': ['alchemy', 'bewitchery', 'charm', 'divination', 'enchantment', 'fetishism', 'glamour', 'gramarye', 'hoodoo', 'juju', 'jujuism', 'magic'],
    'voracious': ['apician', 'a hog for', 'acquisitive', 'all-devouring', 'ardent', 'avaricious', 'avid', 'bolting', 'bottomless', 'cormorant', 'coveting', 'covetous'],
    'voracity': ['acquisitiveness', 'avarice', 'avariciousness', 'avidity', 'avidness', 'covetousness', 'crapulence', 'crapulency', 'cupidity', 'edacity', 'frenzy of desire', 'fury of desire'],
    'vortex': ['charybdis', 'maelstrom', 'ado', 'agitation', 'back stream', 'backflow', 'backwash', 'backwater', 'bother', 'botheration', 'brouhaha', 'burst'],
    'vortical': ['affluent', 'circumgyratory', 'circumvolutory', 'confluent', 'coursing', 'cyclonic', 'decurrent', 'defluent', 'diffluent', 'flowing', 'fluent', 'fluxional'],
    'votary': ['christian', 'god-fearing man', 'maecenas', 'abettor', 'accepter', 'addict', 'adherent', 'admirer', 'adorer', 'advocate', 'aficionado', 'amateur'],
    'vote': ['australian ballot', 'hare system', 'ok', 'pr', 'absentee voting', 'acceptance', 'adherence', 'admiration', 'approbation', 'approval', 'aye', 'back'],
    'voting': ['australian ballot', 'hare system', 'pr', 'absentee voting', 'association', 'aye', 'ballot', 'ballot-box stuffing', 'canvass', 'canvassing', 'card voting', 'casting vote'],
    'votive candle': ['agnus dei', 'holy grail', 'host', 'pieta', 'sanctus bell', 'sangraal', 'ark', 'asperger', 'asperges', 'aspergillum', 'bambino', 'beadroll'],
    'votive offering': ['alms', 'alms fee', 'burnt offering', 'charity', 'collection', 'contribution', 'dole', 'donation', 'donative', 'drink offering', 'ex voto offering', 'handout'],
    'vouch': ['acknowledge', 'affirm', 'affirmance', 'affirmation', 'allegation', 'allege', 'and candle', 'announcement', 'annunciation', 'assert under oath', 'assertion', 'asseverate'],
    'vouched for': ['affirmed', 'alleged', 'announced', 'asserted', 'asseverated', 'attested', 'averred', 'avouched', 'avowed', 'certified', 'declared', 'deposed'],
    'voucher': ['cd', 'iou', 'mo', 'acceptance', 'acceptance bill', 'acknowledgment', 'acquittance', 'advocacy', 'advocating', 'advocation', 'affidavit', 'attestant'],
    'vouchsafe': ['ok', 'accord', 'administer', 'admit', 'afford', 'allot', 'allow', 'award', 'bestow', 'bestow on', 'communicate', 'condescend'],
    'vow': ['bible oath', 'affirm', 'and candle', 'assert', 'assert under oath', 'asseverate', 'assurance', 'assure', 'attest', 'avouch', 'avouchment', 'avow'],
    'vowel': ['accented', 'allophone', 'alveolar', 'apical', 'apico-alveolar', 'apico-dental', 'articulated', 'articulation', 'aspiration', 'assimilated', 'assimilation', 'back'],
    'voyage': ['boat', 'campaign', 'canoe', 'carry sail', 'circuit', 'circumnavigate', 'coast', 'course', 'cover', 'cross', 'crossing', 'cruise'],
    'voyager': ['adventurer', 'alpinist', 'astronaut', 'camper', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser', 'excursionist', 'explorer', 'fare'],
    'voyeur': ['paul pry', 'peeping tom', 'bugger', 'busybody', 'coprophiliac', 'eavesdropper', 'erotomaniac', 'exhibitionist', 'fetishist', 'gossip', 'inquirer', 'inquisitive'],
    'voyeurism': ['active algolagnia', 'algolagnia', 'algolagny', 'amphierotism', 'autoeroticism', 'bisexuality', 'coprophilia', 'curiosity', 'curious mind', 'curiousness', 'exhibitionism', 'fetishism'],
    'vp': ['archon', 'chancellor', 'chief executive', 'chief executive officer', 'dean', 'executive', 'executive director', 'executive officer', 'executive secretary', 'magistrate', 'management', 'managing director'],
    'vulcan': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'vulcanize': ['blaze', 'blister', 'brand', 'burn', 'burn in', 'burn off', 'cast', 'cauterize', 'char', 'coal', 'crack', 'cupel'],
    'vulgar': ['doric', 'average', 'barbarian', 'barbaric', 'barbarous', 'barnyard', 'base', 'baseborn', 'below the salt', 'blatant', 'blue', 'boorish'],
    'vulgar language': ['argot', 'bad language', 'billingsgate', 'blue language', 'cant', 'colorful language', 'cursing', 'cussing', 'dirty language', 'dirty talk', 'dysphemism', 'evil speaking'],
    'vulgarian': ['babbitt', 'philistine', 'arriviste', 'boor', 'bounder', 'bourgeois', 'cad', 'churl', 'clown', 'epicier', 'groundling', 'guttersnipe'],
    'vulgarism': ['babbittry', 'gothicism', 'bad taste', 'barbarism', 'barbarousness', 'bombasticness', 'bourgeois taste', 'cacology', 'cacophony', 'camp', 'campiness', 'clumsiness'],
    'vulgarity': ['gothicism', 'bad manners', 'bad taste', 'barbarism', 'barbarousness', 'baseness', 'bombasticness', 'cacology', 'cacophony', 'caddishness', 'clumsiness', 'coarseness'],
    'vulgarize': ['adulterate', 'alloy', 'canker', 'cheapen', 'clarify', 'coarsen', 'confound', 'contaminate', 'corrupt', 'debase', 'debauch', 'defile'],
    'vulnerability': ['ad lib', 'assailability', 'breakability', 'breakableness', 'brittleness', 'chink', 'crackability', 'crackableness', 'crispness', 'crumbliness', 'crushability', 'crushableness'],
    'vulnerable': ['aidless', 'answerable for', 'apt to', 'assailable', 'attackable', 'beatable', 'breakable', 'brittle', 'brittle as glass', 'capable of', 'conquerable', 'crackable'],
    'vulpine': ['machiavellian', 'machiavellic', 'acute', 'arch', 'artful', 'astute', 'cagey', 'canine', 'canny', 'clever', 'crafty', 'cunning'],
    'vulture': ['blackmailer', 'bloodsucker', 'extortionist', 'filch', 'harpy', 'heist', 'hook', 'leech', 'lift', 'pinch', 'predator', 'profiteer'],
    'vulva': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'vying': ['antagonism', 'antipathy', 'bad blood', 'clashing', 'collision', 'competing', 'competition', 'competitive', 'conflict', 'contrariety', 'contrariness', 'cross-purposes'],
    'wacky': ['abnormal', 'absurd', 'anomalous', 'apish', 'asinine', 'balmy', 'bananas', 'barmy', 'bats', 'batty', 'beany', 'befooled'],
    'wad': ['accumulation', 'acervation', 'agglomerate', 'agglomeration', 'aggregate', 'aggregation', 'amassment', 'bankroll', 'batch', 'block', 'bomb', 'boodle'],
    'wadding': ['bush', 'bushing', 'doubling', 'doublure', 'facing', 'filler', 'filling', 'gasket', 'gland', 'inlay', 'inlayer', 'insole'],
    'waddle': ['amble', 'andante', 'barge', 'bowl along', 'bundle', 'claudicate', 'claudication', 'clump', 'crawl', 'creep', 'dead march', 'dogtrot'],
    'wade into': ['ambush', 'assail', 'assault', 'attack', 'blitz', 'bushwhack', 'come at', 'come down on', 'crack down on', 'descend on', 'descend upon', 'dive into'],
    'wade through': ['bone', 'con', 'contemplate', 'dig', 'drill', 'drudge', 'elucubrate', 'examine', 'fag', 'go over', 'grind', 'grub'],
    'wadi': ['abysm', 'abyss', 'adolescent stream', 'aqueduct', 'arroyo', 'beck', 'bed', 'bottom', 'bottom glade', 'bottoms', 'bourn', 'box canyon'],
    'wading': ['australian crawl', 'aquaplaning', 'aquatics', 'backstroke', 'balneation', 'bathe', 'bathing', 'breaststroke', 'butterfly', 'crawl', 'diving', 'dog paddle'],
    'wafer': ['brussels biscuit', 'communion', 'eucharist', 'holy communion', 'host', 'last supper', 'melba toast', 'sacrament sunday', 'altar bread', 'biscuit', 'bread', 'bread and wine'],
    'waffle': ['babble', 'back and fill', 'blab', 'blabber', 'blather', 'blether', 'blintz', 'buckwheat cake', 'bull', 'bullshit', 'chat', 'chatter'],
    'waft': ['air express', 'airfreight', 'airlift', 'asportation', 'bear', 'bear up', 'bearing', 'blast', 'blow', 'blow a hurricane', 'blow great guns', 'blow over'],
    'wag': ['bad boy', 'banana', 'beat', 'bob', 'bobble', 'booger', 'brandish', 'buffoon', 'bugger', 'burlesquer', 'card', 'careen'],
    'wage': ['base pay', 'carry on', 'compensation', 'conduct', 'dismissal wage', 'do', 'earnings', 'employ', 'engage in', 'escalator clause', 'escalator plan', 'exercise'],
    'wage earner': ['blue-collar worker', 'breadwinner', 'casual', 'casual laborer', 'common laborer', 'day laborer', 'employee', 'factory worker', 'flunky', 'free lance', 'free-lancer', 'full-time worker'],
    'wage war': ['battle', 'box', 'brawl', 'broil', 'carry on hostilities', 'clash', 'close', 'collide', 'combat', 'come to blows', 'contend', 'contest'],
    'wager': ['adventure', 'ante', 'ante up', 'back', 'bet', 'bet on', 'blind bargain', 'book', 'borderline case', 'call', 'chance', 'chance it'],
    'waggery': ['crack', 'devilishness', 'devilment', 'devilry', 'deviltry', 'drollery', 'elfishness', 'flippancy', 'foolishness', 'frivolity', 'gag', 'high spirits'],
    'waggish': ['antic', 'arch', 'capersome', 'comic', 'comical', 'devilish', 'droll', 'elfish', 'elvish', 'facetious', 'foolish', 'frolicsome'],
    'waggle': ['beat', 'bob', 'bobble', 'careen', 'coggle', 'dangle', 'fluctuate', 'flutter', 'lash', 'librate', 'lurch', 'nutate'],
    'wagon': ['black maria', 'conestoga wagon', 'barge', 'boat', 'bus', 'caravan', 'carryall', 'cart', 'coach', 'covered wagon', 'cruiser', 'dray'],
    'wagoner': ['aquarius', 'ganymede', 'hebe', 'jehu', 'bearer', 'bheesty', 'bullwhacker', 'busboy', 'cabby', 'cabdriver', 'cabman', 'caddie'],
    'waif': ['arab', 'beach bum', 'beachcomber', 'beggar', 'bo', 'bum', 'bummer', 'castaway', 'castoff', 'derelict', 'discard', 'dogie'],
    'wail': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'blubber', 'boohoo', 'boom'],
    'wailing': ['acute', 'argute', 'bawling', 'bemoaning', 'bewailing', 'blatant', 'creaky', 'crying', 'ear-piercing', 'grieving', 'howling', 'in mourning'],
    'wainscot': ['base', 'baseboard', 'basement', 'bush', 'bushing', 'ceil', 'chassis', 'dado', 'doubling', 'doublure', 'face', 'facing'],
    'waist': ['blouse', 'bodice', 'center', 'core', 'corsage', 'diameter', 'diaphragm', 'dickey', 'equator', 'heart', 'interior', 'kernel'],
    'waistband': ['baldric', 'band', 'bandolier', 'bellyband', 'belt', 'breechclout', 'cestus', 'cincture', 'cummerbund', 'dhoti', 'diaper', 'fascia'],
    'waistline': ['center', 'core', 'diameter', 'diaphragm', 'equator', 'heart', 'interior', 'kernel', 'mean', 'median', 'middle', 'midmost'],
    'wait': ['abide', 'administer to', 'afterthought', 'attend', 'attend on', 'await', 'ballad singer', 'balladeer', 'bard', 'be patient', 'bear with composure', 'bide'],
    'wait on': ['abide', 'accompany', 'administer to', 'associate', 'associate with', 'assort with', 'attend', 'attend on', 'await', 'band together', 'bide', 'care for'],
    'waiting': ['about to be', 'agape', 'agog', 'all agog', 'already in sight', 'anticipant', 'anticipating', 'anticipative', 'anticipatory', 'anxiety', 'apprehension', 'approaching'],
    'waiting game': ['a wise passiveness', 'acceptance', 'contemplation', 'contemplative life', 'do-nothing policy', 'do-nothingism', 'do-nothingness', 'dormancy', 'endurance', 'forbearance', 'forbearing', 'forbearingness'],
    'waive': ['abandon', 'abdicate', 'abjure', 'abolish', 'abrogate', 'abstain', 'acknowledge defeat', 'adjourn', 'admit', 'admit exceptions', 'allow', 'allow for'],
    'waived': ['abandoned', 'abjured', 'ceded', 'dispensed with', 'disposed of', 'extra', 'forgone', 'forsworn', 'fresh', 'held back', 'held in reserve', 'held out'],
    'waiver': ['ok', 'abandonment', 'abdication', 'abeyance', 'abjuration', 'abjurement', 'abolishment', 'abolition', 'abrogation', 'admission', 'allowance', 'annulment'],
    'wake': ['affair', 'afterclap', 'aftercrop', 'aftereffect', 'afterglow', 'aftergrowth', 'afterimage', 'aftermath', 'afterpart', 'afterpiece', 'aftertaste', 'alertness'],
    'wake up': ['annoy', 'arouse', 'awake', 'awaken', 'blow the coals', 'blow up', 'break the spell', 'burst the bubble', 'call forth', 'call up', 'come alive', 'correct'],
    'wakeful': ['agile', 'alert', 'alive', 'attentive', 'awake', 'bright', 'insomniac', 'insomnious', 'keen', 'nimble', 'on the', 'on the alert'],
    'wale': ['abscess', 'aposteme', 'bed sore', 'bilge', 'birthmark', 'blackhead', 'blain', 'bleb', 'blemish', 'blister', 'blob', 'boil'],
    'walk': ['le mans', 'agora', 'air lane', 'air race', 'airing', 'alameda', 'ambit', 'amble', 'ambulate', 'amphitheater', 'andante', 'ankle'],
    'walk of life': ['art', 'business', 'calling', 'career', 'career building', 'careerism', 'craft', 'game', 'handicraft', 'lifework', 'line', 'line of business'],
    'walk off with': ['abstract', 'and', 'annex', 'appropriate', 'bag', 'boost', 'borrow', 'breeze', 'carry by storm', 'cop', 'crib', 'defraud'],
    'walk on': ['actor', 'antagonist', 'antihero', 'bit', 'bit part', 'bit player', 'cast', 'character', 'cue', 'extra', 'fat part', 'feeder'],
    'walk out': ['apostatize', 'betray', 'bolt', 'bow out', 'boycott', 'break away', 'call a strike', 'call it quits', 'close down', 'close shop', 'defect', 'depart'],
    'walk over': ['beat down', 'break', 'breeze', 'browbeat', 'bulldoze', 'bully', 'carry by storm', 'castrate', 'clamp down on', 'coerce', 'compel', 'cow'],
    'walkaway': ['cadmean victory', 'ko', 'pyrrhic victory', 'ascendancy', 'cakewalk', 'championship', 'conquest', 'easy victory', 'grand slam', 'knockout', 'landslide', 'landslide victory'],
    'walker': ['ambulator', 'baby buggy', 'baby carriage', 'backpacker', 'foot passenger', 'foot soldier', 'foot traveler', 'footslogger', 'gocart', 'hiker', 'hitchhiker', 'hoofer'],
    'walking': ['ambling', 'ambulant', 'ambulation', 'ambulative', 'ambulatory', 'backpacking', 'circuit-riding', 'expeditionary', 'footing', 'footing it', 'footwork', 'globe-girdling'],
    'walking papers': ['cashiering', 'conge', 'deposal', 'discharge', 'disemployment', 'dismissal', 'displacing', 'drumming out', 'firing', 'forced separation', 'furloughing', 'layoff'],
    'walking stick': ['malacca cane', 'advocate', 'alpenstock', 'arm', 'athletic supporter', 'back', 'backbone', 'backing', 'bandeau', 'baton', 'bearer', 'bra'],
    'walkout': ['abandonment', 'apostasy', 'arrest', 'bell', 'betrayal', 'bolt', 'boycott', 'boycottage', 'breakaway', 'check', 'checkmate', 'cutoff'],
    'walkway': ['alameda', 'beaten path', 'beaten track', 'berm', 'bicycle path', 'boardwalk', 'bridle path', 'catwalk', 'esplanade', 'fastwalk', 'foot pavement', 'footpath'],
    'wall': ['arch dam', 'arm', 'armor', 'armor-plate', 'backstop', 'balustrade', 'bamboo curtain', 'bank', 'bar', 'barbed wire', 'barrage', 'barricade'],
    'wall in': ['beleaguer', 'beset', 'besiege', 'blockade', 'board', 'bottle up', 'bound', 'box in', 'box up', 'brick', 'cage', 'chamber'],
    'wall street': ['american stock exchange', 'amex', 'dow-jones industrial average', 'lombard street', 'board', 'bourse', 'commodity exchange', 'competitive market', 'corn pit', 'curb', 'curb exchange', 'curb market'],
    'walled': ['armored', 'barred', 'beleaguered', 'beset', 'besieged', 'blockaded', 'bound', 'cabined', 'caged', 'cased', 'ceiled', 'cloaked'],
    'walleye': ['amaurosis', 'blepharitis', 'bug-eyes', 'cast', 'cataract', 'choroiditis', 'cockeyes', 'conjunctivitis', 'convergent strabismus', 'cross-eye', 'cross-eyedness', 'cross-eyes'],
    'wallop': ['bang', 'bash', 'baste', 'bastinado', 'bat', 'batter', 'beat', 'belabor', 'belt', 'biff', 'birch', 'blast'],
    'walloping': ['banging', 'bumping', 'colossal', 'dressing-down', 'enormous', 'gargantuan', 'giant', 'gigantic', 'hiding', 'immense', 'larruping', 'lathering'],
    'wallow': ['appreciate', 'baby', 'bask', 'baygall', 'be promiscuous', 'bend', 'blunder', 'bog', 'bottom', 'bottomland', 'bottoms', 'buffalo wallow'],
    'wallow in': ['adore', 'appreciate', 'bask in', 'be pleased with', 'delight in', 'derive pleasure from', 'devour', 'eat up', 'enjoy', 'feast on', 'freak out on', 'get high on'],
    'wallpaper': ['board', 'brick', 'clapboard', 'face', 'glass', 'glaze', 'lath', 'paper', 'plank', 'revet', 'shake', 'sheathe'],
    'walter mitty': ['absence of mind', 'absentmindedness', 'absorption', 'abstractedness', 'abstraction', 'bemusement', 'brown study', 'castle-building', 'daydream', 'daydreamer', 'daydreaming', 'depth of thought'],
    'wamble': ['amble', 'barge', 'bowl along', 'bundle', 'circle', 'circulate', 'circumrotate', 'circumvolute', 'clump', 'crank', 'drag', 'flounce'],
    'wampum': ['anklet', 'armlet', 'bangle', 'beads', 'bijou', 'blunt', 'boodle', 'bracelet', 'brass', 'bread', 'breastpin', 'brooch'],
    'wan': ['achromatic', 'achromic', 'anemic', 'apathetic', 'ashen', 'ashy', 'benumbed', 'blanch', 'blanched', 'blase', 'bleach', 'bleach out'],
    'wand': ['tarnkappe', 'armory', 'badge', 'badge of office', 'badges', 'baton', 'blazonry', 'brassard', 'button', 'caduceus', 'cap and gown', 'cap of darkness'],
    'wander': ['amble', 'babble', 'bat', 'bat around', 'be absent', 'be in error', 'be insane', 'be mistaken', 'be wrong', 'boom', 'bum', 'circumambulate'],
    'wanderer': ['ahasuerus', 'ancient mariner', 'argonaut', 'earth', 'flying dutchman', 'goliard', 'jupiter', 'mars', 'mercury', 'neptune', 'odysseus', 'oisin'],
    'wandering': ['wanderjahr', 'aberrancy', 'aberrant', 'aberration', 'aberrative', 'abnormal', 'adrift', 'afebrile delirium', 'afloat', 'afoot and lighthearted', 'aimless', 'aimlessness'],
    'wanderlust': ['wanderjahr', 'afoot and lighthearted', 'bumming', 'discursion', 'divagation', 'drifting', 'errantry', 'flitting', 'gadding', 'hoboism', 'itineracy', 'itinerancy'],
    'wane': ['abate', 'ablate', 'advance', 'age', 'ascend', 'back', 'back up', 'bate', 'be eaten away', 'beat', 'budge', 'calm'],
    'wangle': ['angle', 'argue into', 'arouse', 'brew', 'bring forth', 'bring out', 'bring over', 'bring round', 'bring to light', 'bring to reason', 'cabal', 'call forth'],
    'waning': ['aging', 'at rest', 'calm', 'cloistered', 'coming apart', 'contractive', 'cool', 'cracking', 'crumbling', 'decadent', 'declining', 'decreasing'],
    'want': ['absence', 'ache to', 'adulteration', 'aim at', 'ardor', 'arrearage', 'ask', 'awayness', 'bare cupboard', 'bare necessities', 'bare subsistence', 'be desirous of'],
    'wanted': ['called for', 'coveted', 'desired', 'essential', 'hoped-for', 'in demand', 'indicated', 'indispensable', 'irreducible', 'irreductible', 'irreplaceable', 'longed-for'],
    'wanting': ['absconded', 'absent', 'adulterated', 'appetitive', 'arrested', 'away', 'bankrupt in', 'bare of', 'bereaved', 'bereaved of', 'bereft', 'bereft of'],
    'wanton': ['adamic', 'casanova', 'don juan', 'jezebel', 'lothario', 'paphian', 'abandoned', 'accident-prone', 'adrift', 'afloat', 'alternating', 'amorphous'],
    'war': ['american revolution', 'ares', 'athena', 'balkan wars', 'bellona', 'boer war', 'civil war', 'crimean war', 'crusades', 'enyo', 'franco-prussian war', 'french revolution'],
    'war cry': ['angelus', 'angelus bell', 'alarm', 'alarum', 'bark', 'battle cry', 'bawl', 'bellow', 'bid to combat', 'birdcall', 'bugle call', 'call'],
    'war horse': ['houyhnhnm', 'tammany man', 'beldam', 'brood mare', 'campaigner', 'charger', 'colt', 'courser', 'critter', 'crone', 'dame', 'dobbin'],
    'war paint': ['sunday best', 'base', 'bravery', 'clown white', 'cold cream', 'compact', 'cosmetics', 'drugstore complexion', 'eye shadow', 'eyebrow pencil', 'face', 'foundation'],
    'warble': ['air', 'anthem', 'ballad', 'bark', 'bawl', 'bellow', 'blare', 'blat', 'blubber', 'boom', 'bray', 'breathe'],
    'warbler': ['heldentenor', 'meistersinger', 'philomel', 'alto', 'aria singer', 'avifauna', 'baby bird', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo'],
    'warbling': ['bel canto', 'bravura', 'choral singing', 'coloratura', 'croon', 'crooning', 'folk singing', 'hum', 'humming', 'intonation', 'lyricism', 'operatic singing'],
    'ward': ['kreis', 'va hospital', 'x ray', 'acropolis', 'administration', 'aegis', 'archbishopric', 'archdiocese', 'armament', 'armor', 'arrondissement', 'asylum'],
    'ward heeler': ['conservative', 'democrat', 'labourite', 'republican', 'tory', 'whig', 'adherent', 'appendage', 'attendant', 'buff', 'cavaliere servente', 'courtier'],
    'ward off': ['about the bush', 'anticipate', 'avert', 'bar', 'beat around', 'beat back', 'beat off', 'beg the question', 'block', 'brush off', 'chase', 'chase away'],
    'warden': ['air warden', 'alderman', 'archon', 'attendant', 'bailie', 'bull', 'burghermaster', 'burgomaster', 'cabinet member', 'cabinet minister', 'caretaker', 'castellan'],
    'warder': ['advance guard', 'air warden', 'armed guard', 'attendant', 'bank guard', 'bull', 'caretaker', 'castellan', 'coast guard', 'commandant', 'conservator', 'cordon'],
    'wardrobe': ['accouterments', 'caparison', 'cloakroom', 'closet', 'clothes closet', 'dressing room', 'fitting room', 'furnishings', 'getup', 'harness', 'linen closet', 'livery'],
    'wardship': ['administration', 'auspices', 'care', 'charge', 'clientage', 'clientship', 'cure', 'custodianship', 'custody', 'dependence', 'dependency', 'disability'],
    'ware': ['alive', 'apprehensive', 'article', 'article of commerce', 'article of merchandise', 'au courant', 'awake', 'catalog goods', 'cognizant', 'commodities', 'commodity', 'conscious'],
    'warehouse': ['accommodate', 'archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bestow', 'bin', 'bonded warehouse', 'bookcase'],
    'warfare': ['kilkenny cats', 'altercation', 'argument', 'bickering', 'cat-and-dog life', 'combat', 'competition', 'conflict', 'contention', 'contentiousness', 'contest', 'contestation'],
    'warlike': ['aggressive', 'antagonistic', 'battling', 'bellicose', 'belligerent', 'bloodthirsty', 'bloody', 'bloody-minded', 'chauvinist', 'chauvinistic', 'combative', 'contending'],
    'warlock': ['comus', 'faust', 'charmer', 'conjurer', 'diabolist', 'diviner', 'dowser', 'enchanter', 'mage', 'magus', 'miracle-worker', 'necromancer'],
    'warlord': ['simon legree', 'absolute monarch', 'absolute ruler', 'all-powerful ruler', 'arrogator', 'autarch', 'autocrat', 'caesar', 'commissar', 'czar', 'despot', 'dictator'],
    'warm': ['christian', 'christlike', 'christly', 'titian', 'titian-red', 'abandoned', 'ablaze', 'abounding in riches', 'affable', 'affectionate', 'affluent', 'afire'],
    'warm up': ['arrangement', 'basic training', 'break in', 'briefing', 'bring back', 'bring to', 'call back', 'chafe', 'charge', 'clearing the decks', 'cock', 'cook'],
    'warmed over': ['back-number', 'banal', 'bewhiskered', 'bromidic', 'common', 'commonplace', 'corny', 'cut-and-dried', 'doubled', 'duplicated', 'echoed', 'electric-heated'],
    'warmhearted': ['christian', 'christlike', 'christly', 'affectionate', 'amiable', 'ardent', 'benign', 'benignant', 'bleeding', 'brotherly', 'charitable', 'clement'],
    'warming': ['beating', 'burning', 'calefacient', 'calefaction', 'calefactive', 'calefactory', 'cauterant', 'chafing', 'cooking', 'debacle', 'defeasance', 'dielectric heating'],
    'warmly': ['agreeably', 'amiably', 'amicably', 'ardently', 'arm in arm', 'benignantly', 'benignly', 'breathlessly', 'congenially', 'cordially', 'effectively', 'eloquently'],
    'warmongering': ['aggression', 'aggressiveness', 'antagonism', 'bellicism', 'bellicosity', 'belligerence', 'belligerency', 'chauvinism', 'combativeness', 'contentiousness', 'ferocity', 'fierceness'],
    'warmth': ['abandon', 'activity', 'affectionateness', 'amiability', 'animal heat', 'animation', 'ardency', 'ardor', 'benignancy', 'benignity', 'blood heat', 'blush'],
    'warn': ['admonish', 'advise', 'alarm', 'alert', 'apprehend', 'apprise', 'arouse', 'ask', 'ask for', 'be imminent', 'blackmail', 'bludgeon'],
    'warning': ['admonishing', 'admonition', 'admonitory', 'advice', 'advising', 'advisory', 'advocacy', 'alerting', 'augural', 'blackmail', 'briefing', 'bulldozing'],
    'warp': ['a thing for', 'aberrancy', 'aberration', 'adulterate', 'affinity', 'alloy', 'alter', 'ameliorate', 'anamorphism', 'anamorphosis', 'animus', 'aptitude'],
    'warp and woof': ['anatomy', 'architectonics', 'architecture', 'arrangement', 'braiding', 'build', 'building', 'composition', 'conformation', 'constitution', 'construction', 'creation'],
    'warpath': ['aggression', 'aggressiveness', 'antagonism', 'bellicism', 'bellicosity', 'belligerence', 'belligerency', 'chauvinism', 'combativeness', 'contentiousness', 'ferocity', 'fierceness'],
    'warped': ['abandoned', 'affected', 'anamorphous', 'antiblack', 'apocryphal', 'artificial', 'askew', 'assumed', 'asymmetric', 'bastard', 'bent', 'biased'],
    'warrant': ['bible oath', 'cd', 'iou', 'john hancock', 'mo', 'ok', 'accept', 'acceptance', 'acceptance bill', 'account for', 'accredit', 'acknowledge'],
    'warrant officer': ['nco', 'acting corporal', 'acting sergeant', 'admiral', 'captain', 'centurion', 'chief petty officer', 'chief warrant officer', 'color sergeant', 'commander', 'commodore', 'corporal'],
    'warrantable': ['admissible', 'allowable', 'balanced', 'condonable', 'defensible', 'deserved', 'dispensable', 'due', 'equitable', 'even', 'evenhanded', 'excusable'],
    'warranted': ['accepted', 'acknowledged', 'admitted', 'affianced', 'affirmed', 'alleged', 'allowed', 'announced', 'approved', 'ascertained', 'asserted', 'asseverated'],
    'warranty': ['affidavit', 'assurance', 'attestation', 'authority', 'authorization', 'avouch', 'avouchment', 'bail', 'bill of health', 'bond', 'certificate', 'certificate of proficiency'],
    'warren': ['augean stables', 'hydra', 'abri', 'antre', 'bunker', 'burrow', 'cave', 'cavern', 'cove', 'dugout', 'dump', 'foxhole'],
    'warring': ['aggressive', 'ajar', 'all-out war', 'antagonistic', 'appeal to arms', 'armed combat', 'armed conflict', 'attack', 'battle', 'battling', 'bellicose', 'belligerence'],
    'warrior': ['amazon', 'air serviceman', 'brave', 'cannon fodder', 'fighter', 'fighting man', 'food for powder', 'halberdier', 'hoplite', 'legionary', 'man-at-arms', 'military man'],
    'wart': ['lilliputian', 'tom thumb', 'bantam', 'banty', 'benign tumor', 'bilge', 'birthmark', 'blackhead', 'blain', 'bleb', 'blemish', 'blister'],
    'wartime': ['all-out war', 'appeal to arms', 'armed combat', 'armed conflict', 'attack', 'battle', 'belligerence', 'belligerency', 'bloodshed', 'combat', 'fighting', 'hostilities'],
    'wary': ['argus-eyed', 'machiavellian', 'machiavellic', 'pyrrhonic', 'scotch', 'acute', 'agnostic', 'all ears', 'all eyes', 'arch', 'artful', 'astute'],
    'wash': ['ablution', 'abstergent', 'acrylic painting', 'apply paint', 'aquarelle', 'babble', 'backwash', 'baptize', 'bath', 'bathe', 'baygall', 'be consistent'],
    'wash down': ['bib', 'booze', 'drain the cup', 'drink', 'drink in', 'drink off', 'drink to', 'drink up', 'guzzle', 'imbibe', 'pledge', 'pull'],
    'wash out': ['achromatize', 'baptize', 'bath', 'bathe', 'blanch', 'bleach', 'bust', 'cashier', 'cast', 'decolor', 'decolorize', 'dim'],
    'washbasin': ['aquamanile', 'automatic dishwasher', 'basin', 'bath', 'bathtub', 'bidet', 'dishpan', 'dishwasher', 'ewer', 'finger bowl', 'kitchen sink', 'lavabo'],
    'washboard': ['tarmac', 'tarvia', 'asphalt', 'bitumen', 'bituminous macadam', 'blacktop', 'brick', 'broken ground', 'broken water', 'cement', 'chop', 'cobble'],
    'washed out': ['achromatic', 'achromic', 'all in', 'anemic', 'ashen', 'ashy', 'blanched', 'bleached', 'bleary', 'bled white', 'bloodless', 'cadaverous'],
    'washed up': ['sol', 'all bets off', 'all in', 'all off', 'all over', 'all up', 'at an end', 'beat', 'beat up', 'beaten', 'bone-weary', 'bushed'],
    'washer': ['aquamanile', 'automatic dishwasher', 'basin', 'bath', 'bathtub', 'bidet', 'dishpan', 'dishwasher', 'dishwiper', 'dry cleaner', 'ewer', 'finger bowl'],
    'washing': ['ablution', 'bear raid', 'bull raid', 'cleaning out', 'corner', 'corner in', 'douche', 'douching', 'elution', 'elutriation', 'enema', 'flush'],
    'washing machine': ['aquamanile', 'automatic dishwasher', 'basin', 'bath', 'bathtub', 'bidet', 'dishpan', 'dishwasher', 'ewer', 'finger bowl', 'kitchen sink', 'lavabo'],
    'washingtonese': ['varietyese', 'wall streetese', 'bunkum', 'business english', 'businessese', 'cinemese', 'collegese', 'commercialism', 'computerese', 'economese', 'federalese', 'gobbledygook'],
    'washout': ['ablution', 'airmanship', 'alluvion', 'alluvium', 'also-ran', 'bankrupt', 'bollix', 'bomb', 'botch', 'breakdown', 'breaking up', 'breakup'],
    'washroom': ['wc', 'backhouse', 'bagnio', 'balneae', 'balneum', 'basement', 'bath', 'bathhouse', 'bathroom', 'baths', 'caldarium', 'can'],
    'washstand': ['aquamanile', 'automatic dishwasher', 'basin', 'bath', 'bathtub', 'bidet', 'dishpan', 'dishwasher', 'ewer', 'finger bowl', 'kitchen sink', 'lavabo'],
    'wasp': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'wasp waisted': ['airy', 'attenuate', 'attenuated', 'boyish', 'clamped', 'compressed', 'concentrated', 'condensed', 'consolidated', 'constricted', 'contracted', 'cramped'],
    'waspish': ['bearish', 'bitchy', 'cankered', 'cantankerous', 'churlish', 'contrary', 'crabbed', 'cranky', 'cross', 'cross-grained', 'crotchety', 'crusty'],
    'wassail': ['bacchanal', 'bacchanalia', 'bacchanalian', 'bat', 'bender', 'binge', 'bout', 'bust', 'carousal', 'carouse', 'celebration', 'compotation'],
    'waste': ['arabia deserta', 'death valley', 'sahara', 'abate', 'ablate', 'ablation', 'absorption', 'acarpous', 'afterglow', 'afterimage', 'arid', 'assimilation'],
    'waste away': ['sanforize', 'abate', 'ablate', 'absorb', 'age', 'assimilate', 'atomize', 'atrophy', 'attenuate', 'bate', 'be consumed', 'be eaten away'],
    'waste time': ['beguile the time', 'burn daylight', 'consume time', 'dabble', 'dally', 'dawdle', 'delay', 'diddle', 'dillydally', 'doodle', 'drag', 'falter'],
    'wasted': ['sanforized', 'ablated', 'acarpous', 'arid', 'atrophied', 'attenuated', 'ausgespielt', 'bankrupt', 'barren', 'blasted', 'blighted', 'brittle'],
    'wasteful': ['baneful', 'calamitous', 'cataclysmal', 'cataclysmic', 'catastrophic', 'consuming', 'consumptive', 'deadly', 'demolishing', 'demolitionary', 'depredatory', 'desolating'],
    'wasteland': ['arabia deserta', 'death valley', 'sahara', 'back country', 'backwoods', 'barren', 'barren land', 'barrens', 'boondock', 'boondocks', 'borderland', 'brush'],
    'wasting': ['sanforizing', 'abscess', 'aging', 'ague', 'anemia', 'ankylosis', 'anoxia', 'apnea', 'asphyxiation', 'asthma', 'ataxia', 'atrophy'],
    'wastrel': ['arab', 'bowery bum', 'bad lot', 'beach bum', 'beachcomber', 'beggar', 'beggarly fellow', 'big-time spender', 'black sheep', 'blackguard', 'blighter', 'bo'],
    'watch': ['argus', 'big ben', 'charley', 'abide', 'airplane spotter', 'alarm clock', 'alarm watch', 'anchor watch', 'and listen', 'animadvert', 'appear', 'assister'],
    'watch out': ['and listen', 'attend to business', 'be alert', 'be obsessed with', 'be vigilant', 'be watchful', 'beware', 'concentrate on', 'fix on', 'focus on', 'give heed', 'have a care'],
    'watch out for': ['attend to', 'baby-sit', 'calculate on', 'care for', 'chaperon', 'cherish', 'conserve', 'count on', 'forestall', 'foster', 'keep watch over', 'look after'],
    'watchdog': ['cerberus', 'seeing eye dog', 'bandog', 'bitch', 'bowwow', 'canine', 'cerberus', 'clanger', 'custos', 'dog', 'fancy dog', 'guard dog'],
    'watcher': ['argus', 'charley', 'tv-viewer', 'airplane spotter', 'beholder', 'bird-watcher', 'bystander', 'drugstore cowboy', 'eyewitness', 'fire patrolman', 'fire warden', 'fireguard'],
    'watchful': ['argus-eyed', 'advertent', 'agog', 'alert', 'all ears', 'all eyes', 'assiduous', 'attentive', 'aux aguets', 'aware', 'careful', 'cautious'],
    'watchful eye': ['x-ray eye', 'cover', 'custodianship', 'custody', 'defense', 'eagle eye', 'eye', 'gimlet eye', 'guard', 'guardedness', 'guardianship', 'invigilation'],
    'watchman': ['argus', 'charley', 'airplane spotter', 'fire patrolman', 'fire warden', 'fireguard', 'forward observer', 'lookout', 'lookout man', 'night watchman', 'patrol', 'patroller'],
    'watchtower': ['texas tower', 'beacon', 'belvedere', 'bench mark', 'bleachers', 'bookmark', 'bridge', 'cairn', 'catstone', 'conning tower', 'gallery', 'gazebo'],
    'watchword': ['bugle call', 'byword', 'call to arms', 'call-up', 'catchword', 'clarion', 'clarion call', 'conscription', 'countersign', 'device', 'epigraph', 'epithet'],
    'water': ['april showers', 'bo', 'davy', 'davy jones', 'dylan', 'foamite', 'neptune', 'nereid', 'nereus', 'oceanid', 'oceanus', 'poseidon'],
    'water carrier': ['aquarius', 'cloudcuckooland', 'ganymede', 'hebe', 'alto-cumulus', 'alto-stratus', 'anvil cloud', 'aqueduct', 'arroyo', 'banner cloud', 'bearer', 'bed'],
    'water closet': ['wc', 'backhouse', 'basement', 'bathroom', 'bedpan', 'can', 'chamber', 'chamber pot', 'chemical closet', 'chemical toilet', 'closet', 'comfort station'],
    'water gate': ['aboideau', 'air lock', 'aqueduct', 'arroyo', 'bed', 'canal', 'creek bed', 'culvert', 'dock gate', 'donga', 'dry bed', 'flood-hatch'],
    'water god': ['davy', 'davy jones', 'dylan', 'neptune', 'nereid', 'nereus', 'oceanid', 'oceanus', 'poseidon', 'thetis', 'triton', 'varuna'],
    'water hole': ['artificial lake', 'bayou lake', 'cistern', 'dam', 'dead water', 'dike', 'etang', 'farm pond', 'fishpond', 'freshwater lake', 'glacial lake', 'inland sea'],
    'water sprite': ['davy', 'davy jones', 'neptune', 'nereid', 'oceanid', 'oceanus', 'poseidon', 'thetis', 'triton', 'fresh-water nymph', 'kelpie', 'limniad'],
    'water vapor': ['afterdamp', 'agua', 'aqua', 'blackdamp', 'breath', 'chokedamp', 'cloud', 'damp', 'drinking water', 'eau', 'effluvium', 'exhalation'],
    'water wings': ['mae west', 'breeches buoy', 'buoy', 'cork jacket', 'ejection capsule', 'ejection seat', 'ejector seat', 'life belt', 'life buoy', 'life jacket', 'life net', 'life preserver'],
    'water witch': ['comus', 'faust', 'conjurer', 'diabolist', 'diviner', 'divining rod', 'doodlebug', 'dowser', 'dowsing', 'dowsing rod', 'miracle-worker', 'necromancer'],
    'watercourse': ['adolescent stream', 'aqueduct', 'arroyo', 'beck', 'bed', 'bourn', 'braided stream', 'branch', 'brook', 'brooklet', 'burn', 'canal'],
    'watercraft': ['aircraft', 'argosy', 'bark', 'boat', 'bottom', 'bucket', 'carriage', 'carrier', 'conveyance', 'craft', 'hooker', 'hulk'],
    'watered down': ['abated', 'ablated', 'adulterated', 'airy', 'attenuate', 'attenuated', 'bated', 'belittled', 'boyish', 'consumed', 'contracted', 'curtailed'],
    'waterfall': ['niagara', 'cascade', 'cataract', 'chute', 'collapse', 'comedown', 'crash', 'debacle', 'declension', 'declination', 'defluxion', 'descending'],
    'waterfowl': ['avifauna', 'baby bird', 'bird', 'bird of jove', 'bird of juno', 'bird of minerva', 'bird of night', 'bird of passage', 'bird of prey', 'birdie', 'birdlife', 'birdy'],
    'waterfront': ['bank', 'beach', 'berm', 'coast', 'coastland', 'coastline', 'embankment', 'foreshore', 'ironbound coast', 'lido', 'littoral', 'plage'],
    'watering': ['adulteration', 'affusion', 'aspergation', 'aspersion', 'baptism', 'bastardizing', 'bath', 'bathing', 'bedewing', 'contamination', 'corruption', 'cutting'],
    'watering can': ['aerosol', 'aspergil', 'aspergillum', 'atomizer', 'clyster', 'concentrate sprayer', 'douche', 'enema', 'fountain syringe', 'mist concentrate sprayer', 'needle bath', 'nozzle'],
    'watering place': ['bagnio', 'balneae', 'balneum', 'bar', 'barroom', 'bath', 'bathhouse', 'bathroom', 'baths', 'boozer', 'cabaret', 'cafe'],
    'waterless': ['saharan', 'anhydrous', 'arid', 'athirst', 'bone-dry', 'desert', 'droughty', 'dry', 'dry as dust', 'dusty', 'high and dry', 'juiceless'],
    'waterlogged': ['awash', 'bathed', 'deluged', 'dipped', 'drenched', 'dribbling', 'dripping', 'dripping wet', 'drowned', 'engulfed', 'flooded', 'immersed'],
    'waterloo': ['beating', 'collapse', 'conquering', 'conquest', 'crash', 'deathblow', 'debacle', 'defeat', 'destruction', 'downfall', 'drubbing', 'failure'],
    'watermark': ['plimsoll line', 'plimsoll mark', 'birthmark', 'blaze', 'blemish', 'blotch', 'brand', 'caste mark', 'check', 'checkmark', 'cicatrix', 'cut'],
    'waterproof': ['airtight', 'bold', 'close', 'compact', 'dampproof', 'dripproof', 'dustproof', 'dusttight', 'fast', 'fireproof', 'firm', 'fit for sea'],
    'waterskiing': ['australian crawl', 'aquaplaning', 'aquatics', 'backstroke', 'balneation', 'bathe', 'bathing', 'breaststroke', 'butterfly', 'crawl', 'diving', 'dog paddle'],
    'waterspout': ['baguio', 'beak', 'brash', 'burst of rain', 'cloudburst', 'cyclone', 'deluge', 'downfall', 'downflow', 'downpour', 'downspout', 'drencher'],
    'watertight': ['airtight', 'ballproof', 'bold', 'bombproof', 'bulletproof', 'burglarproof', 'close', 'compact', 'corrosionproof', 'dampproof', 'dripproof', 'dustproof'],
    'waterway': ['adolescent stream', 'approaches', 'aqueduct', 'arroyo', 'beck', 'bed', 'bourn', 'braided stream', 'branch', 'brook', 'brooklet', 'burn'],
    'waterworks': ['aqueduct', 'arroyo', 'bed', 'bleachworks', 'bottling works', 'brassworks', 'canal', 'copperworks', 'creek bed', 'culvert', 'donga', 'dry bed'],
    'watery': ['lenten', 'spartan', 'abstemious', 'airy', 'anemic', 'aquatic', 'aqueous', 'ascetic', 'attenuate', 'attenuated', 'austere', 'banal'],
    'wattage': ['amperage', 'armipotence', 'authority', 'beef', 'black power', 'brute force', 'charge', 'charisma', 'clout', 'cogence', 'cogency', 'compulsion'],
    'wattle': ['arabesque', 'basketry', 'basketwork', 'braid', 'cancellation', 'cross-hatching', 'crossing-out', 'enlace', 'entwine', 'filigree', 'fret', 'fretwork'],
    'wave': ['afro', 'accost', 'address', 'advertise', 'affect', 'air', 'ambages', 'amplitude', 'anfractuosity', 'antinode', 'barber', 'be poised'],
    'wavelength': ['amplitude', 'antinode', 'carrier', 'carrier wave', 'crest', 'de broglie wave', 'diffraction', 'electric wave', 'electromagnetic radiation', 'electromagnetic wave', 'frequency', 'frequency band'],
    'waver': ['alternate', 'back and fill', 'beat', 'beating', 'bicker', 'blench', 'bob', 'bobble', 'boggle', 'careen', 'change', 'coggle'],
    'wavering': ['adrift', 'aflicker', 'afloat', 'agnostic', 'alternating', 'alternation', 'ambiguous', 'amorphous', 'bickering', 'blinking', 'broken', 'capricious'],
    'waving': ['ambages', 'anfractuosity', 'brandish', 'brandishing', 'circuitousness', 'circumambages', 'circumbendibus', 'circumlocution', 'circumvolution', 'convolution', 'crinkle', 'crinkling'],
    'wavy': ['adrift', 'afloat', 'alternating', 'amorphous', 'bent', 'billowing', 'billowy', 'capricious', 'changeable', 'changeful', 'curvaceous', 'curvate'],
    'wax': ['accrue', 'accumulate', 'advance', 'aluminum oxide', 'ambergris', 'anoint', 'antifriction', 'appreciate', 'augment', 'auto polish', 'balloon', 'bear fruit'],
    'wax and wane': ['alternate', 'back and fill', 'battledore and shuttlecock', 'come and go', 'ebb and flow', 'flounder', 'fluctuate', 'go through phases', 'hitch and hike', 'oscillate', 'pass and repass', 'pendulate'],
    'waxen': ['achromatic', 'achromic', 'anemic', 'ashen', 'ashy', 'blanched', 'bled white', 'bloodless', 'cadaverous', 'chloranemic', 'colorless', 'dead'],
    'waxwork': ['bust', 'carving', 'doll', 'dolly', 'dummy', 'fantoccini', 'figure', 'figurehead', 'figurine', 'gingerbread man', 'lay figure', 'man of straw'],
    'way': ['ability', 'access', 'ache to', 'action', 'actions', 'activity', 'acts', 'address', 'adit', 'admission', 'advance', 'advancement'],
    'way out': ['bohemian', 'a la mode', 'a mile off', 'advanced', 'alternative', 'at the height', 'at the limit', 'avant-garde', 'avenue', 'away off', 'beat', 'blowhole'],
    'wayfare': ['bat around', 'bum', 'campaign', 'commute', 'count ties', 'course', 'cover ground', 'cruise', 'divagate', 'drift', 'fare', 'fare forth'],
    'wayfarer': ['adventurer', 'alpinist', 'astronaut', 'camper', 'climber', 'comers and goers', 'commuter', 'cosmopolite', 'cruiser', 'excursionist', 'explorer', 'fare'],
    'wayward': ['adamic', 'paphian', 'adrift', 'afloat', 'alternating', 'amorphous', 'arbitrary', 'backsliding', 'balky', 'cantankerous', 'capricious', 'carnal'],
    'wayworn': ['debilitated', 'drooping', 'droopy', 'dusty', 'enervated', 'enfeebled', 'fagged', 'faint', 'fainting', 'fatigued', 'feeling faint', 'flagging'],
    'wc': ['backhouse', 'basement', 'bathroom', 'can', 'closet', 'comfort station', 'convenience', 'crapper', 'earth closet', 'head', 'john', 'johnny'],
    'weak': ['adamic', 'adamite', 'adamitic', 'abulic', 'accented', 'accessible', 'achromatic', 'achromic', 'afraid', 'airy', 'alveolar', 'amenable'],
    'weak kneed': ['abulic', 'afraid', 'chicken', 'chickenhearted', 'coward', 'cowardly', 'cowed', 'daunted', 'dismayed', 'double-minded', 'faint', 'fainthearted'],
    'weak link': ['assailability', 'blemish', 'bug', 'catch', 'chink', 'crack', 'defect', 'defection', 'deficiency', 'drawback', 'failing', 'failure'],
    'weak minded': ['abulic', 'afraid', 'brainless', 'cowardly', 'faint', 'fainthearted', 'feeble', 'feebleminded', 'foolish', 'frail', 'infirm', 'invertebrate'],
    'weak point': ['argument', 'argument by analogy', 'argumentum ad baculum', 'argumentum ad captandum', 'argumentum ad hominem', 'assailability', 'bad case', 'bad habit', 'begging the question', 'besetting sin', 'blemish', 'bug'],
    'weak sister': ['lord fauntleroy', 'milquetoast', 'percy', 'baby', 'big baby', 'chicken', 'chicken liver', 'coward', 'cream puff', 'crybaby', 'doormat', 'dull tool'],
    'weaken': ['abate', 'afflict', 'aggravate', 'allay', 'alleviate', 'assuage', 'attemper', 'attenuate', 'bank the fire', 'bate', 'beat', 'blunt'],
    'weakened': ['abated', 'ablated', 'aggravated', 'attenuated', 'ausgespielt', 'bated', 'belittled', 'broken', 'burned', 'burned-out', 'burst', 'busted'],
    'weakening': ['abatement', 'abridgment', 'alleviation', 'attenuation', 'attrition', 'bankruptcy', 'blunting', 'breakage', 'breakdown', 'collapse', 'contraction', 'crack-up'],
    'weakhearted': ['afraid', 'chicken', 'chickenhearted', 'coward', 'cowardly', 'cowed', 'daunted', 'dismayed', 'fainthearted', 'fearful', 'funking', 'funky'],
    'weakling': ['milquetoast', 'baby', 'big baby', 'blank cartridge', 'butt', 'castrato', 'chicken', 'chicken liver', 'coward', 'crybaby', 'doormat', 'drip'],
    'weakly': ['a bit', 'a la sourdine', 'a little', 'anemic', 'asthenic', 'barely', 'bloodless', 'by a hair', 'by an ace', 'cachectic', 'chicken', 'cowardly'],
    'weakness': ['amor', 'christian love', 'eros', 'platonic love', 'a thing for', 'abulia', 'accessibility', 'admiration', 'adoration', 'affection', 'affinity', 'agape'],
    'weal': ['easy street', 'affluence', 'bed of roses', 'birthmark', 'blackhead', 'bleb', 'blemish', 'blister', 'bulla', 'check', 'cicatrix', 'clover'],
    'weald': ['alkali flat', 'alluvial plain', 'basin', 'bottomland', 'bushveld', 'campo', 'champaign', 'champaign country', 'coastal plain', 'delta', 'desert', 'down'],
    'wealth': ['easy street', 'abundance', 'affluence', 'ample sufficiency', 'ampleness', 'amplitude', 'assessed valuation', 'assets', 'assets and liabilities', 'avalanche', 'bed of roses', 'bonanza'],
    'wealthy': ['abounding', 'abounding in riches', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'big-rich', 'bottomless', 'bounteous', 'bountiful', 'comfortable'],
    'wean': ['alien', 'alienate', 'blunt', 'break of', 'bring over', 'chill', 'convince', 'cool', 'cure', 'damp', 'dampen', 'deflect'],
    'weapon': ['a-weapons', 'armament', 'arms', 'biological weapons', 'conventional weapons', 'cutting edge', 'deadly weapons', 'edge', 'edge tool', 'featheredge', 'instruments of destruction', 'knife-edge'],
    'wear': ['abate', 'abide', 'ablate', 'ablation', 'about ship', 'abrade', 'abrase', 'abrasion', 'abrasive', 'act a part', 'affect', 'apparel'],
    'wear and tear': ['ablation', 'atomization', 'attrition', 'breakup', 'consumption', 'corrosion', 'crumbling', 'decay', 'decomposition', 'decrement', 'degradation', 'deliquescence'],
    'wear away': ['abate', 'ablate', 'abrade', 'abrase', 'absorb', 'abstract', 'assimilate', 'atomize', 'bark', 'bate', 'be all over', 'be consumed'],
    'wear down': ['ablate', 'abrade', 'affect', 'argue into', 'beat', 'bend', 'bias', 'bring over', 'bring round', 'bring to reason', 'burn out', 'captivate'],
    'wear off': ['ablate', 'abrade', 'be all over', 'be no more', 'become extinct', 'become void', 'blow over', 'die', 'die away', 'erode', 'expire', 'fray'],
    'wear on': ['be infinitely repetitive', 'be tedious', 'beat', 'burn out', 'crawl', 'creep', 'debilitate', 'do in', 'do up', 'drag', 'drag along', 'drag on'],
    'wear out': ['ablate', 'abrade', 'beat', 'bugger', 'burden', 'burn out', 'crush one', 'debilitate', 'do in', 'do up', 'enervate', 'erode'],
    'wear thin': ['bomb', 'break', 'cave in', 'collapse', 'come apart', 'come unstuck', 'conk out', 'crumble', 'decline', 'disintegrate', 'droop', 'drop'],
    'wear well': ['abide', 'bide', 'bloom', 'burst with health', 'carry on', 'continue', 'continue to be', 'defeat time', 'defy time', 'dwell', 'endure', 'enjoy good health'],
    'weariness': ['acedia', 'adynamia', 'anemia', 'apathy', 'atony', 'blah feeling', 'bloodlessness', 'boredness', 'boredom', 'brain fag', 'bromidic', 'cachexia'],
    'wearing apparel': ['apparel', 'array', 'attire', 'bedizenment', 'clothes', 'clothing', 'costume', 'drapery', 'dress', 'dressing', 'duds', 'fashion'],
    'wearisome': ['herculean', 'aggravating', 'annoying', 'arduous', 'backbreaking', 'black', 'bleak', 'boresome', 'boring', 'bothering', 'bothersome', 'burdensome'],
    'weary': ['apathetic', 'be infinitely repetitive', 'be tedious', 'beat', 'benumbed', 'black', 'blase', 'bleak', 'blow', 'bored', 'break down', 'burden'],
    'wearying': ['boresome', 'boring', 'burdensome', 'draining', 'exhausting', 'fatiguesome', 'fatiguing', 'grinding', 'grueling', 'harsh', 'heavy', 'irksome'],
    'weasel': ['argus', 'cape polecat', 'skimobile', 'sno-cat', 'ape', 'avoid', 'back and fill', 'bar', 'bear', 'blade', 'blench', 'blink'],
    'weasel word': ['ambiguity', 'amphibology', 'counterword', 'dodging', 'double entendre', 'equivocal', 'equivocality', 'equivocation', 'equivoque', 'evasion', 'fencing', 'parrying'],
    'weather': ['ablate', 'abrade', 'be safe', 'be unflappable', 'beat the game', 'beat the system', 'bring to', 'calm weather', 'climate', 'clime', 'cold weather', 'come through'],
    'weather eye': ['x-ray eye', 'custodianship', 'custody', 'eagle eye', 'gimlet eye', 'guard', 'guardedness', 'guardianship', 'invigilation', 'keen eye', 'lookout', 'monitoring'],
    'weather map': ['lambert conformal projection', 'mercator projection', 'miller projection', 'aeronautical chart', 'air mass', 'anticyclone', 'astronomical chart', 'atlas', 'azimuthal projection', 'cartographer', 'cartography', 'celestial chart'],
    'weather the storm': ['be safe', 'be unflappable', 'beat the game', 'beat the system', 'bounce back', 'come around', 'come back', 'come round', 'come through', 'come to', 'come up fighting', 'come up smiling'],
    'weather vane': ['april showers', 'proteus', 'aerological instrument', 'anemograph', 'anemometer', 'anemometrograph', 'anemoscope', 'aneroid barometer', 'aneroidograph', 'barograph', 'barometer', 'barometrograph'],
    'weatherboard': ['beam', 'billet', 'board', 'boarding', 'brick', 'clapboard', 'cord', 'cordwood', 'deal', 'driftwood', 'face', 'firewood'],
    'weathercock': ['april showers', 'proteus', 'vicar of bray', 'anemograph', 'anemometer', 'anemometrograph', 'anemoscope', 'barometer', 'chameleon', 'cloud shapes', 'cock', 'feeler'],
    'weatherproof': ['airtight', 'ballproof', 'bombproof', 'bulletproof', 'burglarproof', 'corrosionproof', 'dampproof', 'fire-resisting', 'fireproof', 'flameproof', 'foolproof', 'hermetic'],
    'weave': ['anatomy', 'arabesque', 'architectonics', 'architecture', 'arrangement', 'basketry', 'basketwork', 'braid', 'braiding', 'build', 'building', 'cancellation'],
    'weaving': ['arabesque', 'basketry', 'basketwork', 'cancellation', 'cross-hatching', 'crossing-out', 'entwining', 'filigree', 'fret', 'fretwork', 'grate', 'grating'],
    'weazen': ['sanforize', 'air-dry', 'anhydrate', 'attenuate', 'bake', 'blot', 'brush', 'burn', 'consume', 'cure', 'dehumidify', 'dehydrate'],
    'weazened': ['sanforized', 'adust', 'attenuated', 'baked', 'burnt', 'consumed', 'corky', 'dehydrated', 'desiccated', 'dried', 'dried-up', 'emacerated'],
    'web': ['anatomy', 'animal fiber', 'arabesque', 'architectonics', 'architecture', 'arrangement', 'artificial fiber', 'basketry', 'basketwork', 'bed', 'braid', 'braiding'],
    'wed': ['affiliate', 'ally', 'apply', 'arrange a match', 'associate', 'band together', 'be in cahoots', 'be made one', 'be spliced', 'become one', 'bind', 'bracket'],
    'wedded': ['affiliate', 'affiliated', 'allied', 'assembled', 'associate', 'associated', 'banded together', 'bound', 'bracketed', 'bridal', 'cabalistic', 'collateral'],
    'wedding': ['anschluss', 'gretna green wedding', 'addition', 'affiliation', 'agglomeration', 'aggregation', 'agreement', 'alliance', 'amalgamation', 'assimilation', 'association', 'banns'],
    'wedge': ['arrowhead', 'articulate', 'batten', 'batten down', 'bed', 'bolt', 'buckle', 'butt', 'button', 'character', 'clasp', 'cleat'],
    'wedge in': ['admit', 'barge in', 'be admitted', 'break in', 'breeze in', 'burst in', 'bust in', 'come barging in', 'come breezing in', 'come busting in', 'come in', 'cram in'],
    'wedged': ['aground', 'anchored', 'bonded', 'caught', 'cemented', 'chained', 'close', 'fast', 'fastened', 'firm', 'fixed', 'glued'],
    'wedlock': ['a world-without-end bargain', 'alliance', 'bed', 'bond of matrimony', 'bridebed', 'cohabitation', 'conjugal bond', 'conjugal knot', 'coverture', 'holy matrimony', 'holy wedlock', 'husbandhood'],
    'weed': ['canada thistle', 'det', 'dmt', 'lsd', 'mary jane', 'stp', 'thc', 'abate', 'abrade', 'abstract', 'acid', 'amphibian'],
    'weed killer': ['acaricide', 'anthelmintic', 'antibiotic', 'antiseptic', 'bug bomb', 'carbamate insecticide', 'chemosterilant', 'contact poison', 'defoliant', 'disinfectant', 'eradicant', 'fumigant'],
    'weed out': ['abstract', 'avulse', 'backset', 'cast off', 'cast out', 'chuck', 'clear', 'clear away', 'clear out', 'clear the decks', 'cultivate', 'culture'],
    'weedy': ['botanic', 'bulbous', 'cereal', 'dense', 'exuberant', 'farinaceous', 'flourishing', 'fruitlike', 'fruity', 'gross', 'heavy', 'herbaceous'],
    'week': ['heptateuch', 'abundant year', 'academic year', 'annum', 'bissextile year', 'calendar month', 'calendar year', 'century', 'common year', 'day', 'decade', 'decennary'],
    'weekend': ['christmas', 'sunday', 'buy time', 'consume time', 'furlough', 'go on furlough', 'go on leave', 'holiday', 'keep time', 'kill time', 'leave', 'leave of absence'],
    'weekly': ['annual', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'daily newspaper', 'daybook', 'decennial'],
    'weenie': ['vienna sausage', 'bangers', 'black pudding', 'blood pudding', 'bologna', 'braunschweiger', 'frank', 'frankfurter', 'gooseliver', 'headcheese', 'hot dog', 'knockwurst'],
    'weep': ['bag', 'bawl', 'bemoan', 'bewail', 'bleed', 'blubber', 'boohoo', 'break down', 'burst into tears', 'cascade', 'condense', 'cry'],
    'weep for': ['be sorry for', 'bleed', 'bleed for', 'comfort', 'commiserate', 'compassionate', 'condole with', 'console', 'express sympathy for', 'feel for', 'feel sorrow for', 'feel sorry for'],
    'weeping': ['awash', 'bathed', 'bawling', 'blubbering', 'cascading', 'cry', 'crying', 'dangling', 'deluged', 'dependent', 'depending', 'dipped'],
    'weepy': ['blubbering', 'crying', 'dissolved in tears', 'excretory', 'exudative', 'in tears', 'lachrymal', 'lachrymose', 'lacrimatory', 'leaky', 'oozy', 'percolative'],
    'weevily': ['bad', 'barfy', 'blasted', 'blighted', 'blown', 'brackish', 'buggy', 'cloying', 'despoiled', 'fetid', 'flyblown', 'foul'],
    'weft': ['arabesque', 'basketry', 'basketwork', 'cancellation', 'cloth', 'cross-hatching', 'crossing-out', 'drapery', 'etoffe', 'fabric', 'felt', 'filigree'],
    'weigh': ['amount to something', 'analogize', 'appraise', 'appreciate', 'assay', 'assess', 'assimilate', 'balance', 'be abstracted', 'be featured', 'be heavy', 'be influential'],
    'weigh anchor': ['board', 'break ground', 'cast away', 'cast loose', 'cast off', 'cat the anchor', 'detach', 'disengage', 'doff', 'drop the mooring', 'embark', 'embus'],
    'weigh down': ['ballast', 'bear hard upon', 'burden', 'cramp', 'cripple', 'cumber', 'embarrass', 'encumber', 'enmesh', 'ensnarl', 'entangle', 'entoil'],
    'weigh upon': ['bear hard upon', 'bear on', 'bear upon', 'beat down', 'burden', 'burthen', 'cast down', 'charge', 'crush one', 'cumber', 'damp', 'dampen'],
    'weight': ['indian club', 'accent', 'affliction', 'amperage', 'armipotence', 'ascendancy', 'authoritativeness', 'authority', 'balance', 'ballast', 'barbell', 'be heavy'],
    'weighted down': ['burdened', 'charged', 'cumbered', 'encumbered', 'fraught', 'freighted', 'hampered', 'heavy', 'heavyhearted', 'laden', 'laden with sorrow', 'loaded'],
    'weightless': ['airy', 'bodiless', 'bubbly', 'downy', 'ethereal', 'featherweight', 'feathery', 'fluffy', 'foamy', 'frothy', 'gossamery', 'immaterial'],
    'weightlessness': ['airiness', 'ascent', 'asteroids', 'aurora particles', 'blackout', 'bubbliness', 'buoyancy', 'cosmic particles', 'cosmic ray bombardment', 'daintiness', 'delicacy', 'downiness'],
    'weighty': ['gargantuan', 'absolute', 'adducible', 'admissible', 'amplitudinous', 'ascendant', 'astronomical', 'attestative', 'attestive', 'authentic', 'authoritarian', 'authoritative'],
    'weir': ['aboideau', 'air lock', 'arch dam', 'avenue', 'backstop', 'bamboo curtain', 'bank', 'bar', 'barrage', 'barrier', 'bear-trap dam', 'beaver dam'],
    'weird': ['friday', 'friday the thirteenth', 'absurd', 'appointed lot', 'astral influences', 'astrology', 'awe-inspiring', 'awesome', 'awful', 'awing', 'beyond belief', 'bizarre'],
    'weird sisters': ['atropos', 'clotho', 'dame fortune', 'decuma', 'fata', 'fates', 'fortuna', 'heaven', 'lachesis', 'moirai', 'morta', 'nona'],
    'weirdo': ['aliene', 'bedlamite', 'borderline case', 'character', 'crackbrain', 'crackpot', 'crank', 'dement', 'demoniac', 'eccentric', 'energumen', 'erratic'],
    'welcome': ['abide by', 'accede', 'accept', 'acceptable', 'acceptance', 'accession', 'acclaim', 'accueil', 'acquiesce', 'acquiesce in', 'acquiescence', 'acquire'],
    'welcoming': ['admissible', 'admissive', 'admissory', 'amiable', 'cordial', 'friendly', 'generous', 'genial', 'gracious', 'hearty', 'hospitable', 'imbibitory'],
    'weld': ['accouple', 'accumulate', 'agglutinate', 'amass', 'ankle', 'articulate', 'articulation', 'assemble', 'associate', 'band', 'bind', 'blaze'],
    'welfare': ['adc', 'easy street', 'medicaid', 'medicare', 'advantage', 'affluence', 'aid', 'alimony', 'allotment', 'allowance', 'almsgiving', 'altruistic'],
    'welfare state': ['adc', 'medicaid', 'medicare', 'absolute monarchy', 'aristocracy', 'autarchy', 'autocracy', 'autonomy', 'child welfare', 'coalition government', 'colonialism', 'commonweal'],
    'welkin': ['caelus', 'aerosphere', 'air', 'atmosphere', 'azure', 'biosphere', 'blue sky', 'caelum', 'canopy', 'canopy of heaven', 'cerulean', 'cope'],
    'well': ['ably', 'abysm', 'abyss', 'acceptably', 'adeptly', 'adequately', 'adroitly', 'agilely', 'all right', 'all the way', 'altogether', 'amply'],
    'well done': ['daedalian', 'adept', 'adroit', 'apt', 'artistic', 'authoritative', 'bien cuit', 'bravura', 'brilliant', 'clean', 'clever', 'coordinated'],
    'well dressed': ['braw', 'chic', 'classy', 'clothes-conscious', 'cosmopolitan', 'dapper', 'dashing', 'dressed to advantage', 'dressed to kill', 'dressed up', 'elegant', 'en grande tenue'],
    'well fed': ['adipose', 'beefy', 'big-bellied', 'bloated', 'blowzy', 'bosomy', 'brawny', 'burly', 'buxom', 'chubby', 'chunky', 'corpulent'],
    'well fixed': ['abounding in riches', 'affluent', 'big-rich', 'comfortable', 'disgustingly rich', 'easy', 'fat', 'flush', 'frightfully rich', 'in funds', 'in the money', 'independent'],
    'well-advised': ['careful', 'circumspect', 'considerate', 'discreet', 'discriminating', 'discriminative', 'enlightened', 'judgmatic', 'judicial', 'judicious', 'politic', 'provident'],
    'well-balanced': ['assured', 'balanced', 'coequal', 'collected', 'commonsense', 'composed', 'confident', 'cool', 'coolheaded', 'coordinate', 'equal', 'equanimous'],
    'well-being': ['easy street', 'hygeia', 'abundance', 'acceptance', 'advantage', 'affluence', 'amusement', 'animal pleasure', 'avail', 'bed of roses', 'behalf', 'behoof'],
    'well-bred': ['blue-blooded', 'cultivated', 'cultured', 'full-blooded', 'genteel', 'gentle', 'gentlemanlike', 'gentlemanly', 'highborn', 'highbred', 'ladylike', 'of good breed'],
    'well-built': ['junoesque', 'able-bodied', 'adamantine', 'agreeable', 'amply endowed', 'assembled', 'athletic', 'becoming', 'bonny', 'braw', 'brawny', 'broad-shouldered'],
    'well-defined': ['clean-cut', 'clear', 'clear as crystal', 'clear as day', 'clear-cut', 'coherent', 'connected', 'consistent', 'conspicuous', 'crisp', 'crystal-clear', 'crystalline'],
    'well-disposed': ['acquiescent', 'advocating', 'agreeable', 'alacritous', 'amenable', 'amiable', 'amicable', 'approving', 'ardent', 'backing', 'beneficent', 'benevolent'],
    'well-groomed': ['anal', 'bandbox', 'braw', 'chic', 'chipper', 'classy', 'clothes-conscious', 'cosmopolitan', 'dapper', 'dashing', 'dinky', 'doggy'],
    'well-grounded': ['adamantine', 'admissible', 'authoritative', 'binding', 'bulky', 'calculable', 'cogent', 'confirmed', 'consistent', 'credible', 'deep-dyed', 'deep-engraven'],
    'well-kept': ['anal', 'conserved', 'dinky', 'intact', 'kept', 'neat', 'preserved', 'protected', 'saved', 'shipshape', 'sleek', 'slick'],
    'well-known': ['acclaimed', 'back-number', 'banal', 'bewhiskered', 'bromidic', 'celebrated', 'common', 'commonly known', 'commonplace', 'conspicuous', 'corny', 'current'],
    'well-liked': ['admired', 'adored', 'beloved', 'cherished', 'darling', 'dear', 'dearly beloved', 'esteemed', 'favored', 'favorite', 'held dear', 'loved'],
    'well-made': ['junoesque', 'adamantine', 'agreeable', 'amply endowed', 'assembled', 'becoming', 'bonny', 'braw', 'built', 'built for comfort', 'bulky', 'buxom'],
    'well-mannered': ['ceremonial', 'ceremonious', 'conventional', 'correct', 'courteous', 'decorous', 'genteel', 'good-mannered', 'hieratic', 'liturgic', 'mannerly', 'polite'],
    'well-meaning': ['agreeable', 'amiable', 'amicable', 'beneficent', 'benevolent', 'benign', 'benignant', 'brotherly', 'congenial', 'cooperative', 'favorable', 'fraternal'],
    'well-off': ['abounding in riches', 'affluent', 'big-rich', 'comfortable', 'disgustingly rich', 'do', 'easy', 'fat', 'flush', 'frightfully rich', 'in funds', 'in the money'],
    'well-planned': ['abounding', 'abundant', 'affluent', 'all-sufficing', 'ample', 'aplenty', 'bottomless', 'bounteous', 'bountiful', 'clever', 'copious', 'cunning'],
    'well-read': ['acquainted with', 'at home in', 'at home with', 'conversant with', 'familiar with', 'informed in', 'intimate with', 'master of', 'proficient in', 'strong in', 'up on', 'versed in'],
    'well-regulated': ['arranged', 'businesslike', 'formal', 'habitual', 'harmonious', 'in hand', 'methodical', 'normal', 'ordered', 'orderly', 'regular', 'routine'],
    'well-set': ['able-bodied', 'athletic', 'balanced', 'brawny', 'broad-shouldered', 'burly', 'coequal', 'confirmed', 'coordinate', 'deep-dyed', 'deep-engraven', 'deep-fixed'],
    'well-spoken': ['ciceronian', 'demosthenian', 'demosthenic', 'tullian', 'articulate', 'correct', 'eloquent', 'facund', 'felicitous', 'free-speaking', 'free-spoken', 'glib'],
    'well-thought-of': ['accepted', 'acclaimed', 'admired', 'admitted', 'adored', 'advocated', 'applauded', 'appreciated', 'approved', 'backed', 'creditable', 'cried up'],
    'well-timed': ['advantageous', 'advisable', 'appropriate', 'auspicious', 'becoming', 'befitting', 'congruous', 'convenient', 'decent', 'desirable', 'expedient', 'favorable'],
    'well-to-do': ['abounding in riches', 'affluent', 'big-rich', 'comfortable', 'disgustingly rich', 'easy', 'fat', 'flush', 'frightfully rich', 'in funds', 'in the money', 'independent'],
    'well-versed': ['abreast of', 'adept in', 'at home in', 'au courant', 'briefed', 'educated', 'enlightened', 'expert at', 'good at', 'handy at', 'informed', 'instructed'],
    'well-wisher': ['maecenas', 'abettor', 'acquaintance', 'admirer', 'advocate', 'aficionado', 'alter ego', 'angel', 'apologist', 'backer', 'best friend', 'bosom friend'],
    'well-worn': ['automatic', 'back-number', 'banal', 'bare', 'beaten', 'bewhiskered', 'bromidic', 'common', 'commonplace', 'constant', 'corny', 'cut-and-dried'],
    'wellspring': ['bonanza', 'cornucopia', 'font', 'fount', 'fountain', 'fountainhead', 'gold mine', 'headspring', 'headstream', 'headwater', 'inception', 'lode'],
    'welsh': ['back out', 'backpedal', 'backwater', 'crawfish out', 'cry off', 'default', 'disallow', 'dishonor', 'dodge', 'dog it', 'duck', 'duck duty'],
    'welsher': ['clock watcher', 'defaulter', 'delinquent', 'eye-servant', 'goldbrick', 'goldbricker', 'levanter', 'malingerer', 'nonpayer', 'old soldier', 'shirk', 'shirker'],
    'welt': ['abscess', 'aposteme', 'bash', 'bat', 'beading', 'bed sore', 'belt', 'bilge', 'binding', 'birthmark', 'blackhead', 'blain'],
    'welter': ['arsy-varsiness', 'bask', 'bend', 'blunder', 'careen', 'career', 'clutter', 'cower', 'cringe', 'crouch', 'falter', 'farrago'],
    'welterweight': ['chinese boxer', 'bantamweight', 'black belt', 'boxer', 'brown belt', 'bruiser', 'catchweight', 'featherweight', 'fighter', 'fisticuffer', 'flyweight', 'heavyweight'],
    'wen': ['benign tumor', 'birthmark', 'blackhead', 'bleb', 'blemish', 'blister', 'boil', 'bulla', 'bump', 'bunion', 'callosity', 'callus'],
    'wench': ['jane', 'jezebel', 'abigail', 'amah', 'au pair girl', 'ayah', 'babe', 'baby', 'bad woman', 'baggage', 'betweenmaid', 'biddy'],
    'werewolf': ['dracula', 'frankenstein', 'wolf-man', 'ape-man', 'bogey', 'bogeyman', 'bugaboo', 'bugbear', 'demon', 'devil', 'devil incarnate', 'fee-faw-fum'],
    'west': ['antarctic', 'arctic', 'austral', 'boreal', 'cardinal points', 'compass card', 'compass rose', 'degrees', 'east', 'eastbound', 'easter', 'easterly'],
    'westerly': ['euroclydon', 'tehuantepec wind', 'tehuantepecer', 'antarctic', 'arctic', 'austral', 'bise', 'boreal', 'east', 'east wind', 'eastbound', 'easter'],
    'western': ['antarctic', 'arctic', 'austral', 'boreal', 'east', 'eastbound', 'easterly', 'eastermost', 'eastern', 'easternmost', 'horse opera', 'hyperborean'],
    'westward': ['cardinal points', 'compass card', 'compass rose', 'degrees', 'east', 'eastward', 'half points', 'lubber line', 'north', 'northeast', 'northward', 'northwest'],
    'wet': ['scotch mist', 'apish', 'asinine', 'asperge', 'batty', 'bedew', 'befooled', 'beguiled', 'besotted', 'bespatter', 'besprinkle', 'blood rain'],
    'wet blanket': ['foamite', 'acid', 'automatic sprinkler', 'bore', 'buttonholer', 'carbon tet', 'carbon tetrachloride', 'carbon-dioxide foam', 'chill', 'cold water', 'crashing bore', 'crepehanger'],
    'wet nurse': ['aliment', 'amah', 'ayah', 'breast-feed', 'care for', 'cherish', 'coddle', 'cosset', 'cradle', 'cultivate', 'dry nurse', 'dry-nurse'],
    'wet suit': ['air cylinder', 'aqualung', 'aquascope', 'bathing suit', 'bathyscaphe', 'bathysphere', 'benthoscope', 'bikini', 'diving bell', 'diving boat', 'diving chamber', 'diving goggles'],
    'wetback': ['aussie', 'boche', 'canuck', 'chink', 'dp', 'guinea', 'hunk', 'hunkie', 'jerry', 'kraut', 'krauthead', 'mick'],
    'whack': ['approach', 'assay', 'attempt', 'bang', 'bash', 'bat', 'beating', 'belt', 'bid', 'biff', 'blow', 'bonk'],
    'whack down': ['blow down', 'blow over', 'bowl down', 'bowl over', 'bring down', 'bulldog', 'cast down', 'chop down', 'cut down', 'dash down', 'deck', 'down'],
    'whacked': ['all in', 'beat', 'beat up', 'beaten', 'bone-weary', 'bushed', 'dead', 'dead-and-alive', 'dead-tired', 'deadbeat', 'dog-tired', 'dog-weary'],
    'whacking': ['awful', 'banging', 'bumping', 'deadly', 'dreadful', 'fearful', 'frightful', 'horrible', 'howling', 'rousing', 'slapping', 'spanking'],
    'whale': ['loch ness monster', 'alevin', 'angle', 'bait the hook', 'baste', 'bastinado', 'beat', 'belabor', 'belt', 'benthon', 'benthos', 'birch'],
    'whaler': ['ab', 'ancient mariner', 'argonaut', 'dylan', 'flying dutchman', 'neptune', 'od', 'poseidon', 'varuna', 'able seaman', 'able-bodied seaman', 'angler'],
    'whaling': ['angling', 'banging', 'bumping', 'casting', 'colossal', 'dressing-down', 'enormous', 'fishery', 'fishing', 'fly fishing', 'gargantuan', 'gigantic'],
    'wham': ['bang', 'bash', 'bat', 'belt', 'biff', 'blast', 'bonk', 'boom', 'bump', 'burst', 'bust', 'clap'],
    'whammy': ['jonah', 'amulet', 'anathema', 'bad blood', 'bad influence', 'bad temper', 'bad will', 'ban', 'bedroom eyes', 'blasphemy', 'blighting glance', 'bring bad luck'],
    'wharf': ['anchorage', 'anchorage ground', 'basin', 'berth', 'breakwater', 'bulkhead', 'dock', 'dockage', 'dockyard', 'dry dock', 'embankment', 'groin'],
    'what for': ['ass-reaming', 'bawling-out', 'castigation', 'chastening', 'chastisement', 'chewing', 'condign punishment', 'correction', 'cussing-out', 'deserts', 'disciplinary measures', 'discipline'],
    'wheal': ['abscess', 'aposteme', 'bed sore', 'blain', 'bleb', 'blister', 'boil', 'bubo', 'bulla', 'bunion', 'canker', 'canker sore'],
    'wheat': ['bengal grass', 'english rye grass', 'italian rye grass', 'kentucky bluegrass', 'alfilaria', 'bamboo', 'barley', 'beach grass', 'beard grass', 'bent', 'bent grass', 'bird seed'],
    'wheedle': ['adulate', 'advocate', 'apply pressure', 'banter', 'beset', 'besiege', 'beslobber', 'beslubber', 'blandish', 'blarney', 'bug', 'buttonhole'],
    'wheedling': ['adulation', 'adulatory', 'allurement', 'bland', 'blandishing', 'blandishment', 'blarney', 'blarneying', 'bunkum', 'buttery', 'buttonholing', 'cajolement'],
    'wheel': ['bmoc', 'charybdis', 'ferris wheel', 'procrustean bed', 'airscrew', 'alternate', 'annular muscle', 'annulus', 'areola', 'arsis', 'association', 'aureole'],
    'wheel of fortune': ['april showers', 'chance', 'dame fortune', 'fortuna', 'fortune', 'friday', 'friday the thirteenth', 'lady luck', 'luck', 'proteus', 'appointed lot', 'astral influences'],
    'wheeler dealer': ['machiavellian', 'rasputin', 'svengali', 'vip', 'access', 'activist', 'bad influence', 'ball of fire', 'beaver', 'behind-the-scenes operator', 'big wheel', 'big-time operator'],
    'wheelhorse': ['conservative', 'democrat', 'labourite', 'republican', 'tammany man', 'tory', 'whig', 'bidet', 'carriage horse', 'cart horse', 'cavalry horse', 'draft horse'],
    'wheeling and dealing': ['agency', 'barter', 'bartering', 'brokerage', 'buying and selling', 'dealing', 'doing business', 'exchange', 'give-and-take', 'horse trading', 'interchange', 'jobbing'],
    'wheels': ['action', 'auto', 'autocar', 'automobile', 'boat', 'buggy', 'bus', 'car', 'clockworks', 'crate', 'drive train', 'gear'],
    'wheels within wheels': ['chinese puzzle', 'gordian knot', 'rube goldberg contraption', 'action', 'can of worms', 'clockworks', 'complex', 'drive train', 'gear', 'innards', 'jungle', 'knot'],
    'wheeze': ['aqua-lung', 'antic', 'artificial respiration', 'aspiration', 'assibilate', 'assibilation', 'asthmatic wheeze', 'belly laugh', 'blow', 'blue story', 'break down', 'breath'],
    'wheezing': ['asthmatic', 'breathing', 'breathless', 'effervescent', 'errhine', 'expiratory', 'fizzling', 'heaving', 'hissing', 'huffing', 'hushing', 'inspiratory'],
    'whelk': ['dungeness crab', 'japanese crab', 'abscess', 'aposteme', 'bed sore', 'blain', 'bleb', 'blister', 'blue point', 'boil', 'bubo', 'bulla'],
    'whelm': ['baptize', 'be prodigal with', 'blank', 'bulldoze', 'bury', 'cascade', 'cataract', 'clobber', 'cream', 'defeat utterly', 'deluge', 'dip'],
    'whelp': ['seeing eye dog', 'animal', 'bandog', 'be confined', 'bear', 'bear a child', 'bear young', 'beast', 'birdling', 'bitch', 'bowwow', 'boy'],
    'when': ['after all', 'again', 'albeit', 'all the same', 'although', 'anon', 'as far as', 'as long as', 'at all events', 'at any rate', 'at what time', 'at which'],
    'whence': ['accordingly', 'away', 'because of that', 'because of this', 'consequently', 'derivation', 'ergo', 'for that', 'for that cause', 'for that reason', 'for this cause', 'for this reason'],
    'whenever': ['anytime', 'at any time', 'at what time', 'at whatever time', 'at which', 'at which time', 'if ever', 'in what period', 'in which time', 'no matter when', 'on what occasion', 'on which occasion'],
    'whereabouts': ['abode', 'area', 'bearings', 'bench mark', 'district', 'emplacement', 'hole', 'in what place', 'in which place', 'latitude and longitude', 'lieu', 'locale'],
    'whereas': ['albeit', 'although', 'as', 'as far as', 'as long as', 'as things go', 'at which time', 'because', 'being as how', 'boundary condition', 'catch', 'cause'],
    'wherefore': ['accordingly', 'after all', 'after which', 'all things considered', 'argument', 'because of that', 'because of this', 'before the bench', 'before the court', 'ceteris paribus', 'consequently', 'considering'],
    'whereupon': ['after which', 'at what time', 'at which', 'at which time', 'hereinafter', 'in what period', 'in which time', 'on', 'on what occasion', 'on which occasion', 'upon', 'upon which'],
    'wherewithal': ['swiss bank account', 'ability', 'and pence', 'assets', 'balance', 'bank account', 'bottom dollar', 'budget', 'capacity', 'capital', 'cash', 'cash reserves'],
    'whet': ['accelerate', 'aculeate', 'acuminate', 'aggravate', 'agitate', 'animate', 'antepast', 'antipasto', 'aperitif', 'appetizer', 'arouse', 'awaken'],
    'whey': ['beverage', 'blood', 'butter', 'buttermilk', 'certified milk', 'cheese', 'condensed milk', 'cream', 'dairy products', 'drink', 'fluid', 'fluid extract'],
    'whiff': ['aroma', 'blast', 'blow', 'blow a hurricane', 'blow great guns', 'blow over', 'blow up', 'bluster', 'bomb', 'breath', 'breath of air', 'breathe'],
    'whiffet': ['a nobody', 'a nothing', 'breath', 'breath of air', 'capful of wind', 'cipher', 'common man', 'dummy', 'figurehead', 'flatus', 'insignificancy', 'jackstraw'],
    'whig': ['conservative', 'democrat', 'labourite', 'republican', 'tory', 'heeler', 'loyalist', 'partisan', 'party faithful', 'party hack', 'party man', 'party member'],
    'while': ['albeit', 'although', 'amuse', 'as far as', 'as long as', 'at which time', 'beguile', 'bit', 'brighten', 'chronology', 'continuity', 'day'],
    'while away': ['bestow', 'consecrate to', 'consume', 'dally away', 'dedicate to', 'devote', 'diddle away', 'dribble away', 'drivel away', 'employ', 'expend', 'fool away'],
    'whim': ['apparition', 'bee', 'boutade', 'brainchild', 'brainstorm', 'bubble', 'capriccio', 'caprice', 'chimera', 'conceit', 'crank', 'craze'],
    'whim wham': ['a continental', 'a curse', 'a damn', 'a darn', 'a hoot', 'agate', 'bagatelle', 'ball', 'baseball bat', 'bat', 'battledore', 'bauble'],
    'whimper': ['bawl', 'blubber', 'boohoo', 'break down', 'burst into tears', 'cry', 'dissolve in tears', 'dolorous tirade', 'drop a tear', 'greet', 'groan', 'howl'],
    'whimpering': ['jeremianic', 'bawling', 'blubbering', 'complaining', 'cry', 'crying', 'dissolved in tears', 'faultfinding', 'fit of crying', 'flood of tears', 'fretful', 'good cry'],
    'whimsical': ['attic', 'gothic', 'abnormal', 'absurd', 'adrift', 'afloat', 'agnostic', 'alternating', 'ambiguous', 'amorphous', 'amusing', 'anomalous'],
    'whimsy': ['aberration', 'abnormality', 'anomaly', 'apparition', 'boutade', 'brainchild', 'brainstorm', 'bubble', 'capriccio', 'caprice', 'chimera', 'conceit'],
    'whine': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'blubber', 'boom', 'bray'],
    'whiner': ['bellyacher', 'complainant', 'complainer', 'crab', 'crank', 'croaker', 'faultfinder', 'frondeur', 'griper', 'grouch', 'grouser', 'growler'],
    'whining': ['jeremianic', 'acute', 'argute', 'bawling', 'beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'blatant', 'complaining'],
    'whinny': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'bray', 'call', 'caterwaul'],
    'whip': ['ferris wheel', 'jehu', 'mp', 'member of congress', 'member of parliament', 'accelerate', 'aerate', 'agitate', 'alderman', 'assemblyman', 'avert', 'bang'],
    'whip hand': ['advantage', 'ascendance', 'ascendancy', 'authority', 'balance of power', 'bulge', 'charisma', 'charm', 'clout', 'coign of vantage', 'consequence', 'control'],
    'whip up': ['abduct', 'ad-lib', 'agitate', 'annoy', 'arouse', 'awake', 'awaken', 'beat', 'beat up', 'blow the coals', 'blow up', 'call forth'],
    'whiplash': ['belt', 'blacksnake', 'bullwhack', 'bullwhip', 'cat', 'cowhide', 'crop', 'flagellum', 'gad', 'gadfly', 'goad', 'horsewhip'],
    'whipped': ['all up with', 'beat', 'beaten', 'bested', 'blebby', 'blistered', 'blistering', 'blistery', 'bubbling', 'bubbly', 'burbling', 'burbly'],
    'whippersnapper': ['jd', 'a nobody', 'a nothing', 'boldface', 'brat', 'brazenface', 'chutzpanik', 'cipher', 'common man', 'dummy', 'elf', 'enfant terrible'],
    'whipping': ['waterloo', 'bastinado', 'basting', 'battery', 'beating', 'belting', 'buffeting', 'caning', 'clubbing', 'collapse', 'conquering', 'conquest'],
    'whir': ['angular momentum', 'angular motion', 'angular velocity', 'axial motion', 'birr', 'bombilate', 'bombinate', 'boom', 'bowling', 'bum', 'burr', 'buzz'],
    'whirl': ['charybdis', 'maelstrom', 'sunday drive', 'ado', 'advance', 'agitation', 'airing', 'ascend', 'avert', 'back', 'back stream', 'back up'],
    'whirligig': ['april showers', 'ferris wheel', 'proteus', 'carousel', 'chameleon', 'chute-the-chutes', 'chutes', 'cloud shapes', 'disk', 'flying horses', 'gyrate', 'gyre'],
    'whirling': ['angular momentum', 'angular motion', 'angular velocity', 'axial motion', 'bowling', 'centrifugation', 'circulation', 'circumgyration', 'circumrotation', 'full circle', 'gyrating', 'gyration'],
    'whirlpool': ['charybdis', 'maelstrom', 'ado', 'back stream', 'backflow', 'backwash', 'backwater', 'bustle', 'centrifugate', 'centrifuge', 'countercurrent', 'counterflow'],
    'whirlpool bath': ['finnish bath', 'japanese bath', 'russian bath', 'swedish bath', 'turkish bath', 'bath', 'bathe', 'cold shower', 'douche', 'facial', 'facial massage', 'hip bath'],
    'whirlwind': ['charybdis', 'ado', 'baguio', 'blaze', 'burst', 'bustle', 'convulsion', 'cyclone', 'dizzy round', 'dust devil', 'eddy', 'eruption'],
    'whirly': ['circumgyratory', 'circumvolutory', 'cyclonic', 'gulfy', 'gyral', 'gyrational', 'gyratory', 'gyrostatic', 'rotary', 'rotational', 'rotatory', 'swirly'],
    'whish': ['assibilate', 'assibilation', 'bullet', 'buzz', 'crinkle', 'effervesce', 'effervescence', 'effervescing', 'fizz', 'fizzle', 'fizzling', 'fleet'],
    'whisk': ['aerate', 'agitate', 'agitator', 'ball the jack', 'barrel', 'beak', 'bear', 'beat', 'beat up', 'beater', 'boom', 'bowl along'],
    'whiskey': ['angostura bitters', 'canadian', 'canadian whiskey', 'cognac', 'grand champagne', 'irish', 'irish whiskey', 'kirsch', 'scotch', 'scotch whiskey', 'absinthe', 'bitters'],
    'whisper': ['advice', 'alert', 'alerting', 'articulate', 'aspirate', 'aspiration', 'bark', 'bated breath', 'bawl', 'bellow', 'blare', 'blat'],
    'whispering': ['aspiration', 'bated breath', 'breath', 'breathy voice', 'buzz', 'cry', 'drone', 'droning', 'exhalation', 'gabble', 'gibber', 'gibbering'],
    'whispering campaign': ['aspersion', 'character assassination', 'dirt', 'dirty politics', 'gossip column', 'imputation', 'innuendo', 'insinuation', 'juicy morsel', 'last-minute lie', 'malicious gossip', 'muckraking'],
    'whistle': ['angelus', 'angelus bell', 'english horn', 'klaxon', 'mayday', 'pandean pipe', 'sos', 'air-raid alarm', 'alarm', 'alarm bell', 'alarm clock', 'alarm signal'],
    'whistle blower': ['betrayer', 'blab', 'blabber', 'blabberer', 'blabbermouth', 'delator', 'fink', 'informer', 'narc', 'peacher', 'snitch', 'snitcher'],
    'whistle for': ['apply for', 'ask', 'ask for', 'beg leave', 'bespeak', 'call for', 'crave', 'demand', 'desire', 'file for', 'indent', 'make a request'],
    'whistling': ['acute', 'argute', 'assibilation', 'buzz', 'creaky', 'ear-piercing', 'effervescence', 'effervescing', 'fizz', 'fizzle', 'fizzling', 'frication'],
    'whit': ['ace', 'atom', 'bit', 'dab', 'damn', 'dole', 'dot', 'dram', 'dribble', 'driblet', 'dwarf', 'farthing'],
    'white': ['american indian', 'amerind', 'australian aborigine', 'bourbon', 'bushman', 'caucasian', 'chinese white', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo'],
    'white corpuscle': ['rh factor', 'rh-negative', 'rh-positive', 'rh-type', 'rhesus factor', 'antibody', 'antigen', 'arterial blood', 'blood', 'blood bank', 'blood cell', 'blood count'],
    'white elephant': ['christmas present', 'award', 'birthday present', 'box', 'burden', 'burthen', 'cadeau', 'cargo', 'charge', 'cross', 'cumbrance', 'deadweight'],
    'white feather': ['milquetoast', 'baby', 'big baby', 'chicken', 'chicken heart', 'chicken liver', 'cold feet', 'coward', 'faintheart', 'fraid-cat', 'fraidy-cat', 'funk'],
    'white flag': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'beacon', 'beacon fire', 'bell', 'bell buoy', 'blinker', 'blue peter', 'buoy'],
    'white goods': ['appliances', 'brassware', 'chinaware', 'clayware', 'copperware', 'dinnerware', 'dry goods', 'durable goods', 'durables', 'earthenware', 'enamelware', 'fixtures'],
    'white hot': ['abandoned', 'afire', 'ardent', 'baking', 'blazing', 'blistering', 'boiling', 'broiling', 'burning', 'burning hot', 'canicular', 'committed'],
    'white house': ['dymaxion house', 'adobe house', 'building', 'casa', 'cliff dwelling', 'consulate', 'country house', 'country seat', 'dacha', 'deanery', 'dwelling house', 'edifice'],
    'white lie': ['blague', 'cock-and-bull story', 'exaggeration', 'fairy tale', 'falsehood', 'falsity', 'farfetched story', 'farrago', 'fib', 'fiction', 'fish story', 'flam'],
    'white man': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'white paper': ['congressional record', 'hansard', 'red book', 'account', 'acquaintance', 'announcement', 'annunciation', 'blue book', 'briefing', 'bulletin', 'bulletin board', 'circular'],
    'white slave': ['b-girl', 'cyprian', 'paphian', 'call girl', 'daughter of joy', 'erring sister', 'fallen woman', 'fille de joie', 'harlot', 'hooker', 'hustler', 'meretrix'],
    'white slavery': ['cosa nostra', 'mafia', 'black market', 'bootlegging', 'gambling', 'gray market', 'illegal commerce', 'illegal operations', 'illegitimate business', 'illicit business', 'loan-sharking', 'moonshining'],
    'white water': ['breakers', 'collar', 'foam', 'froth', 'head', 'lather', 'meringue', 'mousse', 'offscum', 'puff', 'scud', 'scum'],
    'whitecaps': ['billow', 'bore', 'breakers', 'chop', 'choppiness', 'chopping sea', 'comb', 'comber', 'dirty water', 'eagre', 'gravity wave', 'ground swell'],
    'whiten': ['achromatize', 'besnow', 'blanch', 'bleach', 'bleach out', 'blench', 'blush', 'bowdlerize', 'chalk', 'change color', 'clean', 'clean out'],
    'whitening': ['achromatization', 'albification', 'blanching', 'bleach', 'bleaching', 'calcimine', 'decoloration', 'decolorization', 'decolorizing', 'discoloration', 'etiolation', 'fading'],
    'whitewash': ['absolve', 'acquit', 'allow for', 'allowance', 'amnesty', 'apply paint', 'becloud', 'bedaub', 'bedizen', 'befog', 'begild', 'belie'],
    'whitewashing': ['albification', 'allowance', 'blanching', 'bleaching', 'calcimining', 'clobbering', 'coating', 'color', 'covering', 'crushing defeat', 'decisive defeat', 'decontamination'],
    'whitey': ['american indian', 'amerind', 'australian aborigine', 'bushman', 'caucasian', 'indian', 'malayan', 'mister charley', 'mongolian', 'negrillo', 'negrito', 'negro'],
    'whitsuntide': ['advent', 'allhallowmas', 'allhallows', 'allhallowtide', 'annunciation', 'annunciation day', 'ascension day', 'ash wednesday', 'candlemas', 'candlemas day', 'carnival', 'christmas'],
    'whittle': ['amputate', 'ax', 'bisect', 'blade', 'butcher', 'carve', 'chop', 'cleave', 'cold steel', 'cut', 'cut away', 'cut in two'],
    'whittler': ['carver', 'chaser', 'clay modeler', 'earth artist', 'figurer', 'figuriste', 'gem carver', 'graver', 'mason', 'modeler', 'molder', 'monumental mason'],
    'whittling': ['cysp sculpture', 'anaglyptics', 'anaglyptography', 'architectural sculpture', 'bone-carving', 'casting', 'ceroplastics', 'chasing', 'clay sculpture', 'decorative sculpture', 'earth art', 'embossing'],
    'whiz': ['ace', 'adept', 'assibilate', 'assibilation', 'ball the jack', 'barrel', 'beaut', 'birr', 'bombilate', 'bombinate', 'boom', 'bowl along'],
    'whodunit': ['marchen', 'western', 'western story', 'westerner', 'adventure story', 'allegory', 'apologue', 'bedtime story', 'detective story', 'fable', 'fabliau', 'fairy tale'],
    'whole': ['a certain', 'absolute', 'account', 'across-the-board', 'admissibility', 'admission', 'admitting no exception', 'aggregate', 'all', 'all hands', 'all the world', 'all-comprehensive'],
    'wholehearted': ['abiding', 'ardent', 'authentic', 'bona fide', 'bound', 'bound and determined', 'committed', 'decided', 'decisive', 'dedicated', 'definite', 'determined'],
    'wholeness': ['advantageousness', 'agreeableness', 'allness', 'auspiciousness', 'beneficialness', 'benevolence', 'benignity', 'class', 'cogency', 'combination', 'completeness', 'comprehensiveness'],
    'wholesale': ['abounding', 'absolute', 'abundant', 'affluent', 'all-embracing', 'all-encompassing', 'all-out', 'all-pervading', 'all-sufficing', 'ample', 'aplenty', 'at a bargain'],
    'wholesale house': ['boutique', 'chain store', 'co-op', 'concession', 'cooperative', 'countinghouse', 'country store', 'department store', 'dime store', 'discount house', 'discount store', 'emporium'],
    'wholesaler': ['agent', 'broker', 'chandler', 'connection', 'dealer', 'distributor', 'go-between', 'importer', 'intermediary', 'intermedium', 'jobber', 'liaison'],
    'wholesaling': ['agency', 'barter', 'bartering', 'brokerage', 'buying and selling', 'consumer preference study', 'consumer research', 'consumer survey', 'dealing', 'direct-mail selling', 'doing business', 'exchange'],
    'wholesome': ['admissible', 'all', 'all in all', 'all there', 'altogether', 'balanced', 'beneficial', 'benign', 'bracing', 'bunkum', 'clearheaded', 'clearminded'],
    'wholly': ['absolutely', 'across the board', 'all', 'all put together', 'altogether', 'as a body', 'as a whole', 'at large', 'at length', 'bodily', 'collectively', 'completely'],
    'whomp': ['appulse', 'bang', 'bang into', 'beat', 'blank', 'blow', 'box', 'box the ears', 'brunt', 'buffet', 'bulldoze', 'bulldozing'],
    'whomp up': ['ad-lib', 'assemble', 'bat out', 'botch', 'build', 'bungle', 'cast', 'compose', 'compound', 'concoct', 'construct', 'cook up'],
    'whoop': ['ace', 'bark', 'battle cry', 'bawl', 'bellow', 'call', 'caterwaul', 'cheer', 'cry', 'damn', 'hail', 'halloo'],
    'whoop it up': ['be enthusiastic', 'be noisy', 'brawl', 'bubble over', 'carouse', 'carry on', 'carry on over', 'celebrate', 'chirm', 'clamor', 'clangor', 'cut loose'],
    'whoopee': ['celebration', 'conviviality', 'elation', 'exultation', 'festivity', 'gaiety', 'high jinks', 'holiday-making', 'hoopla', 'jollification', 'jollity', 'joviality'],
    'whooping cough': ['african lethargy', 'asiatic cholera', 'asiatic flu', 'chagres fever', 'german measles', 'haverhill fever', 'hong kong flu', 'acute articular rheumatism', 'acute bronchitis', 'adenoiditis', 'ague', 'alkali disease'],
    'whoosh': ['assibilate', 'assibilation', 'buzz', 'effervesce', 'effervescence', 'effervescing', 'fizz', 'fizzle', 'fizzling', 'frication', 'frictional rustling', 'hiss'],
    'whop': ['bang', 'bash', 'baste', 'bastinado', 'bat', 'batter', 'beat', 'beating', 'belabor', 'belt', 'biff', 'birch'],
    'whopping': ['awful', 'awfully', 'banging', 'big', 'bumping', 'clobbering', 'colossal', 'crushing defeat', 'damned', 'decisive defeat', 'enormous', 'exceedingly'],
    'whore': ['b-girl', 'cyprian', 'jezebel', 'paphian', 'backslider', 'bad egg', 'bad lot', 'bad woman', 'baggage', 'bawd', 'be promiscuous', 'bitch'],
    'whorehouse': ['bagnio', 'bawdy house', 'bawdyhouse', 'bordello', 'brothel', 'cathouse', 'clip joint', 'crib', 'den', 'den of thieves', 'den of vice', 'disorderly house'],
    'whorish': ['paphian', 'chambering', 'easy', 'fallen', 'harlot', 'hustling', 'lax', 'light', 'loose', 'loose-moraled', 'meretricious', 'of easy virtue'],
    'whorl': ['cirrus', 'coil', 'contort', 'corkscrew', 'crinkle', 'curl', 'curlicue', 'eddy', 'evolute', 'gurge', 'gyre', 'helix'],
    'whorled': ['ambagious', 'anfractuous', 'circuitous', 'circumlocutory', 'cochlear', 'cochleate', 'convolutional', 'corkscrew', 'corkscrewy', 'flexuose', 'flexuous', 'helical'],
    'why': ['chinese puzzle', 'argument', 'baffling problem', 'brain twister', 'conundrum', 'crossword puzzle', 'crux', 'enigma', 'enigmatic question', 'excuse', 'explanation', 'floorer'],
    'wicked': ['herculean', 'aberrant', 'abnormal', 'abominable', 'abstruse', 'adroit', 'antic', 'arduous', 'arrant', 'atrocious', 'au fait', 'bad'],
    'wickedness': ['aberrance', 'aberrancy', 'abnormality', 'arrantness', 'badness', 'baseness', 'bitchiness', 'corruption', 'criminality', 'cussedness', 'damnability', 'debt'],
    'wicket': ['bay', 'bay window', 'bow window', 'casement', 'casement window', 'fan window', 'fanlight', 'grille', 'lancet window', 'lantern', 'lattice', 'light'],
    'widdershins': ['a rebours', 'a reculons', 'against the grain', 'anticlockwise', 'arear', 'around', 'ass-backwards', 'astern', 'away', 'back', 'backward', 'backwards'],
    'wide': ['aberrant', 'abroad', 'abstract', 'accented', 'adrift', 'advanced', 'afield', 'all abroad', 'all off', 'all wrong', 'alveolar', 'amiss'],
    'wide awake': ['agile', 'alert', 'alive', 'astute', 'attentive', 'awake', 'aware', 'bright', 'clear-sighted', 'clear-witted', 'clearheaded', 'conscious'],
    'wide berth': ['ample scope', 'blank check', 'carte blanche', 'clearance', 'elbowroom', 'field', 'free course', 'free hand', 'free play', 'free scope', 'full scope', 'full swing'],
    'wide eyed': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled', 'bewildered'],
    'wide open': ['absolute', 'all out', 'at full blast', 'at full drive', 'at full speed', 'at full throttle', 'bald', 'bare', 'clear', 'cleared', 'deltoid', 'disclosed'],
    'wide open spaces': ['lebensraum', 'agricultural region', 'air space', 'alkali flat', 'alluvial plain', 'arable land', 'back country', 'basin', 'black belt', 'bottomland', 'bushveld', 'campo'],
    'wide world': ['copernican universe', 'einsteinian universe', 'newtonian universe', 'ptolemaic universe', 'all', 'all being', 'all creation', 'allness', 'cosmos', 'created nature', 'created universe', 'creation'],
    'widen': ['accrue', 'accumulate', 'add to', 'advance', 'aggrandize', 'amplify', 'appreciate', 'augment', 'balloon', 'bloat', 'blow up', 'boom'],
    'widened': ['accelerated', 'aggrandized', 'ampliate', 'amplified', 'augmented', 'beefed-up', 'bloated', 'boosted', 'broadened', 'built-up', 'crescendoed', 'deepened'],
    'widening': ['access', 'accession', 'accretion', 'accrual', 'accruement', 'accumulation', 'addition', 'adjunct', 'advance', 'aggrandizement', 'ampliation', 'amplification'],
    'widespread': ['accepted', 'ample', 'amplitudinous', 'broad', 'broadcast', 'capacious', 'commodious', 'conformable', 'consuetudinary', 'conventional', 'current', 'customary'],
    'widget': ['affair', 'article', 'artifact', 'concern', 'dingus', 'dofunny', 'dohickey', 'dojigger', 'dojiggy', 'domajig', 'domajigger', 'doodad'],
    'width': ['ambit', 'amplitude', 'area', 'beam', 'bigness', 'body', 'breadth', 'broadness', 'bulk', 'caliber', 'circle', 'compass'],
    'wield': ['brandish', 'come in contact', 'conduct', 'control', 'dispense', 'do with', 'employ', 'exercise', 'exert', 'feel', 'feel of', 'finger'],
    'wield authority': ['administer', 'administrate', 'be master', 'captain', 'carry authority', 'chair', 'command', 'control', 'crack the whip', 'direct', 'discipline', 'dominate'],
    'wieldy': ['adaptable', 'convenient', 'ductile', 'feasible', 'flexible', 'foolproof', 'handy', 'malleable', 'manageable', 'maneuverable', 'mighty', 'pliable'],
    'wiener': ['vienna sausage', 'bangers', 'black pudding', 'blood pudding', 'bologna', 'braunschweiger', 'dog', 'frank', 'frankfurter', 'gooseliver', 'headcheese', 'hot dog'],
    'wiener roast': ['tv dinner', 'alfresco meal', 'barbecue', 'breakfast', 'brunch', 'buffet supper', 'clambake', 'coffee break', 'cookout', 'diner', 'dinner', 'elevenses'],
    'wife': ['better half', 'bride', 'common-law wife', 'concubine', 'consort', 'dowager', 'feme', 'feme covert', 'goodwife', 'goody', 'helpmate', 'helpmeet'],
    'wifely': ['adoring', 'affectionate', 'bridal', 'conjugal', 'connubial', 'demonstrative', 'devoted', 'epithalamic', 'faithful', 'filial', 'fond', 'husbandly'],
    'wig': ['admonishment', 'admonition', 'bawl out', 'berate', 'chew out', 'chiding', 'hairpiece', 'jaw', 'periwig', 'peruke', 'rail', 'rap'],
    'wiggle': ['amble', 'barge', 'bowl along', 'bundle', 'clump', 'drag', 'fidget', 'flip out', 'flounce', 'flutter', 'foot', 'footslog'],
    'wigwag': ['lissajous figure', 'roman candle', 'aid to navigation', 'alarm', 'alternate', 'alternation', 'amber light', 'back and fill', 'back-and-forth', 'balefire', 'battledore and shuttlecock', 'beacon'],
    'wild': ['arabia deserta', 'death valley', 'dionysiac', 'gothic', 'neanderthal', 'sahara', 'abandoned', 'absurd', 'accident-prone', 'addled', 'adventurous', 'agitated'],
    'wild about': ['ape about', 'attached to', 'bugs on', 'cracked on', 'crazy about', 'devoted to', 'enamored of', 'far gone on', 'fond of', 'freaked-out', 'gaga over', 'gone on'],
    'wild beast': ['animalia', 'mafioso', 'young turk', 'and fish', 'animal kingdom', 'animal life', 'animality', 'beast', 'beasts', 'beasts of field', 'beasts of prey', 'beldam'],
    'wild eyed': ['abandoned', 'amok', 'bellowing', 'berserk', 'bigoted', 'carried away', 'delirious', 'demoniac', 'distracted', 'ecstatic', 'enraptured', 'extravagant'],
    'wild goose chase': ['abortion', 'abortive attempt', 'bootless errand', 'dud', 'labor in vain', 'labor of sisyphus', 'lost', 'merry chase', 'miscarriage', 'miscarrying', 'misfire', 'snipe hunt'],
    'wild man': ['adventurer', 'adventuress', 'animal', 'anthropophagite', 'barbarian', 'beast', 'brazenface', 'brute', 'cannibal', 'daredevil', 'destroyer', 'devil'],
    'wild west': ['dixie', 'dixieland', 'down east', 'east', 'east coast', 'middle atlantic', 'middle west', 'new england', 'north', 'north central region', 'northeast', 'northwest'],
    'wildcat': ['jezebel', 'leo', 'siberian tiger', 'adventurous', 'aleatory', 'beldam', 'bitch-kitty', 'bobcat', 'cat-a-mountain', 'catamount', 'chancy', 'cheetah'],
    'wilderness': ['arabia deserta', 'chinese puzzle', 'death valley', 'gordian knot', 'lebensraum', 'rube goldberg contraption', 'sahara', 'air space', 'back country', 'back of beyond', 'backcountry', 'backlands'],
    'wildest dream': ['apparition', 'appearance', 'brainchild', 'bubble', 'chimera', 'delirium', 'eidolon', 'fancy', 'fantasque', 'fantasy', 'fiction', 'figment'],
    'wildlife': ['animalia', 'and fish', 'animal kingdom', 'animal life', 'animality', 'beasts', 'beasts of field', 'beasts of prey', 'big game', 'birds', 'brute creation', 'cattle'],
    'wildly': ['a corps perdu', 'all to pieces', 'carelessly', 'deliriously', 'demonically', 'desperately', 'distractedly', 'fanatically', 'fiercely', 'frantically', 'frenetically', 'frenziedly'],
    'wildwood': ['afforestation', 'arboretum', 'boondocks', 'bush', 'bushveld', 'chase', 'climax forest', 'cloud forest', 'dendrology', 'forest', 'forest land', 'forest preserve'],
    'wile': ['italian hand', 'machiavellianism', 'acuteness', 'allure', 'ambidexterity', 'art', 'artful dodge', 'artfulness', 'artifice', 'astuteness', 'bad faith', 'bag of tricks'],
    'will': ['add a codicil', 'aim', 'alternativity', 'ambition', 'animus', 'aplomb', 'appetite', 'ardor', 'aspiration', 'assurance', 'attested copy', 'behest'],
    'will power': ['animus', 'appetence', 'appetency', 'appetite', 'choice', 'command', 'conation', 'conatus', 'decision', 'desire', 'determination', 'discretion'],
    'willful': ['advised', 'aimed', 'aimed at', 'arbitrary', 'autonomous', 'balking', 'balky', 'bigoted', 'bulldogged', 'bulletheaded', 'bullheaded', 'calculated'],
    'willing': ['accordant', 'acquiescent', 'affirmative', 'agreeable', 'agreeing', 'alacritous', 'amenable', 'approving', 'apt', 'ardent', 'assenting', 'bright'],
    'willingness': ['ok', 'a thing for', 'acceptance', 'accord', 'acquiescence', 'affinity', 'affirmation', 'affirmative', 'affirmative voice', 'agreement', 'allegiance', 'approbation'],
    'willowy': ['adaptable', 'airy', 'attenuate', 'attenuated', 'bendable', 'bending', 'boyish', 'compliant', 'delicate', 'diaphanous', 'diluted', 'ductile'],
    'willy nilly': ['all over', 'all over hell', 'at intervals', 'brokenly', 'by catches', 'by fits', 'by jerks', 'by skips', 'by snatches', 'come what may', 'compulsorily', 'disconnectedly'],
    'wilt': ['beat', 'blow', 'break', 'break down', 'burn out', 'cave in', 'collapse', 'come apart', 'come unstuck', 'conk out', 'crack up', 'crumble'],
    'wilted': ['atrophied', 'bathed in sweat', 'beaded with sweat', 'brittle', 'clammy', 'desiccated', 'diaphoretic', 'drenched with sweat', 'dried-up', 'emaciated', 'in a sweat', 'papery'],
    'wily': ['byzantine', 'machiavellian', 'machiavellic', 'acute', 'arch', 'artful', 'astute', 'cagey', 'calculating', 'canny', 'chiseling', 'clever'],
    'win': ['cadmean victory', 'ko', 'pyrrhic victory', 'accomplish', 'achieve', 'acquire', 'annex', 'argue into', 'ascendancy', 'attain', 'bag', 'be seized of'],
    'win out': ['bear the palm', 'beat the game', 'beat the system', 'capture', 'carry', 'carry away', 'carry it', 'carry off', 'carry the day', 'come out first', 'come through', 'come up fighting'],
    'win over': ['argue into', 'assure', 'be convincing', 'bring around', 'bring home to', 'bring over', 'bring round', 'bring to reason', 'captivate', 'carry conviction', 'charm', 'con'],
    'wince': ['ache', 'agonize', 'ail', 'anguish', 'avoid', 'avoidance', 'blanch', 'blench', 'blink', 'boggle', 'cower', 'cringe'],
    'wind': ['aqua-lung', 'vayu', 'zephyr', 'zephyrus', 'about ship', 'aerate', 'aerophone', 'air', 'air out', 'air-condition', 'air-cool', 'airify'],
    'wind sock': ['anemograph', 'anemometer', 'anemometrograph', 'anemoscope', 'beacon', 'beam', 'cock', 'fan marker', 'flare path', 'marker', 'pylon', 'racon'],
    'wind tunnel': ['air duct', 'air hole', 'air passage', 'air shaft', 'air tube', 'airway', 'blowhole', 'breathing hole', 'louver', 'louverwork', 'naris', 'nostril'],
    'wind up': ['abort', 'button up', 'cap', 'carry to completion', 'cease', 'charge', 'clean up', 'climax', 'close', 'close out', 'close up', 'cock'],
    'windbag': ['captain bobadil', 'gascon', 'texan', 'agreeable rattle', 'babbler', 'big mouth', 'big talker', 'blab', 'blabberer', 'blatherer', 'blower', 'blowhard'],
    'windfall': ['boast', 'bonus', 'buried treasure', 'catch', 'diamond', 'discovery', 'find', 'finding', 'foundling', 'gem', 'godsend', 'good thing'],
    'winding': ['aberrant', 'aberrative', 'ambages', 'ambagious', 'anfractuosity', 'anfractuous', 'bending', 'circuitous', 'circuitousness', 'circumambages', 'circumbendibus', 'circumlocution'],
    'windjammer': ['ab', 'ancient mariner', 'argonaut', 'captain bobadil', 'dylan', 'flying dutchman', 'gascon', 'neptune', 'od', 'poseidon', 'texan', 'varuna'],
    'windlass': ['chinese windlass', 'spanish windlass', 'capstan', 'crab', 'crane', 'derrick', 'erector', 'forklift', 'gantry crane', 'hoist', 'hydraulic tailgate', 'jack'],
    'window': ['aluminum foil', 'bay', 'bay window', 'bow window', 'casement', 'casement window', 'chaff', 'fan window', 'fanlight', 'grille', 'lancet window', 'lantern'],
    'window dressing': ['acting', 'adjunct', 'adornment', 'affectation', 'anteriority', 'appearance', 'arrangement', 'attitudinizing', 'bluff', 'bluffing', 'bold front', 'brave face'],
    'window shopping': ['buy', 'buying', 'buying power', 'buying up', 'catalog buying', 'coemption', 'consumer power', 'consumer sovereignty', 'consumerism', 'cornering', 'emption', 'hire purchase'],
    'windowpane': ['bay', 'bay window', 'bow window', 'casement', 'casement window', 'diaphane', 'display case', 'fan window', 'fanlight', 'glass', 'glassware', 'grille'],
    'windproof': ['airtight', 'close', 'compact', 'dustproof', 'dusttight', 'fast', 'firm', 'gasproof', 'gastight', 'hermetic', 'hermetically sealed', 'lightproof'],
    'windshield': ['aegis', 'arm guard', 'backstop', 'buffer', 'bulwark', 'bumper', 'contraceptive', 'copyright', 'crash helmet', 'cushion', 'dashboard', 'dodger'],
    'windstorm': ['black squall', 'blizzard', 'blow', 'cyclone', 'dirty weather', 'equinoctial', 'foul weather', 'gale', 'half a gale', 'heavy blow', 'hurricane', 'ill wind'],
    'windup': ['apodosis', 'catastrophe', 'ceasing', 'cessation', 'close', 'coda', 'completing', 'completion', 'conclusion', 'consummation', 'crack of doom', 'culmination'],
    'windward': ['alee', 'anticlockwise', 'aweather', 'clockwise', 'counterclockwise', 'downwind', 'earthward', 'flanking', 'glancing', 'heavenward', 'homeward', 'landward'],
    'windy': ['adulterated', 'aeolian', 'air-built', 'airish', 'airy', 'all jaw', 'asinine', 'attenuate', 'attenuated', 'big', 'blasty', 'bloated'],
    'wine': ['alba flora', 'algarve', 'alsace', 'anjou', 'assmannshausen', 'bad kreuznach', 'barbera', 'bardolino', 'barsac', 'beaujolais', 'beaune', 'bordeaux'],
    'wine cellar': ['archives', 'armory', 'arsenal', 'attic', 'bank', 'basement', 'bay', 'bin', 'bonded warehouse', 'bookcase', 'box', 'bunker'],
    'wine merchant': ['baker', 'barkeep', 'barkeeper', 'barmaid', 'barman', 'bartender', 'bookdealer', 'bookseller', 'bootlegger', 'brewer', 'brewmaster', 'butcher'],
    'wine shop': ['alehouse', 'bar', 'barrel house', 'barroom', 'beer garden', 'beer parlor', 'bistro', 'blind tiger', 'cabaret', 'cafe', 'cocktail lounge', 'dive'],
    'winery': ['armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'bindery', 'boatyard', 'boilery', 'bookbindery', 'bottling works', 'brewery', 'brickyard'],
    'wing': ['kp', 'act drop', 'addition', 'administration', 'aeroplane', 'affiliate', 'age group', 'air arm', 'air corps', 'air force', 'air service', 'airlift'],
    'wing it': ['ad-lib', 'be getting along', 'buzz off', 'come away', 'cook up', 'dash off', 'depart', 'do offhand', 'exit', 'extemporize', 'fake', 'gang along'],
    'wingding': ['bat', 'bender', 'binge', 'bout', 'bust', 'carousal', 'carouse', 'celebration', 'debauch', 'drinking bout', 'escapade', 'fling'],
    'winged': ['agile', 'breakneck', 'dashing', 'double-quick', 'eagle-winged', 'expeditious', 'express', 'fast', 'fleet', 'flying', 'galloping', 'hair-trigger'],
    'wings': ['hershey bar', 'acting area', 'apron', 'apron stage', 'aviation badge', 'backstage', 'badge', 'band shell', 'bandstand', 'bar', 'board', 'bridge'],
    'wink': ['roman candle', 'aid to navigation', 'alarm', 'amber light', 'balefire', 'bat', 'bat the eyes', 'beacon', 'beacon fire', 'beat the drum', 'bell', 'bell buoy'],
    'wink at': ['ok', 'abide with', 'accede to', 'accept', 'accord to', 'agree to', 'allow for', 'approve', 'approve of', 'assent', 'be big', 'be blind'],
    'winner': ['activist', 'ball of fire', 'beaver', 'big-time operator', 'boast', 'bustler', 'busy bee', 'catch', 'champ', 'champion', 'cinch', 'comer'],
    'winning': ['cadmean victory', 'ko', 'pyrrhic victory', 'acceptable', 'accession', 'acquirement', 'acquisition', 'addition', 'admirable', 'adorable', 'agreeable', 'alluring'],
    'winning streak': ['cadmean victory', 'ko', 'pyrrhic victory', 'ascendancy', 'championship', 'conquest', 'easy victory', 'grand slam', 'knockout', 'landslide', 'landslide victory', 'mastery'],
    'winnings': ['capital gains', 'cleanup', 'clear profit', 'dividends', 'earnings', 'filthy lucre', 'gain', 'gains', 'get', 'gettings', 'gleanings', 'gross'],
    'winnow': ['aerate', 'air', 'air out', 'air-condition', 'air-cool', 'airify', 'analyze', 'appraise', 'assess', 'bolt', 'catalog', 'categorize'],
    'winsome': ['admirable', 'adorable', 'alluring', 'angelic', 'appealing', 'appetizing', 'attractive', 'beaming', 'beguiling', 'bewitching', 'blandishing', 'blithe'],
    'winter': ['christmastide', 'christmastime', 'yule', 'yuletide', 'aestival', 'arctic', 'autumn', 'autumnal', 'bitter weather', 'bleak weather', 'boreal', 'brumal'],
    'wintry': ['siberian', 'aestival', 'algid', 'arctic', 'autumn', 'autumnal', 'below zero', 'biting', 'bitter', 'bitterly cold', 'bleak', 'boreal'],
    'wipe': ['air-dry', 'anhydrate', 'bake', 'blackout', 'bleach', 'blocking', 'blot', 'bowdlerize', 'brush', 'burn', 'clean', 'clean out'],
    'wipe out': ['ko', 'abate', 'abolish', 'abscind', 'absolve', 'amputate', 'annihilate', 'annul', 'ban', 'bar', 'black out', 'blast'],
    'wire': ['bx cable', 'teletype', 'armored cable', 'band', 'bandage', 'battery cable', 'bell wire', 'belt', 'bend', 'bind', 'bind up', 'brace'],
    'wire puller': ['machiavellian', 'rasputin', 'svengali', 'vip', 'access', 'bad influence', 'behind-the-scenes operator', 'big wheel', 'calculator', 'coconspirator', 'conniver', 'conspirator'],
    'wire pulling': ['byzantine intrigues', 'artifice', 'backscratching', 'backstairs influence', 'behind-the-scenes influence', 'cabal', 'collusion', 'complicity', 'complot', 'confederacy', 'connections', 'connivance'],
    'wire service': ['telautography', 'teletype', 'teletype network', 'teletyping', 'advice', 'broadcast journalism', 'closed-circuit telegraphy', 'code', 'duplex telegraphy', 'electricity', 'facsimile telegraph', 'information'],
    'wiredrawn': ['airy', 'attenuate', 'attenuated', 'boyish', 'dainty', 'delicate', 'diaphanous', 'diluted', 'downy', 'ethereal', 'filmy', 'fine'],
    'wireless': ['teletype', 'wirephoto', 'audio-frequency', 'beam', 'broadcast', 'cabinet', 'chassis', 'communication', 'communicational', 'communications', 'console', 'electronics'],
    'wirephoto': ['photoradiogram', 'telephoto', 'aerial photograph', 'black-and-white photograph', 'candid photograph', 'cheesecake', 'chronophotograph', 'color photograph', 'color print', 'diapositive', 'facsimile', 'heliochrome'],
    'wiretap': ['attend', 'attend to', 'auscultate', 'be all ears', 'bend an ear', 'bug', 'bugging', 'cloak-and-dagger work', 'cock the ears', 'counterespionage', 'counterintelligence', 'eavesdrop'],
    'wiry': ['able-bodied', 'athletic', 'brawny', 'broad-shouldered', 'burly', 'capillary', 'cartilaginous', 'chewy', 'cirrose', 'cirrous', 'cohesive', 'coriaceous'],
    'wisdom': ['sophia', 'adage', 'advantage', 'advantageousness', 'advisability', 'ana', 'analects', 'aphorism', 'apothegm', 'apprehension', 'appropriateness', 'axiom'],
    'wise': ['mo', 'abstruse', 'acute', 'advantageous', 'advisable', 'alert', 'algorithm', 'all-knowing', 'angle', 'apperceptive', 'appercipient', 'apprehending'],
    'wise ass': ['biggety', 'bluff', 'boldface', 'brash', 'brazenface', 'cheeky', 'chutzpadik', 'chutzpanik', 'cocky', 'contemptuous', 'crusty', 'derisive'],
    'wise guy': ['gothamite', 'boldface', 'brazenface', 'chutzpanik', 'hussy', 'malapert', 'minx', 'pup', 'puppy', 'saucebox', 'smart aleck', 'smart ass'],
    'wise man': ['brahmin', 'brain', 'brainworker', 'consciousness', 'egghead', 'head', 'highbrow', 'intellect', 'intellectual', 'intellectualist', 'intelligence', 'literate'],
    'wise to': ['alive to', 'appreciative of', 'apprised of', 'awake to', 'aware of', 'behind the curtain', 'behind the scenes', 'cognizant of', 'conscious of', 'hep to', 'in the know', 'in the secret'],
    'wisecrack': ['aphorism', 'apothegm', 'be merry with', 'bon mot', 'boutade', 'bright idea', 'bright thought', 'brilliant idea', 'conceit', 'crack', 'crack a joke', 'crack wise'],
    'wisecracker': ['banana', 'burlesquer', 'caricaturist', 'clown', 'comedian', 'comic', 'cutup', 'epigrammatist', 'funnyman', 'gag writer', 'gagman', 'gagster'],
    'wisely': ['artfully', 'astutely', 'circumspectly', 'cleverly', 'considerately', 'cunningly', 'discerningly', 'discreetly', 'intelligently', 'judiciously', 'knowingly', 'providently'],
    'wish for': ['ache for', 'be dying for', 'be hurting for', 'clamor for', 'cry for', 'gape for', 'hone for', 'hope for', 'itch for', 'languish for', 'long for', 'lust for'],
    'wish fulfilling': ['airy', 'autistic', 'dereistic', 'idealistic', 'impractical', 'in the clouds', 'otherworldly', 'poetic', 'quixotic', 'romancing', 'romantic', 'romanticized'],
    'wish fulfillment': ['alienation', 'ardor', 'autism', 'autistic thinking', 'avoidance mechanism', 'blame-shifting', 'compensation', 'concupiscence', 'curiosity', 'decompensation', 'defense mechanism', 'dereism'],
    'wishbone': ['tarnkappe', 'branch', 'breast', 'cap of darkness', 'chicken foot', 'crotch', 'crutch', 'dark meat', 'delta', 'drumstick', 'fan', 'fern seed'],
    'wishful thinker': ['don quixote', 'quixote', 'daydreamer', 'dreamer', 'dreamer of dreams', 'enthusiast', 'escapist', 'idealist', 'lotus-eater', 'prophet', 'rhapsodist', 'romancer'],
    'wishful thinking': ['alienation', 'autism', 'autistic thinking', 'avoidance mechanism', 'bamboozlement', 'befooling', 'blame-shifting', 'blind faith', 'bluffing', 'calculated deception', 'circumvention', 'compensation'],
    'wishy washy': ['adrift', 'afloat', 'alternating', 'amorphous', 'banal', 'betwixt and between', 'bland', 'capricious', 'changeable', 'changeful', 'dead', 'desultory'],
    'wisp': ['autoluminescence', 'bantam', 'banty', 'batch', 'bioluminescence', 'bunch', 'button', 'cathode luminescence', 'chemicoluminescence', 'chemiluminescence', 'chit', 'clump'],
    'wispy': ['airy', 'attenuate', 'attenuated', 'boyish', 'breakable', 'brittle', 'cheap-jack', 'cobwebby', 'crumbly', 'dainty', 'delicate', 'delicately weak'],
    'wistful': ['ashamed', 'atrabiliar', 'atrabilious', 'blue', 'cogitative', 'cognitive', 'concentrating', 'concentrative', 'conceptive', 'conceptual', 'conceptualized', 'conscience-smitten'],
    'wit': ['esp', 'iq', 'italian hand', 'ability', 'acumen', 'acuteness', 'address', 'adeptness', 'adroitness', 'airmanship', 'alertness', 'apprehension'],
    'witch': ['jezebel', 'mafioso', 'weird sisters', 'young turk', 'baboon', 'bag', 'bat', 'battle-ax', 'beast', 'becharm', 'bedevil', 'beguile'],
    'witch hunt': ['mccarthyism', 'amassing evidence', 'close inquiry', 'department of investigation', 'detection', 'detective work', 'exhaustive study', 'harassment', 'harrying', 'hearing', 'hounding', 'indagation'],
    'witchcraft': ['alchemy', 'allure', 'appeal', 'bewitchery', 'bewitchment', 'charisma', 'charm', 'divination', 'enchantment', 'fascination', 'fetishism', 'glamour'],
    'witchery': ['agacerie', 'alchemy', 'allure', 'allurement', 'appeal', 'appealingness', 'attraction', 'attractiveness', 'bedevilment', 'beguilement', 'beguiling', 'bewitchery'],
    'witching': ['circean', 'alluring', 'appealing', 'appetizing', 'attractive', 'beguiling', 'bewitching', 'bewitchment', 'blandishing', 'cajoling', 'captivating', 'catching'],
    'with': ['about', 'added to', 'along with', 'amid', 'amidst', 'among', 'amongst', 'as well as', 'at', 'at all costs', 'at any cost', 'attended by'],
    'with a vengeance': ['a outrance', 'a toute outrance', 'absolutely', 'all hollow', 'all out', 'all the way', 'all to pieces', 'beyond all bounds', 'beyond compare', 'beyond comparison', 'beyond measure', 'cogently'],
    'with bated breath': ['abjectly', 'anticipatingly', 'anticipatively', 'anticipatorily', 'anxious', 'apprehensive', 'apprehensively', 'aside', 'bashfully', 'behind the curtain', 'behind the scenes', 'behind the veil'],
    'with child': ['anticipating', 'big with child', 'big-laden', 'breeding', 'carrying', 'carrying a fetus', 'expecting', 'gestating', 'gravid', 'great', 'heavy', 'heavy with child'],
    'with it': ['a la mode', 'agreeably', 'by consensus', 'compatibly', 'concordantly', 'congenially', 'consonantly', 'fashionable', 'fittingly', 'go-go', 'groovy', 'hand in glove'],
    'with open arms': ['agreeably', 'amiably', 'amicably', 'animatedly', 'anxiously', 'ardently', 'arm in arm', 'avidly', 'breathlessly', 'congenially', 'cordially', 'de bonne volonte'],
    'withdraw': ['abandon', 'abate', 'abdicate', 'abjure', 'abolish', 'abrade', 'abrogate', 'abrupt', 'abscond', 'abstract', 'agree to differ', 'agree to disagree'],
    'withdrawal': ['jim crow', 'abandonment', 'abdication', 'abjuration', 'abjurement', 'abolishment', 'abolition', 'abrogation', 'absentation', 'abstraction', 'abulia', 'agreement to disagree'],
    'withdrawn': ['laodicean', 'olympian', 'alienated', 'alone', 'aloof', 'anonymous', 'apart', 'apathetic', 'aseptic', 'backward', 'bashful', 'benumbed'],
    'wither': ['sanforize', 'age', 'air-dry', 'anhydrate', 'attenuate', 'bake', 'blot', 'brush', 'burn', 'cave in', 'cheat the undertaker', 'collapse'],
    'withered': ['sanforized', 'adust', 'anile', 'atrophied', 'attenuated', 'baked', 'brittle', 'burnt', 'cadaverous', 'consumed', 'corky', 'corpselike'],
    'withering': ['sanforizing', 'acerb', 'acerbate', 'acerbic', 'acid', 'acidic', 'acidulent', 'acidulous', 'acrid', 'acrimonious', 'air-drying', 'anhydration'],
    'withhold': ['abstain', 'abstain from', 'arrest', 'avoid', 'begrudge', 'bit', 'bosom', 'bridle', 'check', 'classify', 'close the hand', 'conceal'],
    'within bounds': ['analytically', 'calmly', 'composedly', 'conservatively', 'coolly', 'dispassionately', 'equably', 'evenly', 'frugally', 'in all conscience', 'in all reason', 'in balance'],
    'within reach': ['about', 'accessible', 'along toward', 'approachable', 'around', 'at close quarters', 'at hand', 'attainable', 'attendant', 'available', 'close', 'close about'],
    'without': ['after', 'apparently', 'aside from', 'bar', 'barring', 'beside', 'besides', 'but', 'discounting', 'empty of', 'ex', 'except'],
    'without delay': ['pdq', 'all at once', 'all together', 'apace', 'at a blow', 'at a stroke', 'at once', 'at one blow', 'at one jump', 'at one stroke', 'at one swoop', 'at one time'],
    'without doubt': ['actually', 'admittedly', 'assuredly', 'believingly', 'beyond doubt', 'beyond question', 'certainly', 'clearly', 'decidedly', 'demonstrably', 'devoutly', 'doubtless'],
    'without exception': ['absolute', 'across-the-board', 'admitting no exception', 'all along', 'all over', 'all the time', 'all the while', 'all-comprehensive', 'all-inclusive', 'all-out', 'always', 'at all times'],
    'without foundation': ['baseless', 'built on sand', 'empty', 'groundless', 'idle', 'ill-founded', 'not well-founded', 'unbased', 'unfounded', 'ungrounded', 'unsupportable', 'unsupported'],
    'without stopping': ['ad infinitum', 'again and again', 'always', 'at a stretch', 'at all times', 'ceaselessly', 'connectedly', 'constantly', 'continually', 'continuously', 'cumulatively', 'cyclically'],
    'without warning': ['abruptly', 'bang', 'by surprise', 'dash', 'hastily', 'impetuously', 'implausibly', 'improbably', 'impulsively', 'like a flash', 'like a thunderbolt', 'of a sudden'],
    'withstand': ['be at cross-purposes', 'be proof against', 'bear', 'bear up', 'bear up against', 'buck', 'challenge', 'combat', 'complain', 'complain loudly', 'confront', 'contend with'],
    'witless': ['a stranger to', 'abnormal', 'apish', 'asinine', 'asleep', 'batty', 'bedlamite', 'befooled', 'beguiled', 'bereft of reason', 'besotted', 'blind to'],
    'witling': ['boeotian', 'gothamite', 'banana', 'block', 'burlesquer', 'caricaturist', 'clod', 'clown', 'comedian', 'comic', 'cutup', 'dimwit'],
    'witness': ['tv-viewer', 'accessory', 'acknowledge', 'admission', 'adviser', 'affidavit', 'affirm', 'affirmation', 'allegation', 'allege', 'announce', 'announcer'],
    'witticism': ['adage', 'ana', 'analects', 'aphorism', 'apothegm', 'axiom', 'bon mot', 'boutade', 'bright idea', 'bright thought', 'brilliant idea', 'byword'],
    'wittiness': ['brilliance', 'cleverness', 'comedy', 'comicality', 'comicalness', 'drollery', 'drollness', 'facetiousness', 'funniness', 'humorousness', 'jocoseness', 'jocularity'],
    'wittingly': ['advisedly', 'by design', 'calculatedly', 'consciously', 'contemplatedly', 'deliberately', 'designedly', 'eruditely', 'in cold blood', 'intelligently', 'intentionally', 'knowingly'],
    'witty': ['attic', 'absurd', 'amusing', 'biting', 'bizarre', 'brilliant', 'clever', 'diverting', 'droll', 'eccentric', 'entertaining', 'facetious'],
    'wizard': ['comus', 'faust', 'ok', 'ace', 'ace-high', 'artist', 'authority', 'bad', 'bang-up', 'bonzer', 'boss', 'bully'],
    'wizardry': ['ability', 'address', 'adeptness', 'adroitness', 'airmanship', 'alchemy', 'artfulness', 'artisanship', 'artistry', 'bewitchery', 'bewitchment', 'bravura'],
    'wizen': ['sanforize', 'age', 'air-dry', 'anhydrate', 'attenuate', 'bake', 'blot', 'brush', 'burn', 'cheat the undertaker', 'consume', 'cure'],
    'wizened': ['lilliputian', 'sanforized', 'tom thumb', 'adust', 'anile', 'atrophied', 'attenuated', 'baked', 'brittle', 'burnt', 'cadaverous', 'consumed'],
    'wobble': ['alternate', 'amble', 'arrhythmia', 'back and fill', 'barge', 'bob', 'bobble', 'bounce', 'bowl along', 'brokenness', 'bump', 'bundle'],
    'wobbly': ['aspen', 'broken', 'capricious', 'careening', 'catchy', 'chattering', 'choppy', 'desultory', 'deviative', 'dickey', 'dilapidated', 'disconnected'],
    'woe': ['abomination', 'aching heart', 'affliction', 'agony', 'agony of mind', 'anguish', 'atrocity', 'bad', 'bale', 'bane', 'befoulment', 'bemoaning'],
    'woebegone': ['affecting', 'afflictive', 'bitter', 'black', 'bleak', 'blue', 'bowed-down', 'cast down', 'cheerless', 'comfortless', 'crestfallen', 'crushed'],
    'woeful': ['abominable', 'affecting', 'afflictive', 'aggrieved', 'anguished', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beneath contempt', 'bitter'],
    'wolf': ['african hunting dog', 'cape hunting dog', 'casanova', 'don juan', 'lothario', 'mafioso', 'young turk', 'amorist', 'atonalism', 'atonality', 'batten', 'beast'],
    'wolf man': ['dracula', 'frankenstein', 'bogey', 'bogeyman', 'bugaboo', 'bugbear', 'fee-faw-fum', 'frightener', 'ghost', 'ghoul', 'hobgoblin', 'holy terror'],
    'wolfish': ['draconian', 'tartarean', 'all-devouring', 'all-engulfing', 'animal', 'anthropophagous', 'atrocious', 'barbaric', 'barbarous', 'beastly', 'bestial', 'bloodsucking'],
    'wolverine': ['cape polecat', 'ape', 'bar', 'bear', 'cavy', 'chimp', 'chimpanzee', 'coon', 'ferret', 'foumart', 'glutton', 'groundhog'],
    'woman': ['eve', 'frau', 'adult', 'better half', 'common-law wife', 'concubine', 'dame', 'daughter of eve', 'distaff', 'distaff side', 'domina', 'donna'],
    'womanhood': ['adulthood', 'adultness', 'age of consent', 'distaff side', 'driving age', 'fair sex', 'female sex', 'femaleness', 'feminacy', 'feminality', 'femineity', 'feminineness'],
    'womanish': ['breakable', 'brittle', 'cheap-jack', 'chicken', 'cobwebby', 'crumbly', 'dainty', 'delicate', 'delicately weak', 'distaff', 'effeminate', 'female'],
    'womanize': ['be promiscuous', 'castrate', 'chase women', 'commit adultery', 'debauch', 'demasculinize', 'dissipate', 'effeminate', 'effeminatize', 'effeminize', 'emasculate', 'fool around'],
    'womanizer': ['casanova', 'don juan', 'lothario', 'chaser', 'debauchee', 'gallant', 'gay deceiver', 'gay dog', 'lady-killer', 'libertine', 'lover-boy', 'masher'],
    'womanly': ['distaff', 'female', 'feminine', 'gentlewomanlike', 'girlish', 'gynecic', 'gynecoid', 'gynic', 'kittenish', 'ladylike', 'little-girlish', 'maidenly'],
    'womb': ['bag', 'ballocks', 'balls', 'basket', 'beard', 'breasts', 'cervix', 'clitoris', 'cod', 'cods', 'cullions', 'family jewels'],
    'wonder': ['admiration', 'agonize over', 'amaze', 'amazement', 'assailability', 'astonishing thing', 'astonishment', 'awe', 'be amazed', 'be astonished', 'be at sea', 'be innocent of'],
    'wonderful': ['amazing', 'appalling', 'astonishing', 'astounding', 'beguiling', 'bewildering', 'conspicuous', 'cool', 'divine', 'egregious', 'enigmatic', 'exceptional'],
    'wonderfully': ['abundantly', 'acutely', 'amazingly', 'amply', 'astonishingly', 'awesomely', 'beguilingly', 'bewilderingly', 'conspicuously', 'copiously', 'divinely', 'eminently'],
    'wonderfulness': ['awesomeness', 'beguilingness', 'enchantingness', 'enticingness', 'extraordinariness', 'fascination', 'glamorousness', 'marvelousness', 'miraculousness', 'mysteriousness', 'mystery', 'numinousness'],
    'wondering': ['agape', 'aghast', 'agog', 'all agog', 'amazed', 'astonished', 'astounded', 'at gaze', 'awed', 'awestruck', 'beguiled', 'bewildered'],
    'wonderland': ['agapemone', 'arcadia', 'big rock-candy mountain', 'canaan', 'cloudcuckooland', 'cockaigne', 'eden', 'eldorado', 'erewhon', 'garden of eden', 'goshen', 'happy valley'],
    'wondrous': ['amazing', 'astonishing', 'astounding', 'beguiling', 'bewildering', 'bewitched', 'enchanted', 'enigmatic', 'exceptional', 'extraordinary', 'fabulous', 'fantastic'],
    'wont': ['acclimate', 'acclimated', 'acclimatize', 'acclimatized', 'accommodate', 'accommodated', 'accustom', 'accustomed', 'adapt', 'adapted', 'adjust', 'adjusted'],
    'wonted': ['accepted', 'acclimated', 'acclimatized', 'accommodated', 'accustomed', 'adapted', 'adjusted', 'average', 'case-hardened', 'chronic', 'common', 'commonplace'],
    'woo': ['address', 'allure', 'angle for', 'bait', 'bait the hook', 'beau', 'bid for', 'bill and coo', 'blandish', 'cajole', 'canvass', 'chase'],
    'wood': ['acacia', 'afforestation', 'alder', 'arboretum', 'ash', 'backlog', 'balsa', 'balsam', 'banyan', 'bass', 'basswood', 'bavin'],
    'wood carving': ['cysp sculpture', 'anaglyptics', 'anaglyptography', 'architectural sculpture', 'bone-carving', 'bust', 'carving', 'casting', 'ceroplastics', 'chasing', 'clay sculpture', 'decorative sculpture'],
    'wood pulp': ['butter', 'cataplasm', 'crush', 'dental pulp', 'mash', 'mush', 'paper pulp', 'paste', 'pith', 'plaster', 'porridge', 'poultice'],
    'woodblock': ['aquatint', 'autolithograph', 'block', 'block print', 'chromolithograph', 'color print', 'copperplate', 'copperplate print', 'crayon engraving', 'cut', 'engravement', 'engraving'],
    'woodcraft': ['christmas tree farming', 'afforestation', 'arboriculture', 'artisan work', 'artisanship', 'craft', 'craftwork', 'forest management', 'forestation', 'forestry', 'handicraft', 'industrial art'],
    'woodcut': ['act drop', 'aquatint', 'asbestos', 'asbestos board', 'autolithograph', 'backdrop', 'batten', 'block', 'block print', 'border', 'cerography', 'chalcography'],
    'wooded': ['afforestational', 'arboreous', 'bosky', 'braky', 'bushy', 'copsy', 'dendrologic', 'forest', 'forestal', 'forested', 'reforestational', 'scrubby'],
    'wooden': ['arid', 'awkward', 'barren', 'blah', 'blank', 'bloodless', 'blunt', 'blunt-witted', 'buckram', 'bumbling', 'cardboard', 'characterless'],
    'woodland': ['acres', 'afforestation', 'afforestational', 'agricultural region', 'alluvion', 'alluvium', 'arable land', 'arboreous', 'arboretum', 'back', 'back of beyond', 'back-country'],
    'woods': ['english horn', 'pandean pipe', 'afforestation', 'arboretum', 'aulos', 'back country', 'backwoods', 'basset horn', 'basset oboe', 'bassoon', 'bombard', 'boondock'],
    'woodsman': ['arboriculturist', 'backwoodsman', 'briar-hopper', 'brush ape', 'bushman', 'clam digger', 'conservationist', 'cracker', 'desert rat', 'forest ranger', 'forester', 'frontiersman'],
    'woodsy': ['afforestational', 'arboreous', 'backwoodsman', 'bosky', 'braky', 'bumpkin', 'bushy', 'clodhopper', 'copsy', 'dendrologic', 'forest', 'forestal'],
    'woodwind': ['english horn', 'german band', 'pandean pipe', 'philharmonic', 'aulos', 'band', 'basset horn', 'basset oboe', 'bassoon', 'big band', 'bombard', 'brass'],
    'woody': ['afforestational', 'arboreous', 'bosky', 'braky', 'bushy', 'copsy', 'dendrologic', 'forest', 'forestal', 'forested', 'reforestational', 'scrubby'],
    'woof': ['cloth', 'drapery', 'etoffe', 'fabric', 'feel', 'felt', 'filling', 'finish', 'goods', 'grain', 'granular texture', 'indentation'],
    'woofer': ['acoustical network', 'capacitor speaker', 'coaxial speaker', 'cone', 'crossover network', 'diaphragm', 'dynamic speaker', 'earphone', 'electrodynamic speaker', 'electromagnetic speaker', 'electrostatic speaker', 'excited-field speaker'],
    'wooing': ['addresses', 'agacerie', 'allure', 'allurement', 'amorous pursuit', 'appeal', 'attraction', 'attractiveness', 'beguilement', 'beguiling', 'bewitchery', 'bewitchment'],
    'wool': ['aralac', 'avisco', 'celanese', 'chemstrand', 'dacron', 'dynel', 'lastex', 'manila', 'orlon', 'terylene', 'velon', 'vicara'],
    'woolgathering': ['walter mitty', 'absence of mind', 'absent', 'absentminded', 'absentmindedness', 'absorbed', 'absorption', 'abstracted', 'abstractedness', 'abstraction', 'bemused', 'bemusement'],
    'woolly': ['bristly', 'bushy', 'cirrose', 'downy', 'feathery', 'fleecy', 'flocculent', 'flossy', 'fluffy', 'furry', 'fuzzy', 'hairy'],
    'word': ['bible oath', 'parthian shot', 'account', 'acquaintance', 'adage', 'address', 'admission', 'advice', 'affidavit', 'affirmance', 'affirmation', 'allegation'],
    'word for word': ['absolutely', 'authentic', 'bona fide', 'candid', 'card-carrying', 'dead', 'definitely', 'dinkum', 'direct', 'directly', 'even', 'exactly'],
    'word formation': ['ic analysis', 'accidence', 'affix', 'affixation', 'allomorph', 'bound morpheme', 'conjugation', 'cutting', 'declension', 'derivation', 'difference of form', 'enclitic'],
    'word painting': ['vorstellung', 'cameo', 'catalog', 'cataloging', 'character', 'character sketch', 'characterization', 'concept', 'conception', 'conceptualization', 'delineation', 'depiction'],
    'wordage': ['choice of words', 'composition', 'dialect', 'diction', 'expression', 'formulation', 'grammar', 'idiom', 'language', 'lexicon', 'lexis', 'locution'],
    'wording': ['choice of words', 'composition', 'dialect', 'diction', 'expression', 'formulation', 'grammar', 'idiom', 'language', 'locution', 'mode', 'parlance'],
    'wordless': ['anaudic', 'aphasic', 'aphonic', 'breathless', 'brief', 'brusque', 'close', 'close-lipped', 'close-tongued', 'closemouthed', 'concise', 'curt'],
    'wordplay': ['abuse of terms', 'acrostic', 'amphibologism', 'amphiboly', 'anagram', 'calembour', 'corruption', 'equivocality', 'equivoque', 'jeu de mots', 'logogram', 'logogriph'],
    'words of wisdom': ['adage', 'ana', 'analects', 'aphorism', 'apothegm', 'axiom', 'byword', 'catchword', 'collected sayings', 'current saying', 'dictate', 'dictum'],
    'wordy': ['bombastic', 'de longue haleine', 'diffuse', 'endless', 'extended', 'filled out', 'flatulent', 'garrulous', 'glib', 'highfalutin', 'inflated', 'lengthy'],
    'work': ['grand guignol', 'nachtmusik', 'passion play', 'tom show', 'abatis', 'absolute music', 'accomplish', 'accomplished fact', 'accomplishment', 'acetify', 'achieve', 'achievement'],
    'work against': ['antagonize', 'be antipathetic', 'be inimical', 'beat against', 'clash', 'collide', 'conflict', 'conflict with', 'confute', 'contradict', 'contrapose', 'contravene'],
    'work at': ['be employed', 'carry on', 'carry on business', 'conduct', 'do', 'do business', 'employ', 'engage in', 'exercise', 'follow', 'follow a trade', 'go in for'],
    'work for': ['administer to', 'attend', 'attend on', 'be employed', 'care for', 'carry on business', 'cater to', 'chore', 'dance attendance upon', 'do business', 'do for', 'do service to'],
    'work in': ['admit', 'barge in', 'be admitted', 'break in', 'break in upon', 'breeze in', 'burst in', 'bust in', 'butt in', 'charge in', 'come barging in', 'come between'],
    'work of art': ['art object', 'brainchild', 'bric-a-brac', 'classic', 'composition', 'creation', 'design', 'grotesque', 'kitsch', 'master', 'masterpiece', 'masterwork'],
    'work on': ['abuse', 'act on', 'act upon', 'advocate', 'affect', 'apply pressure', 'approach', 'bear upon', 'beset', 'besiege', 'blandish', 'bleed'],
    'work out': ['accommodate', 'accomplish', 'achieve', 'add', 'adjust', 'algebraize', 'amplify', 'answer', 'arrange', 'attain', 'attend', 'become of'],
    'work stoppage': ['arrest', 'bell', 'boycott', 'boycottage', 'check', 'checkmate', 'cutoff', 'dead stop', 'deadlock', 'end', 'endgame', 'ending'],
    'work toward': ['bend to', 'bias', 'conduce', 'contribute', 'dispose', 'go', 'have a tendency', 'head', 'incline', 'lead', 'lean', 'look to'],
    'work up': ['pap test', 'aggravate', 'agitate', 'anatomic diagnosis', 'annoy', 'arouse', 'arrange', 'awake', 'awaken', 'beat', 'beat up', 'biological diagnosis'],
    'work well': ['be blooded', 'be effortless', 'be painless', 'be successful', 'catch on', 'click', 'coast', 'come off', 'connect', 'farewell', 'flow', 'give no trouble'],
    'work wonders': ['be blooded', 'be successful', 'catch on', 'click', 'come off', 'connect', 'farewell', 'go', 'go great guns', 'go off', 'go over', 'go over big'],
    'workable': ['achievable', 'actable', 'answerable', 'applicable', 'ascertainable', 'attainable', 'banausic', 'capable of solution', 'compassable', 'decipherable', 'decodable', 'determinable'],
    'workaday': ['attic', 'banausic', 'breadwinning', 'businesslike', 'chaste', 'classic', 'classical', 'commercial', 'common', 'commonplace', 'everyday', 'garden'],
    'workbench': ['agency', 'ambo', 'atelier', 'bar', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'board', 'buffet', 'butcher shop', 'company'],
    'workbook': ['domesday book', 'abecedarium', 'abecedary', 'account book', 'address book', 'adversaria', 'album', 'alphabet book', 'annual', 'appointment calendar', 'appointment schedule', 'battledore'],
    'worked up': ['agog', 'angered', 'angry', 'aquiver', 'aroused', 'atingle', 'atwitter', 'browned-off', 'bursting', 'carried away', 'cross', 'ebullient'],
    'worker': ['actor', 'agent', 'ant', 'architect', 'army ant', 'artisan', 'assistant', 'author', 'bee', 'black ant', 'blue-collar worker', 'brainworker'],
    'workforce': ['men', 'manpower', 'work force', 'hands'],
    'workhorse': ['beast of burden', 'bidet', 'buck', 'carriage horse', 'cart horse', 'cavalry horse', 'draft horse', 'dray horse', 'driving horse', 'drudge', 'fag', 'fill horse'],
    'workhouse': ['agency', 'almshouse', 'asylum', 'atelier', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'butcher shop', 'company', 'concern', 'corporation'],
    'working': ['accomplishment', 'acetification', 'acidification', 'acidulation', 'act', 'acting', 'action', 'active', 'activism', 'activity', 'agency', 'alive'],
    'working class': ['bourgeois', 'bourgeoisie', 'common people', 'common run', 'common sort', 'commonage', 'commonality', 'commonalty', 'commoners', 'commons', 'laborers', 'linendrapers'],
    'workingman': ['blue-collar worker', 'breadwinner', 'casual', 'casual laborer', 'common laborer', 'day laborer', 'employee', 'factory worker', 'flunky', 'free lance', 'free-lancer', 'full-time worker'],
    'workings': ['abysm', 'abyss', 'act', 'acting', 'action', 'activism', 'activity', 'agency', 'bank', 'behavior', 'chasm', 'clockworks'],
    'workman': ['blue-collar worker', 'breadwinner', 'casual', 'casual laborer', 'common laborer', 'day laborer', 'employee', 'factory worker', 'flunky', 'free lance', 'free-lancer', 'full-time worker'],
    'workmanlike': ['daedalian', 'ok', 'acceptable', 'adept', 'adequate', 'admissible', 'adroit', 'all right', 'apt', 'artistic', 'authoritative', 'better than nothing'],
    'workmanship': ['ability', 'address', 'adeptness', 'adroitness', 'airmanship', 'architecture', 'artfulness', 'artisanship', 'artistry', 'assembly', 'bravura', 'brilliance'],
    'workout': ['athletics', 'audition', 'bench test', 'breather', 'calisthenics', 'constitutional', 'daily dozen', 'drill', 'dry run', 'exercise', 'exercising', 'flight test'],
    'workroom': ['agency', 'atelier', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'butcher shop', 'company', 'concern', 'corporation', 'desk', 'establishment'],
    'works': ['abdomen', 'accomplished fact', 'accomplishment', 'achievement', 'act', 'acta', 'action', 'adventure', 'anus', 'appendix', 'benevolences', 'bleachworks'],
    'workshop': ['agency', 'atelier', 'barbershop', 'beauty parlor', 'beauty shop', 'bench', 'butcher shop', 'company', 'concern', 'corporation', 'desk', 'establishment'],
    'world': ['africa', 'america', 'antipodes', 'asia', 'asia major', 'asia minor', 'australasia', 'copernican universe', 'earth', 'east', 'eastern hemisphere', 'einsteinian universe'],
    'world shaking': ['big', 'big-league', 'big-name', 'big-time', 'bigwig', 'bigwigged', 'consequential', 'considerable', 'double-barreled', 'earthshaking', 'grand', 'great'],
    'world view': ['weltanschauung', 'articles of religion', 'body of ideas', 'catechism', 'climate', 'climate of opinion', 'credenda', 'credo', 'creed', 'cult', 'doctrinal statement', 'ethos'],
    'world weary': ['blase', 'bowed-down', 'cast down', 'dashed', 'dejected', 'depressed', 'despairing', 'despondent', 'desponding', 'discouraged', 'disheartened', 'dispirited'],
    'world wide': ['all-comprehending', 'all-comprehensive', 'all-covering', 'all-embracing', 'all-encompassing', 'all-filling', 'all-including', 'all-inclusive', 'all-pervading', 'allover', 'catholic', 'cosmopolitan'],
    'worldly': ['philistine', 'banausic', 'blase', 'bodily', 'carnal', 'carnal-minded', 'corporal', 'corporeal', 'cosmopolitan', 'cosmopolite', 'disenchanted', 'disillusioned'],
    'worldly wise': ['blase', 'cosmopolitan', 'cosmopolite', 'experienced', 'knowing', 'mature', 'matured', 'not born yesterday', 'old', 'practiced', 'ripe', 'ripened'],
    'worlds apart': ['assorted', 'at odds', 'at variance', 'contrary', 'contrasted', 'contrasting', 'departing', 'deviating', 'deviative', 'different', 'differentiated', 'differing'],
    'worm': ['amble', 'angleworm', 'animal', 'armyworm', 'beast', 'blast', 'blight', 'blighter', 'bollworm', 'bookworm', 'cancer', 'canker'],
    'worm eaten': ['blasted', 'blighted', 'blown', 'despoiled', 'flyblown', 'frowsty', 'frowsy', 'frowzy', 'fusty', 'maggoty', 'mildewed', 'moldering'],
    'worm in': ['barge in', 'break in', 'break in upon', 'burst in', 'butt in', 'charge in', 'come between', 'crash', 'crash in', 'crash the gates', 'creep in', 'crowd in'],
    'worm out of': ['alibi', 'alibi out of', 'apologize for', 'arouse', 'bring forth', 'bring out', 'bring to light', 'call forth', 'call out', 'call up', 'catechize', 'cover with excuses'],
    'wormy': ['barfy', 'beset', 'blasted', 'blighted', 'blown', 'crappy', 'despoiled', 'disgusting', 'fecal', 'feculent', 'fetid', 'filthy'],
    'worn': ['abated', 'ablated', 'ablative', 'attenuated', 'ausgespielt', 'back-number', 'banal', 'bare', 'bated', 'belittled', 'bewhiskered', 'biodegradable'],
    'worn away': ['ablated', 'burnt up', 'by the board', 'consumed', 'depleted', 'dissipated', 'drained', 'eaten up', 'effete', 'eroded', 'exhausted', 'expended'],
    'worn out': ['abandoned', 'abjured', 'ablated', 'all in', 'antiquated', 'antique', 'archaic', 'ausgespielt', 'beat', 'beat up', 'beaten', 'bone-weary'],
    'worried': ['annoyed', 'anxious', 'badgered', 'baited', 'bedeviled', 'beset', 'bothered', 'bugged', 'bullyragged', 'chivied', 'deviled', 'distracted'],
    'worrisome': ['aggravating', 'annoying', 'bothering', 'bothersome', 'chafing', 'disquieting', 'distressful', 'distressing', 'disturbing', 'exasperating', 'fretting', 'galling'],
    'worry': ['ado', 'afflict', 'aggravate', 'aggravation', 'aggrieve', 'agitate', 'ail', 'anguish', 'annoy', 'annoyance', 'anxiety', 'bad news'],
    'worrying': ['aggravating', 'annoying', 'bothering', 'bothersome', 'chafing', 'disquieting', 'distressful', 'distressing', 'disturbing', 'exasperating', 'fretting', 'galling'],
    'worse': ['aggravated', 'altered', 'amplified', 'annoyed', 'augmented', 'better', 'broken', 'burned', 'burst', 'busted', 'changeable', 'changed'],
    'worsen': ['accommodate', 'adapt', 'adjust', 'agent provocateur', 'aggravate', 'alter', 'ameliorate', 'amplify', 'annoy', 'augment', 'be changed', 'be converted into'],
    'worsened': ['aggravated', 'amplified', 'annoyed', 'augmented', 'broken', 'burned', 'burst', 'busted', 'checked', 'chipped', 'cracked', 'crazed'],
    'worsening': ['about-face', 'accommodation', 'adaptation', 'adjustment', 'aggravation', 'alteration', 'amelioration', 'amplification', 'annoyance', 'apostasy', 'augmentation', 'betterment'],
    'worship': ['amor', 'christian love', 'eros', 'platonic love', 'accord respect to', 'admiration', 'admire', 'adoration', 'adore', 'affection', 'agape', 'apotheosis'],
    'worshiper': ['admirer', 'adorer', 'amateur', 'beadsman', 'booster', 'buff', 'celebrant', 'chapelgoer', 'churchgoer', 'collector', 'communicant', 'congregation'],
    'worshipful': ['christian', 'christianlike', 'christianly', 'acknowledged', 'admiring', 'admitted', 'adorant', 'adoring', 'apotheosizing', 'august', 'awe-inspiring', 'awed'],
    'worshiping': ['admiring', 'adorant', 'adoration', 'adoring', 'apotheosizing', 'awed', 'awestricken', 'awestruck', 'co-worship', 'cult', 'cultism', 'cultus'],
    'worst': ['abominable', 'arrant', 'atrocious', 'awful', 'base', 'bear the palm', 'beastly', 'beat', 'beat all hollow', 'beat hollow', 'beneath contempt', 'best'],
    'worsted': ['all up with', 'beat', 'beaten', 'bested', 'confounded', 'defeated', 'discomfited', 'done for', 'done in', 'down', 'fallen', 'fixed'],
    'wort': ['algae', 'autophyte', 'bean', 'bracken', 'brown algae', 'climber', 'conferva', 'confervoid', 'creeper', 'diatom', 'fern', 'fruits and vegetables'],
    'worth': ['accent', 'account', 'ad valorem', 'advantage', 'advantageousness', 'agreeableness', 'appraised', 'approbation', 'approval', 'assessed', 'auspiciousness', 'avail'],
    'worthless': ['ng', 'abominable', 'arrant', 'atrocious', 'awful', 'base', 'beastly', 'beggarly', 'beneath contempt', 'beneath notice', 'blameworthy', 'bootless'],
    'worthwhile': ['advantageous', 'advisable', 'appropriate', 'banausic', 'becoming', 'befitting', 'breadwinning', 'congruous', 'convenient', 'decent', 'desirable', 'expedient'],
    'worthy': ['christian', 'establishment', 'vip', 'able', 'acceptable', 'acceptable person', 'admirable', 'admissible', 'aristocratic', 'au fait', 'august', 'baron'],
    'wotan': ['aesir', 'ares', 'athena', 'balder', 'bellona', 'bor', 'bori', 'bragi', 'donar', 'enyo', 'forseti', 'frey'],
    'would be': ['assuming', 'byname', 'cognominal', 'diminutive', 'epithetic', 'formal', 'honorific', 'hypocoristic', 'in name only', 'insolent', 'nominal', 'nominative'],
    'wound': ['abrade', 'abrasion', 'abscess', 'abuse', 'ache', 'aching', 'afflict', 'affront', 'aggrieve', 'agonize', 'ail', 'anguish'],
    'wound up': ['sol', 'ago', 'all bets off', 'all off', 'all over', 'all up', 'antiquated', 'antique', 'at an end', 'blown over', 'by', 'bygone'],
    'wounded': ['aching', 'afflicted', 'aggrieved', 'agonized', 'anguished', 'bleeding', 'bruised', 'convulsed', 'crucified', 'cut', 'distressed', 'grieved'],
    'woven': ['braided', 'enlaced', 'entwined', 'fretted', 'handwoven', 'interknit', 'interlaced', 'interthreaded', 'intertied', 'intertissued', 'intertwined', 'interwoven'],
    'wow': ['amuse', 'bang', 'becharm', 'beguile', 'belly laugh', 'best seller', 'bewitch', 'big hit', 'birdies', 'blooping', 'blue story', 'blurping'],
    'wrack': ['algae', 'autophyte', 'bean', 'bloodbath', 'blue ruin', 'bracken', 'breakdown', 'breaking up', 'breakup', 'bring to ruin', 'brown algae', 'carnage'],
    'wrack and ruin': ['bloodbath', 'blue ruin', 'breakup', 'carnage', 'consumption', 'damnation', 'decimation', 'depredation', 'desolation', 'despoilment', 'despoliation', 'destruction'],
    'wrack up': ['atomize', 'break to pieces', 'cleave', 'demolish', 'disassemble', 'disintegrate', 'dismantle', 'fragment', 'make mincemeat of', 'pick to pieces', 'pull in pieces', 'pull to pieces'],
    'wraith': ['doppelganger', 'masan', 'apparition', 'appearance', 'astral', 'astral spirit', 'banshee', 'co-walker', 'control', 'departed spirit', 'disembodied spirit', 'double'],
    'wrangle': ['altercate', 'altercation', 'argue', 'argufy', 'argument', 'bandy words', 'bicker', 'bicker over', 'bickering', 'blood feud', 'brawl', 'broil'],
    'wrangler': ['philadelphia lawyer', 'apologist', 'arguer', 'argufier', 'battler', 'belligerent', 'belted knight', 'bickerer', 'bitter-ender', 'blade', 'bravo', 'brawler'],
    'wrangling': ['kilkenny cats', 'aggressive', 'altercation', 'apologetics', 'apologia', 'apology', 'argument', 'argumentation', 'bellicose', 'belligerent', 'bicker', 'bickering'],
    'wrap': ['apparel', 'array', 'attire', 'bale', 'band', 'bandage', 'bandaging', 'bedeck', 'bedrape', 'beleaguer', 'belt', 'bend'],
    'wrap up': ['apparel', 'array', 'attire', 'bale', 'band', 'bandage', 'bedeck', 'bedrape', 'belt', 'bend', 'bind', 'bind up'],
    'wrapped': ['absorbed', 'armored', 'cased', 'ceiled', 'cloaked', 'clouded', 'coated', 'compassed', 'coped', 'covered', 'covert', 'cowled'],
    'wrapped up': ['absorbed', 'accumulated', 'agglomerate', 'aggregate', 'amassed', 'assembled', 'bunched', 'bundled', 'cleaned up', 'clumped', 'clustered', 'collected'],
    'wrapped up in': ['absorbed', 'absorbed in', 'attached to', 'buried in', 'caught up in', 'contemplating', 'contemplative', 'crazy about', 'devoted', 'devoted to', 'enamored of', 'engaged'],
    'wrapper': ['smyth sewing', 'backing', 'bandage', 'bandaging', 'bibliopegy', 'binder', 'binder board', 'binding', 'book cloth', 'book cover', 'book jacket', 'bookbinding'],
    'wrapping': ['ambient', 'bandage', 'bandaging', 'binder', 'binding', 'blanketing', 'blocking', 'blotting out', 'cementwork', 'circling', 'circumambient', 'circumferential'],
    'wraps': ['bamboo curtain', 'barrier of secrecy', 'blackout', 'censorship', 'cover', 'curtain', 'disguise', 'hush-up', 'iron curtain', 'ironbound security', 'oath of secrecy', 'official secrecy'],
    'wrath': ['a transient madness', 'acedia', 'acerbity', 'acrimony', 'anger', 'angriness', 'asperity', 'avarice', 'avaritia', 'deadly sin', 'enragement', 'envy'],
    'wrathful': ['angered', 'angry', 'browned-off', 'cross', 'heated', 'incensed', 'indignant', 'irate', 'ireful', 'livid', 'mad', 'pissed'],
    'wreak': ['accomplish', 'achieve', 'bring', 'bring about', 'bring off', 'bring to pass', 'bring upon', 'commit', 'do', 'do to', 'effect', 'effectuate'],
    'wreak havoc': ['abuse', 'afflict', 'aggrieve', 'befoul', 'bewitch', 'blight', 'bring to ruin', 'condemn', 'confound', 'consume', 'corrupt', 'crucify'],
    'wreath': ['old mug', 'achievement', 'alerion', 'animal charge', 'annular muscle', 'annulet', 'annulus', 'areola', 'argent', 'armorial bearings', 'armory', 'arms'],
    'wreathe': ['band', 'bead', 'begird', 'bejewel', 'belt', 'belt in', 'beribbon', 'bespangle', 'braid', 'cincture', 'circle', 'coil'],
    'wreathed': ['adorned', 'beaded', 'bedecked', 'bedizened', 'befrilled', 'bejeweled', 'beribboned', 'bespangled', 'braided', 'compassed', 'decked out', 'decorated'],
    'wreck': ['accident', 'assault', 'atomize', 'attack', 'auto', 'autocar', 'automobile', 'bankrupt', 'barbarize', 'batter', 'beach', 'blight'],
    'wrecked': ['aground', 'ausgespielt', 'bankrupt', 'blasted', 'blighted', 'botched', 'broken', 'castaway', 'desolated', 'destroyed', 'devastated', 'done for'],
    'wrecker': ['animal', 'annihilator', 'anthropophagite', 'arsonist', 'barbarian', 'beast', 'biblioclast', 'bomber', 'brute', 'burner', 'cannibal', 'demolisher'],
    'wrench': ['allen wrench', 'stillson wrench', 'abrade', 'abrasion', 'ache', 'aching', 'acute pain', 'adjustable wrench', 'alligator wrench', 'anamorphism', 'anamorphosis', 'asymmetry'],
    'wrest': ['anamorphism', 'anamorphosis', 'arrogate', 'asymmetry', 'avulse', 'badger', 'bend', 'blackmail', 'buckle', 'claim', 'color', 'confiscate'],
    'wrestle': ['agonize', 'battle', 'box', 'brawl', 'broil', 'buffet', 'clash', 'close', 'collide', 'combat', 'come to blows', 'contend'],
    'wrestler': ['amateur athlete', 'archer', 'athlete', 'ballplayer', 'baseballer', 'baseman', 'batter', 'battery', 'blocking back', 'bowman', 'catcher', 'center'],
    'wretch': ['bowery bum', 'beachcomber', 'beggar', 'beggarly fellow', 'blackguard', 'blighter', 'budmash', 'bum', 'bummer', 'caitiff', 'cur', 'derelict'],
    'wretched': ['abject', 'abominable', 'adverse', 'affecting', 'afflicted', 'afflictive', 'antagonistic', 'arrant', 'atrocious', 'awful', 'base', 'beastly'],
    'wriggle': ['fidget', 'flip out', 'flow', 'flutter', 'freak out on', 'get high on', 'glide', 'glow', 'go pitapat', 'have the fidgets', 'have the shakes', 'heave'],
    'wright': ['ancestors', 'apprentice', 'architect', 'artificer', 'artisan', 'artist', 'author', 'begetter', 'beginner', 'builder', 'conceiver', 'constructor'],
    'wring': ['afflict', 'agonize', 'ail', 'anamorphism', 'anamorphosis', 'asymmetry', 'badger', 'bend', 'bite', 'blackmail', 'bloody', 'buckle'],
    'wrinkle': ['abbreviate', 'age', 'bezel', 'bonus', 'bristle', 'canal', 'canalize', 'carve', 'chamfer', 'channel', 'chase', 'cheat the undertaker'],
    'wrinkled': ['advanced', 'advanced in life', 'advanced in years', 'aged', 'along in years', 'ancient', 'atrophied', 'brittle', 'canaliculate', 'canaliculated', 'chamfered', 'channeled'],
    'wrist': ['ankle', 'arm', 'articulation', 'biceps', 'boundary', 'butt', 'cervix', 'clinch', 'closure', 'connecting link', 'connecting rod', 'connection'],
    'wristband': ['anklet', 'armlet', 'band', 'bangle', 'beads', 'belt', 'bijou', 'bracelet', 'breastpin', 'brooch', 'chain', 'chaplet'],
    'writ': ['bench warrant', 'blank', 'capias', 'caveat', 'chirograph', 'death warrant', 'docket', 'document', 'dossier', 'fieri facias', 'file', 'form'],
    'write': ['adapt', 'arrange', 'assemble', 'author', 'book', 'bring to life', 'build', 'calendar', 'carve', 'cast', 'catalog', 'catch a likeness'],
    'write in': ['australian ballot', 'hare system', 'aye', 'ballot', 'canvass', 'canvassing', 'casting vote', 'counting heads', 'cumulative voting', 'deciding vote', 'division', 'enfranchisement'],
    'write off': ['abate', 'abatement', 'abolish', 'abolishment', 'abolition', 'abrogate', 'abrogation', 'absolve', 'agio', 'allow', 'allowance', 'annul'],
    'write out': ['book', 'calendar', 'carve', 'catalog', 'chalk', 'chalk up', 'check in', 'chronicle', 'copy', 'copy out', 'cut', 'docket'],
    'write up': ['pr', 'advertise', 'analysis', 'announce', 'ballyhoo', 'bark', 'bill', 'blurb', 'book', 'boost', 'break the news', 'bright light'],
    'writer': ['addressee', 'advertising writer', 'amanuensis', 'annalist', 'art critic', 'author', 'authoress', 'belletrist', 'bibliographer', 'calligrapher', 'chirographer', 'clerk'],
    'writhe': ['ache', 'agonize', 'ail', 'anguish', 'bend', 'blanch', 'bleed', 'blench', 'buckle', 'contort', 'crook', 'crumple'],
    'writing': ['alphabet', 'alphabetic character', 'art', 'article', 'artistry', 'authorcraft', 'authorship', 'autograph', 'automatic writing', 'best seller', 'black and white', 'blank'],
    'writing system': ['arabic', 'armenian', 'assyrian', 'avestan', 'babylonian', 'berber', 'chalcidian', 'cherokee', 'coptic', 'cretan', 'cyrillic', 'elamitic'],
    'written': ['appointed', 'autograph', 'autographic', 'calligraphic', 'chirographic', 'cursive', 'destined', 'devoted', 'doomed', 'engrossed', 'fatal', 'fated'],
    'written down': ['booked', 'documented', 'down', 'enrolled', 'entered', 'filed', 'indexed', 'inscribed', 'legal', 'logged', 'minuted', 'of record'],
    'wrong': ['abandoned', 'aberrancy', 'aberrant', 'aberration', 'abnormal', 'abominable', 'abomination', 'abroad', 'abuse', 'accursed', 'adrift', 'afflict'],
    'wrong impression': ['airy nothing', 'autism', 'bubble', 'chimera', 'daydream', 'deception', 'deluded belief', 'delusion', 'dereism', 'dream', 'dream vision', 'dreamland'],
    'wrongdoer': ['bad person', 'criminal', 'crook', 'culprit', 'deceiver', 'delinquent', 'evil man', 'evil person', 'evildoer', 'felon', 'gangster', 'lawbreaker'],
    'wrongdoing': ['amorality', 'backsliding', 'bad policy', 'badness', 'carnality', 'crime', 'criminality', 'delict', 'delinquency', 'diablerie', 'discourtesy', 'disorder'],
    'wrongful': ['aberrant', 'abnormal', 'abominable', 'actionable', 'against the law', 'anarchic', 'anarchistic', 'anomic', 'atrocious', 'black-market', 'bootleg', 'chargeable'],
    'wrongheaded': ['boeotian', 'asinine', 'balky', 'beef-brained', 'beef-witted', 'blockish', 'bovine', 'bullheaded', 'cantankerous', 'chumpish', 'cloddish', 'contrary'],
    'wroth': ['angered', 'angry', 'browned-off', 'cross', 'heated', 'incensed', 'indignant', 'irate', 'ireful', 'livid', 'mad', 'pissed'],
    'wrought up': ['agog', 'angered', 'angry', 'aquiver', 'aroused', 'atingle', 'atwitter', 'browned-off', 'bursting', 'carried away', 'cross', 'ebullient'],
    'wrung': ['afflicted', 'agonized', 'clawed', 'convulsed', 'crucified', 'distressed', 'harrowed', 'hurt', 'hurting', 'in distress', 'in pain', 'lacerated'],
    'wry': ['agee', 'agee-jawed', 'askance', 'askant', 'askew', 'askewgee', 'asquint', 'awry', 'catawampous', 'catawamptious', 'cockeyed', 'crooked'],
    'wryneck': ['adenoiditis', 'adrenitis', 'appendicitis', 'arteritis', 'arthritis deformans', 'arthritis fungosa', 'arthritis pauperum', 'atrophic arthritis', 'atrophic inflammation', 'blennorrhagic arthritis', 'bowlegs', 'brain fever'],
    'x ray': ['becquerel ray', 'ecg', 'eeg', 'ekg', 'grenz ray', 'photostat', 'roentgen ray', 'x radiation', 'x-ray movie', 'xerox', 'actinic ray', 'actinism'],
    'xenophobia': ['anglophobia', 'francophobia', 'germanophobia', 'jim crow', 'jim crow law', 'russophobia', 'abhorrence', 'abomination', 'agoraphobia', 'alien', 'anti-semitism', 'antipathy'],
    'xerography': ['albertype', 'book printing', 'chromotypography', 'chromotypy', 'chromoxylography', 'collotype', 'color printing', 'duplication', 'electronography', 'electrostatic printing', 'graphic arts', 'gravure'],
    'xerox': ['ditto copy', 'photostat', 'x-ray', 'xerox copy', 'blowup', 'blueprint', 'calotype', 'capture on film', 'clone', 'contact print', 'contact printing', 'copy'],
    'xylophone': ['battery', 'bells', 'bones', 'castanets', 'celesta', 'chime', 'chimes', 'clappers', 'crash cymbal', 'cymbals', 'finger cymbals', 'gamelan'],
    'y shaped': ['v-shaped', 'akimbo', 'angular', 'arboreal', 'arborescent', 'arboriform', 'bent', 'biforked', 'bifurcate', 'bifurcated', 'branched', 'branching'],
    'yacht': ['bark', 'bawley', 'bilander', 'boat', 'brig', 'brigantine', 'bully', 'buss', 'canoe', 'caravel', 'carry sail', 'cat'],
    'yachting': ['boating', 'canoeing', 'circumnavigation', 'coasting', 'cruising', 'gunkholing', 'motorboating', 'navigability', 'navigating', 'navigation', 'passage-making', 'periplus'],
    'yachtsman': ['bargee', 'bargeman', 'barger', 'boat-handler', 'boater', 'boatman', 'boatsman', 'ferrier', 'ferryman', 'galley slave', 'gondolier', 'lighterman'],
    'yak': ['brahman', 'indian buffalo', 'aurochs', 'babble', 'babblement', 'bat the breeze', 'bavardage', 'beat the gums', 'beef', 'beef cattle', 'beeves', 'bibble-babble'],
    'yammer': ['babble', 'bark', 'battle cry', 'bawl', 'bellow', 'call', 'caterwaul', 'chat', 'chatter', 'cheer', 'clack', 'creak'],
    'yammering': ['bawling', 'blatant', 'boanergean', 'brawling', 'clamorous', 'clamoursome', 'crying', 'loudmouthed', 'noisy', 'obstreperous', 'openmouthed', 'screaming'],
    'yank': ['bob', 'clutch', 'evulse', 'flick', 'flip', 'flirt', 'flounce', 'grab', 'hitch', 'jerk', 'jig', 'jigger'],
    'yankee': ['acadian', 'anglo-indian', 'bolshevik', 'bolshevist', 'bolshie', 'brooklynese', 'cajun', 'canadian french', 'carbonarist', 'carbonaro', 'castroist', 'castroite'],
    'yap': ['air a grievance', 'backwoodsman', 'bark', 'bat the breeze', 'battle cry', 'bawl', 'bay', 'bazoo', 'beat the gums', 'beef', 'bell', 'bellow'],
    'yapping': ['bawling', 'beef', 'beefing', 'bellyache', 'bellyaching', 'bitch', 'bitching', 'blatant', 'boanergean', 'brawling', 'clamorous', 'clamoursome'],
    'yard': ['c-note', 'g-note', 'arena', 'armory', 'arsenal', 'assembly line', 'assembly plant', 'atomic energy plant', 'beleaguer', 'beset', 'besiege', 'bindery'],
    'yardman': ['baggage man', 'bakehead', 'brakeman', 'brakie', 'butcher', 'conductor', 'dispatcher', 'fireman', 'footplate man', 'guard', 'lineman', 'porter'],
    'yardstick': ['barometer', 'basis', 'benchmark', 'canon', 'check', 'criterion', 'degree', 'exemplar', 'gauge', 'graduated scale', 'measure', 'model'],
    'yarn': ['account', 'anecdotage', 'anecdote', 'belly laugh', 'blague', 'blue story', 'braid', 'brail', 'cable', 'causerie', 'chat', 'chin'],
    'yaw': ['aberrancy', 'aberration', 'about ship', 'back and fill', 'bank', 'bear away', 'bear off', 'bear to starboard', 'beat', 'beat about', 'bend', 'bias'],
    'yawn': ['aperture', 'boredom', 'broaching', 'cavity', 'chasm', 'check', 'clearing', 'cleft', 'crack', 'dehisce', 'dehiscence', 'disclosure'],
    'yawning': ['abysmal', 'abyssal', 'agape', 'ajar', 'anesthetized', 'bottomless', 'cataleptic', 'cavernous', 'comatose', 'deep as hell', 'dehiscence', 'dehiscent'],
    'yawp': ['bark', 'battle cry', 'bawl', 'bay', 'beef', 'bell', 'bellow', 'bellyache', 'bitch', 'blare', 'blat', 'blate'],
    'yaws': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'yea': ['australian ballot', 'hare system', 'ok', 'a fortiori', 'above all', 'acceptance', 'additionally', 'adherence', 'admiration', 'affirmative', 'affirmative attitude', 'affirmativeness'],
    'year': ['abundant year', 'academic year', 'annum', 'bissextile year', 'calendar month', 'calendar year', 'century', 'common year', 'day', 'decade', 'decennary', 'decennium'],
    'yearbook': ['domesday book', 'account', 'account book', 'account rendered', 'accounting', 'acta', 'address book', 'adversaria', 'album', 'annual', 'appointment calendar', 'appointment schedule'],
    'yearling': ['brahman', 'indian buffalo', 'aurochs', 'babe', 'baby', 'baby bunting', 'bambino', 'beef', 'beef cattle', 'beeves', 'bison', 'bossy'],
    'yearly': ['annual', 'annually', 'biannual', 'biennial', 'bimonthly', 'biweekly', 'catamenial', 'centenary', 'centennial', 'daily', 'decennial', 'diurnal'],
    'yearn': ['ache', 'covet', 'crave', 'desire', 'dream', 'fancy', 'hanker', 'hunger', 'itch', 'long', 'lust', 'pant'],
    'yearn for': ['ache for', 'be dying for', 'be hurting for', 'clamor for', 'cry for', 'gape for', 'hone for', 'hope for', 'itch for', 'languish for', 'long for', 'lust for'],
    'yearning': ['amor', 'christian love', 'eros', 'heimweh', 'platonic love', 'aching', 'admiration', 'adoration', 'affection', 'agape', 'ardency', 'ardor'],
    'yeast': ['agent', 'alterant', 'alterative', 'alterer', 'catalyst', 'catalytic agent', 'ferment', 'foam', 'froth', 'innovationist', 'innovator', 'introducer'],
    'yeasty': ['agog', 'airy', 'aquiver', 'aroused', 'atingle', 'atwitter', 'barmy', 'bubbly', 'bursting', 'carried away', 'diastatic', 'dizzy'],
    'yecchy': ['barfy', 'bum', 'cheesy', 'crappy', 'creepy', 'crummy', 'dirty', 'disgusting', 'fecal', 'feculent', 'fetid', 'filthy'],
    'yell': ['alleluia', 'applaud', 'applause', 'bark', 'battle cry', 'bawl', 'bellow', 'bemoan', 'bewail', 'blare', 'blat', 'blubber'],
    'yell at': ['abuse', 'bark at', 'berate', 'betongue', 'blacken', 'execrate', 'fulminate against', 'jaw', 'load with reproaches', 'rag', 'rail at', 'rate'],
    'yelling': ['bawling', 'blatant', 'boanergean', 'brawling', 'clamorous', 'clamoursome', 'crying', 'loudmouthed', 'noisy', 'obstreperous', 'openmouthed', 'screaming'],
    'yellow': ['amytal', 'amytal pill', 'barnumesque', 'cassel yellow', 'claude tint', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill'],
    'yellow fever': ['african lethargy', 'asiatic cholera', 'chagres fever', 'german measles', 'haverhill fever', 'acute articular rheumatism', 'ague', 'alkali disease', 'amebiasis', 'amebic dysentery', 'anthrax', 'bacillary dysentery'],
    'yellow jacket': ['amytal', 'amytal pill', 'demerol', 'dolophine', 'luminal', 'luminal pill', 'mickey finn', 'nembutal', 'nembutal pill', 'seconal', 'seconal pill', 'tuinal'],
    'yellow journalism': ['blood and thunder', 'demonstrativeness', 'emotional appeal', 'emotionalism', 'emotionality', 'emotionalization', 'emotionalizing', 'emotiveness', 'emotivity', 'histrionics', 'human interest', 'love interest'],
    'yellow pages': ['baedeker', 'bibliography', 'business directory', 'catalog', 'checklist', 'city directory', 'classified directory', 'directory', 'finding list', 'guidebook', 'handbook', 'handlist'],
    'yellow race': ['alpine race', 'australoid race', 'bushman race', 'mediterranean race', 'melanesian race', 'nilotic race', 'nordic race', 'papuan race', 'polynesian race', 'pygmoid race', 'black race', 'brown race'],
    'yelp': ['air a grievance', 'bark', 'battle cry', 'bawl', 'bay', 'beef', 'bell', 'bellow', 'bellyache', 'bitch', 'blare', 'blat'],
    'yelping': ['bawling', 'blatant', 'boanergean', 'brawling', 'clamorous', 'clamoursome', 'crying', 'loudmouthed', 'noisy', 'obstreperous', 'openmouthed', 'screaming'],
    'yen': ['deutschmark', 'heimweh', 'mark', 'reichsmark', 'ache', 'aching', 'afghani', 'anna', 'baht', 'cent', 'centavo', 'centime'],
    'yen for': ['ache for', 'be dying for', 'be hurting for', 'clamor for', 'cry for', 'gape for', 'hone for', 'hope for', 'itch for', 'languish for', 'long for', 'lust for'],
    'yenta': ['paul pry', 'peeping tom', 'a tale-bearing animal', 'backseat driver', 'busybody', 'eavesdropper', 'gossip', 'gossip columnist', 'gossiper', 'gossipmonger', 'inquirer', 'inquisitive'],
    'yeoman': ['bauer', 'ganymede', 'hebe', 'agriculturalist', 'agriculturist', 'agrologist', 'agronomist', 'airline hostess', 'airline stewardess', 'attendant', 'bakehead', 'batman'],
    'yes': ['australian ballot', 'hare system', 'ok', 'roger', 'abide by', 'absolutely', 'accede', 'accept', 'acclaim', 'accordantly', 'acquiesce', 'acquiesce in'],
    'yes man': ['babbitt', 'middle american', 'philistine', 'accepter', 'anal character', 'apple-polisher', 'ass-licker', 'assentator', 'assenter', 'backscratcher', 'backslapper', 'bootlick'],
    'yesterday': ['aforetime', 'before', 'before now', 'beforetime', 'bygone days', 'bygone times', 'days gone by', 'dead past', 'earlier', 'erenow', 'erewhile', 'erst'],
    'yesteryear': ['bygone days', 'bygone times', 'days gone by', 'dead past', 'foretime', 'former times', 'history', 'lang syne', 'past', 'past history', 'past times', 'recent past'],
    'yet': ['above', 'additionally', 'after a while', 'after all', 'again', 'albeit', 'all included', 'all the same', 'along', 'already', 'also', 'although'],
    'yield': ['abandon', 'abdicate', 'abjure', 'accede', 'accept', 'accommodate', 'accommodate with', 'accord', 'acknowledge', 'acknowledge defeat', 'adapt', 'adapt to'],
    'yielding': ['abandonment', 'abatement of differences', 'abdication', 'abjuration', 'abjurement', 'acceptance', 'accommodating', 'accommodation', 'acquiescence', 'acquiescent', 'adaptable', 'adjustment'],
    'yip': ['bark', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'bray', 'call', 'caterwaul'],
    'yippie': ['bohemian', 'bolshevik', 'jacobin', 'wobbly', 'anarchist', 'anarcho-syndicalist', 'beatnik', 'deviant', 'dissenter', 'dropout', 'extreme left-winger', 'extremist'],
    'yodel': ['anthem', 'ballad', 'bel canto', 'bravura', 'carol', 'chant', 'chirp', 'chirrup', 'choir', 'choral singing', 'chorus', 'coloratura'],
    'yodeler': ['heldentenor', 'meistersinger', 'alto', 'aria singer', 'baritenor', 'baritone', 'bass', 'basso', 'basso buffo', 'basso cantante', 'basso profundo', 'blues singer'],
    'yoga': ['anagoge', 'anagogics', 'anthroposophy', 'athletics', 'breather', 'cabala', 'cabalism', 'calisthenics', 'constitutional', 'daily dozen', 'drill', 'esotericism'],
    'yogi': ['albigensian', 'brahman', 'catharist', 'franciscan', 'ramwat', 'sabbatarian', 'trappist', 'waldensian', 'abstainer', 'adept', 'anchorite', 'anthroposophist'],
    'yogurt': ['acid', 'acidulant', 'bread-and-butter pickle', 'butter', 'buttermilk', 'caudle', 'certified milk', 'cheese', 'chokecherry', 'condensed milk', 'cottonseed flour', 'crab apple'],
    'yoke': ['oregon boat', 'accouple', 'accumulate', 'agglutinate', 'amass', 'articulate', 'assemble', 'associate', 'back band', 'backstrap', 'band', 'bearing rein'],
    'yoked': ['affiliate', 'affiliated', 'allied', 'assembled', 'associate', 'associated', 'banded together', 'biconjugate', 'bigeminate', 'bijugate', 'bound', 'bracketed'],
    'yokel': ['babbitt', 'philistine', 'arriviste', 'babe', 'backwoodsman', 'blockhead', 'blunderer', 'blunderhead', 'boor', 'boorish', 'botcher', 'bounder'],
    'yom kippur': ['day of atonement', 'fast of av', 'feast of tabernacles', 'feast of weeks', 'hanukkah', 'high holy days', 'lent', 'new year', 'ninth of av', 'passover', 'pentecost', 'pesach'],
    'yore': ['auld lang syne', 'days beyond recall', 'days of old', 'days of yore', 'early times', 'eld', 'foretime', 'good old times', 'lang syne', 'long ago', 'old days', 'old story'],
    'you': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'ego', 'ethical self', 'he', 'her', 'herself', 'him', 'himself'],
    'young': ['adolescent', 'babies', 'babyhood', 'babyish', 'boyhood', 'boyish', 'brood', 'callow', 'childish', 'childkind', 'childlike', 'children'],
    'young man': ['casanova', 'don juan', 'lothario', 'romeo', 'amoroso', 'beau', 'boy', 'boyfriend', 'bub', 'bubba', 'buck', 'bud'],
    'youngest': ['adolescent', 'baby', 'fledgling', 'hopeful', 'infant', 'junior', 'juvenal', 'juvenile', 'minor', 'pubescent', 'sapling', 'slip'],
    'youngster': ['breed', 'brood', 'bud', 'chick', 'children', 'chit', 'descendants', 'descent', 'family', 'fruit', 'grandchildren', 'great-grandchildren'],
    'yourself': ['i myself', 'alter', 'alter ego', 'alterum', 'better self', 'ego', 'ethical self', 'he', 'her', 'herself', 'him', 'himself'],
    'youth': ['adolescence', 'adolescent', 'adolescents', 'awkward age', 'baby', 'babyhood', 'beginnings', 'birth', 'boy', 'boyhood', 'bub', 'bubba'],
    'youthful': ['beardless', 'blooming', 'boyish', 'callow', 'florescent', 'flowering', 'flush', 'flushed', 'fresh', 'fresh as april', 'green', 'immature'],
    'yowl': ['bark', 'battle cry', 'bawl', 'bay', 'bell', 'bellow', 'blare', 'blat', 'blate', 'bleat', 'bray', 'call'],
    'yuck': ['belly laugh', 'boff', 'boffola', 'burst of laughter', 'cachinnation', 'cackle', 'chortle', 'chuckle', 'convulsion', 'crow', 'fit of laughter', 'gales of laughter'],
    'yucky': ['awful', 'bad', 'barfy', 'beastly', 'brackish', 'cloying', 'disgusting', 'fetid', 'foul', 'fulsome', 'high', 'icky'],
    'yummy': ['adorable', 'agreeable', 'ambrosial', 'appetizing', 'dainty', 'darling', 'delectable', 'delicate', 'delicious', 'delightful', 'exquisite', 'good'],
    'zag': ['angle', 'angle off', 'apex', 'bend', 'bifurcate', 'bifurcation', 'bight', 'branch', 'cant', 'chevron', 'coin', 'corner'],
    'zambo': ['cape colored', 'eurasian', 'cattalo', 'citrange', 'cross', 'crossbreed', 'griffe', 'half blood', 'half-bred', 'half-breed', 'half-caste', 'high yellow'],
    'zany': ['columbine', 'hanswurst', 'harlequin', 'pantalone', 'pantaloon', 'polichinelle', 'pulcinella', 'punch', 'punchinello', 'scaramouch', 'absurd', 'ament'],
    'zap': ['ko', 'blast', 'blot out', 'bump off', 'call off', 'cancel', 'complete', 'croak', 'delete', 'dispose of', 'do in', 'drop the curtain'],
    'zeal': ['abandon', 'acquiescence', 'agitation', 'agreeability', 'agreeableness', 'alacrity', 'all-overs', 'amenability', 'angst', 'anxiety', 'anxiety hysteria', 'anxiety neurosis'],
    'zealot': ['christian', 'god-fearing man', 'accepter', 'addict', 'adherent', 'aficionado', 'alien', 'believer', 'bigot', 'buff', 'bug', 'case'],
    'zealotry': ['bibliolatry', 'bigotry', 'charismatic gift', 'charismatic movement', 'charismatic renewal', 'excessiveness', 'extravagance', 'extremeness', 'extremism', 'fanaticalness', 'fanaticism', 'fervor'],
    'zealous': ['abandoned', 'ablaze', 'acquiescent', 'afire', 'agitated', 'agreeable', 'alacritous', 'all-overish', 'amenable', 'anxious', 'anxioused up', 'apprehensive'],
    'zenith': ['olympian heights', 'acme', 'aerial heights', 'apex', 'apogee', 'authority', 'authorization', 'be-all and end-all', 'blue ribbon', 'brow', 'cap', 'capstone'],
    'zephyr': ['air', 'blubber', 'breeze', 'butter', 'clay', 'cooling breeze', 'cushion', 'dough', 'down', 'eiderdown', 'feather bed', 'feathers'],
    'zero': ['absolute zero', 'aught', 'blank', 'boiling point', 'cipher', 'concentrate on', 'dew point', 'duck', 'dud', 'dummy', 'fix on', 'focus on'],
    'zero hour': ['a-day', 'd day', 'h hour', 'charged moment', 'contingency', 'crisis', 'critical moment', 'crossroads', 'crucial moment', 'deadline', 'decisive moment', 'eleventh hour'],
    'zero in on': ['aim at', 'allocate', 'assign', 'barrage', 'blast', 'blitz', 'bombard', 'cannon', 'cannonade', 'collocate', 'commence firing', 'deploy'],
    'zest': ['activity', 'alacrity', 'amusement', 'animal pleasure', 'animal spirits', 'animation', 'anxiety', 'anxiousness', 'appetite', 'ardor', 'avidity', 'avidness'],
    'zestful': ['active', 'acute', 'aggressive', 'agog', 'alacritous', 'all agog', 'animated', 'antic', 'anxious', 'avid', 'bracing', 'breathless'],
    'zeus': ['agdistis', 'amor', 'aphrodite', 'apollo', 'apollon', 'ares', 'artemis', 'ate', 'athena', 'bacchus', 'ceres', 'cora'],
    'zigzag': ['v-shaped', 'y-shaped', 'aberrancy', 'aberrant', 'aberration', 'aberrative', 'akimbo', 'alternate', 'angle', 'angle off', 'angular', 'apex'],
    'zilch': ['aught', 'cipher', 'goose egg', 'insignificancy', 'nada', 'naught', 'nichts', 'nihil', 'nil', 'nix', 'no such thing', 'nobody'],
    'zillion': ['a billion', 'a crore', 'a lakh', 'a million', 'a myriad', 'a nonillion', 'a quadrillion', 'a thousand', 'a zillion', 'astronomical number', 'billion', 'considerable'],
    'zing': ['aggressiveness', 'animation', 'ardor', 'ball the jack', 'bang', 'barrel', 'boom', 'bowl along', 'breeze', 'breeze along', 'brio', 'brush'],
    'zingy': ['active', 'activist', 'activistic', 'alive', 'animated', 'bouncing', 'bouncy', 'breezy', 'brisk', 'bubbly', 'chipper', 'ebullient'],
    'zion': ['canaan', 'celestial city', 'city celestial', 'city of god', 'civitas dei', 'cockaigne', 'holy city', 'new jerusalem', 'shangri-la', 'arcadia', 'bliss', 'elysium'],
    'zip': ['aggressiveness', 'animal spirits', 'animation', 'assibilate', 'assibilation', 'ball the jack', 'bang', 'barrel', 'bite', 'boom', 'bowl along', 'breeze'],
    'zip up': ['animate', 'arouse', 'bang', 'bar', 'barricade', 'batten', 'batten down', 'bolt', 'button', 'button up', 'choke', 'choke off'],
    'zipper': ['articulate', 'bang', 'bar', 'barricade', 'batten', 'batten down', 'bolt', 'buckle', 'butt', 'button', 'button up', 'choke'],
    'zippy': ['active', 'acute', 'aggressive', 'alert', 'animated', 'antic', 'brisk', 'burning', 'capersome', 'catty', 'coltish', 'curried'],
    'zodiac': ['anklet', 'aphelion', 'apogee', 'armlet', 'aspect', 'astrodiagnosis', 'astrology', 'astromancy', 'astronomical longitude', 'autumnal equinox', 'band', 'belt'],
    'zombie': ['masan', 'apparition', 'appearance', 'astral', 'astral spirit', 'banshee', 'boob', 'case', 'character', 'chump', 'clod', 'control'],
    'zone': ['area', 'bailiwick', 'belt', 'circle', 'department', 'district', 'domain', 'locale', 'locality', 'precinct', 'province', 'quarter'],
    'zoning': ['eighteenth amendment', 'prohibition party', 'volstead act', 'abstraction', 'alienation', 'ban', 'contraband', 'denial', 'detachment', 'disallowance', 'disarticulation', 'disassociation'],
    'zonked': ['afflicted', 'asleep', 'bent', 'boiled', 'bombed', 'boozy', 'canned', 'cataleptic', 'catatonic', 'cockeyed', 'cockeyed drunk', 'cold'],
    'zoo': ['festschrift', 'ana', 'anthology', 'aquarium', 'body', 'chrestomathy', 'collectanea', 'collection', 'compilation', 'corpus', 'data', 'florilegium'],
    'zoological': ['animal', 'animalian', 'animalic', 'animalistic', 'beastlike', 'beastly', 'bestial', 'brutal', 'brute', 'brutelike', 'brutish', 'dumb'],
    'zoologist': ['anatomist', 'animal physiologist', 'anthropologist', 'bacteriologist', 'biochemist', 'biologist', 'biometrist', 'biophysicist', 'botanist', 'conchologist', 'cytologist', 'ecologist'],
    'zoology': ['aerobiology', 'agrobiology', 'anatomy', 'astrobiology', 'bacteriology', 'biochemics', 'biochemistry', 'biochemy', 'bioecology', 'biological science', 'biology', 'biometrics'],
    'zoom': ['acrobatics', 'aerobatics', 'ascend', 'aspire', 'ball the jack', 'banking', 'barrel', 'become airborne', 'boom', 'bowl along', 'breeze', 'breeze along'],
}

# ═══════════════════════════════════════════════════════════
#  RUSSIAN SYNONYMS
# ═══════════════════════════════════════════════════════════

RU_SYNONYMS: dict[str, list[str]] = {
    'абсолютно': ['совершенно', 'совсем', 'полностью'],
    'анализ': ['декомпозиция', 'разбор'],
    'большой': ['крупный', 'значительный', 'многочисленный', 'выдающийся', 'взрослый', 'больший'],
    'брать': ['хватать', 'захватывать', 'схватывать', 'поднимать', 'доставать', 'покупать', 'получать', 'захватывать', 'бить', 'рубить', 'арестовывать', 'овладевать'],
    'быстро': ['живо', 'бойко', 'бегло', 'проворно', 'поспешно', 'спешно', 'скоро', 'стремительно', 'торопливо', 'пулей', 'мухой', 'молнией'],
    'важный': ['значительный', 'значимый', 'горделивый', 'величавый', 'внушительный', 'напыщенный', 'высокопоставленный', 'высокий', 'существенный'],
    'великий': ['большой', 'значительный'],
    'верный': ['правильный', 'истинный', 'точный', 'неизбежный', 'предсказуемый', 'непременный', 'характерный', 'преданный', 'надёжный', 'безотказный'],
    'вероятно': ['возможно'],
    'весьма': ['чересчур', 'чрезмерно', 'излишне', 'очень', 'слишком', 'сильно', 'шибко', 'превесьма больно', 'оченно', 'сверх меры', 'избыточно', 'чрезвычайно'],
    'вид': ['облик', 'лик', 'образ', 'картина', 'панорама', 'поле зрения', 'план', 'тип', 'класс', 'разновидность', 'категория'],
    'видеть': ['зреть', 'замечать', 'видать', 'лицезреть', 'зреть', 'узревать', 'считать', 'думать', 'полагать', 'находить', 'рассматривать', 'смотреть'],
    'возможность': ['вероятность'],
    'вопрос': ['дело', 'проблема', 'вопросительный знак'],
    'высокий': ['большой', 'большой', 'важный', 'уважаемый'],
    'главный': ['основной', 'головной', 'ведущий', 'важнейший', 'верховный', 'первостепенный', 'центральный', 'директор', 'начальник', 'предводитель', 'руководитель'],
    'говорить': ['разговаривать', 'разговаривать', 'сообщать', 'подсказывать', 'предсказывать', 'беседовать', 'разговаривать', 'переговариваться', 'поговаривать', 'молва ходит', 'сплетничать', 'судачить'],
    'громкий': ['шумный', 'звучный', 'громогласный'],
    'группа': ['коллектив', 'круг', 'совокупность'],
    'грязный': ['запачканный', 'недостойный', 'непристойный', 'мутный', 'мусорный'],
    'данный': ['этот', 'сей', 'настоящий', 'определённый', 'известный'],
    'движение': ['перемещение'],
    'действительно': ['вправду', 'правда', 'в самом деле', 'на самом деле', 'поистине', 'впрямь', 'верно', 'точно', 'правда', 'в самом деле'],
    'дело': ['работа', 'бизнес', 'предприятие', 'досье'],
    'демонстрировать': ['показывать', 'представлять', 'выставлять'],
    'день': ['свет', 'сутки', 'праздник', 'юбилей', 'годовщина', 'час', 'момент'],
    'длинный': ['вытянутый', 'долгий', 'долгий', 'длительный', 'продолжительный', 'высокий', 'долговязый', 'рослый', 'высокорослый', 'верзила', 'дылда', 'каланча'],
    'довольно': ['удовлетворённо', 'радостно'],
    'древний': ['архаичный'],
    'думать': ['мыслить', 'осмысливать', 'обдумывать', 'размышлять', 'полагать', 'считать', 'находить', 'рассматривать', 'смотреть', 'усматривать', 'видеть', 'предполагать'],
    'жизнь': ['дни', 'бытие'],
    'жёсткий': ['твёрдый', 'неподатливый', 'прочный', 'суровый', 'грубый'],
    'знать': ['видать', 'видно', 'очевидно', 'значит', 'по-видимому'],
    'значимый': ['существенный', 'важный', 'значительный', 'серьезный', 'ценный', 'авторитетный', 'принципиальный', 'весомый', 'немаловажный', 'первостепенный', 'общезначимый', 'означающий'],
    'значительный': ['большой', 'крупный', 'солидный', 'существенный', 'важный', 'значимый', 'приоритетный', 'многозначительный', 'ёмкий'],
    'иногда': ['временами', 'порой', 'подчас', 'время от времени', 'по временам', 'годом-родом', 'временами', 'иной раз'],
    'искать': ['шукать'],
    'использовать': ['пользоваться', 'употреблять', 'применять', 'прибегать', 'эксплуатировать', 'утилизировать', 'пользоваться', 'воспользоваться'],
    'комплексный': ['кватернион'],
    'короткий': ['краткий', 'недолгий', 'кратковременный', 'невысокий', 'низкий', 'приземистый', 'краткий', 'краткий', 'немногословный', 'близкий', 'доверительный'],
    'красивый': ['симпатичный', 'очаровательный', 'прекрасный', 'пригожий', 'смазливый', 'миловидный', 'красивущий'],
    'личный': ['персональный', 'частный', 'собственный', 'интимный'],
    'ложный': ['лживый', 'неверный'],
    'маленький': ['малый', 'незначительный', 'небольшой', 'невеликий', 'невысокий', 'низкорослый', 'малочисленный', 'незначительный', 'ничтожный', 'маловажный', 'малолетний', 'младшенький'],
    'малый': ['маленький', 'незначительный', 'небольшой', 'тесный', 'узкий', 'несовершеннолетний', 'парень', 'пацан', 'мальчик', 'юноша', 'детина'],
    'медленно': ['не спеша', 'неспешно', 'потихоньку', 'тихо'],
    'менять': ['обменивать', 'выменивать', 'заменять', 'сменять', 'замещать', 'преобразовывать', 'изменять', 'модифицировать', 'разменивать'],
    'место': ['местоположение', 'расположение', 'точка', 'пространство', 'объём', 'площадь'],
    'метод': ['метода'],
    'мир': ['спокойствие', 'мирный договор', 'мирный трактат'],
    'мнение': ['суждение', 'точка зрения', 'оценка', 'взгляд', 'видение#ви́дение'],
    'мысль': ['мышление', 'рассуждение', 'дума', 'помысел', 'идея', 'концепция'],
    'мягкий': ['пластичный', 'податливый', 'пушистый', 'нежный', 'тонкий', 'учтивый', 'вежливый', 'воспитанный', 'благоприятный', 'здоровый', 'гашиш', 'дурь'],
    'необходимый': ['насущный', 'незаменимый', 'потребный', 'требуемый', 'неизбежный', 'неотложный'],
    'нижний': ['исподний', 'низовой', 'боттом'],
    'низкий': ['невысокий', 'невысокий', 'пониженный', 'недостаточный', 'неудовлетворительный', 'подлый', 'грубый', 'басовый', 'басистый'],
    'новый': ['нетрадиционный', 'незнакомый', 'недавний', 'свежий'],
    'область': ['район', 'регион', 'участок', 'местность', 'губерния', 'район', 'окрестность', 'отрасль', 'раздел', 'сфера', 'областной центр'],
    'общий': ['совместный', 'коллективный', 'совокупный', 'суммарный', 'отвлечённый', 'неконкретный', 'расхожий', 'свойственный', 'относящийся', 'касающийся'],
    'обычно': ['заурядно', 'привычно', 'чаще всего', 'как правило', 'заурядно'],
    'обычный': ['нормальный', 'обыденный', 'привычный'],
    'определять': ['идентифицировать', 'обнаруживать', 'выявлять', 'давать определение', 'устанавливать', 'назначать', 'обуславливать', 'задавать', 'детерминировать', 'устраивать', 'пристраивать'],
    'оптимальный': ['наилучший'],
    'основа': ['база', 'базис', 'основание', 'остов', 'опора', 'сущность', 'ость'],
    'основной': ['базовый', 'фундаментальный', 'главный', 'ведущий', 'важнейший'],
    'острый': ['вострый', 'отточенный', 'вострый', 'вострый', 'жгучий', 'едкий', 'вострый', 'вострый', 'критический', 'высокотемпературный'],
    'осуществлять': ['воплощать', 'реализовывать', 'претворять в жизнь', 'совершать', 'делать', 'выполнять', 'вести'],
    'очень': ['чересчур', 'чрезмерно', 'излишне', 'слишком', 'сильно', 'весьма', 'сверх меры', 'избыточно', 'чрезвычайно', 'крайне', 'изрядно', 'в высшей степени'],
    'передний': ['лицевой', 'фронтальный', 'первый', 'предний'],
    'план': ['чертёж', 'карта', 'схема', 'рисунок', 'проекция', 'проект', 'намётка', 'программа', 'намерение', 'умысел', 'замысел', 'задумка'],
    'плохой': ['дурной', 'нехороший', 'некачественный', 'скверный', 'безнравственный', 'аморальный', 'недостаточный', 'малый', 'слабый', 'больной'],
    'поздний': ['конечный', 'запоздалый', 'несвоевременный'],
    'полностью': ['до конца', 'без остатка', 'целиком', 'всецело'],
    'помогать': ['содействовать', 'способствовать', 'оказывать помощь', 'подсоблять'],
    'правильный': ['верный', 'подходящий', 'должный', 'истинный', 'нормальный', 'истинный', 'нужный', 'удовлетворительный', 'верный'],
    'проблема': ['задача', 'вопрос', 'затруднение', 'препятствие', 'трабл'],
    'простой': ['понятный', 'доступный', 'лёгкий', 'несложный', 'элементарный', 'примитивный', 'незамысловатый', 'беспримесный', 'обычный', 'обыкновенный', 'скромный', 'дешёвый'],
    'работать': ['пользоваться', 'обслуживать', 'служить', 'служить', 'действовать', 'функционировать', 'фурычить', 'пыхтеть', 'пахать', 'фунциклировать'],
    'ранний': ['начальный'],
    'реализовать': ['осуществлять', 'осуществить', 'продавать', 'продать', 'сбывать', 'сбыть'],
    'регулярно': ['систематически', 'постоянно', 'размеренно', 'упорядоченно'],
    'результат': ['итог', 'следствие', 'плод', 'последствие', 'продукт', 'развязка', 'конец', 'исход', 'эффект', 'выхлоп', 'показатель', 'достижение'],
    'решение': ['поиск', 'выяснение', 'разрешение', 'постановление', 'ответ', 'разгадка', 'выбор', 'идея'],
    'рука': ['кисть', 'длань', 'протез', 'манипулятор', 'почерк'],
    'сильный': ['мощный', 'могучий', 'крепкий', 'мускулистый', 'жилистый'],
    'система': ['систематичность', 'закономерность', 'система счисления', 'геологическая система'],
    'слово': ['дума', 'реч', 'обръщение', 'проповед'],
    'совершенно': ['безупречно', 'безукоризненно', 'идеально', 'в совершенстве', 'совсем', 'полностью', 'абсолютно', 'напрочь'],
    'совсем': ['полностью', 'совершенно', 'абсолютно', 'вполне', 'вовсе', 'ничуть', 'нисколько', 'навсегда', 'насовсем'],
    'способ': ['метод'],
    'способствовать': ['помогать', 'пособлять', 'подсоблять', 'содействовать', '\xadспоспешествовать', 'благоприятствовать'],
    'старый': ['пожилой', 'изношенный', 'знакомый', 'устаревший', 'древний', 'бывший', 'прежний'],
    'стоять': ['находиться', 'покоиться', 'бездействовать'],
    'структура': ['устройство', 'строение', 'запись', 'организация', 'учреждение'],
    'сухой': ['безводный', 'иссохший', 'пересохший', 'худощавый', 'тощий', 'тонкий', 'сухопарый', 'поджарый', 'холодный', 'суровый', 'малословный', 'безучастный'],
    'существенно': ['значительно', 'заметно', 'намного', 'важно', 'значимо', 'немаловажно'],
    'существенный': ['первостепенный', 'значимый', 'значительный', 'важный', 'весомый', 'заметный', 'знаменательный', 'кардинальный', 'конкретный', 'немаловажный', 'основной', 'принципиальный'],
    'тупой': ['незаострённый', 'затупленный', 'неострый', 'неострый', 'приглушённый', 'нерезкий', 'неострый', 'притупившийся', 'безмозглый', 'безголовый', 'бестолковый', 'глупый'],
    'тяжёлый': ['увесистый', 'массивный', 'трудный', 'сложный', 'невосполнимый', 'густой', 'низкий'],
    'тёмный': ['печальный', 'безрадостный', 'мрачный', 'гнетущий', 'хмурый', 'печальный', 'безрадостный', 'мрачный', 'гнетущий', 'хмурый'],
    'узкий': ['тесный', 'тонкий', 'небольшой', 'неширокий'],
    'уменьшать': ['сокращать', 'убавлять', 'умаливать'],
    'условие': ['соглашение', 'договор', 'договорённость', 'пункт', 'требование'],
    'устанавливать': ['постанавливать'],
    'форма': ['внешность', 'вид', 'очертания', 'наружность', 'техника', 'бланк', 'шаблон', 'формуляр', 'стереотип', 'матрица', 'униформа', 'мундир'],
    'фундаментальный': ['солидный', 'основательный', 'глубокий', 'солидный'],
    'хотеть': ['желать', 'алкать'],
    'цель': ['умысел', 'намерение', 'предел', 'задача', 'объект', 'мишень', 'жертва', 'мушка'],
    'частный': ['частичный', 'отдельный', 'случайный', 'нехарактерный', 'личный', 'приватный', 'персональный', 'личный', 'индивидуальный', 'приватный'],
    'часть': ['доля', 'полк', 'корабль', 'войсковая часть'],
    'человек': ['землянин', 'гомо сапиенс', 'хомо сапиенс', 'слуга', 'половой', 'официант', 'лакей'],
    'чистый': ['непорочный', 'целомудренный', 'невинный'],
    'широкий': ['толстый', 'просторный', 'большой'],
    'эффективный': ['действенный', 'результативный', 'равноэффективный', 'аналогичный'],
    'ясный': ['светлый', 'чёткий', 'отчётливый', 'внятный', 'понятный', 'очевидный', 'доступный', 'постижимый', 'внятный'],
}

# ═══════════════════════════════════════════════════════════
#  UKRAINIAN SYNONYMS
# ═══════════════════════════════════════════════════════════

UK_SYNONYMS: dict[str, list[str]] = {
    'високий': ['височезний', 'височенний', 'превисокий', 'превисоченний', 'підхмарний', 'висотний', 'гінкий', 'прогонистий', 'крутий', 'панівний', 'височезний', 'височенний'],
    'день': ['доба', 'дата', 'життя'],
    'досить': ['достатньо', 'багато', 'доста'],
    'здійснювати': ['вчиняти', 'реалізувати', 'виконувати', 'втілювати'],
    'мета': ['ціль', 'мішень', 'задум', 'намір', 'план', 'зміст'],
    'місце': ['місцина', 'локаль', 'фрагмент', 'позиція', 'вакансія', 'вакантне місце'],
    'питання': ['запитання'],
    'показувати': ['демонструвати', 'являти', 'появляти', 'знайомити', 'позначати', 'позначувати', 'виставляти', 'афішувати', "пред'являти"],
    'спосіб': ['засіб', 'прийом'],
    'стан': ['торс', 'талія'],
    'сторона': ['аспект'],
}


SYNONYMS: dict[str, dict[str, list[str]]] = {
    "en": EN_SYNONYMS,
    "ru": RU_SYNONYMS,
    "uk": UK_SYNONYMS,
}


def get_synonyms(word: str, lang: str = 'en') -> list[str]:
    """Get synonyms for a word in the given language."""
    db = SYNONYMS.get(lang, {})
    # Try exact match, then lowercase
    result = db.get(word) or db.get(word.lower(), [])
    return list(result)
